#!/usr/bin/env python3
# -*- coding: utf-8 -*-

'''
ERG pred - WordNet sense mapping

Latest version can be found at https://github.com/letuananh/intsem.fx

@author: Le Tuan Anh <tuananh.ke@gmail.com>
@license: MIT
'''

# Copyright (c) 2017, Le Tuan Anh <tuananh.ke@gmail.com>
#
#Permission is hereby granted, free of charge, to any person obtaining a copy
#of this software and associated documentation files (the "Software"), to deal
#in the Software without restriction, including without limitation the rights
#to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#copies of the Software, and to permit persons to whom the Software is
#furnished to do so, subject to the following conditions:
#
#The above copyright notice and this permission notice shall be included in
#all copies or substantial portions of the Software.
#
#THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
#THE SOFTWARE.

########################################################################

from collections import namedtuple


# ----------------------------------------------------------------------
# Configuration
# ----------------------------------------------------------------------

SenseInfo = namedtuple('SenseInfo', 'synsetid freq'.split())

ERG_PRED_MAP = {
"_at+large_p_rel" : [ SenseInfo('00104233-r', 3), SenseInfo('01062114-a', 1) ],
"_toss_v_aside_rel" : [ SenseInfo('01512625-v', 13), SenseInfo('01893079-v', 10), SenseInfo('01514525-v', 5), SenseInfo('01890792-v', 4), SenseInfo('02222318-v', 1), SenseInfo('01418536-v', 1) ],
"_excerpt_n_1_rel" : [ SenseInfo('06400510-n', 0) ],
"_architectonic_a_1_rel" : [ SenseInfo('02898121-a', 0) ],
"_document_n_1_rel" : [ SenseInfo('06470073-n', 3), SenseInfo('03217458-n', 1), SenseInfo('13403331-n', 0), SenseInfo('06510977-n', 0) ],
"_high+grade_a_1_rel" : [ SenseInfo('00228173-a', 0) ],
"_a+tad_a_1_rel" : [  ],
"_crudity_n_1_rel" : [ SenseInfo('14472624-n', 1), SenseInfo('04915121-n', 1) ],
"_keyword_n_1_rel" : [  ],
"_alienation_n_1_rel" : [ SenseInfo('07502387-n', 2), SenseInfo('14415773-n', 0), SenseInfo('01108150-n', 0), SenseInfo('00035891-n', 0) ],
"_auger_v_1_rel" : [  ],
"_grommet_n_1_rel" : [ SenseInfo('03132438-n', 0) ],
"_transplant_n_of_rel" : [ SenseInfo('05582859-n', 0), SenseInfo('00693679-n', 0), SenseInfo('00331102-n', 0) ],
"_bobbin_n_1_rel" : [ SenseInfo('02860415-n', 0) ],
"_unknown_n_1_rel" : [ SenseInfo('08632096-n', 5), SenseInfo('10661002-n', 0), SenseInfo('07271648-n', 0) ],
"_curriculum_n_1_rel" : [ SenseInfo('06676416-n', 7) ],
"_bypass_v_1_rel" : [ SenseInfo('00811171-v', 4) ],
"_misformed_a_1_rel" : [  ],
"_for_p_ncond-i_rel" : [  ],
"_snort_n_1_rel" : [ SenseInfo('07128060-n', 0), SenseInfo('07123870-n', 0) ],
"_spade_n_1_rel" : [ SenseInfo('04266660-n', 2), SenseInfo('04266486-n', 1), SenseInfo('09638009-n', 0) ],
"_monochrome_a_1_rel" : [ SenseInfo('00398816-a', 0) ],
"_scam_n_1_rel" : [ SenseInfo('00754280-n', 0) ],
"_lemur_n_1_rel" : [ SenseInfo('02496913-n', 0) ],
"_admitted_a_1_rel" : [  ],
"_rally_v_1_rel" : [ SenseInfo('01385643-v', 3), SenseInfo('01097960-v', 2), SenseInfo('01381549-v', 1), SenseInfo('00528608-v', 1), SenseInfo('00850501-v', 0) ],
"_bludgeon_n_1_rel" : [ SenseInfo('02855793-n', 2) ],
"_bride_n_1_rel" : [ SenseInfo('09874618-n', 3), SenseInfo('10864204-n', 0), SenseInfo('09874725-n', 0) ],
"_advise_v_1_rel" : [ SenseInfo('00872886-v', 11), SenseInfo('00873682-v', 10), SenseInfo('00875394-v', 4), SenseInfo('00872886-v', 11), SenseInfo('00873682-v', 10), SenseInfo('00875394-v', 4), SenseInfo('00872886-v', 11), SenseInfo('00873682-v', 10), SenseInfo('00875394-v', 4), SenseInfo('00872886-v', 11), SenseInfo('00873682-v', 10), SenseInfo('00875394-v', 4), SenseInfo('00872886-v', 11), SenseInfo('00873682-v', 10), SenseInfo('00875394-v', 4), SenseInfo('00872886-v', 11), SenseInfo('00873682-v', 10), SenseInfo('00875394-v', 4) ],
"_billiards_n_1_rel" : [ SenseInfo('00499924-n', 0), SenseInfo('00499924-n', 0) ],
"_account_n_i_rel" : [ SenseInfo('06514093-n', 12), SenseInfo('06681551-n', 7), SenseInfo('13929037-n', 5), SenseInfo('06738281-n', 3), SenseInfo('09179382-n', 1), SenseInfo('05169037-n', 1), SenseInfo('13354985-n', 0), SenseInfo('07217924-n', 0), SenseInfo('06516955-n', 0), SenseInfo('05157732-n', 0) ],
"_visual_a_1_rel" : [ SenseInfo('02869563-a', 27), SenseInfo('02516148-a', 0), SenseInfo('02869563-a', 27), SenseInfo('02516148-a', 0) ],
"_adorable_a_1_rel" : [ SenseInfo('01459755-a', 0) ],
"_lucrative_a_1_rel" : [ SenseInfo('01871774-a', 0) ],
"_eminent_a_1_rel" : [ SenseInfo('02339120-a', 0), SenseInfo('01205473-a', 0) ],
"_idiot_n_1_rel" : [ SenseInfo('10197525-n', 4) ],
"_sprinkle_n_of_rel" : [ SenseInfo('11506167-n', 0), SenseInfo('00278555-n', 0) ],
"_self-analysis_n_1_rel" : [ SenseInfo('05786871-n', 0), SenseInfo('00705433-n', 0) ],
"_melancholy_n_1_rel" : [ SenseInfo('07533097-n', 4), SenseInfo('14404722-n', 0), SenseInfo('05406782-n', 0) ],
"_write_v_in_rel" : [ SenseInfo('01698271-v', 112), SenseInfo('00993014-v', 94), SenseInfo('01744611-v', 33), SenseInfo('01007027-v', 15), SenseInfo('01031966-v', 10), SenseInfo('01705494-v', 9), SenseInfo('01691057-v', 8), SenseInfo('00998886-v', 4), SenseInfo('01699896-v', 1), SenseInfo('01692834-v', 0) ],
"_all+morning+long_a_1_rel" : [  ],
"_pilgrim_n_1_rel" : [ SenseInfo('10432441-n', 1), SenseInfo('10432674-n', 0), SenseInfo('10432532-n', 0) ],
"_ex+husband_n_1_rel" : [ SenseInfo('10194231-n', 1), SenseInfo('10194231-n', 1) ],
"_no+matter+what_a_1_rel" : [  ],
"_tentative_a_1_rel" : [ SenseInfo('00556318-a', 7), SenseInfo('02130672-a', 0), SenseInfo('00556318-a', 7), SenseInfo('02130672-a', 0) ],
"_buy+out_n_1_rel" : [ SenseInfo('00789534-n', 0), SenseInfo('00789534-n', 0) ],
"_split_v_off_rel" : [ SenseInfo('02467662-v', 4), SenseInfo('01556572-v', 3), SenseInfo('02431320-v', 2), SenseInfo('02030158-v', 2), SenseInfo('00309310-v', 2), SenseInfo('02467662-v', 4), SenseInfo('01556572-v', 3), SenseInfo('02431320-v', 2), SenseInfo('02030158-v', 2), SenseInfo('00309310-v', 2) ],
"_throng_n_of_rel" : [ SenseInfo('08182716-n', 3) ],
"_variorum_a_1_rel" : [ SenseInfo('06590723-n', 0) ],
"_shrill_a_1_rel" : [ SenseInfo('01214430-a', 9), SenseInfo('00713853-a', 0), SenseInfo('00403982-a', 0), SenseInfo('01214430-a', 9), SenseInfo('00713853-a', 0), SenseInfo('00403982-a', 0), SenseInfo('01214430-a', 9), SenseInfo('00713853-a', 0), SenseInfo('00403982-a', 0) ],
"_tide_n_of_rel" : [ SenseInfo('07402519-n', 5), SenseInfo('07444495-n', 1), SenseInfo('15275727-n', 0) ],
"_obey_v_1_rel" : [ SenseInfo('02542795-v', 14) ],
"_by+and+by_a_1_rel" : [  ],
"_nominative_n_1_rel" : [ SenseInfo('06311160-n', 0), SenseInfo('06311160-n', 0), SenseInfo('06311160-n', 0) ],
"_chili_n_1_rel" : [ SenseInfo('07864934-n', 0), SenseInfo('07721456-n', 0) ],
"_scotsman_n_1_rel" : [ SenseInfo('09730533-n', 0) ],
"_hour+long_a_1_rel" : [ SenseInfo('01440058-a', 0), SenseInfo('01440058-a', 0) ],
"_ado_n_1_rel" : [ SenseInfo('00555138-n', 1) ],
"_perfectly_x_rel" : [ SenseInfo('00008997-r', 13), SenseInfo('00009650-r', 2) ],
"_unleash_v_1_rel" : [ SenseInfo('01475415-v', 2), SenseInfo('01475828-v', 1), SenseInfo('01475536-v', 1), SenseInfo('01475415-v', 2), SenseInfo('01475828-v', 1), SenseInfo('01475536-v', 1) ],
"_trench_n_1_rel" : [ SenseInfo('04478657-n', 2), SenseInfo('09461315-n', 0), SenseInfo('04478889-n', 0) ],
"_grep_v_1_rel" : [  ],
"_sue_v_1_rel" : [ SenseInfo('02582042-v', 8) ],
"_compassion_n_for_rel" : [ SenseInfo('07553741-n', 2), SenseInfo('04829550-n', 1) ],
"_wring_v_out_rel" : [ SenseInfo('01350699-v', 1), SenseInfo('01349130-v', 1), SenseInfo('02241107-v', 0), SenseInfo('01350971-v', 0) ],
"_statutory_a_1_rel" : [ SenseInfo('02802848-a', 4), SenseInfo('01401532-a', 0) ],
"_nw_n_of_rel" : [ SenseInfo('13834885-n', 0) ],
"_discoverer_n_of_rel" : [ SenseInfo('10214637-n', 0), SenseInfo('10090498-n', 0) ],
"_battle_n_1_rel" : [ SenseInfo('00953559-n', 73), SenseInfo('00788973-n', 8), SenseInfo('00958896-n', 0) ],
"_mantelpiece_n_1_rel" : [ SenseInfo('03719343-n', 0) ],
"_jungle+gym_n_1_rel" : [ SenseInfo('03603442-n', 0) ],
"_pull_v_out_rel" : [ SenseInfo('01448100-v', 44), SenseInfo('01505254-v', 8), SenseInfo('02057499-v', 6), SenseInfo('01609287-v', 3), SenseInfo('02582615-v', 2), SenseInfo('01995211-v', 2), SenseInfo('02057337-v', 1), SenseInfo('00071803-v', 1), SenseInfo('02103162-v', 0), SenseInfo('01947247-v', 0), SenseInfo('01858573-v', 0), SenseInfo('01573276-v', 0), SenseInfo('01407059-v', 0), SenseInfo('01384275-v', 0), SenseInfo('01351170-v', 0), SenseInfo('01148710-v', 0), SenseInfo('00571596-v', 0), SenseInfo('01448100-v', 44), SenseInfo('01505254-v', 8), SenseInfo('02057499-v', 6), SenseInfo('01609287-v', 3), SenseInfo('02582615-v', 2), SenseInfo('01995211-v', 2), SenseInfo('02057337-v', 1), SenseInfo('00071803-v', 1), SenseInfo('02103162-v', 0), SenseInfo('01947247-v', 0), SenseInfo('01858573-v', 0), SenseInfo('01573276-v', 0), SenseInfo('01407059-v', 0), SenseInfo('01384275-v', 0), SenseInfo('01351170-v', 0), SenseInfo('01148710-v', 0), SenseInfo('00571596-v', 0) ],
"_leer_v_at_rel" : [ SenseInfo('02164288-v', 3), SenseInfo('02164288-v', 3) ],
"_prohibit_v_1_rel" : [ SenseInfo('00795863-v', 8) ],
"_hatchet_n_1_rel" : [ SenseInfo('04449966-n', 0), SenseInfo('03498962-n', 0) ],
"_buoy_v_up_rel" : [ SenseInfo('01904795-v', 0), SenseInfo('01218512-v', 0), SenseInfo('00922771-v', 0) ],
"_champion_v_1_rel" : [ SenseInfo('01149138-v', 1) ],
"_discipline_n_1_rel" : [ SenseInfo('05996646-n', 2), SenseInfo('05662876-n', 2), SenseInfo('04881623-n', 2), SenseInfo('00893836-n', 1), SenseInfo('01161821-n', 0) ],
"_nazi_n_1_rel" : [ SenseInfo('10350220-n', 6), SenseInfo('10350484-n', 0) ],
"_allure_n_1_rel" : [ SenseInfo('04688842-n', 0) ],
"_ukulele_n_1_rel" : [ SenseInfo('04506289-n', 0) ],
"_adhesive_a_1_rel" : [ SenseInfo('00052672-a', 0) ],
"_operetta_n_1_rel" : [ SenseInfo('07027090-n', 4) ],
"_covering_n_1_rel" : [ SenseInfo('09257949-n', 0), SenseInfo('03122748-n', 0), SenseInfo('01049685-n', 0), SenseInfo('00828082-n', 0), SenseInfo('00712225-n', 0) ],
"_hustle_n_1_rel" : [ SenseInfo('00779248-n', 0), SenseInfo('00555138-n', 0) ],
"_feedmill_n_1_rel" : [  ],
"_content_a_to_rel" : [ SenseInfo('00588797-a', 0), SenseInfo('00588797-a', 0) ],
"_prepare_v_for_rel" : [ SenseInfo('00406243-v', 45), SenseInfo('01664172-v', 15), SenseInfo('01754271-v', 8), SenseInfo('01651444-v', 8), SenseInfo('02387034-v', 5), SenseInfo('00603298-v', 2), SenseInfo('02179915-v', 0), SenseInfo('00602805-v', 0) ],
"_accompaniment_n_1_rel" : [ SenseInfo('07284554-n', 1), SenseInfo('07031752-n', 1), SenseInfo('05109511-n', 0), SenseInfo('00827782-n', 0) ],
"_strop_v_1_rel" : [ SenseInfo('01246959-v', 2) ],
"_squeeze_v_1_rel" : [ SenseInfo('01593937-v', 9), SenseInfo('01447868-v', 6), SenseInfo('01527271-v', 4), SenseInfo('02504562-v', 0), SenseInfo('02241107-v', 0), SenseInfo('02094569-v', 0), SenseInfo('01456771-v', 0), SenseInfo('01424456-v', 0), SenseInfo('01387786-v', 0) ],
"_escort_n_1_rel" : [ SenseInfo('09863031-n', 2), SenseInfo('00827782-n', 1), SenseInfo('10063461-n', 0), SenseInfo('09992538-n', 0) ],
"_fill_v_out_rel" : [ SenseInfo('00452512-v', 61), SenseInfo('00451838-v', 12), SenseInfo('02649042-v', 8), SenseInfo('02394183-v', 5), SenseInfo('01183573-v', 5), SenseInfo('02394081-v', 1), SenseInfo('01203893-v', 1), SenseInfo('01193721-v', 1), SenseInfo('00261533-v', 1), SenseInfo('00452512-v', 61), SenseInfo('00451838-v', 12), SenseInfo('02649042-v', 8), SenseInfo('02394183-v', 5), SenseInfo('01183573-v', 5), SenseInfo('02394081-v', 1), SenseInfo('01203893-v', 1), SenseInfo('01193721-v', 1), SenseInfo('00261533-v', 1) ],
"_stipulate_v_1_rel" : [ SenseInfo('01018928-v', 4), SenseInfo('01019472-v', 0), SenseInfo('00889026-v', 0), SenseInfo('01018928-v', 4), SenseInfo('01019472-v', 0), SenseInfo('00889026-v', 0), SenseInfo('01018928-v', 4), SenseInfo('01019472-v', 0), SenseInfo('00889026-v', 0) ],
"_herpes_n_1_rel" : [ SenseInfo('14131950-n', 0), SenseInfo('01338685-n', 0), SenseInfo('14131950-n', 0), SenseInfo('01338685-n', 0) ],
"_auntie_n_1_rel" : [ SenseInfo('09823502-n', 0) ],
"_hate_n_1_rel" : [ SenseInfo('07546465-n', 9) ],
"_minimize_v_1_rel" : [ SenseInfo('00427802-v', 12), SenseInfo('00841125-v', 2), SenseInfo('00864475-v', 0), SenseInfo('00427802-v', 12), SenseInfo('00841125-v', 2), SenseInfo('00864475-v', 0) ],
"_explanatory_a_1_rel" : [ SenseInfo('01324683-a', 1) ],
"_preference_n_for_rel" : [ SenseInfo('07498210-n', 2), SenseInfo('06200344-n', 2), SenseInfo('05791452-n', 0), SenseInfo('05158095-n', 0), SenseInfo('07498210-n', 2), SenseInfo('06200344-n', 2), SenseInfo('05791452-n', 0), SenseInfo('05158095-n', 0) ],
"_rucksack_n_1_rel" : [ SenseInfo('02769748-n', 0) ],
"_off-balance+sheet_a_1_rel" : [  ],
"_up-front_a_1_rel" : [ SenseInfo('00766348-a', 0), SenseInfo('00766348-a', 0) ],
"_not+always_a_rel" : [  ],
"_retort_v_1_rel" : [ SenseInfo('00816353-v', 4), SenseInfo('00816353-v', 4), SenseInfo('00816353-v', 4) ],
"_ping_v_1_rel" : [ SenseInfo('01236795-v', 1), SenseInfo('02178866-v', 0), SenseInfo('02178709-v', 0), SenseInfo('00743911-v', 0), SenseInfo('00743692-v', 0) ],
"_reason_v_with_rel" : [ SenseInfo('00634472-v', 3), SenseInfo('00772189-v', 2), SenseInfo('00632627-v', 1) ],
"_remarkable_a_to_rel" : [ SenseInfo('01678417-a', 13), SenseInfo('02163602-a', 2), SenseInfo('01678417-a', 13), SenseInfo('02163602-a', 2), SenseInfo('01678417-a', 13), SenseInfo('02163602-a', 2) ],
"_exclamation_n_1_rel" : [ SenseInfo('07125523-n', 7), SenseInfo('07209868-n', 0), SenseInfo('07102802-n', 0), SenseInfo('07125523-n', 7), SenseInfo('07209868-n', 0), SenseInfo('07102802-n', 0) ],
"_ukrainian_a_1_rel" : [ SenseInfo('02963665-a', 0) ],
"_infinitival_a_1_rel" : [ SenseInfo('02937294-a', 0) ],
"_fix_v_up_rel" : [ SenseInfo('00260648-v', 9), SenseInfo('01340439-v', 7), SenseInfo('00947077-v', 6), SenseInfo('01664172-v', 5), SenseInfo('01153947-v', 3), SenseInfo('01647543-v', 2), SenseInfo('00407458-v', 2), SenseInfo('00486998-v', 1), SenseInfo('00061595-v', 1), SenseInfo('02603299-v', 0), SenseInfo('01575675-v', 0), SenseInfo('00406243-v', 0) ],
"_note_v_1_rel" : [ SenseInfo('01020005-v', 41), SenseInfo('02118476-v', 36), SenseInfo('02118933-v', 29), SenseInfo('01020934-v', 3) ],
"_short-lived_a_1_rel" : [ SenseInfo('01756292-a', 2) ],
"_throw_v_up_rel" : [ SenseInfo('01508368-v', 53), SenseInfo('02097204-v', 9), SenseInfo('01513430-v', 7), SenseInfo('01499265-v', 7), SenseInfo('01060317-v', 6), SenseInfo('01510173-v', 5), SenseInfo('01632897-v', 4), SenseInfo('02097341-v', 2), SenseInfo('01791232-v', 2), SenseInfo('01067664-v', 2), SenseInfo('01733477-v', 1), SenseInfo('01663443-v', 0), SenseInfo('01527754-v', 0), SenseInfo('01437011-v', 0), SenseInfo('00621734-v', 0), SenseInfo('01508368-v', 53), SenseInfo('02097204-v', 9), SenseInfo('01513430-v', 7), SenseInfo('01499265-v', 7), SenseInfo('01060317-v', 6), SenseInfo('01510173-v', 5), SenseInfo('01632897-v', 4), SenseInfo('02097341-v', 2), SenseInfo('01791232-v', 2), SenseInfo('01067664-v', 2), SenseInfo('01733477-v', 1), SenseInfo('01663443-v', 0), SenseInfo('01527754-v', 0), SenseInfo('01437011-v', 0), SenseInfo('00621734-v', 0) ],
"_licentious_a_1_rel" : [ SenseInfo('00362269-a', 0) ],
"_cosmetic_a_1_rel" : [ SenseInfo('01091234-a', 0), SenseInfo('00070111-a', 0) ],
"_lady_n_1_rel" : [ SenseInfo('10243137-n', 27), SenseInfo('09989290-n', 3), SenseInfo('10242791-n', 0), SenseInfo('10243137-n', 27), SenseInfo('09989290-n', 3), SenseInfo('10242791-n', 0), SenseInfo('10243137-n', 27), SenseInfo('09989290-n', 3), SenseInfo('10242791-n', 0) ],
"_wavelength_n_1_rel" : [ SenseInfo('05086269-n', 25), SenseInfo('06208265-n', 1) ],
"_boxing_n_1_rel" : [ SenseInfo('00445802-n', 0), SenseInfo('00322228-n', 0) ],
"_diagnostic_a_1_rel" : [ SenseInfo('02975538-a', 1), SenseInfo('00357254-a', 0) ],
"_computerize_v_1_rel" : [ SenseInfo('02337364-v', 0), SenseInfo('02218759-v', 0), SenseInfo('01718952-v', 0), SenseInfo('02337364-v', 0), SenseInfo('02218759-v', 0), SenseInfo('01718952-v', 0) ],
"_dominion_n_1_rel" : [ SenseInfo('14442933-n', 4), SenseInfo('08552138-n', 0), SenseInfo('08167249-n', 0) ],
"_throng_v_1_rel" : [ SenseInfo('02064131-v', 1) ],
"_neither_q_rel" : [  ],
"_sore_n_1_rel" : [ SenseInfo('14183065-n', 1) ],
"_law_n_1_rel" : [ SenseInfo('08441203-n', 50), SenseInfo('06532330-n', 24), SenseInfo('05870916-n', 11), SenseInfo('05872982-n', 5), SenseInfo('06161718-n', 3), SenseInfo('00611143-n', 2), SenseInfo('08209687-n', 1), SenseInfo('08441203-n', 50), SenseInfo('06532330-n', 24), SenseInfo('05870916-n', 11), SenseInfo('05872982-n', 5), SenseInfo('06161718-n', 3), SenseInfo('00611143-n', 2), SenseInfo('08209687-n', 1) ],
"_rehash_n_1_rel" : [ SenseInfo('06635759-n', 0) ],
"_slug_n_1_rel" : [ SenseInfo('02916350-n', 4), SenseInfo('13719102-n', 0), SenseInfo('13390788-n', 0), SenseInfo('10612931-n', 0), SenseInfo('07922607-n', 0), SenseInfo('04504935-n', 0), SenseInfo('01945685-n', 0), SenseInfo('00134780-n', 0) ],
"_topsail_n_1_rel" : [ SenseInfo('04455652-n', 0) ],
"_whiteness_n_1_rel" : [ SenseInfo('04960729-n', 1), SenseInfo('13990064-n', 0), SenseInfo('04978371-n', 0) ],
"_land_v_1_rel" : [ SenseInfo('01979901-v', 16), SenseInfo('01981036-v', 4), SenseInfo('00135857-v', 3), SenseInfo('02087156-v', 2), SenseInfo('02358527-v', 1), SenseInfo('01981436-v', 0), SenseInfo('01981279-v', 0), SenseInfo('01979901-v', 16), SenseInfo('01981036-v', 4), SenseInfo('00135857-v', 3), SenseInfo('02087156-v', 2), SenseInfo('02358527-v', 1), SenseInfo('01981436-v', 0), SenseInfo('01981279-v', 0), SenseInfo('01979901-v', 16), SenseInfo('01981036-v', 4), SenseInfo('00135857-v', 3), SenseInfo('02087156-v', 2), SenseInfo('02358527-v', 1), SenseInfo('01981436-v', 0), SenseInfo('01981279-v', 0) ],
"_swig_v_1_rel" : [ SenseInfo('01415585-v', 0), SenseInfo('01202068-v', 0) ],
"_revive_v_1_rel" : [ SenseInfo('00098083-v', 5), SenseInfo('00024279-v', 5), SenseInfo('00169298-v', 2), SenseInfo('00168910-v', 1), SenseInfo('00024047-v', 0) ],
"_tint_v_cause_rel" : [ SenseInfo('00286928-v', 1) ],
"_anxiety_n_1_rel" : [ SenseInfo('14374432-n', 20), SenseInfo('07523905-n', 9) ],
"_sport_v_1_rel" : [ SenseInfo('02631659-v', 1), SenseInfo('01883716-v', 0) ],
"_pensive_a_1_rel" : [ SenseInfo('02419434-a', 1), SenseInfo('01362950-a', 0) ],
"_unscientific_a_1_rel" : [ SenseInfo('02085132-a', 2), SenseInfo('02085132-a', 2) ],
"_buy-back_n_1_rel" : [ SenseInfo('00079212-n', 0), SenseInfo('00079212-n', 0) ],
"_conundrum_n_1_rel" : [ SenseInfo('06785223-n', 0) ],
"_approach_v_1_rel" : [ SenseInfo('02053941-v', 46), SenseInfo('02703952-v', 9), SenseInfo('02439281-v', 6), SenseInfo('01849746-v', 6), SenseInfo('00990392-v', 6) ],
"_camp_n_1_rel" : [ SenseInfo('02944826-n', 19), SenseInfo('08478018-n', 7), SenseInfo('02945161-n', 6), SenseInfo('08240633-n', 2), SenseInfo('02945379-n', 2), SenseInfo('05649960-n', 1), SenseInfo('02945813-n', 0), SenseInfo('02945594-n', 0) ],
"_brag_v_to_rel" : [ SenseInfo('00883226-v', 2), SenseInfo('00883226-v', 2) ],
"_misspelling_n_1_rel" : [ SenseInfo('06353653-n', 0) ],
"_desire_v_1_rel" : [ SenseInfo('01825237-v', 25), SenseInfo('01826723-v', 2), SenseInfo('01826378-v', 2), SenseInfo('01825237-v', 25), SenseInfo('01826723-v', 2), SenseInfo('01826378-v', 2), SenseInfo('01825237-v', 25), SenseInfo('01826723-v', 2), SenseInfo('01826378-v', 2) ],
"_ask_v_1_rel" : [ SenseInfo('00784342-v', 244), SenseInfo('00752493-v', 165), SenseInfo('00784727-v', 16), SenseInfo('00755745-v', 2), SenseInfo('00897746-v', 1), SenseInfo('02627934-v', 0), SenseInfo('01068565-v', 0), SenseInfo('00784342-v', 244), SenseInfo('00752493-v', 165), SenseInfo('00784727-v', 16), SenseInfo('00755745-v', 2), SenseInfo('00897746-v', 1), SenseInfo('02627934-v', 0), SenseInfo('01068565-v', 0), SenseInfo('00784342-v', 244), SenseInfo('00752493-v', 165), SenseInfo('00784727-v', 16), SenseInfo('00755745-v', 2), SenseInfo('00897746-v', 1), SenseInfo('02627934-v', 0), SenseInfo('01068565-v', 0), SenseInfo('00784342-v', 244), SenseInfo('00752493-v', 165), SenseInfo('00784727-v', 16), SenseInfo('00755745-v', 2), SenseInfo('00897746-v', 1), SenseInfo('02627934-v', 0), SenseInfo('01068565-v', 0), SenseInfo('00784342-v', 244), SenseInfo('00752493-v', 165), SenseInfo('00784727-v', 16), SenseInfo('00755745-v', 2), SenseInfo('00897746-v', 1), SenseInfo('02627934-v', 0), SenseInfo('01068565-v', 0), SenseInfo('00784342-v', 244), SenseInfo('00752493-v', 165), SenseInfo('00784727-v', 16), SenseInfo('00755745-v', 2), SenseInfo('00897746-v', 1), SenseInfo('02627934-v', 0), SenseInfo('01068565-v', 0), SenseInfo('00784342-v', 244), SenseInfo('00752493-v', 165), SenseInfo('00784727-v', 16), SenseInfo('00755745-v', 2), SenseInfo('00897746-v', 1), SenseInfo('02627934-v', 0), SenseInfo('01068565-v', 0), SenseInfo('00784342-v', 244), SenseInfo('00752493-v', 165), SenseInfo('00784727-v', 16), SenseInfo('00755745-v', 2), SenseInfo('00897746-v', 1), SenseInfo('02627934-v', 0), SenseInfo('01068565-v', 0), SenseInfo('00784342-v', 244), SenseInfo('00752493-v', 165), SenseInfo('00784727-v', 16), SenseInfo('00755745-v', 2), SenseInfo('00897746-v', 1), SenseInfo('02627934-v', 0), SenseInfo('01068565-v', 0), SenseInfo('00784342-v', 244), SenseInfo('00752493-v', 165), SenseInfo('00784727-v', 16), SenseInfo('00755745-v', 2), SenseInfo('00897746-v', 1), SenseInfo('02627934-v', 0), SenseInfo('01068565-v', 0) ],
"_volcano_n_1_rel" : [ SenseInfo('09470550-n', 1), SenseInfo('09472597-n', 0) ],
"_timespan_n_1_rel" : [  ],
"_nor_x_subord_rel" : [  ],
"_limp_a_1_rel" : [ SenseInfo('01070002-a', 3), SenseInfo('02404081-a', 0), SenseInfo('01070002-a', 3), SenseInfo('02404081-a', 0) ],
"_crustacean_n_1_rel" : [ SenseInfo('01974773-n', 0) ],
"_whoop_v_1_rel" : [ SenseInfo('00914215-v', 3), SenseInfo('00006100-v', 0), SenseInfo('00914215-v', 3), SenseInfo('00006100-v', 0) ],
"_methanol_n_1_rel" : [ SenseInfo('14687818-n', 0) ],
"_bay_n_1_rel" : [ SenseInfo('09215664-n', 7), SenseInfo('07376836-n', 1), SenseInfo('11704093-n', 0), SenseInfo('02812785-n', 0), SenseInfo('02812631-n', 0), SenseInfo('02696048-n', 0), SenseInfo('02388917-n', 0), SenseInfo('09215664-n', 7), SenseInfo('07376836-n', 1), SenseInfo('11704093-n', 0), SenseInfo('02812785-n', 0), SenseInfo('02812631-n', 0), SenseInfo('02696048-n', 0), SenseInfo('02388917-n', 0), SenseInfo('09215664-n', 7), SenseInfo('07376836-n', 1), SenseInfo('11704093-n', 0), SenseInfo('02812785-n', 0), SenseInfo('02812631-n', 0), SenseInfo('02696048-n', 0), SenseInfo('02388917-n', 0) ],
"_infrared_a_1_rel" : [ SenseInfo('02517999-a', 2), SenseInfo('02517999-a', 2) ],
"_diarrheal_n_1_rel" : [ SenseInfo('00638622-a', 0) ],
"_search_n_of_rel" : [ SenseInfo('00945401-n', 14), SenseInfo('00637354-n', 5), SenseInfo('13553560-n', 0), SenseInfo('05770058-n', 0), SenseInfo('00644366-n', 0) ],
"_gentle_a_1_rel" : [ SenseInfo('01509066-a', 6), SenseInfo('01373314-a', 4), SenseInfo('01455412-a', 2), SenseInfo('01590484-a', 1), SenseInfo('02388773-a', 0), SenseInfo('01192035-a', 0), SenseInfo('01144571-a', 0), SenseInfo('01509066-a', 6), SenseInfo('01373314-a', 4), SenseInfo('01455412-a', 2), SenseInfo('01590484-a', 1), SenseInfo('02388773-a', 0), SenseInfo('01192035-a', 0), SenseInfo('01144571-a', 0), SenseInfo('01509066-a', 6), SenseInfo('01373314-a', 4), SenseInfo('01455412-a', 2), SenseInfo('01590484-a', 1), SenseInfo('02388773-a', 0), SenseInfo('01192035-a', 0), SenseInfo('01144571-a', 0), SenseInfo('01509066-a', 6), SenseInfo('01373314-a', 4), SenseInfo('01455412-a', 2), SenseInfo('01590484-a', 1), SenseInfo('02388773-a', 0), SenseInfo('01192035-a', 0), SenseInfo('01144571-a', 0) ],
"_egoistical_a_1_rel" : [ SenseInfo('00101800-a', 0) ],
"_home-grown_a_1_rel" : [ SenseInfo('01036874-a', 1), SenseInfo('01036874-a', 1) ],
"_download_v_1_rel" : [ SenseInfo('02233704-v', 0), SenseInfo('02233704-v', 0) ],
"_trade_v_1_rel" : [ SenseInfo('02260362-v', 6), SenseInfo('02260085-v', 6), SenseInfo('02728784-v', 2), SenseInfo('02259005-v', 2), SenseInfo('02244956-v', 0) ],
"_peoples_a_1_rel" : [ SenseInfo('07943300-n', 0), SenseInfo('07943300-n', 0), SenseInfo('07943300-n', 0), SenseInfo('07943300-n', 0) ],
"_polish_v_up_rel" : [ SenseInfo('01245637-v', 7), SenseInfo('00474017-v', 3), SenseInfo('00473799-v', 0), SenseInfo('01245637-v', 7), SenseInfo('00474017-v', 3), SenseInfo('00473799-v', 0) ],
"_bird_n_1_rel" : [ SenseInfo('01503061-n', 29), SenseInfo('07644382-n', 1), SenseInfo('09989045-n', 0), SenseInfo('07123870-n', 0), SenseInfo('04212282-n', 0) ],
"_bureau_n_of_rel" : [ SenseInfo('08337324-n', 3), SenseInfo('03015254-n', 1) ],
"_nationalism_n_1_rel" : [ SenseInfo('04878101-n', 7), SenseInfo('05965022-n', 5), SenseInfo('07485047-n', 0), SenseInfo('05965195-n', 0) ],
"_preeminence_n_1_rel" : [ SenseInfo('14435445-n', 0), SenseInfo('14435445-n', 0) ],
"_supercomputer_n_1_rel" : [ SenseInfo('04358117-n', 0), SenseInfo('04358117-n', 0) ],
"_tape_v_1_rel" : [ SenseInfo('01331818-v', 0), SenseInfo('01003049-v', 0), SenseInfo('00998399-v', 0) ],
"_refrain_n_1_rel" : [ SenseInfo('07050177-n', 3) ],
"_barium_n_1_rel" : [ SenseInfo('14629998-n', 1) ],
"_cast_n_1_rel" : [ SenseInfo('08237863-n', 10), SenseInfo('03779370-n', 1), SenseInfo('13913566-n', 0), SenseInfo('04677514-n', 0), SenseInfo('02979836-n', 0), SenseInfo('02979662-n', 0), SenseInfo('01245813-n', 0), SenseInfo('00454624-n', 0), SenseInfo('00105479-n', 0) ],
"_harden_v_1_rel" : [ SenseInfo('00443116-v', 4), SenseInfo('00443384-v', 0), SenseInfo('00302875-v', 0), SenseInfo('00295120-v', 0), SenseInfo('00272910-v', 0) ],
"_light_v_up_rel" : [ SenseInfo('00291873-v', 12), SenseInfo('01199881-v', 10), SenseInfo('01978700-v', 3), SenseInfo('02759614-v', 2), SenseInfo('02229828-v', 0), SenseInfo('01958452-v', 0), SenseInfo('00291873-v', 12), SenseInfo('01199881-v', 10), SenseInfo('01978700-v', 3), SenseInfo('02759614-v', 2), SenseInfo('02229828-v', 0), SenseInfo('01958452-v', 0) ],
"_bandit_n_1_rel" : [ SenseInfo('09837088-n', 3) ],
"_persecute_v_1_rel" : [ SenseInfo('02585489-v', 2) ],
"_afterwards_p_rel" : [ SenseInfo('00061203-r', 6), SenseInfo('00061203-r', 6), SenseInfo('00061203-r', 6) ],
"_poignant_a_1_rel" : [ SenseInfo('01560821-a', 3), SenseInfo('01712174-a', 2) ],
"_rebuff_n_1_rel" : [ SenseInfo('01225783-n', 1), SenseInfo('07208000-n', 0) ],
"_balk_n_1_rel" : [ SenseInfo('08516080-n', 0), SenseInfo('05689249-n', 0), SenseInfo('04045644-n', 0), SenseInfo('00107279-n', 0) ],
"_passable_a_1_rel" : [ SenseInfo('01724551-a', 0), SenseInfo('02080937-a', 0) ],
"_snob_n_1_rel" : [ SenseInfo('10617024-n', 0) ],
"_harmonize_v_1_rel" : [ SenseInfo('02700104-v', 0), SenseInfo('01707306-v', 0), SenseInfo('01706889-v', 0), SenseInfo('00483181-v', 0), SenseInfo('00482473-v', 0), SenseInfo('00482180-v', 0), SenseInfo('02700104-v', 0), SenseInfo('01707306-v', 0), SenseInfo('01706889-v', 0), SenseInfo('00483181-v', 0), SenseInfo('00482473-v', 0), SenseInfo('00482180-v', 0) ],
"_overload_v_1_rel" : [ SenseInfo('01488847-v', 1), SenseInfo('00182037-v', 1), SenseInfo('01488555-v', 0), SenseInfo('01488847-v', 1), SenseInfo('00182037-v', 1), SenseInfo('01488555-v', 0) ],
"_abridged_a_1_rel" : [ SenseInfo('00004413-a', 0) ],
"_finnish_n_1_rel" : [ SenseInfo('06958255-n', 0), SenseInfo('06958255-n', 0), SenseInfo('06958255-n', 0) ],
"_whilst_x_rel" : [  ],
"_succulent_n_1_rel" : [ SenseInfo('13084184-n', 0) ],
"_flavor_v_1_rel" : [ SenseInfo('02191766-v', 0) ],
"_toss_v_in_rel" : [ SenseInfo('01512625-v', 13), SenseInfo('01893079-v', 10), SenseInfo('01514525-v', 5), SenseInfo('01890792-v', 4), SenseInfo('02222318-v', 1), SenseInfo('01418536-v', 1) ],
"_forest_n_of_rel" : [ SenseInfo('08438533-n', 36), SenseInfo('09284015-n', 2), SenseInfo('08438533-n', 36), SenseInfo('09284015-n', 2) ],
"_as+follows_p_rel" : [ SenseInfo('00152684-r', 14) ],
"_marvel_n_1_rel" : [ SenseInfo('07289588-n', 1) ],
"_magnetic_a_1_rel" : [ SenseInfo('02926188-a', 4), SenseInfo('01469677-a', 1), SenseInfo('01470813-a', 0), SenseInfo('01470298-a', 0), SenseInfo('00167077-a', 0), SenseInfo('02926188-a', 4), SenseInfo('01469677-a', 1), SenseInfo('01470813-a', 0), SenseInfo('01470298-a', 0), SenseInfo('00167077-a', 0) ],
"_far+out_a_1_rel" : [ SenseInfo('00609564-a', 0), SenseInfo('00609564-a', 0) ],
"_major_v_in_rel" : [ SenseInfo('00607609-v', 2) ],
"_gush_v_1_rel" : [ SenseInfo('02068413-v', 3), SenseInfo('00882220-v', 2), SenseInfo('01516290-v', 0), SenseInfo('02068413-v', 3), SenseInfo('00882220-v', 2), SenseInfo('01516290-v', 0), SenseInfo('02068413-v', 3), SenseInfo('00882220-v', 2), SenseInfo('01516290-v', 0) ],
"_resize_v_cause_rel" : [ SenseInfo('00319629-v', 0) ],
"_sandal_n_1_rel" : [ SenseInfo('04133789-n', 3) ],
"_unstructured_a_1_rel" : [ SenseInfo('01671881-a', 12), SenseInfo('01680283-a', 0), SenseInfo('01671881-a', 12), SenseInfo('01680283-a', 0) ],
"_storekeeper_n_1_rel" : [ SenseInfo('10592152-n', 1) ],
"_concave_n_1_rel" : [ SenseInfo('00535452-a', 3) ],
"_editor_n_1_rel" : [ SenseInfo('10044879-n', 17), SenseInfo('06574841-n', 0), SenseInfo('10044879-n', 17), SenseInfo('06574841-n', 0) ],
"_jar_n_1_rel" : [ SenseInfo('03593526-n', 2), SenseInfo('13767822-n', 0), SenseInfo('07339098-n', 0) ],
"_respiration_n_1_rel" : [ SenseInfo('00830811-n', 1), SenseInfo('00831782-n', 0), SenseInfo('00831191-n', 0) ],
"_broke_a_1_rel" : [ SenseInfo('02023287-a', 2) ],
"_evolution_n_1_rel" : [ SenseInfo('13464820-n', 5), SenseInfo('13477023-n', 0) ],
"_plate_v_1_rel" : [ SenseInfo('01395049-v', 0) ],
"_quackery_n_1_rel" : [ SenseInfo('00633108-n', 6), SenseInfo('00750306-n', 0) ],
"_culminate_v_1_rel" : [ SenseInfo('00485609-v', 8), SenseInfo('00354030-v', 1), SenseInfo('02526934-v', 0), SenseInfo('02021773-v', 0), SenseInfo('00144040-v', 0) ],
"_hydroxide_n_1_rel" : [ SenseInfo('14935555-n', 1), SenseInfo('14914670-n', 0) ],
"_deluge_v_1_rel" : [ SenseInfo('01524523-v', 0), SenseInfo('00751131-v', 0), SenseInfo('00217700-v', 0) ],
"_hearer_n_1_rel" : [ SenseInfo('10165448-n', 1) ],
"_lexical_a_1_rel" : [ SenseInfo('02886629-a', 2), SenseInfo('02886869-a', 0) ],
"_join_v_in_rel" : [ SenseInfo('02434976-v', 75), SenseInfo('01295275-v', 18), SenseInfo('02598765-v', 8), SenseInfo('01291069-v', 7), SenseInfo('02622234-v', 1), SenseInfo('02434976-v', 75), SenseInfo('01295275-v', 18), SenseInfo('02598765-v', 8), SenseInfo('01291069-v', 7), SenseInfo('02622234-v', 1) ],
"_spell_v_out_rel" : [ SenseInfo('00937879-v', 2), SenseInfo('00932636-v', 2), SenseInfo('01699896-v', 1), SenseInfo('02412366-v', 0), SenseInfo('01064560-v', 0), SenseInfo('00121387-v', 0) ],
"_backgammon_n_1_rel" : [ SenseInfo('00502822-n', 0) ],
"_knockout_n_1_rel" : [ SenseInfo('10613996-n', 0), SenseInfo('00134099-n', 0), SenseInfo('10613996-n', 0), SenseInfo('00134099-n', 0) ],
"_mousse_n_1_rel" : [ SenseInfo('07611991-n', 0), SenseInfo('07611839-n', 0), SenseInfo('03794136-n', 0) ],
"_gastronomy_n_1_rel" : [ SenseInfo('07572206-n', 0), SenseInfo('00936296-n', 0) ],
"_hear_v_of_rel" : [ SenseInfo('02169702-v', 275), SenseInfo('00598954-v', 60), SenseInfo('02500902-v', 12), SenseInfo('02107442-v', 8), SenseInfo('02171039-v', 0) ],
"_office_n_of_rel" : [ SenseInfo('03841666-n', 62), SenseInfo('08337324-n', 24), SenseInfo('00720565-n', 6), SenseInfo('13945102-n', 2), SenseInfo('08352303-n', 0), SenseInfo('01033458-n', 0), SenseInfo('00586262-n', 0) ],
"_waterproof_a_1_rel" : [ SenseInfo('01398941-a', 1) ],
"_stand_v_up-for_rel" : [ SenseInfo('01546111-v', 169), SenseInfo('02611373-v', 53), SenseInfo('02734488-v', 38), SenseInfo('02702120-v', 18), SenseInfo('00668099-v', 9), SenseInfo('00670991-v', 8), SenseInfo('02707125-v', 5), SenseInfo('02703018-v', 3), SenseInfo('02702368-v', 2), SenseInfo('01546768-v', 1), SenseInfo('01115916-v', 1), SenseInfo('01428203-v', 0) ],
"_rebel_n_1_rel" : [ SenseInfo('10628368-n', 10), SenseInfo('10210137-n', 3), SenseInfo('10303654-n', 1) ],
"_horseriding_n_1_rel" : [  ],
"_aircraft_n_1_rel" : [ SenseInfo('02686568-n', 15) ],
"_crystallographic_a_1_rel" : [  ],
"_trinity_n_1_rel" : [ SenseInfo('13744044-n', 0), SenseInfo('09536789-n', 0), SenseInfo('07986066-n', 0) ],
"_uh+uh_a_1_rel" : [  ],
"_espouse_v_1_rel" : [ SenseInfo('02346895-v', 3), SenseInfo('02488834-v', 0), SenseInfo('00601822-v', 0) ],
"_must_v_modal_rel" : [ SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0) ],
"_lefty_n_1_rel" : [ SenseInfo('10253122-n', 2), SenseInfo('10252921-n', 0) ],
"_mash_v_1_rel" : [ SenseInfo('01593937-v', 1), SenseInfo('01037910-v', 0), SenseInfo('00331082-v', 0) ],
"_sect_n_1_rel" : [ SenseInfo('08149781-n', 1), SenseInfo('08251877-n', 0) ],
"_leisurely_a_1_rel" : [ SenseInfo('01272176-a', 0), SenseInfo('01272176-a', 0) ],
"_mm_a_1_rel" : [ SenseInfo('13658657-n', 16), SenseInfo('13658657-n', 16) ],
"_force_n_1_rel" : [ SenseInfo('05194578-n', 29), SenseInfo('11458624-n', 20), SenseInfo('05035353-n', 19), SenseInfo('08208016-n', 15), SenseInfo('08198398-n', 10), SenseInfo('00965404-n', 5), SenseInfo('10461424-n', 1), SenseInfo('08207863-n', 0), SenseInfo('04809642-n', 0), SenseInfo('00129743-n', 0) ],
"_imperfection_n_1_rel" : [ SenseInfo('14462666-n', 0) ],
"_inclement_a_1_rel" : [ SenseInfo('00438567-a', 0), SenseInfo('00437852-a', 0) ],
"_metamorphose_v_1_rel" : [ SenseInfo('00384055-v', 1), SenseInfo('00381601-v', 0) ],
"_free-lance_a_1_rel" : [ SenseInfo('00863823-a', 0), SenseInfo('01709081-a', 0), SenseInfo('00863823-a', 0), SenseInfo('01709081-a', 0), SenseInfo('00863823-a', 0), SenseInfo('01709081-a', 0) ],
"_dinosaur_n_1_rel" : [ SenseInfo('01699831-n', 0) ],
"_whine_n_1_rel" : [ SenseInfo('07211752-n', 0) ],
"_decorate_v_1_rel" : [ SenseInfo('01675963-v', 6), SenseInfo('02748927-v', 0), SenseInfo('02547046-v', 0), SenseInfo('01466543-v', 0) ],
"_filling_n_1_rel" : [ SenseInfo('14868243-n', 4), SenseInfo('13480541-n', 2), SenseInfo('07883031-n', 0), SenseInfo('04598965-n', 0), SenseInfo('03338287-n', 0), SenseInfo('00402535-n', 0) ],
"_cistern_n_1_rel" : [ SenseInfo('05516711-n', 0), SenseInfo('03035715-n', 0), SenseInfo('03035510-n', 0) ],
"_boast_v_to_rel" : [ SenseInfo('00883226-v', 7), SenseInfo('02631659-v', 6), SenseInfo('00883226-v', 7), SenseInfo('02631659-v', 6) ],
"_drastic_a_1_rel" : [ SenseInfo('00841934-a', 1) ],
"_bizarre_a_1_rel" : [ SenseInfo('00608791-a', 2) ],
"_feline_a_1_rel" : [ SenseInfo('02881888-a', 2) ],
"_choice_a_1_rel" : [ SenseInfo('02342899-a', 3), SenseInfo('02396484-a', 0), SenseInfo('02342899-a', 3), SenseInfo('02396484-a', 0), SenseInfo('02342899-a', 3), SenseInfo('02396484-a', 0) ],
"_tyrannosaurus+rex_n_1_rel" : [ SenseInfo('01713764-n', 0) ],
"_arouse_v_1_rel" : [ SenseInfo('01759326-v', 14), SenseInfo('00018526-v', 3), SenseInfo('01629958-v', 2), SenseInfo('00022686-v', 2), SenseInfo('00018813-v', 2), SenseInfo('01894164-v', 1), SenseInfo('01762283-v', 0), SenseInfo('01759326-v', 14), SenseInfo('00018526-v', 3), SenseInfo('01629958-v', 2), SenseInfo('00022686-v', 2), SenseInfo('00018813-v', 2), SenseInfo('01894164-v', 1), SenseInfo('01762283-v', 0) ],
"_clue_n_1_rel" : [ SenseInfo('06802785-n', 9), SenseInfo('06643763-n', 2), SenseInfo('06802785-n', 9), SenseInfo('06643763-n', 2) ],
"_mugging_n_1_rel" : [ SenseInfo('00774009-n', 0) ],
"_excitement_n_1_rel" : [ SenseInfo('07528212-n', 9), SenseInfo('14037011-n', 5), SenseInfo('01260867-n', 4), SenseInfo('00554300-n', 2) ],
"_crunchy_a_1_rel" : [  ],
"_narrow_v_down_rel" : [ SenseInfo('00305109-v', 2), SenseInfo('00715541-v', 1), SenseInfo('00437449-v', 1), SenseInfo('00304422-v', 1), SenseInfo('00305109-v', 2), SenseInfo('00715541-v', 1), SenseInfo('00437449-v', 1), SenseInfo('00304422-v', 1) ],
"_worry_n_1_rel" : [ SenseInfo('05832264-n', 8), SenseInfo('07524242-n', 6), SenseInfo('05832264-n', 8), SenseInfo('07524242-n', 6) ],
"_hew_v_1_rel" : [ SenseInfo('01260685-v', 0), SenseInfo('01260428-v', 0) ],
"_contrition_n_1_rel" : [ SenseInfo('07534700-n', 1) ],
"_overwrite_v_1_rel" : [ SenseInfo('00999079-v', 0), SenseInfo('00999079-v', 0) ],
"_admonition_n_of_rel" : [ SenseInfo('06672297-n', 3), SenseInfo('06714420-n', 0) ],
"_denominator_n_1_rel" : [ SenseInfo('13733066-n', 0) ],
"_nominate_v_1_rel" : [ SenseInfo('00879540-v', 4), SenseInfo('02401523-v', 0), SenseInfo('02396716-v', 0), SenseInfo('02396205-v', 0), SenseInfo('00879540-v', 4), SenseInfo('02401523-v', 0), SenseInfo('02396716-v', 0), SenseInfo('02396205-v', 0) ],
"_call_v_for_rel" : [ SenseInfo('01028748-v', 91), SenseInfo('00971015-v', 51), SenseInfo('00789448-v', 38), SenseInfo('00913065-v', 25), SenseInfo('00792471-v', 25), SenseInfo('02487573-v', 9), SenseInfo('02429810-v', 9), SenseInfo('01067995-v', 1), SenseInfo('01062739-v', 1), SenseInfo('00975036-v', 1), SenseInfo('02643421-v', 0), SenseInfo('02601456-v', 0), SenseInfo('02487901-v', 0), SenseInfo('02359061-v', 0), SenseInfo('02300060-v', 0), SenseInfo('01899017-v', 0), SenseInfo('01068793-v', 0), SenseInfo('00917772-v', 0), SenseInfo('00874002-v', 0), SenseInfo('00869393-v', 0), SenseInfo('00822746-v', 0), SenseInfo('00783523-v', 0), SenseInfo('00754156-v', 0), SenseInfo('00753881-v', 0), SenseInfo('00738747-v', 0), SenseInfo('00738583-v', 0), SenseInfo('00691516-v', 0), SenseInfo('00107231-v', 0) ],
"_insist_v_1_rel" : [ SenseInfo('00818974-v', 59), SenseInfo('00777931-v', 4), SenseInfo('00717045-v', 1), SenseInfo('00818974-v', 59), SenseInfo('00777931-v', 4), SenseInfo('00717045-v', 1), SenseInfo('00818974-v', 59), SenseInfo('00777931-v', 4), SenseInfo('00717045-v', 1), SenseInfo('00818974-v', 59), SenseInfo('00777931-v', 4), SenseInfo('00717045-v', 1), SenseInfo('00818974-v', 59), SenseInfo('00777931-v', 4), SenseInfo('00717045-v', 1) ],
"_depth_n_of_rel" : [ SenseInfo('05134547-n', 32), SenseInfo('05094725-n', 8), SenseInfo('08500213-n', 1), SenseInfo('14441083-n', 0), SenseInfo('05613962-n', 0), SenseInfo('05134353-n', 0), SenseInfo('05134547-n', 32), SenseInfo('05094725-n', 8), SenseInfo('08500213-n', 1), SenseInfo('14441083-n', 0), SenseInfo('05613962-n', 0), SenseInfo('05134353-n', 0) ],
"_alkaline_n_1_rel" : [ SenseInfo('00025728-a', 2) ],
"_controversial_a_1_rel" : [ SenseInfo('00601783-a', 1), SenseInfo('00601783-a', 1) ],
"_make_v_up-for_rel" : [ SenseInfo('02560585-v', 508), SenseInfo('00120316-v', 459), SenseInfo('01617192-v', 243), SenseInfo('00770437-v', 85), SenseInfo('01645601-v', 78), SenseInfo('01621555-v', 52), SenseInfo('00730758-v', 33), SenseInfo('01646075-v', 17), SenseInfo('01640207-v', 16), SenseInfo('02289295-v', 14), SenseInfo('01619014-v', 14), SenseInfo('02621395-v', 12), SenseInfo('02022162-v', 12), SenseInfo('02674708-v', 10), SenseInfo('01653873-v', 9), SenseInfo('01755816-v', 8), SenseInfo('01654628-v', 5), SenseInfo('00556855-v', 5), SenseInfo('00012267-v', 5), SenseInfo('02396716-v', 4), SenseInfo('02355596-v', 4), SenseInfo('02020590-v', 4), SenseInfo('00665476-v', 4), SenseInfo('02582921-v', 3), SenseInfo('02598483-v', 2), SenseInfo('01733477-v', 2), SenseInfo('00276068-v', 2), SenseInfo('02075857-v', 1), SenseInfo('00074038-v', 1), SenseInfo('02748759-v', 0), SenseInfo('02748627-v', 0), SenseInfo('02745332-v', 0), SenseInfo('02665124-v', 0), SenseInfo('02621133-v', 0), SenseInfo('02134050-v', 0), SenseInfo('02051031-v', 0), SenseInfo('02021532-v', 0), SenseInfo('01755504-v', 0), SenseInfo('01664172-v', 0), SenseInfo('01428578-v', 0), SenseInfo('00891038-v', 0), SenseInfo('00838524-v', 0), SenseInfo('00698256-v', 0), SenseInfo('00698104-v', 0), SenseInfo('00562182-v', 0), SenseInfo('00562067-v', 0), SenseInfo('00545953-v', 0), SenseInfo('00107369-v', 0), SenseInfo('00072012-v', 0), SenseInfo('02560585-v', 508), SenseInfo('00120316-v', 459), SenseInfo('01617192-v', 243), SenseInfo('00770437-v', 85), SenseInfo('01645601-v', 78), SenseInfo('01621555-v', 52), SenseInfo('00730758-v', 33), SenseInfo('01646075-v', 17), SenseInfo('01640207-v', 16), SenseInfo('02289295-v', 14), SenseInfo('01619014-v', 14), SenseInfo('02621395-v', 12), SenseInfo('02022162-v', 12), SenseInfo('02674708-v', 10), SenseInfo('01653873-v', 9), SenseInfo('01755816-v', 8), SenseInfo('01654628-v', 5), SenseInfo('00556855-v', 5), SenseInfo('00012267-v', 5), SenseInfo('02396716-v', 4), SenseInfo('02355596-v', 4), SenseInfo('02020590-v', 4), SenseInfo('00665476-v', 4), SenseInfo('02582921-v', 3), SenseInfo('02598483-v', 2), SenseInfo('01733477-v', 2), SenseInfo('00276068-v', 2), SenseInfo('02075857-v', 1), SenseInfo('00074038-v', 1), SenseInfo('02748759-v', 0), SenseInfo('02748627-v', 0), SenseInfo('02745332-v', 0), SenseInfo('02665124-v', 0), SenseInfo('02621133-v', 0), SenseInfo('02134050-v', 0), SenseInfo('02051031-v', 0), SenseInfo('02021532-v', 0), SenseInfo('01755504-v', 0), SenseInfo('01664172-v', 0), SenseInfo('01428578-v', 0), SenseInfo('00891038-v', 0), SenseInfo('00838524-v', 0), SenseInfo('00698256-v', 0), SenseInfo('00698104-v', 0), SenseInfo('00562182-v', 0), SenseInfo('00562067-v', 0), SenseInfo('00545953-v', 0), SenseInfo('00107369-v', 0), SenseInfo('00072012-v', 0) ],
"_rank_n_1_rel" : [ SenseInfo('08431942-n', 20), SenseInfo('14429985-n', 6), SenseInfo('08398179-n', 3), SenseInfo('13947415-n', 2), SenseInfo('08400965-n', 1) ],
"_wholly_x_deg_rel" : [ SenseInfo('00008007-r', 11) ],
"_fess_n_1_rel" : [ SenseInfo('08970064-n', 0) ],
"_quench_v_1_rel" : [ SenseInfo('01204021-v', 1), SenseInfo('02761897-v', 0), SenseInfo('02422967-v', 0), SenseInfo('00463234-v', 0), SenseInfo('00429763-v', 0), SenseInfo('00370773-v', 0), SenseInfo('01204021-v', 1), SenseInfo('02761897-v', 0), SenseInfo('02422967-v', 0), SenseInfo('00463234-v', 0), SenseInfo('00429763-v', 0), SenseInfo('00370773-v', 0), SenseInfo('01204021-v', 1), SenseInfo('02761897-v', 0), SenseInfo('02422967-v', 0), SenseInfo('00463234-v', 0), SenseInfo('00429763-v', 0), SenseInfo('00370773-v', 0) ],
"_gut_v_1_rel" : [ SenseInfo('01591012-v', 0), SenseInfo('01590747-v', 0) ],
"_make_v_believe_rel" : [ SenseInfo('02560585-v', 508), SenseInfo('00120316-v', 459), SenseInfo('01617192-v', 243), SenseInfo('00770437-v', 85), SenseInfo('01645601-v', 78), SenseInfo('01621555-v', 52), SenseInfo('00730758-v', 33), SenseInfo('01646075-v', 17), SenseInfo('01640207-v', 16), SenseInfo('02289295-v', 14), SenseInfo('01619014-v', 14), SenseInfo('02621395-v', 12), SenseInfo('02022162-v', 12), SenseInfo('02674708-v', 10), SenseInfo('01653873-v', 9), SenseInfo('01755816-v', 8), SenseInfo('01654628-v', 5), SenseInfo('00556855-v', 5), SenseInfo('00012267-v', 5), SenseInfo('02396716-v', 4), SenseInfo('02355596-v', 4), SenseInfo('02020590-v', 4), SenseInfo('00665476-v', 4), SenseInfo('02582921-v', 3), SenseInfo('02598483-v', 2), SenseInfo('01733477-v', 2), SenseInfo('00276068-v', 2), SenseInfo('02075857-v', 1), SenseInfo('00074038-v', 1), SenseInfo('02748759-v', 0), SenseInfo('02748627-v', 0), SenseInfo('02745332-v', 0), SenseInfo('02665124-v', 0), SenseInfo('02621133-v', 0), SenseInfo('02134050-v', 0), SenseInfo('02051031-v', 0), SenseInfo('02021532-v', 0), SenseInfo('01755504-v', 0), SenseInfo('01664172-v', 0), SenseInfo('01428578-v', 0), SenseInfo('00891038-v', 0), SenseInfo('00838524-v', 0), SenseInfo('00698256-v', 0), SenseInfo('00698104-v', 0), SenseInfo('00562182-v', 0), SenseInfo('00562067-v', 0), SenseInfo('00545953-v', 0), SenseInfo('00107369-v', 0), SenseInfo('00072012-v', 0) ],
"_meridian_n_1_rel" : [ SenseInfo('13940456-n', 0), SenseInfo('09105156-n', 0), SenseInfo('08598823-n', 0) ],
"_bud_n_1_rel" : [ SenseInfo('11674914-n', 3), SenseInfo('13165086-n', 2) ],
"_ratify_v_1_rel" : [ SenseInfo('02464866-v', 5) ],
"_silhouette_v_1_rel" : [ SenseInfo('02138283-v', 1), SenseInfo('01680621-v', 1) ],
"_optional_a_for_rel" : [ SenseInfo('00847399-a', 0), SenseInfo('00847399-a', 0), SenseInfo('00847399-a', 0), SenseInfo('00847399-a', 0) ],
"_shorten_v_1_rel" : [ SenseInfo('00316768-v', 6), SenseInfo('00243900-v', 3), SenseInfo('00560893-v', 0), SenseInfo('00316494-v', 0), SenseInfo('00201034-v', 0) ],
"_bear_v_on_rel" : [ SenseInfo('02630871-v', 23), SenseInfo('00056930-v', 17), SenseInfo('00668099-v', 13), SenseInfo('01432601-v', 10), SenseInfo('01652139-v', 6), SenseInfo('02301825-v', 5), SenseInfo('02700867-v', 4), SenseInfo('02291708-v', 4), SenseInfo('00047745-v', 1), SenseInfo('02518161-v', 0), SenseInfo('02302220-v', 0), SenseInfo('01601234-v', 0), SenseInfo('00059019-v', 0) ],
"_sullenness_n_1_rel" : [ SenseInfo('07552367-n', 0), SenseInfo('04642057-n', 0) ],
"_secondly_a_1_rel" : [  ],
"_pat_v_1_rel" : [ SenseInfo('01243661-v', 11), SenseInfo('01233027-v', 2) ],
"_coverlet_n_1_rel" : [ SenseInfo('03123553-n', 1) ],
"_no+matter_a_1_rel" : [  ],
"_inclemency_n_1_rel" : [ SenseInfo('14523090-n', 0), SenseInfo('04639732-n', 0) ],
"_costa+rican_n_1_rel" : [ SenseInfo('09698788-n', 0) ],
"_concise_a_1_rel" : [ SenseInfo('00546646-a', 1) ],
"_trying_a_1_rel" : [ SenseInfo('00748947-a', 2), SenseInfo('00090408-a', 0) ],
"_drape_n_1_rel" : [ SenseInfo('03151077-n', 1), SenseInfo('04930139-n', 0), SenseInfo('03232923-n', 0) ],
"_sitz+bath_n_1_rel" : [ SenseInfo('04225031-n', 0), SenseInfo('04225031-n', 0) ],
"_supersede_v_1_rel" : [ SenseInfo('02405390-v', 4) ],
"_nostalgic_a_1_rel" : [ SenseInfo('00889098-a', 0) ],
"_dc4800_n_1_rel" : [  ],
"_parenthetical_a_1_rel" : [ SenseInfo('01857527-a', 0) ],
"_sort_v_out_rel" : [ SenseInfo('02400378-v', 0), SenseInfo('00654625-v', 0) ],
"_cease_v_1_rel" : [ SenseInfo('02680814-v', 25), SenseInfo('02609764-v', 6), SenseInfo('02680814-v', 25), SenseInfo('02609764-v', 6), SenseInfo('02680814-v', 25), SenseInfo('02609764-v', 6) ],
"_oviparous_a_1_rel" : [ SenseInfo('02519171-a', 0) ],
"_repertoire_n_1_rel" : [ SenseInfo('08336844-n', 0), SenseInfo('08336627-n', 0) ],
"_stand_v_i_rel" : [ SenseInfo('01546111-v', 169), SenseInfo('02611373-v', 53), SenseInfo('02734488-v', 38), SenseInfo('02702120-v', 18), SenseInfo('00668099-v', 9), SenseInfo('00670991-v', 8), SenseInfo('02707125-v', 5), SenseInfo('02703018-v', 3), SenseInfo('02702368-v', 2), SenseInfo('01546768-v', 1), SenseInfo('01115916-v', 1), SenseInfo('01428203-v', 0) ],
"_dwelling_n_1_rel" : [ SenseInfo('03259505-n', 11) ],
"_hurt_v_1_rel" : [ SenseInfo('02122164-v', 8), SenseInfo('00064643-v', 8), SenseInfo('01792567-v', 4), SenseInfo('00260470-v', 4), SenseInfo('01793177-v', 3), SenseInfo('02121511-v', 0), SenseInfo('00065070-v', 0), SenseInfo('02122164-v', 8), SenseInfo('00064643-v', 8), SenseInfo('01792567-v', 4), SenseInfo('00260470-v', 4), SenseInfo('01793177-v', 3), SenseInfo('02121511-v', 0), SenseInfo('00065070-v', 0), SenseInfo('02122164-v', 8), SenseInfo('00064643-v', 8), SenseInfo('01792567-v', 4), SenseInfo('00260470-v', 4), SenseInfo('01793177-v', 3), SenseInfo('02121511-v', 0), SenseInfo('00065070-v', 0), SenseInfo('02122164-v', 8), SenseInfo('00064643-v', 8), SenseInfo('01792567-v', 4), SenseInfo('00260470-v', 4), SenseInfo('01793177-v', 3), SenseInfo('02121511-v', 0), SenseInfo('00065070-v', 0), SenseInfo('02122164-v', 8), SenseInfo('00064643-v', 8), SenseInfo('01792567-v', 4), SenseInfo('00260470-v', 4), SenseInfo('01793177-v', 3), SenseInfo('02121511-v', 0), SenseInfo('00065070-v', 0), SenseInfo('02122164-v', 8), SenseInfo('00064643-v', 8), SenseInfo('01792567-v', 4), SenseInfo('00260470-v', 4), SenseInfo('01793177-v', 3), SenseInfo('02121511-v', 0), SenseInfo('00065070-v', 0), SenseInfo('02122164-v', 8), SenseInfo('00064643-v', 8), SenseInfo('01792567-v', 4), SenseInfo('00260470-v', 4), SenseInfo('01793177-v', 3), SenseInfo('02121511-v', 0), SenseInfo('00065070-v', 0) ],
"_rørbu_n_1_rel" : [  ],
"_plant_n_1_rel" : [ SenseInfo('03956922-n', 63), SenseInfo('00017222-n', 37), SenseInfo('10438470-n', 0), SenseInfo('05906080-n', 0) ],
"_banquet_n_1_rel" : [ SenseInfo('08253640-n', 2), SenseInfo('07578093-n', 0) ],
"_walk_v_off_rel" : [ SenseInfo('01904930-v', 184), SenseInfo('01907076-v', 3), SenseInfo('01113473-v', 3), SenseInfo('01912893-v', 1), SenseInfo('01140654-v', 1), SenseInfo('02518839-v', 0), SenseInfo('02470518-v', 0), SenseInfo('01959776-v', 0), SenseInfo('01906823-v', 0), SenseInfo('01882170-v', 0) ],
"_woollen_a_1_rel" : [ SenseInfo('03130689-a', 0) ],
"_caisson_n_1_rel" : [ SenseInfo('03064443-n', 0), SenseInfo('02937336-n', 0), SenseInfo('02937237-n', 0), SenseInfo('02937093-n', 0) ],
"_die_v_1_rel" : [ SenseInfo('00358431-v', 141), SenseInfo('02109818-v', 1), SenseInfo('01784953-v', 1), SenseInfo('00434374-v', 1), SenseInfo('01829475-v', 0), SenseInfo('01785242-v', 0), SenseInfo('01555034-v', 0), SenseInfo('01074914-v', 0), SenseInfo('00538323-v', 0), SenseInfo('00354845-v', 0), SenseInfo('00224295-v', 0) ],
"_ophthalmologist_n_1_rel" : [ SenseInfo('10379073-n', 0) ],
"_nuptial_a_1_rel" : [ SenseInfo('02843495-a', 0) ],
"_travail_n_1_rel" : [ SenseInfo('14048441-n', 0), SenseInfo('00621627-n', 0) ],
"_populace_n_1_rel" : [ SenseInfo('08179689-n', 2) ],
"_left-of-center_a_1_rel" : [ SenseInfo('02031335-a', 1), SenseInfo('02031335-a', 1), SenseInfo('02031335-a', 1), SenseInfo('02031335-a', 1), SenseInfo('02031335-a', 1) ],
"_minotaur_n_1_rel" : [ SenseInfo('09499056-n', 0) ],
"_sit_v_down_rel" : [ SenseInfo('01543123-v', 134), SenseInfo('02692882-v', 33), SenseInfo('01984902-v', 10), SenseInfo('02024874-v', 6), SenseInfo('02142775-v', 1), SenseInfo('01957529-v', 1), SenseInfo('02691214-v', 0), SenseInfo('02456270-v', 0), SenseInfo('01543998-v', 0), SenseInfo('01095581-v', 0) ],
"_overlook_v_1_rel" : [ SenseInfo('02166361-v', 6), SenseInfo('02721966-v', 3), SenseInfo('00614999-v', 1), SenseInfo('02696129-v', 0), SenseInfo('02166248-v', 0) ],
"_above_a_1_rel" : [ SenseInfo('00125993-a', 13) ],
"_cayenne_n_1_rel" : [ SenseInfo('12900987-n', 0), SenseInfo('07822518-n', 0), SenseInfo('07721942-n', 0) ],
"_premium_a_1_rel" : [ SenseInfo('02343931-a', 1) ],
"_zero_v_in-on_rel" : [ SenseInfo('00297507-v', 0), SenseInfo('00297333-v', 0) ],
"_reside_v_1_rel" : [ SenseInfo('02650552-v', 10), SenseInfo('02648639-v', 1), SenseInfo('02664664-v', 0) ],
"_luminescent_a_1_rel" : [ SenseInfo('00272410-a', 1) ],
"_rattle_n_1_rel" : [ SenseInfo('07391240-n', 3), SenseInfo('04056289-n', 0), SenseInfo('01754737-n', 0) ],
"_move_v_about_rel" : [ SenseInfo('01835496-v', 110), SenseInfo('01850315-v', 57), SenseInfo('01831531-v', 52), SenseInfo('01855606-v', 20), SenseInfo('02372605-v', 15), SenseInfo('00014549-v', 7), SenseInfo('00124442-v', 6), SenseInfo('02367363-v', 3), SenseInfo('01767949-v', 3), SenseInfo('01649999-v', 3), SenseInfo('01771390-v', 2), SenseInfo('02355959-v', 1), SenseInfo('00539110-v', 1), SenseInfo('02598863-v', 0), SenseInfo('01076615-v', 0), SenseInfo('00879356-v', 0), SenseInfo('01835496-v', 110), SenseInfo('01850315-v', 57), SenseInfo('01831531-v', 52), SenseInfo('01855606-v', 20), SenseInfo('02372605-v', 15), SenseInfo('00014549-v', 7), SenseInfo('00124442-v', 6), SenseInfo('02367363-v', 3), SenseInfo('01767949-v', 3), SenseInfo('01649999-v', 3), SenseInfo('01771390-v', 2), SenseInfo('02355959-v', 1), SenseInfo('00539110-v', 1), SenseInfo('02598863-v', 0), SenseInfo('01076615-v', 0), SenseInfo('00879356-v', 0) ],
"_gym_n_1_rel" : [ SenseInfo('03472112-n', 4) ],
"_pollute_v_1_rel" : [ SenseInfo('00492706-v', 0) ],
"_sniper_n_1_rel" : [ SenseInfo('10616899-n', 2) ],
"_defect_v_1_rel" : [ SenseInfo('02584097-v', 0) ],
"_user+manual_n_1_rel" : [  ],
"_apparent_a_1_rel" : [ SenseInfo('01618376-a', 19), SenseInfo('01873985-a', 8), SenseInfo('01618376-a', 19), SenseInfo('01873985-a', 8), SenseInfo('01618376-a', 19), SenseInfo('01873985-a', 8), SenseInfo('01618376-a', 19), SenseInfo('01873985-a', 8) ],
"_balance_v_1_rel" : [ SenseInfo('02673134-v', 6), SenseInfo('02264967-v', 3), SenseInfo('01602318-v', 2), SenseInfo('02743020-v', 1), SenseInfo('02673134-v', 6), SenseInfo('02264967-v', 3), SenseInfo('01602318-v', 2), SenseInfo('02743020-v', 1), SenseInfo('02673134-v', 6), SenseInfo('02264967-v', 3), SenseInfo('01602318-v', 2), SenseInfo('02743020-v', 1) ],
"_dative_n_1_rel" : [ SenseInfo('06311723-n', 0), SenseInfo('06311723-n', 0), SenseInfo('06311723-n', 0) ],
"_resupply_v_1_rel" : [  ],
"_justification_n_1_rel" : [ SenseInfo('05823054-n', 3), SenseInfo('06740183-n', 2), SenseInfo('01241767-n', 0), SenseInfo('05823054-n', 3), SenseInfo('06740183-n', 2), SenseInfo('01241767-n', 0) ],
"_benignant_a_1_rel" : [ SenseInfo('00226618-a', 0), SenseInfo('01372568-a', 0) ],
"_display_n_of_rel" : [ SenseInfo('06879521-n', 4), SenseInfo('00521209-n', 3), SenseInfo('03210940-n', 1), SenseInfo('07213717-n', 0), SenseInfo('06887726-n', 0), SenseInfo('03211117-n', 0) ],
"_demagogic_a_1_rel" : [ SenseInfo('03060782-a', 0) ],
"_sin_n_1_rel" : [ SenseInfo('04827957-n', 14), SenseInfo('00757080-n', 9), SenseInfo('13787379-n', 0), SenseInfo('09521994-n', 0), SenseInfo('06838868-n', 0), SenseInfo('01260731-n', 0) ],
"_follower_n_1_rel" : [ SenseInfo('10099375-n', 7), SenseInfo('10100124-n', 0) ],
"_synchronize_v_with_rel" : [ SenseInfo('00393953-v', 1), SenseInfo('02739254-v', 0), SenseInfo('00960734-v', 0), SenseInfo('00735866-v', 0), SenseInfo('00464996-v', 0), SenseInfo('00464828-v', 0), SenseInfo('00393953-v', 1), SenseInfo('02739254-v', 0), SenseInfo('00960734-v', 0), SenseInfo('00735866-v', 0), SenseInfo('00464996-v', 0), SenseInfo('00464828-v', 0), SenseInfo('00393953-v', 1), SenseInfo('02739254-v', 0), SenseInfo('00960734-v', 0), SenseInfo('00735866-v', 0), SenseInfo('00464996-v', 0), SenseInfo('00464828-v', 0) ],
"_put_v_out_rel" : [ SenseInfo('01494310-v', 138), SenseInfo('01493741-v', 98), SenseInfo('00981276-v', 28), SenseInfo('01160370-v', 6), SenseInfo('02271137-v', 3), SenseInfo('00673448-v', 2), SenseInfo('02111499-v', 0), SenseInfo('01706375-v', 0), SenseInfo('00735571-v', 0), SenseInfo('01494310-v', 138), SenseInfo('01493741-v', 98), SenseInfo('00981276-v', 28), SenseInfo('01160370-v', 6), SenseInfo('02271137-v', 3), SenseInfo('00673448-v', 2), SenseInfo('02111499-v', 0), SenseInfo('01706375-v', 0), SenseInfo('00735571-v', 0) ],
"_various_a_1_rel" : [ SenseInfo('02065665-a', 46), SenseInfo('00494409-a', 36), SenseInfo('02067491-a', 3), SenseInfo('02507772-a', 2), SenseInfo('02065665-a', 46), SenseInfo('00494409-a', 36), SenseInfo('02067491-a', 3), SenseInfo('02507772-a', 2) ],
"_imprisonment_n_of_rel" : [ SenseInfo('01162376-n', 3), SenseInfo('13999206-n', 0), SenseInfo('01146768-n', 0) ],
"_wow_a_1_rel" : [ SenseInfo('06778925-n', 0), SenseInfo('06778925-n', 0) ],
"_despondency_n_1_rel" : [ SenseInfo('07538395-n', 1) ],
"_axillary_a_1_rel" : [ SenseInfo('03133666-a', 0), SenseInfo('02655180-a', 0) ],
"_herdsman_n_1_rel" : [ SenseInfo('10171567-n', 0) ],
"_outpost_n_1_rel" : [ SenseInfo('08613985-n', 1), SenseInfo('08374653-n', 1), SenseInfo('03860741-n', 1) ],
"_novelist_n_1_rel" : [ SenseInfo('10363573-n', 6) ],
"_abrupt_a_1_rel" : [ SenseInfo('02294122-a', 3), SenseInfo('01143585-a', 2), SenseInfo('01145151-a', 0), SenseInfo('00640520-a', 0), SenseInfo('02294122-a', 3), SenseInfo('01143585-a', 2), SenseInfo('01145151-a', 0), SenseInfo('00640520-a', 0) ],
"_foam_n_1_rel" : [ SenseInfo('09282724-n', 4), SenseInfo('14872697-n', 1) ],
"_fuck_v_off_rel" : [ SenseInfo('01426397-v', 0) ],
"_disqualify_v_from_rel" : [ SenseInfo('00301338-v', 1), SenseInfo('00972608-v', 0), SenseInfo('00301338-v', 1), SenseInfo('00972608-v', 0), SenseInfo('00301338-v', 1), SenseInfo('00972608-v', 0) ],
"_educated_n_1_rel" : [ SenseInfo('00829745-a', 5), SenseInfo('01307375-a', 0) ],
"_mobilize_v_1_rel" : [ SenseInfo('00270215-v', 5), SenseInfo('01097960-v', 2), SenseInfo('01088381-v', 0), SenseInfo('00270005-v', 0) ],
"_got_v_to_rel" : [  ],
"_buy_v_up_rel" : [ SenseInfo('02207206-v', 102), SenseInfo('02284096-v', 2), SenseInfo('02646757-v', 0), SenseInfo('02212103-v', 0), SenseInfo('00683670-v', 0) ],
"_in+that_x_rel" : [ SenseInfo('00240707-r', 4) ],
"_withdraw_v_from_rel" : [ SenseInfo('01994442-v', 9), SenseInfo('02380009-v', 4), SenseInfo('01511380-v', 4), SenseInfo('02312478-v', 2), SenseInfo('00799076-v', 1), SenseInfo('00495998-v', 1), SenseInfo('02428487-v', 0), SenseInfo('02380760-v', 0), SenseInfo('02311387-v', 0), SenseInfo('01766952-v', 0), SenseInfo('00799383-v', 0), SenseInfo('00173338-v', 0) ],
"_tack_v_on_rel" : [ SenseInfo('01357429-v', 3), SenseInfo('01946408-v', 1), SenseInfo('01656788-v', 0), SenseInfo('01331348-v', 0), SenseInfo('01328513-v', 0), SenseInfo('00121678-v', 0) ],
"_sibling_n_1_rel" : [ SenseInfo('10595164-n', 0) ],
"_falcon_n_1_rel" : [ SenseInfo('01610955-n', 2) ],
"_bite_v_off_rel" : [ SenseInfo('01445932-v', 12), SenseInfo('02120451-v', 2), SenseInfo('01441382-v', 1), SenseInfo('01445407-v', 0) ],
"_spacer_n_1_rel" : [  ],
"_furniture_n_1_rel" : [ SenseInfo('03405725-n', 11) ],
"_fine_n_1_rel" : [ SenseInfo('13301328-n', 0) ],
"_turbo_n_1_rel" : [  ],
"_task_n_of_rel" : [ SenseInfo('00795720-n', 18), SenseInfo('00719705-n', 15), SenseInfo('00795720-n', 18), SenseInfo('00719705-n', 15), SenseInfo('00795720-n', 18), SenseInfo('00719705-n', 15) ],
"_fold_v_cause_rel" : [ SenseInfo('01277974-v', 5), SenseInfo('00398138-v', 1), SenseInfo('02426395-v', 0), SenseInfo('01345877-v', 0), SenseInfo('00564695-v', 0) ],
"_decompress_v_1_rel" : [ SenseInfo('01389607-v', 0), SenseInfo('00403967-v', 0), SenseInfo('00026385-v', 0) ],
"_redpoll_n_1_rel" : [ SenseInfo('01531971-n', 0), SenseInfo('01531811-n', 0), SenseInfo('01531971-n', 0), SenseInfo('01531811-n', 0) ],
"_by_p_cm_rel" : [ SenseInfo('00417787-r', 2), SenseInfo('00233687-r', 0), SenseInfo('00417787-r', 2), SenseInfo('00233687-r', 0) ],
"_all+summer+long_a_1_rel" : [  ],
"_underwear_n_1_rel" : [ SenseInfo('04508949-n', 1) ],
"_imaginable_a_to_rel" : [ SenseInfo('02418249-a', 0), SenseInfo('02418249-a', 0), SenseInfo('02418249-a', 0) ],
"_rapturous_a_1_rel" : [ SenseInfo('01367008-a', 0) ],
"_thin_v_out_rel" : [ SenseInfo('00430999-v', 2), SenseInfo('00430625-v', 0), SenseInfo('00226071-v', 0), SenseInfo('00045817-v', 0), SenseInfo('00430999-v', 2), SenseInfo('00430625-v', 0), SenseInfo('00226071-v', 0), SenseInfo('00045817-v', 0) ],
"_wallet_n_1_rel" : [ SenseInfo('04548362-n', 2) ],
"_summery_a_1_rel" : [ SenseInfo('01254784-a', 0) ],
"_hut_n_1_rel" : [ SenseInfo('03550153-n', 14), SenseInfo('03547054-n', 4), SenseInfo('03550153-n', 14), SenseInfo('03547054-n', 4) ],
"_differential_n_1_rel" : [ SenseInfo('06014730-n', 1), SenseInfo('04749310-n', 0), SenseInfo('03194297-n', 0) ],
"_little+wonder_a_1_rel" : [  ],
"_look_v_like_rel" : [ SenseInfo('02130524-v', 274), SenseInfo('02133435-v', 126), SenseInfo('00033599-v', 25), SenseInfo('02153709-v', 8), SenseInfo('02693319-v', 1), SenseInfo('02549581-v', 1), SenseInfo('00929362-v', 1), SenseInfo('00720063-v', 1), SenseInfo('02658447-v', 0), SenseInfo('00712708-v', 0) ],
"_ponderable_a_1_rel" : [ SenseInfo('01815309-a', 0), SenseInfo('02418093-a', 0) ],
"_self-explanatory_a_1_rel" : [ SenseInfo('01619604-a', 0), SenseInfo('01619604-a', 0), SenseInfo('01619604-a', 0), SenseInfo('01619604-a', 0), SenseInfo('01619604-a', 0), SenseInfo('01619604-a', 0) ],
"_center_v_1_rel" : [ SenseInfo('02676496-v', 11), SenseInfo('00722232-v', 5), SenseInfo('01852701-v', 0), SenseInfo('02676496-v', 11), SenseInfo('00722232-v', 5), SenseInfo('01852701-v', 0) ],
"_yawn_n_1_rel" : [ SenseInfo('00837293-n', 1) ],
"_bonnet_n_1_rel" : [ SenseInfo('02869837-n', 3), SenseInfo('03530910-n', 0) ],
"_enlist_v_cause_rel" : [ SenseInfo('01097192-v', 7), SenseInfo('02240151-v', 6), SenseInfo('01097500-v', 1) ],
"_readable_a_1_rel" : [ SenseInfo('01405047-a', 1) ],
"_tender_a_1_rel" : [ SenseInfo('02448889-a', 2), SenseInfo('01712753-a', 2), SenseInfo('01649561-a', 2), SenseInfo('01464700-a', 2), SenseInfo('02446651-a', 1), SenseInfo('02448166-a', 0), SenseInfo('02292421-a', 0), SenseInfo('00707206-a', 0), SenseInfo('02448889-a', 2), SenseInfo('01712753-a', 2), SenseInfo('01649561-a', 2), SenseInfo('01464700-a', 2), SenseInfo('02446651-a', 1), SenseInfo('02448166-a', 0), SenseInfo('02292421-a', 0), SenseInfo('00707206-a', 0), SenseInfo('02448889-a', 2), SenseInfo('01712753-a', 2), SenseInfo('01649561-a', 2), SenseInfo('01464700-a', 2), SenseInfo('02446651-a', 1), SenseInfo('02448166-a', 0), SenseInfo('02292421-a', 0), SenseInfo('00707206-a', 0), SenseInfo('02448889-a', 2), SenseInfo('01712753-a', 2), SenseInfo('01649561-a', 2), SenseInfo('01464700-a', 2), SenseInfo('02446651-a', 1), SenseInfo('02448166-a', 0), SenseInfo('02292421-a', 0), SenseInfo('00707206-a', 0) ],
"_correspondence_n_1_rel" : [ SenseInfo('06623614-n', 5), SenseInfo('04713428-n', 2), SenseInfo('13817279-n', 0), SenseInfo('05064827-n', 0), SenseInfo('04745240-n', 0) ],
"_class_v_with_rel" : [ SenseInfo('00654625-v', 2) ],
"_cosmetics_n_1_rel" : [ SenseInfo('03113152-n', 0), SenseInfo('03113152-n', 0), SenseInfo('03113152-n', 0), SenseInfo('03113152-n', 0) ],
"_nightly_a_1_rel" : [ SenseInfo('01968352-a', 0), SenseInfo('01968352-a', 0) ],
"_inclined_a_1_rel" : [ SenseInfo('01292128-a', 4), SenseInfo('01234167-a', 0), SenseInfo('02565425-a', 0) ],
"_cost_v_x_rel" : [ SenseInfo('02702508-v', 35), SenseInfo('02628961-v', 16), SenseInfo('02702508-v', 35), SenseInfo('02628961-v', 16), SenseInfo('02702508-v', 35), SenseInfo('02628961-v', 16), SenseInfo('02702508-v', 35), SenseInfo('02628961-v', 16), SenseInfo('02702508-v', 35), SenseInfo('02628961-v', 16) ],
"_bless_v_1_rel" : [ SenseInfo('00866505-v', 4), SenseInfo('02264075-v', 1), SenseInfo('00867231-v', 1), SenseInfo('00866702-v', 0) ],
"_off-again_a_1_rel" : [  ],
"_hub_n_1_rel" : [ SenseInfo('03547658-n', 2), SenseInfo('08543223-n', 0) ],
"_warm_v_1_rel" : [ SenseInfo('00373250-v', 2), SenseInfo('00372958-v', 1) ],
"_southwestward_a_2_rel" : [ SenseInfo('01604146-a', 0), SenseInfo('01604146-a', 0) ],
"_flash_v_1_rel" : [ SenseInfo('02159890-v', 9), SenseInfo('00424691-v', 6), SenseInfo('02141973-v', 3), SenseInfo('00929509-v', 3), SenseInfo('02061495-v', 2), SenseInfo('02138611-v', 1), SenseInfo('01335461-v', 0), SenseInfo('00424869-v', 0), SenseInfo('02159890-v', 9), SenseInfo('00424691-v', 6), SenseInfo('02141973-v', 3), SenseInfo('00929509-v', 3), SenseInfo('02061495-v', 2), SenseInfo('02138611-v', 1), SenseInfo('01335461-v', 0), SenseInfo('00424869-v', 0) ],
"_substantive_a_1_rel" : [ SenseInfo('00901969-a', 1), SenseInfo('00055539-a', 0), SenseInfo('01497245-a', 0), SenseInfo('00901969-a', 1), SenseInfo('00055539-a', 0), SenseInfo('01497245-a', 0) ],
"_tinned_a_1_rel" : [ SenseInfo('01072112-a', 0) ],
"_alkaline_a_1_rel" : [ SenseInfo('00025728-a', 2) ],
"_dreamwork_n_1_rel" : [  ],
"_chafe_v_1_rel" : [ SenseInfo('02119659-v', 2), SenseInfo('01788733-v', 0), SenseInfo('01787955-v', 0), SenseInfo('01253808-v', 0), SenseInfo('01250908-v', 0), SenseInfo('00373397-v', 0) ],
"_gnaw_v_1_rel" : [ SenseInfo('01445597-v', 2), SenseInfo('00275253-v', 1) ],
"_unredeemed_a_1_rel" : [ SenseInfo('01451225-a', 1), SenseInfo('01451225-a', 1) ],
"_starfish_n_1_rel" : [ SenseInfo('02317335-n', 0) ],
"_high_x_deg_rel" : [ SenseInfo('01210854-a', 134), SenseInfo('01204557-a', 51), SenseInfo('02339120-a', 10), SenseInfo('00356957-r', 9), SenseInfo('01213197-a', 7), SenseInfo('05097536-n', 5), SenseInfo('00357139-r', 2), SenseInfo('00705498-a', 2), SenseInfo('14520670-n', 0), SenseInfo('14405621-n', 0), SenseInfo('14405452-n', 0), SenseInfo('08584618-n', 0), SenseInfo('08409617-n', 0), SenseInfo('03518631-n', 0), SenseInfo('00357251-r', 0), SenseInfo('00357052-r', 0), SenseInfo('01054047-a', 0), SenseInfo('00799224-a', 0), SenseInfo('01210854-a', 134), SenseInfo('01204557-a', 51), SenseInfo('02339120-a', 10), SenseInfo('00356957-r', 9), SenseInfo('01213197-a', 7), SenseInfo('05097536-n', 5), SenseInfo('00357139-r', 2), SenseInfo('00705498-a', 2), SenseInfo('14520670-n', 0), SenseInfo('14405621-n', 0), SenseInfo('14405452-n', 0), SenseInfo('08584618-n', 0), SenseInfo('08409617-n', 0), SenseInfo('03518631-n', 0), SenseInfo('00357251-r', 0), SenseInfo('00357052-r', 0), SenseInfo('01054047-a', 0), SenseInfo('00799224-a', 0) ],
"_lust_n_1_rel" : [ SenseInfo('07489714-n', 1), SenseInfo('00759335-n', 1) ],
"_military_n_1_rel" : [ SenseInfo('08199025-n', 1) ],
"_fine_a_1_rel" : [ SenseInfo('02081114-a', 4), SenseInfo('01838253-a', 4), SenseInfo('02414031-a', 2), SenseInfo('00850183-a', 2), SenseInfo('02232251-a', 1), SenseInfo('01906817-a', 0) ],
"_prime_v_1_rel" : [ SenseInfo('00408624-v', 1), SenseInfo('01365355-v', 0), SenseInfo('00454018-v', 0) ],
"_console_n_1_rel" : [ SenseInfo('03092883-n', 0), SenseInfo('03092656-n', 0), SenseInfo('03092476-n', 0), SenseInfo('02933340-n', 0) ],
"_deceit_n_1_rel" : [ SenseInfo('04875352-n', 1), SenseInfo('06758225-n', 0), SenseInfo('00752431-n', 0) ],
"_hourly_a_1_rel" : [ SenseInfo('01968811-a', 0), SenseInfo('01968811-a', 0) ],
"_industrialized_a_1_rel" : [ SenseInfo('01301992-a', 0) ],
"_scruffy_a_1_rel" : [ SenseInfo('02583271-a', 0) ],
"_butcher_v_1_rel" : [ SenseInfo('01322854-v', 1) ],
"_chop_n_1_rel" : [ SenseInfo('11527767-n', 0), SenseInfo('07653982-n', 0), SenseInfo('05546298-n', 0), SenseInfo('00566889-n', 0), SenseInfo('00129317-n', 0) ],
"_book_v_up_rel" : [ SenseInfo('00678777-v', 3), SenseInfo('02498320-v', 1), SenseInfo('02498136-v', 1), SenseInfo('02599754-v', 0) ],
"_killing_n_1_rel" : [ SenseInfo('07361576-n', 5), SenseInfo('00219012-n', 5), SenseInfo('13259797-n', 0) ],
"_rule_v_1_rel" : [ SenseInfo('02586619-v', 12), SenseInfo('00715868-v', 9), SenseInfo('02644234-v', 2), SenseInfo('00971999-v', 1), SenseInfo('02716995-v', 0), SenseInfo('01690020-v', 0), SenseInfo('00234857-v', 0), SenseInfo('02586619-v', 12), SenseInfo('00715868-v', 9), SenseInfo('02644234-v', 2), SenseInfo('00971999-v', 1), SenseInfo('02716995-v', 0), SenseInfo('01690020-v', 0), SenseInfo('00234857-v', 0), SenseInfo('02586619-v', 12), SenseInfo('00715868-v', 9), SenseInfo('02644234-v', 2), SenseInfo('00971999-v', 1), SenseInfo('02716995-v', 0), SenseInfo('01690020-v', 0), SenseInfo('00234857-v', 0) ],
"_editorial_n_1_rel" : [ SenseInfo('06268567-n', 4) ],
"_pirate_n_1_rel" : [ SenseInfo('10437262-n', 2), SenseInfo('10435367-n', 1), SenseInfo('03947888-n', 0) ],
"_use_v_as_rel" : [ SenseInfo('01158872-v', 603), SenseInfo('01165043-v', 12), SenseInfo('01158572-v', 8), SenseInfo('02600490-v', 0), SenseInfo('02561332-v', 0), SenseInfo('02370131-v', 0), SenseInfo('01158872-v', 603), SenseInfo('01165043-v', 12), SenseInfo('01158572-v', 8), SenseInfo('02600490-v', 0), SenseInfo('02561332-v', 0), SenseInfo('02370131-v', 0) ],
"_tattered_a_1_rel" : [ SenseInfo('02583619-a', 35), SenseInfo('00736671-a', 0) ],
"_sweetie_n_1_rel" : [ SenseInfo('10682953-n', 0) ],
"_methodology_n_1_rel" : [ SenseInfo('06166898-n', 0), SenseInfo('05661400-n', 0) ],
"_giant_n_1_rel" : [ SenseInfo('01323781-n', 6), SenseInfo('09938991-n', 2), SenseInfo('08056471-n', 2), SenseInfo('10129133-n', 0), SenseInfo('10128909-n', 0), SenseInfo('09488711-n', 0), SenseInfo('09288769-n', 0) ],
"_bully_n_1_rel" : [ SenseInfo('09879297-n', 1), SenseInfo('09879552-n', 0) ],
"_reflect_v_on_rel" : [ SenseInfo('02136892-v', 41), SenseInfo('00630380-v', 18), SenseInfo('02136271-v', 17), SenseInfo('02765924-v', 5), SenseInfo('02136754-v', 0), SenseInfo('00821765-v', 0), SenseInfo('00821580-v', 0) ],
"_propriety_n_1_rel" : [ SenseInfo('04898437-n', 1) ],
"_taper_v_off_rel" : [ SenseInfo('00152762-v', 1), SenseInfo('00392960-v', 0) ],
"_initial_n_1_rel" : [ SenseInfo('06830997-n', 1) ],
"_harmful_a_to_rel" : [ SenseInfo('01160031-a', 0) ],
"_absent_p_rel" : [ SenseInfo('01847672-a', 12), SenseInfo('00421535-v', 2), SenseInfo('00927832-a', 0), SenseInfo('00165171-a', 0), SenseInfo('01847672-a', 12), SenseInfo('00421535-v', 2), SenseInfo('00927832-a', 0), SenseInfo('00165171-a', 0) ],
"_abortion_n_of_rel" : [ SenseInfo('00230324-n', 3), SenseInfo('07319652-n', 0) ],
"_malformed_a_1_rel" : [ SenseInfo('02141298-a', 1) ],
"_environ_v_1_rel" : [ SenseInfo('01467370-v', 0) ],
"_dwell_v_1_rel" : [ SenseInfo('00704249-v', 4), SenseInfo('02653381-v', 3), SenseInfo('02649830-v', 3), SenseInfo('02755773-v', 0), SenseInfo('00959367-v', 0) ],
"_goat_n_1_rel" : [ SenseInfo('02416519-n', 6), SenseInfo('09884666-n', 0), SenseInfo('09753498-n', 0), SenseInfo('08687709-n', 0) ],
"_acoustic_a_1_rel" : [ SenseInfo('02868489-a', 0) ],
"_equalize_v_1_rel" : [ SenseInfo('01115411-v', 0), SenseInfo('00417001-v', 0) ],
"_invent_v_1_rel" : [ SenseInfo('01632411-v', 14), SenseInfo('01634424-v', 5) ],
"_confetti_n_1_rel" : [ SenseInfo('03090278-n', 0) ],
"_helper_n_1_rel" : [ SenseInfo('09815790-n', 1), SenseInfo('09608709-n', 1) ],
"_keep_v_on_rel" : [ SenseInfo('02681795-v', 206), SenseInfo('02684924-v', 39), SenseInfo('02202384-v', 32), SenseInfo('02450505-v', 22), SenseInfo('02578872-v', 10), SenseInfo('00732552-v', 9), SenseInfo('02202928-v', 8), SenseInfo('01065877-v', 4), SenseInfo('02651853-v', 3), SenseInfo('02410175-v', 3), SenseInfo('01184625-v', 3), SenseInfo('02734800-v', 2), SenseInfo('02578510-v', 2), SenseInfo('02422663-v', 2), SenseInfo('02733122-v', 1), SenseInfo('02652016-v', 0), SenseInfo('02283716-v', 0), SenseInfo('02204094-v', 0), SenseInfo('02203844-v', 0), SenseInfo('02203168-v', 0), SenseInfo('01302019-v', 0), SenseInfo('00212414-v', 0), SenseInfo('02681795-v', 206), SenseInfo('02684924-v', 39), SenseInfo('02202384-v', 32), SenseInfo('02450505-v', 22), SenseInfo('02578872-v', 10), SenseInfo('00732552-v', 9), SenseInfo('02202928-v', 8), SenseInfo('01065877-v', 4), SenseInfo('02651853-v', 3), SenseInfo('02410175-v', 3), SenseInfo('01184625-v', 3), SenseInfo('02734800-v', 2), SenseInfo('02578510-v', 2), SenseInfo('02422663-v', 2), SenseInfo('02733122-v', 1), SenseInfo('02652016-v', 0), SenseInfo('02283716-v', 0), SenseInfo('02204094-v', 0), SenseInfo('02203844-v', 0), SenseInfo('02203168-v', 0), SenseInfo('01302019-v', 0), SenseInfo('00212414-v', 0), SenseInfo('02681795-v', 206), SenseInfo('02684924-v', 39), SenseInfo('02202384-v', 32), SenseInfo('02450505-v', 22), SenseInfo('02578872-v', 10), SenseInfo('00732552-v', 9), SenseInfo('02202928-v', 8), SenseInfo('01065877-v', 4), SenseInfo('02651853-v', 3), SenseInfo('02410175-v', 3), SenseInfo('01184625-v', 3), SenseInfo('02734800-v', 2), SenseInfo('02578510-v', 2), SenseInfo('02422663-v', 2), SenseInfo('02733122-v', 1), SenseInfo('02652016-v', 0), SenseInfo('02283716-v', 0), SenseInfo('02204094-v', 0), SenseInfo('02203844-v', 0), SenseInfo('02203168-v', 0), SenseInfo('01302019-v', 0), SenseInfo('00212414-v', 0) ],
"_wreck_n_1_rel" : [ SenseInfo('14423870-n', 1), SenseInfo('07353075-n', 0), SenseInfo('07301950-n', 0), SenseInfo('04606251-n', 0) ],
"_rotation_n_of_rel" : [ SenseInfo('00342028-n', 3), SenseInfo('13785557-n', 0), SenseInfo('07440979-n', 0), SenseInfo('05045381-n', 0) ],
"_dynamics_n_1_rel" : [ SenseInfo('09179962-n', 0) ],
"_consulate_n_1_rel" : [ SenseInfo('03093427-n', 0) ],
"_curate_v_1_rel" : [  ],
"_afterwards_p_1_rel" : [ SenseInfo('00061203-r', 6) ],
"_allergic_a_to_rel" : [ SenseInfo('02612653-a', 0), SenseInfo('02360944-a', 0) ],
"_press_v_in_rel" : [ SenseInfo('01447257-v', 32), SenseInfo('00765649-v', 7), SenseInfo('02646064-v', 2), SenseInfo('01390616-v', 2), SenseInfo('01387786-v', 2), SenseInfo('02024367-v', 1), SenseInfo('01754105-v', 1), SenseInfo('02722782-v', 0), SenseInfo('02589576-v', 0), SenseInfo('01662614-v', 0), SenseInfo('01447632-v', 0), SenseInfo('01390833-v', 0), SenseInfo('01150370-v', 0), SenseInfo('00759657-v', 0) ],
"_quotation_n_of_rel" : [ SenseInfo('06763681-n', 1), SenseInfo('06613056-n', 1), SenseInfo('06756267-n', 0), SenseInfo('01030642-n', 0) ],
"_binary_a_1_rel" : [ SenseInfo('02664700-a', 0), SenseInfo('02216985-a', 0) ],
"_felicity_n_1_rel" : [ SenseInfo('04716210-n', 1), SenseInfo('13987423-n', 0) ],
"_uninteresting_a_1_rel" : [ SenseInfo('01344963-a', 0), SenseInfo('01231638-a', 0), SenseInfo('01344963-a', 0), SenseInfo('01231638-a', 0), SenseInfo('01344963-a', 0), SenseInfo('01231638-a', 0) ],
"_dentist_n_1_rel" : [ SenseInfo('10004282-n', 3) ],
"_pneumatic_a_1_rel" : [ SenseInfo('02838894-a', 0), SenseInfo('02838894-a', 0) ],
"_bandage_v_up_rel" : [ SenseInfo('01303547-v', 0), SenseInfo('00083124-v', 0) ],
"_flash_n_of_rel" : [ SenseInfo('07412092-n', 7), SenseInfo('04953186-n', 6), SenseInfo('07287088-n', 1), SenseInfo('05808442-n', 1), SenseInfo('15247110-n', 0), SenseInfo('06889330-n', 0), SenseInfo('06874930-n', 0), SenseInfo('06682494-n', 0), SenseInfo('03358380-n', 0), SenseInfo('03358172-n', 0) ],
"_rocket_n_1_rel" : [ SenseInfo('04099429-n', 2), SenseInfo('04099175-n', 2), SenseInfo('11886537-n', 0), SenseInfo('07263053-n', 0), SenseInfo('04232902-n', 0) ],
"_scenic_a_1_rel" : [ SenseInfo('00220600-a', 5), SenseInfo('02792789-a', 0) ],
"_hyphen_n_1_rel" : [ SenseInfo('06843148-n', 0) ],
"_echinoderm_n_1_rel" : [ SenseInfo('02316707-n', 0) ],
"_silk_n_1_rel" : [ SenseInfo('04219424-n', 6), SenseInfo('15041911-n', 1) ],
"_ahem_a_1_rel" : [ SenseInfo('07126521-n', 0) ],
"_at+any+rate_a_1_rel" : [  ],
"_mush_n_1_rel" : [ SenseInfo('09400826-n', 0), SenseInfo('07703333-n', 0), SenseInfo('06775969-n', 0), SenseInfo('00308208-n', 0) ],
"_correlate_v_cause_rel" : [ SenseInfo('02658979-v', 4), SenseInfo('00713996-v', 0) ],
"_network_n_of_rel" : [ SenseInfo('08434259-n', 23), SenseInfo('03820474-n', 4), SenseInfo('03819595-n', 1), SenseInfo('03820950-n', 0), SenseInfo('03820728-n', 0), SenseInfo('08434259-n', 23), SenseInfo('03820474-n', 4), SenseInfo('03819595-n', 1), SenseInfo('03820950-n', 0), SenseInfo('03820728-n', 0), SenseInfo('08434259-n', 23), SenseInfo('03820474-n', 4), SenseInfo('03819595-n', 1), SenseInfo('03820950-n', 0), SenseInfo('03820728-n', 0), SenseInfo('08434259-n', 23), SenseInfo('03820474-n', 4), SenseInfo('03819595-n', 1), SenseInfo('03820950-n', 0), SenseInfo('03820728-n', 0) ],
"_acrobatic_a_1_rel" : [ SenseInfo('00032497-a', 1) ],
"_framework_n_1_rel" : [ SenseInfo('05890249-n', 3), SenseInfo('04933363-n', 1), SenseInfo('03391770-n', 0) ],
"_projection_n_of_rel" : [ SenseInfo('05775293-n', 9), SenseInfo('06887599-n', 3), SenseInfo('05910453-n', 1), SenseInfo('04008947-n', 1), SenseInfo('13919685-n', 0), SenseInfo('13541798-n', 0), SenseInfo('11512331-n', 0), SenseInfo('04009382-n', 0), SenseInfo('00407090-n', 0), SenseInfo('00116687-n', 0), SenseInfo('05775293-n', 9), SenseInfo('06887599-n', 3), SenseInfo('05910453-n', 1), SenseInfo('04008947-n', 1), SenseInfo('13919685-n', 0), SenseInfo('13541798-n', 0), SenseInfo('11512331-n', 0), SenseInfo('04009382-n', 0), SenseInfo('00407090-n', 0), SenseInfo('00116687-n', 0) ],
"_bust_n_1_rel" : [ SenseInfo('07365024-n', 0), SenseInfo('05551494-n', 0), SenseInfo('02926188-n', 0), SenseInfo('00510723-n', 0) ],
"_also_a_1_rel" : [  ],
"_visible_a_to_rel" : [ SenseInfo('02515341-a', 14), SenseInfo('01705513-a', 2), SenseInfo('00184792-a', 0) ],
"_breeze_n_1_rel" : [ SenseInfo('11431754-n', 6), SenseInfo('00575365-n', 0), SenseInfo('11431754-n', 6), SenseInfo('00575365-n', 0), SenseInfo('11431754-n', 6), SenseInfo('00575365-n', 0) ],
"_colourful_a_1_rel" : [ SenseInfo('00406867-a', 0), SenseInfo('00402419-a', 0) ],
"_shrinkage_n_1_rel" : [ SenseInfo('07313004-n', 0), SenseInfo('05112215-n', 0), SenseInfo('00781480-n', 0) ],
"_ip_n_1_rel" : [ SenseInfo('06142118-n', 0) ],
"_decide_v_upon_rel" : [ SenseInfo('00697589-v', 123), SenseInfo('00698855-v', 6), SenseInfo('00699485-v', 4), SenseInfo('00701877-v', 0) ],
"_at+best_a_1_rel" : [  ],
"_plague_n_1_rel" : [ SenseInfo('14138691-n', 0), SenseInfo('14076479-n', 0), SenseInfo('07996412-n', 0), SenseInfo('07316603-n', 0), SenseInfo('05831939-n', 0) ],
"_bite_v_out_rel" : [ SenseInfo('01445932-v', 12), SenseInfo('02120451-v', 2), SenseInfo('01441382-v', 1), SenseInfo('01445407-v', 0) ],
"_fraternal_a_1_rel" : [ SenseInfo('02731699-a', 0), SenseInfo('00292298-a', 0), SenseInfo('00291471-a', 0) ],
"_impudence_n_1_rel" : [ SenseInfo('06721813-n', 0), SenseInfo('04915866-n', 0) ],
"_clip_v_off_rel" : [ SenseInfo('01456463-v', 2), SenseInfo('01901447-v', 0), SenseInfo('01367616-v', 0), SenseInfo('01321002-v', 0), SenseInfo('00292877-v', 0) ],
"_forsaken_a_1_rel" : [  ],
"_lengthened_a_1_rel" : [ SenseInfo('01434218-a', 0) ],
"_investigator_n_1_rel" : [ SenseInfo('10523076-n', 8), SenseInfo('10215623-n', 1), SenseInfo('10009276-n', 1) ],
"_students_a_1_rel" : [  ],
"_dine_v_1_rel" : [ SenseInfo('01167981-v', 6), SenseInfo('01167780-v', 0) ],
"_plea-bargain_v_1_rel" : [ SenseInfo('00764526-v', 0), SenseInfo('00764526-v', 0) ],
"_lurch_v_1_rel" : [ SenseInfo('01924882-v', 5), SenseInfo('01864634-v', 3), SenseInfo('02097544-v', 2), SenseInfo('02639475-v', 0), SenseInfo('01103693-v', 0) ],
"_rollicking_a_1_rel" : [ SenseInfo('02122132-a', 0), SenseInfo('02122132-a', 0) ],
"_laurel_n_1_rel" : [ SenseInfo('11703669-n', 0), SenseInfo('11119190-n', 0), SenseInfo('03648804-n', 0) ],
"_humanity_n_1_rel" : [ SenseInfo('04829182-n', 1), SenseInfo('04726938-n', 1), SenseInfo('02472987-n', 0) ],
"_monastery_n_1_rel" : [ SenseInfo('03781244-n', 1) ],
"_gentleman_n_1_rel" : [ SenseInfo('10127273-n', 9), SenseInfo('10745332-n', 0) ],
"_impractical_a_for_rel" : [ SenseInfo('01836350-a', 2), SenseInfo('02498213-a', 0), SenseInfo('01836350-a', 2), SenseInfo('02498213-a', 0) ],
"_convivial_a_1_rel" : [ SenseInfo('02258002-a', 1) ],
"_crag_n_1_rel" : [ SenseInfo('09259025-n', 1) ],
"_schoolbag_n_1_rel" : [ SenseInfo('04146343-n', 0) ],
"_fade_v_1_rel" : [ SenseInfo('00224651-v', 6), SenseInfo('00421917-v', 4), SenseInfo('00421691-v', 4), SenseInfo('00093593-v', 0), SenseInfo('00224651-v', 6), SenseInfo('00421917-v', 4), SenseInfo('00421691-v', 4), SenseInfo('00093593-v', 0) ],
"_happy_a_with_rel" : [ SenseInfo('01148283-a', 37), SenseInfo('01048406-a', 2), SenseInfo('02565583-a', 0), SenseInfo('01000442-a', 0), SenseInfo('01148283-a', 37), SenseInfo('01048406-a', 2), SenseInfo('02565583-a', 0), SenseInfo('01000442-a', 0), SenseInfo('01148283-a', 37), SenseInfo('01048406-a', 2), SenseInfo('02565583-a', 0), SenseInfo('01000442-a', 0), SenseInfo('01148283-a', 37), SenseInfo('01048406-a', 2), SenseInfo('02565583-a', 0), SenseInfo('01000442-a', 0), SenseInfo('01148283-a', 37), SenseInfo('01048406-a', 2), SenseInfo('02565583-a', 0), SenseInfo('01000442-a', 0), SenseInfo('01148283-a', 37), SenseInfo('01048406-a', 2), SenseInfo('02565583-a', 0), SenseInfo('01000442-a', 0), SenseInfo('01148283-a', 37), SenseInfo('01048406-a', 2), SenseInfo('02565583-a', 0), SenseInfo('01000442-a', 0), SenseInfo('01148283-a', 37), SenseInfo('01048406-a', 2), SenseInfo('02565583-a', 0), SenseInfo('01000442-a', 0) ],
"_shortcoming_n_1_rel" : [ SenseInfo('05162642-n', 0) ],
"_reader_n_of_rel" : [ SenseInfo('10508710-n', 19), SenseInfo('10670483-n', 9), SenseInfo('10508862-n', 2), SenseInfo('10526927-n', 0), SenseInfo('10482768-n', 0), SenseInfo('10252354-n', 0), SenseInfo('10252222-n', 0), SenseInfo('06415061-n', 0) ],
"_wear+and+tear_n_1_rel" : [ SenseInfo('13328357-n', 0) ],
"_repose_n_1_rel" : [ SenseInfo('01064148-n', 3), SenseInfo('07515790-n', 0), SenseInfo('04904352-n', 0) ],
"_pragmatics_n_1_rel" : [ SenseInfo('06541578-n', 0) ],
"_mama_n_1_rel" : [ SenseInfo('10278128-n', 6), SenseInfo('09519192-n', 0) ],
"_elbow_v_1_rel" : [ SenseInfo('01873942-v', 1), SenseInfo('01239494-v', 0), SenseInfo('01873942-v', 1), SenseInfo('01239494-v', 0) ],
"_counselor_n_1_rel" : [ SenseInfo('09968845-n', 3), SenseInfo('09969062-n', 1), SenseInfo('09775663-n', 0) ],
"_slough_n_1_rel" : [ SenseInfo('14313440-n', 0), SenseInfo('09438313-n', 0), SenseInfo('09438212-n', 0), SenseInfo('09438055-n', 0) ],
"_accusative_n_1_rel" : [ SenseInfo('06311557-n', 0), SenseInfo('06311557-n', 0), SenseInfo('06311557-n', 0) ],
"_ever+since_a_1_rel" : [  ],
"_spike_n_1_rel" : [ SenseInfo('07308450-n', 2), SenseInfo('04275661-n', 1), SenseInfo('13133613-n', 0), SenseInfo('13133438-n', 0), SenseInfo('07479366-n', 0), SenseInfo('04276808-n', 0), SenseInfo('04276531-n', 0), SenseInfo('04276404-n', 0), SenseInfo('04276249-n', 0), SenseInfo('04276050-n', 0), SenseInfo('04275904-n', 0) ],
"_quiver_n_1_rel" : [ SenseInfo('07520112-n', 1), SenseInfo('14004572-n', 0), SenseInfo('04035836-n', 0), SenseInfo('00345926-n', 0) ],
"_starve_v_of_rel" : [ SenseInfo('01188144-v', 4), SenseInfo('01187537-v', 3), SenseInfo('01187740-v', 1), SenseInfo('01188485-v', 0), SenseInfo('01187948-v', 0) ],
"_locale_n_1_rel" : [ SenseInfo('08677628-n', 2) ],
"_repeat_v_1_rel" : [ SenseInfo('00958334-v', 33), SenseInfo('01734502-v', 11), SenseInfo('00343334-v', 8), SenseInfo('00957679-v', 7), SenseInfo('02595662-v', 3), SenseInfo('01727490-v', 0), SenseInfo('00958334-v', 33), SenseInfo('01734502-v', 11), SenseInfo('00343334-v', 8), SenseInfo('00957679-v', 7), SenseInfo('02595662-v', 3), SenseInfo('01727490-v', 0) ],
"_represent_v_1_rel" : [ SenseInfo('02699497-v', 39), SenseInfo('00836236-v', 28), SenseInfo('02541921-v', 14), SenseInfo('02541509-v', 11), SenseInfo('00988028-v', 8), SenseInfo('02723733-v', 7), SenseInfo('02620587-v', 5), SenseInfo('02581675-v', 2), SenseInfo('01686132-v', 2), SenseInfo('01719302-v', 1), SenseInfo('01711445-v', 0), SenseInfo('00987345-v', 0), SenseInfo('00825447-v', 0), SenseInfo('00772967-v', 0), SenseInfo('00380698-v', 0), SenseInfo('02699497-v', 39), SenseInfo('00836236-v', 28), SenseInfo('02541921-v', 14), SenseInfo('02541509-v', 11), SenseInfo('00988028-v', 8), SenseInfo('02723733-v', 7), SenseInfo('02620587-v', 5), SenseInfo('02581675-v', 2), SenseInfo('01686132-v', 2), SenseInfo('01719302-v', 1), SenseInfo('01711445-v', 0), SenseInfo('00987345-v', 0), SenseInfo('00825447-v', 0), SenseInfo('00772967-v', 0), SenseInfo('00380698-v', 0) ],
"_husky_n_1_rel" : [ SenseInfo('02109961-n', 0) ],
"_spit_n_1_rel" : [ SenseInfo('09442595-n', 0), SenseInfo('05416198-n', 0), SenseInfo('04280970-n', 0), SenseInfo('00118552-n', 0) ],
"_intercept_v_1_rel" : [ SenseInfo('01440378-v', 5), SenseInfo('02188848-v', 0) ],
"_no_q_rel" : [  ],
"_pigeon_n_1_rel" : [ SenseInfo('01811909-n', 3) ],
"_polarization_n_of_rel" : [ SenseInfo('11492014-n', 3), SenseInfo('14002109-n', 1), SenseInfo('11492014-n', 3), SenseInfo('14002109-n', 1) ],
"_boy_a_1_rel" : [ SenseInfo('10285313-n', 144), SenseInfo('09870926-n', 42), SenseInfo('10624074-n', 16), SenseInfo('09637837-n', 1), SenseInfo('10285313-n', 144), SenseInfo('09870926-n', 42), SenseInfo('10624074-n', 16), SenseInfo('09637837-n', 1) ],
"_jetty_n_1_rel" : [ SenseInfo('02894605-n', 0) ],
"_least_n_of_rel" : [ SenseInfo('05671526-n', 0) ],
"_awry_a_1_rel" : [ SenseInfo('02312450-a', 1), SenseInfo('01092371-a', 0) ],
"_rotundity_n_1_rel" : [ SenseInfo('05073131-n', 1), SenseInfo('07082972-n', 0) ],
"_sordid_a_1_rel" : [ SenseInfo('01984806-a', 2), SenseInfo('00621857-a', 0), SenseInfo('00421875-a', 0), SenseInfo('00031384-a', 0) ],
"_duck_n_1_rel" : [ SenseInfo('01846331-n', 4), SenseInfo('13595844-n', 0), SenseInfo('07646578-n', 0), SenseInfo('03253071-n', 0) ],
"_commute_v_1_rel" : [ SenseInfo('00553407-v', 12), SenseInfo('02061846-v', 2), SenseInfo('00380424-v', 2), SenseInfo('00161987-v', 1), SenseInfo('00161225-v', 0) ],
"_factor_v_1_rel" : [ SenseInfo('00640385-v', 2), SenseInfo('02324901-v', 0), SenseInfo('00640650-v', 0) ],
"_soften_v_up_rel" : [ SenseInfo('02190632-v', 4), SenseInfo('00390215-v', 1), SenseInfo('02703289-v', 0), SenseInfo('01576917-v', 0), SenseInfo('01058036-v', 0), SenseInfo('00255389-v', 0), SenseInfo('00254867-v', 0), SenseInfo('02190632-v', 4), SenseInfo('00390215-v', 1), SenseInfo('02703289-v', 0), SenseInfo('01576917-v', 0), SenseInfo('01058036-v', 0), SenseInfo('00255389-v', 0), SenseInfo('00254867-v', 0) ],
"_windproof_a_1_rel" : [  ],
"_earth_v_1_rel" : [ SenseInfo('02146990-v', 0), SenseInfo('01292727-v', 0) ],
"_root_v_out_rel" : [ SenseInfo('00358135-v', 2), SenseInfo('02623731-v', 0), SenseInfo('01529194-v', 0), SenseInfo('01282413-v', 0), SenseInfo('00415398-v', 0), SenseInfo('00358314-v', 0) ],
"_for_p_trgt_rel" : [  ],
"_film_v_1_rel" : [ SenseInfo('01002740-v', 2), SenseInfo('01711965-v', 0) ],
"_escalator_n_1_rel" : [ SenseInfo('06393800-n', 0), SenseInfo('03295773-n', 0) ],
"_few_n_1_rel" : [ SenseInfo('08388074-n', 0) ],
"_inn_n_1_rel" : [ SenseInfo('03541696-n', 3) ],
"_free+falling_a_1_rel" : [  ],
"_liter_n_1_rel" : [ SenseInfo('13624190-n', 5), SenseInfo('13624190-n', 5), SenseInfo('13624190-n', 5), SenseInfo('13624190-n', 5) ],
"_fiscal_a_1_rel" : [ SenseInfo('02847894-a', 3) ],
"_infertile_a_1_rel" : [ SenseInfo('01002377-a', 1) ],
"_booze_n_1_rel" : [ SenseInfo('07901587-n', 1) ],
"_cataract_n_1_rel" : [ SenseInfo('14254570-n', 0), SenseInfo('09237918-n', 0) ],
"_by+the+hour_a_1_rel" : [  ],
"_era_n_1_rel" : [ SenseInfo('15248564-n', 14), SenseInfo('15248020-n', 0), SenseInfo('07261300-n', 0) ],
"_rug_n_1_rel" : [ SenseInfo('04118021-n', 4) ],
"_reference_n_to_rel" : [ SenseInfo('06766190-n', 9), SenseInfo('06763681-n', 6), SenseInfo('07258332-n', 5), SenseInfo('06417598-n', 5), SenseInfo('06694796-n', 4), SenseInfo('05922949-n', 3), SenseInfo('01264050-n', 2), SenseInfo('07258664-n', 0), SenseInfo('06356515-n', 0), SenseInfo('05923314-n', 0) ],
"_sheath_n_1_rel" : [ SenseInfo('04187061-n', 2), SenseInfo('05238036-n', 1), SenseInfo('03062015-n', 1) ],
"_turn_v_up_rel" : [ SenseInfo('01907258-v', 187), SenseInfo('00146138-v', 21), SenseInfo('02626604-v', 12), SenseInfo('02089984-v', 8), SenseInfo('00138508-v', 7), SenseInfo('01909812-v', 5), SenseInfo('00125841-v', 5), SenseInfo('01436518-v', 2), SenseInfo('02096167-v', 1), SenseInfo('02089420-v', 1), SenseInfo('01952208-v', 1), SenseInfo('01741864-v', 1), SenseInfo('01584450-v', 1), SenseInfo('00282523-v', 1), SenseInfo('00091124-v', 1), SenseInfo('02626934-v', 0), SenseInfo('02562425-v', 0), SenseInfo('02211948-v', 0), SenseInfo('02090435-v', 0), SenseInfo('01951937-v', 0), SenseInfo('01280014-v', 0), SenseInfo('01225215-v', 0), SenseInfo('01151889-v', 0), SenseInfo('00794640-v', 0), SenseInfo('00458471-v', 0), SenseInfo('00248387-v', 0), SenseInfo('01907258-v', 187), SenseInfo('00146138-v', 21), SenseInfo('02626604-v', 12), SenseInfo('02089984-v', 8), SenseInfo('00138508-v', 7), SenseInfo('01909812-v', 5), SenseInfo('00125841-v', 5), SenseInfo('01436518-v', 2), SenseInfo('02096167-v', 1), SenseInfo('02089420-v', 1), SenseInfo('01952208-v', 1), SenseInfo('01741864-v', 1), SenseInfo('01584450-v', 1), SenseInfo('00282523-v', 1), SenseInfo('00091124-v', 1), SenseInfo('02626934-v', 0), SenseInfo('02562425-v', 0), SenseInfo('02211948-v', 0), SenseInfo('02090435-v', 0), SenseInfo('01951937-v', 0), SenseInfo('01280014-v', 0), SenseInfo('01225215-v', 0), SenseInfo('01151889-v', 0), SenseInfo('00794640-v', 0), SenseInfo('00458471-v', 0), SenseInfo('00248387-v', 0) ],
"_tributary_n_1_rel" : [ SenseInfo('09278997-n', 0) ],
"_pick_v_up_rel" : [ SenseInfo('00676450-v', 13), SenseInfo('01382083-v', 4), SenseInfo('00842772-v', 2), SenseInfo('01647131-v', 1), SenseInfo('00178102-v', 1), SenseInfo('00177714-v', 1), SenseInfo('02321648-v', 0), SenseInfo('02287209-v', 0), SenseInfo('01452546-v', 0), SenseInfo('01442578-v', 0), SenseInfo('01243474-v', 0), SenseInfo('01174294-v', 0), SenseInfo('00676450-v', 13), SenseInfo('01382083-v', 4), SenseInfo('00842772-v', 2), SenseInfo('01647131-v', 1), SenseInfo('00178102-v', 1), SenseInfo('00177714-v', 1), SenseInfo('02321648-v', 0), SenseInfo('02287209-v', 0), SenseInfo('01452546-v', 0), SenseInfo('01442578-v', 0), SenseInfo('01243474-v', 0), SenseInfo('01174294-v', 0) ],
"_tomato_n_1_rel" : [ SenseInfo('07734017-n', 2), SenseInfo('12905817-n', 0) ],
"_morsel_n_1_rel" : [ SenseInfo('13771034-n', 1), SenseInfo('07579076-n', 1) ],
"_betrayal_n_1_rel" : [ SenseInfo('00749767-n', 2), SenseInfo('04879879-n', 0) ],
"_callous_n_1_rel" : [ SenseInfo('02107162-a', 3), SenseInfo('02447569-a', 0) ],
"_respective_a_2_rel" : [ SenseInfo('00494409-a', 4) ],
"_rodeo_n_1_rel" : [ SenseInfo('00522939-n', 2), SenseInfo('04100519-n', 0) ],
"_engender_v_1_rel" : [ SenseInfo('01649024-v', 6), SenseInfo('00054628-v', 0) ],
"_grandchild_n_1_rel" : [ SenseInfo('10141590-n', 1) ],
"_foreigner_n_1_rel" : [ SenseInfo('10103485-n', 7), SenseInfo('10103921-n', 0) ],
"_bibliographer_n_1_rel" : [ SenseInfo('09852558-n', 0) ],
"_hand+in+hand+with_p_rel" : [  ],
"_testify_v_to_rel" : [ SenseInfo('01014821-v', 13), SenseInfo('01015244-v', 1), SenseInfo('01014821-v', 13), SenseInfo('01015244-v', 1), SenseInfo('01014821-v', 13), SenseInfo('01015244-v', 1) ],
"_awful_x_deg_rel" : [ SenseInfo('01126291-a', 10), SenseInfo('00054950-r', 4), SenseInfo('00193799-a', 4), SenseInfo('01587077-a', 0), SenseInfo('02012157-a', 0), SenseInfo('01677200-a', 0), SenseInfo('01282510-a', 0) ],
"_hand_v_in_rel" : [ SenseInfo('02230772-v', 25), SenseInfo('02000133-v', 0) ],
"_postulate_n_1_rel" : [ SenseInfo('06753299-n', 1) ],
"_umlaut_n_1_rel" : [ SenseInfo('06823760-n', 0) ],
"_fuse_v_1_rel" : [ SenseInfo('00394813-v', 3), SenseInfo('00397192-v', 1), SenseInfo('01137829-v', 0), SenseInfo('00396997-v', 0) ],
"_precedent_n_1_rel" : [ SenseInfo('05821486-n', 3), SenseInfo('06535035-n', 1), SenseInfo('08453722-n', 0), SenseInfo('06600282-n', 0), SenseInfo('05821486-n', 3), SenseInfo('06535035-n', 1), SenseInfo('08453722-n', 0), SenseInfo('06600282-n', 0) ],
"_lightweight_a_1_rel" : [ SenseInfo('01186733-a', 1), SenseInfo('01281559-a', 0), SenseInfo('01186733-a', 1), SenseInfo('01281559-a', 0) ],
"_redress_v_1_rel" : [ SenseInfo('02519991-v', 1) ],
"_rush_v_1_rel" : [ SenseInfo('02058994-v', 20), SenseInfo('01119950-v', 6), SenseInfo('00459296-v', 2), SenseInfo('00459498-v', 1), SenseInfo('02059770-v', 0), SenseInfo('02059462-v', 0), SenseInfo('01644522-v', 0), SenseInfo('02058994-v', 20), SenseInfo('01119950-v', 6), SenseInfo('00459296-v', 2), SenseInfo('00459498-v', 1), SenseInfo('02059770-v', 0), SenseInfo('02059462-v', 0), SenseInfo('01644522-v', 0), SenseInfo('02058994-v', 20), SenseInfo('01119950-v', 6), SenseInfo('00459296-v', 2), SenseInfo('00459498-v', 1), SenseInfo('02059770-v', 0), SenseInfo('02059462-v', 0), SenseInfo('01644522-v', 0), SenseInfo('02058994-v', 20), SenseInfo('01119950-v', 6), SenseInfo('00459296-v', 2), SenseInfo('00459498-v', 1), SenseInfo('02059770-v', 0), SenseInfo('02059462-v', 0), SenseInfo('01644522-v', 0) ],
"_but_p_except_rel" : [ SenseInfo('00004722-r', 2), SenseInfo('00004722-r', 2) ],
"_corrective_n_1_rel" : [ SenseInfo('03111899-n', 0) ],
"_immediacy_n_1_rel" : [ SenseInfo('04918767-n', 6), SenseInfo('05708322-n', 1), SenseInfo('05059525-n', 1) ],
"_bring_v_about_rel" : [ SenseInfo('02077656-v', 122), SenseInfo('01438902-v', 55), SenseInfo('01629589-v', 31), SenseInfo('01433294-v', 19), SenseInfo('00135857-v', 9), SenseInfo('01434140-v', 4), SenseInfo('01618547-v', 3), SenseInfo('02324478-v', 2), SenseInfo('02247390-v', 1), SenseInfo('01808218-v', 0), SenseInfo('00767334-v', 0) ],
"_really_x_deg_rel" : [ SenseInfo('00037226-r', 61), SenseInfo('00149510-r', 42), SenseInfo('00038013-r', 0), SenseInfo('00031899-r', 0) ],
"_once_x_deg_rel" : [ SenseInfo('00118869-r', 98), SenseInfo('00181342-r', 28), SenseInfo('00118965-r', 21) ],
"_palette_n_1_rel" : [ SenseInfo('05128370-n', 1), SenseInfo('03878674-n', 1), SenseInfo('03879705-n', 0) ],
"_gnarly_a_1_rel" : [ SenseInfo('02313235-a', 0), SenseInfo('02313235-a', 0), SenseInfo('02313235-a', 0) ],
"_without_p_rel" : [  ],
"_sailing_n_1_rel" : [ SenseInfo('00314469-n', 2), SenseInfo('00313806-n', 1), SenseInfo('00057657-n', 1), SenseInfo('00303495-n', 0) ],
"_dismiss_v_as_rel" : [ SenseInfo('00800930-v', 14), SenseInfo('00801626-v', 4), SenseInfo('02465939-v', 1), SenseInfo('02402825-v', 0), SenseInfo('00900728-v', 0), SenseInfo('00338559-v', 0), SenseInfo('00800930-v', 14), SenseInfo('00801626-v', 4), SenseInfo('02465939-v', 1), SenseInfo('02402825-v', 0), SenseInfo('00900728-v', 0), SenseInfo('00338559-v', 0) ],
"_godless_a_1_rel" : [ SenseInfo('01782717-a', 1) ],
"_stink_v_of_rel" : [ SenseInfo('02674173-v', 2), SenseInfo('02124106-v', 0) ],
"_proud_a_of_rel" : [ SenseInfo('01889256-a', 14), SenseInfo('01285136-a', 2), SenseInfo('01889256-a', 14), SenseInfo('01285136-a', 2), SenseInfo('01889256-a', 14), SenseInfo('01285136-a', 2), SenseInfo('01889256-a', 14), SenseInfo('01285136-a', 2) ],
"_drawl_v_1_rel" : [ SenseInfo('00980176-v', 1), SenseInfo('00980176-v', 1) ],
"_saleslady_n_1_rel" : [ SenseInfo('10548419-n', 3) ],
"_snuff_v_out_rel" : [ SenseInfo('02126152-v', 0), SenseInfo('00109263-v', 0) ],
"_pupil_n_1_rel" : [ SenseInfo('10665698-n', 8), SenseInfo('05320183-n', 1), SenseInfo('10559288-n', 0) ],
"_needlework_n_1_rel" : [ SenseInfo('03816849-n', 0), SenseInfo('00910070-n', 0) ],
"_confirmed_a_1_rel" : [ SenseInfo('00347571-a', 2), SenseInfo('01634495-a', 1) ],
"_quick_a_1_rel" : [ SenseInfo('00979366-a', 20), SenseInfo('01270486-a', 6), SenseInfo('00032733-a', 2), SenseInfo('01335903-a', 1), SenseInfo('00978754-a', 1), SenseInfo('00919018-a', 1), SenseInfo('00979366-a', 20), SenseInfo('01270486-a', 6), SenseInfo('00032733-a', 2), SenseInfo('01335903-a', 1), SenseInfo('00978754-a', 1), SenseInfo('00919018-a', 1), SenseInfo('00979366-a', 20), SenseInfo('01270486-a', 6), SenseInfo('00032733-a', 2), SenseInfo('01335903-a', 1), SenseInfo('00978754-a', 1), SenseInfo('00919018-a', 1), SenseInfo('00979366-a', 20), SenseInfo('01270486-a', 6), SenseInfo('00032733-a', 2), SenseInfo('01335903-a', 1), SenseInfo('00978754-a', 1), SenseInfo('00919018-a', 1), SenseInfo('00979366-a', 20), SenseInfo('01270486-a', 6), SenseInfo('00032733-a', 2), SenseInfo('01335903-a', 1), SenseInfo('00978754-a', 1), SenseInfo('00919018-a', 1), SenseInfo('00979366-a', 20), SenseInfo('01270486-a', 6), SenseInfo('00032733-a', 2), SenseInfo('01335903-a', 1), SenseInfo('00978754-a', 1), SenseInfo('00919018-a', 1) ],
"_avenue_n_1_rel" : [ SenseInfo('00941604-n', 1), SenseInfo('02763472-n', 0), SenseInfo('00941604-n', 1), SenseInfo('02763472-n', 0), SenseInfo('00941604-n', 1), SenseInfo('02763472-n', 0) ],
"_repose_v_1_rel" : [ SenseInfo('01160645-v', 1), SenseInfo('02664664-v', 0), SenseInfo('01548072-v', 0), SenseInfo('01547390-v', 0), SenseInfo('01544692-v', 0), SenseInfo('01498166-v', 0), SenseInfo('01160645-v', 1), SenseInfo('02664664-v', 0), SenseInfo('01548072-v', 0), SenseInfo('01547390-v', 0), SenseInfo('01544692-v', 0), SenseInfo('01498166-v', 0) ],
"_lock_v_out_rel" : [ SenseInfo('01348174-v', 8), SenseInfo('01510827-v', 7), SenseInfo('00219775-v', 4), SenseInfo('01606736-v', 2), SenseInfo('01606018-v', 2), SenseInfo('01810320-v', 1), SenseInfo('01347678-v', 1), SenseInfo('02050865-v', 0), SenseInfo('01655347-v', 0) ],
"_averse_a_to_rel" : [ SenseInfo('01293542-a', 0) ],
"_obtain_v_hold_rel" : [ SenseInfo('02238085-v', 116), SenseInfo('00522751-v', 17), SenseInfo('02648502-v', 1) ],
"_copyright_v_1_rel" : [ SenseInfo('02239533-v', 0) ],
"_ha_a_1_rel" : [ SenseInfo('13888783-n', 0), SenseInfo('13888783-n', 0) ],
"_permission_n_1_rel" : [ SenseInfo('06689297-n', 5), SenseInfo('01139194-n', 1), SenseInfo('06689297-n', 5), SenseInfo('01139194-n', 1), SenseInfo('06689297-n', 5), SenseInfo('01139194-n', 1) ],
"_luck_v_out_rel" : [  ],
"_gain_n_1_rel" : [ SenseInfo('13754293-n', 6), SenseInfo('05157574-n', 2), SenseInfo('05109324-n', 2), SenseInfo('13254805-n', 1), SenseInfo('13754293-n', 6), SenseInfo('05157574-n', 2), SenseInfo('05109324-n', 2), SenseInfo('13254805-n', 1), SenseInfo('13754293-n', 6), SenseInfo('05157574-n', 2), SenseInfo('05109324-n', 2), SenseInfo('13254805-n', 1) ],
"_trip_v_over_rel" : [ SenseInfo('01900408-v', 2), SenseInfo('01900760-v', 0), SenseInfo('01843055-v', 0), SenseInfo('01643657-v', 0), SenseInfo('01200934-v', 0) ],
"_hallelujah_a_1_rel" : [ SenseInfo('06693655-n', 1) ],
"_cashiers+check_n_1_rel" : [  ],
"_bashing_n_1_rel" : [  ],
"_hydro_a_1_rel" : [  ],
"_relevance_n_1_rel" : [ SenseInfo('13794417-n', 7) ],
"_fascinating_a_1_rel" : [ SenseInfo('01344171-a', 7), SenseInfo('00166753-a', 0) ],
"_complexion_n_1_rel" : [ SenseInfo('04976952-n', 1), SenseInfo('07964324-n', 0), SenseInfo('06211206-n', 0), SenseInfo('04675193-n', 0), SenseInfo('04624289-n', 0) ],
"_leak_v_1_rel" : [ SenseInfo('00937023-v', 1), SenseInfo('00936169-v', 0), SenseInfo('00529759-v', 0), SenseInfo('00258109-v', 0) ],
"_condensate_n_1_rel" : [ SenseInfo('15008765-n', 0), SenseInfo('11446242-n', 0) ],
"_last+resort_n_i_rel" : [ SenseInfo('00178972-n', 1), SenseInfo('00178972-n', 1) ],
"_next_n_1_rel" : [ SenseInfo('00127948-a', 90), SenseInfo('00447472-a', 24), SenseInfo('01294975-a', 7) ],
"_mortar_n_1_rel" : [ SenseInfo('03786715-n', 3), SenseInfo('14955889-n', 2), SenseInfo('03786901-n', 0) ],
"_categorize_v_as_rel" : [ SenseInfo('00657260-v', 1), SenseInfo('00657260-v', 1) ],
"_if+and+only+if_x_1_rel" : [  ],
"_contrast_n_1_rel" : [ SenseInfo('13855627-n', 23), SenseInfo('00651813-n', 10), SenseInfo('05748786-n', 3), SenseInfo('05711084-n', 2), SenseInfo('05126362-n', 0) ],
"_up+to+and+including_p_rel" : [  ],
"_hurrah_a_1_rel" : [ SenseInfo('06692973-n', 0) ],
"_famine_n_1_rel" : [ SenseInfo('14449865-n', 0), SenseInfo('07315790-n', 0) ],
"_paddler_n_1_rel" : [ SenseInfo('09891470-n', 0) ],
"_shin_n_1_rel" : [ SenseInfo('05562902-n', 2), SenseInfo('07657440-n', 0), SenseInfo('06838975-n', 0), SenseInfo('05594367-n', 0) ],
"_magpie_n_1_rel" : [ SenseInfo('01582220-n', 1), SenseInfo('10281276-n', 0), SenseInfo('09911570-n', 0) ],
"_utter_a_1_rel" : [ SenseInfo('01520091-a', 3), SenseInfo('00522349-a', 0), SenseInfo('01520091-a', 3), SenseInfo('00522349-a', 0), SenseInfo('01520091-a', 3), SenseInfo('00522349-a', 0), SenseInfo('01520091-a', 3), SenseInfo('00522349-a', 0) ],
"_drive_v_off_rel" : [ SenseInfo('01930874-v', 56), SenseInfo('01930117-v', 24), SenseInfo('02056971-v', 13), SenseInfo('01516534-v', 13), SenseInfo('02505358-v', 6), SenseInfo('01506157-v', 5), SenseInfo('01646300-v', 4), SenseInfo('01512259-v', 2), SenseInfo('01509584-v', 2), SenseInfo('02406916-v', 1), SenseInfo('01026975-v', 1), SenseInfo('02742232-v', 0), SenseInfo('02408281-v', 0), SenseInfo('02057656-v', 0), SenseInfo('01939553-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01407904-v', 0), SenseInfo('01407722-v', 0), SenseInfo('01310964-v', 0), SenseInfo('01181741-v', 0), SenseInfo('01142636-v', 0), SenseInfo('01142490-v', 0), SenseInfo('01930874-v', 56), SenseInfo('01930117-v', 24), SenseInfo('02056971-v', 13), SenseInfo('01516534-v', 13), SenseInfo('02505358-v', 6), SenseInfo('01506157-v', 5), SenseInfo('01646300-v', 4), SenseInfo('01512259-v', 2), SenseInfo('01509584-v', 2), SenseInfo('02406916-v', 1), SenseInfo('01026975-v', 1), SenseInfo('02742232-v', 0), SenseInfo('02408281-v', 0), SenseInfo('02057656-v', 0), SenseInfo('01939553-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01407904-v', 0), SenseInfo('01407722-v', 0), SenseInfo('01310964-v', 0), SenseInfo('01181741-v', 0), SenseInfo('01142636-v', 0), SenseInfo('01142490-v', 0) ],
"_aerobatic_a_1_rel" : [  ],
"_diphone_n_1_rel" : [  ],
"_dutch_n_1_rel" : [ SenseInfo('09699763-n', 0), SenseInfo('06952572-n', 0), SenseInfo('09699763-n', 0), SenseInfo('06952572-n', 0), SenseInfo('09699763-n', 0), SenseInfo('06952572-n', 0) ],
"_logo_n_1_rel" : [ SenseInfo('07272084-n', 0) ],
"_hunger_v_for_rel" : [ SenseInfo('02121958-v', 0), SenseInfo('01188485-v', 0), SenseInfo('01188144-v', 0) ],
"_unique_a_1_rel" : [ SenseInfo('00505853-a', 10), SenseInfo('01105042-a', 2), SenseInfo('02215087-a', 0), SenseInfo('00491511-a', 0) ],
"_church_n_1_rel" : [ SenseInfo('08082602-n', 60), SenseInfo('03028079-n', 59), SenseInfo('01032368-n', 10), SenseInfo('08082899-n', 0), SenseInfo('08082602-n', 60), SenseInfo('03028079-n', 59), SenseInfo('01032368-n', 10), SenseInfo('08082899-n', 0) ],
"_ought_v_qmodal_rel" : [ SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0) ],
"_hedge_v_1_rel" : [ SenseInfo('00809654-v', 1), SenseInfo('01615190-v', 0), SenseInfo('01615020-v', 0), SenseInfo('00428067-v', 0) ],
"_impotence_n_1_rel" : [ SenseInfo('05204637-n', 1), SenseInfo('14044930-n', 0) ],
"_programmatic_a_1_rel" : [  ],
"_string_v_along_rel" : [ SenseInfo('01359432-v', 2), SenseInfo('00190389-v', 1), SenseInfo('01993805-v', 0), SenseInfo('01360571-v', 0), SenseInfo('01360423-v', 0), SenseInfo('01360316-v', 0), SenseInfo('01359145-v', 0), SenseInfo('01359432-v', 2), SenseInfo('00190389-v', 1), SenseInfo('01993805-v', 0), SenseInfo('01360571-v', 0), SenseInfo('01360423-v', 0), SenseInfo('01360316-v', 0), SenseInfo('01359145-v', 0) ],
"_come_v_across_rel" : [ SenseInfo('01849221-v', 276), SenseInfo('02005948-v', 235), SenseInfo('00341917-v', 147), SenseInfo('00542120-v', 41), SenseInfo('02625339-v', 40), SenseInfo('00342812-v', 11), SenseInfo('02743921-v', 9), SenseInfo('02743214-v', 7), SenseInfo('02686805-v', 6), SenseInfo('02743565-v', 3), SenseInfo('01839690-v', 3), SenseInfo('02729963-v', 2), SenseInfo('00344886-v', 2), SenseInfo('02645007-v', 1), SenseInfo('02627363-v', 1), SenseInfo('02006709-v', 1), SenseInfo('00723349-v', 1), SenseInfo('02737187-v', 0), SenseInfo('02617567-v', 0), SenseInfo('02197360-v', 0), SenseInfo('00659984-v', 0), SenseInfo('01849221-v', 276), SenseInfo('02005948-v', 235), SenseInfo('00341917-v', 147), SenseInfo('00542120-v', 41), SenseInfo('02625339-v', 40), SenseInfo('00342812-v', 11), SenseInfo('02743921-v', 9), SenseInfo('02743214-v', 7), SenseInfo('02686805-v', 6), SenseInfo('02743565-v', 3), SenseInfo('01839690-v', 3), SenseInfo('02729963-v', 2), SenseInfo('00344886-v', 2), SenseInfo('02645007-v', 1), SenseInfo('02627363-v', 1), SenseInfo('02006709-v', 1), SenseInfo('00723349-v', 1), SenseInfo('02737187-v', 0), SenseInfo('02617567-v', 0), SenseInfo('02197360-v', 0), SenseInfo('00659984-v', 0), SenseInfo('01849221-v', 276), SenseInfo('02005948-v', 235), SenseInfo('00341917-v', 147), SenseInfo('00542120-v', 41), SenseInfo('02625339-v', 40), SenseInfo('00342812-v', 11), SenseInfo('02743921-v', 9), SenseInfo('02743214-v', 7), SenseInfo('02686805-v', 6), SenseInfo('02743565-v', 3), SenseInfo('01839690-v', 3), SenseInfo('02729963-v', 2), SenseInfo('00344886-v', 2), SenseInfo('02645007-v', 1), SenseInfo('02627363-v', 1), SenseInfo('02006709-v', 1), SenseInfo('00723349-v', 1), SenseInfo('02737187-v', 0), SenseInfo('02617567-v', 0), SenseInfo('02197360-v', 0), SenseInfo('00659984-v', 0) ],
"_derange_v_1_rel" : [ SenseInfo('01764586-v', 0), SenseInfo('00276601-v', 0) ],
"_dab_n_1_rel" : [ SenseInfo('00125436-n', 1), SenseInfo('13761171-n', 0) ],
"_educate_v_1_rel" : [ SenseInfo('02387486-v', 7), SenseInfo('00603298-v', 3), SenseInfo('02388403-v', 1), SenseInfo('02387486-v', 7), SenseInfo('00603298-v', 3), SenseInfo('02388403-v', 1) ],
"_tuition_n_1_rel" : [ SenseInfo('13323988-n', 2), SenseInfo('00889294-n', 0) ],
"_cleft_n_1_rel" : [ SenseInfo('13908201-n', 2), SenseInfo('09258715-n', 0) ],
"_ileocolic_a_1_rel" : [  ],
"_peptide_n_1_rel" : [ SenseInfo('14743046-n', 0) ],
"_floss_n_1_rel" : [ SenseInfo('03367545-n', 0), SenseInfo('03175843-n', 0) ],
"_governor_n_1_rel" : [ SenseInfo('10140314-n', 9), SenseInfo('03450018-n', 0), SenseInfo('10140314-n', 9), SenseInfo('03450018-n', 0), SenseInfo('10140314-n', 9), SenseInfo('03450018-n', 0) ],
"_exalt_v_1_rel" : [ SenseInfo('00860620-v', 2), SenseInfo('01812324-v', 1), SenseInfo('01812720-v', 0), SenseInfo('00544936-v', 0) ],
"_pay_v_1_rel" : [ SenseInfo('02251743-v', 138), SenseInfo('01060494-v', 26), SenseInfo('02252931-v', 12), SenseInfo('02291708-v', 6), SenseInfo('02253456-v', 6), SenseInfo('00732224-v', 4), SenseInfo('02732292-v', 3), SenseInfo('02488056-v', 1), SenseInfo('00737884-v', 1), SenseInfo('02344243-v', 0), SenseInfo('02253154-v', 0) ],
"_fella_n_1_rel" : [ SenseInfo('09908025-n', 3) ],
"_expressive_a_1_rel" : [ SenseInfo('00497148-a', 3) ],
"_syndicate+manager_n_1_rel" : [  ],
"_organizer_n_of_rel" : [ SenseInfo('10383237-n', 1), SenseInfo('10383505-n', 0), SenseInfo('03918737-n', 0), SenseInfo('10383237-n', 1), SenseInfo('10383505-n', 0), SenseInfo('03918737-n', 0) ],
"_roadbed_n_1_rel" : [ SenseInfo('04096733-n', 0) ],
"_tight-knit_a_1_rel" : [ SenseInfo('01328877-a', 0), SenseInfo('01328877-a', 0), SenseInfo('01328877-a', 0) ],
"_prop_n_abb_rel" : [ SenseInfo('04011242-n', 1), SenseInfo('04012260-n', 0), SenseInfo('02692086-n', 0) ],
"_first+class_a_1_rel" : [ SenseInfo('02343110-a', 1), SenseInfo('02343110-a', 1), SenseInfo('02343110-a', 1), SenseInfo('02343110-a', 1) ],
"_scratch_v_1_rel" : [ SenseInfo('01250908-v', 9), SenseInfo('01309143-v', 8), SenseInfo('02119874-v', 1), SenseInfo('02477755-v', 0), SenseInfo('01549420-v', 0), SenseInfo('01384752-v', 0), SenseInfo('01321895-v', 0) ],
"_callyx_n_1_rel" : [  ],
"_year+on+year_a_1_rel" : [  ],
"_gospel_n_1_rel" : [ SenseInfo('06455138-n', 7), SenseInfo('06724323-n', 1), SenseInfo('07061334-n', 0), SenseInfo('06789411-n', 0), SenseInfo('05962252-n', 0) ],
"_verbena_n_1_rel" : [ SenseInfo('12914923-n', 3) ],
"_inconsiderate_a_1_rel" : [ SenseInfo('00639356-a', 0), SenseInfo('02420757-a', 0), SenseInfo('00639356-a', 0), SenseInfo('02420757-a', 0) ],
"_detect_v_1_rel" : [ SenseInfo('02154508-v', 21), SenseInfo('02154508-v', 21) ],
"_brutal_a_1_rel" : [ SenseInfo('01263013-a', 1), SenseInfo('01510798-a', 0), SenseInfo('01263445-a', 0), SenseInfo('00765173-a', 0), SenseInfo('01263013-a', 1), SenseInfo('01510798-a', 0), SenseInfo('01263445-a', 0), SenseInfo('00765173-a', 0) ],
"_acreage_n_1_rel" : [ SenseInfo('05128870-n', 4) ],
"_mossy_a_1_rel" : [ SenseInfo('01696632-a', 0), SenseInfo('00974697-a', 0), SenseInfo('01696632-a', 0), SenseInfo('00974697-a', 0), SenseInfo('01696632-a', 0), SenseInfo('00974697-a', 0) ],
"_clerk_v_1_rel" : [ SenseInfo('02411802-v', 0) ],
"_hinge_n_1_rel" : [ SenseInfo('03521076-n', 3), SenseInfo('13943598-n', 0) ],
"_check_v_into_rel" : [ SenseInfo('00661824-v', 27), SenseInfo('02533282-v', 7), SenseInfo('00662589-v', 6), SenseInfo('02510337-v', 5), SenseInfo('01861403-v', 1), SenseInfo('00662182-v', 1), SenseInfo('00440286-v', 1), SenseInfo('02658283-v', 0), SenseInfo('02657219-v', 0), SenseInfo('02557638-v', 0), SenseInfo('02553697-v', 0), SenseInfo('02347905-v', 0), SenseInfo('02347447-v', 0), SenseInfo('01861767-v', 0), SenseInfo('01861622-v', 0), SenseInfo('01692978-v', 0), SenseInfo('01139756-v', 0), SenseInfo('01131473-v', 0), SenseInfo('01114764-v', 0), SenseInfo('01064999-v', 0), SenseInfo('00920336-v', 0), SenseInfo('00663353-v', 0), SenseInfo('00354634-v', 0), SenseInfo('00336539-v', 0), SenseInfo('00336260-v', 0), SenseInfo('00661824-v', 27), SenseInfo('02533282-v', 7), SenseInfo('00662589-v', 6), SenseInfo('02510337-v', 5), SenseInfo('01861403-v', 1), SenseInfo('00662182-v', 1), SenseInfo('00440286-v', 1), SenseInfo('02658283-v', 0), SenseInfo('02657219-v', 0), SenseInfo('02557638-v', 0), SenseInfo('02553697-v', 0), SenseInfo('02347905-v', 0), SenseInfo('02347447-v', 0), SenseInfo('01861767-v', 0), SenseInfo('01861622-v', 0), SenseInfo('01692978-v', 0), SenseInfo('01139756-v', 0), SenseInfo('01131473-v', 0), SenseInfo('01114764-v', 0), SenseInfo('01064999-v', 0), SenseInfo('00920336-v', 0), SenseInfo('00663353-v', 0), SenseInfo('00354634-v', 0), SenseInfo('00336539-v', 0), SenseInfo('00336260-v', 0) ],
"_motorized_a_1_rel" : [ SenseInfo('01559484-a', 0), SenseInfo('01523450-a', 0), SenseInfo('01559484-a', 0), SenseInfo('01523450-a', 0) ],
"_mercantile_a_1_rel" : [ SenseInfo('02995482-a', 0), SenseInfo('00483816-a', 0), SenseInfo('00483650-a', 0) ],
"_bow_v_to_rel" : [ SenseInfo('00898691-v', 11), SenseInfo('00878348-v', 3), SenseInfo('02040273-v', 1), SenseInfo('02062632-v', 0), SenseInfo('01729295-v', 0) ],
"_flap_n_1_rel" : [ SenseInfo('03357376-n', 3), SenseInfo('14403772-n', 0), SenseInfo('07439284-n', 0), SenseInfo('05389762-n', 0), SenseInfo('03357716-n', 0) ],
"_caribbean_a_1_rel" : [ SenseInfo('09235894-n', 1), SenseInfo('08709038-n', 0) ],
"_burst_n_1_rel" : [ SenseInfo('00377364-n', 5), SenseInfo('00988320-n', 2), SenseInfo('00555325-n', 1), SenseInfo('07434942-n', 0) ],
"_chastity_n_1_rel" : [ SenseInfo('01069125-n', 1), SenseInfo('04849759-n', 0) ],
"_live_v_down_rel" : [ SenseInfo('02649830-v', 129), SenseInfo('02614387-v', 51), SenseInfo('02618149-v', 29), SenseInfo('02616713-v', 16), SenseInfo('02614181-v', 14), SenseInfo('00596644-v', 1), SenseInfo('02614970-v', 0) ],
"_reckless_a_1_rel" : [ SenseInfo('00250739-a', 2), SenseInfo('00312757-a', 0) ],
"_starlit_a_1_rel" : [ SenseInfo('02300002-a', 0) ],
"_bleach_v_1_rel" : [ SenseInfo('00279822-v', 1), SenseInfo('00279465-v', 0) ],
"_mesh_v_cause_rel" : [ SenseInfo('01510827-v', 1), SenseInfo('00405079-v', 1), SenseInfo('02458017-v', 0), SenseInfo('01463340-v', 0) ],
"_ventral_a_1_rel" : [ SenseInfo('00132385-a', 0), SenseInfo('00002527-a', 0) ],
"_fascinate_v_1_rel" : [ SenseInfo('02678839-v', 3), SenseInfo('01821132-v', 3), SenseInfo('01806505-v', 0), SenseInfo('02678839-v', 3), SenseInfo('01821132-v', 3), SenseInfo('01806505-v', 0), SenseInfo('02678839-v', 3), SenseInfo('01821132-v', 3), SenseInfo('01806505-v', 0), SenseInfo('02678839-v', 3), SenseInfo('01821132-v', 3), SenseInfo('01806505-v', 0), SenseInfo('02678839-v', 3), SenseInfo('01821132-v', 3), SenseInfo('01806505-v', 0), SenseInfo('02678839-v', 3), SenseInfo('01821132-v', 3), SenseInfo('01806505-v', 0), SenseInfo('02678839-v', 3), SenseInfo('01821132-v', 3), SenseInfo('01806505-v', 0) ],
"_reap_v_1_rel" : [ SenseInfo('01320009-v', 3), SenseInfo('02293148-v', 1) ],
"_skillful_a_1_rel" : [ SenseInfo('02226162-a', 3), SenseInfo('01838916-a', 0), SenseInfo('02226162-a', 3), SenseInfo('01838916-a', 0) ],
"_third+base_n_1_rel" : [ SenseInfo('04425804-n', 5), SenseInfo('00724168-n', 0) ],
"_slice_v_out_rel" : [ SenseInfo('01559055-v', 2), SenseInfo('01408958-v', 1), SenseInfo('01254477-v', 1), SenseInfo('01124389-v', 1) ],
"_enlarge_v_on_rel" : [ SenseInfo('00154778-v', 7), SenseInfo('00240293-v', 2), SenseInfo('00157844-v', 2), SenseInfo('00955601-v', 1) ],
"_bridal_a_1_rel" : [ SenseInfo('02843495-a', 0), SenseInfo('02843382-a', 0) ],
"_pardon_v_1_rel" : [ SenseInfo('00905852-v', 2), SenseInfo('00905399-v', 2) ],
"_toxicity_n_1_rel" : [ SenseInfo('13583478-n', 0), SenseInfo('04790942-n', 0) ],
"_crawler_n_1_rel" : [ SenseInfo('10684827-n', 0), SenseInfo('09976119-n', 0), SenseInfo('01935395-n', 0) ],
"_homeland_n_1_rel" : [ SenseInfo('08510169-n', 2) ],
"_noise_n_1_rel" : [ SenseInfo('07387509-n', 43), SenseInfo('05720248-n', 1), SenseInfo('07430211-n', 0), SenseInfo('07122730-n', 0), SenseInfo('04823031-n', 0), SenseInfo('04771332-n', 0) ],
"_overhear_v_1_rel" : [ SenseInfo('02189168-v', 8), SenseInfo('02189168-v', 8), SenseInfo('02189168-v', 8) ],
"_trill_v_1_rel" : [ SenseInfo('01055266-v', 0), SenseInfo('01050896-v', 0), SenseInfo('01055266-v', 0), SenseInfo('01050896-v', 0) ],
"_depend_v_1_rel" : [ SenseInfo('02664234-v', 10), SenseInfo('00712708-v', 0) ],
"_whimper_n_1_rel" : [ SenseInfo('07211752-n', 0) ],
"_study_n_1_rel" : [ SenseInfo('00644503-n', 90), SenseInfo('05755883-n', 17), SenseInfo('07218470-n', 6), SenseInfo('05705355-n', 6), SenseInfo('04345028-n', 6), SenseInfo('05996646-n', 3), SenseInfo('04227144-n', 2), SenseInfo('05784242-n', 1), SenseInfo('10666464-n', 0), SenseInfo('07048627-n', 0), SenseInfo('00644503-n', 90), SenseInfo('05755883-n', 17), SenseInfo('07218470-n', 6), SenseInfo('05705355-n', 6), SenseInfo('04345028-n', 6), SenseInfo('05996646-n', 3), SenseInfo('04227144-n', 2), SenseInfo('05784242-n', 1), SenseInfo('10666464-n', 0), SenseInfo('07048627-n', 0) ],
"_scammer_n_1_rel" : [ SenseInfo('09955015-n', 0) ],
"_swig_n_1_rel" : [ SenseInfo('00840189-n', 1) ],
"_prosperous_a_1_rel" : [ SenseInfo('02022556-a', 2), SenseInfo('02331857-a', 1), SenseInfo('01149195-a', 0), SenseInfo('00177547-a', 0) ],
"_graphic_n_1_rel" : [ SenseInfo('03453696-n', 0) ],
"_octangular_a_1_rel" : [ SenseInfo('02834862-a', 0) ],
"_baht_n_1_rel" : [ SenseInfo('13663820-n', 0), SenseInfo('13663820-n', 0), SenseInfo('13663820-n', 0) ],
"_windsurf_v_1_rel" : [ SenseInfo('01948450-v', 0) ],
"_archive_v_1_rel" : [ SenseInfo('01384638-v', 0) ],
"_acronym_n_1_rel" : [ SenseInfo('07091902-n', 0) ],
"_reliable_a_1_rel" : [ SenseInfo('00724081-a', 9), SenseInfo('02465519-a', 1), SenseInfo('02465115-a', 1), SenseInfo('00724081-a', 9), SenseInfo('02465519-a', 1), SenseInfo('02465115-a', 1) ],
"_sipper_n_1_rel" : [ SenseInfo('10601362-n', 1) ],
"_trifle_v_with_rel" : [ SenseInfo('02708123-v', 0), SenseInfo('02592895-v', 0), SenseInfo('00711932-v', 0) ],
"_offline_a_1_rel" : [  ],
"_right-to-life_a_1_rel" : [  ],
"_suitable_a_for-as_rel" : [ SenseInfo('01020885-a', 3), SenseInfo('00852197-a', 0), SenseInfo('01020885-a', 3), SenseInfo('00852197-a', 0), SenseInfo('01020885-a', 3), SenseInfo('00852197-a', 0) ],
"_merit_v_1_rel" : [ SenseInfo('02646378-v', 6) ],
"_constitution_n_1_rel" : [ SenseInfo('06533648-n', 2), SenseInfo('00237078-n', 1), SenseInfo('06534132-n', 0), SenseInfo('04933544-n', 0), SenseInfo('03093018-n', 0) ],
"_tighten_v_up_rel" : [ SenseInfo('00420132-v', 8), SenseInfo('00419950-v', 1), SenseInfo('00418765-v', 1), SenseInfo('00233203-v', 0), SenseInfo('00420132-v', 8), SenseInfo('00419950-v', 1), SenseInfo('00418765-v', 1), SenseInfo('00233203-v', 0) ],
"_become_v_id_rel" : [ SenseInfo('00149583-v', 327), SenseInfo('02626604-v', 220), SenseInfo('02623529-v', 5), SenseInfo('02724258-v', 0), SenseInfo('00149583-v', 327), SenseInfo('02626604-v', 220), SenseInfo('02623529-v', 5), SenseInfo('02724258-v', 0), SenseInfo('00149583-v', 327), SenseInfo('02626604-v', 220), SenseInfo('02623529-v', 5), SenseInfo('02724258-v', 0), SenseInfo('00149583-v', 327), SenseInfo('02626604-v', 220), SenseInfo('02623529-v', 5), SenseInfo('02724258-v', 0) ],
"_doubtless_a_1_rel" : [  ],
"_telesystem_n_1_rel" : [  ],
"_tender_v_1_rel" : [ SenseInfo('02296615-v', 1), SenseInfo('02298632-v', 0), SenseInfo('02296495-v', 0), SenseInfo('00514871-v', 0) ],
"_consolation_n_1_rel" : [ SenseInfo('07492655-n', 3), SenseInfo('01211667-n', 0) ],
"_harm_n_to_rel" : [ SenseInfo('14285662-n', 5), SenseInfo('07420770-n', 2), SenseInfo('00403092-n', 1) ],
"_grope_v_1_rel" : [ SenseInfo('01314738-v', 6), SenseInfo('02530936-v', 1), SenseInfo('01211263-v', 0) ],
"_trial_n_1_rel" : [ SenseInfo('00791078-n', 44), SenseInfo('05799212-n', 3), SenseInfo('00794367-n', 2), SenseInfo('01195867-n', 1), SenseInfo('07477231-n', 0), SenseInfo('07372959-n', 0), SenseInfo('00791078-n', 44), SenseInfo('05799212-n', 3), SenseInfo('00794367-n', 2), SenseInfo('01195867-n', 1), SenseInfo('07477231-n', 0), SenseInfo('07372959-n', 0) ],
"_bridle_v_at_rel" : [ SenseInfo('01786292-v', 0), SenseInfo('01300655-v', 0), SenseInfo('01056918-v', 0), SenseInfo('01786292-v', 0), SenseInfo('01300655-v', 0), SenseInfo('01056918-v', 0) ],
"_teacher_n_of_rel" : [ SenseInfo('10694258-n', 41), SenseInfo('05854812-n', 1) ],
"_uh_x_rel" : [  ],
"_bass_n_1_rel" : [ SenseInfo('04986796-n', 2), SenseInfo('07032292-n', 1), SenseInfo('09842528-n', 0), SenseInfo('07777945-n', 0), SenseInfo('07777512-n', 0), SenseInfo('06872354-n', 0), SenseInfo('02803349-n', 0), SenseInfo('02565573-n', 0) ],
"_retriever_n_1_rel" : [ SenseInfo('02099029-n', 0) ],
"_out-and-out_a_1_rel" : [ SenseInfo('00520892-a', 1), SenseInfo('00520892-a', 1) ],
"_scar_v_up_rel" : [ SenseInfo('01551195-v', 0) ],
"_catalunian_a_1_rel" : [  ],
"_cup_v_1_rel" : [ SenseInfo('00477828-v', 2), SenseInfo('00189062-v', 0), SenseInfo('00087290-v', 0) ],
"_waymark_v_1_rel" : [  ],
"_jab_n_1_rel" : [ SenseInfo('00334935-n', 1), SenseInfo('00135952-n', 1), SenseInfo('00135311-n', 0) ],
"_divorce_v_from_rel" : [ SenseInfo('02430580-v', 4), SenseInfo('02490634-v', 2), SenseInfo('02430580-v', 4), SenseInfo('02490634-v', 2) ],
"_sequence_v_1_rel" : [ SenseInfo('00660571-v', 1), SenseInfo('00920125-v', 0) ],
"_oneness_n_1_rel" : [ SenseInfo('04743370-n', 2) ],
"_right_a_1_rel" : [ SenseInfo('02031986-a', 20), SenseInfo('00631391-a', 20), SenseInfo('01879261-a', 16), SenseInfo('02034828-a', 10), SenseInfo('00633410-a', 2), SenseInfo('00135455-a', 1), SenseInfo('02030080-a', 0), SenseInfo('02082081-a', 0), SenseInfo('02029047-a', 0), SenseInfo('01879464-a', 0), SenseInfo('01720930-a', 0), SenseInfo('01693585-a', 0), SenseInfo('01661289-a', 0), SenseInfo('00023278-a', 0), SenseInfo('02031986-a', 20), SenseInfo('00631391-a', 20), SenseInfo('01879261-a', 16), SenseInfo('02034828-a', 10), SenseInfo('00633410-a', 2), SenseInfo('00135455-a', 1), SenseInfo('02030080-a', 0), SenseInfo('02082081-a', 0), SenseInfo('02029047-a', 0), SenseInfo('01879464-a', 0), SenseInfo('01720930-a', 0), SenseInfo('01693585-a', 0), SenseInfo('01661289-a', 0), SenseInfo('00023278-a', 0), SenseInfo('02031986-a', 20), SenseInfo('00631391-a', 20), SenseInfo('01879261-a', 16), SenseInfo('02034828-a', 10), SenseInfo('00633410-a', 2), SenseInfo('00135455-a', 1), SenseInfo('02030080-a', 0), SenseInfo('02082081-a', 0), SenseInfo('02029047-a', 0), SenseInfo('01879464-a', 0), SenseInfo('01720930-a', 0), SenseInfo('01693585-a', 0), SenseInfo('01661289-a', 0), SenseInfo('00023278-a', 0), SenseInfo('02031986-a', 20), SenseInfo('00631391-a', 20), SenseInfo('01879261-a', 16), SenseInfo('02034828-a', 10), SenseInfo('00633410-a', 2), SenseInfo('00135455-a', 1), SenseInfo('02030080-a', 0), SenseInfo('02082081-a', 0), SenseInfo('02029047-a', 0), SenseInfo('01879464-a', 0), SenseInfo('01720930-a', 0), SenseInfo('01693585-a', 0), SenseInfo('01661289-a', 0), SenseInfo('00023278-a', 0), SenseInfo('02031986-a', 20), SenseInfo('00631391-a', 20), SenseInfo('01879261-a', 16), SenseInfo('02034828-a', 10), SenseInfo('00633410-a', 2), SenseInfo('00135455-a', 1), SenseInfo('02030080-a', 0), SenseInfo('02082081-a', 0), SenseInfo('02029047-a', 0), SenseInfo('01879464-a', 0), SenseInfo('01720930-a', 0), SenseInfo('01693585-a', 0), SenseInfo('01661289-a', 0), SenseInfo('00023278-a', 0), SenseInfo('02031986-a', 20), SenseInfo('00631391-a', 20), SenseInfo('01879261-a', 16), SenseInfo('02034828-a', 10), SenseInfo('00633410-a', 2), SenseInfo('00135455-a', 1), SenseInfo('02030080-a', 0), SenseInfo('02082081-a', 0), SenseInfo('02029047-a', 0), SenseInfo('01879464-a', 0), SenseInfo('01720930-a', 0), SenseInfo('01693585-a', 0), SenseInfo('01661289-a', 0), SenseInfo('00023278-a', 0) ],
"_favorite_n_1_rel" : [ SenseInfo('05790758-n', 5), SenseInfo('09991867-n', 1), SenseInfo('10113753-n', 0), SenseInfo('05790758-n', 5), SenseInfo('09991867-n', 1), SenseInfo('10113753-n', 0) ],
"_judge_v_as_rel" : [ SenseInfo('00672277-v', 11), SenseInfo('00670261-v', 8), SenseInfo('00672433-v', 6), SenseInfo('00971650-v', 1), SenseInfo('02501278-v', 0), SenseInfo('00672277-v', 11), SenseInfo('00670261-v', 8), SenseInfo('00672433-v', 6), SenseInfo('00971650-v', 1), SenseInfo('02501278-v', 0) ],
"_corn_n_1_rel" : [ SenseInfo('12143676-n', 3), SenseInfo('12144580-n', 2), SenseInfo('07731952-n', 1), SenseInfo('14364802-n', 0), SenseInfo('12144117-n', 0), SenseInfo('07906877-n', 0), SenseInfo('04627809-n', 0) ],
"_tweezers_n_pair_rel" : [ SenseInfo('03941684-n', 0), SenseInfo('03941684-n', 0) ],
"_witchery_n_1_rel" : [ SenseInfo('05979350-n', 0) ],
"_mysterious_a_1_rel" : [ SenseInfo('00939444-a', 14), SenseInfo('00900071-a', 4) ],
"_discernible_a_1_rel" : [ SenseInfo('00581812-a', 3), SenseInfo('01747195-a', 1), SenseInfo('01287486-a', 0) ],
"_rebuff_v_1_rel" : [ SenseInfo('00798539-v', 3), SenseInfo('01131197-v', 1) ],
"_flow_v_1_rel" : [ SenseInfo('02066510-v', 13), SenseInfo('02066939-v', 10), SenseInfo('02067689-v', 1), SenseInfo('02743727-v', 0), SenseInfo('01542668-v', 0), SenseInfo('00217427-v', 0), SenseInfo('00062203-v', 0) ],
"_lexicon_n_1_rel" : [ SenseInfo('05651242-n', 2), SenseInfo('06418901-n', 0) ],
"_uv_n_1_rel" : [ SenseInfo('11521940-n', 0) ],
"_derail_v_cause_rel" : [ SenseInfo('02012043-v', 0), SenseInfo('02011865-v', 0) ],
"_villager_n_1_rel" : [ SenseInfo('10753442-n', 2) ],
"_hydrostatic_a_1_rel" : [ SenseInfo('02828123-a', 0) ],
"_cdt_n_1_rel" : [  ],
"_pump_v_up_rel" : [ SenseInfo('01225684-v', 4), SenseInfo('01155307-v', 3), SenseInfo('01853310-v', 1), SenseInfo('02356113-v', 0), SenseInfo('02068324-v', 0), SenseInfo('01853192-v', 0), SenseInfo('01853069-v', 0), SenseInfo('00788057-v', 0), SenseInfo('01225684-v', 4), SenseInfo('01155307-v', 3), SenseInfo('01853310-v', 1), SenseInfo('02356113-v', 0), SenseInfo('02068324-v', 0), SenseInfo('01853192-v', 0), SenseInfo('01853069-v', 0), SenseInfo('00788057-v', 0) ],
"_dare_v_1_rel" : [ SenseInfo('02374924-v', 11), SenseInfo('02545045-v', 10), SenseInfo('00868097-v', 3), SenseInfo('02374924-v', 11), SenseInfo('02545045-v', 10), SenseInfo('00868097-v', 3), SenseInfo('02374924-v', 11), SenseInfo('02545045-v', 10), SenseInfo('00868097-v', 3), SenseInfo('02374924-v', 11), SenseInfo('02545045-v', 10), SenseInfo('00868097-v', 3) ],
"_depopulate_v_1_rel" : [ SenseInfo('00531302-v', 0) ],
"_northeastern_a_1_rel" : [ SenseInfo('01601592-a', 0), SenseInfo('00827556-a', 0), SenseInfo('01601592-a', 0), SenseInfo('00827556-a', 0) ],
"_neck_n_1_rel" : [ SenseInfo('05546540-n', 34), SenseInfo('09367733-n', 0), SenseInfo('07661357-n', 0), SenseInfo('03814348-n', 0), SenseInfo('03814112-n', 0) ],
"_trick+or+treat_a_1_rel" : [  ],
"_petty_a_1_rel" : [ SenseInfo('02100968-a', 0), SenseInfo('01280908-a', 0), SenseInfo('00288498-a', 0), SenseInfo('02100968-a', 0), SenseInfo('01280908-a', 0), SenseInfo('00288498-a', 0), SenseInfo('02100968-a', 0), SenseInfo('01280908-a', 0), SenseInfo('00288498-a', 0) ],
"_deterrant_a_1_rel" : [  ],
"_inescapable_a_1_rel" : [ SenseInfo('00343360-a', 4) ],
"_jest_n_1_rel" : [ SenseInfo('06778102-n', 1), SenseInfo('00431005-n', 0), SenseInfo('06778102-n', 1), SenseInfo('00431005-n', 0) ],
"_harmless_a_1_rel" : [ SenseInfo('01159655-a', 1), SenseInfo('01159655-a', 1) ],
"_heat_v_up_rel" : [ SenseInfo('00371264-v', 11), SenseInfo('02333358-v', 0), SenseInfo('01761120-v', 0), SenseInfo('00372665-v', 0) ],
"_read_v_over_rel" : [ SenseInfo('00625119-v', 115), SenseInfo('02730813-v', 17), SenseInfo('00626428-v', 15), SenseInfo('00627520-v', 5), SenseInfo('00627091-v', 5), SenseInfo('00624476-v', 5), SenseInfo('00599992-v', 4), SenseInfo('00922867-v', 3), SenseInfo('01718755-v', 0), SenseInfo('00620239-v', 0), SenseInfo('00593852-v', 0) ],
"_software_n_1_rel" : [ SenseInfo('06566077-n', 0) ],
"_parcel_v_out_rel" : [ SenseInfo('02469085-v', 1), SenseInfo('01336334-v', 0), SenseInfo('01283746-v', 0) ],
"_carolingian_a_1_rel" : [ SenseInfo('02680977-a', 0) ],
"_salient_a_1_rel" : [ SenseInfo('00580805-a', 3), SenseInfo('02591896-a', 0), SenseInfo('01235439-a', 0) ],
"_look_v_up_rel" : [ SenseInfo('02130524-v', 274), SenseInfo('02133435-v', 126), SenseInfo('00033599-v', 25), SenseInfo('02153709-v', 8), SenseInfo('02693319-v', 1), SenseInfo('02549581-v', 1), SenseInfo('00929362-v', 1), SenseInfo('00720063-v', 1), SenseInfo('02658447-v', 0), SenseInfo('00712708-v', 0) ],
"_filter_v_2_rel" : [ SenseInfo('01458664-v', 10), SenseInfo('01457954-v', 3), SenseInfo('02070874-v', 0) ],
"_merely_x_deg_rel" : [ SenseInfo('00004722-r', 73), SenseInfo('00004722-r', 73) ],
"_victory_n_1_rel" : [ SenseInfo('07473441-n', 42) ],
"_demeanor_n_1_rel" : [ SenseInfo('04897762-n', 3) ],
"_cast_v_out_rel" : [ SenseInfo('01632897-v', 15), SenseInfo('02236023-v', 3), SenseInfo('01710481-v', 2), SenseInfo('01507143-v', 1), SenseInfo('02385813-v', 0), SenseInfo('01881180-v', 0), SenseInfo('01662771-v', 0), SenseInfo('01513430-v', 0), SenseInfo('01078050-v', 0), SenseInfo('00981276-v', 0), SenseInfo('00076400-v', 0) ],
"_clearness_n_1_rel" : [ SenseInfo('04820258-n', 3), SenseInfo('04701460-n', 0) ],
"_in-flight_a_1_rel" : [  ],
"_bearable_a_1_rel" : [ SenseInfo('02435206-a', 0) ],
"_aqua+regia_n_1_rel" : [ SenseInfo('14767477-n', 0) ],
"_secure_a_1_rel" : [ SenseInfo('02093305-a', 3), SenseInfo('02093888-a', 2), SenseInfo('02095311-a', 0), SenseInfo('02526124-a', 0), SenseInfo('02273643-a', 0), SenseInfo('02093305-a', 3), SenseInfo('02093888-a', 2), SenseInfo('02095311-a', 0), SenseInfo('02526124-a', 0), SenseInfo('02273643-a', 0), SenseInfo('02093305-a', 3), SenseInfo('02093888-a', 2), SenseInfo('02095311-a', 0), SenseInfo('02526124-a', 0), SenseInfo('02273643-a', 0), SenseInfo('02093305-a', 3), SenseInfo('02093888-a', 2), SenseInfo('02095311-a', 0), SenseInfo('02526124-a', 0), SenseInfo('02273643-a', 0) ],
"_purple_a_1_rel" : [ SenseInfo('00380312-a', 9), SenseInfo('02017372-a', 0), SenseInfo('01591394-a', 0) ],
"_ornamental_a_1_rel" : [ SenseInfo('01091234-a', 0) ],
"_countryperson_n_1_rel" : [  ],
"_modulation_n_1_rel" : [ SenseInfo('07087641-n', 3), SenseInfo('06281295-n', 2), SenseInfo('07084166-n', 0), SenseInfo('07083958-n', 0), SenseInfo('00200379-n', 0) ],
"_devisee_n_1_rel" : [ SenseInfo('10010632-n', 1) ],
"_downloadable_a_1_rel" : [  ],
"_secretariat_n_1_rel" : [ SenseInfo('08324274-n', 0), SenseInfo('02384428-n', 0) ],
"_day_v_dream_rel" : [  ],
"_flag_v_down_rel" : [ SenseInfo('01040550-v', 1), SenseInfo('00511040-v', 1), SenseInfo('01985524-v', 0), SenseInfo('01670172-v', 0), SenseInfo('00156485-v', 0) ],
"_grate_n_1_rel" : [ SenseInfo('03454536-n', 1), SenseInfo('07384244-n', 0), SenseInfo('03454707-n', 0) ],
"_search_v_out_rel" : [ SenseInfo('01315613-v', 13), SenseInfo('02153709-v', 11), SenseInfo('00648224-v', 3), SenseInfo('01317723-v', 2) ],
"_lascivious_a_1_rel" : [ SenseInfo('02133207-a', 0) ],
"_forge_n_1_rel" : [ SenseInfo('03383821-n', 0), SenseInfo('03383646-n', 0) ],
"_literal_n_1_rel" : [ SenseInfo('06769670-n', 0) ],
"_near_v_1_rel" : [ SenseInfo('02053941-v', 11) ],
"_fever_n_1_rel" : [ SenseInfo('14365356-n', 4), SenseInfo('07511380-n', 4) ],
"_assail_v_1_rel" : [ SenseInfo('01120069-v', 6), SenseInfo('01119169-v', 0), SenseInfo('00862683-v', 0) ],
"_nightclub_n_1_rel" : [ SenseInfo('02931417-n', 6) ],
"_north_n_of_rel" : [ SenseInfo('09052652-n', 20), SenseInfo('09052314-n', 3), SenseInfo('13831176-n', 2), SenseInfo('08561081-n', 2), SenseInfo('13835427-n', 0), SenseInfo('13831441-n', 0), SenseInfo('11209790-n', 0) ],
"_bump_v_into_rel" : [ SenseInfo('01239619-v', 2), SenseInfo('02248465-v', 1), SenseInfo('01895383-v', 1), SenseInfo('02399331-v', 0), SenseInfo('01527508-v', 0) ],
"_acquiescence_n_1_rel" : [ SenseInfo('14413162-n', 3), SenseInfo('07175575-n', 1) ],
"_martian_n_1_rel" : [ SenseInfo('09489790-n', 3) ],
"_sway_v_cause_rel" : [ SenseInfo('01875295-v', 5), SenseInfo('01877355-v', 4), SenseInfo('02586121-v', 3), SenseInfo('01876028-v', 0) ],
"_prefect_n_1_rel" : [ SenseInfo('10465128-n', 0) ],
"_string_v_on_rel" : [ SenseInfo('01359432-v', 2), SenseInfo('00190389-v', 1), SenseInfo('01993805-v', 0), SenseInfo('01360571-v', 0), SenseInfo('01360423-v', 0), SenseInfo('01360316-v', 0), SenseInfo('01359145-v', 0) ],
"_passability_n_1_rel" : [  ],
"_headmaster_n_of_rel" : [ SenseInfo('10164233-n', 2), SenseInfo('10164233-n', 2) ],
"_hamster_n_1_rel" : [ SenseInfo('02342885-n', 0) ],
"_infuse_v_1_rel" : [ SenseInfo('00606600-v', 0), SenseInfo('00498299-v', 0), SenseInfo('00327654-v', 0), SenseInfo('00327362-v', 0), SenseInfo('00086598-v', 0) ],
"_incursion_n_1_rel" : [ SenseInfo('00049344-n', 1), SenseInfo('00975452-n', 0), SenseInfo('00072691-n', 0) ],
"_insure_v_against_rel" : [ SenseInfo('00662589-v', 12), SenseInfo('00890590-v', 10), SenseInfo('00891216-v', 2), SenseInfo('02251065-v', 1) ],
"_clip_v_out_rel" : [ SenseInfo('01456463-v', 2), SenseInfo('01901447-v', 0), SenseInfo('01367616-v', 0), SenseInfo('01321002-v', 0), SenseInfo('00292877-v', 0) ],
"_moment_n_1_rel" : [ SenseInfo('15244650-n', 86), SenseInfo('15246853-n', 73), SenseInfo('15120050-n', 1), SenseInfo('05170574-n', 1), SenseInfo('11482985-n', 0), SenseInfo('06022509-n', 0), SenseInfo('15244650-n', 86), SenseInfo('15246853-n', 73), SenseInfo('15120050-n', 1), SenseInfo('05170574-n', 1), SenseInfo('11482985-n', 0), SenseInfo('06022509-n', 0) ],
"_cognate_n_1_rel" : [ SenseInfo('10236114-n', 0), SenseInfo('06289074-n', 0) ],
"_promise_v_1_rel" : [ SenseInfo('00884011-v', 26), SenseInfo('00884317-v', 11), SenseInfo('00917772-v', 5), SenseInfo('02740552-v', 3), SenseInfo('00884011-v', 26), SenseInfo('00884317-v', 11), SenseInfo('00917772-v', 5), SenseInfo('02740552-v', 3), SenseInfo('00884011-v', 26), SenseInfo('00884317-v', 11), SenseInfo('00917772-v', 5), SenseInfo('02740552-v', 3), SenseInfo('00884011-v', 26), SenseInfo('00884317-v', 11), SenseInfo('00917772-v', 5), SenseInfo('02740552-v', 3), SenseInfo('00884011-v', 26), SenseInfo('00884317-v', 11), SenseInfo('00917772-v', 5), SenseInfo('02740552-v', 3), SenseInfo('00884011-v', 26), SenseInfo('00884317-v', 11), SenseInfo('00917772-v', 5), SenseInfo('02740552-v', 3) ],
"_peel_v_off_rel" : [ SenseInfo('01262936-v', 3), SenseInfo('01259951-v', 0), SenseInfo('00049900-v', 0) ],
"_aromatic_a_1_rel" : [ SenseInfo('02641378-a', 0), SenseInfo('01052428-a', 0) ],
"_analog_n_1_rel" : [ SenseInfo('04746430-n', 0) ],
"_acrolect_n_1_rel" : [  ],
"_world's+fair_n_1_rel" : [  ],
"_adjust_v_to_rel" : [ SenseInfo('00296178-v', 19), SenseInfo('00464321-v', 6), SenseInfo('00150287-v', 6), SenseInfo('00298067-v', 2), SenseInfo('00699334-v', 0), SenseInfo('00296178-v', 19), SenseInfo('00464321-v', 6), SenseInfo('00150287-v', 6), SenseInfo('00298067-v', 2), SenseInfo('00699334-v', 0) ],
"_formulation_n_of_rel" : [ SenseInfo('14873641-n', 11), SenseInfo('00940842-n', 2), SenseInfo('07069948-n', 1), SenseInfo('14873641-n', 11), SenseInfo('00940842-n', 2), SenseInfo('07069948-n', 1), SenseInfo('14873641-n', 11), SenseInfo('00940842-n', 2), SenseInfo('07069948-n', 1) ],
"_put_v_together_rel" : [ SenseInfo('01494310-v', 138), SenseInfo('01493741-v', 98), SenseInfo('00981276-v', 28), SenseInfo('01160370-v', 6), SenseInfo('02271137-v', 3), SenseInfo('00673448-v', 2), SenseInfo('02111499-v', 0), SenseInfo('01706375-v', 0), SenseInfo('00735571-v', 0) ],
"_accumulator_n_1_rel" : [ SenseInfo('09936362-n', 0), SenseInfo('04328329-n', 0), SenseInfo('02673078-n', 0) ],
"_dimensional_a_1_rel" : [ SenseInfo('02985102-a', 3), SenseInfo('00660313-a', 3) ],
"_wow_n_1_rel" : [ SenseInfo('06778925-n', 0) ],
"_prostitute_n_1_rel" : [ SenseInfo('10485440-n', 1) ],
"_inherent_a_1_rel" : [ SenseInfo('01348528-a', 7), SenseInfo('00941940-a', 0), SenseInfo('01348528-a', 7), SenseInfo('00941940-a', 0) ],
"_prick_v_1_rel" : [ SenseInfo('01440801-v', 3), SenseInfo('02123424-v', 1), SenseInfo('01983006-v', 1), SenseInfo('01240935-v', 1), SenseInfo('02123298-v', 0), SenseInfo('01760945-v', 0), SenseInfo('01445407-v', 0) ],
"_multimeter_n_1_rel" : [  ],
"_destitution_n_1_rel" : [ SenseInfo('14493613-n', 0) ],
"_faculty_n_1_rel" : [ SenseInfo('05650329-n', 4), SenseInfo('08287586-n', 3) ],
"_catalyst_n_1_rel" : [ SenseInfo('14723628-n', 0), SenseInfo('09900711-n', 0) ],
"_whisk_v_1_rel" : [ SenseInfo('02079679-v', 1), SenseInfo('02079818-v', 0), SenseInfo('01435254-v', 0), SenseInfo('01417868-v', 0), SenseInfo('02079679-v', 1), SenseInfo('02079818-v', 0), SenseInfo('01435254-v', 0), SenseInfo('01417868-v', 0) ],
"_spy_v_on_rel" : [ SenseInfo('02154312-v', 2), SenseInfo('00785690-v', 2), SenseInfo('02163746-v', 0), SenseInfo('00785470-v', 0) ],
"_alongside_p_rel" : [ SenseInfo('00250056-r', 0), SenseInfo('00250056-r', 0), SenseInfo('00250056-r', 0) ],
"_gentile_a_1_rel" : [ SenseInfo('02735066-a', 3) ],
"_airborne_a_1_rel" : [ SenseInfo('01522895-a', 3) ],
"_outstretched_a_1_rel" : [ SenseInfo('01432070-a', 0) ],
"_malice_n_1_rel" : [ SenseInfo('07550666-n', 0), SenseInfo('04842313-n', 0) ],
"_celebrity_n_1_rel" : [ SenseInfo('09903153-n', 1), SenseInfo('14437386-n', 0) ],
"_tailor_n_1_rel" : [ SenseInfo('10689564-n', 0) ],
"_gas_n_1_rel" : [ SenseInfo('14481080-n', 15), SenseInfo('14877585-n', 13), SenseInfo('14686913-n', 7), SenseInfo('14035695-n', 1), SenseInfo('02670683-n', 1), SenseInfo('14960090-n', 0), SenseInfo('14481080-n', 15), SenseInfo('14877585-n', 13), SenseInfo('14686913-n', 7), SenseInfo('14035695-n', 1), SenseInfo('02670683-n', 1), SenseInfo('14960090-n', 0), SenseInfo('14481080-n', 15), SenseInfo('14877585-n', 13), SenseInfo('14686913-n', 7), SenseInfo('14035695-n', 1), SenseInfo('02670683-n', 1), SenseInfo('14960090-n', 0) ],
"_sovereign_n_1_rel" : [ SenseInfo('10628644-n', 5) ],
"_sunken_a_1_rel" : [ SenseInfo('02264521-a', 2) ],
"_smuggle_v_in_rel" : [ SenseInfo('02345856-v', 3) ],
"_yearning_a_1_rel" : [ SenseInfo('07486628-n', 5) ],
"_bladder_n_1_rel" : [ SenseInfo('05512139-n', 0), SenseInfo('02848118-n', 0) ],
"_tape_n_1_rel" : [ SenseInfo('04391569-n', 10), SenseInfo('04391838-n', 2), SenseInfo('08683986-n', 0), SenseInfo('04392113-n', 0), SenseInfo('03708036-n', 0) ],
"_well_x_deg_rel" : [ SenseInfo('00011093-r', 76), SenseInfo('00012779-r', 30), SenseInfo('00012531-r', 16), SenseInfo('04572344-n', 8), SenseInfo('00015135-r', 6), SenseInfo('02540578-a', 4), SenseInfo('00013429-r', 4), SenseInfo('00013092-r', 4), SenseInfo('01048762-a', 3), SenseInfo('00067638-a', 3), SenseInfo('01991204-v', 3), SenseInfo('00014285-r', 2), SenseInfo('04572935-n', 1), SenseInfo('00015007-r', 1), SenseInfo('06675979-n', 0), SenseInfo('04572800-n', 0), SenseInfo('04572559-n', 0), SenseInfo('00014882-r', 0), SenseInfo('00014616-r', 0), SenseInfo('00013793-r', 0), SenseInfo('00013626-r', 0), SenseInfo('00012129-r', 0), SenseInfo('00011093-r', 76), SenseInfo('00012779-r', 30), SenseInfo('00012531-r', 16), SenseInfo('04572344-n', 8), SenseInfo('00015135-r', 6), SenseInfo('02540578-a', 4), SenseInfo('00013429-r', 4), SenseInfo('00013092-r', 4), SenseInfo('01048762-a', 3), SenseInfo('00067638-a', 3), SenseInfo('01991204-v', 3), SenseInfo('00014285-r', 2), SenseInfo('04572935-n', 1), SenseInfo('00015007-r', 1), SenseInfo('06675979-n', 0), SenseInfo('04572800-n', 0), SenseInfo('04572559-n', 0), SenseInfo('00014882-r', 0), SenseInfo('00014616-r', 0), SenseInfo('00013793-r', 0), SenseInfo('00013626-r', 0), SenseInfo('00012129-r', 0), SenseInfo('00011093-r', 76), SenseInfo('00012779-r', 30), SenseInfo('00012531-r', 16), SenseInfo('04572344-n', 8), SenseInfo('00015135-r', 6), SenseInfo('02540578-a', 4), SenseInfo('00013429-r', 4), SenseInfo('00013092-r', 4), SenseInfo('01048762-a', 3), SenseInfo('00067638-a', 3), SenseInfo('01991204-v', 3), SenseInfo('00014285-r', 2), SenseInfo('04572935-n', 1), SenseInfo('00015007-r', 1), SenseInfo('06675979-n', 0), SenseInfo('04572800-n', 0), SenseInfo('04572559-n', 0), SenseInfo('00014882-r', 0), SenseInfo('00014616-r', 0), SenseInfo('00013793-r', 0), SenseInfo('00013626-r', 0), SenseInfo('00012129-r', 0) ],
"_tendril_n_1_rel" : [ SenseInfo('13102775-n', 0) ],
"_pka1_n_1_rel" : [  ],
"_pull_v_1_rel" : [ SenseInfo('01448100-v', 44), SenseInfo('01505254-v', 8), SenseInfo('02057499-v', 6), SenseInfo('01609287-v', 3), SenseInfo('02582615-v', 2), SenseInfo('01995211-v', 2), SenseInfo('02057337-v', 1), SenseInfo('00071803-v', 1), SenseInfo('02103162-v', 0), SenseInfo('01947247-v', 0), SenseInfo('01858573-v', 0), SenseInfo('01573276-v', 0), SenseInfo('01407059-v', 0), SenseInfo('01384275-v', 0), SenseInfo('01351170-v', 0), SenseInfo('01148710-v', 0), SenseInfo('00571596-v', 0), SenseInfo('01448100-v', 44), SenseInfo('01505254-v', 8), SenseInfo('02057499-v', 6), SenseInfo('01609287-v', 3), SenseInfo('02582615-v', 2), SenseInfo('01995211-v', 2), SenseInfo('02057337-v', 1), SenseInfo('00071803-v', 1), SenseInfo('02103162-v', 0), SenseInfo('01947247-v', 0), SenseInfo('01858573-v', 0), SenseInfo('01573276-v', 0), SenseInfo('01407059-v', 0), SenseInfo('01384275-v', 0), SenseInfo('01351170-v', 0), SenseInfo('01148710-v', 0), SenseInfo('00571596-v', 0) ],
"_log_v_in_rel" : [ SenseInfo('01002481-v', 2), SenseInfo('01258828-v', 1), SenseInfo('01002481-v', 2), SenseInfo('01258828-v', 1) ],
"_writing+up_n_1_rel" : [  ],
"_informative_a_1_rel" : [ SenseInfo('01325777-a', 0), SenseInfo('01323449-a', 0), SenseInfo('01304570-a', 0), SenseInfo('01325777-a', 0), SenseInfo('01323449-a', 0), SenseInfo('01304570-a', 0) ],
"_administrative_a_1_rel" : [ SenseInfo('02904075-a', 16), SenseInfo('02904075-a', 16) ],
"_tight_a_1_rel" : [ SenseInfo('01447302-a', 10), SenseInfo('02403505-a', 2), SenseInfo('02526441-a', 1), SenseInfo('01655538-a', 1), SenseInfo('01113807-a', 1), SenseInfo('00017186-a', 1), SenseInfo('01398199-a', 0), SenseInfo('02232739-a', 0), SenseInfo('02095670-a', 0), SenseInfo('00890622-a', 0), SenseInfo('00798103-a', 0), SenseInfo('00747727-a', 0), SenseInfo('00711059-a', 0), SenseInfo('00503157-a', 0), SenseInfo('01447302-a', 10), SenseInfo('02403505-a', 2), SenseInfo('02526441-a', 1), SenseInfo('01655538-a', 1), SenseInfo('01113807-a', 1), SenseInfo('00017186-a', 1), SenseInfo('01398199-a', 0), SenseInfo('02232739-a', 0), SenseInfo('02095670-a', 0), SenseInfo('00890622-a', 0), SenseInfo('00798103-a', 0), SenseInfo('00747727-a', 0), SenseInfo('00711059-a', 0), SenseInfo('00503157-a', 0), SenseInfo('01447302-a', 10), SenseInfo('02403505-a', 2), SenseInfo('02526441-a', 1), SenseInfo('01655538-a', 1), SenseInfo('01113807-a', 1), SenseInfo('00017186-a', 1), SenseInfo('01398199-a', 0), SenseInfo('02232739-a', 0), SenseInfo('02095670-a', 0), SenseInfo('00890622-a', 0), SenseInfo('00798103-a', 0), SenseInfo('00747727-a', 0), SenseInfo('00711059-a', 0), SenseInfo('00503157-a', 0), SenseInfo('01447302-a', 10), SenseInfo('02403505-a', 2), SenseInfo('02526441-a', 1), SenseInfo('01655538-a', 1), SenseInfo('01113807-a', 1), SenseInfo('00017186-a', 1), SenseInfo('01398199-a', 0), SenseInfo('02232739-a', 0), SenseInfo('02095670-a', 0), SenseInfo('00890622-a', 0), SenseInfo('00798103-a', 0), SenseInfo('00747727-a', 0), SenseInfo('00711059-a', 0), SenseInfo('00503157-a', 0) ],
"_make_n_of_rel" : [ SenseInfo('05845140-n', 1), SenseInfo('00340463-n', 0), SenseInfo('05845140-n', 1), SenseInfo('00340463-n', 0) ],
"_workings_n_1_rel" : [ SenseInfo('04601473-n', 0), SenseInfo('04601473-n', 0) ],
"_routing_n_1_rel" : [  ],
"_stillness_n_1_rel" : [ SenseInfo('04982478-n', 6), SenseInfo('14522809-n', 1), SenseInfo('14006179-n', 0) ],
"_cooperation_n_1_rel" : [ SenseInfo('01202904-n', 7), SenseInfo('00411384-n', 1), SenseInfo('01202904-n', 7), SenseInfo('00411384-n', 1), SenseInfo('01202904-n', 7), SenseInfo('00411384-n', 1) ],
"_railhead_n_1_rel" : [ SenseInfo('04047139-n', 1), SenseInfo('04047291-n', 0) ],
"_jumble_v_1_rel" : [ SenseInfo('02739861-v', 1), SenseInfo('01657254-v', 0), SenseInfo('01472807-v', 0) ],
"_keeper_n_1_rel" : [ SenseInfo('10229498-n', 0), SenseInfo('09984298-n', 0) ],
"_overrun_v_1_rel" : [ SenseInfo('02020413-v', 3), SenseInfo('02654686-v', 0), SenseInfo('02072159-v', 0), SenseInfo('01103459-v', 0), SenseInfo('00705924-v', 0), SenseInfo('02020413-v', 3), SenseInfo('02654686-v', 0), SenseInfo('02072159-v', 0), SenseInfo('01103459-v', 0), SenseInfo('00705924-v', 0) ],
"_weathering_n_1_rel" : [  ],
"_counteroffer_n_1_rel" : [ SenseInfo('07164972-n', 0), SenseInfo('07164972-n', 0), SenseInfo('07164972-n', 0), SenseInfo('07164972-n', 0), SenseInfo('07164972-n', 0), SenseInfo('07164972-n', 0), SenseInfo('07164972-n', 0), SenseInfo('07164972-n', 0) ],
"_stop+payment_n_of_rel" : [ SenseInfo('06530586-n', 0), SenseInfo('06530586-n', 0) ],
"_job_n_1_rel" : [ SenseInfo('00582388-n', 76), SenseInfo('00719705-n', 36), SenseInfo('03599628-n', 4), SenseInfo('03599761-n', 2), SenseInfo('00584769-n', 2), SenseInfo('00576877-n', 2), SenseInfo('00576717-n', 1), SenseInfo('14410605-n', 0), SenseInfo('11085402-n', 0), SenseInfo('10222949-n', 0), SenseInfo('06572482-n', 0), SenseInfo('06436939-n', 0), SenseInfo('00782792-n', 0), SenseInfo('00582388-n', 76), SenseInfo('00719705-n', 36), SenseInfo('03599628-n', 4), SenseInfo('03599761-n', 2), SenseInfo('00584769-n', 2), SenseInfo('00576877-n', 2), SenseInfo('00576717-n', 1), SenseInfo('14410605-n', 0), SenseInfo('11085402-n', 0), SenseInfo('10222949-n', 0), SenseInfo('06572482-n', 0), SenseInfo('06436939-n', 0), SenseInfo('00782792-n', 0) ],
"_german_a_1_rel" : [ SenseInfo('02957469-a', 11) ],
"_conceal_v_from_rel" : [ SenseInfo('02144835-v', 8), SenseInfo('02146790-v', 1), SenseInfo('02144835-v', 8), SenseInfo('02146790-v', 1) ],
"_damaskeen_n_1_rel" : [  ],
"_puffy_a_1_rel" : [ SenseInfo('01384081-a', 0), SenseInfo('01174565-a', 0), SenseInfo('00305700-a', 0) ],
"_burly_a_1_rel" : [ SenseInfo('02038126-a', 2), SenseInfo('02038126-a', 2), SenseInfo('02038126-a', 2) ],
"_fourfold_a_1_rel" : [ SenseInfo('02219144-a', 1), SenseInfo('02219287-a', 0), SenseInfo('02219144-a', 1), SenseInfo('02219287-a', 0) ],
"_heel_n_1_rel" : [ SenseInfo('03511426-n', 6), SenseInfo('05578095-n', 4), SenseInfo('09886220-n', 0), SenseInfo('07683973-n', 0), SenseInfo('03511949-n', 0), SenseInfo('03511786-n', 0) ],
"_tonsillitis_n_1_rel" : [ SenseInfo('14357251-n', 0) ],
"_singaporian_a_1_rel" : [  ],
"_tyro_n_1_rel" : [ SenseInfo('10363913-n', 0) ],
"_copper_n_1_rel" : [ SenseInfo('14635722-n', 4), SenseInfo('13391774-n', 0), SenseInfo('09879144-n', 0), SenseInfo('04973669-n', 0), SenseInfo('02282385-n', 0) ],
"_sock_v_in_rel" : [ SenseInfo('01397088-v', 2) ],
"_refresh_v_1_rel" : [ SenseInfo('00696852-v', 0), SenseInfo('00164444-v', 0), SenseInfo('00024814-v', 0), SenseInfo('00024649-v', 0), SenseInfo('00696852-v', 0), SenseInfo('00164444-v', 0), SenseInfo('00024814-v', 0), SenseInfo('00024649-v', 0), SenseInfo('00696852-v', 0), SenseInfo('00164444-v', 0), SenseInfo('00024814-v', 0), SenseInfo('00024649-v', 0), SenseInfo('00696852-v', 0), SenseInfo('00164444-v', 0), SenseInfo('00024814-v', 0), SenseInfo('00024649-v', 0), SenseInfo('00696852-v', 0), SenseInfo('00164444-v', 0), SenseInfo('00024814-v', 0), SenseInfo('00024649-v', 0) ],
"_skim_v_1_rel" : [ SenseInfo('01942718-v', 1), SenseInfo('01247550-v', 1), SenseInfo('02152278-v', 0), SenseInfo('01515924-v', 0), SenseInfo('01261263-v', 0), SenseInfo('01261018-v', 0), SenseInfo('00627824-v', 0) ],
"_inharmonious_a_1_rel" : [ SenseInfo('01164072-a', 0), SenseInfo('00563116-a', 0) ],
"_bring_v_in_rel" : [ SenseInfo('02077656-v', 122), SenseInfo('01438902-v', 55), SenseInfo('01629589-v', 31), SenseInfo('01433294-v', 19), SenseInfo('00135857-v', 9), SenseInfo('01434140-v', 4), SenseInfo('01618547-v', 3), SenseInfo('02324478-v', 2), SenseInfo('02247390-v', 1), SenseInfo('01808218-v', 0), SenseInfo('00767334-v', 0) ],
"_magnet_n_1_rel" : [ SenseInfo('03705379-n', 2), SenseInfo('05850823-n', 0) ],
"_rodent_n_1_rel" : [ SenseInfo('02329401-n', 0) ],
"_curio_n_1_rel" : [ SenseInfo('03149951-n', 2) ],
"_thousander_n_1_rel" : [  ],
"_supply_v_1_rel" : [ SenseInfo('02327200-v', 44), SenseInfo('02479323-v', 8), SenseInfo('01182709-v', 3), SenseInfo('01027174-v', 1), SenseInfo('02327200-v', 44), SenseInfo('02479323-v', 8), SenseInfo('01182709-v', 3), SenseInfo('01027174-v', 1) ],
"_scarf_v_down_rel" : [ SenseInfo('01431132-v', 0), SenseInfo('01294889-v', 0), SenseInfo('00051060-v', 0) ],
"_accurate_a_1_rel" : [ SenseInfo('00021766-a', 12), SenseInfo('00631798-a', 0), SenseInfo('00021766-a', 12), SenseInfo('00631798-a', 0), SenseInfo('00021766-a', 12), SenseInfo('00631798-a', 0) ],
"_suggestion_n_of_rel" : [ SenseInfo('05916155-n', 13), SenseInfo('07162680-n', 9), SenseInfo('13773361-n', 1), SenseInfo('07246582-n', 1), SenseInfo('05771679-n', 0), SenseInfo('00158996-n', 0), SenseInfo('05916155-n', 13), SenseInfo('07162680-n', 9), SenseInfo('13773361-n', 1), SenseInfo('07246582-n', 1), SenseInfo('05771679-n', 0), SenseInfo('00158996-n', 0) ],
"_crash_n_1_rel" : [ SenseInfo('07380144-n', 9), SenseInfo('07301950-n', 4), SenseInfo('07477945-n', 1), SenseInfo('00126236-n', 1), SenseInfo('07478874-n', 0) ],
"_pure_a_1_rel" : [ SenseInfo('01905653-a', 18), SenseInfo('01520091-a', 2), SenseInfo('00393508-a', 1), SenseInfo('01163860-a', 1), SenseInfo('00862911-a', 1), SenseInfo('01904845-a', 0), SenseInfo('00361125-a', 0), SenseInfo('01905653-a', 18), SenseInfo('01520091-a', 2), SenseInfo('00393508-a', 1), SenseInfo('01163860-a', 1), SenseInfo('00862911-a', 1), SenseInfo('01904845-a', 0), SenseInfo('00361125-a', 0), SenseInfo('01905653-a', 18), SenseInfo('01520091-a', 2), SenseInfo('00393508-a', 1), SenseInfo('01163860-a', 1), SenseInfo('00862911-a', 1), SenseInfo('01904845-a', 0), SenseInfo('00361125-a', 0), SenseInfo('01905653-a', 18), SenseInfo('01520091-a', 2), SenseInfo('00393508-a', 1), SenseInfo('01163860-a', 1), SenseInfo('00862911-a', 1), SenseInfo('01904845-a', 0), SenseInfo('00361125-a', 0) ],
"_exotic_a_1_rel" : [ SenseInfo('01035007-a', 2), SenseInfo('00968730-a', 0) ],
"_in+general_a_1_rel" : [  ],
"_inflate_v_1_rel" : [ SenseInfo('00264386-v', 1), SenseInfo('00264034-v', 1), SenseInfo('00562882-v', 0), SenseInfo('00562523-v', 0), SenseInfo('00256117-v', 0) ],
"_lushness_n_1_rel" : [ SenseInfo('05116243-n', 0) ],
"_swoon_n_1_rel" : [ SenseInfo('07478318-n', 0) ],
"_acne_n_1_rel" : [ SenseInfo('14222112-n', 0) ],
"_school_v_1_rel" : [ SenseInfo('02387910-v', 2), SenseInfo('02388403-v', 0), SenseInfo('01961334-v', 0), SenseInfo('02387910-v', 2), SenseInfo('02388403-v', 0), SenseInfo('01961334-v', 0) ],
"_highroad_n_1_rel" : [ SenseInfo('03519578-n', 6) ],
"_flush_n_1_rel" : [ SenseInfo('15295045-n', 1), SenseInfo('14050871-n', 1), SenseInfo('14336169-n', 0), SenseInfo('07958196-n', 0), SenseInfo('07528470-n', 0), SenseInfo('07439570-n', 0), SenseInfo('00118268-n', 0) ],
"_much-beloved_a_1_rel" : [  ],
"_defuel_v_cause_rel" : [  ],
"_via_p_rel" : [  ],
"_unaltered_a_1_rel" : [ SenseInfo('00353206-a', 0), SenseInfo('00353206-a', 0) ],
"_pressure_v_1_rel" : [ SenseInfo('02504562-v', 1), SenseInfo('02581073-v', 0), SenseInfo('02504562-v', 1), SenseInfo('02581073-v', 0) ],
"_suitable_a_1_rel" : [ SenseInfo('01020885-a', 3), SenseInfo('00852197-a', 0) ],
"_upward_a_2_rel" : [ SenseInfo('02491836-a', 2), SenseInfo('02485488-a', 1) ],
"_troop_n_1_rel" : [ SenseInfo('08274354-n', 10), SenseInfo('08274443-n', 5), SenseInfo('08274718-n', 0), SenseInfo('08274565-n', 0) ],
"_alert_v_1_rel" : [ SenseInfo('00872414-v', 9) ],
"_strike_v_down_rel" : [ SenseInfo('01410223-v', 18), SenseInfo('01767949-v', 16), SenseInfo('01236164-v', 14), SenseInfo('01123887-v', 7), SenseInfo('00923622-v', 5), SenseInfo('01209135-v', 4), SenseInfo('02412647-v', 3), SenseInfo('02611976-v', 2), SenseInfo('02526811-v', 2), SenseInfo('01209426-v', 2), SenseInfo('00143540-v', 2), SenseInfo('02286687-v', 1), SenseInfo('01675073-v', 1), SenseInfo('01549420-v', 1), SenseInfo('02108791-v', 0), SenseInfo('02104161-v', 0), SenseInfo('01982395-v', 0), SenseInfo('01639105-v', 0), SenseInfo('01308008-v', 0), SenseInfo('01228235-v', 0), SenseInfo('00635904-v', 0) ],
"_knowledgeable_a_about_rel" : [ SenseInfo('00830051-a', 1), SenseInfo('01307850-a', 0), SenseInfo('00936038-a', 0), SenseInfo('00830051-a', 1), SenseInfo('01307850-a', 0), SenseInfo('00936038-a', 0) ],
"_corpus_n_1_rel" : [ SenseInfo('13355868-n', 0), SenseInfo('07955455-n', 0), SenseInfo('05221526-n', 0) ],
"_glide_n_1_rel" : [ SenseInfo('07114409-n', 0), SenseInfo('00328502-n', 0), SenseInfo('00303495-n', 0) ],
"_lesion_n_1_rel" : [ SenseInfo('14211294-n', 2), SenseInfo('14298815-n', 0) ],
"_manifest_a_1_rel" : [ SenseInfo('01618376-a', 0) ],
"_approve_v_1_rel" : [ SenseInfo('00806502-v', 27), SenseInfo('00673983-v', 7) ],
"_deteriorated_a_1_rel" : [  ],
"_extol_v_1_rel" : [ SenseInfo('00860620-v', 0) ],
"_trimmer_n_1_rel" : [ SenseInfo('10487182-n', 0), SenseInfo('04483925-n', 0), SenseInfo('04483779-n', 0), SenseInfo('04483584-n', 0) ],
"_alcoholism_n_1_rel" : [ SenseInfo('14064644-n', 0), SenseInfo('09181993-n', 0) ],
"_warn_v_against_rel" : [ SenseInfo('00870213-v', 22), SenseInfo('00870577-v', 5), SenseInfo('00833071-v', 0), SenseInfo('00832907-v', 0), SenseInfo('00870213-v', 22), SenseInfo('00870577-v', 5), SenseInfo('00833071-v', 0), SenseInfo('00832907-v', 0) ],
"_deceased_a_1_rel" : [ SenseInfo('00095873-a', 4) ],
"_smug_a_1_rel" : [ SenseInfo('00589448-a', 3), SenseInfo('00589448-a', 3), SenseInfo('00589448-a', 3) ],
"_hook_v_1_rel" : [ SenseInfo('01365549-v', 2), SenseInfo('02319050-v', 1), SenseInfo('01672490-v', 1), SenseInfo('01409177-v', 1), SenseInfo('02322230-v', 0), SenseInfo('02276866-v', 0), SenseInfo('01396790-v', 0), SenseInfo('01365709-v', 0), SenseInfo('01165290-v', 0), SenseInfo('01080883-v', 0), SenseInfo('00783042-v', 0), SenseInfo('00781652-v', 0) ],
"_traverse_n_1_rel" : [ SenseInfo('04475496-n', 0), SenseInfo('04472961-n', 0), SenseInfo('00298047-n', 0), SenseInfo('00296946-n', 0) ],
"_slam_n_1_rel" : [ SenseInfo('07474645-n', 0), SenseInfo('07394115-n', 0), SenseInfo('07338970-n', 0), SenseInfo('06767922-n', 0) ],
"_vagueness_n_about_rel" : [ SenseInfo('04824350-n', 1), SenseInfo('04704839-n', 0) ],
"_hertz_n_1_rel" : [ SenseInfo('15279104-n', 0), SenseInfo('11046934-n', 0), SenseInfo('11046722-n', 0), SenseInfo('15279104-n', 0), SenseInfo('11046934-n', 0), SenseInfo('11046722-n', 0), SenseInfo('15279104-n', 0), SenseInfo('11046934-n', 0), SenseInfo('11046722-n', 0) ],
"_orderly_n_1_rel" : [ SenseInfo('10381981-n', 2), SenseInfo('10381804-n', 0) ],
"_transaction_n_1_rel" : [ SenseInfo('01106808-n', 2) ],
"_burrow_n_1_rel" : [ SenseInfo('09230041-n', 4) ],
"_towards_p_sel_rel" : [  ],
"_bleep_n_1_rel" : [ SenseInfo('07377082-n', 0) ],
"_graze_v_1_rel" : [ SenseInfo('01576165-v', 3), SenseInfo('01608508-v', 2), SenseInfo('01576478-v', 0), SenseInfo('01240514-v', 0), SenseInfo('01174742-v', 0) ],
"_abscond_v_with_rel" : [ SenseInfo('02073714-v', 0) ],
"_maturate_v_1_rel" : [ SenseInfo('00250181-v', 0), SenseInfo('00248026-v', 0), SenseInfo('00096766-v', 0) ],
"_wipe_v_up_rel" : [ SenseInfo('01392237-v', 17), SenseInfo('01392237-v', 17) ],
"_compensation_n_1_rel" : [ SenseInfo('13282550-n', 6), SenseInfo('13450636-n', 0), SenseInfo('00259643-n', 0) ],
"_jotunologist_n_1_rel" : [  ],
"_act_v_seem+to_rel" : [ SenseInfo('02367363-v', 35), SenseInfo('00010435-v', 22), SenseInfo('01719302-v', 7), SenseInfo('01095899-v', 4), SenseInfo('00013615-v', 1), SenseInfo('02744977-v', 0), SenseInfo('02525447-v', 0), SenseInfo('02419073-v', 0), SenseInfo('01721556-v', 0), SenseInfo('01719921-v', 0) ],
"_tell_v_off_rel" : [ SenseInfo('01009240-v', 196), SenseInfo('00952524-v', 189), SenseInfo('00953216-v', 75), SenseInfo('00746718-v', 60), SenseInfo('00720961-v', 27), SenseInfo('01019643-v', 6), SenseInfo('00954422-v', 4), SenseInfo('00650353-v', 3) ],
"_automate_v_1_rel" : [ SenseInfo('00479932-v', 1) ],
"_interregio_n_1_rel" : [  ],
"_zest_n_for_rel" : [ SenseInfo('07491981-n', 1), SenseInfo('04993108-n', 0) ],
"few+if+any_a_rel" : [  ],
"_song_n_of_rel" : [ SenseInfo('07048000-n', 46), SenseInfo('07394588-n', 3), SenseInfo('00546389-n', 3), SenseInfo('06796642-n', 1), SenseInfo('13254011-n', 0), SenseInfo('08158741-n', 0), SenseInfo('07048000-n', 46), SenseInfo('07394588-n', 3), SenseInfo('00546389-n', 3), SenseInfo('06796642-n', 1), SenseInfo('13254011-n', 0), SenseInfo('08158741-n', 0) ],
"_rim_n_1_rel" : [ SenseInfo('13902336-n', 2), SenseInfo('04092447-n', 0), SenseInfo('04092305-n', 0), SenseInfo('03356858-n', 0), SenseInfo('02902250-n', 0) ],
"_burst_v_open_rel" : [ SenseInfo('00309310-v', 11), SenseInfo('01785395-v', 7), SenseInfo('00306017-v', 7), SenseInfo('01964634-v', 4), SenseInfo('02715595-v', 2), SenseInfo('00424224-v', 2), SenseInfo('01989562-v', 0), SenseInfo('00333594-v', 0), SenseInfo('00309310-v', 11), SenseInfo('01785395-v', 7), SenseInfo('00306017-v', 7), SenseInfo('01964634-v', 4), SenseInfo('02715595-v', 2), SenseInfo('00424224-v', 2), SenseInfo('01989562-v', 0), SenseInfo('00333594-v', 0) ],
"_grease_n_1_rel" : [ SenseInfo('14890945-n', 4), SenseInfo('14498096-n', 0) ],
"_exacerbate_v_1_rel" : [ SenseInfo('00208210-v', 2), SenseInfo('01820901-v', 0) ],
"_approx_x_rel" : [  ],
"_syrian_n_1_rel" : [ SenseInfo('09733459-n', 0) ],
"_nowadays_a_1_rel" : [ SenseInfo('15119536-n', 0), SenseInfo('15119536-n', 0) ],
"_cruciform_a_1_rel" : [ SenseInfo('02372434-a', 0) ],
"_vandal_n_1_rel" : [ SenseInfo('10746056-n', 1), SenseInfo('10746195-n', 0) ],
"_ghost_n_1_rel" : [ SenseInfo('05898171-n', 4), SenseInfo('10128748-n', 0), SenseInfo('09545976-n', 0), SenseInfo('07164163-n', 0) ],
"_enthused_a_1_rel" : [  ],
"_ken_n_1_rel" : [ SenseInfo('05805157-n', 2), SenseInfo('05623818-n', 0) ],
"_wannabe_n_1_rel" : [ SenseInfo('09801533-n', 0) ],
"_deadly_x_deg_rel" : [ SenseInfo('00993667-a', 6), SenseInfo('00993885-a', 1), SenseInfo('00304898-r', 0), SenseInfo('00046639-r', 0), SenseInfo('02449952-a', 0), SenseInfo('01721691-a', 0), SenseInfo('01611329-a', 0), SenseInfo('00045888-a', 0) ],
"_prerequisite_a_1_rel" : [ SenseInfo('00849232-a', 0) ],
"_howl_n_1_rel" : [ SenseInfo('07126734-n', 10), SenseInfo('07385548-n', 0), SenseInfo('07385367-n', 0) ],
"_minicircus_n_1_rel" : [  ],
"_moderation_n_1_rel" : [ SenseInfo('05117660-n', 1), SenseInfo('07357101-n', 0), SenseInfo('04883614-n', 0), SenseInfo('00353249-n', 0) ],
"_bus_n_1_rel" : [ SenseInfo('02924116-n', 2), SenseInfo('05730591-n', 0), SenseInfo('02924713-n', 0), SenseInfo('02924554-n', 0) ],
"_air+conditioner_n_1_rel" : [ SenseInfo('02686379-n', 0) ],
"_knickers_n_1_rel" : [ SenseInfo('02896442-n', 0), SenseInfo('02854739-n', 0), SenseInfo('02896442-n', 0), SenseInfo('02854739-n', 0) ],
"_blunder_n_1_rel" : [ SenseInfo('00074790-n', 2) ],
"_apologetic_a_1_rel" : [ SenseInfo('01631830-a', 1), SenseInfo('01631830-a', 1) ],
"_mortal_a_1_rel" : [ SenseInfo('01557614-a', 3), SenseInfo('01721691-a', 1), SenseInfo('01507992-a', 0), SenseInfo('00993667-a', 0), SenseInfo('01557614-a', 3), SenseInfo('01721691-a', 1), SenseInfo('01507992-a', 0), SenseInfo('00993667-a', 0) ],
"_gastrointestinal_a_1_rel" : [ SenseInfo('02975697-a', 2) ],
"_superhuman_n_1_rel" : [ SenseInfo('01260873-a', 0) ],
"_stunning_a_1_rel" : [ SenseInfo('01282921-a', 1), SenseInfo('02360171-a', 0), SenseInfo('01686036-a', 0), SenseInfo('00220739-a', 0) ],
"_capacity_n_1_rel" : [ SenseInfo('05203397-n', 15), SenseInfo('14530836-n', 9), SenseInfo('13779374-n', 6), SenseInfo('00914795-n', 3), SenseInfo('00720951-n', 1), SenseInfo('13755053-n', 0), SenseInfo('11433546-n', 0), SenseInfo('05622956-n', 0), SenseInfo('05033569-n', 0), SenseInfo('05203397-n', 15), SenseInfo('14530836-n', 9), SenseInfo('13779374-n', 6), SenseInfo('00914795-n', 3), SenseInfo('00720951-n', 1), SenseInfo('13755053-n', 0), SenseInfo('11433546-n', 0), SenseInfo('05622956-n', 0), SenseInfo('05033569-n', 0) ],
"_kayak_n_1_rel" : [ SenseInfo('03609235-n', 0) ],
"_go_n_1_rel" : [ SenseInfo('15292069-n', 0), SenseInfo('02678738-n', 0), SenseInfo('00787061-n', 0), SenseInfo('00504325-n', 0) ],
"_bid_v_1_rel" : [ SenseInfo('02298632-v', 6), SenseInfo('00902932-v', 3), SenseInfo('00759657-v', 3), SenseInfo('02300060-v', 1), SenseInfo('02240674-v', 1), SenseInfo('00793580-v', 1), SenseInfo('02298632-v', 6), SenseInfo('00902932-v', 3), SenseInfo('00759657-v', 3), SenseInfo('02300060-v', 1), SenseInfo('02240674-v', 1), SenseInfo('00793580-v', 1), SenseInfo('02298632-v', 6), SenseInfo('00902932-v', 3), SenseInfo('00759657-v', 3), SenseInfo('02300060-v', 1), SenseInfo('02240674-v', 1), SenseInfo('00793580-v', 1) ],
"_incoming_a_1_rel" : [ SenseInfo('01294300-a', 1), SenseInfo('01294051-a', 0) ],
"_destitute_a_1_rel" : [ SenseInfo('02023430-a', 0), SenseInfo('00927978-a', 0) ],
"_boatload_n_1_rel" : [ SenseInfo('13775523-n', 1) ],
"_perk_v_1_rel" : [ SenseInfo('00023473-v', 0) ],
"_circus_n_1_rel" : [ SenseInfo('08189211-n', 2), SenseInfo('00519739-n', 2), SenseInfo('00552679-n', 1), SenseInfo('03035089-n', 0), SenseInfo('03034860-n', 0), SenseInfo('01609549-n', 0) ],
"_waveguide_n_1_rel" : [ SenseInfo('04564413-n', 0) ],
"_flip_v_up_rel" : [ SenseInfo('01893079-v', 3), SenseInfo('01510173-v', 1), SenseInfo('02153023-v', 0), SenseInfo('01893601-v', 0), SenseInfo('01893465-v', 0), SenseInfo('01512625-v', 0), SenseInfo('01241614-v', 0), SenseInfo('01222958-v', 0), SenseInfo('00717921-v', 0), SenseInfo('00584810-v', 0), SenseInfo('00121678-v', 0) ],
"_delete_v_1_rel" : [ SenseInfo('01549187-v', 0), SenseInfo('00999815-v', 0), SenseInfo('00200863-v', 0), SenseInfo('01549187-v', 0), SenseInfo('00999815-v', 0), SenseInfo('00200863-v', 0) ],
"_macadamize_v_1_rel" : [ SenseInfo('01603418-v', 0) ],
"_asset_n_1_rel" : [ SenseInfo('05154517-n', 1), SenseInfo('05154517-n', 1), SenseInfo('05154517-n', 1) ],
"_miry_a_1_rel" : [ SenseInfo('02548066-a', 0) ],
"_leek_n_1_rel" : [ SenseInfo('12434239-n', 0), SenseInfo('07723039-n', 0) ],
"_chechen_n_1_rel" : [ SenseInfo('09912907-n', 0), SenseInfo('06978422-n', 0) ],
"_poison_n_1_rel" : [ SenseInfo('15032376-n', 4), SenseInfo('05166397-n', 1) ],
"_vending+machine_n_1_rel" : [ SenseInfo('04525305-n', 4) ],
"_loaf_v_1_rel" : [ SenseInfo('02639606-v', 1), SenseInfo('02639075-v', 0) ],
"_subjunctive_n_1_rel" : [ SenseInfo('13801937-n', 0) ],
"_permissible_a_1_rel" : [ SenseInfo('01760944-a', 0), SenseInfo('01762404-a', 0) ],
"_earthly_a_1_rel" : [ SenseInfo('01180695-a', 0) ],
"_headphone_n_1_rel" : [ SenseInfo('03261776-n', 0) ],
"_hood_n_1_rel" : [ SenseInfo('10184081-n', 1), SenseInfo('09305358-n', 0), SenseInfo('08225334-n', 0), SenseInfo('03531808-n', 0), SenseInfo('03531691-n', 0), SenseInfo('03531546-n', 0), SenseInfo('03531447-n', 0), SenseInfo('03531281-n', 0), SenseInfo('03530910-n', 0), SenseInfo('01748100-n', 0) ],
"_variable_a_1_rel" : [ SenseInfo('02504131-a', 6), SenseInfo('02507515-a', 2), SenseInfo('01028796-a', 1), SenseInfo('02504131-a', 6), SenseInfo('02507515-a', 2), SenseInfo('01028796-a', 1) ],
"_knock_n_1_rel" : [ SenseInfo('07386370-n', 2), SenseInfo('05734381-n', 1), SenseInfo('07410207-n', 0), SenseInfo('07336999-n', 0), SenseInfo('00133338-n', 0) ],
"_salvadoran_n_1_rel" : [ SenseInfo('09700823-n', 0) ],
"_resume_n_1_rel" : [ SenseInfo('06469694-n', 4), SenseInfo('06468403-n', 0) ],
"_recission_n_1_rel" : [ SenseInfo('00232863-n', 0) ],
"_tabletop_n_1_rel" : [ SenseInfo('04381860-n', 1) ],
"_apply_v_to_rel" : [ SenseInfo('01158872-v', 45), SenseInfo('02676789-v', 29), SenseInfo('00765396-v', 13), SenseInfo('01363648-v', 11), SenseInfo('02707429-v', 4), SenseInfo('02309165-v', 2), SenseInfo('02561332-v', 1), SenseInfo('02560164-v', 1), SenseInfo('01026558-v', 1), SenseInfo('02595523-v', 0), SenseInfo('01158872-v', 45), SenseInfo('02676789-v', 29), SenseInfo('00765396-v', 13), SenseInfo('01363648-v', 11), SenseInfo('02707429-v', 4), SenseInfo('02309165-v', 2), SenseInfo('02561332-v', 1), SenseInfo('02560164-v', 1), SenseInfo('01026558-v', 1), SenseInfo('02595523-v', 0), SenseInfo('01158872-v', 45), SenseInfo('02676789-v', 29), SenseInfo('00765396-v', 13), SenseInfo('01363648-v', 11), SenseInfo('02707429-v', 4), SenseInfo('02309165-v', 2), SenseInfo('02561332-v', 1), SenseInfo('02560164-v', 1), SenseInfo('01026558-v', 1), SenseInfo('02595523-v', 0) ],
"_navigable_a_1_rel" : [ SenseInfo('01724743-a', 0) ],
"_preservation_n_of_rel" : [ SenseInfo('00819024-n', 1), SenseInfo('14578940-n', 0), SenseInfo('13540610-n', 0), SenseInfo('07419599-n', 0) ],
"_uphold_v_1_rel" : [ SenseInfo('02679899-v', 7), SenseInfo('00896017-v', 5), SenseInfo('00896497-v', 4) ],
"_forget_v_about_rel" : [ SenseInfo('00610167-v', 61), SenseInfo('00609100-v', 21), SenseInfo('00614829-v', 9), SenseInfo('00613018-v', 0) ],
"_data_n_1_rel" : [ SenseInfo('08462320-n', 76), SenseInfo('08462320-n', 76) ],
"_expectant_a_1_rel" : [ SenseInfo('01228797-a', 3), SenseInfo('00173391-a', 0) ],
"_chop_v_out_rel" : [ SenseInfo('01258091-v', 2), SenseInfo('01871471-v', 0), SenseInfo('01758410-v', 0), SenseInfo('01415454-v', 0), SenseInfo('01257173-v', 0), SenseInfo('01124535-v', 0) ],
"_charger_n_of_rel" : [ SenseInfo('02378625-n', 3), SenseInfo('03008976-n', 0) ],
"_bosnian_a_1_rel" : [ SenseInfo('02964629-a', 0) ],
"_split_v_up_rel" : [ SenseInfo('02467662-v', 4), SenseInfo('01556572-v', 3), SenseInfo('02431320-v', 2), SenseInfo('02030158-v', 2), SenseInfo('00309310-v', 2), SenseInfo('02467662-v', 4), SenseInfo('01556572-v', 3), SenseInfo('02431320-v', 2), SenseInfo('02030158-v', 2), SenseInfo('00309310-v', 2) ],
"_immigrant_n_1_rel" : [ SenseInfo('10199489-n', 5) ],
"_excel_v_1_rel" : [ SenseInfo('02673965-v', 2) ],
"_creative_a_1_rel" : [ SenseInfo('00643250-a', 13), SenseInfo('00585202-a', 3) ],
"_infrastructure_n_1_rel" : [ SenseInfo('03570372-n', 0), SenseInfo('03569964-n', 0), SenseInfo('03570372-n', 0), SenseInfo('03569964-n', 0) ],
"_bellringer_n_1_rel" : [  ],
"_reconnaissance_n_1_rel" : [ SenseInfo('00984609-n', 0) ],
"_fly_v_over_rel" : [ SenseInfo('01940403-v', 33), SenseInfo('01842068-v', 9), SenseInfo('01941093-v', 5), SenseInfo('01451842-v', 3), SenseInfo('01848058-v', 2), SenseInfo('01839404-v', 2), SenseInfo('00545292-v', 2), SenseInfo('02073065-v', 1), SenseInfo('01840238-v', 1), SenseInfo('02140965-v', 0), SenseInfo('02075462-v', 0), SenseInfo('01847845-v', 0), SenseInfo('01402765-v', 0), SenseInfo('00153061-v', 0) ],
"_flagellation_n_1_rel" : [ SenseInfo('01163316-n', 0), SenseInfo('01163047-n', 0) ],
"_upstream_a_1_rel" : [ SenseInfo('02494401-a', 1), SenseInfo('02494401-a', 1) ],
"_hell_n_1_rel" : [ SenseInfo('08582837-n', 6), SenseInfo('07305907-n', 0), SenseInfo('05629682-n', 0), SenseInfo('05629381-n', 0), SenseInfo('01260731-n', 0), SenseInfo('00736786-n', 0) ],
"_legging_n_1_rel" : [ SenseInfo('03655072-n', 0) ],
"_by_p_means_rel" : [ SenseInfo('00417787-r', 2), SenseInfo('00233687-r', 0), SenseInfo('00417787-r', 2), SenseInfo('00233687-r', 0) ],
"_mips_n_1_rel" : [ SenseInfo('13607616-n', 0), SenseInfo('13607616-n', 0) ],
"_comment_v_on_rel" : [ SenseInfo('01058574-v', 23), SenseInfo('01033189-v', 1), SenseInfo('00961329-v', 0), SenseInfo('01058574-v', 23), SenseInfo('01033189-v', 1), SenseInfo('00961329-v', 0) ],
"_existence_n_1_rel" : [ SenseInfo('13954253-n', 51), SenseInfo('09466280-n', 1) ],
"_lifetime_n_of_rel" : [ SenseInfo('15140405-n', 2), SenseInfo('15140405-n', 2) ],
"_texture_v_1_rel" : [  ],
"_select_v_1_rel" : [ SenseInfo('00674607-v', 58), SenseInfo('00674607-v', 58) ],
"_recipient_n_of_rel" : [ SenseInfo('09627906-n', 2), SenseInfo('06333095-n', 0) ],
"_hacker_n_1_rel" : [ SenseInfo('10155140-n', 1), SenseInfo('10155222-n', 0), SenseInfo('10154871-n', 0), SenseInfo('10154601-n', 0) ],
"_neck-and-neck_a_1_rel" : [ SenseInfo('00551416-a', 0), SenseInfo('00551416-a', 0) ],
"_call_v_down_rel" : [ SenseInfo('01028748-v', 91), SenseInfo('00971015-v', 51), SenseInfo('00789448-v', 38), SenseInfo('00913065-v', 25), SenseInfo('00792471-v', 25), SenseInfo('02487573-v', 9), SenseInfo('02429810-v', 9), SenseInfo('01067995-v', 1), SenseInfo('01062739-v', 1), SenseInfo('00975036-v', 1), SenseInfo('02643421-v', 0), SenseInfo('02601456-v', 0), SenseInfo('02487901-v', 0), SenseInfo('02359061-v', 0), SenseInfo('02300060-v', 0), SenseInfo('01899017-v', 0), SenseInfo('01068793-v', 0), SenseInfo('00917772-v', 0), SenseInfo('00874002-v', 0), SenseInfo('00869393-v', 0), SenseInfo('00822746-v', 0), SenseInfo('00783523-v', 0), SenseInfo('00754156-v', 0), SenseInfo('00753881-v', 0), SenseInfo('00738747-v', 0), SenseInfo('00738583-v', 0), SenseInfo('00691516-v', 0), SenseInfo('00107231-v', 0) ],
"_suspect_v_of_rel" : [ SenseInfo('00921072-v', 6), SenseInfo('00687926-v', 2), SenseInfo('00924873-v', 1), SenseInfo('00921072-v', 6), SenseInfo('00687926-v', 2), SenseInfo('00924873-v', 1), SenseInfo('00921072-v', 6), SenseInfo('00687926-v', 2), SenseInfo('00924873-v', 1) ],
"_line_v_out_rel" : [ SenseInfo('02703539-v', 7), SenseInfo('01270784-v', 5), SenseInfo('01582645-v', 0), SenseInfo('01276361-v', 0), SenseInfo('00454135-v', 0), SenseInfo('00222993-v', 0), SenseInfo('02703539-v', 7), SenseInfo('01270784-v', 5), SenseInfo('01582645-v', 0), SenseInfo('01276361-v', 0), SenseInfo('00454135-v', 0), SenseInfo('00222993-v', 0) ],
"_bellow_n_1_rel" : [ SenseInfo('07121361-n', 2), SenseInfo('10843228-n', 0) ],
"_vietnamese_n_1_rel" : [ SenseInfo('09747191-n', 0), SenseInfo('06937229-n', 0), SenseInfo('09747191-n', 0), SenseInfo('06937229-n', 0), SenseInfo('09747191-n', 0), SenseInfo('06937229-n', 0) ],
"_toe_n_1_rel" : [ SenseInfo('05577410-n', 13), SenseInfo('04444218-n', 2), SenseInfo('05577654-n', 0), SenseInfo('04444345-n', 0) ],
"_dub_v_as_rel" : [ SenseInfo('01028640-v', 2), SenseInfo('00960562-v', 1), SenseInfo('02399185-v', 0), SenseInfo('01028640-v', 2), SenseInfo('00960562-v', 1), SenseInfo('02399185-v', 0) ],
"_rube_n_1_rel" : [ SenseInfo('10804102-n', 0) ],
"_stern_a_1_rel" : [ SenseInfo('01300187-a', 5), SenseInfo('01785341-a', 2), SenseInfo('00711308-a', 2), SenseInfo('01792387-a', 0), SenseInfo('01300187-a', 5), SenseInfo('01785341-a', 2), SenseInfo('00711308-a', 2), SenseInfo('01792387-a', 0), SenseInfo('01300187-a', 5), SenseInfo('01785341-a', 2), SenseInfo('00711308-a', 2), SenseInfo('01792387-a', 0) ],
"_future_a_1_rel" : [ SenseInfo('01732270-a', 12), SenseInfo('01884353-a', 4), SenseInfo('01294975-a', 3), SenseInfo('02992914-a', 0) ],
"_axle_n_1_rel" : [ SenseInfo('02764779-n', 1) ],
"_paint_n_1_rel" : [ SenseInfo('03875218-n', 7), SenseInfo('08590909-n', 0), SenseInfo('04112752-n', 0) ],
"_exact_v_1_rel" : [ SenseInfo('01017826-v', 1), SenseInfo('00756076-v', 0) ],
"_countervail_v_1_rel" : [ SenseInfo('02718015-v', 0), SenseInfo('02543874-v', 0) ],
"_squish_v_1_rel" : [ SenseInfo('01921591-v', 0), SenseInfo('01613589-v', 0) ],
"_skirt_n_1_rel" : [ SenseInfo('04231272-n', 4), SenseInfo('04230808-n', 2), SenseInfo('13095348-n', 0), SenseInfo('09989045-n', 0) ],
"_memory_n_of_rel" : [ SenseInfo('05935060-n', 25), SenseInfo('05760202-n', 15), SenseInfo('05651399-n', 9), SenseInfo('03744276-n', 3), SenseInfo('06140268-n', 0) ],
"_vcr_n_1_rel" : [ SenseInfo('04533802-n', 0) ],
"_present_v_to_rel" : [ SenseInfo('02148788-v', 40), SenseInfo('00772967-v', 28), SenseInfo('01711445-v', 14), SenseInfo('02262752-v', 13), SenseInfo('02722663-v', 7), SenseInfo('02261888-v', 3), SenseInfo('02200686-v', 3), SenseInfo('00989602-v', 3), SenseInfo('00901103-v', 2), SenseInfo('01688771-v', 1), SenseInfo('01066433-v', 0), SenseInfo('00901651-v', 0), SenseInfo('00899956-v', 0) ],
"_in+situ_a_2_rel" : [ SenseInfo('00353604-a', 0) ],
"_crackle_v_1_rel" : [ SenseInfo('02175384-v', 2), SenseInfo('01058224-v', 1), SenseInfo('00122648-v', 1) ],
"_cure_v_of_rel" : [ SenseInfo('00081725-v', 12), SenseInfo('00527572-v', 1), SenseInfo('00527935-v', 0), SenseInfo('00527801-v', 0), SenseInfo('00081725-v', 12), SenseInfo('00527572-v', 1), SenseInfo('00527935-v', 0), SenseInfo('00527801-v', 0) ],
"_justify_v_1_rel" : [ SenseInfo('00896803-v', 17), SenseInfo('00896141-v', 9), SenseInfo('00894738-v', 2), SenseInfo('00902424-v', 0), SenseInfo('00489699-v', 0), SenseInfo('00896803-v', 17), SenseInfo('00896141-v', 9), SenseInfo('00894738-v', 2), SenseInfo('00902424-v', 0), SenseInfo('00489699-v', 0) ],
"_hold_v_in_rel" : [ SenseInfo('02681795-v', 79), SenseInfo('01216670-v', 65), SenseInfo('01733477-v', 62), SenseInfo('02203362-v', 26), SenseInfo('00693780-v', 20), SenseInfo('01773130-v', 17), SenseInfo('01301410-v', 17), SenseInfo('02283324-v', 14), SenseInfo('02302220-v', 9), SenseInfo('01217043-v', 9), SenseInfo('02700867-v', 7), SenseInfo('02732798-v', 3), SenseInfo('02683489-v', 3), SenseInfo('01601234-v', 3), SenseInfo('02648502-v', 2), SenseInfo('00683771-v', 2), SenseInfo('02746275-v', 1), SenseInfo('02701210-v', 1), SenseInfo('02498320-v', 1), SenseInfo('01129876-v', 1), SenseInfo('00885217-v', 1), SenseInfo('00736586-v', 1), SenseInfo('00607000-v', 1), SenseInfo('02706816-v', 0), SenseInfo('02676789-v', 0), SenseInfo('02643574-v', 0), SenseInfo('02510337-v', 0), SenseInfo('02450989-v', 0), SenseInfo('02441897-v', 0), SenseInfo('01859586-v', 0), SenseInfo('01334744-v', 0), SenseInfo('01205153-v', 0), SenseInfo('01151753-v', 0), SenseInfo('00822367-v', 0), SenseInfo('00805376-v', 0), SenseInfo('00004492-v', 0) ],
"_extraordinary_a_to_rel" : [ SenseInfo('01675190-a', 12), SenseInfo('01534648-a', 2), SenseInfo('00490650-a', 1), SenseInfo('01675190-a', 12), SenseInfo('01534648-a', 2), SenseInfo('00490650-a', 1), SenseInfo('01675190-a', 12), SenseInfo('01534648-a', 2), SenseInfo('00490650-a', 1) ],
"_angle_v_2_rel" : [ SenseInfo('02044866-v', 2), SenseInfo('02038357-v', 0), SenseInfo('01319346-v', 0), SenseInfo('01141612-v', 0), SenseInfo('00680485-v', 0) ],
"_sill_n_1_rel" : [ SenseInfo('04220036-n', 2), SenseInfo('09435232-n', 0) ],
"_presbyterian_a_1_rel" : [ SenseInfo('10465922-n', 1) ],
"_guess+what_a_1_rel" : [  ],
"_threefold_a_1_rel" : [ SenseInfo('02218834-a', 0), SenseInfo('02217799-a', 0), SenseInfo('02218834-a', 0), SenseInfo('02217799-a', 0) ],
"_do_v_in_rel" : [ SenseInfo('02560585-v', 526), SenseInfo('01712704-v', 173), SenseInfo('02561995-v', 134), SenseInfo('02617567-v', 58), SenseInfo('01645601-v', 35), SenseInfo('02568672-v', 20), SenseInfo('02669789-v', 11), SenseInfo('01619014-v', 9), SenseInfo('00010435-v', 3), SenseInfo('02709107-v', 2), SenseInfo('02523221-v', 2), SenseInfo('00038849-v', 2), SenseInfo('01841772-v', 1) ],
"_scarce_a_1_rel" : [ SenseInfo('00016756-a', 0), SenseInfo('00016756-a', 0), SenseInfo('00016756-a', 0), SenseInfo('00016756-a', 0), SenseInfo('00016756-a', 0) ],
"_layout_n_of_rel" : [ SenseInfo('05837271-n', 1), SenseInfo('01010901-n', 1) ],
"_trapdoor_n_1_rel" : [  ],
"_belle_n_1_rel" : [ SenseInfo('09849012-n', 1) ],
"_martial_a_1_rel" : [ SenseInfo('01518694-a', 1), SenseInfo('01518860-a', 0), SenseInfo('01517526-a', 0) ],
"_round_a_1_rel" : [ SenseInfo('02040652-a', 12), SenseInfo('01457486-a', 1), SenseInfo('00916524-a', 1), SenseInfo('02040652-a', 12), SenseInfo('01457486-a', 1), SenseInfo('00916524-a', 1), SenseInfo('02040652-a', 12), SenseInfo('01457486-a', 1), SenseInfo('00916524-a', 1) ],
"_spare_a_1_rel" : [ SenseInfo('00991301-a', 3), SenseInfo('01581305-a', 1), SenseInfo('01624115-a', 0), SenseInfo('01582306-a', 0), SenseInfo('00106821-a', 0), SenseInfo('00060605-a', 0) ],
"_ring_v_2_rel" : [ SenseInfo('02180898-v', 15), SenseInfo('02183787-v', 7), SenseInfo('02181538-v', 5), SenseInfo('00789448-v', 1), SenseInfo('01467370-v', 0), SenseInfo('01297401-v', 0) ],
"_gasp_v_out_rel" : [ SenseInfo('00005526-v', 9) ],
"_ministry_n_1_rel" : [ SenseInfo('08113797-n', 1), SenseInfo('03770316-n', 1), SenseInfo('08114004-n', 0), SenseInfo('00314271-n', 0) ],
"_reiteration_n_of_rel" : [ SenseInfo('01019372-n', 0), SenseInfo('01019372-n', 0) ],
"_24/7_a_1_rel" : [ SenseInfo('15118011-n', 0), SenseInfo('15118011-n', 0) ],
"_look_v_up-to_rel" : [ SenseInfo('02130524-v', 274), SenseInfo('02133435-v', 126), SenseInfo('00033599-v', 25), SenseInfo('02153709-v', 8), SenseInfo('02693319-v', 1), SenseInfo('02549581-v', 1), SenseInfo('00929362-v', 1), SenseInfo('00720063-v', 1), SenseInfo('02658447-v', 0), SenseInfo('00712708-v', 0), SenseInfo('02130524-v', 274), SenseInfo('02133435-v', 126), SenseInfo('00033599-v', 25), SenseInfo('02153709-v', 8), SenseInfo('02693319-v', 1), SenseInfo('02549581-v', 1), SenseInfo('00929362-v', 1), SenseInfo('00720063-v', 1), SenseInfo('02658447-v', 0), SenseInfo('00712708-v', 0) ],
"_about_a_1_rel" : [ SenseInfo('00032358-a', 0), SenseInfo('00032358-a', 0) ],
"_self-confidence_n_1_rel" : [ SenseInfo('05697363-n', 3) ],
"_forecast_n_1_rel" : [ SenseInfo('06749881-n', 1), SenseInfo('06749881-n', 1) ],
"_help_v_but_rel" : [ SenseInfo('02547586-v', 183), SenseInfo('00082081-v', 23), SenseInfo('02735897-v', 19), SenseInfo('02726164-v', 5), SenseInfo('01181295-v', 2), SenseInfo('02555434-v', 0), SenseInfo('01193569-v', 0), SenseInfo('00206998-v', 0) ],
"_cost_v_1_rel" : [ SenseInfo('02702508-v', 35), SenseInfo('02628961-v', 16), SenseInfo('02702508-v', 35), SenseInfo('02628961-v', 16) ],
"_pecuniary_a_1_rel" : [ SenseInfo('02775934-a', 0) ],
"_lazy_n_1_rel" : [ SenseInfo('00981304-a', 4), SenseInfo('00294579-a', 2) ],
"_telecommunications_n_1_rel" : [ SenseInfo('06271778-n', 0), SenseInfo('06128307-n', 0) ],
"_senatorial_a_1_rel" : [ SenseInfo('02796301-a', 1) ],
"_interloping_a_1_rel" : [  ],
"_ethnicity_n_1_rel" : [ SenseInfo('04799133-n', 0) ],
"_if+you+want_a_1_rel" : [  ],
"_bedewed_a_1_rel" : [ SenseInfo('02547862-a', 0) ],
"_compare_v_with_rel" : [ SenseInfo('00652900-v', 57), SenseInfo('02729632-v', 12), SenseInfo('00653620-v', 9), SenseInfo('00982779-v', 0), SenseInfo('00652900-v', 57), SenseInfo('02729632-v', 12), SenseInfo('00653620-v', 9), SenseInfo('00982779-v', 0) ],
"_grumble_v_1_rel" : [ SenseInfo('00909573-v', 5), SenseInfo('00909219-v', 3), SenseInfo('01045719-v', 1), SenseInfo('02187320-v', 0), SenseInfo('00909573-v', 5), SenseInfo('00909219-v', 3), SenseInfo('01045719-v', 1), SenseInfo('02187320-v', 0) ],
"_procedural_a_1_rel" : [ SenseInfo('03103198-a', 4), SenseInfo('00055340-a', 0) ],
"_exit_v_1_rel" : [ SenseInfo('02015598-v', 0), SenseInfo('01078689-v', 0), SenseInfo('00358431-v', 0) ],
"_serration_n_1_rel" : [ SenseInfo('14568621-n', 0), SenseInfo('08431600-n', 0), SenseInfo('04174705-n', 0) ],
"_upkeep_n_1_rel" : [ SenseInfo('00267522-n', 2), SenseInfo('01216191-n', 0) ],
"_lead_v_on_rel" : [ SenseInfo('01999798-v', 40), SenseInfo('02635659-v', 35), SenseInfo('02635956-v', 27), SenseInfo('01999423-v', 17), SenseInfo('00771632-v', 17), SenseInfo('02685951-v', 13), SenseInfo('02440244-v', 13), SenseInfo('02687385-v', 10), SenseInfo('02555908-v', 9), SenseInfo('01732921-v', 8), SenseInfo('02686471-v', 5), SenseInfo('01999218-v', 2), SenseInfo('02686625-v', 1), SenseInfo('00813790-v', 0), SenseInfo('01999798-v', 40), SenseInfo('02635659-v', 35), SenseInfo('02635956-v', 27), SenseInfo('01999423-v', 17), SenseInfo('00771632-v', 17), SenseInfo('02685951-v', 13), SenseInfo('02440244-v', 13), SenseInfo('02687385-v', 10), SenseInfo('02555908-v', 9), SenseInfo('01732921-v', 8), SenseInfo('02686471-v', 5), SenseInfo('01999218-v', 2), SenseInfo('02686625-v', 1), SenseInfo('00813790-v', 0) ],
"_wield_v_1_rel" : [ SenseInfo('02204564-v', 3), SenseInfo('01224415-v', 2) ],
"_button_v_up_rel" : [ SenseInfo('01368126-v', 0), SenseInfo('01367862-v', 0), SenseInfo('01368126-v', 0), SenseInfo('01367862-v', 0) ],
"_fretting_n_1_rel" : [  ],
"_educational_a_1_rel" : [ SenseInfo('02946221-a', 6), SenseInfo('01324565-a', 4) ],
"_disintegrate_v_1_rel" : [ SenseInfo('00397576-v', 2), SenseInfo('00399368-v', 0), SenseInfo('00399074-v', 0) ],
"_stare_v_down_rel" : [ SenseInfo('02132745-v', 82), SenseInfo('00033406-v', 4) ],
"_plastic_n_1_rel" : [ SenseInfo('14592610-n', 2), SenseInfo('13376012-n', 0), SenseInfo('14592610-n', 2), SenseInfo('13376012-n', 0) ],
"_awkward_a_1_rel" : [ SenseInfo('00605406-a', 6), SenseInfo('01140514-a', 2), SenseInfo('02564023-a', 1), SenseInfo('01001180-a', 0), SenseInfo('00746047-a', 0), SenseInfo('00480439-a', 0), SenseInfo('00605406-a', 6), SenseInfo('01140514-a', 2), SenseInfo('02564023-a', 1), SenseInfo('01001180-a', 0), SenseInfo('00746047-a', 0), SenseInfo('00480439-a', 0) ],
"_desirable_a_to-for_rel" : [ SenseInfo('00732960-a', 16), SenseInfo('00852197-a', 0), SenseInfo('00732960-a', 16), SenseInfo('00852197-a', 0), SenseInfo('00732960-a', 16), SenseInfo('00852197-a', 0) ],
"_resentment_n_of_rel" : [ SenseInfo('07548978-n', 6), SenseInfo('07548978-n', 6) ],
"_bipedal_a_1_rel" : [ SenseInfo('00241672-a', 0) ],
"_square_v_1_rel" : [ SenseInfo('00145448-v', 4), SenseInfo('00640136-v', 2), SenseInfo('02659656-v', 1), SenseInfo('01987493-v', 1), SenseInfo('02659541-v', 0), SenseInfo('02253341-v', 0), SenseInfo('01124964-v', 0), SenseInfo('01124828-v', 0) ],
"_aesthetic_n_1_rel" : [ SenseInfo('05968971-n', 0) ],
"_bend_n_1_rel" : [ SenseInfo('13869327-n', 1), SenseInfo('07310991-n', 1), SenseInfo('02829696-n', 1), SenseInfo('13907415-n', 0), SenseInfo('09133364-n', 0), SenseInfo('02830013-n', 0) ],
"_discontinue_v_1_rel" : [ SenseInfo('02680814-v', 4), SenseInfo('02683840-v', 2), SenseInfo('00362348-v', 0), SenseInfo('02680814-v', 4), SenseInfo('02683840-v', 2), SenseInfo('00362348-v', 0) ],
"_countless_a_1_rel" : [ SenseInfo('00301951-a', 5) ],
"_aboveground_p_rel" : [ SenseInfo('02471264-a', 1) ],
"_circuit_n_1_rel" : [ SenseInfo('03033362-n', 4), SenseInfo('00310666-n', 3), SenseInfo('08616985-n', 0), SenseInfo('08514592-n', 0), SenseInfo('08330514-n', 0), SenseInfo('04038109-n', 0), SenseInfo('00295172-n', 0) ],
"_almost_x_deg_rel" : [ SenseInfo('00073033-r', 175), SenseInfo('00073033-r', 175) ],
"_partial_a_1_rel" : [ SenseInfo('00524693-a', 5), SenseInfo('01722965-a', 1), SenseInfo('01292683-a', 0), SenseInfo('00524693-a', 5), SenseInfo('01722965-a', 1), SenseInfo('01292683-a', 0) ],
"_each+and+every_q_rel" : [  ],
"_lonely_a_1_rel" : [ SenseInfo('02251212-a', 4), SenseInfo('00704360-a', 4), SenseInfo('02250430-a', 0), SenseInfo('01313649-a', 0), SenseInfo('02251212-a', 4), SenseInfo('00704360-a', 4), SenseInfo('02250430-a', 0), SenseInfo('01313649-a', 0), SenseInfo('02251212-a', 4), SenseInfo('00704360-a', 4), SenseInfo('02250430-a', 0), SenseInfo('01313649-a', 0) ],
"_versify_v_1_rel" : [ SenseInfo('01702514-v', 0) ],
"_bonsai_n_1_rel" : [ SenseInfo('13111881-n', 0) ],
"_homogeneous_a_of_rel" : [ SenseInfo('01199751-a', 7) ],
"_seize_v_up_rel" : [ SenseInfo('01212572-v', 13), SenseInfo('01213614-v', 5), SenseInfo('02272549-v', 4), SenseInfo('02273293-v', 3), SenseInfo('02274482-v', 0), SenseInfo('01365839-v', 0), SenseInfo('00737656-v', 0), SenseInfo('00737476-v', 0) ],
"_maturity_n_1_rel" : [ SenseInfo('15152817-n', 16), SenseInfo('14424780-n', 11), SenseInfo('15153225-n', 1) ],
"_round_v_down_rel" : [ SenseInfo('01858910-v', 3), SenseInfo('00145147-v', 1), SenseInfo('00980339-v', 0), SenseInfo('00862683-v', 0), SenseInfo('00473799-v', 0), SenseInfo('00145623-v', 0), SenseInfo('00046382-v', 0) ],
"_imitation_n_of_rel" : [ SenseInfo('05962602-n', 11), SenseInfo('03562126-n', 4), SenseInfo('01020936-n', 4), SenseInfo('06780069-n', 0) ],
"_aardvark_n_1_rel" : [ SenseInfo('02082791-n', 0) ],
"_knot_n_1_rel" : [ SenseInfo('07960384-n', 2), SenseInfo('03627232-n', 2), SenseInfo('15102712-n', 1), SenseInfo('13885836-n', 0), SenseInfo('13660337-n', 0), SenseInfo('04948905-n', 0), SenseInfo('02028900-n', 0), SenseInfo('07960384-n', 2), SenseInfo('03627232-n', 2), SenseInfo('15102712-n', 1), SenseInfo('13885836-n', 0), SenseInfo('13660337-n', 0), SenseInfo('04948905-n', 0), SenseInfo('02028900-n', 0) ],
"_cover_v_over_rel" : [ SenseInfo('01332730-v', 35), SenseInfo('01207951-v', 19), SenseInfo('02687916-v', 18), SenseInfo('02675935-v', 16), SenseInfo('01033527-v', 14), SenseInfo('02629793-v', 10), SenseInfo('01912159-v', 4), SenseInfo('00967098-v', 3), SenseInfo('01129201-v', 2), SenseInfo('02395000-v', 1), SenseInfo('02148369-v', 1), SenseInfo('01148296-v', 1), SenseInfo('00967455-v', 1), SenseInfo('00891216-v', 1), SenseInfo('02672859-v', 0), SenseInfo('02474446-v', 0), SenseInfo('02395194-v', 0), SenseInfo('02310674-v', 0), SenseInfo('02147109-v', 0), SenseInfo('01582200-v', 0), SenseInfo('01430447-v', 0), SenseInfo('01336635-v', 0), SenseInfo('01150010-v', 0), SenseInfo('01148580-v', 0), SenseInfo('00060185-v', 0), SenseInfo('00048633-v', 0) ],
"_switch_v_from-to_rel" : [ SenseInfo('00140751-v', 5), SenseInfo('02259005-v', 3), SenseInfo('00550117-v', 2), SenseInfo('00380159-v', 1), SenseInfo('01510173-v', 0), SenseInfo('01411630-v', 0), SenseInfo('00121678-v', 0) ],
"_broiler_n_1_rel" : [ SenseInfo('02905036-n', 1), SenseInfo('07645242-n', 0) ],
"temp_rel" : [  ],
"_innocent_n_1_rel" : [ SenseInfo('09621359-n', 0) ],
"_clipping_n_1_rel" : [ SenseInfo('06612649-n', 0), SenseInfo('00359903-n', 0), SenseInfo('00359614-n', 0) ],
"_glare_n_1_rel" : [ SenseInfo('04952570-n', 5), SenseInfo('00878797-n', 1), SenseInfo('14433769-n', 0) ],
"_fedora_n_1_rel" : [ SenseInfo('03325941-n', 1) ],
"_algae_n_1_rel" : [ SenseInfo('01397114-n', 6) ],
"_eyes+busy_a_1_rel" : [  ],
"_pause_v_1_rel" : [ SenseInfo('02641035-v', 23), SenseInfo('00779061-v', 12) ],
"_expensive_a_1_rel" : [ SenseInfo('00933154-a', 13), SenseInfo('00933154-a', 13) ],
"_salt_v_1_rel" : [ SenseInfo('02196214-v', 1), SenseInfo('01375120-v', 0), SenseInfo('00560122-v', 0), SenseInfo('00213353-v', 0) ],
"_sink_n_1_rel" : [ SenseInfo('04223580-n', 4), SenseInfo('13555915-n', 0), SenseInfo('09435739-n', 0), SenseInfo('02998563-n', 0) ],
"_righthand_a_1_rel" : [  ],
"_off-the-shelf_a_1_rel" : [ SenseInfo('00672932-a', 0), SenseInfo('00672932-a', 0) ],
"_conception_n_of_rel" : [ SenseInfo('05835747-n', 11), SenseInfo('00844847-n', 4), SenseInfo('07328942-n', 2), SenseInfo('05633385-n', 1), SenseInfo('05835747-n', 11), SenseInfo('00844847-n', 4), SenseInfo('07328942-n', 2), SenseInfo('05633385-n', 1), SenseInfo('05835747-n', 11), SenseInfo('00844847-n', 4), SenseInfo('07328942-n', 2), SenseInfo('05633385-n', 1), SenseInfo('05835747-n', 11), SenseInfo('00844847-n', 4), SenseInfo('07328942-n', 2), SenseInfo('05633385-n', 1) ],
"_i/o_n_1_rel" : [  ],
"_height_n_of_rel" : [ SenseInfo('05137165-n', 11), SenseInfo('13940456-n', 4), SenseInfo('05002352-n', 3), SenseInfo('05131647-n', 1), SenseInfo('05137165-n', 11), SenseInfo('13940456-n', 4), SenseInfo('05002352-n', 3), SenseInfo('05131647-n', 1) ],
"_shout_v_back_rel" : [ SenseInfo('00912473-v', 39), SenseInfo('00913065-v', 18), SenseInfo('00912048-v', 2), SenseInfo('00845299-v', 0) ],
"_affiliate_v_with_rel" : [ SenseInfo('02589245-v', 0), SenseInfo('02435311-v', 0), SenseInfo('02589245-v', 0), SenseInfo('02435311-v', 0), SenseInfo('02589245-v', 0), SenseInfo('02435311-v', 0) ],
"_exhilarate_v_1_rel" : [ SenseInfo('01812324-v', 0), SenseInfo('01812324-v', 0), SenseInfo('01812324-v', 0) ],
"_lodging_n_1_rel" : [ SenseInfo('03546340-n', 2), SenseInfo('04777634-n', 0), SenseInfo('01054227-n', 0) ],
"_lumber_v_1_rel" : [ SenseInfo('01925548-v', 1), SenseInfo('01258828-v', 0) ],
"_a+great+deal_x_deg_rel" : [ SenseInfo('00059171-r', 1), SenseInfo('00059413-r', 0) ],
"_barb_v_1_rel" : [ SenseInfo('01339181-v', 0) ],
"_actual_a_1_rel" : [ SenseInfo('00043765-a', 22), SenseInfo('01933520-a', 8), SenseInfo('02460964-a', 3), SenseInfo('01933731-a', 2), SenseInfo('00666610-a', 0), SenseInfo('00043765-a', 22), SenseInfo('01933520-a', 8), SenseInfo('02460964-a', 3), SenseInfo('01933731-a', 2), SenseInfo('00666610-a', 0), SenseInfo('00043765-a', 22), SenseInfo('01933520-a', 8), SenseInfo('02460964-a', 3), SenseInfo('01933731-a', 2), SenseInfo('00666610-a', 0) ],
"_iron_v_out_rel" : [ SenseInfo('01390833-v', 2) ],
"_repair_v_1_rel" : [ SenseInfo('00260648-v', 11), SenseInfo('02250625-v', 0), SenseInfo('01843497-v', 0), SenseInfo('00199912-v', 0), SenseInfo('00024279-v', 0) ],
"_cord_n_1_rel" : [ SenseInfo('03106110-n', 5), SenseInfo('13602401-n', 0), SenseInfo('03106898-n', 0), SenseInfo('03106722-n', 0) ],
"_yen_n_2_rel" : [ SenseInfo('07486922-n', 1), SenseInfo('13709700-n', 0) ],
"_vintage_n_1_rel" : [ SenseInfo('07892418-n', 1), SenseInfo('04926217-n', 0) ],
"_tetrahedron_n_1_rel" : [ SenseInfo('13915113-n', 0) ],
"_clarification_n_of_rel" : [ SenseInfo('07171206-n', 0), SenseInfo('00264192-n', 0), SenseInfo('07171206-n', 0), SenseInfo('00264192-n', 0) ],
"_automation_n_of_rel" : [ SenseInfo('00102457-n', 2), SenseInfo('14574504-n', 0), SenseInfo('02761206-n', 0) ],
"_iranian_n_1_rel" : [ SenseInfo('09714429-n', 0), SenseInfo('06973610-n', 0) ],
"_score_v_1_rel" : [ SenseInfo('01111816-v', 18), SenseInfo('01275762-v', 12), SenseInfo('01004062-v', 3), SenseInfo('01706488-v', 0), SenseInfo('01428578-v', 0), SenseInfo('01112364-v', 0), SenseInfo('00657728-v', 0) ],
"_dormer_n_1_rel" : [ SenseInfo('03224603-n', 0) ],
"_summon_v_forth_rel" : [ SenseInfo('00791134-v', 8), SenseInfo('01041762-v', 2), SenseInfo('01381549-v', 0), SenseInfo('00270215-v', 0) ],
"_respective_a_1_rel" : [ SenseInfo('00494409-a', 4), SenseInfo('00494409-a', 4), SenseInfo('00494409-a', 4) ],
"_compare_v_to_rel" : [ SenseInfo('00652900-v', 57), SenseInfo('02729632-v', 12), SenseInfo('00653620-v', 9), SenseInfo('00982779-v', 0) ],
"_uninterrupted_a_1_rel" : [ SenseInfo('00291338-a', 2), SenseInfo('00594413-a', 0), SenseInfo('00291338-a', 2), SenseInfo('00594413-a', 0) ],
"_chronicle_n_1_rel" : [ SenseInfo('06514093-n', 0) ],
"_gun_v_down_rel" : [ SenseInfo('01136614-v', 0) ],
"_analogy_n_1_rel" : [ SenseInfo('05780339-n', 2), SenseInfo('00651176-n', 2), SenseInfo('05942579-n', 0) ],
"_gear_v_to_rel" : [ SenseInfo('00298244-v', 3), SenseInfo('00298244-v', 3) ],
"_arrest_n_1_rel" : [ SenseInfo('00088725-n', 5), SenseInfo('14010927-n', 0) ],
"_motion_v_for_rel" : [ SenseInfo('00992041-v', 1), SenseInfo('00992041-v', 1), SenseInfo('00992041-v', 1) ],
"_off_p_sel_rel" : [ SenseInfo('00232936-r', 13), SenseInfo('00235254-r', 12), SenseInfo('00193194-r', 5), SenseInfo('01651469-a', 3), SenseInfo('02082924-a', 1), SenseInfo('01651896-a', 0), SenseInfo('02369869-a', 0), SenseInfo('00035254-a', 0), SenseInfo('02482425-v', 0) ],
"_right+side+up_a_1_rel" : [ SenseInfo('02468538-a', 0) ],
"_guilder_n_1_rel" : [ SenseInfo('13680146-n', 0), SenseInfo('13679855-n', 0) ],
"_preventative_a_1_rel" : [ SenseInfo('01763813-a', 0), SenseInfo('01167269-a', 0) ],
"_sweltering_a_1_rel" : [ SenseInfo('01250393-a', 1) ],
"_one-off_n_1_rel" : [ SenseInfo('07296083-n', 0), SenseInfo('07296083-n', 0) ],
"_chessboard_n_1_rel" : [ SenseInfo('03014317-n', 0) ],
"_latter_a_1_rel" : [ SenseInfo('01047561-a', 52) ],
"_tat_v_1_rel" : [ SenseInfo('01674544-v', 1) ],
"_such_q_rel" : [  ],
"_agree_v_upon_rel" : [ SenseInfo('00805376-v', 62), SenseInfo('00764222-v', 25), SenseInfo('02657219-v', 4), SenseInfo('02700104-v', 1), SenseInfo('02741793-v', 0), SenseInfo('02291135-v', 0), SenseInfo('01035530-v', 0) ],
"_maladroit_a_1_rel" : [ SenseInfo('00063277-a', 1) ],
"_flytrap_n_1_rel" : [ SenseInfo('03374570-n', 0) ],
"_well_n_1_rel" : [ SenseInfo('04572344-n', 8), SenseInfo('04572935-n', 1), SenseInfo('06675979-n', 0), SenseInfo('04572800-n', 0), SenseInfo('04572559-n', 0) ],
"_discrete_a_1_rel" : [ SenseInfo('02110778-a', 3) ],
"_ceremonial_n_1_rel" : [ SenseInfo('07450842-n', 0) ],
"_on_p_dir_rel" : [ SenseInfo('00068368-r', 40), SenseInfo('01651196-a', 6), SenseInfo('00069346-r', 2), SenseInfo('00069472-r', 1), SenseInfo('01651741-a', 0) ],
"_sewage_n_1_rel" : [ SenseInfo('14856893-n', 19) ],
"_bundle_n_1_rel" : [ SenseInfo('08008017-n', 4), SenseInfo('02919414-n', 4), SenseInfo('13250680-n', 0) ],
"_parallel_v_1_rel" : [ SenseInfo('02659222-v', 5), SenseInfo('00525281-v', 1), SenseInfo('02659358-v', 0), SenseInfo('02659222-v', 5), SenseInfo('00525281-v', 1), SenseInfo('02659358-v', 0), SenseInfo('02659222-v', 5), SenseInfo('00525281-v', 1), SenseInfo('02659358-v', 0) ],
"_struggle_v_1_rel" : [ SenseInfo('02407338-v', 13), SenseInfo('01505058-v', 7), SenseInfo('01921772-v', 3), SenseInfo('01090335-v', 2), SenseInfo('02407338-v', 13), SenseInfo('01505058-v', 7), SenseInfo('01921772-v', 3), SenseInfo('01090335-v', 2) ],
"_brook_v_1_rel" : [ SenseInfo('00668099-v', 1) ],
"_smile_v_at_rel" : [ SenseInfo('00028565-v', 79), SenseInfo('01067512-v', 0) ],
"_wash_v_out_rel" : [ SenseInfo('01270199-v', 13), SenseInfo('00036362-v', 9), SenseInfo('01535246-v', 7), SenseInfo('02098179-v', 2), SenseInfo('02742842-v', 0), SenseInfo('02703153-v', 0), SenseInfo('01536344-v', 0), SenseInfo('01269844-v', 0), SenseInfo('00557686-v', 0), SenseInfo('00274942-v', 0), SenseInfo('00217956-v', 0), SenseInfo('00217576-v', 0), SenseInfo('00036178-v', 0), SenseInfo('01270199-v', 13), SenseInfo('00036362-v', 9), SenseInfo('01535246-v', 7), SenseInfo('02098179-v', 2), SenseInfo('02742842-v', 0), SenseInfo('02703153-v', 0), SenseInfo('01536344-v', 0), SenseInfo('01269844-v', 0), SenseInfo('00557686-v', 0), SenseInfo('00274942-v', 0), SenseInfo('00217956-v', 0), SenseInfo('00217576-v', 0), SenseInfo('00036178-v', 0) ],
"_inch_v_up_rel" : [ SenseInfo('02072501-v', 1) ],
"_concessionaire_n_1_rel" : [ SenseInfo('09951717-n', 3) ],
"_fall_n_1_rel" : [ SenseInfo('15236859-n', 14), SenseInfo('00076884-n', 4), SenseInfo('07478531-n', 3), SenseInfo('09265620-n', 2), SenseInfo('00756919-n', 2), SenseInfo('07427728-n', 1), SenseInfo('07370270-n', 1), SenseInfo('00067707-n', 1), SenseInfo('15169421-n', 0), SenseInfo('07471371-n', 0), SenseInfo('07362386-n', 0), SenseInfo('05111835-n', 0) ],
"_get_v_in_rel" : [ SenseInfo('02210855-v', 235), SenseInfo('00149583-v', 157), SenseInfo('00120796-v', 82), SenseInfo('00522751-v', 64), SenseInfo('02005948-v', 58), SenseInfo('01433294-v', 45), SenseInfo('02108026-v', 36), SenseInfo('01153947-v', 14), SenseInfo('02355596-v', 9), SenseInfo('00770437-v', 7), SenseInfo('01215421-v', 4), SenseInfo('00094460-v', 4), SenseInfo('00087736-v', 4), SenseInfo('01066036-v', 3), SenseInfo('00120316-v', 3), SenseInfo('01026975-v', 2), SenseInfo('00589904-v', 2), SenseInfo('01505958-v', 1), SenseInfo('01401115-v', 1), SenseInfo('00639849-v', 1), SenseInfo('02359340-v', 0), SenseInfo('02208265-v', 0), SenseInfo('02189398-v', 0), SenseInfo('02109645-v', 0), SenseInfo('02108654-v', 0), SenseInfo('02010864-v', 0), SenseInfo('02006573-v', 0), SenseInfo('01771194-v', 0), SenseInfo('01771039-v', 0), SenseInfo('01738107-v', 0), SenseInfo('01643297-v', 0), SenseInfo('01565211-v', 0), SenseInfo('00622384-v', 0), SenseInfo('00345761-v', 0), SenseInfo('00065639-v', 0), SenseInfo('00054628-v', 0) ],
"_medium_n_1_rel" : [ SenseInfo('06254669-n', 5), SenseInfo('08568142-n', 4), SenseInfo('06254475-n', 2), SenseInfo('14899328-n', 1), SenseInfo('14899888-n', 0), SenseInfo('14899530-n', 0), SenseInfo('14899152-n', 0), SenseInfo('13920169-n', 0), SenseInfo('10306279-n', 0), SenseInfo('06261586-n', 0), SenseInfo('00610222-n', 0) ],
"_concur_v_1_rel" : [ SenseInfo('00805376-v', 5), SenseInfo('00345312-v', 1), SenseInfo('00805376-v', 5), SenseInfo('00345312-v', 1) ],
"_beneath_p_rel" : [ SenseInfo('00080039-r', 1), SenseInfo('00080039-r', 1), SenseInfo('00080039-r', 1) ],
"_identical_a_1_rel" : [ SenseInfo('02064127-a', 12), SenseInfo('02068946-a', 9), SenseInfo('00292448-a', 0), SenseInfo('01360962-a', 0), SenseInfo('00561896-a', 0) ],
"_notch_v_1_rel" : [ SenseInfo('01276970-v', 3), SenseInfo('01004550-v', 0) ],
"_spill_v_over_rel" : [ SenseInfo('01542207-v', 2), SenseInfo('02069888-v', 1), SenseInfo('01541579-v', 1), SenseInfo('01541803-v', 0), SenseInfo('00952841-v', 0), SenseInfo('00429642-v', 0) ],
"_finalist_n_1_rel" : [ SenseInfo('10089779-n', 0) ],
"_patent_n_1_rel" : [ SenseInfo('06501141-n', 5), SenseInfo('06551627-n', 0), SenseInfo('06501141-n', 5), SenseInfo('06551627-n', 0) ],
"_hold_v_still_rel" : [ SenseInfo('02681795-v', 79), SenseInfo('01216670-v', 65), SenseInfo('01733477-v', 62), SenseInfo('02203362-v', 26), SenseInfo('00693780-v', 20), SenseInfo('01773130-v', 17), SenseInfo('01301410-v', 17), SenseInfo('02283324-v', 14), SenseInfo('02302220-v', 9), SenseInfo('01217043-v', 9), SenseInfo('02700867-v', 7), SenseInfo('02732798-v', 3), SenseInfo('02683489-v', 3), SenseInfo('01601234-v', 3), SenseInfo('02648502-v', 2), SenseInfo('00683771-v', 2), SenseInfo('02746275-v', 1), SenseInfo('02701210-v', 1), SenseInfo('02498320-v', 1), SenseInfo('01129876-v', 1), SenseInfo('00885217-v', 1), SenseInfo('00736586-v', 1), SenseInfo('00607000-v', 1), SenseInfo('02706816-v', 0), SenseInfo('02676789-v', 0), SenseInfo('02643574-v', 0), SenseInfo('02510337-v', 0), SenseInfo('02450989-v', 0), SenseInfo('02441897-v', 0), SenseInfo('01859586-v', 0), SenseInfo('01334744-v', 0), SenseInfo('01205153-v', 0), SenseInfo('01151753-v', 0), SenseInfo('00822367-v', 0), SenseInfo('00805376-v', 0), SenseInfo('00004492-v', 0) ],
"_hierarchical_a_1_rel" : [ SenseInfo('01203288-a', 0) ],
"_petrify_v_1_rel" : [ SenseInfo('00192471-v', 1), SenseInfo('00507485-v', 0), SenseInfo('00418110-v', 0) ],
"_hag_n_1_rel" : [ SenseInfo('10155485-n', 0), SenseInfo('01478511-n', 0) ],
"_cork_n_1_rel" : [ SenseInfo('14823227-n', 1), SenseInfo('14823547-n', 0), SenseInfo('08889400-n', 0), SenseInfo('03108853-n', 0), SenseInfo('02860063-n', 0) ],
"_cultist_n_1_rel" : [ SenseInfo('09982370-n', 2), SenseInfo('09982525-n', 0) ],
"_errand_n_1_rel" : [ SenseInfo('00731947-n', 5) ],
"_arboretum_n_1_rel" : [ SenseInfo('02733075-n', 0), SenseInfo('02733075-n', 0) ],
"_apt_a_1_rel" : [ SenseInfo('01292411-a', 6), SenseInfo('01411919-a', 0), SenseInfo('01334958-a', 0), SenseInfo('00138314-a', 0), SenseInfo('01292411-a', 6), SenseInfo('01411919-a', 0), SenseInfo('01334958-a', 0), SenseInfo('00138314-a', 0), SenseInfo('01292411-a', 6), SenseInfo('01411919-a', 0), SenseInfo('01334958-a', 0), SenseInfo('00138314-a', 0) ],
"_liable_a_for_rel" : [ SenseInfo('01411919-a', 4), SenseInfo('02366365-a', 1), SenseInfo('02362178-a', 1), SenseInfo('01997583-a', 0) ],
"_tidepool_n_1_rel" : [  ],
"_twisty_a_1_rel" : [ SenseInfo('02313784-a', 0), SenseInfo('02313784-a', 0), SenseInfo('02313784-a', 0) ],
"_colonize_v_1_rel" : [ SenseInfo('02590340-v', 1), SenseInfo('00414174-v', 0) ],
"_comfort_n_1_rel" : [ SenseInfo('14445379-n', 5), SenseInfo('07492516-n', 5), SenseInfo('01211667-n', 4), SenseInfo('14491889-n', 0), SenseInfo('13987219-n', 0), SenseInfo('04033995-n', 0), SenseInfo('01211185-n', 0) ],
"_rake_v_1_rel" : [ SenseInfo('02099669-v', 1), SenseInfo('01307020-v', 1), SenseInfo('02688527-v', 0), SenseInfo('02152278-v', 0), SenseInfo('01306853-v', 0), SenseInfo('01240514-v', 0) ],
"_grandpa_n_1_rel" : [ SenseInfo('10142391-n', 0) ],
"_somehow+or+other_a_1_rel" : [  ],
"_NZ$_n_1_rel" : [  ],
"_salvation_n_of_rel" : [ SenseInfo('00094001-n', 10), SenseInfo('00179380-n', 1), SenseInfo('14539165-n', 0), SenseInfo('00096513-n', 0) ],
"_aristocratic_a_1_rel" : [ SenseInfo('01590484-a', 1) ],
"_tradewind_n_1_rel" : [  ],
"_brushlike_a_1_rel" : [ SenseInfo('00145706-a', 0) ],
"_relax_v_1_rel" : [ SenseInfo('00026385-v', 17), SenseInfo('00419685-v', 5), SenseInfo('00419137-v', 3), SenseInfo('00025654-v', 1), SenseInfo('02602212-v', 0), SenseInfo('02601996-v', 0), SenseInfo('02601808-v', 0), SenseInfo('00441212-v', 0), SenseInfo('00026385-v', 17), SenseInfo('00419685-v', 5), SenseInfo('00419137-v', 3), SenseInfo('00025654-v', 1), SenseInfo('02602212-v', 0), SenseInfo('02601996-v', 0), SenseInfo('02601808-v', 0), SenseInfo('00441212-v', 0), SenseInfo('00026385-v', 17), SenseInfo('00419685-v', 5), SenseInfo('00419137-v', 3), SenseInfo('00025654-v', 1), SenseInfo('02602212-v', 0), SenseInfo('02601996-v', 0), SenseInfo('02601808-v', 0), SenseInfo('00441212-v', 0) ],
"_buff_v_1_rel" : [ SenseInfo('01417578-v', 1), SenseInfo('01246095-v', 0) ],
"_glance_v_1_rel" : [ SenseInfo('02165304-v', 34), SenseInfo('01893000-v', 1) ],
"_check+in_a_1_rel" : [  ],
"_solemnity_n_1_rel" : [ SenseInfo('04647826-n', 1), SenseInfo('07512147-n', 0) ],
"_escalate_v_cause_rel" : [ SenseInfo('00290302-v', 0) ],
"_inflation_n_of_rel" : [ SenseInfo('13498828-n', 1), SenseInfo('07409255-n', 0), SenseInfo('04817923-n', 0), SenseInfo('00367280-n', 0) ],
"_day+long_a_1_rel" : [ SenseInfo('01439072-a', 0), SenseInfo('01439072-a', 0), SenseInfo('01439072-a', 0), SenseInfo('01439072-a', 0), SenseInfo('01439072-a', 0), SenseInfo('01439072-a', 0) ],
"_exert_v_1_rel" : [ SenseInfo('01166093-v', 12), SenseInfo('02204564-v', 7), SenseInfo('02371811-v', 1) ],
"_trail_n_1_rel" : [ SenseInfo('09460312-n', 5), SenseInfo('04466613-n', 4), SenseInfo('05826914-n', 1) ],
"_pack_v_up_rel" : [ SenseInfo('01482449-v', 11), SenseInfo('02086963-v', 2), SenseInfo('01483779-v', 2), SenseInfo('01451176-v', 2), SenseInfo('02396536-v', 1), SenseInfo('02717102-v', 0), SenseInfo('02064131-v', 0), SenseInfo('01926031-v', 0), SenseInfo('01574571-v', 0), SenseInfo('01484884-v', 0), SenseInfo('01484027-v', 0), SenseInfo('01483131-v', 0), SenseInfo('00108909-v', 0), SenseInfo('01482449-v', 11), SenseInfo('02086963-v', 2), SenseInfo('01483779-v', 2), SenseInfo('01451176-v', 2), SenseInfo('02396536-v', 1), SenseInfo('02717102-v', 0), SenseInfo('02064131-v', 0), SenseInfo('01926031-v', 0), SenseInfo('01574571-v', 0), SenseInfo('01484884-v', 0), SenseInfo('01484027-v', 0), SenseInfo('01483131-v', 0), SenseInfo('00108909-v', 0) ],
"_ritzy_a_1_rel" : [ SenseInfo('00850875-a', 0), SenseInfo('00850875-a', 0), SenseInfo('00850875-a', 0) ],
"_lose_v_by_rel" : [ SenseInfo('02287789-v', 123), SenseInfo('01099592-v', 17), SenseInfo('01795082-v', 10), SenseInfo('01503101-v', 7), SenseInfo('02287618-v', 6), SenseInfo('02197091-v', 4), SenseInfo('02288828-v', 3), SenseInfo('02288155-v', 2), SenseInfo('01113806-v', 2), SenseInfo('02127853-v', 1), SenseInfo('00204872-v', 0) ],
"_leakage_n_1_rel" : [ SenseInfo('07436661-n', 1) ],
"_indignity_n_1_rel" : [ SenseInfo('01225299-n', 1) ],
"_derail_v_1_rel" : [ SenseInfo('02012043-v', 0), SenseInfo('02011865-v', 0) ],
"_harebell_n_1_rel" : [ SenseInfo('12459275-n', 0), SenseInfo('12037328-n', 0) ],
"_ad_n_1_rel" : [ SenseInfo('07248801-n', 6) ],
"_lie_v_2_rel" : [ SenseInfo('02690708-v', 88), SenseInfo('01547001-v', 58), SenseInfo('02653381-v', 15), SenseInfo('02734338-v', 14), SenseInfo('00834259-v', 9), SenseInfo('02731390-v', 4), SenseInfo('01985029-v', 4), SenseInfo('02690708-v', 88), SenseInfo('01547001-v', 58), SenseInfo('02653381-v', 15), SenseInfo('02734338-v', 14), SenseInfo('00834259-v', 9), SenseInfo('02731390-v', 4), SenseInfo('01985029-v', 4) ],
"_swagger_v_1_rel" : [ SenseInfo('01916634-v', 2), SenseInfo('01035199-v', 0), SenseInfo('00012434-v', 0) ],
"_giraffe_n_1_rel" : [ SenseInfo('02439033-n', 0) ],
"_hoser_n_1_rel" : [  ],
"_wheat_n_1_rel" : [ SenseInfo('12142085-n', 1), SenseInfo('07803545-n', 0), SenseInfo('04966941-n', 0) ],
"_heave_v_out_rel" : [ SenseInfo('00986586-v', 5), SenseInfo('01507792-v', 3), SenseInfo('02041206-v', 2), SenseInfo('01455866-v', 2), SenseInfo('02088470-v', 1), SenseInfo('00005526-v', 1), SenseInfo('00356954-v', 0), SenseInfo('00077458-v', 0) ],
"_build_v_into_rel" : [ SenseInfo('01654628-v', 123), SenseInfo('00252990-v', 11), SenseInfo('01655505-v', 4), SenseInfo('00447158-v', 1), SenseInfo('02443424-v', 0), SenseInfo('01739099-v', 0), SenseInfo('01685601-v', 0), SenseInfo('00637115-v', 0), SenseInfo('00253277-v', 0), SenseInfo('00226882-v', 0) ],
"_cancer_n_1_rel" : [ SenseInfo('14239918-n', 15), SenseInfo('09752657-n', 0), SenseInfo('09232687-n', 0), SenseInfo('08686658-n', 0), SenseInfo('01977832-n', 0) ],
"_incredibly_x_deg_rel" : [ SenseInfo('00295825-r', 5), SenseInfo('00032180-r', 0) ],
"_duckboard_n_1_rel" : [ SenseInfo('03253187-n', 0) ],
"_gazebo_n_1_rel" : [ SenseInfo('03430418-n', 0) ],
"_flank_v_1_rel" : [ SenseInfo('02694106-v', 5) ],
"_stellate_n_1_rel" : [ SenseInfo('02373055-a', 0) ],
"_snail_n_1_rel" : [ SenseInfo('01944390-n', 3), SenseInfo('07782475-n', 0) ],
"_recognize_v_1_rel" : [ SenseInfo('00592883-v', 33), SenseInfo('00728617-v', 32), SenseInfo('02193194-v', 25), SenseInfo('00610374-v', 11), SenseInfo('02475535-v', 2), SenseInfo('00897241-v', 2), SenseInfo('00892467-v', 2), SenseInfo('02754158-v', 0), SenseInfo('02546467-v', 0), SenseInfo('00592883-v', 33), SenseInfo('00728617-v', 32), SenseInfo('02193194-v', 25), SenseInfo('00610374-v', 11), SenseInfo('02475535-v', 2), SenseInfo('00897241-v', 2), SenseInfo('00892467-v', 2), SenseInfo('02754158-v', 0), SenseInfo('02546467-v', 0), SenseInfo('00592883-v', 33), SenseInfo('00728617-v', 32), SenseInfo('02193194-v', 25), SenseInfo('00610374-v', 11), SenseInfo('02475535-v', 2), SenseInfo('00897241-v', 2), SenseInfo('00892467-v', 2), SenseInfo('02754158-v', 0), SenseInfo('02546467-v', 0), SenseInfo('00592883-v', 33), SenseInfo('00728617-v', 32), SenseInfo('02193194-v', 25), SenseInfo('00610374-v', 11), SenseInfo('02475535-v', 2), SenseInfo('00897241-v', 2), SenseInfo('00892467-v', 2), SenseInfo('02754158-v', 0), SenseInfo('02546467-v', 0) ],
"_chamber_n_1_rel" : [ SenseInfo('03003730-n', 6), SenseInfo('05392744-n', 1), SenseInfo('03004146-n', 1), SenseInfo('08318904-n', 0), SenseInfo('02821627-n', 0), SenseInfo('03003730-n', 6), SenseInfo('05392744-n', 1), SenseInfo('03004146-n', 1), SenseInfo('08318904-n', 0), SenseInfo('02821627-n', 0) ],
"_patriotic_a_1_rel" : [ SenseInfo('01740207-a', 4) ],
"_clog_n_1_rel" : [ SenseInfo('03047690-n', 0), SenseInfo('03047553-n', 0), SenseInfo('00530208-n', 0) ],
"_hint_v_to_rel" : [ SenseInfo('00927430-v', 7) ],
"_resist_v_1_rel" : [ SenseInfo('02707800-v', 12), SenseInfo('01116585-v', 11), SenseInfo('02521410-v', 2), SenseInfo('01115916-v', 1), SenseInfo('02755017-v', 0), SenseInfo('02583545-v', 0) ],
"_mullion_n_1_rel" : [ SenseInfo('03798268-n', 0) ],
"_sound_v_1_rel" : [ SenseInfo('02134927-v', 38), SenseInfo('02176268-v', 14), SenseInfo('02135048-v', 9), SenseInfo('02180529-v', 1), SenseInfo('00952182-v', 1), SenseInfo('02179518-v', 0), SenseInfo('00491689-v', 0), SenseInfo('02134927-v', 38), SenseInfo('02176268-v', 14), SenseInfo('02135048-v', 9), SenseInfo('02180529-v', 1), SenseInfo('00952182-v', 1), SenseInfo('02179518-v', 0), SenseInfo('00491689-v', 0) ],
"_symmetrical_a_1_rel" : [ SenseInfo('02371718-a', 1), SenseInfo('00894029-a', 1) ],
"_zone_v_1_rel" : [ SenseInfo('02512150-v', 0), SenseInfo('00332835-v', 0) ],
"_metamorphose_v_cause_rel" : [ SenseInfo('00384055-v', 1), SenseInfo('00381601-v', 0) ],
"_vastness_n_1_rel" : [ SenseInfo('05104548-n', 0), SenseInfo('05104548-n', 0) ],
"_on+foot_p_rel" : [  ],
"_franciscan_n_1_rel" : [ SenseInfo('10778553-n', 0) ],
"_semilunar_a_1_rel" : [ SenseInfo('02045473-a', 0) ],
"_undisturbed_a_1_rel" : [ SenseInfo('02460262-a', 0), SenseInfo('02460262-a', 0) ],
"_grizzly_n_1_rel" : [ SenseInfo('02132580-n', 0) ],
"_helicopter_n_1_rel" : [ SenseInfo('03512147-n', 0) ],
"_corrugate_v_1_rel" : [ SenseInfo('01387164-v', 0) ],
"_digestive_n_1_rel" : [ SenseInfo('14834714-n', 0) ],
"_stir_v_in_rel" : [ SenseInfo('01894320-v', 7), SenseInfo('01893988-v', 5), SenseInfo('02116118-v', 4), SenseInfo('01761706-v', 4), SenseInfo('01770802-v', 1), SenseInfo('01629958-v', 1), SenseInfo('01894164-v', 0), SenseInfo('01541467-v', 0) ],
"_lash_v_out_rel" : [ SenseInfo('01411085-v', 4), SenseInfo('01877946-v', 0), SenseInfo('01398032-v', 0), SenseInfo('01303707-v', 0), SenseInfo('01411085-v', 4), SenseInfo('01877946-v', 0), SenseInfo('01398032-v', 0), SenseInfo('01303707-v', 0), SenseInfo('01411085-v', 4), SenseInfo('01877946-v', 0), SenseInfo('01398032-v', 0), SenseInfo('01303707-v', 0) ],
"_set_v_out-aim_rel" : [ SenseInfo('01494310-v', 30), SenseInfo('00699815-v', 29), SenseInfo('00947077-v', 12), SenseInfo('01062395-v', 10), SenseInfo('00298896-v', 9), SenseInfo('01607445-v', 6), SenseInfo('00406243-v', 5), SenseInfo('00298556-v', 5), SenseInfo('01711749-v', 3), SenseInfo('01970646-v', 2), SenseInfo('01706129-v', 2), SenseInfo('01567275-v', 2), SenseInfo('01628899-v', 1), SenseInfo('00442669-v', 1), SenseInfo('01744888-v', 0), SenseInfo('01613239-v', 0), SenseInfo('01530273-v', 0), SenseInfo('01247322-v', 0), SenseInfo('01115006-v', 0), SenseInfo('00673448-v', 0), SenseInfo('00408085-v', 0), SenseInfo('00407848-v', 0), SenseInfo('00296178-v', 0), SenseInfo('00056188-v', 0), SenseInfo('00038849-v', 0) ],
"_flabbergast_v_1_rel" : [ SenseInfo('00726153-v', 0), SenseInfo('00726153-v', 0) ],
"_demand_v_of_rel" : [ SenseInfo('00754942-v', 47), SenseInfo('02627934-v', 22), SenseInfo('01017826-v', 7), SenseInfo('01069090-v', 0), SenseInfo('01068985-v', 0), SenseInfo('01018065-v', 0), SenseInfo('00754942-v', 47), SenseInfo('02627934-v', 22), SenseInfo('01017826-v', 7), SenseInfo('01069090-v', 0), SenseInfo('01068985-v', 0), SenseInfo('01018065-v', 0), SenseInfo('00754942-v', 47), SenseInfo('02627934-v', 22), SenseInfo('01017826-v', 7), SenseInfo('01069090-v', 0), SenseInfo('01068985-v', 0), SenseInfo('01018065-v', 0), SenseInfo('00754942-v', 47), SenseInfo('02627934-v', 22), SenseInfo('01017826-v', 7), SenseInfo('01069090-v', 0), SenseInfo('01068985-v', 0), SenseInfo('01018065-v', 0), SenseInfo('00754942-v', 47), SenseInfo('02627934-v', 22), SenseInfo('01017826-v', 7), SenseInfo('01069090-v', 0), SenseInfo('01068985-v', 0), SenseInfo('01018065-v', 0) ],
"_hairstyle_n_1_rel" : [ SenseInfo('05256862-n', 0) ],
"_kidney_n_1_rel" : [ SenseInfo('05332802-n', 9) ],
"_bleak_a_1_rel" : [ SenseInfo('01229561-a', 2), SenseInfo('01242750-a', 1), SenseInfo('01252399-a', 0), SenseInfo('01229561-a', 2), SenseInfo('01242750-a', 1), SenseInfo('01252399-a', 0), SenseInfo('01229561-a', 2), SenseInfo('01242750-a', 1), SenseInfo('01252399-a', 0) ],
"_tie_v_1_rel" : [ SenseInfo('01285440-v', 13), SenseInfo('01115190-v', 5), SenseInfo('00234217-v', 4), SenseInfo('01354673-v', 2), SenseInfo('00141632-v', 1), SenseInfo('02538086-v', 0), SenseInfo('02489456-v', 0), SenseInfo('01658444-v', 0), SenseInfo('01355411-v', 0) ],
"_freeway_n_1_rel" : [ SenseInfo('03306610-n', 7) ],
"_all+the+way_x_deg_rel" : [ SenseInfo('00152066-r', 9), SenseInfo('00285854-r', 5), SenseInfo('00152173-r', 0) ],
"_manage_v_1_rel" : [ SenseInfo('02522864-v', 27), SenseInfo('02436349-v', 5), SenseInfo('02587532-v', 3), SenseInfo('02443049-v', 3), SenseInfo('02527431-v', 2), SenseInfo('02523221-v', 0), SenseInfo('01224415-v', 0), SenseInfo('02522864-v', 27), SenseInfo('02436349-v', 5), SenseInfo('02587532-v', 3), SenseInfo('02443049-v', 3), SenseInfo('02527431-v', 2), SenseInfo('02523221-v', 0), SenseInfo('01224415-v', 0) ],
"_cardiovascular_a_1_rel" : [ SenseInfo('02874130-a', 1) ],
"_hexagon_n_1_rel" : [ SenseInfo('13882276-n', 0) ],
"_unspecified_a_1_rel" : [ SenseInfo('01100082-a', 0), SenseInfo('01100082-a', 0) ],
"_piece_n_of-2_rel" : [ SenseInfo('03932203-n', 23), SenseInfo('03932499-n', 13), SenseInfo('09385911-n', 8), SenseInfo('07037465-n', 7), SenseInfo('07309457-n', 4), SenseInfo('06269396-n', 2), SenseInfo('03343853-n', 2), SenseInfo('07654667-n', 1), SenseInfo('05084889-n', 1), SenseInfo('03838535-n', 1), SenseInfo('15246353-n', 0), SenseInfo('13286524-n', 0), SenseInfo('03716327-n', 0), SenseInfo('03932203-n', 23), SenseInfo('03932499-n', 13), SenseInfo('09385911-n', 8), SenseInfo('07037465-n', 7), SenseInfo('07309457-n', 4), SenseInfo('06269396-n', 2), SenseInfo('03343853-n', 2), SenseInfo('07654667-n', 1), SenseInfo('05084889-n', 1), SenseInfo('03838535-n', 1), SenseInfo('15246353-n', 0), SenseInfo('13286524-n', 0), SenseInfo('03716327-n', 0) ],
"_line_v_up_rel" : [ SenseInfo('02703539-v', 7), SenseInfo('01270784-v', 5), SenseInfo('01582645-v', 0), SenseInfo('01276361-v', 0), SenseInfo('00454135-v', 0), SenseInfo('00222993-v', 0), SenseInfo('02703539-v', 7), SenseInfo('01270784-v', 5), SenseInfo('01582645-v', 0), SenseInfo('01276361-v', 0), SenseInfo('00454135-v', 0), SenseInfo('00222993-v', 0) ],
"_gloom_n_1_rel" : [ SenseInfo('13985462-n', 10), SenseInfo('07533257-n', 1), SenseInfo('14525365-n', 0) ],
"_reproach_n_of_rel" : [ SenseInfo('06713512-n', 7), SenseInfo('14441714-n', 1) ],
"_arms+length_n_1_rel" : [  ],
"_reference_v_1_rel" : [ SenseInfo('01705257-v', 0) ],
"_unload_v_1_rel" : [ SenseInfo('01489465-v', 3), SenseInfo('01488123-v', 0), SenseInfo('01489465-v', 3), SenseInfo('01488123-v', 0) ],
"_respondent_n_1_rel" : [ SenseInfo('10524711-n', 0), SenseInfo('10524413-n', 0) ],
"_reciprocal_n_1_rel" : [ SenseInfo('13843601-n', 0), SenseInfo('13843173-n', 0), SenseInfo('00851146-n', 0) ],
"_regularly_x_deg_rel" : [ SenseInfo('00195024-r', 6), SenseInfo('00331817-r', 0), SenseInfo('00331461-r', 0) ],
"_implement_n_1_rel" : [ SenseInfo('03563967-n', 2) ],
"_subordinate_n_1_rel" : [ SenseInfo('10669991-n', 3), SenseInfo('06292973-n', 0) ],
"_sister+in+law_n_1_rel" : [ SenseInfo('10603766-n', 1), SenseInfo('10603766-n', 1) ],
"_proximity_n_1_rel" : [ SenseInfo('05085867-n', 1), SenseInfo('08642517-n', 0), SenseInfo('06250771-n', 0) ],
"_morain_n_1_rel" : [  ],
"_buzzard_n_1_rel" : [ SenseInfo('01619310-n', 0), SenseInfo('01607962-n', 0) ],
"_fabric_n_1_rel" : [ SenseInfo('03309808-n', 11), SenseInfo('04933363-n', 1) ],
"_marketplace_n_of_rel" : [ SenseInfo('01097292-n', 3), SenseInfo('03722288-n', 2) ],
"_commit_v_1_rel" : [ SenseInfo('02582615-v', 12), SenseInfo('00887463-v', 12), SenseInfo('02348568-v', 3), SenseInfo('02349212-v', 1), SenseInfo('02271137-v', 1), SenseInfo('02375468-v', 0) ],
"_switch_v_on_rel" : [ SenseInfo('00140751-v', 5), SenseInfo('02259005-v', 3), SenseInfo('00550117-v', 2), SenseInfo('00380159-v', 1), SenseInfo('01510173-v', 0), SenseInfo('01411630-v', 0), SenseInfo('00121678-v', 0), SenseInfo('00140751-v', 5), SenseInfo('02259005-v', 3), SenseInfo('00550117-v', 2), SenseInfo('00380159-v', 1), SenseInfo('01510173-v', 0), SenseInfo('01411630-v', 0), SenseInfo('00121678-v', 0) ],
"_align_v_with_rel" : [ SenseInfo('00464321-v', 2), SenseInfo('02658867-v', 1), SenseInfo('00733632-v', 1), SenseInfo('00466053-v', 0) ],
"_cache_v_1_rel" : [ SenseInfo('02305856-v', 0) ],
"_unsheathe_v_1_rel" : [ SenseInfo('01581485-v', 1), SenseInfo('01581485-v', 1) ],
"_intercity_n_1_rel" : [  ],
"_overboard_p_rel" : [ SenseInfo('00506715-r', 3), SenseInfo('00173131-r', 3) ],
"_sting_v_1_rel" : [ SenseInfo('02120451-v', 1), SenseInfo('01445407-v', 1), SenseInfo('00748084-v', 1), SenseInfo('02123424-v', 0), SenseInfo('01793742-v', 0), SenseInfo('02120451-v', 1), SenseInfo('01445407-v', 1), SenseInfo('00748084-v', 1), SenseInfo('02123424-v', 0), SenseInfo('01793742-v', 0) ],
"_far+removed_a_from_rel" : [  ],
"_run_v_into_rel" : [ SenseInfo('01926311-v', 106), SenseInfo('02075049-v', 38), SenseInfo('02685951-v', 21), SenseInfo('02443849-v', 20), SenseInfo('02721284-v', 10), SenseInfo('02066939-v', 9), SenseInfo('01525666-v', 8), SenseInfo('02727039-v', 7), SenseInfo('01094086-v', 7), SenseInfo('01717169-v', 5), SenseInfo('02099829-v', 4), SenseInfo('02719399-v', 3), SenseInfo('01526290-v', 3), SenseInfo('00549063-v', 3), SenseInfo('00517529-v', 3), SenseInfo('02720904-v', 2), SenseInfo('02647497-v', 2), SenseInfo('02612234-v', 2), SenseInfo('02563327-v', 2), SenseInfo('01746359-v', 2), SenseInfo('01641545-v', 2), SenseInfo('01212230-v', 2), SenseInfo('02686625-v', 1), SenseInfo('02525312-v', 1), SenseInfo('02242256-v', 1), SenseInfo('02092309-v', 1), SenseInfo('02060792-v', 1), SenseInfo('01927903-v', 1), SenseInfo('01914947-v', 1), SenseInfo('02648110-v', 0), SenseInfo('02421921-v', 0), SenseInfo('01927747-v', 0), SenseInfo('01927447-v', 0), SenseInfo('01926984-v', 0), SenseInfo('01864038-v', 0), SenseInfo('01143838-v', 0), SenseInfo('01086103-v', 0), SenseInfo('00539110-v', 0), SenseInfo('00444629-v', 0), SenseInfo('00334803-v', 0), SenseInfo('00332672-v', 0) ],
"_maximum_p_rel" : [ SenseInfo('01495725-a', 36), SenseInfo('13776137-n', 11), SenseInfo('05124928-n', 1), SenseInfo('08598132-n', 0) ],
"_spacious_a_1_rel" : [ SenseInfo('01384212-a', 2), SenseInfo('00476249-a', 0) ],
"_vane_n_1_rel" : [ SenseInfo('04568069-n', 0), SenseInfo('04520784-n', 0), SenseInfo('02848523-n', 0), SenseInfo('01897991-n', 0) ],
"_stun_v_1_rel" : [ SenseInfo('00268968-v', 2), SenseInfo('01410079-v', 1), SenseInfo('02115430-v', 0), SenseInfo('00268968-v', 2), SenseInfo('01410079-v', 1), SenseInfo('02115430-v', 0), SenseInfo('00268968-v', 2), SenseInfo('01410079-v', 1), SenseInfo('02115430-v', 0) ],
"_regularly_x_rel" : [ SenseInfo('00195024-r', 6), SenseInfo('00331817-r', 0), SenseInfo('00331461-r', 0) ],
"_whaling_n_1_rel" : [  ],
"_scowl_v_at_rel" : [ SenseInfo('00033852-v', 3), SenseInfo('00033852-v', 3) ],
"_pretty_x_rel" : [ SenseInfo('00035718-r', 35), SenseInfo('00220082-a', 20), SenseInfo('01128871-a', 3) ],
"_cool_v_off_rel" : [ SenseInfo('00370412-v', 15), SenseInfo('00369864-v', 1), SenseInfo('00370126-v', 0) ],
"_oak_n_1_rel" : [ SenseInfo('12268918-n', 3), SenseInfo('12268246-n', 1) ],
"_cake_v_cause_rel" : [ SenseInfo('01262321-v', 0) ],
"_waltz_v_1_rel" : [ SenseInfo('01895612-v', 0) ],
"_swinger_n_1_rel" : [ SenseInfo('10683801-n', 0), SenseInfo('10683675-n', 0) ],
"_reluctance_n_to_rel" : [ SenseInfo('11504750-n', 0), SenseInfo('04645943-n', 0), SenseInfo('11504750-n', 0), SenseInfo('04645943-n', 0) ],
"_admission_n_of_rel" : [ SenseInfo('01248191-n', 8), SenseInfo('07215948-n', 1), SenseInfo('13321495-n', 0), SenseInfo('05176188-n', 0), SenseInfo('01248191-n', 8), SenseInfo('07215948-n', 1), SenseInfo('13321495-n', 0), SenseInfo('05176188-n', 0), SenseInfo('01248191-n', 8), SenseInfo('07215948-n', 1), SenseInfo('13321495-n', 0), SenseInfo('05176188-n', 0), SenseInfo('01248191-n', 8), SenseInfo('07215948-n', 1), SenseInfo('13321495-n', 0), SenseInfo('05176188-n', 0) ],
"_foreign-based_a_1_rel" : [  ],
"_accord_n_1_rel" : [ SenseInfo('13971065-n', 0), SenseInfo('07176804-n', 0), SenseInfo('06773434-n', 0), SenseInfo('04713332-n', 0) ],
"_trophy_n_1_rel" : [ SenseInfo('06709442-n', 0), SenseInfo('04487996-n', 0) ],
"_alarmed_a_1_rel" : [ SenseInfo('00078851-a', 1) ],
"_all+around_a_1_rel" : [ SenseInfo('00526541-a', 0), SenseInfo('00526541-a', 0) ],
"_mother_v_1_rel" : [ SenseInfo('02550516-v', 2), SenseInfo('00054628-v', 0) ],
"_pollinate_v_1_rel" : [ SenseInfo('00054059-v', 0) ],
"_australian_n_1_rel" : [ SenseInfo('09691279-n', 0), SenseInfo('06940290-n', 0) ],
"_dream_v_about_rel" : [ SenseInfo('01637633-v', 15), SenseInfo('02118242-v', 11) ],
"_wiles_n_1_rel" : [ SenseInfo('00752954-n', 1), SenseInfo('00752954-n', 1) ],
"_sulfate_n_1_rel" : [ SenseInfo('15063493-n', 0) ],
"_thin_v_1_rel" : [ SenseInfo('00430999-v', 2), SenseInfo('00430625-v', 0), SenseInfo('00226071-v', 0), SenseInfo('00045817-v', 0) ],
"_bulk_v_1_rel" : [ SenseInfo('00263564-v', 2), SenseInfo('00256369-v', 0) ],
"_robotic_a_1_rel" : [ SenseInfo('02939781-a', 0), SenseInfo('01499999-a', 0) ],
"_jelly_n_1_rel" : [ SenseInfo('07643981-n', 1), SenseInfo('07643306-n', 1), SenseInfo('14925198-n', 0) ],
"_finance_v_1_rel" : [ SenseInfo('02217266-v', 23), SenseInfo('02217864-v', 0) ],
"_overcrowded_a_1_rel" : [  ],
"_cane_n_1_rel" : [ SenseInfo('02949202-n', 5), SenseInfo('12136206-n', 0), SenseInfo('02949084-n', 0) ],
"_significative_a_1_rel" : [ SenseInfo('02091300-a', 0) ],
"_jobber_n_1_rel" : [ SenseInfo('10222497-n', 0) ],
"_suspensor_n_1_rel" : [ SenseInfo('02752615-n', 0) ],
"_heroic_a_1_rel" : [ SenseInfo('01386010-a', 5), SenseInfo('02740508-a', 2), SenseInfo('00251134-a', 2), SenseInfo('01284544-a', 1), SenseInfo('00263463-a', 0) ],
"_plank_n_1_rel" : [ SenseInfo('15101854-n', 9), SenseInfo('06501622-n', 0) ],
"_a+good+deal_a_1_rel" : [  ],
"_strap_n_1_rel" : [ SenseInfo('04333129-n', 2), SenseInfo('04333709-n', 0), SenseInfo('04333500-n', 0), SenseInfo('04332987-n', 0) ],
"_agro-industrial_a_1_rel" : [  ],
"_title_n_of_rel" : [ SenseInfo('06345993-n', 26), SenseInfo('06343520-n', 8), SenseInfo('06346461-n', 3), SenseInfo('13948912-n', 2), SenseInfo('06545137-n', 2), SenseInfo('06339416-n', 1), SenseInfo('05181199-n', 1), SenseInfo('06346220-n', 0), SenseInfo('06343117-n', 0), SenseInfo('05175904-n', 0), SenseInfo('06345993-n', 26), SenseInfo('06343520-n', 8), SenseInfo('06346461-n', 3), SenseInfo('13948912-n', 2), SenseInfo('06545137-n', 2), SenseInfo('06339416-n', 1), SenseInfo('05181199-n', 1), SenseInfo('06346220-n', 0), SenseInfo('06343117-n', 0), SenseInfo('05175904-n', 0) ],
"_worth_n_of_rel" : [ SenseInfo('13764342-n', 5), SenseInfo('05138208-n', 4), SenseInfo('11397885-n', 0) ],
"_modesty_n_1_rel" : [ SenseInfo('04900947-n', 1), SenseInfo('04900121-n', 1) ],
"_tabloid_n_1_rel" : [ SenseInfo('06267991-n', 0), SenseInfo('06267893-n', 0) ],
"_variance_n_1_rel" : [ SenseInfo('07366627-n', 0), SenseInfo('07181842-n', 0), SenseInfo('06024936-n', 0), SenseInfo('04749709-n', 0), SenseInfo('04735233-n', 0), SenseInfo('01142150-n', 0), SenseInfo('00194969-n', 0) ],
"_v+neck_n_1_rel" : [ SenseInfo('04539535-n', 0), SenseInfo('04539535-n', 0) ],
"_clifftop_a_1_rel" : [  ],
"_treasured_a_1_rel" : [ SenseInfo('01462625-a', 1) ],
"_cheat_v_1_rel" : [ SenseInfo('02573275-v', 2), SenseInfo('01104624-v', 2), SenseInfo('02574516-v', 1), SenseInfo('02576503-v', 0) ],
"_extremity_n_1_rel" : [ SenseInfo('05559908-n', 1), SenseInfo('14476521-n', 0), SenseInfo('13942405-n', 0), SenseInfo('08568978-n', 0), SenseInfo('05566919-n', 0) ],
"_arduous_a_1_rel" : [ SenseInfo('00836544-a', 1), SenseInfo('00837977-a', 0), SenseInfo('00745858-a', 0) ],
"_trailhead_n_1_rel" : [ SenseInfo('08585447-n', 0) ],
"_waive_v_1_rel" : [ SenseInfo('02534062-v', 1), SenseInfo('02303331-v', 0) ],
"_crash_v_cause-into_rel" : [ SenseInfo('01972570-v', 9), SenseInfo('02088627-v', 3), SenseInfo('01561819-v', 2), SenseInfo('02019282-v', 1), SenseInfo('01562061-v', 1), SenseInfo('02657080-v', 0), SenseInfo('02177512-v', 0), SenseInfo('02019011-v', 0), SenseInfo('01562209-v', 0), SenseInfo('01507407-v', 0), SenseInfo('00583064-v', 0), SenseInfo('00434919-v', 0), SenseInfo('00017674-v', 0) ],
"_inkjet_n_1_rel" : [  ],
"_refrigeration_n_1_rel" : [ SenseInfo('13548531-n', 2), SenseInfo('00707344-n', 0) ],
"_athletic_a_1_rel" : [ SenseInfo('02907656-a', 3), SenseInfo('00032497-a', 1), SenseInfo('00828661-a', 0), SenseInfo('02907656-a', 3), SenseInfo('00032497-a', 1), SenseInfo('00828661-a', 0) ],
"_per+second_p_rel" : [  ],
"_newsboy_n_1_rel" : [ SenseInfo('09897603-n', 2) ],
"_esquire_n_1_rel" : [ SenseInfo('10064229-n', 0), SenseInfo('10064046-n', 0) ],
"_questionable_a_1_rel" : [ SenseInfo('01916229-a', 2), SenseInfo('00721371-a', 0), SenseInfo('01916229-a', 2), SenseInfo('00721371-a', 0) ],
"_dam_n_1_rel" : [ SenseInfo('03160309-n', 2), SenseInfo('13659419-n', 0), SenseInfo('01323493-n', 0) ],
"_quarrel_v_about_rel" : [ SenseInfo('00775156-v', 11), SenseInfo('00775156-v', 11) ],
"_negotiation_n_of_rel" : [ SenseInfo('07148192-n', 2), SenseInfo('01266364-n', 0) ],
"_homemade_a_1_rel" : [ SenseInfo('00674270-a', 1), SenseInfo('00674270-a', 1), SenseInfo('00674270-a', 1) ],
"_uncontrollable_a_1_rel" : [ SenseInfo('02452789-a', 1), SenseInfo('01475526-a', 0), SenseInfo('00635752-a', 0), SenseInfo('00600540-a', 0), SenseInfo('02452789-a', 1), SenseInfo('01475526-a', 0), SenseInfo('00635752-a', 0), SenseInfo('00600540-a', 0) ],
"_thicket_n_1_rel" : [ SenseInfo('08437515-n', 11) ],
"_limit_v_1_rel" : [ SenseInfo('00233335-v', 23), SenseInfo('00235368-v', 6), SenseInfo('00947077-v', 0), SenseInfo('00233335-v', 23), SenseInfo('00235368-v', 6), SenseInfo('00947077-v', 0), SenseInfo('00233335-v', 23), SenseInfo('00235368-v', 6), SenseInfo('00947077-v', 0), SenseInfo('00233335-v', 23), SenseInfo('00235368-v', 6), SenseInfo('00947077-v', 0), SenseInfo('00233335-v', 23), SenseInfo('00235368-v', 6), SenseInfo('00947077-v', 0) ],
"_fissure_n_1_rel" : [ SenseInfo('13907272-n', 0), SenseInfo('09258715-n', 0), SenseInfo('05223370-n', 0) ],
"_meek_a_1_rel" : [ SenseInfo('01893510-a', 4), SenseInfo('02328916-a', 0), SenseInfo('00789494-a', 0), SenseInfo('01893510-a', 4), SenseInfo('02328916-a', 0), SenseInfo('00789494-a', 0), SenseInfo('01893510-a', 4), SenseInfo('02328916-a', 0), SenseInfo('00789494-a', 0), SenseInfo('01893510-a', 4), SenseInfo('02328916-a', 0), SenseInfo('00789494-a', 0) ],
"_healthy_n_1_rel" : [ SenseInfo('01170243-a', 15), SenseInfo('02273838-a', 3), SenseInfo('02558184-a', 1), SenseInfo('01944088-a', 0), SenseInfo('00624576-a', 0) ],
"_iceberg_n_1_rel" : [ SenseInfo('09308572-n', 0), SenseInfo('07724269-n', 0) ],
"_seamless_a_1_rel" : [ SenseInfo('02254264-a', 0), SenseInfo('02237978-a', 0), SenseInfo('00464845-a', 0), SenseInfo('02254264-a', 0), SenseInfo('02237978-a', 0), SenseInfo('00464845-a', 0) ],
"_misfeed_n_1_rel" : [  ],
"_break_n_1_rel" : [ SenseInfo('07367812-n', 3), SenseInfo('07316856-n', 2), SenseInfo('09278537-n', 1), SenseInfo('07313814-n', 1), SenseInfo('01062997-n', 1), SenseInfo('00376400-n', 1), SenseInfo('15271008-n', 0), SenseInfo('14292090-n', 0), SenseInfo('07367548-n', 0), SenseInfo('07297633-n', 0), SenseInfo('00500280-n', 0), SenseInfo('00482892-n', 0), SenseInfo('00383952-n', 0), SenseInfo('00294748-n', 0), SenseInfo('00188007-n', 0), SenseInfo('00059989-n', 0) ],
"_speciation_n_of_rel" : [ SenseInfo('13560079-n', 0) ],
"_weatherproof_a_1_rel" : [ SenseInfo('01886241-a', 0) ],
"_in+charge_a_of_rel" : [  ],
"_disarm_v_cause_rel" : [ SenseInfo('01087835-v', 2), SenseInfo('01830445-v', 0), SenseInfo('01088005-v', 0), SenseInfo('01087835-v', 2), SenseInfo('01830445-v', 0), SenseInfo('01088005-v', 0), SenseInfo('01087835-v', 2), SenseInfo('01830445-v', 0), SenseInfo('01088005-v', 0) ],
"_indulge_v_1_rel" : [ SenseInfo('02511276-v', 2), SenseInfo('01182293-v', 2), SenseInfo('01191645-v', 1), SenseInfo('02570267-v', 0) ],
"_humiliate_v_1_rel" : [ SenseInfo('01799794-v', 2), SenseInfo('01799794-v', 2), SenseInfo('01799794-v', 2), SenseInfo('01799794-v', 2), SenseInfo('01799794-v', 2), SenseInfo('01799794-v', 2) ],
"_popcorn_n_1_rel" : [ SenseInfo('12145477-n', 0), SenseInfo('07732636-n', 0) ],
"_incinerate_v_1_rel" : [ SenseInfo('00378361-v', 0), SenseInfo('00378042-v', 0) ],
"_tempo_n_1_rel" : [ SenseInfo('15264363-n', 2), SenseInfo('15283097-n', 1) ],
"_gingko_n_1_rel" : [ SenseInfo('11664418-n', 0) ],
"_scandinavian_a_1_rel" : [ SenseInfo('02960130-a', 1) ],
"_applicator_n_1_rel" : [ SenseInfo('02730265-n', 1) ],
"_push_v_open_rel" : [ SenseInfo('01871979-v', 56), SenseInfo('00765977-v', 7), SenseInfo('00976653-v', 6), SenseInfo('02406916-v', 3), SenseInfo('01872645-v', 3), SenseInfo('02054864-v', 1), SenseInfo('02589576-v', 0), SenseInfo('02245555-v', 0), SenseInfo('01872877-v', 0), SenseInfo('01447632-v', 0), SenseInfo('01871979-v', 56), SenseInfo('00765977-v', 7), SenseInfo('00976653-v', 6), SenseInfo('02406916-v', 3), SenseInfo('01872645-v', 3), SenseInfo('02054864-v', 1), SenseInfo('02589576-v', 0), SenseInfo('02245555-v', 0), SenseInfo('01872877-v', 0), SenseInfo('01447632-v', 0) ],
"_extinguisher_n_1_rel" : [ SenseInfo('03345837-n', 0) ],
"_respite_n_1_rel" : [ SenseInfo('14446034-n', 2), SenseInfo('01062997-n', 2), SenseInfo('07368256-n', 1), SenseInfo('15274074-n', 0), SenseInfo('01259034-n', 0) ],
"_repay_v_1_rel" : [ SenseInfo('02284951-v', 7), SenseInfo('02344060-v', 1), SenseInfo('02344381-v', 0), SenseInfo('00816353-v', 0), SenseInfo('02284951-v', 7), SenseInfo('02344060-v', 1), SenseInfo('02344381-v', 0), SenseInfo('00816353-v', 0) ],
"_rely_v_upon_rel" : [ SenseInfo('00688377-v', 1) ],
"_unionist_n_1_rel" : [ SenseInfo('10720964-n', 0) ],
"_help_v_to_rel" : [ SenseInfo('02547586-v', 183), SenseInfo('00082081-v', 23), SenseInfo('02735897-v', 19), SenseInfo('02726164-v', 5), SenseInfo('01181295-v', 2), SenseInfo('02555434-v', 0), SenseInfo('01193569-v', 0), SenseInfo('00206998-v', 0), SenseInfo('02547586-v', 183), SenseInfo('00082081-v', 23), SenseInfo('02735897-v', 19), SenseInfo('02726164-v', 5), SenseInfo('01181295-v', 2), SenseInfo('02555434-v', 0), SenseInfo('01193569-v', 0), SenseInfo('00206998-v', 0), SenseInfo('02547586-v', 183), SenseInfo('00082081-v', 23), SenseInfo('02735897-v', 19), SenseInfo('02726164-v', 5), SenseInfo('01181295-v', 2), SenseInfo('02555434-v', 0), SenseInfo('01193569-v', 0), SenseInfo('00206998-v', 0), SenseInfo('02547586-v', 183), SenseInfo('00082081-v', 23), SenseInfo('02735897-v', 19), SenseInfo('02726164-v', 5), SenseInfo('01181295-v', 2), SenseInfo('02555434-v', 0), SenseInfo('01193569-v', 0), SenseInfo('00206998-v', 0), SenseInfo('02547586-v', 183), SenseInfo('00082081-v', 23), SenseInfo('02735897-v', 19), SenseInfo('02726164-v', 5), SenseInfo('01181295-v', 2), SenseInfo('02555434-v', 0), SenseInfo('01193569-v', 0), SenseInfo('00206998-v', 0), SenseInfo('02547586-v', 183), SenseInfo('00082081-v', 23), SenseInfo('02735897-v', 19), SenseInfo('02726164-v', 5), SenseInfo('01181295-v', 2), SenseInfo('02555434-v', 0), SenseInfo('01193569-v', 0), SenseInfo('00206998-v', 0) ],
"_enchanted_a_1_rel" : [ SenseInfo('00865471-a', 1) ],
"_camper_n_1_rel" : [ SenseInfo('09889941-n', 10), SenseInfo('02946348-n', 0) ],
"_tango_v_1_rel" : [ SenseInfo('01896007-v', 0) ],
"_confuse_v_1_rel" : [ SenseInfo('00619610-v', 10), SenseInfo('00621734-v', 5), SenseInfo('01790739-v', 0), SenseInfo('01657254-v', 0), SenseInfo('00620673-v', 0), SenseInfo('00619610-v', 10), SenseInfo('00621734-v', 5), SenseInfo('01790739-v', 0), SenseInfo('01657254-v', 0), SenseInfo('00620673-v', 0), SenseInfo('00619610-v', 10), SenseInfo('00621734-v', 5), SenseInfo('01790739-v', 0), SenseInfo('01657254-v', 0), SenseInfo('00620673-v', 0) ],
"_click_v_1_rel" : [ SenseInfo('01893771-v', 5), SenseInfo('02185664-v', 1), SenseInfo('02185861-v', 0), SenseInfo('01242208-v', 0), SenseInfo('01055146-v', 0), SenseInfo('01054849-v', 0), SenseInfo('00591755-v', 0) ],
"_cripple_n_1_rel" : [ SenseInfo('09978889-n', 1) ],
"_learner_n_1_rel" : [ SenseInfo('10251779-n', 1), SenseInfo('09801864-n', 0) ],
"_chiropractor_n_1_rel" : [ SenseInfo('09919200-n', 2) ],
"_pool_v_1_rel" : [ SenseInfo('02295842-v', 4), SenseInfo('01090107-v', 0) ],
"_foe_n_1_rel" : [ SenseInfo('10055847-n', 12), SenseInfo('10098710-n', 2) ],
"_ideological_a_1_rel" : [ SenseInfo('02745555-a', 0), SenseInfo('00012932-a', 0) ],
"_acceptance_n_1_rel" : [ SenseInfo('06193727-n', 4), SenseInfo('00180413-n', 3), SenseInfo('13932421-n', 1), SenseInfo('07176073-n', 1), SenseInfo('13381602-n', 0), SenseInfo('04638175-n', 0), SenseInfo('00082525-n', 0) ],
"_unchanged_a_1_rel" : [ SenseInfo('00355258-a', 2), SenseInfo('00353206-a', 1), SenseInfo('00355258-a', 2), SenseInfo('00353206-a', 1) ],
"_consideration_n_of_rel" : [ SenseInfo('05784831-n', 17), SenseInfo('05822746-n', 11), SenseInfo('07138915-n', 1), SenseInfo('04841358-n', 1), SenseInfo('13323313-n', 0), SenseInfo('01229793-n', 0) ],
"_waterslide_n_1_rel" : [  ],
"_employ_n_1_rel" : [ SenseInfo('13968092-n', 1) ],
"_wrest_v_away_rel" : [ SenseInfo('01213998-v', 0) ],
"_functionalize_v_1_rel" : [  ],
"_displace_v_as_rel" : [ SenseInfo('02013571-v', 1), SenseInfo('02406011-v', 0), SenseInfo('02402825-v', 0), SenseInfo('01850315-v', 0) ],
"_a+ways_a_1_rel" : [  ],
"_fret_n_1_rel" : [ SenseInfo('14403560-n', 0), SenseInfo('04683002-n', 0), SenseInfo('03396311-n', 0), SenseInfo('03396074-n', 0) ],
"_exhaustion_n_1_rel" : [ SenseInfo('14017206-n', 2), SenseInfo('07331210-n', 0), SenseInfo('00356621-n', 0) ],
"_crude_a_1_rel" : [ SenseInfo('02229584-a', 6), SenseInfo('00683531-a', 2), SenseInfo('01953467-a', 0), SenseInfo('00818175-a', 0), SenseInfo('00556881-a', 0), SenseInfo('00417204-a', 0), SenseInfo('02229584-a', 6), SenseInfo('00683531-a', 2), SenseInfo('01953467-a', 0), SenseInfo('00818175-a', 0), SenseInfo('00556881-a', 0), SenseInfo('00417204-a', 0), SenseInfo('02229584-a', 6), SenseInfo('00683531-a', 2), SenseInfo('01953467-a', 0), SenseInfo('00818175-a', 0), SenseInfo('00556881-a', 0), SenseInfo('00417204-a', 0), SenseInfo('02229584-a', 6), SenseInfo('00683531-a', 2), SenseInfo('01953467-a', 0), SenseInfo('00818175-a', 0), SenseInfo('00556881-a', 0), SenseInfo('00417204-a', 0) ],
"_versatile_a_1_rel" : [ SenseInfo('02507772-a', 0), SenseInfo('02505617-a', 0), SenseInfo('02228163-a', 0), SenseInfo('01524722-a', 0) ],
"_familiar_n_1_rel" : [ SenseInfo('10077106-n', 0), SenseInfo('09945905-n', 0), SenseInfo('09545171-n', 0) ],
"_gust_n_of_rel" : [ SenseInfo('11465017-n', 3) ],
"_interrupt_n_1_rel" : [ SenseInfo('11447532-n', 0) ],
"_atom_n_1_rel" : [ SenseInfo('14619225-n', 19), SenseInfo('14585519-n', 0) ],
"_debilitating_a_for_rel" : [ SenseInfo('01357966-a', 2), SenseInfo('01357966-a', 2), SenseInfo('01357966-a', 2) ],
"_caravan_n_of_rel" : [ SenseInfo('08427629-n', 1), SenseInfo('04520382-n', 0), SenseInfo('08427629-n', 1), SenseInfo('04520382-n', 0) ],
"_spring_v_up_rel" : [ SenseInfo('01963942-v', 15), SenseInfo('02623906-v', 5), SenseInfo('01892104-v', 2), SenseInfo('00095271-v', 1), SenseInfo('00935827-v', 0) ],
"_swallow_n_1_rel" : [ SenseInfo('07579276-n', 3), SenseInfo('00839778-n', 1), SenseInfo('01594372-n', 0) ],
"_chide_v_1_rel" : [ SenseInfo('00824767-v', 3) ],
"_bisque_n_1_rel" : [ SenseInfo('07584332-n', 0) ],
"_tertiary_a_1_rel" : [ SenseInfo('02202307-a', 0) ],
"_interest_v_1_rel" : [ SenseInfo('01821423-v', 5), SenseInfo('02678438-v', 2), SenseInfo('02678663-v', 1), SenseInfo('01821423-v', 5), SenseInfo('02678438-v', 2), SenseInfo('02678663-v', 1), SenseInfo('01821423-v', 5), SenseInfo('02678438-v', 2), SenseInfo('02678663-v', 1) ],
"_btw_a_1_rel" : [  ],
"_well-organized_a_1_rel" : [  ],
"_shortcut_n_1_rel" : [ SenseInfo('04204953-n', 1) ],
"_abase_v_1_rel" : [ SenseInfo('01799794-v', 0) ],
"_program_n_1_rel" : [ SenseInfo('05898568-n', 106), SenseInfo('05899087-n', 36), SenseInfo('06619428-n', 5), SenseInfo('06501311-n', 3), SenseInfo('06748466-n', 0), SenseInfo('06676416-n', 0), SenseInfo('06568978-n', 0), SenseInfo('00551215-n', 0) ],
"_sanction_v_1_rel" : [ SenseInfo('00806502-v', 6), SenseInfo('02479154-v', 1), SenseInfo('00806891-v', 0) ],
"_apron_n_1_rel" : [ SenseInfo('02730930-n', 3), SenseInfo('08496334-n', 0), SenseInfo('04013362-n', 0), SenseInfo('02731123-n', 0) ],
"_openness_n_1_rel" : [ SenseInfo('05083905-n', 0), SenseInfo('04654066-n', 0), SenseInfo('04645020-n', 0) ],
"_canarygrass_n_1_rel" : [  ],
"_elect_v_1_rel" : [ SenseInfo('02400760-v', 21), SenseInfo('00676864-v', 3), SenseInfo('02400760-v', 21), SenseInfo('00676864-v', 3), SenseInfo('02400760-v', 21), SenseInfo('00676864-v', 3), SenseInfo('02400760-v', 21), SenseInfo('00676864-v', 3) ],
"_off-shore_a_1_rel" : [ SenseInfo('00464399-a', 0), SenseInfo('01381340-a', 0), SenseInfo('00464399-a', 0), SenseInfo('01381340-a', 0), SenseInfo('00464399-a', 0), SenseInfo('01381340-a', 0) ],
"_warp_v_1_rel" : [ SenseInfo('00835903-v', 2), SenseInfo('00356954-v', 1) ],
"_glower_v_at_rel" : [ SenseInfo('00033203-v', 4), SenseInfo('00032981-v', 0), SenseInfo('00033203-v', 4), SenseInfo('00032981-v', 0) ],
"_have_v_qmodal-2_rel" : [ SenseInfo('02203362-v', 1202), SenseInfo('02630189-v', 377), SenseInfo('02108026-v', 220), SenseInfo('02204692-v', 143), SenseInfo('00120796-v', 64), SenseInfo('01156834-v', 42), SenseInfo('02378453-v', 31), SenseInfo('01733477-v', 30), SenseInfo('02205098-v', 28), SenseInfo('02740745-v', 25), SenseInfo('00121046-v', 25), SenseInfo('00065370-v', 11), SenseInfo('00770437-v', 8), SenseInfo('02236124-v', 7), SenseInfo('02210119-v', 7), SenseInfo('00065639-v', 5), SenseInfo('02355596-v', 3), SenseInfo('00056930-v', 3), SenseInfo('01427127-v', 2) ],
"_successive_a_1_rel" : [ SenseInfo('01667729-a', 5), SenseInfo('01667729-a', 5) ],
"_rough_v_out_rel" : [ SenseInfo('01754452-v', 1) ],
"_structure_v_1_rel" : [ SenseInfo('00404222-v', 1) ],
"_return_v_to_rel" : [ SenseInfo('02004874-v', 111), SenseInfo('02310007-v', 14), SenseInfo('00387310-v', 12), SenseInfo('00959524-v', 5), SenseInfo('02078294-v', 3), SenseInfo('02357072-v', 2), SenseInfo('01433159-v', 2), SenseInfo('00816353-v', 2), SenseInfo('00548153-v', 2), SenseInfo('02284951-v', 1), SenseInfo('01062253-v', 1), SenseInfo('02401296-v', 0), SenseInfo('02229550-v', 0), SenseInfo('02005617-v', 0), SenseInfo('01629000-v', 0), SenseInfo('00879028-v', 0) ],
"_weasel_n_1_rel" : [ SenseInfo('10771990-n', 0), SenseInfo('02441942-n', 0) ],
"_taxation_n_of_rel" : [ SenseInfo('13308999-n', 0), SenseInfo('13261916-n', 0), SenseInfo('01160170-n', 0) ],
"_merriment_n_1_rel" : [ SenseInfo('07529245-n', 2), SenseInfo('00429949-n', 1) ],
"_darkness_n_1_rel" : [ SenseInfo('13983515-n', 20), SenseInfo('08646306-n', 6), SenseInfo('14563564-n', 2), SenseInfo('05988498-n', 1), SenseInfo('04979870-n', 0), SenseInfo('04978216-n', 0) ],
"_weekly_a_1_rel" : [ SenseInfo('01968503-a', 0), SenseInfo('01968503-a', 0) ],
"_depose_v_1_rel" : [ SenseInfo('02405252-v', 2), SenseInfo('01013040-v', 0) ],
"_gallows_n_1_rel" : [ SenseInfo('03412906-n', 1) ],
"_manservant_n_1_rel" : [ SenseInfo('10292192-n', 1) ],
"_let_v_off_rel" : [ SenseInfo('02423183-v', 219), SenseInfo('00771490-v', 15), SenseInfo('00802318-v', 2), SenseInfo('00120796-v', 2), SenseInfo('00496673-v', 1), SenseInfo('02208903-v', 0) ],
"_firkin_n_1_rel" : [ SenseInfo('13622769-n', 0), SenseInfo('03349296-n', 0) ],
"_NKr_n_1_rel" : [  ],
"_essential_a_for_rel" : [ SenseInfo('01580306-a', 17), SenseInfo('00900616-a', 15), SenseInfo('01276150-a', 8), SenseInfo('02722988-a', 0), SenseInfo('00055539-a', 0), SenseInfo('01580306-a', 17), SenseInfo('00900616-a', 15), SenseInfo('01276150-a', 8), SenseInfo('02722988-a', 0), SenseInfo('00055539-a', 0), SenseInfo('01580306-a', 17), SenseInfo('00900616-a', 15), SenseInfo('01276150-a', 8), SenseInfo('02722988-a', 0), SenseInfo('00055539-a', 0), SenseInfo('01580306-a', 17), SenseInfo('00900616-a', 15), SenseInfo('01276150-a', 8), SenseInfo('02722988-a', 0), SenseInfo('00055539-a', 0) ],
"_bet_v_1_rel" : [ SenseInfo('00918580-v', 19), SenseInfo('01155687-v', 0), SenseInfo('00712708-v', 0) ],
"_rely_v_on_rel" : [ SenseInfo('00688377-v', 1) ],
"_dais_n_1_rel" : [ SenseInfo('03159640-n', 1) ],
"_shimmer_v_1_rel" : [ SenseInfo('02763450-v', 0), SenseInfo('02706478-v', 0) ],
"_fast_n_1_rel" : [ SenseInfo('01069980-n', 1) ],
"_destructive_a_1_rel" : [ SenseInfo('00586183-a', 6) ],
"_plug_v_in_rel" : [ SenseInfo('01422886-v', 2), SenseInfo('00351266-v', 1), SenseInfo('01415285-v', 0), SenseInfo('00976487-v', 0), SenseInfo('00188137-v', 0), SenseInfo('00188000-v', 0), SenseInfo('01422886-v', 2), SenseInfo('00351266-v', 1), SenseInfo('01415285-v', 0), SenseInfo('00976487-v', 0), SenseInfo('00188137-v', 0), SenseInfo('00188000-v', 0) ],
"_jammed_a_1_rel" : [ SenseInfo('00560100-a', 1) ],
"_chirp_v_1_rel" : [ SenseInfo('01052301-v', 1), SenseInfo('01730663-v', 0) ],
"_prototype_v_1_rel" : [  ],
"_presumable_a_1_rel" : [ SenseInfo('02418412-a', 0) ],
"_contractor_n_1_rel" : [ SenseInfo('09960688-n', 5), SenseInfo('09961012-n', 0), SenseInfo('09960891-n', 0), SenseInfo('05289601-n', 0) ],
"_value_v_1_rel" : [ SenseInfo('00695226-v', 2), SenseInfo('02256109-v', 1), SenseInfo('00694068-v', 1), SenseInfo('00681429-v', 0), SenseInfo('00660971-v', 0) ],
"_pride_n_1_rel" : [ SenseInfo('07508486-n', 6), SenseInfo('07531536-n', 5), SenseInfo('04886646-n', 3), SenseInfo('07995278-n', 0), SenseInfo('00758175-n', 0) ],
"_low_n_1_rel" : [ SenseInfo('14520829-n', 0), SenseInfo('11142155-n', 0), SenseInfo('05097706-n', 0), SenseInfo('03350011-n', 0) ],
"_trolley_n_1_rel" : [ SenseInfo('04335435-n', 0) ],
"_co-writer_n_1_rel" : [  ],
"_riverbank_n_1_rel" : [ SenseInfo('09415584-n', 2) ],
"_wadding_n_1_rel" : [ SenseInfo('14976448-n', 0) ],
"_offender_n_1_rel" : [ SenseInfo('09633969-n', 1), SenseInfo('09633969-n', 1), SenseInfo('09633969-n', 1) ],
"_clot_n_1_rel" : [ SenseInfo('05402091-n', 1) ],
"_sharp_a_1_rel" : [ SenseInfo('00780352-a', 9), SenseInfo('01810189-a', 6), SenseInfo('01744515-a', 6), SenseInfo('00438909-a', 6), SenseInfo('01804728-a', 3), SenseInfo('01214430-a', 3), SenseInfo('01145151-a', 3), SenseInfo('00803038-a', 2), SenseInfo('00800826-a', 1), SenseInfo('01577973-a', 0), SenseInfo('01144230-a', 0), SenseInfo('00842810-a', 0), SenseInfo('00780352-a', 9), SenseInfo('01810189-a', 6), SenseInfo('01744515-a', 6), SenseInfo('00438909-a', 6), SenseInfo('01804728-a', 3), SenseInfo('01214430-a', 3), SenseInfo('01145151-a', 3), SenseInfo('00803038-a', 2), SenseInfo('00800826-a', 1), SenseInfo('01577973-a', 0), SenseInfo('01144230-a', 0), SenseInfo('00842810-a', 0), SenseInfo('00780352-a', 9), SenseInfo('01810189-a', 6), SenseInfo('01744515-a', 6), SenseInfo('00438909-a', 6), SenseInfo('01804728-a', 3), SenseInfo('01214430-a', 3), SenseInfo('01145151-a', 3), SenseInfo('00803038-a', 2), SenseInfo('00800826-a', 1), SenseInfo('01577973-a', 0), SenseInfo('01144230-a', 0), SenseInfo('00842810-a', 0), SenseInfo('00780352-a', 9), SenseInfo('01810189-a', 6), SenseInfo('01744515-a', 6), SenseInfo('00438909-a', 6), SenseInfo('01804728-a', 3), SenseInfo('01214430-a', 3), SenseInfo('01145151-a', 3), SenseInfo('00803038-a', 2), SenseInfo('00800826-a', 1), SenseInfo('01577973-a', 0), SenseInfo('01144230-a', 0), SenseInfo('00842810-a', 0) ],
"_abnormal_a_1_rel" : [ SenseInfo('01595596-a', 1), SenseInfo('01598592-a', 0), SenseInfo('01533535-a', 0), SenseInfo('01595596-a', 1), SenseInfo('01598592-a', 0), SenseInfo('01533535-a', 0) ],
"_juvenile_a_1_rel" : [ SenseInfo('02892980-a', 1), SenseInfo('01492596-a', 0) ],
"_marshland_n_1_rel" : [ SenseInfo('09347779-n', 0) ],
"_ventilate_v_1_rel" : [ SenseInfo('00488770-v', 1), SenseInfo('02112345-v', 0), SenseInfo('02042672-v', 0), SenseInfo('00944548-v', 0), SenseInfo('00581891-v', 0) ],
"_lost_n_1_rel" : [ SenseInfo('07946694-n', 1) ],
"_warm_a_1_rel" : [ SenseInfo('02529264-a', 27), SenseInfo('02530861-a', 8), SenseInfo('02531919-a', 3), SenseInfo('01464700-a', 1), SenseInfo('01068609-a', 0), SenseInfo('00919018-a', 0), SenseInfo('00886117-a', 0), SenseInfo('00806387-a', 0), SenseInfo('00479192-a', 0), SenseInfo('00445308-a', 0), SenseInfo('02529264-a', 27), SenseInfo('02530861-a', 8), SenseInfo('02531919-a', 3), SenseInfo('01464700-a', 1), SenseInfo('01068609-a', 0), SenseInfo('00919018-a', 0), SenseInfo('00886117-a', 0), SenseInfo('00806387-a', 0), SenseInfo('00479192-a', 0), SenseInfo('00445308-a', 0), SenseInfo('02529264-a', 27), SenseInfo('02530861-a', 8), SenseInfo('02531919-a', 3), SenseInfo('01464700-a', 1), SenseInfo('01068609-a', 0), SenseInfo('00919018-a', 0), SenseInfo('00886117-a', 0), SenseInfo('00806387-a', 0), SenseInfo('00479192-a', 0), SenseInfo('00445308-a', 0), SenseInfo('02529264-a', 27), SenseInfo('02530861-a', 8), SenseInfo('02531919-a', 3), SenseInfo('01464700-a', 1), SenseInfo('01068609-a', 0), SenseInfo('00919018-a', 0), SenseInfo('00886117-a', 0), SenseInfo('00806387-a', 0), SenseInfo('00479192-a', 0), SenseInfo('00445308-a', 0), SenseInfo('02529264-a', 27), SenseInfo('02530861-a', 8), SenseInfo('02531919-a', 3), SenseInfo('01464700-a', 1), SenseInfo('01068609-a', 0), SenseInfo('00919018-a', 0), SenseInfo('00886117-a', 0), SenseInfo('00806387-a', 0), SenseInfo('00479192-a', 0), SenseInfo('00445308-a', 0), SenseInfo('02529264-a', 27), SenseInfo('02530861-a', 8), SenseInfo('02531919-a', 3), SenseInfo('01464700-a', 1), SenseInfo('01068609-a', 0), SenseInfo('00919018-a', 0), SenseInfo('00886117-a', 0), SenseInfo('00806387-a', 0), SenseInfo('00479192-a', 0), SenseInfo('00445308-a', 0), SenseInfo('02529264-a', 27), SenseInfo('02530861-a', 8), SenseInfo('02531919-a', 3), SenseInfo('01464700-a', 1), SenseInfo('01068609-a', 0), SenseInfo('00919018-a', 0), SenseInfo('00886117-a', 0), SenseInfo('00806387-a', 0), SenseInfo('00479192-a', 0), SenseInfo('00445308-a', 0) ],
"_get-out-the-vote_n_1_rel" : [  ],
"_chat_n_1_rel" : [ SenseInfo('07134850-n', 0), SenseInfo('01569836-n', 0), SenseInfo('01560636-n', 0) ],
"_quadrille_n_1_rel" : [ SenseInfo('07056593-n', 0), SenseInfo('00540485-n', 0) ],
"_inhere_v_in_rel" : [ SenseInfo('02653564-v', 0) ],
"_hatchway_n_1_rel" : [ SenseInfo('03499142-n', 2) ],
"_anorexia+nervosa_n_1_rel" : [ SenseInfo('14061263-n', 0) ],
"_ivory_a_1_rel" : [ SenseInfo('14757547-n', 6), SenseInfo('04961331-n', 2) ],
"_uppermost_a_1_rel" : [ SenseInfo('02440461-a', 1) ],
"_gardener_n_1_rel" : [ SenseInfo('10120533-n', 3), SenseInfo('10120671-n', 0) ],
"_hazmat_n_1_rel" : [ SenseInfo('14586119-n', 0) ],
"_hoarse_a_1_rel" : [ SenseInfo('00299690-a', 7) ],
"_scarcely_x_deg_rel" : [ SenseInfo('00002621-r', 10), SenseInfo('00003093-r', 0) ],
"_superficies_n_1_rel" : [ SenseInfo('04677113-n', 0), SenseInfo('04358381-n', 0) ],
"_geminate_v_1_rel" : [ SenseInfo('01735556-v', 0), SenseInfo('01465365-v', 0), SenseInfo('01465218-v', 0), SenseInfo('00246588-v', 0) ],
"_tax_v_1_rel" : [ SenseInfo('02307547-v', 16), SenseInfo('02308389-v', 0), SenseInfo('01166237-v', 0), SenseInfo('00844161-v', 0), SenseInfo('02307547-v', 16), SenseInfo('02308389-v', 0), SenseInfo('01166237-v', 0), SenseInfo('00844161-v', 0), SenseInfo('02307547-v', 16), SenseInfo('02308389-v', 0), SenseInfo('01166237-v', 0), SenseInfo('00844161-v', 0), SenseInfo('02307547-v', 16), SenseInfo('02308389-v', 0), SenseInfo('01166237-v', 0), SenseInfo('00844161-v', 0) ],
"_extremely_x_deg_rel" : [ SenseInfo('00089408-r', 11), SenseInfo('00046299-r', 6) ],
"_mo_n_1_rel" : [ SenseInfo('15246853-n', 0), SenseInfo('14645661-n', 0), SenseInfo('09105821-n', 0) ],
"_asylum_n_1_rel" : [ SenseInfo('04071102-n', 0), SenseInfo('03746574-n', 0) ],
"_shell_v_out_rel" : [ SenseInfo('01135922-v', 1), SenseInfo('01759021-v', 0), SenseInfo('01513710-v', 0), SenseInfo('01406195-v', 0), SenseInfo('01316813-v', 0), SenseInfo('01101913-v', 0), SenseInfo('00197744-v', 0), SenseInfo('00181258-v', 0), SenseInfo('01135922-v', 1), SenseInfo('01759021-v', 0), SenseInfo('01513710-v', 0), SenseInfo('01406195-v', 0), SenseInfo('01316813-v', 0), SenseInfo('01101913-v', 0), SenseInfo('00197744-v', 0), SenseInfo('00181258-v', 0) ],
"_convert_n_1_rel" : [ SenseInfo('09962414-n', 3) ],
"_brains_n_i_rel" : [ SenseInfo('05481095-n', 22), SenseInfo('05618056-n', 5), SenseInfo('05611302-n', 5), SenseInfo('10126926-n', 3), SenseInfo('07652585-n', 0) ],
"_saudi_a_1_rel" : [ SenseInfo('03114139-a', 0) ],
"_haunt_n_1_rel" : [ SenseInfo('08581503-n', 2) ],
"_affluence_n_1_rel" : [ SenseInfo('14491625-n', 3) ],
"_loose-knit_a_1_rel" : [  ],
"_cheerless_a_1_rel" : [ SenseInfo('00364479-a', 0) ],
"_screech_v_1_rel" : [ SenseInfo('02171664-v', 5), SenseInfo('01048939-v', 0), SenseInfo('02171664-v', 5), SenseInfo('01048939-v', 0) ],
"_litterer_n_1_rel" : [ SenseInfo('10267166-n', 0) ],
"_rumble_v_1_rel" : [ SenseInfo('02187320-v', 3), SenseInfo('01045719-v', 1) ],
"_fuzziness_n_1_rel" : [ SenseInfo('04704346-n', 0) ],
"_on+behalf+of_p_rel" : [  ],
"_genitive_n_1_rel" : [ SenseInfo('06311852-n', 0) ],
"_hospital_n_1_rel" : [ SenseInfo('03540595-n', 25), SenseInfo('08054417-n', 0), SenseInfo('03540595-n', 25), SenseInfo('08054417-n', 0), SenseInfo('03540595-n', 25), SenseInfo('08054417-n', 0) ],
"_curl_v_cause_rel" : [ SenseInfo('00362128-v', 3), SenseInfo('02098458-v', 2), SenseInfo('01523986-v', 2), SenseInfo('01223616-v', 1), SenseInfo('01074074-v', 0) ],
"_away_p_sel_rel" : [ SenseInfo('00232936-r', 70), SenseInfo('00233295-r', 21), SenseInfo('00234052-r', 13), SenseInfo('00234553-r', 3), SenseInfo('00235254-r', 2), SenseInfo('00234747-r', 2), SenseInfo('00235438-r', 1), SenseInfo('01847864-a', 1), SenseInfo('01219938-a', 0), SenseInfo('00235570-r', 0), SenseInfo('00235070-r', 0), SenseInfo('00234951-r', 0), SenseInfo('00233687-r', 0), SenseInfo('00023655-a', 0) ],
"_others_n_of_rel" : [  ],
"_cuban_n_1_rel" : [ SenseInfo('09698901-n', 0) ],
"_denominate_v_1_rel" : [ SenseInfo('01030132-v', 0) ],
"_tell_v_1_rel" : [ SenseInfo('01009240-v', 196), SenseInfo('00952524-v', 189), SenseInfo('00953216-v', 75), SenseInfo('00746718-v', 60), SenseInfo('00720961-v', 27), SenseInfo('01019643-v', 6), SenseInfo('00954422-v', 4), SenseInfo('00650353-v', 3), SenseInfo('01009240-v', 196), SenseInfo('00952524-v', 189), SenseInfo('00953216-v', 75), SenseInfo('00746718-v', 60), SenseInfo('00720961-v', 27), SenseInfo('01019643-v', 6), SenseInfo('00954422-v', 4), SenseInfo('00650353-v', 3), SenseInfo('01009240-v', 196), SenseInfo('00952524-v', 189), SenseInfo('00953216-v', 75), SenseInfo('00746718-v', 60), SenseInfo('00720961-v', 27), SenseInfo('01019643-v', 6), SenseInfo('00954422-v', 4), SenseInfo('00650353-v', 3), SenseInfo('01009240-v', 196), SenseInfo('00952524-v', 189), SenseInfo('00953216-v', 75), SenseInfo('00746718-v', 60), SenseInfo('00720961-v', 27), SenseInfo('01019643-v', 6), SenseInfo('00954422-v', 4), SenseInfo('00650353-v', 3), SenseInfo('01009240-v', 196), SenseInfo('00952524-v', 189), SenseInfo('00953216-v', 75), SenseInfo('00746718-v', 60), SenseInfo('00720961-v', 27), SenseInfo('01019643-v', 6), SenseInfo('00954422-v', 4), SenseInfo('00650353-v', 3), SenseInfo('01009240-v', 196), SenseInfo('00952524-v', 189), SenseInfo('00953216-v', 75), SenseInfo('00746718-v', 60), SenseInfo('00720961-v', 27), SenseInfo('01019643-v', 6), SenseInfo('00954422-v', 4), SenseInfo('00650353-v', 3) ],
"_arctic_n_1_rel" : [ SenseInfo('08496477-n', 2), SenseInfo('02735538-n', 0) ],
"_field_n_of_rel" : [ SenseInfo('08569998-n', 49), SenseInfo('08506641-n', 22), SenseInfo('08569777-n', 20), SenseInfo('05996646-n', 18), SenseInfo('11456760-n', 14), SenseInfo('01097119-n', 9), SenseInfo('14514039-n', 8), SenseInfo('08570758-n', 8), SenseInfo('09393605-n', 7), SenseInfo('08005260-n', 7), SenseInfo('08551628-n', 4), SenseInfo('07999584-n', 1), SenseInfo('07999471-n', 1), SenseInfo('08659446-n', 0), SenseInfo('08005580-n', 0), SenseInfo('05932891-n', 0), SenseInfo('02687992-n', 0), SenseInfo('08569998-n', 49), SenseInfo('08506641-n', 22), SenseInfo('08569777-n', 20), SenseInfo('05996646-n', 18), SenseInfo('11456760-n', 14), SenseInfo('01097119-n', 9), SenseInfo('14514039-n', 8), SenseInfo('08570758-n', 8), SenseInfo('09393605-n', 7), SenseInfo('08005260-n', 7), SenseInfo('08551628-n', 4), SenseInfo('07999584-n', 1), SenseInfo('07999471-n', 1), SenseInfo('08659446-n', 0), SenseInfo('08005580-n', 0), SenseInfo('05932891-n', 0), SenseInfo('02687992-n', 0) ],
"_as-needed_a_1_rel" : [  ],
"_chaplain_n_1_rel" : [ SenseInfo('09908508-n', 0) ],
"_language_n_1_rel" : [ SenseInfo('06282651-n', 48), SenseInfo('07109196-n', 5), SenseInfo('07051975-n', 2), SenseInfo('05808557-n', 1), SenseInfo('05650820-n', 1), SenseInfo('06304059-n', 0), SenseInfo('06282651-n', 48), SenseInfo('07109196-n', 5), SenseInfo('07051975-n', 2), SenseInfo('05808557-n', 1), SenseInfo('05650820-n', 1), SenseInfo('06304059-n', 0), SenseInfo('06282651-n', 48), SenseInfo('07109196-n', 5), SenseInfo('07051975-n', 2), SenseInfo('05808557-n', 1), SenseInfo('05650820-n', 1), SenseInfo('06304059-n', 0), SenseInfo('06282651-n', 48), SenseInfo('07109196-n', 5), SenseInfo('07051975-n', 2), SenseInfo('05808557-n', 1), SenseInfo('05650820-n', 1), SenseInfo('06304059-n', 0), SenseInfo('06282651-n', 48), SenseInfo('07109196-n', 5), SenseInfo('07051975-n', 2), SenseInfo('05808557-n', 1), SenseInfo('05650820-n', 1), SenseInfo('06304059-n', 0), SenseInfo('06282651-n', 48), SenseInfo('07109196-n', 5), SenseInfo('07051975-n', 2), SenseInfo('05808557-n', 1), SenseInfo('05650820-n', 1), SenseInfo('06304059-n', 0), SenseInfo('06282651-n', 48), SenseInfo('07109196-n', 5), SenseInfo('07051975-n', 2), SenseInfo('05808557-n', 1), SenseInfo('05650820-n', 1), SenseInfo('06304059-n', 0), SenseInfo('06282651-n', 48), SenseInfo('07109196-n', 5), SenseInfo('07051975-n', 2), SenseInfo('05808557-n', 1), SenseInfo('05650820-n', 1), SenseInfo('06304059-n', 0) ],
"_wireless_a_1_rel" : [ SenseInfo('02569030-a', 0) ],
"_swindle_v_1_rel" : [ SenseInfo('02572119-v', 2) ],
"_introductory_a_1_rel" : [ SenseInfo('01009709-a', 3), SenseInfo('01011753-a', 0), SenseInfo('00126339-a', 0) ],
"_pogo_n_1_rel" : [  ],
"_schlep_v_around_rel" : [ SenseInfo('01453718-v', 0) ],
"_outright_x_deg_rel" : [ SenseInfo('00097731-r', 2), SenseInfo('01914407-a', 1), SenseInfo('00097620-r', 0), SenseInfo('00033421-r', 0) ],
"much-many_a_rel" : [  ],
"_bronze_v_1_rel" : [ SenseInfo('00281913-v', 0), SenseInfo('00103875-v', 0) ],
"_detachment_n_of_rel" : [ SenseInfo('07506031-n', 1), SenseInfo('00390906-n', 1), SenseInfo('14415518-n', 0), SenseInfo('08215248-n', 0), SenseInfo('07331400-n', 0) ],
"_niter_n_1_rel" : [ SenseInfo('14861355-n', 0) ],
"_abbey_n_1_rel" : [ SenseInfo('02667576-n', 1), SenseInfo('02667478-n', 0), SenseInfo('02667379-n', 0), SenseInfo('02667576-n', 1), SenseInfo('02667478-n', 0), SenseInfo('02667379-n', 0) ],
"_slight_n_1_rel" : [ SenseInfo('01225783-n', 2) ],
"_ballast_n_1_rel" : [ SenseInfo('02779845-n', 1), SenseInfo('14699209-n', 0), SenseInfo('04691992-n', 0), SenseInfo('02780121-n', 0), SenseInfo('02779971-n', 0) ],
"_overland_a_1_rel" : [ SenseInfo('00125170-a', 0) ],
"_aerospace_n_1_rel" : [ SenseInfo('08502171-n', 0) ],
"_dragonfly_n_1_rel" : [ SenseInfo('02268443-n', 0) ],
"_remark_n_1_rel" : [ SenseInfo('06765044-n', 32), SenseInfo('05710573-n', 0), SenseInfo('06765044-n', 32), SenseInfo('05710573-n', 0) ],
"_craftsman_n_1_rel" : [ SenseInfo('09975630-n', 1), SenseInfo('09975425-n', 1), SenseInfo('09974648-n', 1) ],
"_bring_v_home_rel" : [ SenseInfo('02077656-v', 122), SenseInfo('01438902-v', 55), SenseInfo('01629589-v', 31), SenseInfo('01433294-v', 19), SenseInfo('00135857-v', 9), SenseInfo('01434140-v', 4), SenseInfo('01618547-v', 3), SenseInfo('02324478-v', 2), SenseInfo('02247390-v', 1), SenseInfo('01808218-v', 0), SenseInfo('00767334-v', 0) ],
"_present_a_1_rel" : [ SenseInfo('01731351-a', 60), SenseInfo('01846413-a', 39), SenseInfo('01731351-a', 60), SenseInfo('01846413-a', 39), SenseInfo('01731351-a', 60), SenseInfo('01846413-a', 39), SenseInfo('01731351-a', 60), SenseInfo('01846413-a', 39) ],
"_password_n_1_rel" : [ SenseInfo('06674188-n', 0) ],
"_validate_v_1_rel" : [ SenseInfo('02478701-v', 2), SenseInfo('00667224-v', 2), SenseInfo('01012561-v', 0), SenseInfo('00448290-v', 0) ],
"_striving_n_1_rel" : [ SenseInfo('00788766-n', 3) ],
"_distracted_a_1_rel" : [ SenseInfo('00165458-a', 0) ],
"_crack_v_open_rel" : [ SenseInfo('00336260-v', 6), SenseInfo('02183024-v', 4), SenseInfo('02182851-v', 2), SenseInfo('01401955-v', 2), SenseInfo('00539770-v', 2), SenseInfo('00337234-v', 1), SenseInfo('00337065-v', 1), SenseInfo('02571067-v', 0), SenseInfo('01785579-v', 0), SenseInfo('00953923-v', 0), SenseInfo('00336718-v', 0), SenseInfo('00238542-v', 0), SenseInfo('00238372-v', 0), SenseInfo('00336260-v', 6), SenseInfo('02183024-v', 4), SenseInfo('02182851-v', 2), SenseInfo('01401955-v', 2), SenseInfo('00539770-v', 2), SenseInfo('00337234-v', 1), SenseInfo('00337065-v', 1), SenseInfo('02571067-v', 0), SenseInfo('01785579-v', 0), SenseInfo('00953923-v', 0), SenseInfo('00336718-v', 0), SenseInfo('00238542-v', 0), SenseInfo('00238372-v', 0) ],
"_ordeal_n_1_rel" : [ SenseInfo('07287730-n', 3), SenseInfo('01196477-n', 0) ],
"_giant_a_1_rel" : [ SenseInfo('01385773-a', 9) ],
"_underpass_n_1_rel" : [ SenseInfo('04508804-n', 0) ],
"_prison_n_1_rel" : [ SenseInfo('04005630-n', 3), SenseInfo('13937284-n', 0) ],
"_surly_a_1_rel" : [ SenseInfo('01139067-a', 1), SenseInfo('01139067-a', 1), SenseInfo('01139067-a', 1) ],
"_en+route_p_rel" : [ SenseInfo('00171322-r', 0), SenseInfo('00171322-r', 0) ],
"_show_v_as_rel" : [ SenseInfo('02148788-v', 136), SenseInfo('00664788-v', 63), SenseInfo('01015244-v', 57), SenseInfo('02137132-v', 43), SenseInfo('01686956-v', 32), SenseInfo('00943837-v', 24), SenseInfo('00923793-v', 24), SenseInfo('02139544-v', 11), SenseInfo('00922867-v', 7), SenseInfo('00923307-v', 6), SenseInfo('02000547-v', 2), SenseInfo('01086549-v', 0), SenseInfo('02148788-v', 136), SenseInfo('00664788-v', 63), SenseInfo('01015244-v', 57), SenseInfo('02137132-v', 43), SenseInfo('01686956-v', 32), SenseInfo('00943837-v', 24), SenseInfo('00923793-v', 24), SenseInfo('02139544-v', 11), SenseInfo('00922867-v', 7), SenseInfo('00923307-v', 6), SenseInfo('02000547-v', 2), SenseInfo('01086549-v', 0), SenseInfo('02148788-v', 136), SenseInfo('00664788-v', 63), SenseInfo('01015244-v', 57), SenseInfo('02137132-v', 43), SenseInfo('01686956-v', 32), SenseInfo('00943837-v', 24), SenseInfo('00923793-v', 24), SenseInfo('02139544-v', 11), SenseInfo('00922867-v', 7), SenseInfo('00923307-v', 6), SenseInfo('02000547-v', 2), SenseInfo('01086549-v', 0) ],
"_trouble_v_1_rel" : [ SenseInfo('01770501-v', 6), SenseInfo('02507736-v', 3), SenseInfo('01764171-v', 3), SenseInfo('02507464-v', 1), SenseInfo('00070816-v', 1), SenseInfo('01770501-v', 6), SenseInfo('02507736-v', 3), SenseInfo('01764171-v', 3), SenseInfo('02507464-v', 1), SenseInfo('00070816-v', 1), SenseInfo('01770501-v', 6), SenseInfo('02507736-v', 3), SenseInfo('01764171-v', 3), SenseInfo('02507464-v', 1), SenseInfo('00070816-v', 1), SenseInfo('01770501-v', 6), SenseInfo('02507736-v', 3), SenseInfo('01764171-v', 3), SenseInfo('02507464-v', 1), SenseInfo('00070816-v', 1) ],
"_gracious_a_1_rel" : [ SenseInfo('01141743-a', 1), SenseInfo('01372568-a', 0), SenseInfo('00641460-a', 0), SenseInfo('00177834-a', 0) ],
"_rationalize_v_to_rel" : [ SenseInfo('00894738-v', 3), SenseInfo('00473322-v', 2), SenseInfo('02269485-v', 0), SenseInfo('00629257-v', 0), SenseInfo('00568879-v', 0), SenseInfo('00894738-v', 3), SenseInfo('00473322-v', 2), SenseInfo('02269485-v', 0), SenseInfo('00629257-v', 0), SenseInfo('00568879-v', 0), SenseInfo('00894738-v', 3), SenseInfo('00473322-v', 2), SenseInfo('02269485-v', 0), SenseInfo('00629257-v', 0), SenseInfo('00568879-v', 0), SenseInfo('00894738-v', 3), SenseInfo('00473322-v', 2), SenseInfo('02269485-v', 0), SenseInfo('00629257-v', 0), SenseInfo('00568879-v', 0) ],
"_manner_n_of_rel" : [ SenseInfo('04928903-n', 49), SenseInfo('04910135-n', 17), SenseInfo('05845562-n', 7), SenseInfo('04928903-n', 49), SenseInfo('04910135-n', 17), SenseInfo('05845562-n', 7) ],
"_crayfish_n_1_rel" : [ SenseInfo('07793260-n', 0), SenseInfo('07788885-n', 0), SenseInfo('01985128-n', 0), SenseInfo('01984695-n', 0) ],
"_march_v_1_rel" : [ SenseInfo('01996735-v', 24), SenseInfo('02084380-v', 5), SenseInfo('01919391-v', 5), SenseInfo('02521816-v', 1), SenseInfo('01924712-v', 1), SenseInfo('02084587-v', 0), SenseInfo('01466978-v', 0) ],
"_string_v_together_rel" : [ SenseInfo('01359432-v', 2), SenseInfo('00190389-v', 1), SenseInfo('01993805-v', 0), SenseInfo('01360571-v', 0), SenseInfo('01360423-v', 0), SenseInfo('01360316-v', 0), SenseInfo('01359145-v', 0) ],
"_geography_n_1_rel" : [ SenseInfo('06122178-n', 0) ],
"_wispy_a_1_rel" : [ SenseInfo('00991678-a', 0), SenseInfo('00782216-a', 0) ],
"_microscopy_n_1_rel" : [ SenseInfo('00640889-n', 1) ],
"_sloop_n_1_rel" : [ SenseInfo('04242408-n', 1) ],
"_drought_n_1_rel" : [ SenseInfo('14537054-n', 5), SenseInfo('15244505-n', 1) ],
"_deadlock_v_1_rel" : [  ],
"_sideboard_n_1_rel" : [ SenseInfo('04214154-n', 1), SenseInfo('04214046-n', 0), SenseInfo('02912065-n', 0) ],
"_rethink_n_1_rel" : [ SenseInfo('05790012-n', 0), SenseInfo('05790012-n', 0) ],
"_clinker_n_1_rel" : [ SenseInfo('09245212-n', 0), SenseInfo('03043693-n', 0) ],
"_matter_v_to_rel" : [ SenseInfo('02645839-v', 21), SenseInfo('02645839-v', 21), SenseInfo('02645839-v', 21) ],
"_montgolfiere_n_1_rel" : [  ],
"_explain_v_to_rel" : [ SenseInfo('00939277-v', 109), SenseInfo('01065456-v', 9), SenseInfo('00893435-v', 7), SenseInfo('00939277-v', 109), SenseInfo('01065456-v', 9), SenseInfo('00893435-v', 7), SenseInfo('00939277-v', 109), SenseInfo('01065456-v', 9), SenseInfo('00893435-v', 7), SenseInfo('00939277-v', 109), SenseInfo('01065456-v', 9), SenseInfo('00893435-v', 7) ],
"_rink_n_1_rel" : [ SenseInfo('04093625-n', 0) ],
"_punch_n_1_rel" : [ SenseInfo('00134780-n', 1), SenseInfo('07930554-n', 0), SenseInfo('04023249-n', 0) ],
"_diversity_n_1_rel" : [ SenseInfo('04751305-n', 2), SenseInfo('04735711-n', 0) ],
"_tune_n_1_rel" : [ SenseInfo('07028373-n', 12), SenseInfo('04987169-n', 0), SenseInfo('01000843-n', 0), SenseInfo('07028373-n', 12), SenseInfo('04987169-n', 0), SenseInfo('01000843-n', 0) ],
"_fry_v_cause_rel" : [ SenseInfo('02738241-v', 1), SenseInfo('00325328-v', 1), SenseInfo('02484957-v', 0) ],
"_bowl_n_1_rel" : [ SenseInfo('02881193-n', 2), SenseInfo('13893694-n', 1), SenseInfo('02880940-n', 1), SenseInfo('13765531-n', 0), SenseInfo('04295881-n', 0), SenseInfo('02882301-n', 0), SenseInfo('02881546-n', 0), SenseInfo('02881397-n', 0), SenseInfo('00104409-n', 0) ],
"_return_v_1_rel" : [ SenseInfo('02004874-v', 111), SenseInfo('02310007-v', 14), SenseInfo('00387310-v', 12), SenseInfo('00959524-v', 5), SenseInfo('02078294-v', 3), SenseInfo('02357072-v', 2), SenseInfo('01433159-v', 2), SenseInfo('00816353-v', 2), SenseInfo('00548153-v', 2), SenseInfo('02284951-v', 1), SenseInfo('01062253-v', 1), SenseInfo('02401296-v', 0), SenseInfo('02229550-v', 0), SenseInfo('02005617-v', 0), SenseInfo('01629000-v', 0), SenseInfo('00879028-v', 0), SenseInfo('02004874-v', 111), SenseInfo('02310007-v', 14), SenseInfo('00387310-v', 12), SenseInfo('00959524-v', 5), SenseInfo('02078294-v', 3), SenseInfo('02357072-v', 2), SenseInfo('01433159-v', 2), SenseInfo('00816353-v', 2), SenseInfo('00548153-v', 2), SenseInfo('02284951-v', 1), SenseInfo('01062253-v', 1), SenseInfo('02401296-v', 0), SenseInfo('02229550-v', 0), SenseInfo('02005617-v', 0), SenseInfo('01629000-v', 0), SenseInfo('00879028-v', 0), SenseInfo('02004874-v', 111), SenseInfo('02310007-v', 14), SenseInfo('00387310-v', 12), SenseInfo('00959524-v', 5), SenseInfo('02078294-v', 3), SenseInfo('02357072-v', 2), SenseInfo('01433159-v', 2), SenseInfo('00816353-v', 2), SenseInfo('00548153-v', 2), SenseInfo('02284951-v', 1), SenseInfo('01062253-v', 1), SenseInfo('02401296-v', 0), SenseInfo('02229550-v', 0), SenseInfo('02005617-v', 0), SenseInfo('01629000-v', 0), SenseInfo('00879028-v', 0) ],
"_unsaid_a_1_rel" : [ SenseInfo('00942380-a', 1), SenseInfo('00942380-a', 1) ],
"_alfresco_a_1_rel" : [ SenseInfo('01692512-a', 1), SenseInfo('01692512-a', 1) ],
"_intuit_v_1_rel" : [ SenseInfo('00590761-v', 0), SenseInfo('00590761-v', 0) ],
"_have_v_it_rel" : [ SenseInfo('02203362-v', 1202), SenseInfo('02630189-v', 377), SenseInfo('02108026-v', 220), SenseInfo('02204692-v', 143), SenseInfo('00120796-v', 64), SenseInfo('01156834-v', 42), SenseInfo('02378453-v', 31), SenseInfo('01733477-v', 30), SenseInfo('02205098-v', 28), SenseInfo('02740745-v', 25), SenseInfo('00121046-v', 25), SenseInfo('00065370-v', 11), SenseInfo('00770437-v', 8), SenseInfo('02236124-v', 7), SenseInfo('02210119-v', 7), SenseInfo('00065639-v', 5), SenseInfo('02355596-v', 3), SenseInfo('00056930-v', 3), SenseInfo('01427127-v', 2) ],
"_taswegian_n_1_rel" : [  ],
"_thereof_p_rel" : [ SenseInfo('00468024-r', 9), SenseInfo('00043794-r', 0) ],
"comp_not+too_rel" : [  ],
"_dissent_n_1_rel" : [ SenseInfo('07209305-n', 1), SenseInfo('07181358-n', 1), SenseInfo('01177033-n', 0) ],
"_purport_v_1_rel" : [ SenseInfo('00757192-v', 3), SenseInfo('00708980-v', 1) ],
"_puzzle_n_1_rel" : [ SenseInfo('06784639-n', 0), SenseInfo('04028315-n', 0) ],
"_a+priori_a_1_rel" : [ SenseInfo('00138912-a', 0), SenseInfo('00861109-a', 0), SenseInfo('00138912-a', 0), SenseInfo('00861109-a', 0), SenseInfo('00138912-a', 0), SenseInfo('00861109-a', 0), SenseInfo('00138912-a', 0), SenseInfo('00861109-a', 0) ],
"_template_n_1_rel" : [ SenseInfo('05938976-n', 0) ],
"_stab_v_1_rel" : [ SenseInfo('01231652-v', 1), SenseInfo('01230350-v', 0), SenseInfo('01229976-v', 0) ],
"_handstand_n_1_rel" : [ SenseInfo('00436187-n', 3) ],
"_wish_n_1_rel" : [ SenseInfo('07486229-n', 6), SenseInfo('07185870-n', 2), SenseInfo('06630627-n', 0), SenseInfo('05791602-n', 0), SenseInfo('07486229-n', 6), SenseInfo('07185870-n', 2), SenseInfo('06630627-n', 0), SenseInfo('05791602-n', 0), SenseInfo('07486229-n', 6), SenseInfo('07185870-n', 2), SenseInfo('06630627-n', 0), SenseInfo('05791602-n', 0), SenseInfo('07486229-n', 6), SenseInfo('07185870-n', 2), SenseInfo('06630627-n', 0), SenseInfo('05791602-n', 0), SenseInfo('07486229-n', 6), SenseInfo('07185870-n', 2), SenseInfo('06630627-n', 0), SenseInfo('05791602-n', 0) ],
"_submission_n_of_rel" : [ SenseInfo('07167578-n', 3), SenseInfo('01166926-n', 2), SenseInfo('14580090-n', 0), SenseInfo('07509325-n', 0), SenseInfo('06772094-n', 0), SenseInfo('06771957-n', 0), SenseInfo('06731510-n', 0) ],
"_odd_a_to_rel" : [ SenseInfo('00913454-a', 7), SenseInfo('00490845-a', 6), SenseInfo('00916383-a', 3), SenseInfo('00968010-a', 1), SenseInfo('01487496-a', 0), SenseInfo('00926505-a', 0), SenseInfo('00913454-a', 7), SenseInfo('00490845-a', 6), SenseInfo('00916383-a', 3), SenseInfo('00968010-a', 1), SenseInfo('01487496-a', 0), SenseInfo('00926505-a', 0), SenseInfo('00913454-a', 7), SenseInfo('00490845-a', 6), SenseInfo('00916383-a', 3), SenseInfo('00968010-a', 1), SenseInfo('01487496-a', 0), SenseInfo('00926505-a', 0) ],
"_bash_n_1_rel" : [ SenseInfo('07410207-n', 1), SenseInfo('07448038-n', 0) ],
"_ps_a_1_rel" : [ SenseInfo('06764623-n', 0), SenseInfo('06764623-n', 0), SenseInfo('06764623-n', 0), SenseInfo('06764623-n', 0) ],
"_nourish_v_1_rel" : [ SenseInfo('01202728-v', 4), SenseInfo('01204191-v', 1), SenseInfo('01202728-v', 4), SenseInfo('01204191-v', 1) ],
"_garlic_n_1_rel" : [ SenseInfo('12434775-n', 0), SenseInfo('07818277-n', 0) ],
"_diseased_a_1_rel" : [ SenseInfo('01176246-a', 1) ],
"_luminous_a_1_rel" : [ SenseInfo('00279332-a', 3) ],
"_beer_n_1_rel" : [ SenseInfo('07886849-n', 18) ],
"_carry_v_1_rel" : [ SenseInfo('01449974-v', 72), SenseInfo('02717102-v', 36), SenseInfo('02079933-v', 8), SenseInfo('01061017-v', 8), SenseInfo('01218084-v', 6), SenseInfo('01601234-v', 5), SenseInfo('02700867-v', 4), SenseInfo('02561168-v', 4), SenseInfo('00235110-v', 3), SenseInfo('02636325-v', 2), SenseInfo('01101416-v', 2), SenseInfo('00738951-v', 2), SenseInfo('02518161-v', 1), SenseInfo('02285392-v', 1), SenseInfo('01746359-v', 1), SenseInfo('01408760-v', 1), SenseInfo('01061320-v', 1), SenseInfo('02746735-v', 0), SenseInfo('02741357-v', 0), SenseInfo('02682954-v', 0), SenseInfo('02636516-v', 0), SenseInfo('02630734-v', 0), SenseInfo('02586121-v', 0), SenseInfo('02556537-v', 0), SenseInfo('02555684-v', 0), SenseInfo('02359228-v', 0), SenseInfo('02303878-v', 0), SenseInfo('02233195-v', 0), SenseInfo('02012725-v', 0), SenseInfo('02001699-v', 0), SenseInfo('01740320-v', 0), SenseInfo('01241881-v', 0), SenseInfo('01205153-v', 0), SenseInfo('01203074-v', 0), SenseInfo('01123609-v', 0), SenseInfo('01123415-v', 0), SenseInfo('01101571-v', 0), SenseInfo('01100672-v', 0), SenseInfo('01049606-v', 0), SenseInfo('00059019-v', 0), SenseInfo('01449974-v', 72), SenseInfo('02717102-v', 36), SenseInfo('02079933-v', 8), SenseInfo('01061017-v', 8), SenseInfo('01218084-v', 6), SenseInfo('01601234-v', 5), SenseInfo('02700867-v', 4), SenseInfo('02561168-v', 4), SenseInfo('00235110-v', 3), SenseInfo('02636325-v', 2), SenseInfo('01101416-v', 2), SenseInfo('00738951-v', 2), SenseInfo('02518161-v', 1), SenseInfo('02285392-v', 1), SenseInfo('01746359-v', 1), SenseInfo('01408760-v', 1), SenseInfo('01061320-v', 1), SenseInfo('02746735-v', 0), SenseInfo('02741357-v', 0), SenseInfo('02682954-v', 0), SenseInfo('02636516-v', 0), SenseInfo('02630734-v', 0), SenseInfo('02586121-v', 0), SenseInfo('02556537-v', 0), SenseInfo('02555684-v', 0), SenseInfo('02359228-v', 0), SenseInfo('02303878-v', 0), SenseInfo('02233195-v', 0), SenseInfo('02012725-v', 0), SenseInfo('02001699-v', 0), SenseInfo('01740320-v', 0), SenseInfo('01241881-v', 0), SenseInfo('01205153-v', 0), SenseInfo('01203074-v', 0), SenseInfo('01123609-v', 0), SenseInfo('01123415-v', 0), SenseInfo('01101571-v', 0), SenseInfo('01100672-v', 0), SenseInfo('01049606-v', 0), SenseInfo('00059019-v', 0) ],
"_square_v_away_rel" : [ SenseInfo('00145448-v', 4), SenseInfo('00640136-v', 2), SenseInfo('02659656-v', 1), SenseInfo('01987493-v', 1), SenseInfo('02659541-v', 0), SenseInfo('02253341-v', 0), SenseInfo('01124964-v', 0), SenseInfo('01124828-v', 0) ],
"_pest_n_1_rel" : [ SenseInfo('14138691-n', 0), SenseInfo('14076479-n', 0), SenseInfo('10419630-n', 0), SenseInfo('01314388-n', 0) ],
"_program_v_1_rel" : [ SenseInfo('00795264-v', 4), SenseInfo('01747717-v', 3) ],
"_provision_v_1_rel" : [ SenseInfo('02338975-v', 1) ],
"_storm_v_1_rel" : [ SenseInfo('02723016-v', 2), SenseInfo('01586600-v', 1), SenseInfo('02770170-v', 0), SenseInfo('02769900-v', 0), SenseInfo('01126051-v', 0) ],
"_depressor_n_1_rel" : [ SenseInfo('05552467-n', 0), SenseInfo('05476592-n', 0), SenseInfo('03177708-n', 0) ],
"_photographic_a_1_rel" : [ SenseInfo('02838592-a', 7), SenseInfo('00915420-a', 0), SenseInfo('02838592-a', 7), SenseInfo('00915420-a', 0) ],
"_multifariousness_n_1_rel" : [ SenseInfo('04751305-n', 0) ],
"_thunderstruck_a_1_rel" : [ SenseInfo('02358277-a', 0) ],
"_enjoyment_n_of_rel" : [ SenseInfo('07491708-n', 6), SenseInfo('01072072-n', 2), SenseInfo('05190106-n', 1) ],
"_usually_x_deg_rel" : [ SenseInfo('00106921-r', 96) ],
"_massacre_n_1_rel" : [ SenseInfo('00223983-n', 0) ],
"_anywise_a_1_rel" : [  ],
"_on-column_a_1_rel" : [  ],
"_støl_n_1_rel" : [  ],
"_plop_n_1_rel" : [ SenseInfo('07390049-n', 0) ],
"_stock_n_1_rel" : [ SenseInfo('13333833-n', 28), SenseInfo('04321534-n', 3), SenseInfo('04322026-n', 2), SenseInfo('13417071-n', 1), SenseInfo('13367070-n', 1), SenseInfo('08101937-n', 1), SenseInfo('08101410-n', 1), SenseInfo('07585208-n', 1), SenseInfo('14438541-n', 0), SenseInfo('13130305-n', 0), SenseInfo('13127091-n', 0), SenseInfo('11892637-n', 0), SenseInfo('11892029-n', 0), SenseInfo('04322387-n', 0), SenseInfo('04321804-n', 0), SenseInfo('03814727-n', 0), SenseInfo('01887474-n', 0) ],
"_diabetes_n_1_rel" : [ SenseInfo('14117805-n', 1) ],
"_pore_n_1_rel" : [ SenseInfo('13912115-n', 2), SenseInfo('05245906-n', 1), SenseInfo('11680032-n', 0) ],
"_blink_n_1_rel" : [ SenseInfo('00117959-n', 0) ],
"_explorer_n_of_rel" : [ SenseInfo('10072708-n', 3), SenseInfo('06571538-n', 0) ],
"_recompense_n_1_rel" : [ SenseInfo('13282007-n', 0), SenseInfo('00259643-n', 0) ],
"_override_v_1_rel" : [ SenseInfo('00716130-v', 3), SenseInfo('02644622-v', 0), SenseInfo('02544191-v', 0), SenseInfo('01957995-v', 0), SenseInfo('00716130-v', 3), SenseInfo('02644622-v', 0), SenseInfo('02544191-v', 0), SenseInfo('01957995-v', 0) ],
"_walker_n_1_rel" : [ SenseInfo('11371254-n', 0), SenseInfo('11371125-n', 0), SenseInfo('10412055-n', 0), SenseInfo('04545748-n', 0), SenseInfo('04545471-n', 0), SenseInfo('04545305-n', 0) ],
"_underpay_v_for_rel" : [ SenseInfo('02250216-v', 0), SenseInfo('02250216-v', 0), SenseInfo('02250216-v', 0), SenseInfo('02250216-v', 0), SenseInfo('02250216-v', 0) ],
"_beck+and+call_n_1_rel" : [  ],
"_trapeze_n_1_rel" : [ SenseInfo('04475411-n', 0) ],
"_describe_v_1_rel" : [ SenseInfo('00987071-v', 77), SenseInfo('00965035-v', 52), SenseInfo('01582645-v', 1), SenseInfo('00652346-v', 1) ],
"_rupee_n_1_rel" : [ SenseInfo('13705415-n', 0), SenseInfo('13705153-n', 0), SenseInfo('13704897-n', 0), SenseInfo('13704643-n', 0), SenseInfo('13704274-n', 0), SenseInfo('13703804-n', 0) ],
"_whisker_n_1_rel" : [ SenseInfo('13761603-n', 0), SenseInfo('01901828-n', 0) ],
"_users_a_1_rel" : [  ],
"_sinuous_a_1_rel" : [ SenseInfo('02316992-a', 1) ],
"_alteration_n_1_rel" : [ SenseInfo('07296428-n', 4), SenseInfo('00199707-n', 2), SenseInfo('00399393-n', 0) ],
"_maniac_a_1_rel" : [ SenseInfo('02076416-a', 0) ],
"_backtrace_n_1_rel" : [  ],
"_saltcellar_n_1_rel" : [ SenseInfo('04131499-n', 0) ],
"_fells_n_1_rel" : [ SenseInfo('14759275-n', 0), SenseInfo('03326475-n', 0), SenseInfo('00222376-n', 0), SenseInfo('14759275-n', 0), SenseInfo('03326475-n', 0), SenseInfo('00222376-n', 0) ],
"_world’s+fair_n_1_rel" : [  ],
"_import_n_of_rel" : [ SenseInfo('03564667-n', 2), SenseInfo('10200531-n', 1), SenseInfo('06601327-n', 1), SenseInfo('05920791-n', 1), SenseInfo('05170574-n', 0) ],
"_bed_v_down_rel" : [ SenseInfo('02337066-v', 0), SenseInfo('01567653-v', 0), SenseInfo('01500082-v', 0), SenseInfo('01426397-v', 0), SenseInfo('00017865-v', 0) ],
"_florist_n_1_rel" : [ SenseInfo('10097705-n', 1), SenseInfo('03367410-n', 1) ],
"_essentially_x_deg_rel" : [ SenseInfo('00003483-r', 28) ],
"_blob_n_1_rel" : [ SenseInfo('13910019-n', 2) ],
"_hawker_n_1_rel" : [ SenseInfo('10411551-n', 1), SenseInfo('10076604-n', 0) ],
"_plethora_n_1_rel" : [ SenseInfo('05120116-n', 0) ],
"_antibiotic_n_1_rel" : [ SenseInfo('02716866-n', 0) ],
"_landscape_n_1_rel" : [ SenseInfo('08646902-n', 13), SenseInfo('03640166-n', 2), SenseInfo('03640011-n', 2), SenseInfo('06209940-n', 0) ],
"_trapped_a_1_rel" : [ SenseInfo('01064913-a', 1) ],
"_coronary_a_1_rel" : [ SenseInfo('02984607-a', 0) ],
"_or+what_a_1_rel" : [  ],
"_enlighten_v_1_rel" : [ SenseInfo('00991385-v', 0), SenseInfo('00926932-v', 0), SenseInfo('00621058-v', 0), SenseInfo('00991385-v', 0), SenseInfo('00926932-v', 0), SenseInfo('00621058-v', 0), SenseInfo('00991385-v', 0), SenseInfo('00926932-v', 0), SenseInfo('00621058-v', 0), SenseInfo('00991385-v', 0), SenseInfo('00926932-v', 0), SenseInfo('00621058-v', 0), SenseInfo('00991385-v', 0), SenseInfo('00926932-v', 0), SenseInfo('00621058-v', 0), SenseInfo('00991385-v', 0), SenseInfo('00926932-v', 0), SenseInfo('00621058-v', 0) ],
"_ignore_v_1_rel" : [ SenseInfo('01059564-v', 17), SenseInfo('00800930-v', 13), SenseInfo('02119241-v', 7), SenseInfo('00616857-v', 3), SenseInfo('00595505-v', 0), SenseInfo('01059564-v', 17), SenseInfo('00800930-v', 13), SenseInfo('02119241-v', 7), SenseInfo('00616857-v', 3), SenseInfo('00595505-v', 0) ],
"_series_n_of_rel" : [ SenseInfo('08457976-n', 40), SenseInfo('06621447-n', 7), SenseInfo('06593803-n', 3), SenseInfo('07465448-n', 2), SenseInfo('13791910-n', 0), SenseInfo('08458504-n', 0), SenseInfo('05862721-n', 0), SenseInfo('08457976-n', 40), SenseInfo('06621447-n', 7), SenseInfo('06593803-n', 3), SenseInfo('07465448-n', 2), SenseInfo('13791910-n', 0), SenseInfo('08458504-n', 0), SenseInfo('05862721-n', 0) ],
"_prisoners+dilemma_n_1_rel" : [  ],
"_lacerate_v_1_rel" : [ SenseInfo('01559340-v', 2), SenseInfo('01793587-v', 0) ],
"_backflip_v_1_rel" : [  ],
"_emulate_v_1_rel" : [ SenseInfo('02675701-v', 2), SenseInfo('02675270-v', 0), SenseInfo('01122405-v', 0) ],
"_highway_n_1_rel" : [ SenseInfo('03519981-n', 12), SenseInfo('03519981-n', 12) ],
"_wage_v_1_rel" : [ SenseInfo('02376089-v', 9) ],
"_month_n_1_rel" : [ SenseInfo('15209413-n', 70), SenseInfo('15206296-n', 37) ],
"_winnow_v_1_rel" : [ SenseInfo('01460937-v', 1), SenseInfo('01885708-v', 0), SenseInfo('00677203-v', 0), SenseInfo('00177984-v', 0) ],
"_quilt_n_1_rel" : [ SenseInfo('04033995-n', 1) ],
"_breathe_v_1_rel" : [ SenseInfo('00001740-v', 22), SenseInfo('02617083-v', 1), SenseInfo('02325272-v', 1), SenseInfo('02751787-v', 0), SenseInfo('00941346-v', 0), SenseInfo('00929703-v', 0), SenseInfo('00779360-v', 0), SenseInfo('00239754-v', 0), SenseInfo('00105333-v', 0), SenseInfo('00001740-v', 22), SenseInfo('02617083-v', 1), SenseInfo('02325272-v', 1), SenseInfo('02751787-v', 0), SenseInfo('00941346-v', 0), SenseInfo('00929703-v', 0), SenseInfo('00779360-v', 0), SenseInfo('00239754-v', 0), SenseInfo('00105333-v', 0) ],
"_tamper_v_with_rel" : [ SenseInfo('01586018-v', 1), SenseInfo('02539101-v', 0), SenseInfo('01586018-v', 1), SenseInfo('02539101-v', 0) ],
"_hanovarian_n_1_rel" : [  ],
"_check_n_1_rel" : [ SenseInfo('13381734-n', 18), SenseInfo('05738625-n', 4), SenseInfo('06517942-n', 2), SenseInfo('14010927-n', 1), SenseInfo('05825245-n', 1), SenseInfo('00141806-n', 1), SenseInfo('06818747-n', 0), SenseInfo('05689249-n', 0), SenseInfo('04692908-n', 0), SenseInfo('03011162-n', 0), SenseInfo('01146039-n', 0), SenseInfo('00562935-n', 0), SenseInfo('00167446-n', 0) ],
"_alcoholic_a_1_rel" : [ SenseInfo('01158596-a', 0), SenseInfo('00047243-a', 0) ],
"_cast_v_1_rel" : [ SenseInfo('01632897-v', 15), SenseInfo('02236023-v', 3), SenseInfo('01710481-v', 2), SenseInfo('01507143-v', 1), SenseInfo('02385813-v', 0), SenseInfo('01881180-v', 0), SenseInfo('01662771-v', 0), SenseInfo('01513430-v', 0), SenseInfo('01078050-v', 0), SenseInfo('00981276-v', 0), SenseInfo('00076400-v', 0), SenseInfo('01632897-v', 15), SenseInfo('02236023-v', 3), SenseInfo('01710481-v', 2), SenseInfo('01507143-v', 1), SenseInfo('02385813-v', 0), SenseInfo('01881180-v', 0), SenseInfo('01662771-v', 0), SenseInfo('01513430-v', 0), SenseInfo('01078050-v', 0), SenseInfo('00981276-v', 0), SenseInfo('00076400-v', 0), SenseInfo('01632897-v', 15), SenseInfo('02236023-v', 3), SenseInfo('01710481-v', 2), SenseInfo('01507143-v', 1), SenseInfo('02385813-v', 0), SenseInfo('01881180-v', 0), SenseInfo('01662771-v', 0), SenseInfo('01513430-v', 0), SenseInfo('01078050-v', 0), SenseInfo('00981276-v', 0), SenseInfo('00076400-v', 0) ],
"_amendment_n_of_rel" : [ SenseInfo('01250101-n', 6), SenseInfo('06723635-n', 1) ],
"_choke_v_cause_rel" : [ SenseInfo('00002724-v', 8), SenseInfo('01570562-v', 2), SenseInfo('01570744-v', 1), SenseInfo('00077950-v', 1), SenseInfo('00077698-v', 1), SenseInfo('02529669-v', 0), SenseInfo('02423999-v', 0), SenseInfo('01478603-v', 0), SenseInfo('01476180-v', 0), SenseInfo('00391203-v', 0), SenseInfo('00391021-v', 0), SenseInfo('00358431-v', 0), SenseInfo('00173159-v', 0), SenseInfo('00077606-v', 0) ],
"_cultured_a_1_rel" : [ SenseInfo('01947741-a', 2) ],
"_copy_v_1_rel" : [ SenseInfo('01747374-v', 3), SenseInfo('01742886-v', 3), SenseInfo('01734929-v', 0), SenseInfo('01693881-v', 0), SenseInfo('01747374-v', 3), SenseInfo('01742886-v', 3), SenseInfo('01734929-v', 0), SenseInfo('01693881-v', 0) ],
"_push_v_through_rel" : [ SenseInfo('01871979-v', 56), SenseInfo('00765977-v', 7), SenseInfo('00976653-v', 6), SenseInfo('02406916-v', 3), SenseInfo('01872645-v', 3), SenseInfo('02054864-v', 1), SenseInfo('02589576-v', 0), SenseInfo('02245555-v', 0), SenseInfo('01872877-v', 0), SenseInfo('01447632-v', 0) ],
"_fit_v_into_rel" : [ SenseInfo('02702830-v', 14), SenseInfo('02659763-v', 11), SenseInfo('02667900-v', 9), SenseInfo('00300537-v', 7), SenseInfo('00300113-v', 5), SenseInfo('02657219-v', 4), SenseInfo('02735753-v', 1), SenseInfo('02339413-v', 1), SenseInfo('00456740-v', 0) ],
"_soulful_a_1_rel" : [ SenseInfo('00856651-a', 0), SenseInfo('00856651-a', 0) ],
"_brighten_v_1_rel" : [ SenseInfo('00312815-v', 1), SenseInfo('02771169-v', 0) ],
"_bring_v_up_rel" : [ SenseInfo('02077656-v', 122), SenseInfo('01438902-v', 55), SenseInfo('01629589-v', 31), SenseInfo('01433294-v', 19), SenseInfo('00135857-v', 9), SenseInfo('01434140-v', 4), SenseInfo('01618547-v', 3), SenseInfo('02324478-v', 2), SenseInfo('02247390-v', 1), SenseInfo('01808218-v', 0), SenseInfo('00767334-v', 0) ],
"_prize_v_1_rel" : [ SenseInfo('02256109-v', 1), SenseInfo('01593254-v', 0), SenseInfo('00694068-v', 0) ],
"_column_n_of_rel" : [ SenseInfo('08429052-n', 18), SenseInfo('03074574-n', 10), SenseInfo('08433575-n', 8), SenseInfo('13900422-n', 5), SenseInfo('06268567-n', 4), SenseInfo('03074380-n', 1), SenseInfo('03073977-n', 1), SenseInfo('06268357-n', 0), SenseInfo('05585999-n', 0) ],
"_intuitive_a_1_rel" : [ SenseInfo('02282843-a', 0), SenseInfo('01431471-a', 0) ],
"_collapse_v_1_rel" : [ SenseInfo('01989053-v', 8), SenseInfo('00030647-v', 6), SenseInfo('02083497-v', 0), SenseInfo('02041877-v', 0), SenseInfo('01989562-v', 0), SenseInfo('01785579-v', 0), SenseInfo('00224460-v', 0) ],
"_over-used_a_1_rel" : [  ],
"_traction_n_1_rel" : [ SenseInfo('11460281-n', 0), SenseInfo('00116122-n', 0) ],
"_phenomenon_n_1_rel" : [ SenseInfo('00034213-n', 25), SenseInfo('07423818-n', 5) ],
"_feast_v_on_rel" : [ SenseInfo('01185981-v', 1), SenseInfo('01186208-v', 0), SenseInfo('01182152-v', 0), SenseInfo('01185981-v', 1), SenseInfo('01186208-v', 0), SenseInfo('01182152-v', 0), SenseInfo('01185981-v', 1), SenseInfo('01186208-v', 0), SenseInfo('01182152-v', 0) ],
"_underwrite_v_1_rel" : [ SenseInfo('00889740-v', 2), SenseInfo('00891216-v', 1) ],
"_provoke_v_1_rel" : [ SenseInfo('01759326-v', 3), SenseInfo('01646866-v', 3), SenseInfo('00794079-v', 3), SenseInfo('01789514-v', 1) ],
"_naturalist_n_1_rel" : [ SenseInfo('10346955-n', 0), SenseInfo('10346514-n', 0) ],
"_one-by-one_a_1_rel" : [  ],
"_easiest_a_for_rel" : [  ],
"_safe_n_1_rel" : [ SenseInfo('04125021-n', 6), SenseInfo('04125116-n', 0), SenseInfo('03088164-n', 0) ],
"_curious_a_as+to_rel" : [ SenseInfo('00968010-a', 14), SenseInfo('00664449-a', 13), SenseInfo('01342572-a', 0) ],
"_accommodate_v_as_rel" : [ SenseInfo('02702830-v', 5), SenseInfo('00299580-v', 5), SenseInfo('01184453-v', 3), SenseInfo('02732798-v', 2), SenseInfo('02651424-v', 0), SenseInfo('00885925-v', 0), SenseInfo('00482893-v', 0), SenseInfo('02702830-v', 5), SenseInfo('00299580-v', 5), SenseInfo('01184453-v', 3), SenseInfo('02732798-v', 2), SenseInfo('02651424-v', 0), SenseInfo('00885925-v', 0), SenseInfo('00482893-v', 0) ],
"_reorganization_n_of_rel" : [ SenseInfo('01137987-n', 0), SenseInfo('00200768-n', 0), SenseInfo('01137987-n', 0), SenseInfo('00200768-n', 0) ],
"_babbiting_n_1_rel" : [  ],
"_dynamic_a_1_rel" : [ SenseInfo('00808191-a', 3), SenseInfo('02979878-a', 0), SenseInfo('00041618-a', 0), SenseInfo('00808191-a', 3), SenseInfo('02979878-a', 0), SenseInfo('00041618-a', 0) ],
"_calculation_n_of_rel" : [ SenseInfo('00868910-n', 7), SenseInfo('05802185-n', 4), SenseInfo('05796423-n', 0), SenseInfo('00868910-n', 7), SenseInfo('05802185-n', 4), SenseInfo('05796423-n', 0) ],
"_do_v_so_rel" : [ SenseInfo('02560585-v', 526), SenseInfo('01712704-v', 173), SenseInfo('02561995-v', 134), SenseInfo('02617567-v', 58), SenseInfo('01645601-v', 35), SenseInfo('02568672-v', 20), SenseInfo('02669789-v', 11), SenseInfo('01619014-v', 9), SenseInfo('00010435-v', 3), SenseInfo('02709107-v', 2), SenseInfo('02523221-v', 2), SenseInfo('00038849-v', 2), SenseInfo('01841772-v', 1) ],
"_grass_v_on_rel" : [ SenseInfo('01137055-v', 1), SenseInfo('01603032-v', 0), SenseInfo('01580348-v', 0), SenseInfo('01209025-v', 0), SenseInfo('01204581-v', 0), SenseInfo('00841986-v', 0) ],
"_engineering_n_1_rel" : [ SenseInfo('00949619-n', 6), SenseInfo('06125041-n', 2), SenseInfo('03288500-n', 0) ],
"_disappoint_v_1_rel" : [ SenseInfo('01798936-v', 5), SenseInfo('01798936-v', 5), SenseInfo('01798936-v', 5), SenseInfo('01798936-v', 5), SenseInfo('01798936-v', 5) ],
"_wonder_n_1_rel" : [ SenseInfo('07509996-n', 5), SenseInfo('07289588-n', 4), SenseInfo('05682570-n', 4), SenseInfo('07509996-n', 5), SenseInfo('07289588-n', 4), SenseInfo('05682570-n', 4) ],
"_fluid_n_1_rel" : [ SenseInfo('14939900-n', 25), SenseInfo('14939445-n', 1) ],
"_snore_v_1_rel" : [ SenseInfo('00017031-v', 4) ],
"_first-ever_a_1_rel" : [  ],
"_scar_v_cause_rel" : [ SenseInfo('01551195-v', 0) ],
"_daily_n_1_rel" : [ SenseInfo('06267564-n', 0) ],
"_disregard_v_1_rel" : [ SenseInfo('01059564-v', 3), SenseInfo('00800930-v', 2), SenseInfo('00616857-v', 0) ],
"_bring_v_forward_rel" : [ SenseInfo('02077656-v', 122), SenseInfo('01438902-v', 55), SenseInfo('01629589-v', 31), SenseInfo('01433294-v', 19), SenseInfo('00135857-v', 9), SenseInfo('01434140-v', 4), SenseInfo('01618547-v', 3), SenseInfo('02324478-v', 2), SenseInfo('02247390-v', 1), SenseInfo('01808218-v', 0), SenseInfo('00767334-v', 0) ],
"_abalienate_v_1_rel" : [  ],
"_turbidity_n_1_rel" : [ SenseInfo('04703932-n', 0) ],
"_folic_a_1_rel" : [  ],
"_fashion_n_1_rel" : [ SenseInfo('04928903-n', 17), SenseInfo('00415226-n', 6), SenseInfo('05750657-n', 2), SenseInfo('03323593-n', 0) ],
"_recall_v_of_rel" : [ SenseInfo('00607780-v', 47), SenseInfo('00959524-v', 4), SenseInfo('02675458-v', 1), SenseInfo('00791506-v', 1), SenseInfo('00722848-v', 1), SenseInfo('02480216-v', 0), SenseInfo('02312478-v', 0) ],
"_figure_v_1_rel" : [ SenseInfo('00712135-v', 20), SenseInfo('02722207-v', 8), SenseInfo('01635432-v', 3), SenseInfo('00637259-v', 2), SenseInfo('00590241-v', 1), SenseInfo('00712135-v', 20), SenseInfo('02722207-v', 8), SenseInfo('01635432-v', 3), SenseInfo('00637259-v', 2), SenseInfo('00590241-v', 1), SenseInfo('00712135-v', 20), SenseInfo('02722207-v', 8), SenseInfo('01635432-v', 3), SenseInfo('00637259-v', 2), SenseInfo('00590241-v', 1), SenseInfo('00712135-v', 20), SenseInfo('02722207-v', 8), SenseInfo('01635432-v', 3), SenseInfo('00637259-v', 2), SenseInfo('00590241-v', 1) ],
"_waltz_n_1_rel" : [ SenseInfo('07475762-n', 0), SenseInfo('07058184-n', 0), SenseInfo('00537534-n', 0) ],
"_collapse_v_cause_rel" : [ SenseInfo('01989053-v', 8), SenseInfo('00030647-v', 6), SenseInfo('02083497-v', 0), SenseInfo('02041877-v', 0), SenseInfo('01989562-v', 0), SenseInfo('01785579-v', 0), SenseInfo('00224460-v', 0) ],
"_nose_v_around_rel" : [ SenseInfo('02169119-v', 1), SenseInfo('01994128-v', 1), SenseInfo('02125223-v', 0), SenseInfo('01873051-v', 0), SenseInfo('01424350-v', 0), SenseInfo('01109644-v', 0) ],
"_sclerosis_n_1_rel" : [ SenseInfo('14110411-n', 0) ],
"_scoop_v_1_rel" : [ SenseInfo('01312371-v', 0), SenseInfo('01109259-v', 0), SenseInfo('01312371-v', 0), SenseInfo('01109259-v', 0), SenseInfo('01312371-v', 0), SenseInfo('01109259-v', 0) ],
"_bang_v_1_rel" : [ SenseInfo('01242391-v', 3), SenseInfo('02187693-v', 2), SenseInfo('01242832-v', 2), SenseInfo('02100176-v', 1), SenseInfo('01426397-v', 0), SenseInfo('01236941-v', 0) ],
"_proportional_a_1_rel" : [ SenseInfo('00482673-a', 6), SenseInfo('00482948-a', 0) ],
"_flash_v_cause-at_rel" : [ SenseInfo('02159890-v', 9), SenseInfo('00424691-v', 6), SenseInfo('02141973-v', 3), SenseInfo('00929509-v', 3), SenseInfo('02061495-v', 2), SenseInfo('02138611-v', 1), SenseInfo('01335461-v', 0), SenseInfo('00424869-v', 0) ],
"_placid_a_1_rel" : [ SenseInfo('00302951-a', 2), SenseInfo('01134486-a', 1) ],
"_adoption_n_of_rel" : [ SenseInfo('00180413-n', 2), SenseInfo('01185292-n', 0), SenseInfo('00084371-n', 0) ],
"_duplicate_v_1_rel" : [ SenseInfo('01734502-v', 3), SenseInfo('02659358-v', 0), SenseInfo('01735308-v', 0), SenseInfo('00246217-v', 0) ],
"_lavender_a_1_rel" : [ SenseInfo('00376917-a', 3) ],
"_romp_v_1_rel" : [ SenseInfo('01883716-v', 2), SenseInfo('01926878-v', 0), SenseInfo('01100567-v', 0) ],
"_neutralize_v_cause_rel" : [ SenseInfo('02535896-v', 3), SenseInfo('00470084-v', 1), SenseInfo('02543874-v', 0), SenseInfo('01327301-v', 0), SenseInfo('01117931-v', 0), SenseInfo('00469904-v', 0) ],
"_coroners_a_1_rel" : [  ],
"_contribution_n_of_rel" : [ SenseInfo('00787465-n', 12), SenseInfo('13270038-n', 4), SenseInfo('01089778-n', 3), SenseInfo('13269890-n', 2), SenseInfo('01102712-n', 0) ],
"_vassal_n_1_rel" : [ SenseInfo('10746581-n', 0) ],
"_cordiality_n_1_rel" : [ SenseInfo('04655929-n', 0) ],
"_medical_a_1_rel" : [ SenseInfo('02760116-a', 29), SenseInfo('01168988-a', 4), SenseInfo('02607455-a', 1) ],
"_ferocity_n_1_rel" : [ SenseInfo('05037813-n', 1) ],
"_highland_n_1_rel" : [ SenseInfo('09302616-n', 0) ],
"_fucking_x_deg_rel" : [ SenseInfo('00846021-n', 0), SenseInfo('00032705-r', 0), SenseInfo('01520655-a', 0) ],
"_razor_n_1_rel" : [ SenseInfo('04057047-n', 5) ],
"_affection_n_1_rel" : [ SenseInfo('07544647-n', 9) ],
"_delicates_n_1_rel" : [  ],
"_bloody_a_1_rel" : [ SenseInfo('00247439-a', 8), SenseInfo('01520655-a', 0), SenseInfo('00247439-a', 8), SenseInfo('01520655-a', 0), SenseInfo('00247439-a', 8), SenseInfo('01520655-a', 0) ],
"_dike_n_1_rel" : [ SenseInfo('09883947-n', 0), SenseInfo('03160309-n', 0) ],
"_choral_a_1_rel" : [ SenseInfo('02874282-a', 0) ],
"_confines_n_1_rel" : [ SenseInfo('05126228-n', 1), SenseInfo('05126228-n', 1) ],
"_twine_n_1_rel" : [ SenseInfo('04337974-n', 0) ],
"_yank_v_out_rel" : [ SenseInfo('01592072-v', 5) ],
"_secretion_n_of_rel" : [ SenseInfo('13553916-n', 3), SenseInfo('05404728-n', 1) ],
"_flier_n_1_rel" : [ SenseInfo('10096217-n', 0), SenseInfo('09826204-n', 0), SenseInfo('07250339-n', 0) ],
"_grotto_n_1_rel" : [ SenseInfo('09294877-n', 0) ],
"_steel_n_1_rel" : [ SenseInfo('14802450-n', 20), SenseInfo('04373894-n', 1), SenseInfo('04310904-n', 0) ],
"_tiny_a_1_rel" : [ SenseInfo('01392249-a', 19), SenseInfo('01392249-a', 19), SenseInfo('01392249-a', 19) ],
"_reagent_n_1_rel" : [ SenseInfo('14778982-n', 3) ],
"_crook_n_1_rel" : [ SenseInfo('09977660-n', 2), SenseInfo('13869327-n', 1), SenseInfo('03134118-n', 0) ],
"_gray_v_1_rel" : [ SenseInfo('00289679-v', 0), SenseInfo('00289392-v', 0) ],
"_no+matter+how_x_deg_rel" : [  ],
"_postpone_v_1_rel" : [ SenseInfo('02642814-v', 12) ],
"_affront_n_1_rel" : [ SenseInfo('01225027-n', 1) ],
"_destabilize_v_1_rel" : [ SenseInfo('00272177-v', 0), SenseInfo('00271711-v', 0) ],
"_enter_v_1_rel" : [ SenseInfo('02016523-v', 85), SenseInfo('01082606-v', 24), SenseInfo('02471327-v', 17), SenseInfo('02722207-v', 8), SenseInfo('01000214-v', 7), SenseInfo('01720660-v', 2), SenseInfo('02381397-v', 0), SenseInfo('01421622-v', 0), SenseInfo('00348252-v', 0), SenseInfo('02016523-v', 85), SenseInfo('01082606-v', 24), SenseInfo('02471327-v', 17), SenseInfo('02722207-v', 8), SenseInfo('01000214-v', 7), SenseInfo('01720660-v', 2), SenseInfo('02381397-v', 0), SenseInfo('01421622-v', 0), SenseInfo('00348252-v', 0) ],
"_tense_n_1_rel" : [ SenseInfo('06329506-n', 2) ],
"_long_v_1_rel" : [ SenseInfo('01828405-v', 6), SenseInfo('01828405-v', 6) ],
"_cut_v_loose_rel" : [ SenseInfo('01552519-v', 58), SenseInfo('00429060-v', 18), SenseInfo('02033295-v', 3), SenseInfo('01610834-v', 2), SenseInfo('02422283-v', 1), SenseInfo('01754915-v', 1), SenseInfo('01666717-v', 1), SenseInfo('01413917-v', 1), SenseInfo('01064799-v', 1), SenseInfo('00201722-v', 1), SenseInfo('02613860-v', 0), SenseInfo('02588280-v', 0), SenseInfo('02134232-v', 0), SenseInfo('02101649-v', 0), SenseInfo('01915865-v', 0), SenseInfo('01915730-v', 0), SenseInfo('01860107-v', 0), SenseInfo('01859995-v', 0), SenseInfo('01756563-v', 0), SenseInfo('01756416-v', 0), SenseInfo('01756277-v', 0), SenseInfo('01754737-v', 0), SenseInfo('01713491-v', 0), SenseInfo('01611123-v', 0), SenseInfo('01610990-v', 0), SenseInfo('01555437-v', 0), SenseInfo('01510576-v', 0), SenseInfo('01320424-v', 0), SenseInfo('01319738-v', 0), SenseInfo('01227088-v', 0), SenseInfo('01059564-v', 0), SenseInfo('00561090-v', 0), SenseInfo('00473322-v', 0), SenseInfo('00447654-v', 0), SenseInfo('00429968-v', 0), SenseInfo('00292507-v', 0), SenseInfo('00243900-v', 0), SenseInfo('00226071-v', 0), SenseInfo('00108475-v', 0), SenseInfo('00096136-v', 0), SenseInfo('00061219-v', 0), SenseInfo('01552519-v', 58), SenseInfo('00429060-v', 18), SenseInfo('02033295-v', 3), SenseInfo('01610834-v', 2), SenseInfo('02422283-v', 1), SenseInfo('01754915-v', 1), SenseInfo('01666717-v', 1), SenseInfo('01413917-v', 1), SenseInfo('01064799-v', 1), SenseInfo('00201722-v', 1), SenseInfo('02613860-v', 0), SenseInfo('02588280-v', 0), SenseInfo('02134232-v', 0), SenseInfo('02101649-v', 0), SenseInfo('01915865-v', 0), SenseInfo('01915730-v', 0), SenseInfo('01860107-v', 0), SenseInfo('01859995-v', 0), SenseInfo('01756563-v', 0), SenseInfo('01756416-v', 0), SenseInfo('01756277-v', 0), SenseInfo('01754737-v', 0), SenseInfo('01713491-v', 0), SenseInfo('01611123-v', 0), SenseInfo('01610990-v', 0), SenseInfo('01555437-v', 0), SenseInfo('01510576-v', 0), SenseInfo('01320424-v', 0), SenseInfo('01319738-v', 0), SenseInfo('01227088-v', 0), SenseInfo('01059564-v', 0), SenseInfo('00561090-v', 0), SenseInfo('00473322-v', 0), SenseInfo('00447654-v', 0), SenseInfo('00429968-v', 0), SenseInfo('00292507-v', 0), SenseInfo('00243900-v', 0), SenseInfo('00226071-v', 0), SenseInfo('00108475-v', 0), SenseInfo('00096136-v', 0), SenseInfo('00061219-v', 0) ],
"_cult_n_1_rel" : [ SenseInfo('08151490-n', 3), SenseInfo('05751173-n', 1), SenseInfo('08151229-n', 0), SenseInfo('05948537-n', 0), SenseInfo('05948264-n', 0) ],
"_implausible_a_1_rel" : [ SenseInfo('01799957-a', 0), SenseInfo('01412721-a', 0), SenseInfo('01799957-a', 0), SenseInfo('01412721-a', 0) ],
"_function_v_as_rel" : [ SenseInfo('01525666-v', 9), SenseInfo('02670890-v', 3), SenseInfo('01096497-v', 1) ],
"_energize_v_1_rel" : [ SenseInfo('00022686-v', 1), SenseInfo('00559102-v', 0), SenseInfo('00022686-v', 1), SenseInfo('00559102-v', 0) ],
"_shepherd_v_1_rel" : [ SenseInfo('02550168-v', 1), SenseInfo('02550044-v', 0) ],
"_snow+plow_v_1_rel" : [  ],
"_join_v_1_rel" : [ SenseInfo('02434976-v', 75), SenseInfo('01295275-v', 18), SenseInfo('02598765-v', 8), SenseInfo('01291069-v', 7), SenseInfo('02622234-v', 1) ],
"_well_a_1_rel" : [ SenseInfo('02540578-a', 4), SenseInfo('01048762-a', 3), SenseInfo('00067638-a', 3), SenseInfo('02540578-a', 4), SenseInfo('01048762-a', 3), SenseInfo('00067638-a', 3), SenseInfo('02540578-a', 4), SenseInfo('01048762-a', 3), SenseInfo('00067638-a', 3) ],
"_clench_n_1_rel" : [ SenseInfo('03042984-n', 0), SenseInfo('00812526-n', 0) ],
"_typewritten_a_1_rel" : [  ],
"_personification_n_1_rel" : [ SenseInfo('10418101-n', 1), SenseInfo('07108123-n', 0), SenseInfo('00933259-n', 0) ],
"_reckon_v_on_rel" : [ SenseInfo('00631737-v', 5), SenseInfo('00712135-v', 3), SenseInfo('00690614-v', 1), SenseInfo('00637259-v', 1), SenseInfo('00712708-v', 0), SenseInfo('00712556-v', 0) ],
"_cuban_a_1_rel" : [ SenseInfo('02969591-a', 7) ],
"_long_v_for_rel" : [ SenseInfo('01828405-v', 6) ],
"_filesystem_n_1_rel" : [  ],
"_infect_v_1_rel" : [ SenseInfo('00089750-v', 2), SenseInfo('00088713-v', 1), SenseInfo('02580237-v', 0), SenseInfo('00605498-v', 0) ],
"_sprawl_v_1_rel" : [ SenseInfo('01543426-v', 8), SenseInfo('02032227-v', 2) ],
"_praise_v_1_rel" : [ SenseInfo('00856824-v', 14) ],
"_portuguese_a_1_rel" : [ SenseInfo('02959007-a', 0) ],
"_phrase_n_1_rel" : [ SenseInfo('06316048-n', 10), SenseInfo('07045353-n', 3), SenseInfo('07154330-n', 0), SenseInfo('00527061-n', 0), SenseInfo('06316048-n', 10), SenseInfo('07045353-n', 3), SenseInfo('07154330-n', 0), SenseInfo('00527061-n', 0), SenseInfo('06316048-n', 10), SenseInfo('07045353-n', 3), SenseInfo('07154330-n', 0), SenseInfo('00527061-n', 0) ],
"_wreck_v_1_rel" : [ SenseInfo('01566185-v', 10) ],
"_reveal_v_as_rel" : [ SenseInfo('02143283-v', 34), SenseInfo('00933821-v', 17), SenseInfo('02144243-v', 0) ],
"_freighter_n_1_rel" : [ SenseInfo('02878222-n', 1) ],
"_cross_a_1_rel" : [ SenseInfo('01445917-a', 4), SenseInfo('01136248-a', 1) ],
"_flatiron_n_1_rel" : [ SenseInfo('03361194-n', 0) ],
"_trace_v_1_rel" : [ SenseInfo('00729109-v', 9), SenseInfo('01582645-v', 5), SenseInfo('02004352-v', 2), SenseInfo('02003601-v', 2), SenseInfo('02156063-v', 0), SenseInfo('01995949-v', 0), SenseInfo('01694376-v', 0), SenseInfo('00626130-v', 0) ],
"_harden_v_cause_rel" : [ SenseInfo('00443116-v', 4), SenseInfo('00443384-v', 0), SenseInfo('00302875-v', 0), SenseInfo('00295120-v', 0), SenseInfo('00272910-v', 0) ],
"_chase_v_away_rel" : [ SenseInfo('02001858-v', 10), SenseInfo('02535093-v', 0), SenseInfo('01583881-v', 0), SenseInfo('01277649-v', 0) ],
"_bare_a_1_rel" : [ SenseInfo('00457998-a', 2), SenseInfo('00106821-a', 2), SenseInfo('02155524-a', 0), SenseInfo('01698400-a', 0), SenseInfo('02563466-a', 0), SenseInfo('01792573-a', 0), SenseInfo('01714157-a', 0), SenseInfo('01242750-a', 0), SenseInfo('01086915-a', 0), SenseInfo('00060605-a', 0) ],
"_patrolman_n_1_rel" : [ SenseInfo('10095664-n', 3) ],
"_prism_n_1_rel" : [ SenseInfo('13884511-n', 0), SenseInfo('04005340-n', 0) ],
"_compliment_v_on_rel" : [ SenseInfo('00881661-v', 2), SenseInfo('00881901-v', 1), SenseInfo('00881661-v', 2), SenseInfo('00881901-v', 1) ],
"_comment_n_1_rel" : [ SenseInfo('06765044-n', 24), SenseInfo('06762711-n', 6), SenseInfo('07223170-n', 0), SenseInfo('06765044-n', 24), SenseInfo('06762711-n', 6), SenseInfo('07223170-n', 0), SenseInfo('06765044-n', 24), SenseInfo('06762711-n', 6), SenseInfo('07223170-n', 0), SenseInfo('06765044-n', 24), SenseInfo('06762711-n', 6), SenseInfo('07223170-n', 0) ],
"_head_v_off_rel" : [ SenseInfo('01935233-v', 29), SenseInfo('02440244-v', 19), SenseInfo('01999423-v', 3), SenseInfo('02729023-v', 2), SenseInfo('01931768-v', 2), SenseInfo('02754463-v', 0), SenseInfo('02694287-v', 0), SenseInfo('02624128-v', 0), SenseInfo('01590915-v', 0), SenseInfo('01935233-v', 29), SenseInfo('02440244-v', 19), SenseInfo('01999423-v', 3), SenseInfo('02729023-v', 2), SenseInfo('01931768-v', 2), SenseInfo('02754463-v', 0), SenseInfo('02694287-v', 0), SenseInfo('02624128-v', 0), SenseInfo('01590915-v', 0) ],
"_shelter_v_1_rel" : [ SenseInfo('02656390-v', 1), SenseInfo('02271817-v', 0) ],
"_homepage_n_1_rel" : [ SenseInfo('06359096-n', 0) ],
"_marble_n_1_rel" : [ SenseInfo('14947807-n', 8), SenseInfo('03721047-n', 2), SenseInfo('03721169-n', 0) ],
"_assyriology_n_1_rel" : [ SenseInfo('06144762-n', 1) ],
"_haystack_n_1_rel" : [ SenseInfo('07963208-n', 1) ],
"_thunderstorm_n_1_rel" : [ SenseInfo('11519253-n', 0) ],
"_right+then_a_1_rel" : [  ],
"_feudal_a_1_rel" : [ SenseInfo('02726546-a', 1) ],
"_disable_v_1_rel" : [ SenseInfo('00512186-v', 1), SenseInfo('00091968-v', 0), SenseInfo('00512186-v', 1), SenseInfo('00091968-v', 0) ],
"_brontosaurus_n_1_rel" : [ SenseInfo('01709484-n', 0) ],
"_slaty_a_1_rel" : [ SenseInfo('00391897-a', 0) ],
"_retina_n_1_rel" : [ SenseInfo('05426989-n', 1) ],
"_tolerant_a_of_rel" : [ SenseInfo('02436341-a', 3), SenseInfo('01041209-a', 1), SenseInfo('00286837-a', 1), SenseInfo('02435383-a', 0), SenseInfo('01736883-a', 0) ],
"_mine_v_for_rel" : [ SenseInfo('01163620-v', 3), SenseInfo('01125724-v', 0) ],
"_seamark_n_1_rel" : [  ],
"_loop_v_1_rel" : [ SenseInfo('02044745-v', 1), SenseInfo('01673472-v', 1), SenseInfo('02044596-v', 0), SenseInfo('01523986-v', 0), SenseInfo('01286290-v', 0), SenseInfo('02044745-v', 1), SenseInfo('01673472-v', 1), SenseInfo('02044596-v', 0), SenseInfo('01523986-v', 0), SenseInfo('01286290-v', 0) ],
"_left+hander_n_1_rel" : [ SenseInfo('10252921-n', 2), SenseInfo('10253122-n', 1), SenseInfo('10252921-n', 2), SenseInfo('10253122-n', 1) ],
"_stylish_a_1_rel" : [ SenseInfo('00975171-a', 0), SenseInfo('00971075-a', 0) ],
"_cutlass_n_1_rel" : [ SenseInfo('03153246-n', 0) ],
"_strong_n_1_rel" : [ SenseInfo('02321009-a', 58), SenseInfo('01513512-a', 9), SenseInfo('01826979-a', 3), SenseInfo('01824244-a', 0), SenseInfo('02526124-a', 0), SenseInfo('02275412-a', 0), SenseInfo('01961786-a', 0), SenseInfo('01158974-a', 0), SenseInfo('01068609-a', 0), SenseInfo('00842199-a', 0) ],
"_plan_v_1_rel" : [ SenseInfo('00705227-v', 44), SenseInfo('00704690-v', 27), SenseInfo('01638368-v', 17), SenseInfo('01639714-v', 2), SenseInfo('00705227-v', 44), SenseInfo('00704690-v', 27), SenseInfo('01638368-v', 17), SenseInfo('01639714-v', 2) ],
"_go_v_for_rel" : [ SenseInfo('01835496-v', 343), SenseInfo('02372605-v', 95), SenseInfo('01848718-v', 49), SenseInfo('00149583-v', 29), SenseInfo('02653862-v', 14), SenseInfo('02721284-v', 10), SenseInfo('02685951-v', 10), SenseInfo('00341560-v', 10), SenseInfo('00359916-v', 9), SenseInfo('02618001-v', 7), SenseInfo('02176268-v', 3), SenseInfo('01525666-v', 3), SenseInfo('01192773-v', 3), SenseInfo('00539110-v', 3), SenseInfo('02618149-v', 2), SenseInfo('02617798-v', 2), SenseInfo('00358431-v', 2), SenseInfo('02737876-v', 1), SenseInfo('02729819-v', 1), SenseInfo('01864230-v', 1), SenseInfo('01076615-v', 1), SenseInfo('02700772-v', 0), SenseInfo('02700666-v', 0), SenseInfo('02700455-v', 0), SenseInfo('02686471-v', 0), SenseInfo('02659763-v', 0), SenseInfo('01318849-v', 0), SenseInfo('01192992-v', 0), SenseInfo('00676267-v', 0), SenseInfo('00434374-v', 0) ],
"_require_v_of_rel" : [ SenseInfo('02627934-v', 144), SenseInfo('00755745-v', 16), SenseInfo('00751567-v', 16), SenseInfo('01188725-v', 6), SenseInfo('02627934-v', 144), SenseInfo('00755745-v', 16), SenseInfo('00751567-v', 16), SenseInfo('01188725-v', 6), SenseInfo('02627934-v', 144), SenseInfo('00755745-v', 16), SenseInfo('00751567-v', 16), SenseInfo('01188725-v', 6), SenseInfo('02627934-v', 144), SenseInfo('00755745-v', 16), SenseInfo('00751567-v', 16), SenseInfo('01188725-v', 6), SenseInfo('02627934-v', 144), SenseInfo('00755745-v', 16), SenseInfo('00751567-v', 16), SenseInfo('01188725-v', 6) ],
"_mountainous_a_1_rel" : [ SenseInfo('02240490-a', 2), SenseInfo('01389846-a', 2), SenseInfo('01219502-a', 1) ],
"_pegboard_n_1_rel" : [ SenseInfo('03906224-n', 8) ],
"_max_v_out_rel" : [  ],
"_fathom_n_1_rel" : [ SenseInfo('13660178-n', 0), SenseInfo('13617308-n', 0) ],
"_rub_v_in_rel" : [ SenseInfo('01249724-v', 19), SenseInfo('01250908-v', 1), SenseInfo('02119874-v', 0) ],
"_hall_n_1_rel" : [ SenseInfo('03479952-n', 25), SenseInfo('02715513-n', 10), SenseInfo('03478907-n', 6), SenseInfo('03224893-n', 3), SenseInfo('03718581-n', 2), SenseInfo('11025125-n', 0), SenseInfo('11024908-n', 0), SenseInfo('11024731-n', 0), SenseInfo('11024582-n', 0), SenseInfo('11024419-n', 0), SenseInfo('03719053-n', 0), SenseInfo('03479121-n', 0), SenseInfo('03478756-n', 0), SenseInfo('03479952-n', 25), SenseInfo('02715513-n', 10), SenseInfo('03478907-n', 6), SenseInfo('03224893-n', 3), SenseInfo('03718581-n', 2), SenseInfo('11025125-n', 0), SenseInfo('11024908-n', 0), SenseInfo('11024731-n', 0), SenseInfo('11024582-n', 0), SenseInfo('11024419-n', 0), SenseInfo('03719053-n', 0), SenseInfo('03479121-n', 0), SenseInfo('03478756-n', 0) ],
"_savage_a_1_rel" : [ SenseInfo('01263013-a', 6), SenseInfo('02389520-a', 1), SenseInfo('00412788-a', 1), SenseInfo('02511528-a', 0) ],
"_lose_v_out_rel" : [ SenseInfo('02287789-v', 123), SenseInfo('01099592-v', 17), SenseInfo('01795082-v', 10), SenseInfo('01503101-v', 7), SenseInfo('02287618-v', 6), SenseInfo('02197091-v', 4), SenseInfo('02288828-v', 3), SenseInfo('02288155-v', 2), SenseInfo('01113806-v', 2), SenseInfo('02127853-v', 1), SenseInfo('00204872-v', 0), SenseInfo('02287789-v', 123), SenseInfo('01099592-v', 17), SenseInfo('01795082-v', 10), SenseInfo('01503101-v', 7), SenseInfo('02287618-v', 6), SenseInfo('02197091-v', 4), SenseInfo('02288828-v', 3), SenseInfo('02288155-v', 2), SenseInfo('01113806-v', 2), SenseInfo('02127853-v', 1), SenseInfo('00204872-v', 0) ],
"_sucky_a_1_rel" : [  ],
"_heavens_a_1_rel" : [ SenseInfo('08521267-n', 2), SenseInfo('08521267-n', 2) ],
"_bright_a_1_rel" : [ SenseInfo('00278551-a', 16), SenseInfo('00402855-a', 6), SenseInfo('01335458-a', 5), SenseInfo('00271022-a', 3), SenseInfo('01812237-a', 1), SenseInfo('01121238-a', 1), SenseInfo('00284930-a', 0), SenseInfo('02009688-a', 0), SenseInfo('01149050-a', 0), SenseInfo('00176387-a', 0), SenseInfo('00278551-a', 16), SenseInfo('00402855-a', 6), SenseInfo('01335458-a', 5), SenseInfo('00271022-a', 3), SenseInfo('01812237-a', 1), SenseInfo('01121238-a', 1), SenseInfo('00284930-a', 0), SenseInfo('02009688-a', 0), SenseInfo('01149050-a', 0), SenseInfo('00176387-a', 0), SenseInfo('00278551-a', 16), SenseInfo('00402855-a', 6), SenseInfo('01335458-a', 5), SenseInfo('00271022-a', 3), SenseInfo('01812237-a', 1), SenseInfo('01121238-a', 1), SenseInfo('00284930-a', 0), SenseInfo('02009688-a', 0), SenseInfo('01149050-a', 0), SenseInfo('00176387-a', 0), SenseInfo('00278551-a', 16), SenseInfo('00402855-a', 6), SenseInfo('01335458-a', 5), SenseInfo('00271022-a', 3), SenseInfo('01812237-a', 1), SenseInfo('01121238-a', 1), SenseInfo('00284930-a', 0), SenseInfo('02009688-a', 0), SenseInfo('01149050-a', 0), SenseInfo('00176387-a', 0) ],
"_collapse_n_1_rel" : [ SenseInfo('14066203-n', 3), SenseInfo('07361128-n', 2), SenseInfo('00327510-n', 1), SenseInfo('07477945-n', 0) ],
"_business-as-usual_n_1_rel" : [  ],
"_slavery_n_1_rel" : [ SenseInfo('13997253-n', 9), SenseInfo('00415442-n', 1), SenseInfo('00623545-n', 0) ],
"_cookset_n_1_rel" : [  ],
"_inkling_n_of_rel" : [ SenseInfo('05916306-n', 1), SenseInfo('05916306-n', 1) ],
"_birdlife_n_1_rel" : [  ],
"_uniformed_a_1_rel" : [ SenseInfo('00457355-a', 3) ],
"_shadow_v_1_rel" : [ SenseInfo('02001461-v', 3), SenseInfo('02768702-v', 0), SenseInfo('02696306-v', 0) ],
"_priceless_a_1_rel" : [ SenseInfo('02501367-a', 3) ],
"_girl_n_1_rel" : [ SenseInfo('10129825-n', 80), SenseInfo('10084295-n', 57), SenseInfo('09992837-n', 8), SenseInfo('10130686-n', 6), SenseInfo('10130447-n', 5) ],
"_pucker_n_1_rel" : [ SenseInfo('13907847-n', 1) ],
"_rue_v_1_rel" : [ SenseInfo('01796582-v', 0), SenseInfo('01796582-v', 0) ],
"_millionth_n_of_rel" : [ SenseInfo('13849913-n', 0), SenseInfo('13739507-n', 0) ],
"_kingdom+come_n_1_rel" : [ SenseInfo('15143984-n', 0), SenseInfo('15121880-n', 0) ],
"_no+less_a_1_rel" : [  ],
"_higher_x_deg_rel" : [ SenseInfo('01211962-a', 10), SenseInfo('01211828-a', 1) ],
"_expansiveness_n_1_rel" : [ SenseInfo('04729710-n', 1), SenseInfo('04651009-n', 1) ],
"_dent_v_1_rel" : [ SenseInfo('01279631-v', 3) ],
"_palace_n_1_rel" : [ SenseInfo('03878066-n', 3), SenseInfo('08053121-n', 2), SenseInfo('03878211-n', 0), SenseInfo('03877845-n', 0), SenseInfo('03878066-n', 3), SenseInfo('08053121-n', 2), SenseInfo('03878211-n', 0), SenseInfo('03877845-n', 0) ],
"_succeed_v_in_rel" : [ SenseInfo('02524171-v', 28), SenseInfo('02406585-v', 12) ],
"_lessen_v_1_rel" : [ SenseInfo('00151689-v', 5), SenseInfo('00441445-v', 2), SenseInfo('00232956-v', 1) ],
"_overdo_v_1_rel" : [ SenseInfo('02568999-v', 0), SenseInfo('02568999-v', 0) ],
"_corset_n_1_rel" : [ SenseInfo('03112869-n', 0) ],
"_bestow_v_on_rel" : [ SenseInfo('02263346-v', 4), SenseInfo('02263692-v', 1), SenseInfo('02324478-v', 0), SenseInfo('02263346-v', 4), SenseInfo('02263692-v', 1), SenseInfo('02324478-v', 0) ],
"_thank_v_1_rel" : [ SenseInfo('00892315-v', 17), SenseInfo('00892315-v', 17), SenseInfo('00892315-v', 17), SenseInfo('00892315-v', 17), SenseInfo('00892315-v', 17) ],
"_type_v_up_rel" : [ SenseInfo('01004692-v', 2), SenseInfo('00618682-v', 1) ],
"_yoke_n_1_rel" : [ SenseInfo('04613015-n', 1), SenseInfo('13996909-n', 0), SenseInfo('13743605-n', 0), SenseInfo('08231065-n', 0), SenseInfo('04613350-n', 0), SenseInfo('04613158-n', 0), SenseInfo('04612840-n', 0) ],
"_what+of_x_rel" : [  ],
"_teenage_a_1_rel" : [ SenseInfo('01647983-a', 4) ],
"_shaving_n_1_rel" : [ SenseInfo('00254769-n', 3), SenseInfo('09385137-n', 1), SenseInfo('00150762-n', 0) ],
"_illustrious_a_1_rel" : [ SenseInfo('01375831-a', 1), SenseInfo('01121989-a', 1) ],
"_heighten_v_cause_rel" : [ SenseInfo('00432436-v', 1), SenseInfo('00432281-v', 1), SenseInfo('00229605-v', 1), SenseInfo('01975753-v', 0), SenseInfo('00392588-v', 0), SenseInfo('00227165-v', 0) ],
"_bold_a_1_rel" : [ SenseInfo('00249721-a', 9), SenseInfo('00579881-a', 3), SenseInfo('01145422-a', 0), SenseInfo('00249721-a', 9), SenseInfo('00579881-a', 3), SenseInfo('01145422-a', 0), SenseInfo('00249721-a', 9), SenseInfo('00579881-a', 3), SenseInfo('01145422-a', 0), SenseInfo('00249721-a', 9), SenseInfo('00579881-a', 3), SenseInfo('01145422-a', 0) ],
"_piston_v_cause_rel" : [  ],
"_unserviceable_a_1_rel" : [ SenseInfo('02124654-a', 0), SenseInfo('02497830-a', 0), SenseInfo('02124654-a', 0), SenseInfo('02497830-a', 0) ],
"_classmate_n_1_rel" : [ SenseInfo('10560106-n', 1) ],
"_costume_n_1_rel" : [ SenseInfo('03113657-n', 7), SenseInfo('03114041-n', 1), SenseInfo('03114236-n', 0), SenseInfo('03113835-n', 0), SenseInfo('03113657-n', 7), SenseInfo('03114041-n', 1), SenseInfo('03114236-n', 0), SenseInfo('03113835-n', 0) ],
"_widescreen_a_1_rel" : [  ],
"_hero_n_1_rel" : [ SenseInfo('10325013-n', 19), SenseInfo('05929670-n', 10), SenseInfo('09906538-n', 1), SenseInfo('11045106-n', 0), SenseInfo('10173086-n', 0), SenseInfo('09554297-n', 0), SenseInfo('07697825-n', 0) ],
"_advantage_n_1_rel" : [ SenseInfo('05155821-n', 23), SenseInfo('13610426-n', 0), SenseInfo('05142863-n', 0), SenseInfo('05155821-n', 23), SenseInfo('13610426-n', 0), SenseInfo('05142863-n', 0) ],
"_position_n_1_rel" : [ SenseInfo('08621598-n', 34), SenseInfo('08622586-n', 18), SenseInfo('06208751-n', 18), SenseInfo('05079866-n', 14), SenseInfo('13945919-n', 12), SenseInfo('00586262-n', 12), SenseInfo('05074774-n', 7), SenseInfo('08622201-n', 3), SenseInfo('00722479-n', 3), SenseInfo('01051331-n', 2), SenseInfo('13925752-n', 1), SenseInfo('06196284-n', 1), SenseInfo('06783265-n', 0), SenseInfo('06483454-n', 0), SenseInfo('00721431-n', 0), SenseInfo('00083448-n', 0) ],
"_tailor_v_to_rel" : [ SenseInfo('00301662-v', 5), SenseInfo('01666717-v', 1), SenseInfo('01666327-v', 0) ],
"_breech_v_1_rel" : [  ],
"_supremes_n_1_rel" : [  ],
"_nonentity_n_1_rel" : [ SenseInfo('13959931-n', 0), SenseInfo('09923418-n', 0) ],
"_amity_n_1_rel" : [ SenseInfo('04655929-n', 1), SenseInfo('13970460-n', 0) ],
"_pressurize_v_cause_rel" : [ SenseInfo('00403609-v', 0), SenseInfo('00403401-v', 0), SenseInfo('00403149-v', 0) ],
"_bets_n_i_rel" : [ SenseInfo('13343526-n', 1), SenseInfo('00506658-n', 0) ],
"_appreciative_a_1_rel" : [ SenseInfo('01146732-a', 1), SenseInfo('00774676-a', 0) ],
"_converse_n_1_rel" : [ SenseInfo('06751742-n', 0) ],
"_engage_v_1_rel" : [ SenseInfo('02375131-v', 31), SenseInfo('00600370-v', 9), SenseInfo('02409412-v', 2), SenseInfo('02401399-v', 1), SenseInfo('00886602-v', 1), SenseInfo('00220115-v', 1), SenseInfo('02376089-v', 0), SenseInfo('02240151-v', 0), SenseInfo('02208537-v', 0), SenseInfo('01510827-v', 0), SenseInfo('02375131-v', 31), SenseInfo('00600370-v', 9), SenseInfo('02409412-v', 2), SenseInfo('02401399-v', 1), SenseInfo('00886602-v', 1), SenseInfo('00220115-v', 1), SenseInfo('02376089-v', 0), SenseInfo('02240151-v', 0), SenseInfo('02208537-v', 0), SenseInfo('01510827-v', 0), SenseInfo('02375131-v', 31), SenseInfo('00600370-v', 9), SenseInfo('02409412-v', 2), SenseInfo('02401399-v', 1), SenseInfo('00886602-v', 1), SenseInfo('00220115-v', 1), SenseInfo('02376089-v', 0), SenseInfo('02240151-v', 0), SenseInfo('02208537-v', 0), SenseInfo('01510827-v', 0) ],
"_deepen_v_cause_rel" : [ SenseInfo('00227165-v', 1), SenseInfo('00226566-v', 1), SenseInfo('00570524-v', 0), SenseInfo('00551210-v', 0) ],
"_shoot_v_up_rel" : [ SenseInfo('01137138-v', 28), SenseInfo('02484570-v', 27), SenseInfo('01134781-v', 26), SenseInfo('01002740-v', 7), SenseInfo('02096047-v', 3), SenseInfo('02061495-v', 3), SenseInfo('02055267-v', 1), SenseInfo('01597286-v', 1), SenseInfo('01003249-v', 1), SenseInfo('02768259-v', 0), SenseInfo('02123175-v', 0), SenseInfo('01585523-v', 0), SenseInfo('01519184-v', 0), SenseInfo('01437144-v', 0), SenseInfo('01195804-v', 0), SenseInfo('01084466-v', 0), SenseInfo('00985219-v', 0), SenseInfo('00647508-v', 0), SenseInfo('00357332-v', 0), SenseInfo('00086320-v', 0) ],
"_leash_v_1_rel" : [ SenseInfo('01289155-v', 0) ],
"_corporeal_a_1_rel" : [ SenseInfo('00629997-a', 1), SenseInfo('01778935-a', 0) ],
"_turn_v_2-in_rel" : [ SenseInfo('01907258-v', 187), SenseInfo('00146138-v', 21), SenseInfo('02626604-v', 12), SenseInfo('02089984-v', 8), SenseInfo('00138508-v', 7), SenseInfo('01909812-v', 5), SenseInfo('00125841-v', 5), SenseInfo('01436518-v', 2), SenseInfo('02096167-v', 1), SenseInfo('02089420-v', 1), SenseInfo('01952208-v', 1), SenseInfo('01741864-v', 1), SenseInfo('01584450-v', 1), SenseInfo('00282523-v', 1), SenseInfo('00091124-v', 1), SenseInfo('02626934-v', 0), SenseInfo('02562425-v', 0), SenseInfo('02211948-v', 0), SenseInfo('02090435-v', 0), SenseInfo('01951937-v', 0), SenseInfo('01280014-v', 0), SenseInfo('01225215-v', 0), SenseInfo('01151889-v', 0), SenseInfo('00794640-v', 0), SenseInfo('00458471-v', 0), SenseInfo('00248387-v', 0) ],
"_tourniquet_n_1_rel" : [ SenseInfo('03082656-n', 0) ],
"_cast_v_as_rel" : [ SenseInfo('01632897-v', 15), SenseInfo('02236023-v', 3), SenseInfo('01710481-v', 2), SenseInfo('01507143-v', 1), SenseInfo('02385813-v', 0), SenseInfo('01881180-v', 0), SenseInfo('01662771-v', 0), SenseInfo('01513430-v', 0), SenseInfo('01078050-v', 0), SenseInfo('00981276-v', 0), SenseInfo('00076400-v', 0), SenseInfo('01632897-v', 15), SenseInfo('02236023-v', 3), SenseInfo('01710481-v', 2), SenseInfo('01507143-v', 1), SenseInfo('02385813-v', 0), SenseInfo('01881180-v', 0), SenseInfo('01662771-v', 0), SenseInfo('01513430-v', 0), SenseInfo('01078050-v', 0), SenseInfo('00981276-v', 0), SenseInfo('00076400-v', 0) ],
"_backtrack_v_1_rel" : [ SenseInfo('02004528-v', 0) ],
"_repentance_n_1_rel" : [ SenseInfo('07536870-n', 1) ],
"_st_n_1_rel" : [  ],
"_tank_v_up_rel" : [ SenseInfo('02282082-v', 0), SenseInfo('01171563-v', 0), SenseInfo('00185348-v', 0), SenseInfo('02282082-v', 0), SenseInfo('01171563-v', 0), SenseInfo('00185348-v', 0) ],
"_impulse_n_1_rel" : [ SenseInfo('09180431-n', 10), SenseInfo('07490579-n', 3), SenseInfo('07308042-n', 2), SenseInfo('07420991-n', 1), SenseInfo('00104249-n', 1), SenseInfo('05035820-n', 0) ],
"_whitish_a_1_rel" : [ SenseInfo('00434384-a', 0), SenseInfo('00392460-a', 0) ],
"_webbing_n_1_rel" : [ SenseInfo('09477319-n', 0), SenseInfo('04568944-n', 0), SenseInfo('04568841-n', 0) ],
"_impeccable_a_1_rel" : [ SenseInfo('01750847-a', 2), SenseInfo('02513521-a', 0) ],
"_stadium_n_1_rel" : [ SenseInfo('04295881-n', 2), SenseInfo('04295881-n', 2) ],
"_hemisphere_n_1_rel" : [ SenseInfo('08583095-n', 5), SenseInfo('13899109-n', 0), SenseInfo('05476915-n', 0) ],
"_scrape_v_away_rel" : [ SenseInfo('01308160-v', 4), SenseInfo('01750156-v', 1), SenseInfo('01309143-v', 1), SenseInfo('02040709-v', 0), SenseInfo('01384752-v', 0), SenseInfo('01309478-v', 0) ],
"_shine_n_1_rel" : [ SenseInfo('04953954-n', 0) ],
"_solicitous_a_of_rel" : [ SenseInfo('00544860-a', 0), SenseInfo('00164681-a', 0) ],
"_rather_a_1_rel" : [  ],
"_think_v_loc_rel" : [ SenseInfo('00689344-v', 274), SenseInfo('00631737-v', 188), SenseInfo('00628491-v', 111), SenseInfo('00607780-v', 8), SenseInfo('01637166-v', 4), SenseInfo('00723056-v', 3), SenseInfo('00708538-v', 2), SenseInfo('00739340-v', 0), SenseInfo('00739082-v', 0), SenseInfo('00689809-v', 0), SenseInfo('00629738-v', 0), SenseInfo('00608808-v', 0), SenseInfo('00561887-v', 0) ],
"_charter_n_1_rel" : [ SenseInfo('06471737-n', 2), SenseInfo('06522501-n', 0) ],
"_pastureland_n_1_rel" : [ SenseInfo('08616050-n', 0) ],
"_through_p_sel_rel" : [ SenseInfo('00478821-r', 5), SenseInfo('01003536-a', 4), SenseInfo('00478634-r', 2), SenseInfo('00478904-r', 1), SenseInfo('00478730-r', 0), SenseInfo('00057626-r', 0), SenseInfo('00762168-a', 0) ],
"_run-up_n_1_rel" : [ SenseInfo('07414370-n', 0), SenseInfo('00476788-n', 0), SenseInfo('07414370-n', 0), SenseInfo('00476788-n', 0) ],
"_eastward_a_2_rel" : [ SenseInfo('00823556-a', 1) ],
"_wink_v_at_rel" : [ SenseInfo('00008299-v', 10), SenseInfo('02159890-v', 3), SenseInfo('00007739-v', 1), SenseInfo('00008435-v', 0) ],
"_exceptional_a_1_rel" : [ SenseInfo('01676026-a', 3), SenseInfo('00488187-a', 2), SenseInfo('01598859-a', 0), SenseInfo('01676026-a', 3), SenseInfo('00488187-a', 2), SenseInfo('01598859-a', 0) ],
"_puff_v_1_rel" : [ SenseInfo('01198616-v', 2), SenseInfo('01199009-v', 1), SenseInfo('00005526-v', 1), SenseInfo('01812197-v', 0), SenseInfo('01065272-v', 0), SenseInfo('00797303-v', 0), SenseInfo('00263682-v', 0), SenseInfo('00006802-v', 0) ],
"_dust_v_1_rel" : [ SenseInfo('01244351-v', 3), SenseInfo('01252216-v', 1), SenseInfo('01612660-v', 0), SenseInfo('01376245-v', 0) ],
"_unless_x_rel" : [  ],
"_conspirator_n_1_rel" : [ SenseInfo('09958892-n', 1) ],
"_ramble_v_1_rel" : [ SenseInfo('02684453-v', 2), SenseInfo('01881180-v', 0), SenseInfo('02684453-v', 2), SenseInfo('01881180-v', 0) ],
"_today_a_2_rel" : [ SenseInfo('15262921-n', 69), SenseInfo('15156001-n', 13), SenseInfo('15262921-n', 69), SenseInfo('15156001-n', 13) ],
"_check_v_on_rel" : [ SenseInfo('00661824-v', 27), SenseInfo('02533282-v', 7), SenseInfo('00662589-v', 6), SenseInfo('02510337-v', 5), SenseInfo('01861403-v', 1), SenseInfo('00662182-v', 1), SenseInfo('00440286-v', 1), SenseInfo('02658283-v', 0), SenseInfo('02657219-v', 0), SenseInfo('02557638-v', 0), SenseInfo('02553697-v', 0), SenseInfo('02347905-v', 0), SenseInfo('02347447-v', 0), SenseInfo('01861767-v', 0), SenseInfo('01861622-v', 0), SenseInfo('01692978-v', 0), SenseInfo('01139756-v', 0), SenseInfo('01131473-v', 0), SenseInfo('01114764-v', 0), SenseInfo('01064999-v', 0), SenseInfo('00920336-v', 0), SenseInfo('00663353-v', 0), SenseInfo('00354634-v', 0), SenseInfo('00336539-v', 0), SenseInfo('00336260-v', 0) ],
"_angling_n_1_rel" : [ SenseInfo('00454237-n', 0) ],
"_yen_n_1_rel" : [ SenseInfo('07486922-n', 1), SenseInfo('13709700-n', 0), SenseInfo('07486922-n', 1), SenseInfo('13709700-n', 0), SenseInfo('07486922-n', 1), SenseInfo('13709700-n', 0) ],
"_revelation_n_of_rel" : [ SenseInfo('07213395-n', 4), SenseInfo('05808102-n', 4), SenseInfo('07213232-n', 0), SenseInfo('06447897-n', 0), SenseInfo('07213395-n', 4), SenseInfo('05808102-n', 4), SenseInfo('07213232-n', 0), SenseInfo('06447897-n', 0) ],
"_recycle_n_1_rel" : [  ],
"_hopeful_a_1_rel" : [ SenseInfo('01228530-a', 2), SenseInfo('00176387-a', 1) ],
"_geographer_n_1_rel" : [ SenseInfo('10127555-n', 1) ],
"_esker_n_1_rel" : [ SenseInfo('09274305-n', 0) ],
"_conductive_a_1_rel" : [ SenseInfo('00557813-a', 0) ],
"_requirement_n_1_rel" : [ SenseInfo('05892651-n', 19), SenseInfo('09367203-n', 18), SenseInfo('05892427-n', 11), SenseInfo('05892651-n', 19), SenseInfo('09367203-n', 18), SenseInfo('05892427-n', 11), SenseInfo('05892651-n', 19), SenseInfo('09367203-n', 18), SenseInfo('05892427-n', 11), SenseInfo('05892651-n', 19), SenseInfo('09367203-n', 18), SenseInfo('05892427-n', 11), SenseInfo('05892651-n', 19), SenseInfo('09367203-n', 18), SenseInfo('05892427-n', 11), SenseInfo('05892651-n', 19), SenseInfo('09367203-n', 18), SenseInfo('05892427-n', 11) ],
"_validity_n_1_rel" : [ SenseInfo('04783567-n', 4), SenseInfo('04809453-n', 1), SenseInfo('05031012-n', 0), SenseInfo('04783567-n', 4), SenseInfo('04809453-n', 1), SenseInfo('05031012-n', 0) ],
"_first+of+all_a_1_rel" : [  ],
"_chill_v_1_rel" : [ SenseInfo('01818972-v', 2), SenseInfo('00370412-v', 1), SenseInfo('00369864-v', 0), SenseInfo('01818972-v', 2), SenseInfo('00370412-v', 1), SenseInfo('00369864-v', 0), SenseInfo('01818972-v', 2), SenseInfo('00370412-v', 1), SenseInfo('00369864-v', 0), SenseInfo('01818972-v', 2), SenseInfo('00370412-v', 1), SenseInfo('00369864-v', 0) ],
"_lunge_v_1_rel" : [ SenseInfo('02062212-v', 6) ],
"_palliate_v_1_rel" : [ SenseInfo('00906037-v', 0), SenseInfo('00064095-v', 0) ],
"_drop_v_off_rel" : [ SenseInfo('01977701-v', 36), SenseInfo('01976841-v', 21), SenseInfo('00432683-v', 12), SenseInfo('01985923-v', 7), SenseInfo('02403920-v', 6), SenseInfo('00941446-v', 6), SenseInfo('00363110-v', 5), SenseInfo('01489465-v', 3), SenseInfo('01258302-v', 2), SenseInfo('01100008-v', 2), SenseInfo('02267060-v', 1), SenseInfo('00393534-v', 1), SenseInfo('02717472-v', 0), SenseInfo('02465939-v', 0), SenseInfo('01611516-v', 0), SenseInfo('01513430-v', 0), SenseInfo('01200661-v', 0), SenseInfo('00615615-v', 0), SenseInfo('00614999-v', 0), SenseInfo('00548616-v', 0), SenseInfo('00148341-v', 0), SenseInfo('00092293-v', 0), SenseInfo('00057764-v', 0), SenseInfo('01977701-v', 36), SenseInfo('01976841-v', 21), SenseInfo('00432683-v', 12), SenseInfo('01985923-v', 7), SenseInfo('02403920-v', 6), SenseInfo('00941446-v', 6), SenseInfo('00363110-v', 5), SenseInfo('01489465-v', 3), SenseInfo('01258302-v', 2), SenseInfo('01100008-v', 2), SenseInfo('02267060-v', 1), SenseInfo('00393534-v', 1), SenseInfo('02717472-v', 0), SenseInfo('02465939-v', 0), SenseInfo('01611516-v', 0), SenseInfo('01513430-v', 0), SenseInfo('01200661-v', 0), SenseInfo('00615615-v', 0), SenseInfo('00614999-v', 0), SenseInfo('00548616-v', 0), SenseInfo('00148341-v', 0), SenseInfo('00092293-v', 0), SenseInfo('00057764-v', 0) ],
"_methodical_a_1_rel" : [ SenseInfo('01668567-a', 3) ],
"_impetus_n_1_rel" : [ SenseInfo('11447851-n', 3), SenseInfo('00104249-n', 0) ],
"_untruth_n_1_rel" : [ SenseInfo('06756407-n', 1) ],
"_crater_v_1_rel" : [  ],
"_security_n_1_rel" : [ SenseInfo('14539268-n', 17), SenseInfo('13344071-n', 5), SenseInfo('07526338-n', 1), SenseInfo('13416345-n', 0), SenseInfo('13349395-n', 0), SenseInfo('08120910-n', 0), SenseInfo('06685754-n', 0), SenseInfo('04165945-n', 0), SenseInfo('00823316-n', 0), SenseInfo('14539268-n', 17), SenseInfo('13344071-n', 5), SenseInfo('07526338-n', 1), SenseInfo('13416345-n', 0), SenseInfo('13349395-n', 0), SenseInfo('08120910-n', 0), SenseInfo('06685754-n', 0), SenseInfo('04165945-n', 0), SenseInfo('00823316-n', 0), SenseInfo('14539268-n', 17), SenseInfo('13344071-n', 5), SenseInfo('07526338-n', 1), SenseInfo('13416345-n', 0), SenseInfo('13349395-n', 0), SenseInfo('08120910-n', 0), SenseInfo('06685754-n', 0), SenseInfo('04165945-n', 0), SenseInfo('00823316-n', 0) ],
"_panamanian_n_1_rel" : [ SenseInfo('09726120-n', 0) ],
"_akin_a_1_rel" : [ SenseInfo('02071782-a', 3), SenseInfo('01971846-a', 0) ],
"_exit_n_1_rel" : [ SenseInfo('03303965-n', 1), SenseInfo('07333649-n', 0), SenseInfo('00058519-n', 0) ],
"_hump_v_1_rel" : [ SenseInfo('02035559-v', 0), SenseInfo('01426397-v', 0) ],
"_readiness_n_1_rel" : [ SenseInfo('14031108-n', 3), SenseInfo('04644719-n', 2), SenseInfo('05674584-n', 1), SenseInfo('04708796-n', 0), SenseInfo('14031108-n', 3), SenseInfo('04644719-n', 2), SenseInfo('05674584-n', 1), SenseInfo('04708796-n', 0) ],
"_mortal_n_1_rel" : [ SenseInfo('00007846-n', 2) ],
"_unimaginable_a_to_rel" : [ SenseInfo('02418692-a', 1), SenseInfo('02418692-a', 1), SenseInfo('02418692-a', 1), SenseInfo('02418692-a', 1) ],
"_special_a_1_rel" : [ SenseInfo('01104026-a', 30), SenseInfo('01678729-a', 20), SenseInfo('00488187-a', 7), SenseInfo('02278011-a', 6), SenseInfo('01103844-a', 3), SenseInfo('01853228-a', 2), SenseInfo('02367319-a', 0), SenseInfo('01104026-a', 30), SenseInfo('01678729-a', 20), SenseInfo('00488187-a', 7), SenseInfo('02278011-a', 6), SenseInfo('01103844-a', 3), SenseInfo('01853228-a', 2), SenseInfo('02367319-a', 0) ],
"_carry_v_away_rel" : [ SenseInfo('01449974-v', 72), SenseInfo('02717102-v', 36), SenseInfo('02079933-v', 8), SenseInfo('01061017-v', 8), SenseInfo('01218084-v', 6), SenseInfo('01601234-v', 5), SenseInfo('02700867-v', 4), SenseInfo('02561168-v', 4), SenseInfo('00235110-v', 3), SenseInfo('02636325-v', 2), SenseInfo('01101416-v', 2), SenseInfo('00738951-v', 2), SenseInfo('02518161-v', 1), SenseInfo('02285392-v', 1), SenseInfo('01746359-v', 1), SenseInfo('01408760-v', 1), SenseInfo('01061320-v', 1), SenseInfo('02746735-v', 0), SenseInfo('02741357-v', 0), SenseInfo('02682954-v', 0), SenseInfo('02636516-v', 0), SenseInfo('02630734-v', 0), SenseInfo('02586121-v', 0), SenseInfo('02556537-v', 0), SenseInfo('02555684-v', 0), SenseInfo('02359228-v', 0), SenseInfo('02303878-v', 0), SenseInfo('02233195-v', 0), SenseInfo('02012725-v', 0), SenseInfo('02001699-v', 0), SenseInfo('01740320-v', 0), SenseInfo('01241881-v', 0), SenseInfo('01205153-v', 0), SenseInfo('01203074-v', 0), SenseInfo('01123609-v', 0), SenseInfo('01123415-v', 0), SenseInfo('01101571-v', 0), SenseInfo('01100672-v', 0), SenseInfo('01049606-v', 0), SenseInfo('00059019-v', 0) ],
"_affix_n_1_rel" : [ SenseInfo('06308049-n', 0) ],
"_esteemed_a_1_rel" : [ SenseInfo('01982957-a', 0) ],
"_pentagon_n_1_rel" : [ SenseInfo('03912496-n', 2), SenseInfo('08207095-n', 1), SenseInfo('13882201-n', 0) ],
"_moon_n_1_rel" : [ SenseInfo('09358358-n', 30), SenseInfo('09358550-n', 1), SenseInfo('15207872-n', 0), SenseInfo('11484975-n', 0), SenseInfo('11189054-n', 0), SenseInfo('09358226-n', 0) ],
"_geographic_a_1_rel" : [ SenseInfo('03021543-a', 1), SenseInfo('01470496-a', 0) ],
"_sleepy_a_1_rel" : [ SenseInfo('00189017-a', 6), SenseInfo('00189017-a', 6), SenseInfo('00189017-a', 6) ],
"_tourism_n_1_rel" : [ SenseInfo('00298161-n', 0) ],
"_revolutionary_a_1_rel" : [ SenseInfo('01642657-a', 7), SenseInfo('02939919-a', 0), SenseInfo('02835481-a', 0), SenseInfo('02015238-a', 0) ],
"_parenthood_n_1_rel" : [ SenseInfo('14425414-n', 2) ],
"_invocation_n_1_rel" : [ SenseInfo('07190290-n', 1), SenseInfo('07160296-n', 0), SenseInfo('05978159-n', 0), SenseInfo('00097244-n', 0) ],
"_that+is_a_1_rel" : [  ],
"_underofficer_n_1_rel" : [  ],
"_diabetic_a_1_rel" : [ SenseInfo('03060971-a', 0), SenseInfo('02543934-a', 0) ],
"_award_n_for_rel" : [ SenseInfo('00087663-n', 26), SenseInfo('06696483-n', 6), SenseInfo('13268146-n', 5) ],
"_torque_v_1_rel" : [  ],
"_ballpark_n_1_rel" : [ SenseInfo('02782778-n', 1), SenseInfo('05126066-n', 0), SenseInfo('02782778-n', 1), SenseInfo('05126066-n', 0) ],
"_plus+sign_n_1_rel" : [ SenseInfo('06811986-n', 0) ],
"_cite_v_1_rel" : [ SenseInfo('01024190-v', 13), SenseInfo('01023071-v', 4), SenseInfo('01705257-v', 3), SenseInfo('01023259-v', 2), SenseInfo('01023574-v', 0), SenseInfo('01015866-v', 0), SenseInfo('00791134-v', 0) ],
"_postmortem_n_1_rel" : [ SenseInfo('07144039-n', 0), SenseInfo('00141396-n', 0), SenseInfo('07144039-n', 0), SenseInfo('00141396-n', 0) ],
"_subtract_v_1_rel" : [ SenseInfo('00641252-v', 9), SenseInfo('00586973-v', 0) ],
"_outhouse_n_1_rel" : [ SenseInfo('03860404-n', 0) ],
"_do_v_1_rel" : [ SenseInfo('02560585-v', 526), SenseInfo('01712704-v', 173), SenseInfo('02561995-v', 134), SenseInfo('02617567-v', 58), SenseInfo('01645601-v', 35), SenseInfo('02568672-v', 20), SenseInfo('02669789-v', 11), SenseInfo('01619014-v', 9), SenseInfo('00010435-v', 3), SenseInfo('02709107-v', 2), SenseInfo('02523221-v', 2), SenseInfo('00038849-v', 2), SenseInfo('01841772-v', 1), SenseInfo('02560585-v', 526), SenseInfo('01712704-v', 173), SenseInfo('02561995-v', 134), SenseInfo('02617567-v', 58), SenseInfo('01645601-v', 35), SenseInfo('02568672-v', 20), SenseInfo('02669789-v', 11), SenseInfo('01619014-v', 9), SenseInfo('00010435-v', 3), SenseInfo('02709107-v', 2), SenseInfo('02523221-v', 2), SenseInfo('00038849-v', 2), SenseInfo('01841772-v', 1), SenseInfo('02560585-v', 526), SenseInfo('01712704-v', 173), SenseInfo('02561995-v', 134), SenseInfo('02617567-v', 58), SenseInfo('01645601-v', 35), SenseInfo('02568672-v', 20), SenseInfo('02669789-v', 11), SenseInfo('01619014-v', 9), SenseInfo('00010435-v', 3), SenseInfo('02709107-v', 2), SenseInfo('02523221-v', 2), SenseInfo('00038849-v', 2), SenseInfo('01841772-v', 1), SenseInfo('02560585-v', 526), SenseInfo('01712704-v', 173), SenseInfo('02561995-v', 134), SenseInfo('02617567-v', 58), SenseInfo('01645601-v', 35), SenseInfo('02568672-v', 20), SenseInfo('02669789-v', 11), SenseInfo('01619014-v', 9), SenseInfo('00010435-v', 3), SenseInfo('02709107-v', 2), SenseInfo('02523221-v', 2), SenseInfo('00038849-v', 2), SenseInfo('01841772-v', 1), SenseInfo('02560585-v', 526), SenseInfo('01712704-v', 173), SenseInfo('02561995-v', 134), SenseInfo('02617567-v', 58), SenseInfo('01645601-v', 35), SenseInfo('02568672-v', 20), SenseInfo('02669789-v', 11), SenseInfo('01619014-v', 9), SenseInfo('00010435-v', 3), SenseInfo('02709107-v', 2), SenseInfo('02523221-v', 2), SenseInfo('00038849-v', 2), SenseInfo('01841772-v', 1) ],
"_racism_n_1_rel" : [ SenseInfo('06203758-n', 0), SenseInfo('01155044-n', 0) ],
"_bus+line_n_1_rel" : [ SenseInfo('02925901-n', 1) ],
"_horrible_a_to_rel" : [ SenseInfo('00193480-a', 4), SenseInfo('00193480-a', 4), SenseInfo('00193480-a', 4) ],
"_forwards_a_1_rel" : [ SenseInfo('00203237-a', 8), SenseInfo('00204491-a', 0), SenseInfo('00203774-a', 0), SenseInfo('01876555-a', 0) ],
"_jealousy_n_1_rel" : [ SenseInfo('07550079-n', 2), SenseInfo('05706076-n', 0) ],
"_occur_v_to_rel" : [ SenseInfo('00339934-v', 81), SenseInfo('00723349-v', 21), SenseInfo('02612368-v', 0), SenseInfo('00339934-v', 81), SenseInfo('00723349-v', 21), SenseInfo('02612368-v', 0), SenseInfo('00339934-v', 81), SenseInfo('00723349-v', 21), SenseInfo('02612368-v', 0) ],
"_elucidate_v_1_rel" : [ SenseInfo('00939857-v', 1), SenseInfo('00621058-v', 0), SenseInfo('00939857-v', 1), SenseInfo('00621058-v', 0) ],
"_rudiment_n_1_rel" : [ SenseInfo('05872742-n', 0), SenseInfo('05604022-n', 0) ],
"_managerial_a_1_rel" : [ SenseInfo('02904223-a', 0) ],
"_continual_a_1_rel" : [ SenseInfo('00592222-a', 4), SenseInfo('00595863-a', 0), SenseInfo('00592222-a', 4), SenseInfo('00595863-a', 0) ],
"_founder_v_1_rel" : [ SenseInfo('02530003-v', 0), SenseInfo('01990168-v', 0), SenseInfo('01989053-v', 0), SenseInfo('01900648-v', 0) ],
"_free_v_up_rel" : [ SenseInfo('02421374-v', 6), SenseInfo('02350175-v', 3), SenseInfo('01528522-v', 3), SenseInfo('02564146-v', 1), SenseInfo('02494047-v', 1), SenseInfo('02422026-v', 1), SenseInfo('01475953-v', 1), SenseInfo('00902424-v', 1), SenseInfo('02316304-v', 0), SenseInfo('01757994-v', 0), SenseInfo('00269682-v', 0) ],
"_advertise_v_1_rel" : [ SenseInfo('00975902-v', 7), SenseInfo('00976653-v', 0) ],
"_voice_n_1_rel" : [ SenseInfo('04981941-n', 78), SenseInfo('07110615-n', 69), SenseInfo('07399452-n', 5), SenseInfo('07073208-n', 5), SenseInfo('00179683-n', 4), SenseInfo('07277697-n', 3), SenseInfo('10758713-n', 2), SenseInfo('10638385-n', 2), SenseInfo('05202284-n', 2), SenseInfo('13802920-n', 0), SenseInfo('07030718-n', 0) ],
"_minuet_n_1_rel" : [ SenseInfo('00536778-n', 1), SenseInfo('07056113-n', 0) ],
"_buffalo_v_1_rel" : [ SenseInfo('01780010-v', 0) ],
"_torpedo_n_1_rel" : [ SenseInfo('10152083-n', 0), SenseInfo('07697825-n', 0), SenseInfo('04457157-n', 0), SenseInfo('04456964-n', 0), SenseInfo('04456734-n', 0), SenseInfo('04456472-n', 0), SenseInfo('01496331-n', 0) ],
"_orderly_a_1_rel" : [ SenseInfo('01666126-a', 4), SenseInfo('02423284-a', 0) ],
"_reveal_v_to_rel" : [ SenseInfo('02143283-v', 34), SenseInfo('00933821-v', 17), SenseInfo('02144243-v', 0), SenseInfo('02143283-v', 34), SenseInfo('00933821-v', 17), SenseInfo('02144243-v', 0), SenseInfo('02143283-v', 34), SenseInfo('00933821-v', 17), SenseInfo('02144243-v', 0), SenseInfo('02143283-v', 34), SenseInfo('00933821-v', 17), SenseInfo('02144243-v', 0), SenseInfo('02143283-v', 34), SenseInfo('00933821-v', 17), SenseInfo('02144243-v', 0), SenseInfo('02143283-v', 34), SenseInfo('00933821-v', 17), SenseInfo('02144243-v', 0), SenseInfo('02143283-v', 34), SenseInfo('00933821-v', 17), SenseInfo('02144243-v', 0), SenseInfo('02143283-v', 34), SenseInfo('00933821-v', 17), SenseInfo('02144243-v', 0) ],
"_fluctuation_n_in_rel" : [ SenseInfo('07346057-n', 0), SenseInfo('07337390-n', 0), SenseInfo('04770911-n', 0) ],
"_runway_n_1_rel" : [ SenseInfo('04463679-n', 0), SenseInfo('04121142-n', 0), SenseInfo('04120998-n', 0), SenseInfo('04120842-n', 0) ],
"_navigation+wise_a_1_rel" : [  ],
"_pictorial_a_1_rel" : [ SenseInfo('02861617-a', 3), SenseInfo('01941026-a', 1) ],
"_gravitational_a_1_rel" : [ SenseInfo('02737183-a', 1) ],
"_pro_x_deg_rel" : [ SenseInfo('01817301-a', 5), SenseInfo('10480583-n', 1), SenseInfo('06649223-n', 0), SenseInfo('00289204-r', 0) ],
"_hitch_v_to_rel" : [ SenseInfo('01327816-v', 2), SenseInfo('01917244-v', 1), SenseInfo('01884383-v', 1), SenseInfo('01956955-v', 0), SenseInfo('01614774-v', 0) ],
"_juice_v_1_rel" : [  ],
"_skew_v_cause_rel" : [ SenseInfo('00466484-v', 0) ],
"_impression_n_of_rel" : [ SenseInfo('05916739-n', 14), SenseInfo('04675314-n', 6), SenseInfo('05936704-n', 1), SenseInfo('13896369-n', 0), SenseInfo('06855207-n', 0), SenseInfo('06590210-n', 0), SenseInfo('03564849-n', 0), SenseInfo('00549106-n', 0), SenseInfo('00113532-n', 0), SenseInfo('05916739-n', 14), SenseInfo('04675314-n', 6), SenseInfo('05936704-n', 1), SenseInfo('13896369-n', 0), SenseInfo('06855207-n', 0), SenseInfo('06590210-n', 0), SenseInfo('03564849-n', 0), SenseInfo('00549106-n', 0), SenseInfo('00113532-n', 0) ],
"_demur_v_to_rel" : [ SenseInfo('00807941-v', 1), SenseInfo('01016626-v', 0) ],
"_urbanize_v_1_rel" : [ SenseInfo('00499812-v', 1), SenseInfo('00500055-v', 0) ],
"_crust_v_1_rel" : [ SenseInfo('00356789-v', 0) ],
"_worry_v_1_rel" : [ SenseInfo('01767163-v', 32), SenseInfo('01766748-v', 9), SenseInfo('01765908-v', 9), SenseInfo('02678438-v', 0), SenseInfo('01559473-v', 0), SenseInfo('01251109-v', 0), SenseInfo('01767163-v', 32), SenseInfo('01766748-v', 9), SenseInfo('01765908-v', 9), SenseInfo('02678438-v', 0), SenseInfo('01559473-v', 0), SenseInfo('01251109-v', 0), SenseInfo('01767163-v', 32), SenseInfo('01766748-v', 9), SenseInfo('01765908-v', 9), SenseInfo('02678438-v', 0), SenseInfo('01559473-v', 0), SenseInfo('01251109-v', 0), SenseInfo('01767163-v', 32), SenseInfo('01766748-v', 9), SenseInfo('01765908-v', 9), SenseInfo('02678438-v', 0), SenseInfo('01559473-v', 0), SenseInfo('01251109-v', 0) ],
"_why_x_rel" : [ SenseInfo('09179606-n', 0), SenseInfo('09179606-n', 0), SenseInfo('09179606-n', 0) ],
"_will+power_n_1_rel" : [ SenseInfo('04862005-n', 1) ],
"_cannon_v_1_rel" : [ SenseInfo('01147987-v', 0), SenseInfo('01134522-v', 0) ],
"_fend_v_for_rel" : [ SenseInfo('02588122-v', 0), SenseInfo('01115916-v', 0) ],
"_tame_v_1_rel" : [ SenseInfo('00202445-v', 1), SenseInfo('00933566-v', 0), SenseInfo('00302464-v', 0), SenseInfo('00302130-v', 0), SenseInfo('00301856-v', 0) ],
"_troll_n_1_rel" : [ SenseInfo('09502481-n', 1), SenseInfo('07053089-n', 0), SenseInfo('04486934-n', 0), SenseInfo('00454493-n', 0) ],
"_powerful_n_1_rel" : [ SenseInfo('01825671-a', 18), SenseInfo('02323072-a', 2), SenseInfo('01830599-a', 2), SenseInfo('02321809-a', 1), SenseInfo('01261363-a', 0) ],
"_parent_v_1_rel" : [ SenseInfo('02539788-v', 0) ],
"_wind_v_up_rel" : [ SenseInfo('01882814-v', 3), SenseInfo('02738701-v', 2), SenseInfo('01522276-v', 2), SenseInfo('02125223-v', 0), SenseInfo('01522052-v', 0), SenseInfo('01516965-v', 0), SenseInfo('01455184-v', 0), SenseInfo('01882814-v', 3), SenseInfo('02738701-v', 2), SenseInfo('01522276-v', 2), SenseInfo('02125223-v', 0), SenseInfo('01522052-v', 0), SenseInfo('01516965-v', 0), SenseInfo('01455184-v', 0), SenseInfo('01882814-v', 3), SenseInfo('02738701-v', 2), SenseInfo('01522276-v', 2), SenseInfo('02125223-v', 0), SenseInfo('01522052-v', 0), SenseInfo('01516965-v', 0), SenseInfo('01455184-v', 0), SenseInfo('01882814-v', 3), SenseInfo('02738701-v', 2), SenseInfo('01522276-v', 2), SenseInfo('02125223-v', 0), SenseInfo('01522052-v', 0), SenseInfo('01516965-v', 0), SenseInfo('01455184-v', 0) ],
"_practicable_a_1_rel" : [ SenseInfo('01835663-a', 2), SenseInfo('01822563-a', 2) ],
"_nicest_a_for_rel" : [  ],
"_practical_a_1_rel" : [ SenseInfo('01834304-a', 21), SenseInfo('01940651-a', 2), SenseInfo('01941814-a', 0), SenseInfo('00863555-a', 0), SenseInfo('01834304-a', 21), SenseInfo('01940651-a', 2), SenseInfo('01941814-a', 0), SenseInfo('00863555-a', 0) ],
"_curtain_v_1_rel" : [ SenseInfo('02353537-v', 0) ],
"_decoration_n_of_rel" : [ SenseInfo('03169390-n', 4), SenseInfo('06706676-n', 0), SenseInfo('00262249-n', 0) ],
"_go_v_through_rel" : [ SenseInfo('01835496-v', 343), SenseInfo('02372605-v', 95), SenseInfo('01848718-v', 49), SenseInfo('00149583-v', 29), SenseInfo('02653862-v', 14), SenseInfo('02721284-v', 10), SenseInfo('02685951-v', 10), SenseInfo('00341560-v', 10), SenseInfo('00359916-v', 9), SenseInfo('02618001-v', 7), SenseInfo('02176268-v', 3), SenseInfo('01525666-v', 3), SenseInfo('01192773-v', 3), SenseInfo('00539110-v', 3), SenseInfo('02618149-v', 2), SenseInfo('02617798-v', 2), SenseInfo('00358431-v', 2), SenseInfo('02737876-v', 1), SenseInfo('02729819-v', 1), SenseInfo('01864230-v', 1), SenseInfo('01076615-v', 1), SenseInfo('02700772-v', 0), SenseInfo('02700666-v', 0), SenseInfo('02700455-v', 0), SenseInfo('02686471-v', 0), SenseInfo('02659763-v', 0), SenseInfo('01318849-v', 0), SenseInfo('01192992-v', 0), SenseInfo('00676267-v', 0), SenseInfo('00434374-v', 0), SenseInfo('01835496-v', 343), SenseInfo('02372605-v', 95), SenseInfo('01848718-v', 49), SenseInfo('00149583-v', 29), SenseInfo('02653862-v', 14), SenseInfo('02721284-v', 10), SenseInfo('02685951-v', 10), SenseInfo('00341560-v', 10), SenseInfo('00359916-v', 9), SenseInfo('02618001-v', 7), SenseInfo('02176268-v', 3), SenseInfo('01525666-v', 3), SenseInfo('01192773-v', 3), SenseInfo('00539110-v', 3), SenseInfo('02618149-v', 2), SenseInfo('02617798-v', 2), SenseInfo('00358431-v', 2), SenseInfo('02737876-v', 1), SenseInfo('02729819-v', 1), SenseInfo('01864230-v', 1), SenseInfo('01076615-v', 1), SenseInfo('02700772-v', 0), SenseInfo('02700666-v', 0), SenseInfo('02700455-v', 0), SenseInfo('02686471-v', 0), SenseInfo('02659763-v', 0), SenseInfo('01318849-v', 0), SenseInfo('01192992-v', 0), SenseInfo('00676267-v', 0), SenseInfo('00434374-v', 0) ],
"_focus_v_cause-on_rel" : [ SenseInfo('00722232-v', 6), SenseInfo('02161922-v', 4), SenseInfo('00731789-v', 1), SenseInfo('00314782-v', 0), SenseInfo('00314272-v', 0) ],
"_lobster_n_1_rel" : [ SenseInfo('07792725-n', 0), SenseInfo('01982650-n', 0) ],
"_show_v_off_rel" : [ SenseInfo('02148788-v', 136), SenseInfo('00664788-v', 63), SenseInfo('01015244-v', 57), SenseInfo('02137132-v', 43), SenseInfo('01686956-v', 32), SenseInfo('00943837-v', 24), SenseInfo('00923793-v', 24), SenseInfo('02139544-v', 11), SenseInfo('00922867-v', 7), SenseInfo('00923307-v', 6), SenseInfo('02000547-v', 2), SenseInfo('01086549-v', 0), SenseInfo('02148788-v', 136), SenseInfo('00664788-v', 63), SenseInfo('01015244-v', 57), SenseInfo('02137132-v', 43), SenseInfo('01686956-v', 32), SenseInfo('00943837-v', 24), SenseInfo('00923793-v', 24), SenseInfo('02139544-v', 11), SenseInfo('00922867-v', 7), SenseInfo('00923307-v', 6), SenseInfo('02000547-v', 2), SenseInfo('01086549-v', 0) ],
"_frenzy_n_1_rel" : [ SenseInfo('14391876-n', 6) ],
"_muse_v_1_rel" : [ SenseInfo('00630380-v', 10), SenseInfo('00630380-v', 10) ],
"_colitis_n_1_rel" : [ SenseInfo('14341091-n', 0) ],
"_enticement_n_1_rel" : [ SenseInfo('05694791-n', 0), SenseInfo('04689660-n', 0), SenseInfo('00159620-n', 0) ],
"_frame_n_1_rel" : [ SenseInfo('03391301-n', 7), SenseInfo('03391464-n', 5), SenseInfo('05217168-n', 3), SenseInfo('15255804-n', 2), SenseInfo('07003568-n', 0), SenseInfo('06570805-n', 0), SenseInfo('05663104-n', 0), SenseInfo('05585383-n', 0), SenseInfo('04226537-n', 0), SenseInfo('03390983-n', 0), SenseInfo('00462116-n', 0) ],
"_unsatisfying_a_for_rel" : [ SenseInfo('02082611-a', 0), SenseInfo('02082611-a', 0), SenseInfo('02082611-a', 0), SenseInfo('02082611-a', 0), SenseInfo('02082611-a', 0), SenseInfo('02082611-a', 0) ],
"_straight_a_1_rel" : [ SenseInfo('00596511-a', 10), SenseInfo('02310895-a', 6), SenseInfo('01030826-a', 5), SenseInfo('01237754-a', 2), SenseInfo('00022962-a', 1), SenseInfo('02318464-a', 0), SenseInfo('02318272-a', 0), SenseInfo('02314584-a', 0), SenseInfo('02423981-a', 0), SenseInfo('01201298-a', 0), SenseInfo('00911204-a', 0), SenseInfo('00766102-a', 0), SenseInfo('00757120-a', 0), SenseInfo('00632306-a', 0), SenseInfo('00607857-a', 0), SenseInfo('00596511-a', 10), SenseInfo('02310895-a', 6), SenseInfo('01030826-a', 5), SenseInfo('01237754-a', 2), SenseInfo('00022962-a', 1), SenseInfo('02318464-a', 0), SenseInfo('02318272-a', 0), SenseInfo('02314584-a', 0), SenseInfo('02423981-a', 0), SenseInfo('01201298-a', 0), SenseInfo('00911204-a', 0), SenseInfo('00766102-a', 0), SenseInfo('00757120-a', 0), SenseInfo('00632306-a', 0), SenseInfo('00607857-a', 0), SenseInfo('00596511-a', 10), SenseInfo('02310895-a', 6), SenseInfo('01030826-a', 5), SenseInfo('01237754-a', 2), SenseInfo('00022962-a', 1), SenseInfo('02318464-a', 0), SenseInfo('02318272-a', 0), SenseInfo('02314584-a', 0), SenseInfo('02423981-a', 0), SenseInfo('01201298-a', 0), SenseInfo('00911204-a', 0), SenseInfo('00766102-a', 0), SenseInfo('00757120-a', 0), SenseInfo('00632306-a', 0), SenseInfo('00607857-a', 0), SenseInfo('00596511-a', 10), SenseInfo('02310895-a', 6), SenseInfo('01030826-a', 5), SenseInfo('01237754-a', 2), SenseInfo('00022962-a', 1), SenseInfo('02318464-a', 0), SenseInfo('02318272-a', 0), SenseInfo('02314584-a', 0), SenseInfo('02423981-a', 0), SenseInfo('01201298-a', 0), SenseInfo('00911204-a', 0), SenseInfo('00766102-a', 0), SenseInfo('00757120-a', 0), SenseInfo('00632306-a', 0), SenseInfo('00607857-a', 0) ],
"_courtship_n_1_rel" : [ SenseInfo('07188685-n', 0) ],
"_punctuate_v_1_rel" : [ SenseInfo('00190023-v', 1), SenseInfo('01013367-v', 0), SenseInfo('00364478-v', 0) ],
"_cavity_n_1_rel" : [ SenseInfo('09393108-n', 1), SenseInfo('13911517-n', 0), SenseInfo('13444513-n', 0), SenseInfo('05303402-n', 0) ],
"_inspired_a_1_rel" : [ SenseInfo('01121507-a', 1) ],
"_embodiment_n_1_rel" : [ SenseInfo('10418302-n', 1), SenseInfo('05941210-n', 0), SenseInfo('00933000-n', 0) ],
"_inclination_n_1_rel" : [ SenseInfo('06196584-n', 2), SenseInfo('13889843-n', 1), SenseInfo('13889602-n', 1), SenseInfo('13892897-n', 0), SenseInfo('07498854-n', 0), SenseInfo('05068080-n', 0), SenseInfo('04944048-n', 0), SenseInfo('00335384-n', 0), SenseInfo('06196584-n', 2), SenseInfo('13889843-n', 1), SenseInfo('13889602-n', 1), SenseInfo('13892897-n', 0), SenseInfo('07498854-n', 0), SenseInfo('05068080-n', 0), SenseInfo('04944048-n', 0), SenseInfo('00335384-n', 0) ],
"_doable_a_1_rel" : [ SenseInfo('01821690-a', 0) ],
"_placeholder_n_1_rel" : [ SenseInfo('10486909-n', 0), SenseInfo('07271478-n', 0) ],
"_next_a_1_rel" : [ SenseInfo('00127948-a', 90), SenseInfo('00447472-a', 24), SenseInfo('01294975-a', 7), SenseInfo('00127948-a', 90), SenseInfo('00447472-a', 24), SenseInfo('01294975-a', 7), SenseInfo('00127948-a', 90), SenseInfo('00447472-a', 24), SenseInfo('01294975-a', 7) ],
"_patrician_a_1_rel" : [ SenseInfo('01948848-a', 0), SenseInfo('01590484-a', 0) ],
"_tweezers_n_1_rel" : [ SenseInfo('03941684-n', 0) ],
"_arrive_v_1_rel" : [ SenseInfo('02005948-v', 52), SenseInfo('02585860-v', 0), SenseInfo('02005948-v', 52), SenseInfo('02585860-v', 0) ],
"_frostbite_n_1_rel" : [ SenseInfo('14294678-n', 1) ],
"_classifier_n_1_rel" : [ SenseInfo('09926862-n', 1), SenseInfo('06308436-n', 0) ],
"_analog_a_1_rel" : [ SenseInfo('00110497-a', 0) ],
"_postposition_n_1_rel" : [ SenseInfo('06483702-n', 0) ],
"_all+that_x_deg_rel" : [  ],
"_slow_v_down_rel" : [ SenseInfo('00439958-v', 9), SenseInfo('00440580-v', 2), SenseInfo('00440786-v', 1), SenseInfo('00439958-v', 9), SenseInfo('00440580-v', 2), SenseInfo('00440786-v', 1) ],
"_flick_v_on_rel" : [ SenseInfo('02160177-v', 1), SenseInfo('02153023-v', 1), SenseInfo('01893465-v', 1), SenseInfo('01591158-v', 1), SenseInfo('02763609-v', 0), SenseInfo('01591357-v', 0), SenseInfo('01242208-v', 0), SenseInfo('01242071-v', 0), SenseInfo('00190586-v', 0), SenseInfo('02160177-v', 1), SenseInfo('02153023-v', 1), SenseInfo('01893465-v', 1), SenseInfo('01591158-v', 1), SenseInfo('02763609-v', 0), SenseInfo('01591357-v', 0), SenseInfo('01242208-v', 0), SenseInfo('01242071-v', 0), SenseInfo('00190586-v', 0) ],
"_remote_a_1_rel" : [ SenseInfo('00442917-a', 5), SenseInfo('01413084-a', 4), SenseInfo('00443075-a', 3), SenseInfo('00020103-a', 1), SenseInfo('00450606-a', 0), SenseInfo('00442917-a', 5), SenseInfo('01413084-a', 4), SenseInfo('00443075-a', 3), SenseInfo('00020103-a', 1), SenseInfo('00450606-a', 0), SenseInfo('00442917-a', 5), SenseInfo('01413084-a', 4), SenseInfo('00443075-a', 3), SenseInfo('00020103-a', 1), SenseInfo('00450606-a', 0), SenseInfo('00442917-a', 5), SenseInfo('01413084-a', 4), SenseInfo('00443075-a', 3), SenseInfo('00020103-a', 1), SenseInfo('00450606-a', 0) ],
"_boss_n_1_rel" : [ SenseInfo('10104209-n', 6), SenseInfo('09867956-n', 4), SenseInfo('10104064-n', 1), SenseInfo('10403162-n', 0), SenseInfo('03626115-n', 0) ],
"_microbe_n_1_rel" : [ SenseInfo('01384491-n', 0) ],
"_non+essential_a_1_rel" : [ SenseInfo('00903264-a', 0) ],
"_air_v_out_rel" : [ SenseInfo('02112891-v', 1), SenseInfo('00973728-v', 0), SenseInfo('00973056-v', 0), SenseInfo('00954608-v', 0), SenseInfo('00489029-v', 0), SenseInfo('00488770-v', 0), SenseInfo('02112891-v', 1), SenseInfo('00973728-v', 0), SenseInfo('00973056-v', 0), SenseInfo('00954608-v', 0), SenseInfo('00489029-v', 0), SenseInfo('00488770-v', 0) ],
"_tessellated_a_1_rel" : [ SenseInfo('01790938-a', 0), SenseInfo('00059326-a', 0) ],
"_still_v_1_rel" : [ SenseInfo('01764800-v', 1), SenseInfo('00461493-v', 1), SenseInfo('01815185-v', 0), SenseInfo('00583905-v', 0) ],
"_apostrophe_n_1_rel" : [ SenseInfo('07101937-n', 0), SenseInfo('06841987-n', 0) ],
"_enemy_n_1_rel" : [ SenseInfo('08190482-n', 66), SenseInfo('10055847-n', 11), SenseInfo('07946851-n', 5), SenseInfo('10098710-n', 1) ],
"_encode_v_1_rel" : [ SenseInfo('00993892-v', 0) ],
"_hormone_n_1_rel" : [ SenseInfo('05407119-n', 6) ],
"_worship_n_1_rel" : [ SenseInfo('01028655-n', 12), SenseInfo('07501420-n', 0) ],
"_exporter_n_1_rel" : [ SenseInfo('10073634-n', 1) ],
"_payout_n_1_rel" : [  ],
"_syntactics_n_1_rel" : [  ],
"_livable_a_1_rel" : [ SenseInfo('01423676-a', 1) ],
"_markka_n_2_rel" : [ SenseInfo('13688447-n', 0) ],
"_stroll_n_1_rel" : [ SenseInfo('00284101-n', 1) ],
"_municipality_n_1_rel" : [ SenseInfo('08626283-n', 0), SenseInfo('08225581-n', 0), SenseInfo('08626283-n', 0), SenseInfo('08225581-n', 0) ],
"_gravitation_n_1_rel" : [ SenseInfo('11464143-n', 0), SenseInfo('07362830-n', 0), SenseInfo('06198313-n', 0) ],
"_cattleman_n_1_rel" : [ SenseInfo('09902017-n', 2), SenseInfo('09972661-n', 0) ],
"_put_v_up-with_rel" : [ SenseInfo('01494310-v', 138), SenseInfo('01493741-v', 98), SenseInfo('00981276-v', 28), SenseInfo('01160370-v', 6), SenseInfo('02271137-v', 3), SenseInfo('00673448-v', 2), SenseInfo('02111499-v', 0), SenseInfo('01706375-v', 0), SenseInfo('00735571-v', 0) ],
"_ginger_n_1_rel" : [ SenseInfo('12355760-n', 0), SenseInfo('07815163-n', 0), SenseInfo('07814925-n', 0), SenseInfo('04634833-n', 0) ],
"_heterogeneous_a_1_rel" : [ SenseInfo('01198737-a', 4), SenseInfo('00181373-a', 0), SenseInfo('01198737-a', 4), SenseInfo('00181373-a', 0) ],
"_action_n_1_rel" : [ SenseInfo('00037396-n', 94), SenseInfo('14006945-n', 18), SenseInfo('00952963-n', 16), SenseInfo('13518963-n', 7), SenseInfo('06373513-n', 1), SenseInfo('04835950-n', 1), SenseInfo('02677718-n', 1), SenseInfo('01181902-n', 1), SenseInfo('01182312-n', 0), SenseInfo('00576451-n', 0) ],
"_grade_n_1_rel" : [ SenseInfo('08238463-n', 17), SenseInfo('14428160-n', 5), SenseInfo('05068716-n', 1), SenseInfo('13612319-n', 0), SenseInfo('07112282-n', 0), SenseInfo('05737153-n', 0), SenseInfo('05132045-n', 0), SenseInfo('05093890-n', 0), SenseInfo('02406952-n', 0) ],
"_altar_n_1_rel" : [ SenseInfo('02699629-n', 0), SenseInfo('02699494-n', 0) ],
"_analysis_n_of_rel" : [ SenseInfo('00634276-n', 45), SenseInfo('05772667-n', 5), SenseInfo('06376014-n', 2), SenseInfo('07067876-n', 0), SenseInfo('06014043-n', 0), SenseInfo('00704305-n', 0), SenseInfo('00634276-n', 45), SenseInfo('05772667-n', 5), SenseInfo('06376014-n', 2), SenseInfo('07067876-n', 0), SenseInfo('06014043-n', 0), SenseInfo('00704305-n', 0) ],
"_nots_n_1_rel" : [  ],
"_tip_v_off_rel" : [ SenseInfo('02039544-v', 5), SenseInfo('00511178-v', 1), SenseInfo('02202133-v', 0), SenseInfo('02097047-v', 0), SenseInfo('02038357-v', 0), SenseInfo('01924023-v', 0), SenseInfo('01247804-v', 0), SenseInfo('00873469-v', 0), SenseInfo('00176021-v', 0) ],
"_mite_n_1_rel" : [ SenseInfo('13774115-n', 2), SenseInfo('01779629-n', 0) ],
"_kneecap_n_1_rel" : [ SenseInfo('05278395-n', 1) ],
"_enter_v_in_rel" : [ SenseInfo('02016523-v', 85), SenseInfo('01082606-v', 24), SenseInfo('02471327-v', 17), SenseInfo('02722207-v', 8), SenseInfo('01000214-v', 7), SenseInfo('01720660-v', 2), SenseInfo('02381397-v', 0), SenseInfo('01421622-v', 0), SenseInfo('00348252-v', 0) ],
"_stretch_n_of_rel" : [ SenseInfo('09448945-n', 3), SenseInfo('00341243-n', 3), SenseInfo('04336645-n', 2), SenseInfo('00628692-n', 2), SenseInfo('00371059-n', 1), SenseInfo('15134490-n', 0), SenseInfo('05021345-n', 0), SenseInfo('09448945-n', 3), SenseInfo('00341243-n', 3), SenseInfo('04336645-n', 2), SenseInfo('00628692-n', 2), SenseInfo('00371059-n', 1), SenseInfo('15134490-n', 0), SenseInfo('05021345-n', 0) ],
"_headset_n_1_rel" : [ SenseInfo('03505667-n', 0) ],
"_check_v_in_rel" : [ SenseInfo('00661824-v', 27), SenseInfo('02533282-v', 7), SenseInfo('00662589-v', 6), SenseInfo('02510337-v', 5), SenseInfo('01861403-v', 1), SenseInfo('00662182-v', 1), SenseInfo('00440286-v', 1), SenseInfo('02658283-v', 0), SenseInfo('02657219-v', 0), SenseInfo('02557638-v', 0), SenseInfo('02553697-v', 0), SenseInfo('02347905-v', 0), SenseInfo('02347447-v', 0), SenseInfo('01861767-v', 0), SenseInfo('01861622-v', 0), SenseInfo('01692978-v', 0), SenseInfo('01139756-v', 0), SenseInfo('01131473-v', 0), SenseInfo('01114764-v', 0), SenseInfo('01064999-v', 0), SenseInfo('00920336-v', 0), SenseInfo('00663353-v', 0), SenseInfo('00354634-v', 0), SenseInfo('00336539-v', 0), SenseInfo('00336260-v', 0), SenseInfo('00661824-v', 27), SenseInfo('02533282-v', 7), SenseInfo('00662589-v', 6), SenseInfo('02510337-v', 5), SenseInfo('01861403-v', 1), SenseInfo('00662182-v', 1), SenseInfo('00440286-v', 1), SenseInfo('02658283-v', 0), SenseInfo('02657219-v', 0), SenseInfo('02557638-v', 0), SenseInfo('02553697-v', 0), SenseInfo('02347905-v', 0), SenseInfo('02347447-v', 0), SenseInfo('01861767-v', 0), SenseInfo('01861622-v', 0), SenseInfo('01692978-v', 0), SenseInfo('01139756-v', 0), SenseInfo('01131473-v', 0), SenseInfo('01114764-v', 0), SenseInfo('01064999-v', 0), SenseInfo('00920336-v', 0), SenseInfo('00663353-v', 0), SenseInfo('00354634-v', 0), SenseInfo('00336539-v', 0), SenseInfo('00336260-v', 0) ],
"_sixpenny_n_1_rel" : [ SenseInfo('00935359-a', 0) ],
"_editorial_a_1_rel" : [ SenseInfo('02717258-a', 1), SenseInfo('02717402-a', 0) ],
"_unlock_v_1_rel" : [ SenseInfo('01348705-v', 4), SenseInfo('01511289-v', 1), SenseInfo('00219963-v', 1), SenseInfo('01348705-v', 4), SenseInfo('01511289-v', 1), SenseInfo('00219963-v', 1) ],
"_symbolic_a_1_rel" : [ SenseInfo('02806907-a', 2), SenseInfo('01982186-a', 2), SenseInfo('02807163-a', 1), SenseInfo('02806907-a', 2), SenseInfo('01982186-a', 2), SenseInfo('02807163-a', 1) ],
"_assert_v_to_rel" : [ SenseInfo('01016778-v', 22), SenseInfo('01011031-v', 6), SenseInfo('02373785-v', 2), SenseInfo('00717045-v', 1), SenseInfo('01016778-v', 22), SenseInfo('01011031-v', 6), SenseInfo('02373785-v', 2), SenseInfo('00717045-v', 1) ],
"_toss_v_off_rel" : [ SenseInfo('01512625-v', 13), SenseInfo('01893079-v', 10), SenseInfo('01514525-v', 5), SenseInfo('01890792-v', 4), SenseInfo('02222318-v', 1), SenseInfo('01418536-v', 1) ],
"_reddish_a_1_rel" : [ SenseInfo('00381097-a', 0) ],
"_terror_n_1_rel" : [ SenseInfo('07520612-n', 11), SenseInfo('10702615-n', 1), SenseInfo('10702483-n', 0), SenseInfo('00759500-n', 0) ],
"_pardon_n_1_rel" : [ SenseInfo('01227190-n', 1), SenseInfo('06552639-n', 0), SenseInfo('01249315-n', 0) ],
"_surf_n_1_rel" : [ SenseInfo('07344233-n', 1) ],
"_rambler_n_1_rel" : [ SenseInfo('10506220-n', 0), SenseInfo('10506094-n', 0) ],
"_dun_n_1_rel" : [ SenseInfo('02381261-n', 1), SenseInfo('04973110-n', 0) ],
"_inarticulate_a_1_rel" : [ SenseInfo('00151105-a', 0) ],
"_reason_v_1_rel" : [ SenseInfo('00634472-v', 3), SenseInfo('00772189-v', 2), SenseInfo('00632627-v', 1), SenseInfo('00634472-v', 3), SenseInfo('00772189-v', 2), SenseInfo('00632627-v', 1) ],
"_age-old_a_1_rel" : [ SenseInfo('01638962-a', 1), SenseInfo('01638962-a', 1) ],
"_tennis_n_1_rel" : [ SenseInfo('00482298-n', 1) ],
"_check_n_of_rel" : [ SenseInfo('13381734-n', 18), SenseInfo('05738625-n', 4), SenseInfo('06517942-n', 2), SenseInfo('14010927-n', 1), SenseInfo('05825245-n', 1), SenseInfo('00141806-n', 1), SenseInfo('06818747-n', 0), SenseInfo('05689249-n', 0), SenseInfo('04692908-n', 0), SenseInfo('03011162-n', 0), SenseInfo('01146039-n', 0), SenseInfo('00562935-n', 0), SenseInfo('00167446-n', 0), SenseInfo('13381734-n', 18), SenseInfo('05738625-n', 4), SenseInfo('06517942-n', 2), SenseInfo('14010927-n', 1), SenseInfo('05825245-n', 1), SenseInfo('00141806-n', 1), SenseInfo('06818747-n', 0), SenseInfo('05689249-n', 0), SenseInfo('04692908-n', 0), SenseInfo('03011162-n', 0), SenseInfo('01146039-n', 0), SenseInfo('00562935-n', 0), SenseInfo('00167446-n', 0) ],
"_skiff_n_1_rel" : [ SenseInfo('04229480-n', 7) ],
"_self-evident_a_1_rel" : [ SenseInfo('01618895-a', 2) ],
"_unmask_v_1_rel" : [ SenseInfo('00935631-v', 1), SenseInfo('01358573-v', 0), SenseInfo('00935631-v', 1), SenseInfo('01358573-v', 0) ],
"_snorkel_v_1_rel" : [ SenseInfo('01963795-v', 0) ],
"_incline_v_1_rel" : [ SenseInfo('02719399-v', 6), SenseInfo('02171322-v', 0), SenseInfo('02063018-v', 0), SenseInfo('02037090-v', 0), SenseInfo('01772172-v', 0), SenseInfo('00680841-v', 0) ],
"_conductivity_n_1_rel" : [ SenseInfo('11512818-n', 2) ],
"_subtitle_v_1_rel" : [ SenseInfo('02332311-v', 1) ],
"_tension_n_1_rel" : [ SenseInfo('14376188-n', 9), SenseInfo('14544335-n', 4), SenseInfo('14002481-n', 3), SenseInfo('11515051-n', 3), SenseInfo('13980596-n', 0), SenseInfo('00366675-n', 0) ],
"_haitian_n_1_rel" : [ SenseInfo('09712448-n', 0) ],
"_pencil_v_in_rel" : [ SenseInfo('01688604-v', 0) ],
"_invasion_n_of_rel" : [ SenseInfo('00976531-n', 3), SenseInfo('07429976-n', 1), SenseInfo('07332313-n', 0) ],
"_adviser_n_1_rel" : [ SenseInfo('09774266-n', 0) ],
"_as_x_subord_rel" : [ SenseInfo('13658027-n', 6), SenseInfo('15089803-n', 0), SenseInfo('14829565-n', 0), SenseInfo('14706889-n', 0), SenseInfo('13637376-n', 0), SenseInfo('06831177-n', 0), SenseInfo('05400860-n', 0), SenseInfo('13658027-n', 6), SenseInfo('15089803-n', 0), SenseInfo('14829565-n', 0), SenseInfo('14706889-n', 0), SenseInfo('13637376-n', 0), SenseInfo('06831177-n', 0), SenseInfo('05400860-n', 0), SenseInfo('13658027-n', 6), SenseInfo('15089803-n', 0), SenseInfo('14829565-n', 0), SenseInfo('14706889-n', 0), SenseInfo('13637376-n', 0), SenseInfo('06831177-n', 0), SenseInfo('05400860-n', 0), SenseInfo('13658027-n', 6), SenseInfo('15089803-n', 0), SenseInfo('14829565-n', 0), SenseInfo('14706889-n', 0), SenseInfo('13637376-n', 0), SenseInfo('06831177-n', 0), SenseInfo('05400860-n', 0) ],
"_lord_a_1_rel" : [ SenseInfo('09536363-n', 10), SenseInfo('10388440-n', 3), SenseInfo('10271677-n', 1), SenseInfo('09536363-n', 10), SenseInfo('10388440-n', 3), SenseInfo('10271677-n', 1) ],
"_arborescent_a_1_rel" : [ SenseInfo('00613382-a', 0) ],
"_rust_v_cause_rel" : [ SenseInfo('00273963-v', 2), SenseInfo('00274283-v', 0), SenseInfo('00239614-v', 0) ],
"_pee_v_1_rel" : [ SenseInfo('00072012-v', 0) ],
"_constituent_n_1_rel" : [ SenseInfo('03081021-n', 7), SenseInfo('09611884-n', 2), SenseInfo('13809207-n', 0), SenseInfo('06312966-n', 0), SenseInfo('05868954-n', 0) ],
"_heaping_a_1_rel" : [  ],
"_essential_n_1_rel" : [ SenseInfo('09367203-n', 1) ],
"_sideways_a_1_rel" : [ SenseInfo('01719779-a', 0) ],
"_moral_a_1_rel" : [ SenseInfo('01548193-a', 8), SenseInfo('01780596-a', 0), SenseInfo('01548193-a', 8), SenseInfo('01780596-a', 0) ],
"_alpha_n_1_rel" : [ SenseInfo('06834138-n', 1), SenseInfo('07329169-n', 0) ],
"_swear_v_to_rel" : [ SenseInfo('00865387-v', 20), SenseInfo('01011031-v', 8), SenseInfo('00889947-v', 2), SenseInfo('01013040-v', 1), SenseInfo('00688377-v', 0), SenseInfo('00865387-v', 20), SenseInfo('01011031-v', 8), SenseInfo('00889947-v', 2), SenseInfo('01013040-v', 1), SenseInfo('00688377-v', 0) ],
"_boast_n_1_rel" : [ SenseInfo('07229530-n', 1), SenseInfo('07229530-n', 1) ],
"_elf_n_1_rel" : [ SenseInfo('09540739-n', 0), SenseInfo('05057163-n', 0) ],
"_fire_v_at_rel" : [ SenseInfo('01135783-v', 30), SenseInfo('01133825-v', 16), SenseInfo('00320536-v', 10), SenseInfo('02402825-v', 7), SenseInfo('01134238-v', 5), SenseInfo('02002410-v', 1), SenseInfo('01759326-v', 1), SenseInfo('00378664-v', 1), SenseInfo('02356420-v', 0) ],
"_intolerable_a_1_rel" : [ SenseInfo('02435671-a', 3), SenseInfo('02435671-a', 3), SenseInfo('02435671-a', 3) ],
"_incorporate_v_1_rel" : [ SenseInfo('00466651-v', 6), SenseInfo('02629535-v', 1), SenseInfo('02448079-v', 0), SenseInfo('01541000-v', 0), SenseInfo('00466651-v', 6), SenseInfo('02629535-v', 1), SenseInfo('02448079-v', 0), SenseInfo('01541000-v', 0) ],
"_cotton_n_1_rel" : [ SenseInfo('14870078-n', 6), SenseInfo('03115180-n', 2), SenseInfo('12175949-n', 0), SenseInfo('03115301-n', 0) ],
"_heighten_v_1_rel" : [ SenseInfo('00432436-v', 1), SenseInfo('00432281-v', 1), SenseInfo('00229605-v', 1), SenseInfo('01975753-v', 0), SenseInfo('00392588-v', 0), SenseInfo('00227165-v', 0) ],
"_marque_n_1_rel" : [ SenseInfo('06845599-n', 0) ],
"_pony_v_up_rel" : [  ],
"_coil_v_cause_rel" : [ SenseInfo('02049190-v', 2), SenseInfo('01663580-v', 0), SenseInfo('01523986-v', 0) ],
"_holophone_n_1_rel" : [  ],
"_deductive_a_1_rel" : [ SenseInfo('02710294-a', 1), SenseInfo('01296474-a', 0) ],
"_unexciting_a_1_rel" : [ SenseInfo('02307367-a', 0), SenseInfo('00922594-a', 0), SenseInfo('02307367-a', 0), SenseInfo('00922594-a', 0) ],
"_unfilled_a_1_rel" : [ SenseInfo('03149843-a', 0), SenseInfo('03149843-a', 0) ],
"_popsicle_n_1_rel" : [ SenseInfo('07615774-n', 0) ],
"_self-protect_v_1_rel" : [  ],
"_northerner_n_1_rel" : [ SenseInfo('10362682-n', 3), SenseInfo('10802283-n', 1) ],
"_underground_a_2_rel" : [ SenseInfo('02471984-a', 7), SenseInfo('01706465-a', 0) ],
"_twirl_v_1_rel" : [ SenseInfo('02048891-v', 2), SenseInfo('02048051-v', 1) ],
"_discourtesy_n_1_rel" : [ SenseInfo('06714976-n', 0), SenseInfo('04914292-n', 0), SenseInfo('01224031-n', 0) ],
"_bolivian_a_1_rel" : [ SenseInfo('02967485-a', 0) ],
"_thread_n_of_rel" : [ SenseInfo('04426788-n', 4), SenseInfo('09409203-n', 0), SenseInfo('05773548-n', 0), SenseInfo('04154938-n', 0) ],
"_deprivation_n_1_rel" : [ SenseInfo('14493426-n', 0), SenseInfo('05162985-n', 0), SenseInfo('01150200-n', 0) ],
"_no+more+than_x_deg_rel" : [  ],
"_despise_v_as_rel" : [ SenseInfo('01774799-v', 8), SenseInfo('01774799-v', 8) ],
"_uruguayan_n_1_rel" : [ SenseInfo('09746936-n', 0) ],
"_detector_n_of_rel" : [ SenseInfo('03180969-n', 4), SenseInfo('03181501-n', 0), SenseInfo('03181293-n', 0) ],
"_bequest_n_1_rel" : [ SenseInfo('13263779-n', 4) ],
"_transit_n_1_rel" : [ SenseInfo('04419073-n', 2), SenseInfo('04473432-n', 0), SenseInfo('00309115-n', 0) ],
"_cohesive_a_1_rel" : [ SenseInfo('00053564-a', 3), SenseInfo('02477047-a', 0) ],
"_set_n_of_rel" : [ SenseInfo('07996689-n', 23), SenseInfo('07999699-n', 14), SenseInfo('00625699-n', 6), SenseInfo('04297476-n', 3), SenseInfo('08240169-n', 2), SenseInfo('06199702-n', 1), SenseInfo('01052853-n', 1), SenseInfo('15256417-n', 0), SenseInfo('13491060-n', 0), SenseInfo('09513569-n', 0), SenseInfo('07363545-n', 0), SenseInfo('05674584-n', 0), SenseInfo('04176528-n', 0), SenseInfo('07996689-n', 23), SenseInfo('07999699-n', 14), SenseInfo('00625699-n', 6), SenseInfo('04297476-n', 3), SenseInfo('08240169-n', 2), SenseInfo('06199702-n', 1), SenseInfo('01052853-n', 1), SenseInfo('15256417-n', 0), SenseInfo('13491060-n', 0), SenseInfo('09513569-n', 0), SenseInfo('07363545-n', 0), SenseInfo('05674584-n', 0), SenseInfo('04176528-n', 0) ],
"_elucidation_n_of_rel" : [ SenseInfo('07232655-n', 0), SenseInfo('07171206-n', 0), SenseInfo('07232655-n', 0), SenseInfo('07171206-n', 0) ],
"_seasonal_a_1_rel" : [ SenseInfo('01494273-a', 2) ],
"_debatable_a_1_rel" : [ SenseInfo('01916784-a', 0), SenseInfo('00602117-a', 0), SenseInfo('00590669-a', 0) ],
"_rose_n_1_rel" : [ SenseInfo('12620196-n', 5), SenseInfo('07893253-n', 0), SenseInfo('04971313-n', 0) ],
"_whereabouts_n_of_rel" : [ SenseInfo('08683383-n', 3) ],
"_transcript_n_of_rel" : [ SenseInfo('07277384-n', 0), SenseInfo('06505517-n', 0) ],
"_river_n_of_rel" : [ SenseInfo('09411430-n', 55), SenseInfo('09411430-n', 55) ],
"_defence_n_1_rel" : [ SenseInfo('13459322-n', 0), SenseInfo('08081403-n', 0), SenseInfo('08064523-n', 0), SenseInfo('08064130-n', 0), SenseInfo('07200813-n', 0), SenseInfo('06740644-n', 0), SenseInfo('03171356-n', 0), SenseInfo('01198750-n', 0), SenseInfo('00954311-n', 0), SenseInfo('00823750-n', 0), SenseInfo('00823532-n', 0) ],
"_brandish_v_1_rel" : [ SenseInfo('01446901-v', 2), SenseInfo('02142520-v', 1) ],
"_try_v_out_rel" : [ SenseInfo('02530167-v', 342), SenseInfo('02531625-v', 16), SenseInfo('02501278-v', 4), SenseInfo('01195299-v', 2), SenseInfo('02500902-v', 0), SenseInfo('01798782-v', 0), SenseInfo('01798452-v', 0), SenseInfo('00444975-v', 0), SenseInfo('00047317-v', 0) ],
"_hydrogen_n_1_rel" : [ SenseInfo('14640434-n', 6) ],
"_transient_a_1_rel" : [ SenseInfo('01274125-a', 0), SenseInfo('01756292-a', 0) ],
"_beam_v_out_rel" : [ SenseInfo('00029214-v', 5), SenseInfo('02763740-v', 1), SenseInfo('01067380-v', 1), SenseInfo('00973056-v', 1), SenseInfo('02161530-v', 0), SenseInfo('01829747-v', 0) ],
"_hoist_v_up_rel" : [ SenseInfo('01455184-v', 1), SenseInfo('01611359-v', 0), SenseInfo('01455754-v', 0) ],
"_skunk_n_1_rel" : [ SenseInfo('10539715-n', 1), SenseInfo('07476495-n', 0), SenseInfo('03990834-n', 0), SenseInfo('02445715-n', 0) ],
"_willie_n_1_rel" : [  ],
"_after+all_a_1_rel" : [  ],
"_kluge_v_1_rel" : [  ],
"_jump_v_1_rel" : [ SenseInfo('01963942-v', 19), SenseInfo('01910373-v', 6), SenseInfo('01121178-v', 4), SenseInfo('00155727-v', 2), SenseInfo('02674564-v', 1), SenseInfo('01082937-v', 1), SenseInfo('00155547-v', 1), SenseInfo('02105082-v', 0), SenseInfo('02011865-v', 0), SenseInfo('01968275-v', 0), SenseInfo('01965156-v', 0), SenseInfo('01859050-v', 0), SenseInfo('00616498-v', 0), SenseInfo('00560391-v', 0), SenseInfo('00121506-v', 0), SenseInfo('01963942-v', 19), SenseInfo('01910373-v', 6), SenseInfo('01121178-v', 4), SenseInfo('00155727-v', 2), SenseInfo('02674564-v', 1), SenseInfo('01082937-v', 1), SenseInfo('00155547-v', 1), SenseInfo('02105082-v', 0), SenseInfo('02011865-v', 0), SenseInfo('01968275-v', 0), SenseInfo('01965156-v', 0), SenseInfo('01859050-v', 0), SenseInfo('00616498-v', 0), SenseInfo('00560391-v', 0), SenseInfo('00121506-v', 0) ],
"_impressed_a_with_rel" : [ SenseInfo('00071142-a', 0) ],
"_prejudice_n_1_rel" : [ SenseInfo('06201908-n', 3), SenseInfo('06201908-n', 3) ],
"_southwesterly_a_1_rel" : [ SenseInfo('01604000-a', 0), SenseInfo('01603869-a', 0), SenseInfo('01604000-a', 0), SenseInfo('01603869-a', 0) ],
"_dish_v_out_rel" : [ SenseInfo('01180351-v', 0), SenseInfo('00263471-v', 0) ],
"_replenish_v_1_rel" : [ SenseInfo('00453803-v', 6) ],
"_lantern_n_1_rel" : [ SenseInfo('03640988-n', 4) ],
"_logical_a_for_rel" : [ SenseInfo('01430111-a', 6), SenseInfo('02499301-a', 5), SenseInfo('00464513-a', 0), SenseInfo('01925708-a', 0), SenseInfo('01430111-a', 6), SenseInfo('02499301-a', 5), SenseInfo('00464513-a', 0), SenseInfo('01925708-a', 0), SenseInfo('01430111-a', 6), SenseInfo('02499301-a', 5), SenseInfo('00464513-a', 0), SenseInfo('01925708-a', 0) ],
"_quarry_n_1_rel" : [ SenseInfo('10470460-n', 0), SenseInfo('03949442-n', 0), SenseInfo('02152881-n', 0) ],
"_head_v_up_rel" : [ SenseInfo('01935233-v', 29), SenseInfo('02440244-v', 19), SenseInfo('01999423-v', 3), SenseInfo('02729023-v', 2), SenseInfo('01931768-v', 2), SenseInfo('02754463-v', 0), SenseInfo('02694287-v', 0), SenseInfo('02624128-v', 0), SenseInfo('01590915-v', 0) ],
"_mountain-climb_v_1_rel" : [  ],
"_hot-dipped_a_1_rel" : [  ],
"_wait+and+see_a_1_rel" : [  ],
"_derelict_a_1_rel" : [ SenseInfo('02581530-a', 0), SenseInfo('01313004-a', 0), SenseInfo('00755220-a', 0), SenseInfo('00679717-a', 0) ],
"_knickerbocker_n_1_rel" : [  ],
"_thither_p_rel" : [ SenseInfo('00109328-r', 6) ],
"_triple_n_1_rel" : [ SenseInfo('00132982-n', 3), SenseInfo('07986198-n', 0), SenseInfo('05860377-n', 0) ],
"_spur_v_1_rel" : [ SenseInfo('02554647-v', 2), SenseInfo('01818835-v', 2), SenseInfo('01241490-v', 1), SenseInfo('01241253-v', 1), SenseInfo('01241379-v', 0), SenseInfo('02554647-v', 2), SenseInfo('01818835-v', 2), SenseInfo('01241490-v', 1), SenseInfo('01241253-v', 1), SenseInfo('01241379-v', 0) ],
"_architectural_a_1_rel" : [ SenseInfo('02897957-a', 4), SenseInfo('02897957-a', 4) ],
"_hoary_a_1_rel" : [ SenseInfo('01645678-a', 0), SenseInfo('01639891-a', 0), SenseInfo('00212949-a', 0), SenseInfo('01645678-a', 0), SenseInfo('01639891-a', 0), SenseInfo('00212949-a', 0), SenseInfo('01645678-a', 0), SenseInfo('01639891-a', 0), SenseInfo('00212949-a', 0) ],
"_bang_a_1_rel" : [ SenseInfo('07410207-n', 2), SenseInfo('07376257-n', 2), SenseInfo('05258985-n', 1), SenseInfo('07528470-n', 0), SenseInfo('00064504-n', 0) ],
"_boredom_n_1_rel" : [ SenseInfo('07539790-n', 7) ],
"_stake_v_1_rel" : [ SenseInfo('02545272-v', 2), SenseInfo('01139104-v', 2), SenseInfo('01591476-v', 1), SenseInfo('01591940-v', 0), SenseInfo('01572003-v', 0) ],
"_close_v_down_rel" : [ SenseInfo('01345109-v', 32), SenseInfo('01346978-v', 20), SenseInfo('02426395-v', 18), SenseInfo('02425913-v', 13), SenseInfo('02610628-v', 2), SenseInfo('00763831-v', 1), SenseInfo('02754276-v', 0), SenseInfo('02375619-v', 0), SenseInfo('02140781-v', 0), SenseInfo('02104503-v', 0), SenseInfo('02054541-v', 0), SenseInfo('02054382-v', 0), SenseInfo('01607288-v', 0), SenseInfo('01478423-v', 0), SenseInfo('01423285-v', 0), SenseInfo('01291941-v', 0), SenseInfo('00352137-v', 0), SenseInfo('01345109-v', 32), SenseInfo('01346978-v', 20), SenseInfo('02426395-v', 18), SenseInfo('02425913-v', 13), SenseInfo('02610628-v', 2), SenseInfo('00763831-v', 1), SenseInfo('02754276-v', 0), SenseInfo('02375619-v', 0), SenseInfo('02140781-v', 0), SenseInfo('02104503-v', 0), SenseInfo('02054541-v', 0), SenseInfo('02054382-v', 0), SenseInfo('01607288-v', 0), SenseInfo('01478423-v', 0), SenseInfo('01423285-v', 0), SenseInfo('01291941-v', 0), SenseInfo('00352137-v', 0) ],
"_point_v_1_rel" : [ SenseInfo('00923793-v', 25), SenseInfo('02713184-v', 8), SenseInfo('01152214-v', 8), SenseInfo('01931768-v', 5), SenseInfo('00921300-v', 1), SenseInfo('01928154-v', 0), SenseInfo('01589363-v', 0), SenseInfo('01589224-v', 0), SenseInfo('01589056-v', 0), SenseInfo('01152670-v', 0), SenseInfo('01150559-v', 0), SenseInfo('00924255-v', 0), SenseInfo('00392960-v', 0), SenseInfo('00261957-v', 0), SenseInfo('00923793-v', 25), SenseInfo('02713184-v', 8), SenseInfo('01152214-v', 8), SenseInfo('01931768-v', 5), SenseInfo('00921300-v', 1), SenseInfo('01928154-v', 0), SenseInfo('01589363-v', 0), SenseInfo('01589224-v', 0), SenseInfo('01589056-v', 0), SenseInfo('01152670-v', 0), SenseInfo('01150559-v', 0), SenseInfo('00924255-v', 0), SenseInfo('00392960-v', 0), SenseInfo('00261957-v', 0) ],
"_space_v_1_rel" : [ SenseInfo('01988080-v', 3) ],
"_rack_v_i_rel" : [ SenseInfo('01960491-v', 2), SenseInfo('01798678-v', 1), SenseInfo('02408722-v', 0), SenseInfo('02241107-v', 0), SenseInfo('01946138-v', 0), SenseInfo('01940782-v', 0), SenseInfo('01855058-v', 0), SenseInfo('01802689-v', 0), SenseInfo('01669419-v', 0), SenseInfo('01213348-v', 0), SenseInfo('00071547-v', 0) ],
"_appoint_v_1_rel" : [ SenseInfo('02396205-v', 13), SenseInfo('02475922-v', 8), SenseInfo('02341370-v', 0), SenseInfo('02396205-v', 13), SenseInfo('02475922-v', 8), SenseInfo('02341370-v', 0), SenseInfo('02396205-v', 13), SenseInfo('02475922-v', 8), SenseInfo('02341370-v', 0) ],
"_pallor_n_1_rel" : [ SenseInfo('04977561-n', 2) ],
"_stain_n_1_rel" : [ SenseInfo('04695176-n', 5), SenseInfo('15052970-n', 2), SenseInfo('14498096-n', 1), SenseInfo('06794666-n', 0), SenseInfo('00072261-n', 0) ],
"_duck_v_1_rel" : [ SenseInfo('01865203-v', 10), SenseInfo('01967792-v', 3), SenseInfo('01976220-v', 0), SenseInfo('00809654-v', 0) ],
"_delicateness_n_1_rel" : [  ],
"_police_n_1_rel" : [ SenseInfo('08209687-n', 34) ],
"_crush_v_1_rel" : [ SenseInfo('02424652-v', 4), SenseInfo('01593937-v', 3), SenseInfo('01101913-v', 3), SenseInfo('00339085-v', 2), SenseInfo('01800195-v', 0), SenseInfo('01492944-v', 0), SenseInfo('01103836-v', 0), SenseInfo('00559390-v', 0) ],
"_dirt_n_1_rel" : [ SenseInfo('14844693-n', 14), SenseInfo('14498096-n', 11), SenseInfo('14854581-n', 0), SenseInfo('07223811-n', 0) ],
"_restricted_a_1_rel" : [ SenseInfo('02002227-a', 2), SenseInfo('01540871-a', 1), SenseInfo('00415931-a', 0) ],
"_mp_n_1_rel" : [ SenseInfo('10317500-n', 0), SenseInfo('08211290-n', 0) ],
"_stew_n_1_rel" : [ SenseInfo('14403560-n', 0), SenseInfo('07588947-n', 0) ],
"_derivative_n_1_rel" : [ SenseInfo('06014730-n', 1), SenseInfo('14833885-n', 0), SenseInfo('06480506-n', 0), SenseInfo('06290051-n', 0), SenseInfo('06014730-n', 1), SenseInfo('14833885-n', 0), SenseInfo('06480506-n', 0), SenseInfo('06290051-n', 0) ],
"_doughy_a_1_rel" : [ SenseInfo('01185417-a', 0) ],
"_full+up_a_1_rel" : [  ],
"_rejoice_v_1_rel" : [ SenseInfo('01813884-v', 4), SenseInfo('00857923-v', 2), SenseInfo('01823370-v', 1), SenseInfo('01813884-v', 4), SenseInfo('00857923-v', 2), SenseInfo('01823370-v', 1) ],
"_inadmissible_a_1_rel" : [ SenseInfo('01762582-a', 0) ],
"_marsupial_a_1_rel" : [ SenseInfo('02995373-a', 0) ],
"_rumor_v_1_rel" : [ SenseInfo('01042228-v', 1), SenseInfo('01042228-v', 1), SenseInfo('01042228-v', 1) ],
"_agent_n_of_rel" : [ SenseInfo('09190918-n', 21), SenseInfo('09777353-n', 6), SenseInfo('14778436-n', 5), SenseInfo('09777012-n', 1), SenseInfo('10373801-n', 0), SenseInfo('06332364-n', 0) ],
"_paragraph_n_1_rel" : [ SenseInfo('06399995-n', 5), SenseInfo('06399995-n', 5) ],
"_thorough_a_1_rel" : [ SenseInfo('00311505-a', 4), SenseInfo('00522463-a', 3), SenseInfo('00311505-a', 4), SenseInfo('00522463-a', 3) ],
"_rottweiler_n_1_rel" : [ SenseInfo('02106550-n', 0) ],
"_saltpeter_n_1_rel" : [ SenseInfo('14861355-n', 0) ],
"_grammatical_a_1_rel" : [ SenseInfo('02880322-a', 4), SenseInfo('01146012-a', 0) ],
"_upwards_a_2_rel" : [  ],
"_goodies_n_1_rel" : [ SenseInfo('07557165-n', 0), SenseInfo('07557165-n', 0) ],
"_fear_v_1_rel" : [ SenseInfo('01780729-v', 23), SenseInfo('01780202-v', 20), SenseInfo('01780568-v', 1), SenseInfo('01780434-v', 0), SenseInfo('01778568-v', 0), SenseInfo('01780729-v', 23), SenseInfo('01780202-v', 20), SenseInfo('01780568-v', 1), SenseInfo('01780434-v', 0), SenseInfo('01778568-v', 0), SenseInfo('01780729-v', 23), SenseInfo('01780202-v', 20), SenseInfo('01780568-v', 1), SenseInfo('01780434-v', 0), SenseInfo('01778568-v', 0), SenseInfo('01780729-v', 23), SenseInfo('01780202-v', 20), SenseInfo('01780568-v', 1), SenseInfo('01780434-v', 0), SenseInfo('01778568-v', 0), SenseInfo('01780729-v', 23), SenseInfo('01780202-v', 20), SenseInfo('01780568-v', 1), SenseInfo('01780434-v', 0), SenseInfo('01778568-v', 0) ],
"_array_v_1_rel" : [ SenseInfo('01474209-v', 1), SenseInfo('00733632-v', 0) ],
"_ask_v_about_rel" : [ SenseInfo('00784342-v', 244), SenseInfo('00752493-v', 165), SenseInfo('00784727-v', 16), SenseInfo('00755745-v', 2), SenseInfo('00897746-v', 1), SenseInfo('02627934-v', 0), SenseInfo('01068565-v', 0) ],
"_tent_v_1_rel" : [ SenseInfo('02653996-v', 0) ],
"_/_a_1_rel" : [  ],
"_strive_v_1_rel" : [ SenseInfo('02531199-v', 13), SenseInfo('01146051-v', 6), SenseInfo('02531199-v', 13), SenseInfo('01146051-v', 6) ],
"_superiority_n_1_rel" : [ SenseInfo('04728376-n', 3), SenseInfo('05158619-n', 1), SenseInfo('04889000-n', 1), SenseInfo('13950440-n', 0) ],
"_dissimilar_a_1_rel" : [ SenseInfo('02073113-a', 1), SenseInfo('01410905-a', 0), SenseInfo('01410363-a', 0) ],
"_bob_v_cause_rel" : [ SenseInfo('01865383-v', 6), SenseInfo('01939811-v', 0), SenseInfo('01556178-v', 0), SenseInfo('00899352-v', 0), SenseInfo('00039121-v', 0) ],
"_ancillary_a_1_rel" : [ SenseInfo('02354897-a', 0) ],
"_come_v_back_rel" : [ SenseInfo('01849221-v', 276), SenseInfo('02005948-v', 235), SenseInfo('00341917-v', 147), SenseInfo('00542120-v', 41), SenseInfo('02625339-v', 40), SenseInfo('00342812-v', 11), SenseInfo('02743921-v', 9), SenseInfo('02743214-v', 7), SenseInfo('02686805-v', 6), SenseInfo('02743565-v', 3), SenseInfo('01839690-v', 3), SenseInfo('02729963-v', 2), SenseInfo('00344886-v', 2), SenseInfo('02645007-v', 1), SenseInfo('02627363-v', 1), SenseInfo('02006709-v', 1), SenseInfo('00723349-v', 1), SenseInfo('02737187-v', 0), SenseInfo('02617567-v', 0), SenseInfo('02197360-v', 0), SenseInfo('00659984-v', 0), SenseInfo('01849221-v', 276), SenseInfo('02005948-v', 235), SenseInfo('00341917-v', 147), SenseInfo('00542120-v', 41), SenseInfo('02625339-v', 40), SenseInfo('00342812-v', 11), SenseInfo('02743921-v', 9), SenseInfo('02743214-v', 7), SenseInfo('02686805-v', 6), SenseInfo('02743565-v', 3), SenseInfo('01839690-v', 3), SenseInfo('02729963-v', 2), SenseInfo('00344886-v', 2), SenseInfo('02645007-v', 1), SenseInfo('02627363-v', 1), SenseInfo('02006709-v', 1), SenseInfo('00723349-v', 1), SenseInfo('02737187-v', 0), SenseInfo('02617567-v', 0), SenseInfo('02197360-v', 0), SenseInfo('00659984-v', 0) ],
"_capitalist_n_1_rel" : [ SenseInfo('09892262-n', 1), SenseInfo('09609232-n', 0) ],
"_run_v_for_rel" : [ SenseInfo('01926311-v', 106), SenseInfo('02075049-v', 38), SenseInfo('02685951-v', 21), SenseInfo('02443849-v', 20), SenseInfo('02721284-v', 10), SenseInfo('02066939-v', 9), SenseInfo('01525666-v', 8), SenseInfo('02727039-v', 7), SenseInfo('01094086-v', 7), SenseInfo('01717169-v', 5), SenseInfo('02099829-v', 4), SenseInfo('02719399-v', 3), SenseInfo('01526290-v', 3), SenseInfo('00549063-v', 3), SenseInfo('00517529-v', 3), SenseInfo('02720904-v', 2), SenseInfo('02647497-v', 2), SenseInfo('02612234-v', 2), SenseInfo('02563327-v', 2), SenseInfo('01746359-v', 2), SenseInfo('01641545-v', 2), SenseInfo('01212230-v', 2), SenseInfo('02686625-v', 1), SenseInfo('02525312-v', 1), SenseInfo('02242256-v', 1), SenseInfo('02092309-v', 1), SenseInfo('02060792-v', 1), SenseInfo('01927903-v', 1), SenseInfo('01914947-v', 1), SenseInfo('02648110-v', 0), SenseInfo('02421921-v', 0), SenseInfo('01927747-v', 0), SenseInfo('01927447-v', 0), SenseInfo('01926984-v', 0), SenseInfo('01864038-v', 0), SenseInfo('01143838-v', 0), SenseInfo('01086103-v', 0), SenseInfo('00539110-v', 0), SenseInfo('00444629-v', 0), SenseInfo('00334803-v', 0), SenseInfo('00332672-v', 0), SenseInfo('01926311-v', 106), SenseInfo('02075049-v', 38), SenseInfo('02685951-v', 21), SenseInfo('02443849-v', 20), SenseInfo('02721284-v', 10), SenseInfo('02066939-v', 9), SenseInfo('01525666-v', 8), SenseInfo('02727039-v', 7), SenseInfo('01094086-v', 7), SenseInfo('01717169-v', 5), SenseInfo('02099829-v', 4), SenseInfo('02719399-v', 3), SenseInfo('01526290-v', 3), SenseInfo('00549063-v', 3), SenseInfo('00517529-v', 3), SenseInfo('02720904-v', 2), SenseInfo('02647497-v', 2), SenseInfo('02612234-v', 2), SenseInfo('02563327-v', 2), SenseInfo('01746359-v', 2), SenseInfo('01641545-v', 2), SenseInfo('01212230-v', 2), SenseInfo('02686625-v', 1), SenseInfo('02525312-v', 1), SenseInfo('02242256-v', 1), SenseInfo('02092309-v', 1), SenseInfo('02060792-v', 1), SenseInfo('01927903-v', 1), SenseInfo('01914947-v', 1), SenseInfo('02648110-v', 0), SenseInfo('02421921-v', 0), SenseInfo('01927747-v', 0), SenseInfo('01927447-v', 0), SenseInfo('01926984-v', 0), SenseInfo('01864038-v', 0), SenseInfo('01143838-v', 0), SenseInfo('01086103-v', 0), SenseInfo('00539110-v', 0), SenseInfo('00444629-v', 0), SenseInfo('00334803-v', 0), SenseInfo('00332672-v', 0) ],
"_hash_v_1_rel" : [ SenseInfo('01257399-v', 0) ],
"_gerfalcon_n_1_rel" : [ SenseInfo('01611800-n', 0) ],
"_whisk_v_away_rel" : [ SenseInfo('02079679-v', 1), SenseInfo('02079818-v', 0), SenseInfo('01435254-v', 0), SenseInfo('01417868-v', 0) ],
"_converge_v_1_rel" : [ SenseInfo('02710402-v', 1), SenseInfo('02732401-v', 0), SenseInfo('02032634-v', 0), SenseInfo('00368847-v', 0) ],
"_bribed_n_1_rel" : [  ],
"_appointment_n_1_rel" : [ SenseInfo('00163779-n', 6), SenseInfo('08385009-n', 1), SenseInfo('02730568-n', 1), SenseInfo('09607630-n', 0), SenseInfo('00586105-n', 0), SenseInfo('00090393-n', 0), SenseInfo('00163779-n', 6), SenseInfo('08385009-n', 1), SenseInfo('02730568-n', 1), SenseInfo('09607630-n', 0), SenseInfo('00586105-n', 0), SenseInfo('00090393-n', 0), SenseInfo('00163779-n', 6), SenseInfo('08385009-n', 1), SenseInfo('02730568-n', 1), SenseInfo('09607630-n', 0), SenseInfo('00586105-n', 0), SenseInfo('00090393-n', 0) ],
"_exchange_n_1_rel" : [ SenseInfo('11409538-n', 14), SenseInfo('07134706-n', 3), SenseInfo('01166258-n', 3), SenseInfo('01109467-n', 3), SenseInfo('02994858-n', 1), SenseInfo('03302487-n', 0), SenseInfo('01166517-n', 0), SenseInfo('01093085-n', 0), SenseInfo('00196485-n', 0), SenseInfo('00167278-n', 0), SenseInfo('00167063-n', 0) ],
"_coke_n_1_rel" : [ SenseInfo('14685768-n', 0), SenseInfo('07928696-n', 0), SenseInfo('03066743-n', 0) ],
"_stereo_n_1_rel" : [ SenseInfo('04315948-n', 5), SenseInfo('04316275-n', 0) ],
"_daylight_n_1_rel" : [ SenseInfo('15164957-n', 3), SenseInfo('11444038-n', 2) ],
"_peripheral_a_1_rel" : [ SenseInfo('00331446-a', 2), SenseInfo('01857743-a', 1) ],
"_fairground_n_1_rel" : [ SenseInfo('08614632-n', 0) ],
"_personality_n_1_rel" : [ SenseInfo('04617562-n', 14), SenseInfo('10417424-n', 2) ],
"_analogue_n_1_rel" : [ SenseInfo('04746430-n', 1), SenseInfo('04746430-n', 1) ],
"_fs_n_1_rel" : [ SenseInfo('13714641-n', 8), SenseInfo('14637507-n', 0), SenseInfo('13636286-n', 0), SenseInfo('06831712-n', 0), SenseInfo('13714641-n', 8), SenseInfo('14637507-n', 0), SenseInfo('13636286-n', 0), SenseInfo('06831712-n', 0) ],
"_whinny_v_1_rel" : [ SenseInfo('01059743-v', 2), SenseInfo('01059743-v', 2) ],
"_players_a_1_rel" : [  ],
"_well-being_n_1_rel" : [ SenseInfo('14447525-n', 0), SenseInfo('14447525-n', 0) ],
"_upshot_n_of_rel" : [ SenseInfo('11410625-n', 1) ],
"_sterilize_v_1_rel" : [ SenseInfo('00062582-v', 2), SenseInfo('00061595-v', 0) ],
"_prosecute_v_1_rel" : [ SenseInfo('02581900-v', 3), SenseInfo('02581477-v', 3), SenseInfo('02375131-v', 0) ],
"_stride_v_1_rel" : [ SenseInfo('01919711-v', 0), SenseInfo('01912709-v', 0) ],
"_gear_v_towards_rel" : [ SenseInfo('00298244-v', 3) ],
"_vacuum_v_1_rel" : [ SenseInfo('01244853-v', 2) ],
"_blithe_a_1_rel" : [ SenseInfo('00545600-a', 3), SenseInfo('00363291-a', 1) ],
"_tick_v_1_rel" : [ SenseInfo('02185664-v', 2), SenseInfo('02175578-v', 1), SenseInfo('01331689-v', 0), SenseInfo('00662182-v', 0) ],
"_homophone_n_1_rel" : [ SenseInfo('07131169-n', 0) ],
"_at+the+latest_a_1_rel" : [  ],
"_buckboard_n_1_rel" : [ SenseInfo('02909706-n', 2) ],
"_cheerfulness_n_1_rel" : [ SenseInfo('04630689-n', 1), SenseInfo('07530478-n', 0) ],
"_tipi_n_1_rel" : [ SenseInfo('04412416-n', 0) ],
"_chink_n_1_rel" : [ SenseInfo('09698337-n', 0), SenseInfo('09243769-n', 0), SenseInfo('07379223-n', 0) ],
"_furrow_n_1_rel" : [ SenseInfo('03406966-n', 1), SenseInfo('13905792-n', 0) ],
"_impair_v_1_rel" : [ SenseInfo('00262881-v', 4), SenseInfo('00477941-v', 3) ],
"_splash_n_1_rel" : [ SenseInfo('07395104-n', 1), SenseInfo('13978166-n', 0), SenseInfo('13761171-n', 0), SenseInfo('04682319-n', 0), SenseInfo('00717748-n', 0), SenseInfo('00278221-n', 0) ],
"_incumbent_a_1_rel" : [ SenseInfo('02349003-a', 0), SenseInfo('01580601-a', 0), SenseInfo('00667208-a', 0) ],
"_drip_n_1_rel" : [ SenseInfo('07432559-n', 0), SenseInfo('07383323-n', 0), SenseInfo('03241660-n', 0) ],
"_predictive_a_1_rel" : [ SenseInfo('01883325-a', 2) ],
"_point_v_at_rel" : [ SenseInfo('00923793-v', 25), SenseInfo('02713184-v', 8), SenseInfo('01152214-v', 8), SenseInfo('01931768-v', 5), SenseInfo('00921300-v', 1), SenseInfo('01928154-v', 0), SenseInfo('01589363-v', 0), SenseInfo('01589224-v', 0), SenseInfo('01589056-v', 0), SenseInfo('01152670-v', 0), SenseInfo('01150559-v', 0), SenseInfo('00924255-v', 0), SenseInfo('00392960-v', 0), SenseInfo('00261957-v', 0) ],
"_register_n_1_rel" : [ SenseInfo('06507041-n', 2), SenseInfo('05126849-n', 1), SenseInfo('13412321-n', 0), SenseInfo('04071876-n', 0), SenseInfo('04071712-n', 0), SenseInfo('04071536-n', 0), SenseInfo('02977438-n', 0) ],
"_mind_n_1_rel" : [ SenseInfo('05611302-n', 120), SenseInfo('05762149-n', 13), SenseInfo('05837957-n', 10), SenseInfo('10708292-n', 3), SenseInfo('05703956-n', 1), SenseInfo('05982915-n', 0), SenseInfo('05618849-n', 0) ],
"_demoralization_n_1_rel" : [ SenseInfo('00272713-n', 1), SenseInfo('13975988-n', 0), SenseInfo('07537973-n', 0) ],
"_prediction_n_of_rel" : [ SenseInfo('05775081-n', 2), SenseInfo('06748969-n', 0), SenseInfo('05775081-n', 2), SenseInfo('06748969-n', 0) ],
"_nod_n_1_rel" : [ SenseInfo('07274316-n', 1), SenseInfo('00336430-n', 1) ],
"_heal_v_1_rel" : [ SenseInfo('00270561-v', 2), SenseInfo('00099184-v', 1), SenseInfo('00081725-v', 0) ],
"_ill-gotten_a_1_rel" : [ SenseInfo('01403012-a', 0), SenseInfo('01403012-a', 0) ],
"_sabre_n_1_rel" : [ SenseInfo('04121511-n', 0), SenseInfo('02987492-n', 0) ],
"_reset_n_1_rel" : [ SenseInfo('04078955-n', 0) ],
"_present_n_1_rel" : [ SenseInfo('15119536-n', 17), SenseInfo('13268842-n', 4), SenseInfo('06329734-n', 0) ],
"_whistle_n_1_rel" : [ SenseInfo('07400156-n', 0), SenseInfo('06806098-n', 0), SenseInfo('04579667-n', 0), SenseInfo('04579432-n', 0), SenseInfo('03912218-n', 0) ],
"_wean_v_cause_rel" : [ SenseInfo('01186958-v', 1), SenseInfo('01824253-v', 0) ],
"_dessert_n_1_rel" : [ SenseInfo('07609840-n', 2) ],
"_inspiring_a_1_rel" : [ SenseInfo('01323096-a', 1) ],
"_egad_a_1_rel" : [  ],
"_transform_n_1_rel" : [  ],
"_publish_v_1_rel" : [ SenseInfo('01745722-v', 39), SenseInfo('00967625-v', 14), SenseInfo('01744611-v', 1) ],
"_astonished_a_at_rel" : [ SenseInfo('02357810-a', 4) ],
"_motion_n_1_rel" : [ SenseInfo('06876309-n', 8), SenseInfo('07309781-n', 7), SenseInfo('00331950-n', 6), SenseInfo('14004317-n', 2), SenseInfo('07163593-n', 1), SenseInfo('00279835-n', 1), SenseInfo('11425088-n', 0) ],
"_stout_n_1_rel" : [ SenseInfo('07890352-n', 0), SenseInfo('05097166-n', 0) ],
"_lens_n_1_rel" : [ SenseInfo('03656484-n', 5), SenseInfo('12544027-n', 0), SenseInfo('06261060-n', 0), SenseInfo('05320362-n', 0), SenseInfo('03656957-n', 0) ],
"_encourage_v_for_rel" : [ SenseInfo('02554922-v', 53), SenseInfo('01818235-v', 12), SenseInfo('00771341-v', 1), SenseInfo('02554922-v', 53), SenseInfo('01818235-v', 12), SenseInfo('00771341-v', 1), SenseInfo('02554922-v', 53), SenseInfo('01818235-v', 12), SenseInfo('00771341-v', 1) ],
"_fabrication_n_of_rel" : [ SenseInfo('06757891-n', 0), SenseInfo('00931040-n', 0), SenseInfo('00924825-n', 0), SenseInfo('00912001-n', 0), SenseInfo('00751944-n', 0) ],
"_make_v_up-i_rel" : [ SenseInfo('02560585-v', 508), SenseInfo('00120316-v', 459), SenseInfo('01617192-v', 243), SenseInfo('00770437-v', 85), SenseInfo('01645601-v', 78), SenseInfo('01621555-v', 52), SenseInfo('00730758-v', 33), SenseInfo('01646075-v', 17), SenseInfo('01640207-v', 16), SenseInfo('02289295-v', 14), SenseInfo('01619014-v', 14), SenseInfo('02621395-v', 12), SenseInfo('02022162-v', 12), SenseInfo('02674708-v', 10), SenseInfo('01653873-v', 9), SenseInfo('01755816-v', 8), SenseInfo('01654628-v', 5), SenseInfo('00556855-v', 5), SenseInfo('00012267-v', 5), SenseInfo('02396716-v', 4), SenseInfo('02355596-v', 4), SenseInfo('02020590-v', 4), SenseInfo('00665476-v', 4), SenseInfo('02582921-v', 3), SenseInfo('02598483-v', 2), SenseInfo('01733477-v', 2), SenseInfo('00276068-v', 2), SenseInfo('02075857-v', 1), SenseInfo('00074038-v', 1), SenseInfo('02748759-v', 0), SenseInfo('02748627-v', 0), SenseInfo('02745332-v', 0), SenseInfo('02665124-v', 0), SenseInfo('02621133-v', 0), SenseInfo('02134050-v', 0), SenseInfo('02051031-v', 0), SenseInfo('02021532-v', 0), SenseInfo('01755504-v', 0), SenseInfo('01664172-v', 0), SenseInfo('01428578-v', 0), SenseInfo('00891038-v', 0), SenseInfo('00838524-v', 0), SenseInfo('00698256-v', 0), SenseInfo('00698104-v', 0), SenseInfo('00562182-v', 0), SenseInfo('00562067-v', 0), SenseInfo('00545953-v', 0), SenseInfo('00107369-v', 0), SenseInfo('00072012-v', 0), SenseInfo('02560585-v', 508), SenseInfo('00120316-v', 459), SenseInfo('01617192-v', 243), SenseInfo('00770437-v', 85), SenseInfo('01645601-v', 78), SenseInfo('01621555-v', 52), SenseInfo('00730758-v', 33), SenseInfo('01646075-v', 17), SenseInfo('01640207-v', 16), SenseInfo('02289295-v', 14), SenseInfo('01619014-v', 14), SenseInfo('02621395-v', 12), SenseInfo('02022162-v', 12), SenseInfo('02674708-v', 10), SenseInfo('01653873-v', 9), SenseInfo('01755816-v', 8), SenseInfo('01654628-v', 5), SenseInfo('00556855-v', 5), SenseInfo('00012267-v', 5), SenseInfo('02396716-v', 4), SenseInfo('02355596-v', 4), SenseInfo('02020590-v', 4), SenseInfo('00665476-v', 4), SenseInfo('02582921-v', 3), SenseInfo('02598483-v', 2), SenseInfo('01733477-v', 2), SenseInfo('00276068-v', 2), SenseInfo('02075857-v', 1), SenseInfo('00074038-v', 1), SenseInfo('02748759-v', 0), SenseInfo('02748627-v', 0), SenseInfo('02745332-v', 0), SenseInfo('02665124-v', 0), SenseInfo('02621133-v', 0), SenseInfo('02134050-v', 0), SenseInfo('02051031-v', 0), SenseInfo('02021532-v', 0), SenseInfo('01755504-v', 0), SenseInfo('01664172-v', 0), SenseInfo('01428578-v', 0), SenseInfo('00891038-v', 0), SenseInfo('00838524-v', 0), SenseInfo('00698256-v', 0), SenseInfo('00698104-v', 0), SenseInfo('00562182-v', 0), SenseInfo('00562067-v', 0), SenseInfo('00545953-v', 0), SenseInfo('00107369-v', 0), SenseInfo('00072012-v', 0) ],
"_ledge_n_1_rel" : [ SenseInfo('09337253-n', 1) ],
"_descendent_n_of_rel" : [ SenseInfo('10006511-n', 1) ],
"_impenetrability_n_1_rel" : [ SenseInfo('04942516-n', 0), SenseInfo('04822870-n', 0) ],
"_bitch_n_1_rel" : [ SenseInfo('14408519-n', 0), SenseInfo('09982873-n', 0), SenseInfo('07209965-n', 0), SenseInfo('02083672-n', 0), SenseInfo('14408519-n', 0), SenseInfo('09982873-n', 0), SenseInfo('07209965-n', 0), SenseInfo('02083672-n', 0), SenseInfo('14408519-n', 0), SenseInfo('09982873-n', 0), SenseInfo('07209965-n', 0), SenseInfo('02083672-n', 0) ],
"_publisher_n_1_rel" : [ SenseInfo('08062623-n', 4), SenseInfo('10491309-n', 3), SenseInfo('10491575-n', 0) ],
"_condense_v_1_rel" : [ SenseInfo('00364868-v', 2), SenseInfo('00244625-v', 1), SenseInfo('00366547-v', 0), SenseInfo('00366275-v', 0), SenseInfo('00365647-v', 0), SenseInfo('00365446-v', 0), SenseInfo('00365188-v', 0) ],
"_weir_n_1_rel" : [ SenseInfo('04571566-n', 3), SenseInfo('04571686-n', 0) ],
"_toe_v_1_rel" : [ SenseInfo('01906525-v', 0), SenseInfo('01516865-v', 0), SenseInfo('01404138-v', 0), SenseInfo('01402305-v', 0), SenseInfo('01207044-v', 0) ],
"_meatball_n_1_rel" : [ SenseInfo('07871436-n', 0) ],
"_dutchman_n_1_rel" : [ SenseInfo('09713108-n', 0) ],
"_moll_n_1_rel" : [ SenseInfo('10327475-n', 0) ],
"_dipper_n_1_rel" : [ SenseInfo('03204306-n', 4), SenseInfo('09340452-n', 0), SenseInfo('09219858-n', 0), SenseInfo('01850192-n', 0), SenseInfo('01601694-n', 0) ],
"_awe_v_1_rel" : [ SenseInfo('01779644-v', 1) ],
"_citation_n_1_rel" : [ SenseInfo('06706125-n', 2), SenseInfo('07180570-n', 0), SenseInfo('06763681-n', 0), SenseInfo('06613056-n', 0), SenseInfo('06558277-n', 0), SenseInfo('02384326-n', 0) ],
"_cat+and+mouse_n_1_rel" : [ SenseInfo('00484532-n', 0), SenseInfo('00484532-n', 0), SenseInfo('00484532-n', 0) ],
"_avarice_n_1_rel" : [ SenseInfo('00758525-n', 1), SenseInfo('04945758-n', 0) ],
"_garbage_n_1_rel" : [ SenseInfo('14857151-n', 2), SenseInfo('06612266-n', 0), SenseInfo('03416900-n', 0) ],
"_film_n_1_rel" : [ SenseInfo('06613686-n', 38), SenseInfo('06262567-n', 16), SenseInfo('03338821-n', 5), SenseInfo('03338648-n', 5), SenseInfo('03339296-n', 0) ],
"_wager_v_1_rel" : [ SenseInfo('01155687-v', 0), SenseInfo('00918580-v', 0) ],
"_collect_v_1_rel" : [ SenseInfo('02304982-v', 16), SenseInfo('02218173-v', 15), SenseInfo('01380638-v', 12), SenseInfo('01384439-v', 8), SenseInfo('02305586-v', 2), SenseInfo('02304982-v', 16), SenseInfo('02218173-v', 15), SenseInfo('01380638-v', 12), SenseInfo('01384439-v', 8), SenseInfo('02305586-v', 2) ],
"_coffin_n_1_rel" : [ SenseInfo('03064758-n', 3) ],
"_obstacle_n_1_rel" : [ SenseInfo('05690269-n', 5), SenseInfo('03839795-n', 4) ],
"_hold_v_off_rel" : [ SenseInfo('02681795-v', 79), SenseInfo('01216670-v', 65), SenseInfo('01733477-v', 62), SenseInfo('02203362-v', 26), SenseInfo('00693780-v', 20), SenseInfo('01773130-v', 17), SenseInfo('01301410-v', 17), SenseInfo('02283324-v', 14), SenseInfo('02302220-v', 9), SenseInfo('01217043-v', 9), SenseInfo('02700867-v', 7), SenseInfo('02732798-v', 3), SenseInfo('02683489-v', 3), SenseInfo('01601234-v', 3), SenseInfo('02648502-v', 2), SenseInfo('00683771-v', 2), SenseInfo('02746275-v', 1), SenseInfo('02701210-v', 1), SenseInfo('02498320-v', 1), SenseInfo('01129876-v', 1), SenseInfo('00885217-v', 1), SenseInfo('00736586-v', 1), SenseInfo('00607000-v', 1), SenseInfo('02706816-v', 0), SenseInfo('02676789-v', 0), SenseInfo('02643574-v', 0), SenseInfo('02510337-v', 0), SenseInfo('02450989-v', 0), SenseInfo('02441897-v', 0), SenseInfo('01859586-v', 0), SenseInfo('01334744-v', 0), SenseInfo('01205153-v', 0), SenseInfo('01151753-v', 0), SenseInfo('00822367-v', 0), SenseInfo('00805376-v', 0), SenseInfo('00004492-v', 0), SenseInfo('02681795-v', 79), SenseInfo('01216670-v', 65), SenseInfo('01733477-v', 62), SenseInfo('02203362-v', 26), SenseInfo('00693780-v', 20), SenseInfo('01773130-v', 17), SenseInfo('01301410-v', 17), SenseInfo('02283324-v', 14), SenseInfo('02302220-v', 9), SenseInfo('01217043-v', 9), SenseInfo('02700867-v', 7), SenseInfo('02732798-v', 3), SenseInfo('02683489-v', 3), SenseInfo('01601234-v', 3), SenseInfo('02648502-v', 2), SenseInfo('00683771-v', 2), SenseInfo('02746275-v', 1), SenseInfo('02701210-v', 1), SenseInfo('02498320-v', 1), SenseInfo('01129876-v', 1), SenseInfo('00885217-v', 1), SenseInfo('00736586-v', 1), SenseInfo('00607000-v', 1), SenseInfo('02706816-v', 0), SenseInfo('02676789-v', 0), SenseInfo('02643574-v', 0), SenseInfo('02510337-v', 0), SenseInfo('02450989-v', 0), SenseInfo('02441897-v', 0), SenseInfo('01859586-v', 0), SenseInfo('01334744-v', 0), SenseInfo('01205153-v', 0), SenseInfo('01151753-v', 0), SenseInfo('00822367-v', 0), SenseInfo('00805376-v', 0), SenseInfo('00004492-v', 0) ],
"_tulip_n_1_rel" : [ SenseInfo('12454159-n', 1) ],
"_boresight_n_1_rel" : [  ],
"_en+masse_a_1_rel" : [  ],
"_abstractive_a_1_rel" : [ SenseInfo('00860932-a', 1) ],
"_fortunate_a_1_rel" : [ SenseInfo('01047874-a', 7), SenseInfo('00670938-a', 1), SenseInfo('00176676-a', 0), SenseInfo('01047874-a', 7), SenseInfo('00670938-a', 1), SenseInfo('00176676-a', 0), SenseInfo('01047874-a', 7), SenseInfo('00670938-a', 1), SenseInfo('00176676-a', 0), SenseInfo('01047874-a', 7), SenseInfo('00670938-a', 1), SenseInfo('00176676-a', 0), SenseInfo('01047874-a', 7), SenseInfo('00670938-a', 1), SenseInfo('00176676-a', 0) ],
"_married_a_1_rel" : [ SenseInfo('01481612-a', 17), SenseInfo('02852920-a', 0) ],
"_promptness_n_1_rel" : [ SenseInfo('05060052-n', 0), SenseInfo('05047778-n', 0), SenseInfo('05060052-n', 0), SenseInfo('05047778-n', 0) ],
"_take_v_into_rel" : [ SenseInfo('02599636-v', 92), SenseInfo('02267989-v', 74), SenseInfo('01999798-v', 73), SenseInfo('01214265-v', 50), SenseInfo('00524682-v', 38), SenseInfo('00624476-v', 36), SenseInfo('02077656-v', 32), SenseInfo('02205272-v', 28), SenseInfo('01842690-v', 26), SenseInfo('00674607-v', 26), SenseInfo('02236124-v', 25), SenseInfo('02394183-v', 22), SenseInfo('00734054-v', 22), SenseInfo('02627934-v', 21), SenseInfo('02109045-v', 21), SenseInfo('01002740-v', 16), SenseInfo('00173338-v', 16), SenseInfo('01156834-v', 15), SenseInfo('00669762-v', 15), SenseInfo('02209936-v', 14), SenseInfo('02206619-v', 13), SenseInfo('01982395-v', 10), SenseInfo('02236624-v', 8), SenseInfo('00523095-v', 7), SenseInfo('00599992-v', 6), SenseInfo('00756076-v', 5), SenseInfo('02075857-v', 4), SenseInfo('01151110-v', 4), SenseInfo('00557404-v', 4), SenseInfo('02717102-v', 2), SenseInfo('02208537-v', 2), SenseInfo('02209745-v', 1), SenseInfo('02208118-v', 1), SenseInfo('02201138-v', 1), SenseInfo('01427127-v', 1), SenseInfo('00758333-v', 1), SenseInfo('02741546-v', 0), SenseInfo('02701210-v', 0), SenseInfo('02590253-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01100830-v', 0), SenseInfo('00087736-v', 0) ],
"_roger+wilco_a_1_rel" : [  ],
"_declaration_n_of_rel" : [ SenseInfo('06725877-n', 4), SenseInfo('06736217-n', 1), SenseInfo('07204110-n', 0), SenseInfo('06737394-n', 0), SenseInfo('06726158-n', 0), SenseInfo('06511874-n', 0), SenseInfo('06725877-n', 4), SenseInfo('06736217-n', 1), SenseInfo('07204110-n', 0), SenseInfo('06737394-n', 0), SenseInfo('06726158-n', 0), SenseInfo('06511874-n', 0) ],
"_headache_n_1_rel" : [ SenseInfo('05832264-n', 5), SenseInfo('14326607-n', 3) ],
"_propagandistic_a_1_rel" : [ SenseInfo('03022739-a', 4) ],
"_homeowner_n_1_rel" : [ SenseInfo('10182499-n', 0), SenseInfo('10182499-n', 0), SenseInfo('10182499-n', 0) ],
"_lunchroom_n_1_rel" : [ SenseInfo('03697552-n', 1) ],
"_crush_v_cause_rel" : [ SenseInfo('02424652-v', 4), SenseInfo('01593937-v', 3), SenseInfo('01101913-v', 3), SenseInfo('00339085-v', 2), SenseInfo('01800195-v', 0), SenseInfo('01492944-v', 0), SenseInfo('01103836-v', 0), SenseInfo('00559390-v', 0) ],
"_capitalist_a_1_rel" : [ SenseInfo('03000110-a', 3), SenseInfo('00297403-a', 0) ],
"_receptionist_n_1_rel" : [ SenseInfo('10511069-n', 6) ],
"_submissive_a_1_rel" : [ SenseInfo('00788821-a', 4), SenseInfo('00790691-a', 0) ],
"_approve_v_of_rel" : [ SenseInfo('00806502-v', 27), SenseInfo('00673983-v', 7) ],
"_collector_n_1_rel" : [ SenseInfo('09936620-n', 9), SenseInfo('09936362-n', 1), SenseInfo('09249155-n', 1), SenseInfo('03069381-n', 0) ],
"_store_v_up_rel" : [ SenseInfo('02281093-v', 16), SenseInfo('02282506-v', 11) ],
"_eaglet_n_1_rel" : [ SenseInfo('01613807-n', 0) ],
"_convolution_n_1_rel" : [ SenseInfo('13878112-n', 0), SenseInfo('05492426-n', 0), SenseInfo('00404959-n', 0) ],
"_steep_v_1_rel" : [ SenseInfo('00601043-v', 2), SenseInfo('00327362-v', 0) ],
"_rating_n_1_rel" : [ SenseInfo('05736149-n', 7), SenseInfo('00874806-n', 3), SenseInfo('14429382-n', 1), SenseInfo('14431471-n', 0), SenseInfo('05736149-n', 7), SenseInfo('00874806-n', 3), SenseInfo('14429382-n', 1), SenseInfo('14431471-n', 0), SenseInfo('05736149-n', 7), SenseInfo('00874806-n', 3), SenseInfo('14429382-n', 1), SenseInfo('14431471-n', 0) ],
"_uh+huh_a_1_rel" : [  ],
"_ecology_n_1_rel" : [ SenseInfo('14513062-n', 0), SenseInfo('06070929-n', 0) ],
"_never_a_1_rel" : [  ],
"_beta_n_1_rel" : [ SenseInfo('06834245-n', 1), SenseInfo('11832108-n', 0) ],
"_cruelty_n_1_rel" : [ SenseInfo('00424599-n', 4), SenseInfo('07506382-n', 1), SenseInfo('04845475-n', 1) ],
"_away_x_deg_rel" : [ SenseInfo('00232936-r', 70), SenseInfo('00233295-r', 21), SenseInfo('00234052-r', 13), SenseInfo('00234553-r', 3), SenseInfo('00235254-r', 2), SenseInfo('00234747-r', 2), SenseInfo('00235438-r', 1), SenseInfo('01847864-a', 1), SenseInfo('01219938-a', 0), SenseInfo('00235570-r', 0), SenseInfo('00235070-r', 0), SenseInfo('00234951-r', 0), SenseInfo('00233687-r', 0), SenseInfo('00023655-a', 0) ],
"_psi_n_meas_rel" : [ SenseInfo('13711570-n', 1), SenseInfo('06836493-n', 0) ],
"_astronaut_n_1_rel" : [ SenseInfo('09818022-n', 0) ],
"_hope_v_for_rel" : [ SenseInfo('01826723-v', 60), SenseInfo('01811441-v', 37), SenseInfo('00706047-v', 23) ],
"_self-conscious_a_1_rel" : [ SenseInfo('00570991-a', 1), SenseInfo('00480965-a', 0), SenseInfo('00570991-a', 1), SenseInfo('00480965-a', 0), SenseInfo('00570991-a', 1), SenseInfo('00480965-a', 0), SenseInfo('00570991-a', 1), SenseInfo('00480965-a', 0), SenseInfo('00570991-a', 1), SenseInfo('00480965-a', 0) ],
"_vehemence_n_1_rel" : [ SenseInfo('05037394-n', 1), SenseInfo('05037813-n', 0) ],
"_commodity_n_1_rel" : [ SenseInfo('03076708-n', 4), SenseInfo('03076708-n', 4), SenseInfo('03076708-n', 4) ],
"_lopsided_a_1_rel" : [ SenseInfo('02373868-a', 0), SenseInfo('02312450-a', 0), SenseInfo('02373868-a', 0), SenseInfo('02312450-a', 0) ],
"_robe_v_1_rel" : [ SenseInfo('00052043-v', 1), SenseInfo('01617034-v', 0) ],
"_combine_v_cause_rel" : [ SenseInfo('02631163-v', 14), SenseInfo('00193486-v', 12), SenseInfo('01461328-v', 5), SenseInfo('02309008-v', 4), SenseInfo('02377938-v', 2), SenseInfo('01385170-v', 1), SenseInfo('00394813-v', 1), SenseInfo('02631163-v', 14), SenseInfo('00193486-v', 12), SenseInfo('01461328-v', 5), SenseInfo('02309008-v', 4), SenseInfo('02377938-v', 2), SenseInfo('01385170-v', 1), SenseInfo('00394813-v', 1) ],
"_pension_n_1_rel" : [ SenseInfo('13384164-n', 4) ],
"_ravish_v_1_rel" : [ SenseInfo('02567519-v', 0), SenseInfo('01817314-v', 0) ],
"_blacken_v_1_rel" : [ SenseInfo('00280532-v', 2), SenseInfo('00379440-v', 0) ],
"_unfavorable_a_1_rel" : [ SenseInfo('00996448-a', 2), SenseInfo('00995468-a', 0), SenseInfo('01129644-a', 0), SenseInfo('00996448-a', 2), SenseInfo('00995468-a', 0), SenseInfo('01129644-a', 0), SenseInfo('00996448-a', 2), SenseInfo('00995468-a', 0), SenseInfo('01129644-a', 0), SenseInfo('00996448-a', 2), SenseInfo('00995468-a', 0), SenseInfo('01129644-a', 0), SenseInfo('00996448-a', 2), SenseInfo('00995468-a', 0), SenseInfo('01129644-a', 0), SenseInfo('00996448-a', 2), SenseInfo('00995468-a', 0), SenseInfo('01129644-a', 0) ],
"_wrap+up_n_1_rel" : [  ],
"_probing_n_1_rel" : [ SenseInfo('00879918-a', 0) ],
"_doom_v_to_rel" : [ SenseInfo('00746479-v', 9), SenseInfo('00906735-v', 0), SenseInfo('00890855-v', 0) ],
"_wharf_n_1_rel" : [ SenseInfo('03933529-n', 1) ],
"_sw_n_of_rel" : [ SenseInfo('13833886-n', 0) ],
"_hang_v_1_rel" : [ SenseInfo('01482075-v', 35), SenseInfo('01481360-v', 12), SenseInfo('02485451-v', 11), SenseInfo('01977962-v', 6), SenseInfo('01542668-v', 5), SenseInfo('02734952-v', 2), SenseInfo('02170427-v', 1), SenseInfo('01481957-v', 1), SenseInfo('01216331-v', 1), SenseInfo('02741003-v', 0), SenseInfo('02557790-v', 0), SenseInfo('01677716-v', 0), SenseInfo('01481819-v', 0), SenseInfo('01481647-v', 0), SenseInfo('00210110-v', 0), SenseInfo('01482075-v', 35), SenseInfo('01481360-v', 12), SenseInfo('02485451-v', 11), SenseInfo('01977962-v', 6), SenseInfo('01542668-v', 5), SenseInfo('02734952-v', 2), SenseInfo('02170427-v', 1), SenseInfo('01481957-v', 1), SenseInfo('01216331-v', 1), SenseInfo('02741003-v', 0), SenseInfo('02557790-v', 0), SenseInfo('01677716-v', 0), SenseInfo('01481819-v', 0), SenseInfo('01481647-v', 0), SenseInfo('00210110-v', 0) ],
"_overcast_a_1_rel" : [ SenseInfo('00461971-a', 1) ],
"_therefore_x_rel" : [ SenseInfo('00043003-r', 88), SenseInfo('00294459-r', 0) ],
"_cave_v_1_rel" : [ SenseInfo('01283033-v', 0), SenseInfo('00649887-v', 0) ],
"_predispose_v_to_rel" : [ SenseInfo('00680692-v', 0), SenseInfo('00680692-v', 0) ],
"_bank_v_on_rel" : [ SenseInfo('02039413-v', 2), SenseInfo('01587705-v', 1), SenseInfo('02343374-v', 0), SenseInfo('02343252-v', 0), SenseInfo('02343056-v', 0), SenseInfo('02310855-v', 0), SenseInfo('01234793-v', 0), SenseInfo('00688377-v', 0) ],
"_stead_n_1_rel" : [ SenseInfo('00721431-n', 2) ],
"_perforator_n_1_rel" : [  ],
"_formula_n_1_rel" : [ SenseInfo('06731802-n', 8), SenseInfo('06788785-n', 6), SenseInfo('06732013-n', 3), SenseInfo('06816935-n', 1), SenseInfo('05667613-n', 1), SenseInfo('07845087-n', 0), SenseInfo('05846932-n', 0), SenseInfo('06731802-n', 8), SenseInfo('06788785-n', 6), SenseInfo('06732013-n', 3), SenseInfo('06816935-n', 1), SenseInfo('05667613-n', 1), SenseInfo('07845087-n', 0), SenseInfo('05846932-n', 0) ],
"_unambiguous_a_1_rel" : [ SenseInfo('00103696-a', 2), SenseInfo('00896555-a', 1), SenseInfo('00103696-a', 2), SenseInfo('00896555-a', 1), SenseInfo('00103696-a', 2), SenseInfo('00896555-a', 1) ],
"_animation_n_of_rel" : [ SenseInfo('13961642-n', 0), SenseInfo('05005809-n', 0), SenseInfo('04631700-n', 0), SenseInfo('01048466-n', 0), SenseInfo('00908405-n', 0), SenseInfo('00552436-n', 0) ],
"_celibacy_n_1_rel" : [ SenseInfo('13967507-n', 0), SenseInfo('01069125-n', 0) ],
"_note_v_down_rel" : [ SenseInfo('01020005-v', 41), SenseInfo('02118476-v', 36), SenseInfo('02118933-v', 29), SenseInfo('01020934-v', 3) ],
"_scuttle_n_1_rel" : [ SenseInfo('04158002-n', 0), SenseInfo('03499142-n', 0) ],
"_unstable_a_1_rel" : [ SenseInfo('02291843-a', 5), SenseInfo('01929456-a', 1), SenseInfo('00823192-a', 1), SenseInfo('02076817-a', 0), SenseInfo('01992712-a', 0), SenseInfo('00345494-a', 0), SenseInfo('02291843-a', 5), SenseInfo('01929456-a', 1), SenseInfo('00823192-a', 1), SenseInfo('02076817-a', 0), SenseInfo('01992712-a', 0), SenseInfo('00345494-a', 0) ],
"_fungal_a_1_rel" : [ SenseInfo('02832678-a', 1) ],
"_butt_v_1_rel" : [ SenseInfo('01466978-v', 3), SenseInfo('01235769-v', 2), SenseInfo('01498713-v', 1) ],
"_excepting_p_rel" : [  ],
"_rail_v_at_rel" : [ SenseInfo('00911261-v', 2), SenseInfo('02711543-v', 0), SenseInfo('02330407-v', 0), SenseInfo('02031430-v', 0), SenseInfo('01954559-v', 0), SenseInfo('01936537-v', 0), SenseInfo('01503268-v', 0), SenseInfo('01141271-v', 0), SenseInfo('00847870-v', 0), SenseInfo('00841767-v', 0), SenseInfo('00911261-v', 2), SenseInfo('02711543-v', 0), SenseInfo('02330407-v', 0), SenseInfo('02031430-v', 0), SenseInfo('01954559-v', 0), SenseInfo('01936537-v', 0), SenseInfo('01503268-v', 0), SenseInfo('01141271-v', 0), SenseInfo('00847870-v', 0), SenseInfo('00841767-v', 0) ],
"_hew_v_to_rel" : [ SenseInfo('01260685-v', 0), SenseInfo('01260428-v', 0) ],
"_tricky_a_for_rel" : [ SenseInfo('02466734-a', 0), SenseInfo('00746819-a', 0), SenseInfo('00148078-a', 0), SenseInfo('02466734-a', 0), SenseInfo('00746819-a', 0), SenseInfo('00148078-a', 0) ],
"_fondant_n_1_rel" : [ SenseInfo('07605380-n', 0) ],
"_not+least_x_deg_rel" : [ SenseInfo('00111758-r', 5), SenseInfo('01556061-a', 2), SenseInfo('05671526-n', 0) ],
"_bliss_n_1_rel" : [ SenseInfo('13987905-n', 0) ],
"_blast_v_1_rel" : [ SenseInfo('02182479-v', 3), SenseInfo('01401772-v', 2), SenseInfo('01135922-v', 1), SenseInfo('02101216-v', 0), SenseInfo('01759021-v', 0), SenseInfo('01758276-v', 0), SenseInfo('01134781-v', 0), SenseInfo('00823827-v', 0), SenseInfo('00336158-v', 0), SenseInfo('00241924-v', 0) ],
"_notion_n_of_rel" : [ SenseInfo('05916739-n', 14), SenseInfo('05836598-n', 14), SenseInfo('05919549-n', 2), SenseInfo('03832799-n', 0), SenseInfo('05916739-n', 14), SenseInfo('05836598-n', 14), SenseInfo('05919549-n', 2), SenseInfo('03832799-n', 0) ],
"_mainland_a_1_rel" : [ SenseInfo('09346120-n', 3) ],
"_piece_v_1_rel" : [ SenseInfo('01590171-v', 1), SenseInfo('01656788-v', 0), SenseInfo('01294992-v', 0), SenseInfo('01174294-v', 0), SenseInfo('00261705-v', 0) ],
"_tribute_n_1_rel" : [ SenseInfo('06697195-n', 5), SenseInfo('01122387-n', 0), SenseInfo('00784755-n', 0) ],
"_nearly_x_deg_rel" : [ SenseInfo('00073033-r', 53), SenseInfo('00160659-r', 0), SenseInfo('00073033-r', 53), SenseInfo('00160659-r', 0) ],
"_responsibility_n_1_rel" : [ SenseInfo('01129920-n', 17), SenseInfo('14515633-n', 2), SenseInfo('04669247-n', 2) ],
"_result_v_in_rel" : [ SenseInfo('02634265-v', 45), SenseInfo('02635659-v', 38), SenseInfo('00340704-v', 0) ],
"_arm_n_1_rel" : [ SenseInfo('05563770-n', 104), SenseInfo('02737833-n', 3), SenseInfo('04565375-n', 1), SenseInfo('02737660-n', 1), SenseInfo('08401248-n', 0), SenseInfo('04236377-n', 0) ],
"_incomplete_a_1_rel" : [ SenseInfo('00523978-a', 9), SenseInfo('01004541-a', 0), SenseInfo('00523978-a', 9), SenseInfo('01004541-a', 0) ],
"_hither_p_rel" : [ SenseInfo('00108647-r', 6) ],
"_electrotherapist_n_1_rel" : [ SenseInfo('10049896-n', 1) ],
"_cornsilk_a_1_rel" : [ SenseInfo('12145638-n', 0) ],
"_ironic_a_1_rel" : [ SenseInfo('01266092-a', 1), SenseInfo('00563288-a', 0), SenseInfo('01266092-a', 1), SenseInfo('00563288-a', 0), SenseInfo('01266092-a', 1), SenseInfo('00563288-a', 0) ],
"_messaging_n_1_rel" : [ SenseInfo('06280477-n', 0) ],
"_gravy_n_1_rel" : [ SenseInfo('07838073-n', 0), SenseInfo('07837912-n', 0), SenseInfo('07477587-n', 0) ],
"_talk_v_into_rel" : [ SenseInfo('00962447-v', 108), SenseInfo('00941990-v', 26), SenseInfo('00963570-v', 8), SenseInfo('00952841-v', 4), SenseInfo('00937208-v', 2), SenseInfo('00830761-v', 0) ],
"_intermittent_a_1_rel" : [ SenseInfo('00593836-a', 2), SenseInfo('00593836-a', 2) ],
"_nihilism_n_1_rel" : [ SenseInfo('05965388-n', 1), SenseInfo('14378712-n', 0), SenseInfo('13973320-n', 0) ],
"_coastline_n_1_rel" : [ SenseInfo('08613000-n', 0) ],
"_atrium_n_1_rel" : [ SenseInfo('05393023-n', 0), SenseInfo('02754656-n', 0) ],
"_vault_v_1_rel" : [ SenseInfo('01966168-v', 0), SenseInfo('01965806-v', 0) ],
"_drawbridge_n_1_rel" : [ SenseInfo('03233744-n', 0) ],
"_voicemail_n_1_rel" : [ SenseInfo('06272612-n', 0) ],
"_harbour_n_1_rel" : [ SenseInfo('08639058-n', 0), SenseInfo('03492250-n', 0) ],
"_in+vitro_a_1_rel" : [ SenseInfo('01359277-a', 3) ],
"_chemical_a_1_rel" : [ SenseInfo('02692624-a', 11), SenseInfo('02692966-a', 3), SenseInfo('02692624-a', 11), SenseInfo('02692966-a', 3) ],
"_farce_v_1_rel" : [ SenseInfo('00320681-v', 0) ],
"_chasm_n_1_rel" : [ SenseInfo('09242389-n', 0) ],
"_negus_n_1_rel" : [ SenseInfo('07927070-n', 0) ],
"_easterly_a_1_rel" : [ SenseInfo('00823832-a', 0), SenseInfo('00823665-a', 0), SenseInfo('00823832-a', 0), SenseInfo('00823665-a', 0) ],
"_clock_v_in_rel" : [ SenseInfo('00490968-v', 1) ],
"_begin_v_1_rel" : [ SenseInfo('00345761-v', 375), SenseInfo('02608347-v', 57), SenseInfo('00348746-v', 27), SenseInfo('00747640-v', 9), SenseInfo('02679227-v', 0), SenseInfo('02609203-v', 0), SenseInfo('02608823-v', 0), SenseInfo('02600948-v', 0), SenseInfo('02526509-v', 0), SenseInfo('01070777-v', 0), SenseInfo('00345761-v', 375), SenseInfo('02608347-v', 57), SenseInfo('00348746-v', 27), SenseInfo('00747640-v', 9), SenseInfo('02679227-v', 0), SenseInfo('02609203-v', 0), SenseInfo('02608823-v', 0), SenseInfo('02600948-v', 0), SenseInfo('02526509-v', 0), SenseInfo('01070777-v', 0), SenseInfo('00345761-v', 375), SenseInfo('02608347-v', 57), SenseInfo('00348746-v', 27), SenseInfo('00747640-v', 9), SenseInfo('02679227-v', 0), SenseInfo('02609203-v', 0), SenseInfo('02608823-v', 0), SenseInfo('02600948-v', 0), SenseInfo('02526509-v', 0), SenseInfo('01070777-v', 0) ],
"_ramble_n_1_rel" : [ SenseInfo('00284409-n', 0) ],
"_seat_v_1_rel" : [ SenseInfo('01543998-v', 9), SenseInfo('02701962-v', 2), SenseInfo('02384275-v', 2), SenseInfo('02334302-v', 0), SenseInfo('02333979-v', 0), SenseInfo('01616901-v', 0), SenseInfo('01544285-v', 0), SenseInfo('01543998-v', 9), SenseInfo('02701962-v', 2), SenseInfo('02384275-v', 2), SenseInfo('02334302-v', 0), SenseInfo('02333979-v', 0), SenseInfo('01616901-v', 0), SenseInfo('01544285-v', 0) ],
"_antiseptic_a_1_rel" : [ SenseInfo('02115324-a', 1), SenseInfo('00622828-a', 1), SenseInfo('02118047-a', 0), SenseInfo('00424240-a', 0) ],
"_remark_v_on_rel" : [ SenseInfo('01020005-v', 41), SenseInfo('01058574-v', 0), SenseInfo('01020005-v', 41), SenseInfo('01058574-v', 0), SenseInfo('01020005-v', 41), SenseInfo('01058574-v', 0), SenseInfo('01020005-v', 41), SenseInfo('01058574-v', 0) ],
"_bottom_n_1_rel" : [ SenseInfo('08511241-n', 9), SenseInfo('08511970-n', 5), SenseInfo('05559256-n', 2), SenseInfo('15256245-n', 1), SenseInfo('09217638-n', 1), SenseInfo('09227428-n', 0), SenseInfo('02878222-n', 0), SenseInfo('08511241-n', 9), SenseInfo('08511970-n', 5), SenseInfo('05559256-n', 2), SenseInfo('15256245-n', 1), SenseInfo('09217638-n', 1), SenseInfo('09227428-n', 0), SenseInfo('02878222-n', 0) ],
"_hostess_n_1_rel" : [ SenseInfo('10187491-n', 2), SenseInfo('10187059-n', 2), SenseInfo('10655875-n', 1) ],
"_argument_n_1_rel" : [ SenseInfo('06648724-n', 22), SenseInfo('07183151-n', 21), SenseInfo('07140978-n', 2), SenseInfo('06467680-n', 1), SenseInfo('06356299-n', 0), SenseInfo('05857781-n', 0), SenseInfo('05773049-n', 0), SenseInfo('06648724-n', 22), SenseInfo('07183151-n', 21), SenseInfo('07140978-n', 2), SenseInfo('06467680-n', 1), SenseInfo('06356299-n', 0), SenseInfo('05857781-n', 0), SenseInfo('05773049-n', 0) ],
"_birthplace_n_1_rel" : [ SenseInfo('08510350-n', 1), SenseInfo('08510456-n', 0) ],
"_loneliness_n_1_rel" : [ SenseInfo('14415163-n', 4), SenseInfo('07534108-n', 1), SenseInfo('04622415-n', 0) ],
"_pretzel_n_1_rel" : [ SenseInfo('07695742-n', 0) ],
"_telephone_v_1_rel" : [ SenseInfo('00789448-v', 12), SenseInfo('00789448-v', 12), SenseInfo('00789448-v', 12) ],
"_corporation_n_1_rel" : [ SenseInfo('08059412-n', 40), SenseInfo('05556071-n', 0), SenseInfo('08059412-n', 40), SenseInfo('05556071-n', 0), SenseInfo('08059412-n', 40), SenseInfo('05556071-n', 0), SenseInfo('08059412-n', 40), SenseInfo('05556071-n', 0), SenseInfo('08059412-n', 40), SenseInfo('05556071-n', 0) ],
"_croatoan_a_1_rel" : [  ],
"_overtake_v_1_rel" : [ SenseInfo('01155090-v', 3), SenseInfo('02049696-v', 2), SenseInfo('01809321-v', 0) ],
"_district_n_of_rel" : [ SenseInfo('08552138-n', 38) ],
"_lined_a_1_rel" : [ SenseInfo('00258797-a', 3), SenseInfo('02241543-a', 1), SenseInfo('01417941-a', 0) ],
"_paste_v_1_rel" : [ SenseInfo('01332205-v', 5), SenseInfo('01412644-v', 0), SenseInfo('01332599-v', 0), SenseInfo('01332205-v', 5), SenseInfo('01412644-v', 0), SenseInfo('01332599-v', 0) ],
"_crumble_n_1_rel" : [  ],
"_parachute_v_in_rel" : [ SenseInfo('01968275-v', 0) ],
"_craggy_a_1_rel" : [ SenseInfo('02240490-a', 1), SenseInfo('02240490-a', 1), SenseInfo('02240490-a', 1) ],
"_subsidiary_a_1_rel" : [ SenseInfo('01854129-a', 0) ],
"_bossy_a_1_rel" : [ SenseInfo('00787595-a', 0) ],
"_surname_n_1_rel" : [ SenseInfo('06336904-n', 0) ],
"_glint_v_1_rel" : [ SenseInfo('02162947-v', 4), SenseInfo('02165304-v', 1) ],
"_listen_v_to_rel" : [ SenseInfo('02169891-v', 60), SenseInfo('02171039-v', 34), SenseInfo('02571901-v', 4), SenseInfo('02169891-v', 60), SenseInfo('02171039-v', 34), SenseInfo('02571901-v', 4), SenseInfo('02169891-v', 60), SenseInfo('02171039-v', 34), SenseInfo('02571901-v', 4) ],
"_hound_n_1_rel" : [ SenseInfo('02087551-n', 2), SenseInfo('09886220-n', 1) ],
"_motivation_n_for_rel" : [ SenseInfo('00023773-n', 5), SenseInfo('14578471-n', 0), SenseInfo('00070641-n', 0) ],
"_newtonian_a_1_rel" : [ SenseInfo('03036014-a', 2) ],
"_drop-dead_a_1_rel" : [  ],
"_could_v_modal_rel" : [ SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0) ],
"_arctic_a_1_rel" : [ SenseInfo('02444475-a', 1), SenseInfo('01252151-a', 0) ],
"_rainfall_n_1_rel" : [ SenseInfo('11501381-n', 1) ],
"_privilege_n_of_rel" : [ SenseInfo('05158296-n', 8), SenseInfo('05178715-n', 3), SenseInfo('05179567-n', 0) ],
"_fill_n_1_rel" : [ SenseInfo('13580723-n', 4), SenseInfo('14868243-n', 0) ],
"_wedge_v_1_rel" : [ SenseInfo('01528069-v', 1), SenseInfo('01527271-v', 0) ],
"_class_n_of_rel" : [ SenseInfo('07997703-n', 15), SenseInfo('08238463-n', 13), SenseInfo('07974025-n', 6), SenseInfo('00884466-n', 4), SenseInfo('08239808-n', 2), SenseInfo('08238660-n', 0), SenseInfo('08103777-n', 0), SenseInfo('04815177-n', 0), SenseInfo('07997703-n', 15), SenseInfo('08238463-n', 13), SenseInfo('07974025-n', 6), SenseInfo('00884466-n', 4), SenseInfo('08239808-n', 2), SenseInfo('08238660-n', 0), SenseInfo('08103777-n', 0), SenseInfo('04815177-n', 0), SenseInfo('07997703-n', 15), SenseInfo('08238463-n', 13), SenseInfo('07974025-n', 6), SenseInfo('00884466-n', 4), SenseInfo('08239808-n', 2), SenseInfo('08238660-n', 0), SenseInfo('08103777-n', 0), SenseInfo('04815177-n', 0) ],
"_pounce_n_1_rel" : [ SenseInfo('01258161-n', 0) ],
"_acrobatics_n_1_rel" : [ SenseInfo('00434075-n', 1), SenseInfo('00302861-n', 0) ],
"_flag_v_1_rel" : [ SenseInfo('01040550-v', 1), SenseInfo('00511040-v', 1), SenseInfo('01985524-v', 0), SenseInfo('01670172-v', 0), SenseInfo('00156485-v', 0) ],
"_cheerful_a_1_rel" : [ SenseInfo('00362467-a', 4), SenseInfo('01664015-a', 0), SenseInfo('00362467-a', 4), SenseInfo('01664015-a', 0) ],
"_acid_n_1_rel" : [ SenseInfo('14607521-n', 4), SenseInfo('02675657-n', 0) ],
"_niche_n_1_rel" : [ SenseInfo('13926168-n', 1), SenseInfo('13872421-n', 1), SenseInfo('04061969-n', 1), SenseInfo('13924336-n', 0) ],
"_rot_v_cause_rel" : [ SenseInfo('00209837-v', 3), SenseInfo('00093775-v', 0) ],
"_holy_a_1_rel" : [ SenseInfo('02053818-a', 0), SenseInfo('02053818-a', 0), SenseInfo('02053818-a', 0) ],
"_inverse_a_1_rel" : [ SenseInfo('00202095-a', 1), SenseInfo('00769489-a', 0) ],
"_sore_a_1_rel" : [ SenseInfo('01712753-a', 8), SenseInfo('01804175-a', 1), SenseInfo('00115193-a', 1), SenseInfo('01712753-a', 8), SenseInfo('01804175-a', 1), SenseInfo('00115193-a', 1), SenseInfo('01712753-a', 8), SenseInfo('01804175-a', 1), SenseInfo('00115193-a', 1) ],
"_ruling_n_1_rel" : [ SenseInfo('01191158-n', 4), SenseInfo('01191158-n', 4) ],
"_cotter_n_1_rel" : [ SenseInfo('09968741-n', 0), SenseInfo('09968652-n', 0), SenseInfo('03114839-n', 0) ],
"_floodlit_a_1_rel" : [ SenseInfo('00271288-a', 0) ],
"_record_v_1_rel" : [ SenseInfo('01000214-v', 34), SenseInfo('00998399-v', 9), SenseInfo('00922867-v', 4), SenseInfo('02105810-v', 0), SenseInfo('00612042-v', 0) ],
"_consult_v_about_rel" : [ SenseInfo('00877559-v', 15), SenseInfo('00877083-v', 4), SenseInfo('00876665-v', 2), SenseInfo('00876442-v', 0) ],
"_direct_v_to_rel" : [ SenseInfo('00749205-v', 17), SenseInfo('01150559-v', 16), SenseInfo('01710317-v', 13), SenseInfo('02439501-v', 7), SenseInfo('01999798-v', 5), SenseInfo('01951480-v', 5), SenseInfo('01151110-v', 5), SenseInfo('01732921-v', 4), SenseInfo('00749376-v', 1), SenseInfo('00713015-v', 1), SenseInfo('01931768-v', 0), SenseInfo('00990812-v', 0), SenseInfo('00710005-v', 0), SenseInfo('00749205-v', 17), SenseInfo('01150559-v', 16), SenseInfo('01710317-v', 13), SenseInfo('02439501-v', 7), SenseInfo('01999798-v', 5), SenseInfo('01951480-v', 5), SenseInfo('01151110-v', 5), SenseInfo('01732921-v', 4), SenseInfo('00749376-v', 1), SenseInfo('00713015-v', 1), SenseInfo('01931768-v', 0), SenseInfo('00990812-v', 0), SenseInfo('00710005-v', 0), SenseInfo('00749205-v', 17), SenseInfo('01150559-v', 16), SenseInfo('01710317-v', 13), SenseInfo('02439501-v', 7), SenseInfo('01999798-v', 5), SenseInfo('01951480-v', 5), SenseInfo('01151110-v', 5), SenseInfo('01732921-v', 4), SenseInfo('00749376-v', 1), SenseInfo('00713015-v', 1), SenseInfo('01931768-v', 0), SenseInfo('00990812-v', 0), SenseInfo('00710005-v', 0), SenseInfo('00749205-v', 17), SenseInfo('01150559-v', 16), SenseInfo('01710317-v', 13), SenseInfo('02439501-v', 7), SenseInfo('01999798-v', 5), SenseInfo('01951480-v', 5), SenseInfo('01151110-v', 5), SenseInfo('01732921-v', 4), SenseInfo('00749376-v', 1), SenseInfo('00713015-v', 1), SenseInfo('01931768-v', 0), SenseInfo('00990812-v', 0), SenseInfo('00710005-v', 0), SenseInfo('00749205-v', 17), SenseInfo('01150559-v', 16), SenseInfo('01710317-v', 13), SenseInfo('02439501-v', 7), SenseInfo('01999798-v', 5), SenseInfo('01951480-v', 5), SenseInfo('01151110-v', 5), SenseInfo('01732921-v', 4), SenseInfo('00749376-v', 1), SenseInfo('00713015-v', 1), SenseInfo('01931768-v', 0), SenseInfo('00990812-v', 0), SenseInfo('00710005-v', 0) ],
"_detain_v_1_rel" : [ SenseInfo('02495038-v', 1), SenseInfo('00460900-v', 0), SenseInfo('00459776-v', 0) ],
"_for+better+or+for+worse_a_1_rel" : [  ],
"_diagram_n_1_rel" : [ SenseInfo('03186399-n', 6) ],
"_year+in+and+year_out_a_1_rel" : [  ],
"_praise_n_1_rel" : [ SenseInfo('06693198-n', 5), SenseInfo('06693502-n', 0) ],
"_range_n_of_rel" : [ SenseInfo('05125377-n', 45), SenseInfo('08628921-n', 14), SenseInfo('08629199-n', 7), SenseInfo('09403734-n', 1), SenseInfo('04053218-n', 1), SenseInfo('08399586-n', 0), SenseInfo('08000304-n', 0), SenseInfo('05623628-n', 0), SenseInfo('04330340-n', 0), SenseInfo('05125377-n', 45), SenseInfo('08628921-n', 14), SenseInfo('08629199-n', 7), SenseInfo('09403734-n', 1), SenseInfo('04053218-n', 1), SenseInfo('08399586-n', 0), SenseInfo('08000304-n', 0), SenseInfo('05623628-n', 0), SenseInfo('04330340-n', 0) ],
"_hands-off_a_1_rel" : [ SenseInfo('00039929-a', 0), SenseInfo('00039929-a', 0) ],
"_on+all+fours_a_1_rel" : [  ],
"_grab_v_for_rel" : [ SenseInfo('01439190-v', 27), SenseInfo('02304648-v', 4), SenseInfo('02099239-v', 1), SenseInfo('02358217-v', 0), SenseInfo('01350283-v', 0), SenseInfo('00737476-v', 0) ],
"_horseride_n_1_rel" : [  ],
"_cumulous_a_1_rel" : [ SenseInfo('00539207-a', 0) ],
"_vibrate_v_1_rel" : [ SenseInfo('01891249-v', 1), SenseInfo('01878063-v', 1), SenseInfo('02706046-v', 0), SenseInfo('02175958-v', 0), SenseInfo('01796346-v', 0) ],
"_afloat_a_1_rel" : [ SenseInfo('01910652-a', 1), SenseInfo('00076921-a', 0), SenseInfo('01083754-a', 0) ],
"_cheer_v_on_rel" : [ SenseInfo('01817938-v', 1), SenseInfo('00858568-v', 1), SenseInfo('00859325-v', 0), SenseInfo('00859153-v', 0), SenseInfo('00858781-v', 0) ],
"_sufferer_n_1_rel" : [ SenseInfo('10595647-n', 2), SenseInfo('10296618-n', 0) ],
"_full-frontal_a_1_rel" : [  ],
"_northern_a_1_rel" : [ SenseInfo('01605753-a', 15), SenseInfo('01601297-a', 6), SenseInfo('01601069-a', 1), SenseInfo('01604226-a', 0), SenseInfo('01605753-a', 15), SenseInfo('01601297-a', 6), SenseInfo('01601069-a', 1), SenseInfo('01604226-a', 0) ],
"_contact_v_1_rel" : [ SenseInfo('00743344-v', 10), SenseInfo('01205696-v', 0) ],
"_add_v_to_rel" : [ SenseInfo('00182406-v', 116), SenseInfo('01027174-v', 68), SenseInfo('02324478-v', 15), SenseInfo('00640828-v', 3), SenseInfo('00949288-v', 1), SenseInfo('02745172-v', 0), SenseInfo('00182406-v', 116), SenseInfo('01027174-v', 68), SenseInfo('02324478-v', 15), SenseInfo('00640828-v', 3), SenseInfo('00949288-v', 1), SenseInfo('02745172-v', 0), SenseInfo('00182406-v', 116), SenseInfo('01027174-v', 68), SenseInfo('02324478-v', 15), SenseInfo('00640828-v', 3), SenseInfo('00949288-v', 1), SenseInfo('02745172-v', 0) ],
"_neutralist_n_1_rel" : [ SenseInfo('10355306-n', 5) ],
"_shoehorn_n_1_rel" : [ SenseInfo('04200537-n', 0) ],
"_indifferent_a_to_rel" : [ SenseInfo('01342949-a', 4), SenseInfo('00546452-a', 3), SenseInfo('01194328-a', 2), SenseInfo('01280576-a', 1), SenseInfo('02340710-a', 0), SenseInfo('01930004-a', 0), SenseInfo('01724072-a', 0), SenseInfo('01723856-a', 0), SenseInfo('01674604-a', 0), SenseInfo('01532454-a', 0), SenseInfo('01342949-a', 4), SenseInfo('00546452-a', 3), SenseInfo('01194328-a', 2), SenseInfo('01280576-a', 1), SenseInfo('02340710-a', 0), SenseInfo('01930004-a', 0), SenseInfo('01724072-a', 0), SenseInfo('01723856-a', 0), SenseInfo('01674604-a', 0), SenseInfo('01532454-a', 0) ],
"_a+good+deal_x_rel" : [ SenseInfo('00059171-r', 0) ],
"_gypsy_n_1_rel" : [ SenseInfo('10217831-n', 0), SenseInfo('10154186-n', 0), SenseInfo('06969822-n', 0) ],
"_some_q_indiv_rel" : [  ],
"_sow_n_1_rel" : [ SenseInfo('02396088-n', 0) ],
"_barkeeper_n_1_rel" : [ SenseInfo('09841188-n', 0) ],
"_ninepins_n_1_rel" : [ SenseInfo('03825271-n', 0) ],
"_winch_v_up_rel" : [ SenseInfo('01592306-v', 0) ],
"_crocus_n_1_rel" : [ SenseInfo('12416423-n', 0) ],
"_experienced_a_in_rel" : [ SenseInfo('00935500-a', 10) ],
"_get_v_down-to_rel" : [ SenseInfo('02210855-v', 235), SenseInfo('00149583-v', 157), SenseInfo('00120796-v', 82), SenseInfo('00522751-v', 64), SenseInfo('02005948-v', 58), SenseInfo('01433294-v', 45), SenseInfo('02108026-v', 36), SenseInfo('01153947-v', 14), SenseInfo('02355596-v', 9), SenseInfo('00770437-v', 7), SenseInfo('01215421-v', 4), SenseInfo('00094460-v', 4), SenseInfo('00087736-v', 4), SenseInfo('01066036-v', 3), SenseInfo('00120316-v', 3), SenseInfo('01026975-v', 2), SenseInfo('00589904-v', 2), SenseInfo('01505958-v', 1), SenseInfo('01401115-v', 1), SenseInfo('00639849-v', 1), SenseInfo('02359340-v', 0), SenseInfo('02208265-v', 0), SenseInfo('02189398-v', 0), SenseInfo('02109645-v', 0), SenseInfo('02108654-v', 0), SenseInfo('02010864-v', 0), SenseInfo('02006573-v', 0), SenseInfo('01771194-v', 0), SenseInfo('01771039-v', 0), SenseInfo('01738107-v', 0), SenseInfo('01643297-v', 0), SenseInfo('01565211-v', 0), SenseInfo('00622384-v', 0), SenseInfo('00345761-v', 0), SenseInfo('00065639-v', 0), SenseInfo('00054628-v', 0) ],
"_hoard_n_1_rel" : [ SenseInfo('13366912-n', 0) ],
"_radio_v_1_rel" : [ SenseInfo('01007495-v', 2) ],
"_alarm_v_1_rel" : [ SenseInfo('01782650-v', 2), SenseInfo('00872414-v', 1), SenseInfo('01782650-v', 2), SenseInfo('00872414-v', 1), SenseInfo('01782650-v', 2), SenseInfo('00872414-v', 1), SenseInfo('01782650-v', 2), SenseInfo('00872414-v', 1), SenseInfo('01782650-v', 2), SenseInfo('00872414-v', 1) ],
"_sneeze_n_1_rel" : [ SenseInfo('14314850-n', 0) ],
"_suppress_v_1_rel" : [ SenseInfo('00462092-v', 4), SenseInfo('02424652-v', 1), SenseInfo('02423762-v', 1), SenseInfo('00612841-v', 0), SenseInfo('00153964-v', 0) ],
"_quibble_n_1_rel" : [ SenseInfo('06761798-n', 0) ],
"_come_p_temp_rel" : [ SenseInfo('01849221-v', 276), SenseInfo('02005948-v', 235), SenseInfo('00341917-v', 147), SenseInfo('00542120-v', 41), SenseInfo('02625339-v', 40), SenseInfo('00342812-v', 11), SenseInfo('02743921-v', 9), SenseInfo('02743214-v', 7), SenseInfo('02686805-v', 6), SenseInfo('02743565-v', 3), SenseInfo('01839690-v', 3), SenseInfo('02729963-v', 2), SenseInfo('00344886-v', 2), SenseInfo('02645007-v', 1), SenseInfo('02627363-v', 1), SenseInfo('02006709-v', 1), SenseInfo('00723349-v', 1), SenseInfo('05404336-n', 0), SenseInfo('02737187-v', 0), SenseInfo('02617567-v', 0), SenseInfo('02197360-v', 0), SenseInfo('00659984-v', 0) ],
"_impassioned_a_1_rel" : [ SenseInfo('01726235-a', 4) ],
"_egalitarianism_n_1_rel" : [ SenseInfo('05967588-n', 2) ],
"_bushel_n_1_rel" : [ SenseInfo('13620871-n', 3), SenseInfo('13622591-n', 0) ],
"_arbor_n_1_rel" : [ SenseInfo('13107891-n', 0), SenseInfo('04277493-n', 0), SenseInfo('02732827-n', 0) ],
"_retirement_n_of_rel" : [ SenseInfo('13954118-n', 9), SenseInfo('00212205-n', 1), SenseInfo('00054652-n', 0) ],
"_sixth_n_of_rel" : [ SenseInfo('13847402-n', 0), SenseInfo('13737952-n', 0), SenseInfo('06859925-n', 0), SenseInfo('13847402-n', 0), SenseInfo('13737952-n', 0), SenseInfo('06859925-n', 0), SenseInfo('13847402-n', 0), SenseInfo('13737952-n', 0), SenseInfo('06859925-n', 0) ],
"_top-down_a_1_rel" : [ SenseInfo('02443155-a', 0), SenseInfo('02443155-a', 0) ],
"_digress_v_1_rel" : [ SenseInfo('00780575-v', 1), SenseInfo('02066304-v', 0) ],
"_whale+watch_v_1_rel" : [  ],
"_shrink_v_cause_rel" : [ SenseInfo('00241689-v', 3), SenseInfo('02061069-v', 2), SenseInfo('00241038-v', 2), SenseInfo('00240571-v', 1), SenseInfo('00152558-v', 0) ],
"_dealings_n_1_rel" : [ SenseInfo('01135372-n', 1), SenseInfo('01106808-n', 0), SenseInfo('01135372-n', 1), SenseInfo('01106808-n', 0) ],
"_underline_v_1_rel" : [ SenseInfo('01014609-v', 6), SenseInfo('01004235-v', 0) ],
"_immature_a_1_rel" : [ SenseInfo('01492394-a', 2), SenseInfo('01646941-a', 0), SenseInfo('01493897-a', 0), SenseInfo('01489722-a', 0), SenseInfo('01096471-a', 0) ],
"_classical_n_1_rel" : [ SenseInfo('07025900-n', 0) ],
"_overestimate_v_1_rel" : [ SenseInfo('00672017-v', 1), SenseInfo('00695475-v', 0), SenseInfo('00672017-v', 1), SenseInfo('00695475-v', 0) ],
"_up+until_p_rel" : [  ],
"_anticipation_n_of_rel" : [ SenseInfo('07511080-n', 4), SenseInfo('05951323-n', 4), SenseInfo('05775081-n', 2), SenseInfo('14486122-n', 0), SenseInfo('07511080-n', 4), SenseInfo('05951323-n', 4), SenseInfo('05775081-n', 2), SenseInfo('14486122-n', 0), SenseInfo('07511080-n', 4), SenseInfo('05951323-n', 4), SenseInfo('05775081-n', 2), SenseInfo('14486122-n', 0) ],
"_solemnize_v_1_rel" : [ SenseInfo('02579247-v', 0), SenseInfo('02489748-v', 0), SenseInfo('00579565-v', 0) ],
"_detract_v_from_rel" : [ SenseInfo('00532115-v', 1) ],
"_crumple_v_1_rel" : [ SenseInfo('02041877-v', 1), SenseInfo('01279186-v', 0), SenseInfo('01278817-v', 0), SenseInfo('00564857-v', 0) ],
"_smooch_n_1_rel" : [ SenseInfo('00138599-n', 0) ],
"_clutter_v_1_rel" : [ SenseInfo('00181875-v', 0) ],
"_open_v_up_rel" : [ SenseInfo('01346003-v', 66), SenseInfo('02426171-v', 45), SenseInfo('01346804-v', 17), SenseInfo('02425462-v', 14), SenseInfo('01579813-v', 4), SenseInfo('00539936-v', 4), SenseInfo('00540101-v', 2), SenseInfo('02744651-v', 1), SenseInfo('01077887-v', 1), SenseInfo('02358034-v', 0), SenseInfo('02140630-v', 0), SenseInfo('01346003-v', 66), SenseInfo('02426171-v', 45), SenseInfo('01346804-v', 17), SenseInfo('02425462-v', 14), SenseInfo('01579813-v', 4), SenseInfo('00539936-v', 4), SenseInfo('00540101-v', 2), SenseInfo('02744651-v', 1), SenseInfo('01077887-v', 1), SenseInfo('02358034-v', 0), SenseInfo('02140630-v', 0) ],
"_as+best_x_subord_rel" : [  ],
"_unpack_v_1_rel" : [ SenseInfo('01485513-v', 1), SenseInfo('01485513-v', 1) ],
"_wipe_v_out_rel" : [ SenseInfo('01392237-v', 17), SenseInfo('01392237-v', 17) ],
"_block_v_1_rel" : [ SenseInfo('01478002-v', 7), SenseInfo('02557199-v', 3), SenseInfo('02559752-v', 1), SenseInfo('01057034-v', 1), SenseInfo('02444297-v', 0), SenseInfo('02198423-v', 0), SenseInfo('02145543-v', 0), SenseInfo('01531492-v', 0), SenseInfo('01479333-v', 0), SenseInfo('01476483-v', 0), SenseInfo('01217924-v', 0), SenseInfo('01147060-v', 0), SenseInfo('00609100-v', 0), SenseInfo('00477528-v', 0), SenseInfo('00477382-v', 0), SenseInfo('00269423-v', 0) ],
"_impressionist_n_1_rel" : [ SenseInfo('10201956-n', 1) ],
"_morrow_n_1_rel" : [ SenseInfo('15156311-n', 2) ],
"_manoeuvre_n_1_rel" : [ SenseInfo('05905152-n', 0), SenseInfo('00959992-n', 0), SenseInfo('00556313-n', 0), SenseInfo('00168237-n', 0), SenseInfo('00059552-n', 0) ],
"_cutlet_n_1_rel" : [ SenseInfo('07654886-n', 0) ],
"_holster_n_1_rel" : [ SenseInfo('03527444-n', 5), SenseInfo('03527565-n', 0) ],
"_instep_n_1_rel" : [ SenseInfo('05576950-n', 0), SenseInfo('03574243-n', 0) ],
"_microgram_n_1_rel" : [ SenseInfo('13722929-n', 0), SenseInfo('13722929-n', 0) ],
"_crack_n_1_rel" : [ SenseInfo('09258715-n', 3), SenseInfo('03416329-n', 2), SenseInfo('13907272-n', 1), SenseInfo('07381423-n', 1), SenseInfo('14485673-n', 0), SenseInfo('06767777-n', 0), SenseInfo('04693096-n', 0), SenseInfo('03125184-n', 0), SenseInfo('00787061-n', 0), SenseInfo('00376994-n', 0) ],
"_carry_v_sound_rel" : [ SenseInfo('01449974-v', 72), SenseInfo('02717102-v', 36), SenseInfo('02079933-v', 8), SenseInfo('01061017-v', 8), SenseInfo('01218084-v', 6), SenseInfo('01601234-v', 5), SenseInfo('02700867-v', 4), SenseInfo('02561168-v', 4), SenseInfo('00235110-v', 3), SenseInfo('02636325-v', 2), SenseInfo('01101416-v', 2), SenseInfo('00738951-v', 2), SenseInfo('02518161-v', 1), SenseInfo('02285392-v', 1), SenseInfo('01746359-v', 1), SenseInfo('01408760-v', 1), SenseInfo('01061320-v', 1), SenseInfo('02746735-v', 0), SenseInfo('02741357-v', 0), SenseInfo('02682954-v', 0), SenseInfo('02636516-v', 0), SenseInfo('02630734-v', 0), SenseInfo('02586121-v', 0), SenseInfo('02556537-v', 0), SenseInfo('02555684-v', 0), SenseInfo('02359228-v', 0), SenseInfo('02303878-v', 0), SenseInfo('02233195-v', 0), SenseInfo('02012725-v', 0), SenseInfo('02001699-v', 0), SenseInfo('01740320-v', 0), SenseInfo('01241881-v', 0), SenseInfo('01205153-v', 0), SenseInfo('01203074-v', 0), SenseInfo('01123609-v', 0), SenseInfo('01123415-v', 0), SenseInfo('01101571-v', 0), SenseInfo('01100672-v', 0), SenseInfo('01049606-v', 0), SenseInfo('00059019-v', 0) ],
"_psychic_a_1_rel" : [ SenseInfo('01780740-a', 0), SenseInfo('01599898-a', 0) ],
"_telephony_n_1_rel" : [ SenseInfo('06272290-n', 0) ],
"_greyish_a_1_rel" : [ SenseInfo('00389310-a', 0) ],
"_solvent_a_1_rel" : [ SenseInfo('02026312-a', 0) ],
"_intangible_n_1_rel" : [ SenseInfo('13332670-n', 1) ],
"_as+much+as_x_deg_rel" : [  ],
"_occupy_v_1_rel" : [ SenseInfo('02415831-v', 8), SenseInfo('02648639-v', 7), SenseInfo('02649042-v', 3), SenseInfo('02678438-v', 2), SenseInfo('01126360-v', 2), SenseInfo('02267989-v', 1), SenseInfo('00600370-v', 1), SenseInfo('02394183-v', 0) ],
"_dismay_n_1_rel" : [ SenseInfo('07542675-n', 4), SenseInfo('07519773-n', 2), SenseInfo('07542675-n', 4), SenseInfo('07519773-n', 2) ],
"_cleaning_n_1_rel" : [ SenseInfo('00251013-n', 13) ],
"_prune_n_1_rel" : [ SenseInfo('07752602-n', 0) ],
"_a+half_x_deg_rel" : [  ],
"_tilt_v_1_rel" : [ SenseInfo('02038357-v', 9), SenseInfo('01884577-v', 1), SenseInfo('01884974-v', 0), SenseInfo('01122906-v', 0) ],
"_tighten_v_1_rel" : [ SenseInfo('00420132-v', 8), SenseInfo('00419950-v', 1), SenseInfo('00418765-v', 1), SenseInfo('00233203-v', 0) ],
"_gull_n_1_rel" : [ SenseInfo('09921409-n', 0), SenseInfo('02041246-n', 0) ],
"_unequivocal_a_1_rel" : [ SenseInfo('00896555-a', 0), SenseInfo('00940969-a', 0), SenseInfo('00896555-a', 0), SenseInfo('00940969-a', 0), SenseInfo('00896555-a', 0), SenseInfo('00940969-a', 0) ],
"_reiterate_v_to_rel" : [ SenseInfo('00958334-v', 5), SenseInfo('00958334-v', 5) ],
"_desperate_a_for_rel" : [ SenseInfo('01229826-a', 7), SenseInfo('01990507-a', 3), SenseInfo('02059626-a', 1), SenseInfo('00263463-a', 1), SenseInfo('00713351-a', 0), SenseInfo('00651451-a', 0), SenseInfo('01229826-a', 7), SenseInfo('01990507-a', 3), SenseInfo('02059626-a', 1), SenseInfo('00263463-a', 1), SenseInfo('00713351-a', 0), SenseInfo('00651451-a', 0), SenseInfo('01229826-a', 7), SenseInfo('01990507-a', 3), SenseInfo('02059626-a', 1), SenseInfo('00263463-a', 1), SenseInfo('00713351-a', 0), SenseInfo('00651451-a', 0) ],
"_squat_a_1_rel" : [ SenseInfo('02386962-a', 3), SenseInfo('01207697-a', 2) ],
"_rib_n_1_rel" : [ SenseInfo('04087126-n', 4), SenseInfo('05279026-n', 2), SenseInfo('07656741-n', 0), SenseInfo('06767693-n', 0), SenseInfo('05235879-n', 0), SenseInfo('04087290-n', 0) ],
"_after-market_a_1_rel" : [  ],
"_all-fire_a_1_rel" : [  ],
"_immune_a_1_rel" : [ SenseInfo('02745862-a', 0), SenseInfo('02365900-a', 0), SenseInfo('02363614-a', 0), SenseInfo('00072281-a', 0) ],
"_clothing_n_1_rel" : [ SenseInfo('03051540-n', 9) ],
"_blogger_n_1_rel" : [ SenseInfo('09860415-n', 0) ],
"_imagine_v_as_rel" : [ SenseInfo('01636397-v', 66), SenseInfo('00631737-v', 11), SenseInfo('01636397-v', 66), SenseInfo('00631737-v', 11) ],
"_brownie_n_1_rel" : [ SenseInfo('09877370-n', 0), SenseInfo('09540739-n', 0), SenseInfo('07636271-n', 0) ],
"_gospeler_n_1_rel" : [ SenseInfo('10067011-n', 1) ],
"_human_n_1_rel" : [ SenseInfo('02472293-n', 5) ],
"_garrison_n_1_rel" : [ SenseInfo('03420559-n', 2), SenseInfo('10991583-n', 0), SenseInfo('08398036-n', 0), SenseInfo('03420559-n', 2), SenseInfo('10991583-n', 0), SenseInfo('08398036-n', 0) ],
"_lettuce_n_1_rel" : [ SenseInfo('13385216-n', 0), SenseInfo('11986306-n', 0), SenseInfo('07723559-n', 0) ],
"_mark_v_1_rel" : [ SenseInfo('01588493-v', 13), SenseInfo('00921738-v', 13), SenseInfo('00651991-v', 13), SenseInfo('00612612-v', 9), SenseInfo('00508032-v', 5), SenseInfo('02508245-v', 2), SenseInfo('02118476-v', 2), SenseInfo('01551195-v', 1), SenseInfo('01275762-v', 0), SenseInfo('01062395-v', 0), SenseInfo('01004062-v', 0), SenseInfo('00800750-v', 0), SenseInfo('00662182-v', 0), SenseInfo('00657728-v', 0), SenseInfo('00190023-v', 0), SenseInfo('01588493-v', 13), SenseInfo('00921738-v', 13), SenseInfo('00651991-v', 13), SenseInfo('00612612-v', 9), SenseInfo('00508032-v', 5), SenseInfo('02508245-v', 2), SenseInfo('02118476-v', 2), SenseInfo('01551195-v', 1), SenseInfo('01275762-v', 0), SenseInfo('01062395-v', 0), SenseInfo('01004062-v', 0), SenseInfo('00800750-v', 0), SenseInfo('00662182-v', 0), SenseInfo('00657728-v', 0), SenseInfo('00190023-v', 0) ],
"_further_x_deg_rel" : [ SenseInfo('00029985-r', 33), SenseInfo('00030443-r', 10), SenseInfo('02554422-v', 7), SenseInfo('00443988-a', 2), SenseInfo('02554922-v', 2), SenseInfo('00029639-r', 1) ],
"_plunge_n_of_rel" : [ SenseInfo('00442847-n', 1), SenseInfo('07434209-n', 0) ],
"_restaurant_n_1_rel" : [ SenseInfo('04081281-n', 7), SenseInfo('04081281-n', 7) ],
"_far+from_a_rel" : [  ],
"_landlord_n_1_rel" : [ SenseInfo('10245236-n', 3) ],
"_tone_n_of_rel" : [ SenseInfo('07082573-n', 24), SenseInfo('04986883-n', 22), SenseInfo('04987620-n', 11), SenseInfo('14526182-n', 5), SenseInfo('04959230-n', 2), SenseInfo('06865345-n', 1), SenseInfo('05719605-n', 1), SenseInfo('14544672-n', 0), SenseInfo('06859056-n', 0), SenseInfo('05211451-n', 0) ],
"_all+at+once_a_1_rel" : [  ],
"_inhibition_n_1_rel" : [ SenseInfo('01070892-n', 3), SenseInfo('04884072-n', 2), SenseInfo('13500214-n', 0), SenseInfo('00201923-n', 0) ],
"_case_v_in_rel" : [ SenseInfo('02165982-v', 1), SenseInfo('01486312-v', 0) ],
"_electoral_a_1_rel" : [ SenseInfo('02717538-a', 11), SenseInfo('00846219-a', 0) ],
"_curate_n_1_rel" : [ SenseInfo('09983572-n', 0) ],
"_mattress_n_1_rel" : [ SenseInfo('03731164-n', 0) ],
"_sporting_a_1_rel" : [ SenseInfo('00956733-a', 5), SenseInfo('02801839-a', 3), SenseInfo('00066565-a', 1), SenseInfo('01297946-a', 0) ],
"_increasingly_x_deg_rel" : [ SenseInfo('00059854-r', 16) ],
"_if+need+be_a_1_rel" : [  ],
"_claim_n_1_rel" : [ SenseInfo('06729864-n', 26), SenseInfo('06730563-n', 11), SenseInfo('01061945-n', 6), SenseInfo('05175904-n', 3), SenseInfo('05181199-n', 2), SenseInfo('07192129-n', 0), SenseInfo('06729864-n', 26), SenseInfo('06730563-n', 11), SenseInfo('01061945-n', 6), SenseInfo('05175904-n', 3), SenseInfo('05181199-n', 2), SenseInfo('07192129-n', 0) ],
"_gallery_n_of_rel" : [ SenseInfo('08222203-n', 0), SenseInfo('04527648-n', 0), SenseInfo('03412058-n', 0), SenseInfo('03411927-n', 0), SenseInfo('03411762-n', 0), SenseInfo('03411544-n', 0), SenseInfo('03239399-n', 0) ],
"_swimmer_n_1_rel" : [ SenseInfo('10683349-n', 0), SenseInfo('10683126-n', 0) ],
"_make_v_i_rel" : [ SenseInfo('02560585-v', 508), SenseInfo('00120316-v', 459), SenseInfo('01617192-v', 243), SenseInfo('00770437-v', 85), SenseInfo('01645601-v', 78), SenseInfo('01621555-v', 52), SenseInfo('00730758-v', 33), SenseInfo('01646075-v', 17), SenseInfo('01640207-v', 16), SenseInfo('02289295-v', 14), SenseInfo('01619014-v', 14), SenseInfo('02621395-v', 12), SenseInfo('02022162-v', 12), SenseInfo('02674708-v', 10), SenseInfo('01653873-v', 9), SenseInfo('01755816-v', 8), SenseInfo('01654628-v', 5), SenseInfo('00556855-v', 5), SenseInfo('00012267-v', 5), SenseInfo('02396716-v', 4), SenseInfo('02355596-v', 4), SenseInfo('02020590-v', 4), SenseInfo('00665476-v', 4), SenseInfo('02582921-v', 3), SenseInfo('02598483-v', 2), SenseInfo('01733477-v', 2), SenseInfo('00276068-v', 2), SenseInfo('02075857-v', 1), SenseInfo('00074038-v', 1), SenseInfo('02748759-v', 0), SenseInfo('02748627-v', 0), SenseInfo('02745332-v', 0), SenseInfo('02665124-v', 0), SenseInfo('02621133-v', 0), SenseInfo('02134050-v', 0), SenseInfo('02051031-v', 0), SenseInfo('02021532-v', 0), SenseInfo('01755504-v', 0), SenseInfo('01664172-v', 0), SenseInfo('01428578-v', 0), SenseInfo('00891038-v', 0), SenseInfo('00838524-v', 0), SenseInfo('00698256-v', 0), SenseInfo('00698104-v', 0), SenseInfo('00562182-v', 0), SenseInfo('00562067-v', 0), SenseInfo('00545953-v', 0), SenseInfo('00107369-v', 0), SenseInfo('00072012-v', 0) ],
"_incline_n_1_rel" : [ SenseInfo('09437454-n', 1), SenseInfo('04051549-n', 1) ],
"_calumny_n_1_rel" : [ SenseInfo('06719579-n', 1), SenseInfo('01220336-n', 0) ],
"_gullible_a_1_rel" : [ SenseInfo('02272485-a', 1), SenseInfo('00163315-a', 0) ],
"_unintelligible_a_1_rel" : [ SenseInfo('01337121-a', 0), SenseInfo('00535293-a', 0), SenseInfo('01337121-a', 0), SenseInfo('00535293-a', 0), SenseInfo('01337121-a', 0), SenseInfo('00535293-a', 0) ],
"_assemblage_n_1_rel" : [ SenseInfo('07975026-n', 2), SenseInfo('03533486-n', 1), SenseInfo('01229938-n', 1), SenseInfo('07951464-n', 0) ],
"_work_v_up_rel" : [ SenseInfo('02413480-v', 74), SenseInfo('02410855-v', 62), SenseInfo('02525447-v', 32), SenseInfo('01525666-v', 20), SenseInfo('01668603-v', 9), SenseInfo('00100551-v', 9), SenseInfo('02051031-v', 5), SenseInfo('02594979-v', 4), SenseInfo('02373015-v', 3), SenseInfo('01852468-v', 3), SenseInfo('01629589-v', 3), SenseInfo('02407987-v', 2), SenseInfo('01741446-v', 2), SenseInfo('02751271-v', 0), SenseInfo('02536557-v', 0), SenseInfo('02444159-v', 0), SenseInfo('02436963-v', 0), SenseInfo('02116980-v', 0), SenseInfo('01817574-v', 0), SenseInfo('01659248-v', 0), SenseInfo('01541231-v', 0), SenseInfo('01235355-v', 0), SenseInfo('01162754-v', 0), SenseInfo('00634906-v', 0), SenseInfo('00458754-v', 0), SenseInfo('00458471-v', 0), SenseInfo('00150096-v', 0) ],
"_slice_v_off_rel" : [ SenseInfo('01559055-v', 2), SenseInfo('01408958-v', 1), SenseInfo('01254477-v', 1), SenseInfo('01124389-v', 1) ],
"_rust_n_1_rel" : [ SenseInfo('14889479-n', 0), SenseInfo('14277655-n', 0), SenseInfo('13552270-n', 0), SenseInfo('13063269-n', 0) ],
"_confederate_a_1_rel" : [ SenseInfo('01606942-a', 2), SenseInfo('02476485-a', 0) ],
"_grimace_n_1_rel" : [ SenseInfo('06877578-n', 0) ],
"_mollusk_n_1_rel" : [ SenseInfo('01940736-n', 0) ],
"_batsman_n_1_rel" : [ SenseInfo('09843956-n', 0) ],
"_incubation_n_of_rel" : [ SenseInfo('00658796-n', 1), SenseInfo('15287578-n', 0), SenseInfo('13441812-n', 0) ],
"_subconscious_a_1_rel" : [ SenseInfo('00573093-a', 1), SenseInfo('00573093-a', 1) ],
"_beset_v_with_rel" : [ SenseInfo('01789514-v', 5), SenseInfo('01126700-v', 2), SenseInfo('01517355-v', 0), SenseInfo('01789514-v', 5), SenseInfo('01126700-v', 2), SenseInfo('01517355-v', 0) ],
"_artful_a_1_rel" : [ SenseInfo('01310685-a', 0), SenseInfo('00147734-a', 0) ],
"_gooseberry_n_1_rel" : [ SenseInfo('12806015-n', 0), SenseInfo('07744430-n', 0) ],
"_swish_v_1_rel" : [ SenseInfo('02188198-v', 1) ],
"_precipitate_v_1_rel" : [ SenseInfo('01644339-v', 4), SenseInfo('00474994-v', 4), SenseInfo('02756821-v', 0), SenseInfo('01971750-v', 0), SenseInfo('01507596-v', 0) ],
"_fjord_n_1_rel" : [ SenseInfo('09281104-n', 0), SenseInfo('09281104-n', 0) ],
"_beef_v_up_rel" : [ SenseInfo('00910973-v', 0) ],
"_unaware_a_of_rel" : [ SenseInfo('00191603-a', 8), SenseInfo('00191603-a', 8) ],
"_circulate_v_1_rel" : [ SenseInfo('00969873-v', 2), SenseInfo('00968211-v', 2), SenseInfo('02043190-v', 1), SenseInfo('02042404-v', 1), SenseInfo('02044278-v', 0), SenseInfo('02042843-v', 0), SenseInfo('02042237-v', 0), SenseInfo('00270005-v', 0), SenseInfo('00969873-v', 2), SenseInfo('00968211-v', 2), SenseInfo('02043190-v', 1), SenseInfo('02042404-v', 1), SenseInfo('02044278-v', 0), SenseInfo('02042843-v', 0), SenseInfo('02042237-v', 0), SenseInfo('00270005-v', 0) ],
"_contraceptive_n_1_rel" : [ SenseInfo('03096593-n', 4) ],
"_clown_v_1_rel" : [ SenseInfo('00105778-v', 0) ],
"_meter_v_1_rel" : [ SenseInfo('00490586-v', 1), SenseInfo('01273974-v', 0) ],
"_critic_n_of_rel" : [ SenseInfo('09979589-n', 6), SenseInfo('09979321-n', 2), SenseInfo('09979072-n', 0) ],
"_chief+of+staff_n_1_rel" : [ SenseInfo('09917214-n', 0) ],
"_quilt_v_1_rel" : [ SenseInfo('01667449-v', 0), SenseInfo('01667304-v', 0) ],
"_dalesman_n_1_rel" : [ SenseInfo('09988597-n', 0) ],
"_i+c+e_n_1_rel" : [ SenseInfo('14915184-n', 22), SenseInfo('09308398-n', 1), SenseInfo('13372123-n', 0), SenseInfo('07620822-n', 0), SenseInfo('07614198-n', 0), SenseInfo('03754295-n', 0), SenseInfo('03579982-n', 0), SenseInfo('03558176-n', 0) ],
"_austrian_n_1_rel" : [ SenseInfo('09691604-n', 0) ],
"_in+general_a_2_rel" : [  ],
"_avantgarde_a_1_rel" : [  ],
"_coloring_n_1_rel" : [ SenseInfo('07567139-n', 0), SenseInfo('04956594-n', 0), SenseInfo('00274941-n', 0), SenseInfo('07567139-n', 0), SenseInfo('04956594-n', 0), SenseInfo('00274941-n', 0) ],
"_whine_v_1_rel" : [ SenseInfo('01839280-v', 1), SenseInfo('01042531-v', 1), SenseInfo('02171664-v', 0), SenseInfo('00907930-v', 0), SenseInfo('01839280-v', 1), SenseInfo('01042531-v', 1), SenseInfo('02171664-v', 0), SenseInfo('00907930-v', 0) ],
"_beautiful_a_1_rel" : [ SenseInfo('00217728-a', 25), SenseInfo('01800764-a', 0), SenseInfo('00217728-a', 25), SenseInfo('01800764-a', 0), SenseInfo('00217728-a', 25), SenseInfo('01800764-a', 0) ],
"_prestigious_a_1_rel" : [ SenseInfo('01982957-a', 0), SenseInfo('01830703-a', 0) ],
"_bracelet_n_1_rel" : [ SenseInfo('04556204-n', 0), SenseInfo('02887970-n', 0) ],
"_climatic_a_1_rel" : [ SenseInfo('03055374-a', 0) ],
"_better-off_n_1_rel" : [  ],
"_equidistant_a_1_rel" : [ SenseInfo('00890985-a', 0) ],
"_debtor_n_1_rel" : [ SenseInfo('09997622-n', 0) ],
"_undesirable_a_to_rel" : [ SenseInfo('00733905-a', 2), SenseInfo('00853473-a', 0), SenseInfo('00733905-a', 2), SenseInfo('00853473-a', 0) ],
"_ballot_v_1_rel" : [ SenseInfo('02463141-v', 0) ],
"_esprit+de+corps_n_1_rel" : [ SenseInfo('04625129-n', 3) ],
"_annul_v_1_rel" : [ SenseInfo('02478059-v', 0), SenseInfo('00799798-v', 0) ],
"_precision_n_1_rel" : [ SenseInfo('04803880-n', 9) ],
"_super_a_1_rel" : [ SenseInfo('02341864-a', 3), SenseInfo('00528761-a', 1), SenseInfo('01390588-a', 0) ],
"_endure_v_1_rel" : [ SenseInfo('00668099-v', 6), SenseInfo('02707251-v', 4), SenseInfo('02618149-v', 4), SenseInfo('02109190-v', 2), SenseInfo('02705132-v', 0), SenseInfo('02704928-v', 0), SenseInfo('02647497-v', 0), SenseInfo('00668099-v', 6), SenseInfo('02707251-v', 4), SenseInfo('02618149-v', 4), SenseInfo('02109190-v', 2), SenseInfo('02705132-v', 0), SenseInfo('02704928-v', 0), SenseInfo('02647497-v', 0) ],
"_available_a_for_rel" : [ SenseInfo('00183053-a', 91), SenseInfo('01062631-a', 0), SenseInfo('00777650-a', 0) ],
"_bearer_n_1_rel" : [ SenseInfo('09897696-n', 3), SenseInfo('10311243-n', 1), SenseInfo('10395073-n', 0), SenseInfo('10179911-n', 0) ],
"_visitation_n_1_rel" : [ SenseInfo('07372959-n', 0), SenseInfo('07316724-n', 0), SenseInfo('00652069-n', 0) ],
"_face+to+face_a_2_rel" : [ SenseInfo('01767975-a', 0), SenseInfo('01767975-a', 0), SenseInfo('01767975-a', 0), SenseInfo('01767975-a', 0), SenseInfo('01767975-a', 0), SenseInfo('01767975-a', 0) ],
"_quote_n_1_rel" : [ SenseInfo('06844199-n', 0), SenseInfo('06613056-n', 0) ],
"_paltry_a_1_rel" : [ SenseInfo('02502994-a', 0), SenseInfo('00107384-a', 0), SenseInfo('02502994-a', 0), SenseInfo('00107384-a', 0), SenseInfo('02502994-a', 0), SenseInfo('00107384-a', 0) ],
"_cooperate_v_1_rel" : [ SenseInfo('02416278-v', 20) ],
"_bread_n_1_rel" : [ SenseInfo('07679356-n', 3), SenseInfo('13385216-n', 0) ],
"_irreclaimable_a_1_rel" : [ SenseInfo('02514819-a', 0) ],
"_grass-roots_a_1_rel" : [ SenseInfo('01856686-a', 1), SenseInfo('00487327-a', 0), SenseInfo('01856686-a', 1), SenseInfo('00487327-a', 0), SenseInfo('01856686-a', 1), SenseInfo('00487327-a', 0) ],
"_more+than_x_deg_rel" : [ SenseInfo('01555133-a', 0) ],
"_achievement_n_of_rel" : [ SenseInfo('00035189-n', 39) ],
"_showery_a_1_rel" : [ SenseInfo('02550333-a', 0) ],
"_appeal_n_1_rel" : [ SenseInfo('07186828-n', 9), SenseInfo('04687333-n', 8), SenseInfo('01185611-n', 8), SenseInfo('06513764-n', 0), SenseInfo('07186828-n', 9), SenseInfo('04687333-n', 8), SenseInfo('01185611-n', 8), SenseInfo('06513764-n', 0), SenseInfo('07186828-n', 9), SenseInfo('04687333-n', 8), SenseInfo('01185611-n', 8), SenseInfo('06513764-n', 0), SenseInfo('07186828-n', 9), SenseInfo('04687333-n', 8), SenseInfo('01185611-n', 8), SenseInfo('06513764-n', 0), SenseInfo('07186828-n', 9), SenseInfo('04687333-n', 8), SenseInfo('01185611-n', 8), SenseInfo('06513764-n', 0) ],
"_interview_v_1_rel" : [ SenseInfo('00808855-v', 8), SenseInfo('00809248-v', 5), SenseInfo('00809453-v', 1) ],
"_open_n_1_rel" : [ SenseInfo('08632423-n', 1), SenseInfo('08613733-n', 1), SenseInfo('07465159-n', 0), SenseInfo('05612809-n', 0) ],
"_overheat_v_cause_rel" : [ SenseInfo('00370263-v', 1), SenseInfo('00372501-v', 0), SenseInfo('00370263-v', 1), SenseInfo('00372501-v', 0) ],
"_backward_a_1_rel" : [ SenseInfo('00201354-a', 2), SenseInfo('00204077-a', 0), SenseInfo('01840673-a', 0), SenseInfo('00810636-a', 0) ],
"_farther_x_deg_rel" : [ SenseInfo('00029985-r', 3), SenseInfo('00029639-r', 2), SenseInfo('00443490-a', 2), SenseInfo('00443988-a', 1) ],
"_forerunner_n_1_rel" : [ SenseInfo('09627117-n', 1), SenseInfo('06802571-n', 1), SenseInfo('13844923-n', 0) ],
"_flower_n_1_rel" : [ SenseInfo('11669921-n', 31), SenseInfo('11669335-n', 8), SenseInfo('15295045-n', 0) ],
"_exacting_a_1_rel" : [ SenseInfo('00985608-a', 0), SenseInfo('00711308-a', 0), SenseInfo('00710585-a', 0) ],
"_normal_a_1_rel" : [ SenseInfo('01593649-a', 77), SenseInfo('01599445-a', 1), SenseInfo('01598319-a', 0), SenseInfo('01720549-a', 0), SenseInfo('01593649-a', 77), SenseInfo('01599445-a', 1), SenseInfo('01598319-a', 0), SenseInfo('01720549-a', 0), SenseInfo('01593649-a', 77), SenseInfo('01599445-a', 1), SenseInfo('01598319-a', 0), SenseInfo('01720549-a', 0), SenseInfo('01593649-a', 77), SenseInfo('01599445-a', 1), SenseInfo('01598319-a', 0), SenseInfo('01720549-a', 0) ],
"_withhold_v_1_rel" : [ SenseInfo('02213690-v', 8), SenseInfo('02215001-v', 1) ],
"_on+the+contrary_a_1_rel" : [  ],
"_guttural_a_1_rel" : [ SenseInfo('00299313-a', 1), SenseInfo('02737461-a', 0) ],
"_prosody_n_1_rel" : [ SenseInfo('07083732-n', 1), SenseInfo('07093895-n', 0), SenseInfo('06170025-n', 0) ],
"_emphasize_v_1_rel" : [ SenseInfo('01013367-v', 26), SenseInfo('01014609-v', 1), SenseInfo('01013367-v', 26), SenseInfo('01014609-v', 1) ],
"_stable_n_1_rel" : [ SenseInfo('04294879-n', 3) ],
"_slip_v_on_rel" : [ SenseInfo('01888295-v', 11), SenseInfo('00189669-v', 7), SenseInfo('01870275-v', 6), SenseInfo('00204391-v', 4), SenseInfo('02076280-v', 2), SenseInfo('00617748-v', 1), SenseInfo('02231328-v', 0), SenseInfo('02105549-v', 0), SenseInfo('02076501-v', 0), SenseInfo('00608978-v', 0), SenseInfo('00465762-v', 0) ],
"_jocular_a_1_rel" : [ SenseInfo('01267076-a', 2) ],
"_drum_v_up_rel" : [ SenseInfo('02174830-v', 1), SenseInfo('01732532-v', 1), SenseInfo('00605783-v', 0) ],
"_year-ago_a_1_rel" : [  ],
"_unresolved_a_1_rel" : [ SenseInfo('02267164-a', 0), SenseInfo('02130821-a', 0), SenseInfo('01164561-a', 0), SenseInfo('02267164-a', 0), SenseInfo('02130821-a', 0), SenseInfo('01164561-a', 0) ],
"_bytecode_n_1_rel" : [  ],
"_hogshead_n_1_rel" : [ SenseInfo('13623205-n', 0), SenseInfo('03524976-n', 0) ],
"_charcoal_n_1_rel" : [ SenseInfo('14685296-n', 4), SenseInfo('03007824-n', 2), SenseInfo('04962240-n', 0), SenseInfo('03007955-n', 0) ],
"_know-it-all_n_1_rel" : [ SenseInfo('10240235-n', 0), SenseInfo('10240235-n', 0) ],
"_distribution_n_of_rel" : [ SenseInfo('05729036-n', 23), SenseInfo('05087297-n', 13), SenseInfo('01083077-n', 7), SenseInfo('01112885-n', 4) ],
"_videotape_n_1_rel" : [ SenseInfo('04534520-n', 0), SenseInfo('04534359-n', 0) ],
"_strip_v_away_rel" : [ SenseInfo('02314275-v', 7), SenseInfo('00049900-v', 2), SenseInfo('01263479-v', 1), SenseInfo('00488617-v', 1), SenseInfo('00194912-v', 1), SenseInfo('02344568-v', 0), SenseInfo('01608706-v', 0), SenseInfo('01263659-v', 0), SenseInfo('00194812-v', 0), SenseInfo('00194696-v', 0), SenseInfo('00194534-v', 0), SenseInfo('00194079-v', 0), SenseInfo('00177243-v', 0) ],
"_dial_v_1_rel" : [ SenseInfo('00790308-v', 3), SenseInfo('00676135-v', 0) ],
"_entrapment_n_1_rel" : [ SenseInfo('01199035-n', 0) ],
"_embarrassing_a_1_rel" : [ SenseInfo('00746047-a', 3), SenseInfo('01803335-a', 2), SenseInfo('00746047-a', 3), SenseInfo('01803335-a', 2) ],
"_lash_n_1_rel" : [ SenseInfo('05314919-n', 0), SenseInfo('03643907-n', 0), SenseInfo('00134574-n', 0) ],
"_cover_v_for_rel" : [ SenseInfo('01332730-v', 35), SenseInfo('01207951-v', 19), SenseInfo('02687916-v', 18), SenseInfo('02675935-v', 16), SenseInfo('01033527-v', 14), SenseInfo('02629793-v', 10), SenseInfo('01912159-v', 4), SenseInfo('00967098-v', 3), SenseInfo('01129201-v', 2), SenseInfo('02395000-v', 1), SenseInfo('02148369-v', 1), SenseInfo('01148296-v', 1), SenseInfo('00967455-v', 1), SenseInfo('00891216-v', 1), SenseInfo('02672859-v', 0), SenseInfo('02474446-v', 0), SenseInfo('02395194-v', 0), SenseInfo('02310674-v', 0), SenseInfo('02147109-v', 0), SenseInfo('01582200-v', 0), SenseInfo('01430447-v', 0), SenseInfo('01336635-v', 0), SenseInfo('01150010-v', 0), SenseInfo('01148580-v', 0), SenseInfo('00060185-v', 0), SenseInfo('00048633-v', 0) ],
"_conditioner_n_1_rel" : [ SenseInfo('00625551-n', 1), SenseInfo('09953178-n', 0), SenseInfo('03088020-n', 0) ],
"_absolutely_x_deg_rel" : [ SenseInfo('00008997-r', 13), SenseInfo('00007488-r', 0) ],
"_tourist+station_n_1_rel" : [  ],
"_tungsten_n_1_rel" : [ SenseInfo('14659512-n', 2) ],
"_lift_n_1_rel" : [ SenseInfo('01209487-n', 1), SenseInfo('11422277-n', 0), SenseInfo('07370671-n', 0), SenseInfo('07348399-n', 0), SenseInfo('04231693-n', 0), SenseInfo('03664514-n', 0), SenseInfo('03664374-n', 0), SenseInfo('03281145-n', 0), SenseInfo('00674158-n', 0), SenseInfo('00316594-n', 0), SenseInfo('00309276-n', 0), SenseInfo('00116376-n', 0) ],
"_mentality_n_1_rel" : [ SenseInfo('06195839-n', 1), SenseInfo('05618056-n', 1) ],
"_absurd_n_1_rel" : [ SenseInfo('13928191-n', 0) ],
"_southwestward_a_1_rel" : [ SenseInfo('01604146-a', 0), SenseInfo('01604146-a', 0) ],
"_fence_v_2_rel" : [ SenseInfo('01588134-v', 1), SenseInfo('02210754-v', 0), SenseInfo('01146918-v', 0), SenseInfo('01130607-v', 0), SenseInfo('00773432-v', 0) ],
"_octoroon_n_1_rel" : [ SenseInfo('09638722-n', 0) ],
"_megabit_n_1_rel" : [ SenseInfo('13628419-n', 0) ],
"_sturdy_a_1_rel" : [ SenseInfo('02038994-a', 9), SenseInfo('01025913-a', 0), SenseInfo('00707795-a', 0), SenseInfo('02038994-a', 9), SenseInfo('01025913-a', 0), SenseInfo('00707795-a', 0), SenseInfo('02038994-a', 9), SenseInfo('01025913-a', 0), SenseInfo('00707795-a', 0) ],
"_stork_n_1_rel" : [ SenseInfo('02002075-n', 0) ],
"_usher_v_in_rel" : [ SenseInfo('02000547-v', 2), SenseInfo('02000547-v', 2) ],
"_cauldron_n_1_rel" : [ SenseInfo('02939185-n', 0) ],
"_redden_v_1_rel" : [ SenseInfo('00103317-v', 1), SenseInfo('00534837-v', 0), SenseInfo('00289031-v', 0) ],
"_clutch_v_at_rel" : [ SenseInfo('01212572-v', 16), SenseInfo('01220303-v', 1), SenseInfo('00737656-v', 0) ],
"_zloty_n_1_rel" : [ SenseInfo('13710777-n', 1) ],
"_push_v_up_rel" : [ SenseInfo('01871979-v', 56), SenseInfo('00765977-v', 7), SenseInfo('00976653-v', 6), SenseInfo('02406916-v', 3), SenseInfo('01872645-v', 3), SenseInfo('02054864-v', 1), SenseInfo('02589576-v', 0), SenseInfo('02245555-v', 0), SenseInfo('01872877-v', 0), SenseInfo('01447632-v', 0) ],
"_subterfuge_n_1_rel" : [ SenseInfo('06760508-n', 1) ],
"_in+short_a_1_rel" : [  ],
"_doom_n_1_rel" : [ SenseInfo('07334206-n', 3) ],
"_graphics_n_1_rel" : [ SenseInfo('03453696-n', 0), SenseInfo('03453696-n', 0) ],
"_contribute_v_to_rel" : [ SenseInfo('02324478-v', 31), SenseInfo('02308741-v', 25), SenseInfo('02555908-v', 13), SenseInfo('02237782-v', 3), SenseInfo('02324478-v', 31), SenseInfo('02308741-v', 25), SenseInfo('02555908-v', 13), SenseInfo('02237782-v', 3) ],
"_ironworks_n_1_rel" : [ SenseInfo('03586911-n', 0) ],
"_foothill_n_1_rel" : [ SenseInfo('09283405-n', 0) ],
"_enhance_v_1_rel" : [ SenseInfo('00229605-v', 5), SenseInfo('00230033-v', 4) ],
"_airless_a_1_rel" : [ SenseInfo('02509484-a', 1) ],
"_fix_n_1_rel" : [ SenseInfo('14409489-n', 2), SenseInfo('00323262-n', 0), SenseInfo('00266806-n', 0), SenseInfo('00214148-n', 0), SenseInfo('00155487-n', 0) ],
"_pluck_v_out_rel" : [ SenseInfo('01592456-v', 3), SenseInfo('02322596-v', 0), SenseInfo('02319050-v', 0), SenseInfo('01452546-v', 0), SenseInfo('01384275-v', 0), SenseInfo('01382083-v', 0) ],
"_considerable_a_1_rel" : [ SenseInfo('00624026-a', 32), SenseInfo('00624026-a', 32) ],
"_pound_v_1_rel" : [ SenseInfo('01414626-v', 5), SenseInfo('01575146-v', 3), SenseInfo('01925548-v', 1), SenseInfo('01880113-v', 1), SenseInfo('01563996-v', 0), SenseInfo('01302365-v', 0), SenseInfo('01302183-v', 0), SenseInfo('00331514-v', 0), SenseInfo('01414626-v', 5), SenseInfo('01575146-v', 3), SenseInfo('01925548-v', 1), SenseInfo('01880113-v', 1), SenseInfo('01563996-v', 0), SenseInfo('01302365-v', 0), SenseInfo('01302183-v', 0), SenseInfo('00331514-v', 0), SenseInfo('01414626-v', 5), SenseInfo('01575146-v', 3), SenseInfo('01925548-v', 1), SenseInfo('01880113-v', 1), SenseInfo('01563996-v', 0), SenseInfo('01302365-v', 0), SenseInfo('01302183-v', 0), SenseInfo('00331514-v', 0) ],
"_fisherman_n_1_rel" : [ SenseInfo('10093658-n', 6) ],
"_frustrated_a_at-by-with_rel" : [ SenseInfo('02333976-a', 2), SenseInfo('02333976-a', 2), SenseInfo('02333976-a', 2) ],
"_crop_v_up_rel" : [ SenseInfo('01553761-v', 1), SenseInfo('01741446-v', 0), SenseInfo('01652537-v', 0), SenseInfo('01576478-v', 0), SenseInfo('01576165-v', 0), SenseInfo('01321002-v', 0) ],
"_hemorrhage_n_1_rel" : [ SenseInfo('14288235-n', 4) ],
"_franc_n_1_rel" : [ SenseInfo('13662190-n', 1), SenseInfo('13662190-n', 1), SenseInfo('13662190-n', 1), SenseInfo('13662190-n', 1) ],
"_muscle_n_1_rel" : [ SenseInfo('05289297-n', 43), SenseInfo('05289057-n', 2), SenseInfo('10339350-n', 0), SenseInfo('05198132-n', 0), SenseInfo('05030418-n', 0) ],
"_get_v_through_rel" : [ SenseInfo('02210855-v', 235), SenseInfo('00149583-v', 157), SenseInfo('00120796-v', 82), SenseInfo('00522751-v', 64), SenseInfo('02005948-v', 58), SenseInfo('01433294-v', 45), SenseInfo('02108026-v', 36), SenseInfo('01153947-v', 14), SenseInfo('02355596-v', 9), SenseInfo('00770437-v', 7), SenseInfo('01215421-v', 4), SenseInfo('00094460-v', 4), SenseInfo('00087736-v', 4), SenseInfo('01066036-v', 3), SenseInfo('00120316-v', 3), SenseInfo('01026975-v', 2), SenseInfo('00589904-v', 2), SenseInfo('01505958-v', 1), SenseInfo('01401115-v', 1), SenseInfo('00639849-v', 1), SenseInfo('02359340-v', 0), SenseInfo('02208265-v', 0), SenseInfo('02189398-v', 0), SenseInfo('02109645-v', 0), SenseInfo('02108654-v', 0), SenseInfo('02010864-v', 0), SenseInfo('02006573-v', 0), SenseInfo('01771194-v', 0), SenseInfo('01771039-v', 0), SenseInfo('01738107-v', 0), SenseInfo('01643297-v', 0), SenseInfo('01565211-v', 0), SenseInfo('00622384-v', 0), SenseInfo('00345761-v', 0), SenseInfo('00065639-v', 0), SenseInfo('00054628-v', 0) ],
"_coil_v_up_rel" : [ SenseInfo('02049190-v', 2), SenseInfo('01663580-v', 0), SenseInfo('01523986-v', 0), SenseInfo('02049190-v', 2), SenseInfo('01663580-v', 0), SenseInfo('01523986-v', 0) ],
"_brazen_a_1_rel" : [ SenseInfo('00155144-a', 2), SenseInfo('02905485-a', 0) ],
"_chokecherry_n_1_rel" : [ SenseInfo('12650805-n', 0), SenseInfo('12650556-n', 0) ],
"_off-road_a_1_rel" : [  ],
"_object_v_to_rel" : [ SenseInfo('00807461-v', 19), SenseInfo('02753865-v', 0) ],
"_between_p_rel" : [ SenseInfo('00498387-r', 1), SenseInfo('00250898-r', 1), SenseInfo('00498387-r', 1), SenseInfo('00250898-r', 1) ],
"_irrelevant_a_1_rel" : [ SenseInfo('01976084-a', 6) ],
"_destiny_n_1_rel" : [ SenseInfo('07330007-n', 6), SenseInfo('09504915-n', 1), SenseInfo('14473222-n', 0) ],
"_polished_a_1_rel" : [ SenseInfo('01811997-a', 2), SenseInfo('02271177-a', 0), SenseInfo('01952153-a', 0), SenseInfo('01005306-a', 0) ],
"_deduce_v_from_rel" : [ SenseInfo('00636574-v', 7), SenseInfo('00944924-v', 2) ],
"_in+case+of_p_rel" : [  ],
"_behind_p_sel_rel" : [ SenseInfo('00221985-r', 13), SenseInfo('00222180-r', 3), SenseInfo('05559256-n', 1), SenseInfo('02492383-a', 1), SenseInfo('00222879-r', 0), SenseInfo('00222713-r', 0), SenseInfo('00222479-r', 0) ],
"_genuineness_n_1_rel" : [ SenseInfo('13955341-n', 0), SenseInfo('04783247-n', 0) ],
"_humor_v_1_rel" : [ SenseInfo('00859604-v', 2), SenseInfo('00859604-v', 2) ],
"_intrude_v_1_rel" : [ SenseInfo('02018524-v', 2), SenseInfo('02571251-v', 1), SenseInfo('02169119-v', 0), SenseInfo('00747757-v', 0) ],
"_disproportionate_a_1_rel" : [ SenseInfo('00483048-a', 1), SenseInfo('00482059-a', 1) ],
"_furthermore_a_1_rel" : [  ],
"_showerhead_n_1_rel" : [ SenseInfo('04209383-n', 1) ],
"_arc_v_1_rel" : [ SenseInfo('02034986-v', 0) ],
"_fuck_v_1_rel" : [ SenseInfo('01426397-v', 0) ],
"_pull_n_1_rel" : [ SenseInfo('00114431-n', 5), SenseInfo('11498040-n', 2), SenseInfo('05157274-n', 1), SenseInfo('04019696-n', 1), SenseInfo('14299070-n', 0), SenseInfo('00837675-n', 0), SenseInfo('00625427-n', 0) ],
"_clear_v_away_rel" : [ SenseInfo('00181664-v', 16), SenseInfo('00195617-v', 5), SenseInfo('02771169-v', 2), SenseInfo('00803325-v', 2), SenseInfo('00195342-v', 2), SenseInfo('02523351-v', 1), SenseInfo('02289134-v', 1), SenseInfo('02156844-v', 1), SenseInfo('02081178-v', 1), SenseInfo('00621058-v', 1), SenseInfo('02422409-v', 0), SenseInfo('02350440-v', 0), SenseInfo('02291548-v', 0), SenseInfo('02291258-v', 0), SenseInfo('02289295-v', 0), SenseInfo('02208409-v', 0), SenseInfo('02053490-v', 0), SenseInfo('00904046-v', 0), SenseInfo('00761454-v', 0), SenseInfo('00549217-v', 0), SenseInfo('00450863-v', 0), SenseInfo('00450691-v', 0), SenseInfo('00450565-v', 0), SenseInfo('00178235-v', 0) ],
"_teakettle_n_1_rel" : [ SenseInfo('04397768-n', 1) ],
"_hah_a_1_rel" : [  ],
"_almond_a_1_rel" : [ SenseInfo('12645174-n', 0), SenseInfo('07750586-n', 0) ],
"_concierge_n_1_rel" : [ SenseInfo('09951953-n', 2) ],
"_boot_n_1_rel" : [ SenseInfo('02872752-n', 13), SenseInfo('02873244-n', 1), SenseInfo('07528470-n', 0), SenseInfo('02873520-n', 0), SenseInfo('02873363-n', 0), SenseInfo('00422261-n', 0), SenseInfo('00136329-n', 0) ],
"_twin_v_cause_rel" : [ SenseInfo('02659358-v', 0), SenseInfo('01292885-v', 0), SenseInfo('00246125-v', 0), SenseInfo('00057665-v', 0) ],
"_nuclear_a_1_rel" : [ SenseInfo('00610532-a', 12), SenseInfo('02862444-a', 5), SenseInfo('02862629-a', 1), SenseInfo('00331259-a', 1) ],
"_unaware_a_1_rel" : [ SenseInfo('00191603-a', 8), SenseInfo('00191603-a', 8) ],
"_without_p_sel_rel" : [  ],
"_treat_v_with_rel" : [ SenseInfo('02514187-v', 30), SenseInfo('00515154-v', 23), SenseInfo('00078760-v', 17), SenseInfo('01033527-v', 10), SenseInfo('02261642-v', 3), SenseInfo('01176232-v', 0), SenseInfo('00762720-v', 0), SenseInfo('00651145-v', 0) ],
"_snowfall_n_1_rel" : [ SenseInfo('11508382-n', 1) ],
"_pledge_v_1_rel" : [ SenseInfo('00884540-v', 3), SenseInfo('02299269-v', 0), SenseInfo('01175467-v', 0), SenseInfo('00886281-v', 0), SenseInfo('00884946-v', 0), SenseInfo('00884540-v', 3), SenseInfo('02299269-v', 0), SenseInfo('01175467-v', 0), SenseInfo('00886281-v', 0), SenseInfo('00884946-v', 0), SenseInfo('00884540-v', 3), SenseInfo('02299269-v', 0), SenseInfo('01175467-v', 0), SenseInfo('00886281-v', 0), SenseInfo('00884946-v', 0) ],
"_ostentatious_a_1_rel" : [ SenseInfo('01848355-a', 1), SenseInfo('02394975-a', 0), SenseInfo('01848355-a', 1), SenseInfo('02394975-a', 0) ],
"_have_v_yet_rel" : [ SenseInfo('02203362-v', 1202), SenseInfo('02630189-v', 377), SenseInfo('02108026-v', 220), SenseInfo('02204692-v', 143), SenseInfo('00120796-v', 64), SenseInfo('01156834-v', 42), SenseInfo('02378453-v', 31), SenseInfo('01733477-v', 30), SenseInfo('02205098-v', 28), SenseInfo('02740745-v', 25), SenseInfo('00121046-v', 25), SenseInfo('00065370-v', 11), SenseInfo('00770437-v', 8), SenseInfo('02236124-v', 7), SenseInfo('02210119-v', 7), SenseInfo('00065639-v', 5), SenseInfo('02355596-v', 3), SenseInfo('00056930-v', 3), SenseInfo('01427127-v', 2) ],
"_tease_v_out_rel" : [ SenseInfo('01803380-v', 2), SenseInfo('00850501-v', 1), SenseInfo('01803641-v', 0), SenseInfo('01572386-v', 0), SenseInfo('01531635-v', 0), SenseInfo('01463792-v', 0), SenseInfo('01356256-v', 0), SenseInfo('00852506-v', 0), SenseInfo('00040188-v', 0) ],
"_homesick_a_1_rel" : [ SenseInfo('00889239-a', 0) ],
"_appendix_n_1_rel" : [ SenseInfo('06399337-n', 6), SenseInfo('05537576-n', 0) ],
"_afflictive_a_1_rel" : [ SenseInfo('01804175-a', 0) ],
"_come_v_along_rel" : [ SenseInfo('01849221-v', 276), SenseInfo('02005948-v', 235), SenseInfo('00341917-v', 147), SenseInfo('00542120-v', 41), SenseInfo('02625339-v', 40), SenseInfo('00342812-v', 11), SenseInfo('02743921-v', 9), SenseInfo('02743214-v', 7), SenseInfo('02686805-v', 6), SenseInfo('02743565-v', 3), SenseInfo('01839690-v', 3), SenseInfo('02729963-v', 2), SenseInfo('00344886-v', 2), SenseInfo('02645007-v', 1), SenseInfo('02627363-v', 1), SenseInfo('02006709-v', 1), SenseInfo('00723349-v', 1), SenseInfo('02737187-v', 0), SenseInfo('02617567-v', 0), SenseInfo('02197360-v', 0), SenseInfo('00659984-v', 0), SenseInfo('01849221-v', 276), SenseInfo('02005948-v', 235), SenseInfo('00341917-v', 147), SenseInfo('00542120-v', 41), SenseInfo('02625339-v', 40), SenseInfo('00342812-v', 11), SenseInfo('02743921-v', 9), SenseInfo('02743214-v', 7), SenseInfo('02686805-v', 6), SenseInfo('02743565-v', 3), SenseInfo('01839690-v', 3), SenseInfo('02729963-v', 2), SenseInfo('00344886-v', 2), SenseInfo('02645007-v', 1), SenseInfo('02627363-v', 1), SenseInfo('02006709-v', 1), SenseInfo('00723349-v', 1), SenseInfo('02737187-v', 0), SenseInfo('02617567-v', 0), SenseInfo('02197360-v', 0), SenseInfo('00659984-v', 0) ],
"_skew_v_1_rel" : [ SenseInfo('00466484-v', 0) ],
"_lilt_n_1_rel" : [ SenseInfo('04992008-n', 1) ],
"_go_v_1_rel" : [ SenseInfo('01835496-v', 343), SenseInfo('02372605-v', 95), SenseInfo('01848718-v', 49), SenseInfo('00149583-v', 29), SenseInfo('02653862-v', 14), SenseInfo('02721284-v', 10), SenseInfo('02685951-v', 10), SenseInfo('00341560-v', 10), SenseInfo('00359916-v', 9), SenseInfo('02618001-v', 7), SenseInfo('02176268-v', 3), SenseInfo('01525666-v', 3), SenseInfo('01192773-v', 3), SenseInfo('00539110-v', 3), SenseInfo('02618149-v', 2), SenseInfo('02617798-v', 2), SenseInfo('00358431-v', 2), SenseInfo('02737876-v', 1), SenseInfo('02729819-v', 1), SenseInfo('01864230-v', 1), SenseInfo('01076615-v', 1), SenseInfo('02700772-v', 0), SenseInfo('02700666-v', 0), SenseInfo('02700455-v', 0), SenseInfo('02686471-v', 0), SenseInfo('02659763-v', 0), SenseInfo('01318849-v', 0), SenseInfo('01192992-v', 0), SenseInfo('00676267-v', 0), SenseInfo('00434374-v', 0), SenseInfo('01835496-v', 343), SenseInfo('02372605-v', 95), SenseInfo('01848718-v', 49), SenseInfo('00149583-v', 29), SenseInfo('02653862-v', 14), SenseInfo('02721284-v', 10), SenseInfo('02685951-v', 10), SenseInfo('00341560-v', 10), SenseInfo('00359916-v', 9), SenseInfo('02618001-v', 7), SenseInfo('02176268-v', 3), SenseInfo('01525666-v', 3), SenseInfo('01192773-v', 3), SenseInfo('00539110-v', 3), SenseInfo('02618149-v', 2), SenseInfo('02617798-v', 2), SenseInfo('00358431-v', 2), SenseInfo('02737876-v', 1), SenseInfo('02729819-v', 1), SenseInfo('01864230-v', 1), SenseInfo('01076615-v', 1), SenseInfo('02700772-v', 0), SenseInfo('02700666-v', 0), SenseInfo('02700455-v', 0), SenseInfo('02686471-v', 0), SenseInfo('02659763-v', 0), SenseInfo('01318849-v', 0), SenseInfo('01192992-v', 0), SenseInfo('00676267-v', 0), SenseInfo('00434374-v', 0), SenseInfo('01835496-v', 343), SenseInfo('02372605-v', 95), SenseInfo('01848718-v', 49), SenseInfo('00149583-v', 29), SenseInfo('02653862-v', 14), SenseInfo('02721284-v', 10), SenseInfo('02685951-v', 10), SenseInfo('00341560-v', 10), SenseInfo('00359916-v', 9), SenseInfo('02618001-v', 7), SenseInfo('02176268-v', 3), SenseInfo('01525666-v', 3), SenseInfo('01192773-v', 3), SenseInfo('00539110-v', 3), SenseInfo('02618149-v', 2), SenseInfo('02617798-v', 2), SenseInfo('00358431-v', 2), SenseInfo('02737876-v', 1), SenseInfo('02729819-v', 1), SenseInfo('01864230-v', 1), SenseInfo('01076615-v', 1), SenseInfo('02700772-v', 0), SenseInfo('02700666-v', 0), SenseInfo('02700455-v', 0), SenseInfo('02686471-v', 0), SenseInfo('02659763-v', 0), SenseInfo('01318849-v', 0), SenseInfo('01192992-v', 0), SenseInfo('00676267-v', 0), SenseInfo('00434374-v', 0), SenseInfo('01835496-v', 343), SenseInfo('02372605-v', 95), SenseInfo('01848718-v', 49), SenseInfo('00149583-v', 29), SenseInfo('02653862-v', 14), SenseInfo('02721284-v', 10), SenseInfo('02685951-v', 10), SenseInfo('00341560-v', 10), SenseInfo('00359916-v', 9), SenseInfo('02618001-v', 7), SenseInfo('02176268-v', 3), SenseInfo('01525666-v', 3), SenseInfo('01192773-v', 3), SenseInfo('00539110-v', 3), SenseInfo('02618149-v', 2), SenseInfo('02617798-v', 2), SenseInfo('00358431-v', 2), SenseInfo('02737876-v', 1), SenseInfo('02729819-v', 1), SenseInfo('01864230-v', 1), SenseInfo('01076615-v', 1), SenseInfo('02700772-v', 0), SenseInfo('02700666-v', 0), SenseInfo('02700455-v', 0), SenseInfo('02686471-v', 0), SenseInfo('02659763-v', 0), SenseInfo('01318849-v', 0), SenseInfo('01192992-v', 0), SenseInfo('00676267-v', 0), SenseInfo('00434374-v', 0), SenseInfo('01835496-v', 343), SenseInfo('02372605-v', 95), SenseInfo('01848718-v', 49), SenseInfo('00149583-v', 29), SenseInfo('02653862-v', 14), SenseInfo('02721284-v', 10), SenseInfo('02685951-v', 10), SenseInfo('00341560-v', 10), SenseInfo('00359916-v', 9), SenseInfo('02618001-v', 7), SenseInfo('02176268-v', 3), SenseInfo('01525666-v', 3), SenseInfo('01192773-v', 3), SenseInfo('00539110-v', 3), SenseInfo('02618149-v', 2), SenseInfo('02617798-v', 2), SenseInfo('00358431-v', 2), SenseInfo('02737876-v', 1), SenseInfo('02729819-v', 1), SenseInfo('01864230-v', 1), SenseInfo('01076615-v', 1), SenseInfo('02700772-v', 0), SenseInfo('02700666-v', 0), SenseInfo('02700455-v', 0), SenseInfo('02686471-v', 0), SenseInfo('02659763-v', 0), SenseInfo('01318849-v', 0), SenseInfo('01192992-v', 0), SenseInfo('00676267-v', 0), SenseInfo('00434374-v', 0) ],
"_weekly_n_1_rel" : [ SenseInfo('06594258-n', 2) ],
"_bridle_v_1_rel" : [ SenseInfo('01786292-v', 0), SenseInfo('01300655-v', 0), SenseInfo('01056918-v', 0), SenseInfo('01786292-v', 0), SenseInfo('01300655-v', 0), SenseInfo('01056918-v', 0), SenseInfo('01786292-v', 0), SenseInfo('01300655-v', 0), SenseInfo('01056918-v', 0) ],
"_transcendent_a_1_rel" : [ SenseInfo('02344793-a', 0), SenseInfo('01374912-a', 0) ],
"_graphic_a_1_rel" : [ SenseInfo('02285278-a', 2), SenseInfo('00941242-a', 1), SenseInfo('02736983-a', 0), SenseInfo('02736808-a', 0), SenseInfo('01941026-a', 0) ],
"_keelson_n_1_rel" : [ SenseInfo('03609959-n', 0) ],
"_shower_v_x_rel" : [ SenseInfo('02264601-v', 2), SenseInfo('01372994-v', 2), SenseInfo('00035259-v', 2), SenseInfo('02757651-v', 0), SenseInfo('01184333-v', 0) ],
"_recipe_n_1_rel" : [ SenseInfo('06788785-n', 0) ],
"_meadow_n_1_rel" : [ SenseInfo('08570634-n', 6) ],
"_alrighty_a_1_rel" : [  ],
"_multiple_a_1_rel" : [ SenseInfo('02215977-a', 6) ],
"_atrocious_a_1_rel" : [ SenseInfo('01131454-a', 0), SenseInfo('01126291-a', 0), SenseInfo('00193480-a', 0) ],
"_drive-through_n_1_rel" : [  ],
"_aloft_a_1_rel" : [  ],
"_scooter_n_1_rel" : [ SenseInfo('04562122-n', 0), SenseInfo('04149374-n', 0), SenseInfo('03791053-n', 0), SenseInfo('03556811-n', 0), SenseInfo('01853498-n', 0) ],
"_tunnel_v_1_rel" : [ SenseInfo('02042067-v', 1), SenseInfo('01444037-v', 1), SenseInfo('02042067-v', 1), SenseInfo('01444037-v', 1) ],
"_introduce_v_to_rel" : [ SenseInfo('00901103-v', 21), SenseInfo('01642437-v', 10), SenseInfo('00187526-v', 9), SenseInfo('02078591-v', 7), SenseInfo('01618693-v', 1), SenseInfo('01421622-v', 1), SenseInfo('01065115-v', 1), SenseInfo('00706693-v', 1), SenseInfo('00901799-v', 0), SenseInfo('00349592-v', 0), SenseInfo('00901103-v', 21), SenseInfo('01642437-v', 10), SenseInfo('00187526-v', 9), SenseInfo('02078591-v', 7), SenseInfo('01618693-v', 1), SenseInfo('01421622-v', 1), SenseInfo('01065115-v', 1), SenseInfo('00706693-v', 1), SenseInfo('00901799-v', 0), SenseInfo('00349592-v', 0) ],
"_dash_v_out_rel" : [ SenseInfo('02061495-v', 7), SenseInfo('00335923-v', 2), SenseInfo('01507407-v', 1), SenseInfo('02558703-v', 0), SenseInfo('01785748-v', 0), SenseInfo('00184377-v', 0) ],
"_serf_n_1_rel" : [ SenseInfo('10580535-n', 0) ],
"_elasticity_n_1_rel" : [ SenseInfo('05020358-n', 3) ],
"_tete-a-tete_n_1_rel" : [ SenseInfo('07142107-n', 0), SenseInfo('03693474-n', 0), SenseInfo('07142107-n', 0), SenseInfo('03693474-n', 0) ],
"_annual_n_1_rel" : [ SenseInfo('11552806-n', 0), SenseInfo('06426468-n', 0) ],
"_regret_n_1_rel" : [ SenseInfo('07535670-n', 5), SenseInfo('07535670-n', 5) ],
"_tempest_n_1_rel" : [ SenseInfo('13978344-n', 1), SenseInfo('11518494-n', 0) ],
"_shady_a_1_rel" : [ SenseInfo('02466566-a', 0), SenseInfo('01984669-a', 0), SenseInfo('01917594-a', 0), SenseInfo('00276862-a', 0), SenseInfo('02466566-a', 0), SenseInfo('01984669-a', 0), SenseInfo('01917594-a', 0), SenseInfo('00276862-a', 0), SenseInfo('02466566-a', 0), SenseInfo('01984669-a', 0), SenseInfo('01917594-a', 0), SenseInfo('00276862-a', 0) ],
"_sparkle_v_1_rel" : [ SenseInfo('02766390-v', 1), SenseInfo('00473003-v', 1), SenseInfo('02766687-v', 0), SenseInfo('00519363-v', 0) ],
"_herr_n_1_rel" : [ SenseInfo('10173771-n', 0), SenseInfo('06341127-n', 0) ],
"_telegraphic_a_1_rel" : [ SenseInfo('02910074-a', 2), SenseInfo('00548579-a', 0) ],
"_mistake_v_for_rel" : [ SenseInfo('00618267-v', 7), SenseInfo('00617748-v', 0), SenseInfo('00618267-v', 7), SenseInfo('00617748-v', 0), SenseInfo('00618267-v', 7), SenseInfo('00617748-v', 0) ],
"_dock_v_1_rel" : [ SenseInfo('02085742-v', 2), SenseInfo('02313690-v', 0), SenseInfo('02215266-v', 0), SenseInfo('01556178-v', 0), SenseInfo('01305731-v', 0) ],
"_germany+internal_a_1_rel" : [  ],
"_letterhead_n_1_rel" : [ SenseInfo('06259027-n', 1) ],
"_unconvincing_a_1_rel" : [ SenseInfo('00615457-a', 2), SenseInfo('01800169-a', 0), SenseInfo('00615457-a', 2), SenseInfo('01800169-a', 0) ],
"_astride_p_rel" : [ SenseInfo('00275974-r', 2), SenseInfo('00276076-r', 0) ],
"_dogsled_n_1_rel" : [ SenseInfo('03218198-n', 0) ],
"_barely_x_deg_rel" : [ SenseInfo('00002621-r', 11), SenseInfo('00073763-r', 2), SenseInfo('00002621-r', 11), SenseInfo('00073763-r', 2) ],
"_short_v_out_rel" : [ SenseInfo('02572667-v', 0), SenseInfo('01618884-v', 0), SenseInfo('02572667-v', 0), SenseInfo('01618884-v', 0) ],
"_sign_v_off_rel" : [ SenseInfo('00996485-v', 16), SenseInfo('02464866-v', 13), SenseInfo('00889229-v', 8), SenseInfo('02409941-v', 2), SenseInfo('01039330-v', 1), SenseInfo('01498319-v', 0), SenseInfo('00929160-v', 0), SenseInfo('00867231-v', 0) ],
"_inhabitant_n_of_rel" : [ SenseInfo('09620078-n', 4) ],
"_stink_n_1_rel" : [ SenseInfo('05714894-n', 0) ],
"_if+possible_a_1_rel" : [  ],
"_safest_a_for_rel" : [  ],
"_okay_v_1_rel" : [ SenseInfo('00806502-v', 0), SenseInfo('00806502-v', 0) ],
"_competition_n_1_rel" : [ SenseInfo('13837009-n', 17), SenseInfo('07456188-n', 4), SenseInfo('01168569-n', 4), SenseInfo('10533013-n', 0) ],
"_show_n_of_rel" : [ SenseInfo('00520257-n', 18), SenseInfo('06879521-n', 9), SenseInfo('06619065-n', 0), SenseInfo('00755277-n', 0), SenseInfo('00520257-n', 18), SenseInfo('06879521-n', 9), SenseInfo('06619065-n', 0), SenseInfo('00755277-n', 0) ],
"_point_v_up_rel" : [ SenseInfo('00923793-v', 25), SenseInfo('02713184-v', 8), SenseInfo('01152214-v', 8), SenseInfo('01931768-v', 5), SenseInfo('00921300-v', 1), SenseInfo('01928154-v', 0), SenseInfo('01589363-v', 0), SenseInfo('01589224-v', 0), SenseInfo('01589056-v', 0), SenseInfo('01152670-v', 0), SenseInfo('01150559-v', 0), SenseInfo('00924255-v', 0), SenseInfo('00392960-v', 0), SenseInfo('00261957-v', 0) ],
"_bagger_n_1_rel" : [ SenseInfo('10390427-n', 0), SenseInfo('02775359-n', 0) ],
"_synthesizer_n_1_rel" : [ SenseInfo('10687231-n', 0), SenseInfo('04376400-n', 0), SenseInfo('10687231-n', 0), SenseInfo('04376400-n', 0) ],
"_threadbare_a_1_rel" : [ SenseInfo('01688757-a', 1), SenseInfo('02583898-a', 0) ],
"_evaporate_v_cause_rel" : [ SenseInfo('00366858-v', 2), SenseInfo('00575970-v', 0), SenseInfo('00575720-v', 0), SenseInfo('00223928-v', 0) ],
"_suffer_v_through_rel" : [ SenseInfo('02109190-v', 17), SenseInfo('00065639-v', 17), SenseInfo('01794668-v', 12), SenseInfo('00668099-v', 8), SenseInfo('00204750-v', 7), SenseInfo('00065070-v', 4), SenseInfo('02121511-v', 1), SenseInfo('00078401-v', 1), SenseInfo('02719807-v', 0), SenseInfo('02110082-v', 0), SenseInfo('00204872-v', 0) ],
"_latitude_n_1_rel" : [ SenseInfo('08595531-n', 2), SenseInfo('13995148-n', 0), SenseInfo('08595720-n', 0), SenseInfo('05127640-n', 0) ],
"_instate_a_1_rel" : [  ],
"_anyhow_a_1_rel" : [  ],
"_paste_n_1_rel" : [ SenseInfo('14705287-n', 6), SenseInfo('14882248-n', 0), SenseInfo('14704966-n', 0), SenseInfo('07856270-n', 0) ],
"_not-for-profit_a_1_rel" : [ SenseInfo('01137597-n', 0), SenseInfo('01137597-n', 0) ],
"_advice_n_1_rel" : [ SenseInfo('06671484-n', 18), SenseInfo('06671484-n', 18) ],
"_largely_a_1_rel" : [  ],
"_shoo-in_n_1_rel" : [ SenseInfo('07475107-n', 0), SenseInfo('07475107-n', 0) ],
"_µm-size_n_1_rel" : [  ],
"_tumble_v_1_rel" : [ SenseInfo('01976488-v', 10), SenseInfo('02097047-v', 2), SenseInfo('01867997-v', 2), SenseInfo('02047857-v', 1), SenseInfo('02041877-v', 1), SenseInfo('01473020-v', 0), SenseInfo('00590366-v', 0), SenseInfo('00433069-v', 0), SenseInfo('00211642-v', 0), SenseInfo('00204281-v', 0), SenseInfo('00100235-v', 0) ],
"_strain_v_1_rel" : [ SenseInfo('01146051-v', 6), SenseInfo('01798452-v', 3), SenseInfo('01165579-v', 3), SenseInfo('01460029-v', 1), SenseInfo('00025203-v', 1), SenseInfo('01572728-v', 0), SenseInfo('01458664-v', 0), SenseInfo('01250474-v', 0), SenseInfo('00476744-v', 0), SenseInfo('01146051-v', 6), SenseInfo('01798452-v', 3), SenseInfo('01165579-v', 3), SenseInfo('01460029-v', 1), SenseInfo('00025203-v', 1), SenseInfo('01572728-v', 0), SenseInfo('01458664-v', 0), SenseInfo('01250474-v', 0), SenseInfo('00476744-v', 0), SenseInfo('01146051-v', 6), SenseInfo('01798452-v', 3), SenseInfo('01165579-v', 3), SenseInfo('01460029-v', 1), SenseInfo('00025203-v', 1), SenseInfo('01572728-v', 0), SenseInfo('01458664-v', 0), SenseInfo('01250474-v', 0), SenseInfo('00476744-v', 0) ],
"_bow-wow_n_1_rel" : [ SenseInfo('07378163-n', 0), SenseInfo('02084732-n', 0), SenseInfo('07378163-n', 0), SenseInfo('02084732-n', 0) ],
"_weaken_v_1_rel" : [ SenseInfo('00224901-v', 6), SenseInfo('00223500-v', 2), SenseInfo('02543607-v', 1), SenseInfo('00290740-v', 1), SenseInfo('00390215-v', 0) ],
"_encompass_v_1_rel" : [ SenseInfo('02629793-v', 4), SenseInfo('02629793-v', 4), SenseInfo('02629793-v', 4) ],
"_herder_n_1_rel" : [ SenseInfo('11044789-n', 0), SenseInfo('10171567-n', 0) ],
"_strike_v_as_rel" : [ SenseInfo('01410223-v', 18), SenseInfo('01767949-v', 16), SenseInfo('01236164-v', 14), SenseInfo('01123887-v', 7), SenseInfo('00923622-v', 5), SenseInfo('01209135-v', 4), SenseInfo('02412647-v', 3), SenseInfo('02611976-v', 2), SenseInfo('02526811-v', 2), SenseInfo('01209426-v', 2), SenseInfo('00143540-v', 2), SenseInfo('02286687-v', 1), SenseInfo('01675073-v', 1), SenseInfo('01549420-v', 1), SenseInfo('02108791-v', 0), SenseInfo('02104161-v', 0), SenseInfo('01982395-v', 0), SenseInfo('01639105-v', 0), SenseInfo('01308008-v', 0), SenseInfo('01228235-v', 0), SenseInfo('00635904-v', 0) ],
"_granular_a_1_rel" : [ SenseInfo('02231502-a', 3), SenseInfo('00365799-a', 0) ],
"_misconception_n_1_rel" : [ SenseInfo('05893653-n', 3), SenseInfo('05893653-n', 3) ],
"_stiffen_v_1_rel" : [ SenseInfo('00418563-v', 11), SenseInfo('00417596-v', 2), SenseInfo('00418765-v', 0) ],
"_take_v_after_rel" : [ SenseInfo('02599636-v', 92), SenseInfo('02267989-v', 74), SenseInfo('01999798-v', 73), SenseInfo('01214265-v', 50), SenseInfo('00524682-v', 38), SenseInfo('00624476-v', 36), SenseInfo('02077656-v', 32), SenseInfo('02205272-v', 28), SenseInfo('01842690-v', 26), SenseInfo('00674607-v', 26), SenseInfo('02236124-v', 25), SenseInfo('02394183-v', 22), SenseInfo('00734054-v', 22), SenseInfo('02627934-v', 21), SenseInfo('02109045-v', 21), SenseInfo('01002740-v', 16), SenseInfo('00173338-v', 16), SenseInfo('01156834-v', 15), SenseInfo('00669762-v', 15), SenseInfo('02209936-v', 14), SenseInfo('02206619-v', 13), SenseInfo('01982395-v', 10), SenseInfo('02236624-v', 8), SenseInfo('00523095-v', 7), SenseInfo('00599992-v', 6), SenseInfo('00756076-v', 5), SenseInfo('02075857-v', 4), SenseInfo('01151110-v', 4), SenseInfo('00557404-v', 4), SenseInfo('02717102-v', 2), SenseInfo('02208537-v', 2), SenseInfo('02209745-v', 1), SenseInfo('02208118-v', 1), SenseInfo('02201138-v', 1), SenseInfo('01427127-v', 1), SenseInfo('00758333-v', 1), SenseInfo('02741546-v', 0), SenseInfo('02701210-v', 0), SenseInfo('02590253-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01100830-v', 0), SenseInfo('00087736-v', 0) ],
"_lose_v_i_rel" : [ SenseInfo('02287789-v', 123), SenseInfo('01099592-v', 17), SenseInfo('01795082-v', 10), SenseInfo('01503101-v', 7), SenseInfo('02287618-v', 6), SenseInfo('02197091-v', 4), SenseInfo('02288828-v', 3), SenseInfo('02288155-v', 2), SenseInfo('01113806-v', 2), SenseInfo('02127853-v', 1), SenseInfo('00204872-v', 0), SenseInfo('02287789-v', 123), SenseInfo('01099592-v', 17), SenseInfo('01795082-v', 10), SenseInfo('01503101-v', 7), SenseInfo('02287618-v', 6), SenseInfo('02197091-v', 4), SenseInfo('02288828-v', 3), SenseInfo('02288155-v', 2), SenseInfo('01113806-v', 2), SenseInfo('02127853-v', 1), SenseInfo('00204872-v', 0) ],
"_nutshell_n_1_rel" : [ SenseInfo('11683747-n', 0) ],
"_appear_v_1_rel" : [ SenseInfo('02133435-v', 121), SenseInfo('00422090-v', 102), SenseInfo('00425967-v', 22), SenseInfo('02134672-v', 14), SenseInfo('00425071-v', 7), SenseInfo('01721169-v', 2), SenseInfo('02597762-v', 1), SenseInfo('02133435-v', 121), SenseInfo('00422090-v', 102), SenseInfo('00425967-v', 22), SenseInfo('02134672-v', 14), SenseInfo('00425071-v', 7), SenseInfo('01721169-v', 2), SenseInfo('02597762-v', 1), SenseInfo('02133435-v', 121), SenseInfo('00422090-v', 102), SenseInfo('00425967-v', 22), SenseInfo('02134672-v', 14), SenseInfo('00425071-v', 7), SenseInfo('01721169-v', 2), SenseInfo('02597762-v', 1), SenseInfo('02133435-v', 121), SenseInfo('00422090-v', 102), SenseInfo('00425967-v', 22), SenseInfo('02134672-v', 14), SenseInfo('00425071-v', 7), SenseInfo('01721169-v', 2), SenseInfo('02597762-v', 1) ],
"_disorienting_a_for_rel" : [ SenseInfo('01685377-a', 0), SenseInfo('01685377-a', 0), SenseInfo('01685377-a', 0) ],
"_facilitate_v_1_rel" : [ SenseInfo('00518395-v', 5), SenseInfo('02735897-v', 0), SenseInfo('01757338-v', 0) ],
"_obligatory_a_for_rel" : [ SenseInfo('00848074-a', 0), SenseInfo('01580968-a', 0), SenseInfo('00848074-a', 0), SenseInfo('01580968-a', 0), SenseInfo('00848074-a', 0), SenseInfo('01580968-a', 0), SenseInfo('00848074-a', 0), SenseInfo('01580968-a', 0) ],
"_stack_v_1_rel" : [ SenseInfo('01503952-v', 2), SenseInfo('01503404-v', 0), SenseInfo('01464781-v', 0) ],
"_step_n_1_rel" : [ SenseInfo('00174412-n', 36), SenseInfo('13757249-n', 13), SenseInfo('00285557-n', 7), SenseInfo('04314914-n', 2), SenseInfo('14429608-n', 1), SenseInfo('13762579-n', 0), SenseInfo('07383823-n', 0), SenseInfo('06859056-n', 0), SenseInfo('06645039-n', 0), SenseInfo('04315185-n', 0), SenseInfo('00533922-n', 0), SenseInfo('00174412-n', 36), SenseInfo('13757249-n', 13), SenseInfo('00285557-n', 7), SenseInfo('04314914-n', 2), SenseInfo('14429608-n', 1), SenseInfo('13762579-n', 0), SenseInfo('07383823-n', 0), SenseInfo('06859056-n', 0), SenseInfo('06645039-n', 0), SenseInfo('04315185-n', 0), SenseInfo('00533922-n', 0), SenseInfo('00174412-n', 36), SenseInfo('13757249-n', 13), SenseInfo('00285557-n', 7), SenseInfo('04314914-n', 2), SenseInfo('14429608-n', 1), SenseInfo('13762579-n', 0), SenseInfo('07383823-n', 0), SenseInfo('06859056-n', 0), SenseInfo('06645039-n', 0), SenseInfo('04315185-n', 0), SenseInfo('00533922-n', 0), SenseInfo('00174412-n', 36), SenseInfo('13757249-n', 13), SenseInfo('00285557-n', 7), SenseInfo('04314914-n', 2), SenseInfo('14429608-n', 1), SenseInfo('13762579-n', 0), SenseInfo('07383823-n', 0), SenseInfo('06859056-n', 0), SenseInfo('06645039-n', 0), SenseInfo('04315185-n', 0), SenseInfo('00533922-n', 0) ],
"_highball_n_1_rel" : [ SenseInfo('07912211-n', 0) ],
"_handicap_n_1_rel" : [ SenseInfo('14548343-n', 1), SenseInfo('05156822-n', 1), SenseInfo('05689249-n', 0) ],
"_toy_n_1_rel" : [ SenseInfo('03964744-n', 4), SenseInfo('04462102-n', 0), SenseInfo('04461879-n', 0), SenseInfo('03769235-n', 0), SenseInfo('02085374-n', 0) ],
"_cocktail_n_1_rel" : [ SenseInfo('07911677-n', 0), SenseInfo('07581775-n', 0) ],
"_rain+or+shine_a_1_rel" : [  ],
"_glib_a_1_rel" : [ SenseInfo('01874716-a', 0), SenseInfo('01799781-a', 0), SenseInfo('01770726-a', 0) ],
"_apprentice_n_1_rel" : [ SenseInfo('09801864-n', 10) ],
"_lubberlander_n_1_rel" : [  ],
"_malaise_n_1_rel" : [ SenseInfo('14447019-n', 6) ],
"_queue_v_up_rel" : [ SenseInfo('02036755-v', 0), SenseInfo('02036755-v', 0) ],
"_traitorous_a_1_rel" : [ SenseInfo('00962939-a', 1) ],
"_deciliter_n_1_rel" : [ SenseInfo('13624026-n', 0), SenseInfo('13624026-n', 0) ],
"_oriental_a_1_rel" : [ SenseInfo('00825807-a', 4) ],
"_agistment_n_1_rel" : [  ],
"_mug_v_1_rel" : [ SenseInfo('02277663-v', 0) ],
"_atm_n_1_rel" : [ SenseInfo('13711060-n', 1), SenseInfo('06279071-n', 0), SenseInfo('02977058-n', 0) ],
"_wheat_a_1_rel" : [ SenseInfo('12142085-n', 1), SenseInfo('07803545-n', 0), SenseInfo('04966941-n', 0) ],
"_motivate_v_1_rel" : [ SenseInfo('01649999-v', 6), SenseInfo('01649999-v', 6), SenseInfo('01649999-v', 6), SenseInfo('01649999-v', 6), SenseInfo('01649999-v', 6) ],
"_challenging_a_1_rel" : [ SenseInfo('00745642-a', 3), SenseInfo('02306598-a', 0), SenseInfo('01897106-a', 0), SenseInfo('00745642-a', 3), SenseInfo('02306598-a', 0), SenseInfo('01897106-a', 0) ],
"_indecent_a_1_rel" : [ SenseInfo('01880918-a', 2), SenseInfo('00683185-a', 1), SenseInfo('01539022-a', 0) ],
"_focus_n_1_rel" : [ SenseInfo('05704694-n', 6), SenseInfo('04703235-n', 3), SenseInfo('04821084-n', 2), SenseInfo('14182697-n', 1), SenseInfo('14435187-n', 0), SenseInfo('11455695-n', 0), SenseInfo('08572335-n', 0) ],
"_god_a_1_rel" : [ SenseInfo('09536058-n', 90), SenseInfo('09505418-n', 26), SenseInfo('10133307-n', 0), SenseInfo('03560161-n', 0), SenseInfo('09536058-n', 90), SenseInfo('09505418-n', 26), SenseInfo('10133307-n', 0), SenseInfo('03560161-n', 0) ],
"_lift_v_1_rel" : [ SenseInfo('01974062-v', 31), SenseInfo('01579153-v', 10), SenseInfo('01973759-v', 2), SenseInfo('01968569-v', 2), SenseInfo('00986074-v', 2), SenseInfo('00799798-v', 2), SenseInfo('02276866-v', 1), SenseInfo('01455184-v', 1), SenseInfo('00549982-v', 1), SenseInfo('00544549-v', 1), SenseInfo('00178652-v', 1), SenseInfo('02696801-v', 0), SenseInfo('02352181-v', 0), SenseInfo('02278061-v', 0), SenseInfo('02277138-v', 0), SenseInfo('01452057-v', 0), SenseInfo('01311608-v', 0), SenseInfo('00792921-v', 0), SenseInfo('00357198-v', 0), SenseInfo('00354195-v', 0), SenseInfo('00198623-v', 0), SenseInfo('00178773-v', 0), SenseInfo('00178502-v', 0), SenseInfo('00061933-v', 0) ],
"_beast_n_1_rel" : [ SenseInfo('00015388-n', 4), SenseInfo('09845589-n', 1) ],
"_creep_v_1_rel" : [ SenseInfo('01885845-v', 11), SenseInfo('01911888-v', 4), SenseInfo('02060588-v', 2), SenseInfo('02063771-v', 0) ],
"_pillar_n_of_rel" : [ SenseInfo('05913842-n', 1), SenseInfo('13900422-n', 0), SenseInfo('10432957-n', 0), SenseInfo('03074380-n', 0), SenseInfo('03073977-n', 0) ],
"_libra_n_1_rel" : [ SenseInfo('09753065-n', 0), SenseInfo('09339109-n', 0), SenseInfo('08687150-n', 0) ],
"_freak_v_cause_rel" : [ SenseInfo('01784148-v', 0) ],
"_alleged_a_1_rel" : [ SenseInfo('00687614-a', 3), SenseInfo('01916555-a', 1), SenseInfo('00687614-a', 3), SenseInfo('01916555-a', 1), SenseInfo('00687614-a', 3), SenseInfo('01916555-a', 1) ],
"_aviary_n_1_rel" : [ SenseInfo('02763604-n', 1) ],
"_creak_v_1_rel" : [ SenseInfo('02171664-v', 9) ],
"_profess_v_to_rel" : [ SenseInfo('00819756-v', 4), SenseInfo('00760735-v', 3), SenseInfo('00818553-v', 1), SenseInfo('01010690-v', 0), SenseInfo('00888657-v', 0), SenseInfo('00888326-v', 0), SenseInfo('00756649-v', 0), SenseInfo('00819756-v', 4), SenseInfo('00760735-v', 3), SenseInfo('00818553-v', 1), SenseInfo('01010690-v', 0), SenseInfo('00888657-v', 0), SenseInfo('00888326-v', 0), SenseInfo('00756649-v', 0), SenseInfo('00819756-v', 4), SenseInfo('00760735-v', 3), SenseInfo('00818553-v', 1), SenseInfo('01010690-v', 0), SenseInfo('00888657-v', 0), SenseInfo('00888326-v', 0), SenseInfo('00756649-v', 0), SenseInfo('00819756-v', 4), SenseInfo('00760735-v', 3), SenseInfo('00818553-v', 1), SenseInfo('01010690-v', 0), SenseInfo('00888657-v', 0), SenseInfo('00888326-v', 0), SenseInfo('00756649-v', 0) ],
"_buggy_a_1_rel" : [ SenseInfo('02074929-a', 0), SenseInfo('00421202-a', 0) ],
"_directress_n_of_rel" : [  ],
"_stroke_n_1_rel" : [ SenseInfo('00565302-n', 3), SenseInfo('07351195-n', 2), SenseInfo('14082303-n', 1), SenseInfo('07413815-n', 1), SenseInfo('00144632-n', 1), SenseInfo('13595094-n', 0), SenseInfo('10664850-n', 0), SenseInfo('07300960-n', 0), SenseInfo('06844903-n', 0), SenseInfo('06799260-n', 0), SenseInfo('00569898-n', 0), SenseInfo('00349369-n', 0) ],
"_anglian_a_1_rel" : [ SenseInfo('06949852-n', 0) ],
"_revolt_n_1_rel" : [ SenseInfo('00962129-n', 4) ],
"_kickball_n_1_rel" : [  ],
"_darken_v_cause_rel" : [ SenseInfo('00312380-v', 4), SenseInfo('01537829-v', 0), SenseInfo('00311559-v', 0) ],
"_leaven_v_1_rel" : [ SenseInfo('01975587-v', 0), SenseInfo('01975587-v', 0) ],
"_collar_n_1_rel" : [ SenseInfo('03068181-n', 5), SenseInfo('04680752-n', 0), SenseInfo('03068998-n', 0), SenseInfo('03068862-n', 0), SenseInfo('03068707-n', 0), SenseInfo('03068486-n', 0), SenseInfo('03024882-n', 0), SenseInfo('01145688-n', 0), SenseInfo('00088725-n', 0) ],
"_odds_n_1_rel" : [ SenseInfo('04756504-n', 1), SenseInfo('13823483-n', 0) ],
"_relentless_a_1_rel" : [ SenseInfo('01785341-a', 2), SenseInfo('00593071-a', 1) ],
"_postponement_n_of_rel" : [ SenseInfo('15272029-n', 0), SenseInfo('01066881-n', 0) ],
"_slacker_n_1_rel" : [ SenseInfo('10608385-n', 0) ],
"_scarlet_a_1_rel" : [ SenseInfo('00381097-a', 0) ],
"_leap_v_over_rel" : [ SenseInfo('01963942-v', 22), SenseInfo('00560391-v', 1), SenseInfo('02105082-v', 0), SenseInfo('01965156-v', 0) ],
"_tray_n_1_rel" : [ SenseInfo('04476259-n', 12) ],
"_debris_n_1_rel" : [ SenseInfo('14857897-n', 5) ],
"_innocent_a_of_rel" : [ SenseInfo('01319874-a', 11), SenseInfo('01159907-a', 2), SenseInfo('02513614-a', 1), SenseInfo('02272670-a', 1), SenseInfo('01309220-a', 0), SenseInfo('00927978-a', 0), SenseInfo('00572392-a', 0) ],
"_finger_n_1_rel" : [ SenseInfo('05566504-n', 53), SenseInfo('13653461-n', 0), SenseInfo('03341153-n', 0) ],
"_scary_a_1_rel" : [ SenseInfo('00194924-a', 0), SenseInfo('00194924-a', 0) ],
"_billet_n_1_rel" : [ SenseInfo('06626286-n', 0), SenseInfo('02839200-n', 0), SenseInfo('00586262-n', 0) ],
"_tire_n_1_rel" : [ SenseInfo('04440749-n', 8), SenseInfo('04440749-n', 8), SenseInfo('04440749-n', 8), SenseInfo('04440749-n', 8) ],
"_better_a_for_rel" : [ SenseInfo('00230335-a', 69), SenseInfo('00231761-a', 23), SenseInfo('00067379-a', 8), SenseInfo('01471260-a', 0) ],
"_trough_n_1_rel" : [ SenseInfo('09462773-n', 4), SenseInfo('03471473-n', 1), SenseInfo('13893694-n', 0), SenseInfo('13357891-n', 0), SenseInfo('04488427-n', 0), SenseInfo('03717131-n', 0) ],
"_micrometer_n_1_rel" : [ SenseInfo('13658496-n', 0), SenseInfo('03759661-n', 0), SenseInfo('13658496-n', 0), SenseInfo('03759661-n', 0), SenseInfo('13658496-n', 0), SenseInfo('03759661-n', 0), SenseInfo('13658496-n', 0), SenseInfo('03759661-n', 0) ],
"_asphalt_n_1_rel" : [ SenseInfo('14769465-n', 1), SenseInfo('14667455-n', 0) ],
"_consecution_n_1_rel" : [  ],
"_unreliable_a_1_rel" : [ SenseInfo('00964590-a', 2), SenseInfo('00724861-a', 0), SenseInfo('02061126-a', 0), SenseInfo('01999180-a', 0), SenseInfo('00964590-a', 2), SenseInfo('00724861-a', 0), SenseInfo('02061126-a', 0), SenseInfo('01999180-a', 0) ],
"_confederacy_n_1_rel" : [ SenseInfo('09050244-n', 1), SenseInfo('08303275-n', 1), SenseInfo('08251303-n', 0), SenseInfo('06524935-n', 0) ],
"_handheld_n_1_rel" : [ SenseInfo('03149169-a', 0), SenseInfo('03149169-a', 0), SenseInfo('03149169-a', 0) ],
"_gardening_n_1_rel" : [ SenseInfo('00918383-n', 1) ],
"_impatience_n_1_rel" : [ SenseInfo('14407283-n', 4), SenseInfo('07514071-n', 1), SenseInfo('04642596-n', 0) ],
"_nighttime_n_1_rel" : [ SenseInfo('15167027-n', 1) ],
"_counter+suit_n_1_rel" : [ SenseInfo('01183373-n', 0), SenseInfo('01183373-n', 0), SenseInfo('01183373-n', 0), SenseInfo('01183373-n', 0), SenseInfo('01183373-n', 0), SenseInfo('01183373-n', 0), SenseInfo('01183373-n', 0), SenseInfo('01183373-n', 0) ],
"_self-generate_v_1_rel" : [  ],
"_rifle_v_from_rel" : [ SenseInfo('02344568-v', 1), SenseInfo('01318849-v', 0) ],
"_teapot_n_1_rel" : [ SenseInfo('04398044-n', 0) ],
"_chive_n_1_rel" : [ SenseInfo('12435152-n', 0) ],
"_remorseful_a_1_rel" : [ SenseInfo('01743506-a', 1) ],
"_supple_a_1_rel" : [ SenseInfo('01140290-a', 0), SenseInfo('01024228-a', 0), SenseInfo('01022785-a', 0), SenseInfo('01140290-a', 0), SenseInfo('01024228-a', 0), SenseInfo('01022785-a', 0), SenseInfo('01140290-a', 0), SenseInfo('01024228-a', 0), SenseInfo('01022785-a', 0) ],
"_forbid_v_1_rel" : [ SenseInfo('00795863-v', 15), SenseInfo('02452885-v', 1), SenseInfo('00795863-v', 15), SenseInfo('02452885-v', 1) ],
"_gradual_a_1_rel" : [ SenseInfo('01142804-a', 7), SenseInfo('01144359-a', 0), SenseInfo('01142804-a', 7), SenseInfo('01144359-a', 0) ],
"_prior_n_1_rel" : [ SenseInfo('10475940-n', 0) ],
"_smack+dab_x_deg_rel" : [  ],
"_typical_a_of_rel" : [ SenseInfo('02468635-a', 26), SenseInfo('00357556-a', 2), SenseInfo('01595440-a', 0), SenseInfo('02468635-a', 26), SenseInfo('00357556-a', 2), SenseInfo('01595440-a', 0), SenseInfo('02468635-a', 26), SenseInfo('00357556-a', 2), SenseInfo('01595440-a', 0) ],
"_unimposing_a_1_rel" : [ SenseInfo('01286659-a', 1), SenseInfo('01286659-a', 1) ],
"_crosswise_a_1_rel" : [ SenseInfo('01445705-a', 0), SenseInfo('01232917-a', 0), SenseInfo('01445705-a', 0), SenseInfo('01232917-a', 0) ],
"_brittle_n_1_rel" : [ SenseInfo('07599783-n', 0) ],
"_orientation_n_1_rel" : [ SenseInfo('01052372-n', 2), SenseInfo('06208021-n', 1), SenseInfo('13828075-n', 0), SenseInfo('06200344-n', 0), SenseInfo('05676755-n', 0), SenseInfo('00891512-n', 0) ],
"_snap_v_off_rel" : [ SenseInfo('00916274-v', 7), SenseInfo('01573515-v', 3), SenseInfo('00337065-v', 3), SenseInfo('01893771-v', 2), SenseInfo('00355670-v', 2), SenseInfo('02182851-v', 1), SenseInfo('02088949-v', 1), SenseInfo('01439745-v', 1), SenseInfo('01402872-v', 1), SenseInfo('01242208-v', 1), SenseInfo('01784295-v', 0), SenseInfo('01446301-v', 0), SenseInfo('01003249-v', 0), SenseInfo('00916274-v', 7), SenseInfo('01573515-v', 3), SenseInfo('00337065-v', 3), SenseInfo('01893771-v', 2), SenseInfo('00355670-v', 2), SenseInfo('02182851-v', 1), SenseInfo('02088949-v', 1), SenseInfo('01439745-v', 1), SenseInfo('01402872-v', 1), SenseInfo('01242208-v', 1), SenseInfo('01784295-v', 0), SenseInfo('01446301-v', 0), SenseInfo('01003249-v', 0) ],
"_cooper_n_1_rel" : [ SenseInfo('10909471-n', 0), SenseInfo('10909303-n', 0), SenseInfo('10909127-n', 0), SenseInfo('09963773-n', 0) ],
"_embarrassment_n_1_rel" : [ SenseInfo('07507098-n', 3), SenseInfo('13986189-n', 1), SenseInfo('07305551-n', 1), SenseInfo('05120116-n', 0) ],
"_brake_v_cause_rel" : [ SenseInfo('01863817-v', 0), SenseInfo('01863593-v', 0) ],
"_resigned_a_to_rel" : [  ],
"_retain_v_1_rel" : [ SenseInfo('02701628-v', 2), SenseInfo('02410175-v', 2), SenseInfo('02283324-v', 1), SenseInfo('00610010-v', 0) ],
"_overalls_n_1_rel" : [ SenseInfo('03863108-n', 4), SenseInfo('03863262-n', 0), SenseInfo('03863108-n', 4), SenseInfo('03863262-n', 0) ],
"_abnet_n_1_rel" : [  ],
"_terrifying_a_1_rel" : [ SenseInfo('00196449-a', 3) ],
"_interference_n_1_rel" : [ SenseInfo('06661562-n', 3), SenseInfo('01073995-n', 3), SenseInfo('07430211-n', 1), SenseInfo('00562643-n', 1), SenseInfo('03520811-n', 0) ],
"_cross_n_1_rel" : [ SenseInfo('03135532-n', 2), SenseInfo('04681387-n', 1), SenseInfo('03135152-n', 1), SenseInfo('14477667-n', 0), SenseInfo('01327322-n', 0), SenseInfo('00850425-n', 0) ],
"_fuck_v_over_rel" : [ SenseInfo('01426397-v', 0) ],
"_m505_n_1_rel" : [  ],
"_headlight_n_1_rel" : [ SenseInfo('03503997-n', 5) ],
"_co-star_n_1_rel" : [ SenseInfo('09967967-n', 0), SenseInfo('09967967-n', 0), SenseInfo('09967967-n', 0), SenseInfo('09967967-n', 0) ],
"_wreath_n_1_rel" : [ SenseInfo('04606014-n', 2) ],
"_chaff_v_1_rel" : [ SenseInfo('00855295-v', 1) ],
"_thanks_n_1_rel" : [ SenseInfo('07228971-n', 7), SenseInfo('01208797-n', 2), SenseInfo('07228971-n', 7), SenseInfo('01208797-n', 2) ],
"_each_p_rel" : [ SenseInfo('02269635-a', 64), SenseInfo('00239908-r', 7), SenseInfo('02269635-a', 64), SenseInfo('00239908-r', 7) ],
"_win_n_1_rel" : [ SenseInfo('07354731-n', 2), SenseInfo('13259917-n', 0) ],
"_nationalist_n_1_rel" : [ SenseInfo('10407310-n', 0), SenseInfo('10346015-n', 0) ],
"_urgent_a_for_rel" : [ SenseInfo('00713558-a', 6), SenseInfo('00713558-a', 6), SenseInfo('00713558-a', 6), SenseInfo('00713558-a', 6) ],
"_gasp_v_1_rel" : [ SenseInfo('00005526-v', 9), SenseInfo('00005526-v', 9) ],
"_governess_n_1_rel" : [ SenseInfo('10140169-n', 1) ],
"_analogous_a_to_rel" : [ SenseInfo('02071973-a', 6), SenseInfo('01221290-a', 0) ],
"_psycho_n_1_rel" : [ SenseInfo('10490141-n', 0) ],
"_backwards_p_rel" : [ SenseInfo('00074407-r', 1), SenseInfo('00075966-r', 0) ],
"_self-flagellation_n_1_rel" : [ SenseInfo('01162257-n', 1) ],
"_competence_n_1_rel" : [ SenseInfo('05153520-n', 7) ],
"_waterproof_n_1_rel" : [ SenseInfo('04561734-n', 0), SenseInfo('04049405-n', 0) ],
"_spread_v_out_rel" : [ SenseInfo('01378556-v', 24), SenseInfo('01380122-v', 6), SenseInfo('02689299-v', 5), SenseInfo('01579813-v', 5), SenseInfo('00968211-v', 5), SenseInfo('00969873-v', 4), SenseInfo('02082690-v', 3), SenseInfo('02060141-v', 3), SenseInfo('01611901-v', 0), SenseInfo('01611746-v', 0), SenseInfo('01378556-v', 24), SenseInfo('01380122-v', 6), SenseInfo('02689299-v', 5), SenseInfo('01579813-v', 5), SenseInfo('00968211-v', 5), SenseInfo('00969873-v', 4), SenseInfo('02082690-v', 3), SenseInfo('02060141-v', 3), SenseInfo('01611901-v', 0), SenseInfo('01611746-v', 0) ],
"_fictional_a_1_rel" : [ SenseInfo('02727706-a', 7), SenseInfo('01935935-a', 3) ],
"_bat_v_1_rel" : [ SenseInfo('01413173-v', 11), SenseInfo('00008195-v', 2), SenseInfo('01413561-v', 0), SenseInfo('01413436-v', 0), SenseInfo('01412912-v', 0) ],
"_catch_v_up_rel" : [ SenseInfo('00725748-v', 19), SenseInfo('02117955-v', 14), SenseInfo('01401115-v', 10), SenseInfo('01439190-v', 8), SenseInfo('01215421-v', 8), SenseInfo('01327816-v', 7), SenseInfo('01505958-v', 6), SenseInfo('01480149-v', 4), SenseInfo('02018372-v', 3), SenseInfo('02248299-v', 2), SenseInfo('01155090-v', 2), SenseInfo('00543016-v', 2), SenseInfo('02510905-v', 1), SenseInfo('02189168-v', 1), SenseInfo('02150948-v', 1), SenseInfo('01328012-v', 1), SenseInfo('00599835-v', 1), SenseInfo('00589904-v', 1), SenseInfo('00087988-v', 1), SenseInfo('02761134-v', 0), SenseInfo('02189398-v', 0), SenseInfo('02109645-v', 0), SenseInfo('01806505-v', 0), SenseInfo('01738107-v', 0), SenseInfo('01480469-v', 0), SenseInfo('01380366-v', 0), SenseInfo('01082454-v', 0), SenseInfo('00726009-v', 0), SenseInfo('00460357-v', 0), SenseInfo('00725748-v', 19), SenseInfo('02117955-v', 14), SenseInfo('01401115-v', 10), SenseInfo('01439190-v', 8), SenseInfo('01215421-v', 8), SenseInfo('01327816-v', 7), SenseInfo('01505958-v', 6), SenseInfo('01480149-v', 4), SenseInfo('02018372-v', 3), SenseInfo('02248299-v', 2), SenseInfo('01155090-v', 2), SenseInfo('00543016-v', 2), SenseInfo('02510905-v', 1), SenseInfo('02189168-v', 1), SenseInfo('02150948-v', 1), SenseInfo('01328012-v', 1), SenseInfo('00599835-v', 1), SenseInfo('00589904-v', 1), SenseInfo('00087988-v', 1), SenseInfo('02761134-v', 0), SenseInfo('02189398-v', 0), SenseInfo('02109645-v', 0), SenseInfo('01806505-v', 0), SenseInfo('01738107-v', 0), SenseInfo('01480469-v', 0), SenseInfo('01380366-v', 0), SenseInfo('01082454-v', 0), SenseInfo('00726009-v', 0), SenseInfo('00460357-v', 0), SenseInfo('00725748-v', 19), SenseInfo('02117955-v', 14), SenseInfo('01401115-v', 10), SenseInfo('01439190-v', 8), SenseInfo('01215421-v', 8), SenseInfo('01327816-v', 7), SenseInfo('01505958-v', 6), SenseInfo('01480149-v', 4), SenseInfo('02018372-v', 3), SenseInfo('02248299-v', 2), SenseInfo('01155090-v', 2), SenseInfo('00543016-v', 2), SenseInfo('02510905-v', 1), SenseInfo('02189168-v', 1), SenseInfo('02150948-v', 1), SenseInfo('01328012-v', 1), SenseInfo('00599835-v', 1), SenseInfo('00589904-v', 1), SenseInfo('00087988-v', 1), SenseInfo('02761134-v', 0), SenseInfo('02189398-v', 0), SenseInfo('02109645-v', 0), SenseInfo('01806505-v', 0), SenseInfo('01738107-v', 0), SenseInfo('01480469-v', 0), SenseInfo('01380366-v', 0), SenseInfo('01082454-v', 0), SenseInfo('00726009-v', 0), SenseInfo('00460357-v', 0), SenseInfo('00725748-v', 19), SenseInfo('02117955-v', 14), SenseInfo('01401115-v', 10), SenseInfo('01439190-v', 8), SenseInfo('01215421-v', 8), SenseInfo('01327816-v', 7), SenseInfo('01505958-v', 6), SenseInfo('01480149-v', 4), SenseInfo('02018372-v', 3), SenseInfo('02248299-v', 2), SenseInfo('01155090-v', 2), SenseInfo('00543016-v', 2), SenseInfo('02510905-v', 1), SenseInfo('02189168-v', 1), SenseInfo('02150948-v', 1), SenseInfo('01328012-v', 1), SenseInfo('00599835-v', 1), SenseInfo('00589904-v', 1), SenseInfo('00087988-v', 1), SenseInfo('02761134-v', 0), SenseInfo('02189398-v', 0), SenseInfo('02109645-v', 0), SenseInfo('01806505-v', 0), SenseInfo('01738107-v', 0), SenseInfo('01480469-v', 0), SenseInfo('01380366-v', 0), SenseInfo('01082454-v', 0), SenseInfo('00726009-v', 0), SenseInfo('00460357-v', 0), SenseInfo('00725748-v', 19), SenseInfo('02117955-v', 14), SenseInfo('01401115-v', 10), SenseInfo('01439190-v', 8), SenseInfo('01215421-v', 8), SenseInfo('01327816-v', 7), SenseInfo('01505958-v', 6), SenseInfo('01480149-v', 4), SenseInfo('02018372-v', 3), SenseInfo('02248299-v', 2), SenseInfo('01155090-v', 2), SenseInfo('00543016-v', 2), SenseInfo('02510905-v', 1), SenseInfo('02189168-v', 1), SenseInfo('02150948-v', 1), SenseInfo('01328012-v', 1), SenseInfo('00599835-v', 1), SenseInfo('00589904-v', 1), SenseInfo('00087988-v', 1), SenseInfo('02761134-v', 0), SenseInfo('02189398-v', 0), SenseInfo('02109645-v', 0), SenseInfo('01806505-v', 0), SenseInfo('01738107-v', 0), SenseInfo('01480469-v', 0), SenseInfo('01380366-v', 0), SenseInfo('01082454-v', 0), SenseInfo('00726009-v', 0), SenseInfo('00460357-v', 0), SenseInfo('00725748-v', 19), SenseInfo('02117955-v', 14), SenseInfo('01401115-v', 10), SenseInfo('01439190-v', 8), SenseInfo('01215421-v', 8), SenseInfo('01327816-v', 7), SenseInfo('01505958-v', 6), SenseInfo('01480149-v', 4), SenseInfo('02018372-v', 3), SenseInfo('02248299-v', 2), SenseInfo('01155090-v', 2), SenseInfo('00543016-v', 2), SenseInfo('02510905-v', 1), SenseInfo('02189168-v', 1), SenseInfo('02150948-v', 1), SenseInfo('01328012-v', 1), SenseInfo('00599835-v', 1), SenseInfo('00589904-v', 1), SenseInfo('00087988-v', 1), SenseInfo('02761134-v', 0), SenseInfo('02189398-v', 0), SenseInfo('02109645-v', 0), SenseInfo('01806505-v', 0), SenseInfo('01738107-v', 0), SenseInfo('01480469-v', 0), SenseInfo('01380366-v', 0), SenseInfo('01082454-v', 0), SenseInfo('00726009-v', 0), SenseInfo('00460357-v', 0) ],
"_trashman_n_1_rel" : [  ],
"_hiss_v_1_rel" : [ SenseInfo('01053771-v', 1), SenseInfo('02069014-v', 0), SenseInfo('01054186-v', 0), SenseInfo('00862225-v', 0), SenseInfo('01053771-v', 1), SenseInfo('02069014-v', 0), SenseInfo('01054186-v', 0), SenseInfo('00862225-v', 0), SenseInfo('01053771-v', 1), SenseInfo('02069014-v', 0), SenseInfo('01054186-v', 0), SenseInfo('00862225-v', 0) ],
"_pinpoint_v_1_rel" : [ SenseInfo('02287380-v', 3), SenseInfo('02287380-v', 3), SenseInfo('02287380-v', 3), SenseInfo('02287380-v', 3), SenseInfo('02287380-v', 3), SenseInfo('02287380-v', 3) ],
"_north+korean_n_1_rel" : [ SenseInfo('09719105-n', 2) ],
"_high+up_a_1_rel" : [  ],
"_chairlift_n_1_rel" : [ SenseInfo('03002341-n', 0) ],
"_bother_v_about_rel" : [ SenseInfo('02507464-v', 18), SenseInfo('01787955-v', 16), SenseInfo('02507736-v', 8), SenseInfo('02018858-v', 0), SenseInfo('01791535-v', 0), SenseInfo('01791408-v', 0) ],
"_ovary_n_1_rel" : [ SenseInfo('11678635-n', 0), SenseInfo('05515287-n', 0) ],
"_potential_n_1_rel" : [ SenseInfo('14482620-n', 10), SenseInfo('11493827-n', 0), SenseInfo('14482620-n', 10), SenseInfo('11493827-n', 0), SenseInfo('14482620-n', 10), SenseInfo('11493827-n', 0), SenseInfo('14482620-n', 10), SenseInfo('11493827-n', 0) ],
"_elate_v_1_rel" : [ SenseInfo('01811736-v', 1) ],
"_wend_v_1_rel" : [ SenseInfo('01841347-v', 2) ],
"_referendum_n_1_rel" : [ SenseInfo('00181640-n', 1) ],
"_rebound_v_1_rel" : [ SenseInfo('01892104-v', 1), SenseInfo('00528608-v', 0) ],
"_anonymity_n_1_rel" : [ SenseInfo('14436285-n', 1) ],
"_coexistence_n_1_rel" : [ SenseInfo('13957268-n', 2), SenseInfo('13957268-n', 2) ],
"_default_v_1_rel" : [ SenseInfo('02253766-v', 1) ],
"_foray_n_1_rel" : [ SenseInfo('00976953-n', 0), SenseInfo('00787307-n', 0) ],
"_massive_a_1_rel" : [ SenseInfo('01389170-a', 9), SenseInfo('02263875-a', 0), SenseInfo('01389451-a', 0), SenseInfo('01185916-a', 0), SenseInfo('01389170-a', 9), SenseInfo('02263875-a', 0), SenseInfo('01389451-a', 0), SenseInfo('01185916-a', 0) ],
"_audio+visual_a_1_rel" : [ SenseInfo('02648392-a', 0), SenseInfo('02648392-a', 0) ],
"_please_v_1_rel" : [ SenseInfo('01815628-v', 15), SenseInfo('01824958-v', 10), SenseInfo('01816054-v', 0), SenseInfo('01815628-v', 15), SenseInfo('01824958-v', 10), SenseInfo('01816054-v', 0), SenseInfo('01815628-v', 15), SenseInfo('01824958-v', 10), SenseInfo('01816054-v', 0), SenseInfo('01815628-v', 15), SenseInfo('01824958-v', 10), SenseInfo('01816054-v', 0) ],
"_worship_v_1_rel" : [ SenseInfo('01778017-v', 5), SenseInfo('01778990-v', 2), SenseInfo('02613275-v', 1) ],
"_truck_n_1_rel" : [ SenseInfo('04490091-n', 20), SenseInfo('03490119-n', 0) ],
"_vocable_n_1_rel" : [ SenseInfo('06304576-n', 0) ],
"_wort_n_1_rel" : [ SenseInfo('13085747-n', 0), SenseInfo('07889193-n', 0) ],
"_membrane_n_1_rel" : [ SenseInfo('03743761-n', 1), SenseInfo('05426243-n', 0) ],
"_respect_n_for_rel" : [ SenseInfo('05820170-n', 15), SenseInfo('14437552-n', 5), SenseInfo('06206800-n', 5), SenseInfo('01228877-n', 1), SenseInfo('01132864-n', 1), SenseInfo('07545415-n', 0), SenseInfo('04913839-n', 0), SenseInfo('05820170-n', 15), SenseInfo('14437552-n', 5), SenseInfo('06206800-n', 5), SenseInfo('01228877-n', 1), SenseInfo('01132864-n', 1), SenseInfo('07545415-n', 0), SenseInfo('04913839-n', 0), SenseInfo('05820170-n', 15), SenseInfo('14437552-n', 5), SenseInfo('06206800-n', 5), SenseInfo('01228877-n', 1), SenseInfo('01132864-n', 1), SenseInfo('07545415-n', 0), SenseInfo('04913839-n', 0), SenseInfo('05820170-n', 15), SenseInfo('14437552-n', 5), SenseInfo('06206800-n', 5), SenseInfo('01228877-n', 1), SenseInfo('01132864-n', 1), SenseInfo('07545415-n', 0), SenseInfo('04913839-n', 0) ],
"_hunt_v_down_rel" : [ SenseInfo('01143838-v', 4), SenseInfo('02003601-v', 2), SenseInfo('02056691-v', 0), SenseInfo('02034147-v', 0), SenseInfo('01878376-v', 0), SenseInfo('01316401-v', 0), SenseInfo('01144657-v', 0) ],
"_rock_v_1_rel" : [ SenseInfo('01875295-v', 6), SenseInfo('01876028-v', 0) ],
"_architrave_n_1_rel" : [ SenseInfo('02734994-n', 0), SenseInfo('02734835-n', 0) ],
"_gobble_v_1_rel" : [ SenseInfo('01173933-v', 2), SenseInfo('01058426-v', 1) ],
"_locality_n_1_rel" : [ SenseInfo('08641113-n', 6), SenseInfo('08641113-n', 6) ],
"_halfway_x_deg_rel" : [ SenseInfo('00255415-r', 5), SenseInfo('00330506-a', 4), SenseInfo('01014838-a', 1), SenseInfo('00517710-a', 0) ],
"_flyfishing_n_1_rel" : [  ],
"_shanty_n_1_rel" : [ SenseInfo('03547054-n', 1), SenseInfo('07050042-n', 0) ],
"_dioxide_n_1_rel" : [ SenseInfo('14836127-n', 0) ],
"_wane_v_1_rel" : [ SenseInfo('00431826-v', 2), SenseInfo('00433933-v', 1), SenseInfo('00433778-v', 0) ],
"_burgundy_n_1_rel" : [ SenseInfo('08941057-n', 0), SenseInfo('07893891-n', 0), SenseInfo('04963905-n', 0) ],
"_segregate_v_1_rel" : [ SenseInfo('02482139-v', 5), SenseInfo('01558218-v', 0), SenseInfo('00494613-v', 0) ],
"_lifespan_n_1_rel" : [ SenseInfo('15140405-n', 0) ],
"_whip_v_in_rel" : [ SenseInfo('01411085-v', 8), SenseInfo('01102997-v', 4), SenseInfo('01891092-v', 3), SenseInfo('01398032-v', 3), SenseInfo('01417868-v', 0), SenseInfo('00863906-v', 0) ],
"_exhausted_a_1_rel" : [ SenseInfo('02433451-a', 6), SenseInfo('00926141-a', 0), SenseInfo('01088881-a', 0) ],
"_normal_a_for_rel" : [ SenseInfo('01593649-a', 77), SenseInfo('01599445-a', 1), SenseInfo('01598319-a', 0), SenseInfo('01720549-a', 0), SenseInfo('01593649-a', 77), SenseInfo('01599445-a', 1), SenseInfo('01598319-a', 0), SenseInfo('01720549-a', 0), SenseInfo('01593649-a', 77), SenseInfo('01599445-a', 1), SenseInfo('01598319-a', 0), SenseInfo('01720549-a', 0), SenseInfo('01593649-a', 77), SenseInfo('01599445-a', 1), SenseInfo('01598319-a', 0), SenseInfo('01720549-a', 0), SenseInfo('01593649-a', 77), SenseInfo('01599445-a', 1), SenseInfo('01598319-a', 0), SenseInfo('01720549-a', 0), SenseInfo('01593649-a', 77), SenseInfo('01599445-a', 1), SenseInfo('01598319-a', 0), SenseInfo('01720549-a', 0) ],
"_agree_v_to_rel" : [ SenseInfo('00805376-v', 62), SenseInfo('00764222-v', 25), SenseInfo('02657219-v', 4), SenseInfo('02700104-v', 1), SenseInfo('02741793-v', 0), SenseInfo('02291135-v', 0), SenseInfo('01035530-v', 0) ],
"_slipway_n_1_rel" : [ SenseInfo('04565039-n', 0) ],
"_arthritis_n_1_rel" : [ SenseInfo('14186541-n', 2) ],
"_major_n_abb_rel" : [ SenseInfo('10283170-n', 2), SenseInfo('11150634-n', 0), SenseInfo('10283366-n', 0), SenseInfo('05997659-n', 0), SenseInfo('10283170-n', 2), SenseInfo('11150634-n', 0), SenseInfo('10283366-n', 0), SenseInfo('05997659-n', 0) ],
"_toll+free_a_1_rel" : [ SenseInfo('02816522-a', 0) ],
"_marry_v_1_rel" : [ SenseInfo('02488834-v', 44), SenseInfo('02489456-v', 2) ],
"_vitality_n_1_rel" : [ SenseInfo('04633453-n', 8), SenseInfo('14050143-n', 1), SenseInfo('11523839-n', 0), SenseInfo('05005809-n', 0) ],
"_national+park_n_1_rel" : [ SenseInfo('08600992-n', 1) ],
"_hang_v_up_rel" : [ SenseInfo('01482075-v', 35), SenseInfo('01481360-v', 12), SenseInfo('02485451-v', 11), SenseInfo('01977962-v', 6), SenseInfo('01542668-v', 5), SenseInfo('02734952-v', 2), SenseInfo('02170427-v', 1), SenseInfo('01481957-v', 1), SenseInfo('01216331-v', 1), SenseInfo('02741003-v', 0), SenseInfo('02557790-v', 0), SenseInfo('01677716-v', 0), SenseInfo('01481819-v', 0), SenseInfo('01481647-v', 0), SenseInfo('00210110-v', 0), SenseInfo('01482075-v', 35), SenseInfo('01481360-v', 12), SenseInfo('02485451-v', 11), SenseInfo('01977962-v', 6), SenseInfo('01542668-v', 5), SenseInfo('02734952-v', 2), SenseInfo('02170427-v', 1), SenseInfo('01481957-v', 1), SenseInfo('01216331-v', 1), SenseInfo('02741003-v', 0), SenseInfo('02557790-v', 0), SenseInfo('01677716-v', 0), SenseInfo('01481819-v', 0), SenseInfo('01481647-v', 0), SenseInfo('00210110-v', 0) ],
"_magnificent_a_1_rel" : [ SenseInfo('01285376-a', 12), SenseInfo('01285376-a', 12) ],
"_dainty_a_1_rel" : [ SenseInfo('01948092-a', 1), SenseInfo('00706311-a', 1), SenseInfo('02396578-a', 0), SenseInfo('00984333-a', 0), SenseInfo('01948092-a', 1), SenseInfo('00706311-a', 1), SenseInfo('02396578-a', 0), SenseInfo('00984333-a', 0), SenseInfo('01948092-a', 1), SenseInfo('00706311-a', 1), SenseInfo('02396578-a', 0), SenseInfo('00984333-a', 0), SenseInfo('01948092-a', 1), SenseInfo('00706311-a', 1), SenseInfo('02396578-a', 0), SenseInfo('00984333-a', 0) ],
"_bear_v_with_rel" : [ SenseInfo('02630871-v', 23), SenseInfo('00056930-v', 17), SenseInfo('00668099-v', 13), SenseInfo('01432601-v', 10), SenseInfo('01652139-v', 6), SenseInfo('02301825-v', 5), SenseInfo('02700867-v', 4), SenseInfo('02291708-v', 4), SenseInfo('00047745-v', 1), SenseInfo('02518161-v', 0), SenseInfo('02302220-v', 0), SenseInfo('01601234-v', 0), SenseInfo('00059019-v', 0) ],
"_mitten_n_1_rel" : [ SenseInfo('03775071-n', 0) ],
"_heartwarming_a_1_rel" : [ SenseInfo('01561280-a', 0), SenseInfo('01561280-a', 0), SenseInfo('01561280-a', 0), SenseInfo('01561280-a', 0) ],
"_martyr_v_1_rel" : [ SenseInfo('01605021-v', 0), SenseInfo('00071646-v', 0) ],
"_uncool_a_1_rel" : [ SenseInfo('01129533-a', 0), SenseInfo('01129533-a', 0) ],
"_identify_v_as_rel" : [ SenseInfo('00618878-v', 32), SenseInfo('01026095-v', 7), SenseInfo('00691944-v', 6), SenseInfo('00714531-v', 4), SenseInfo('00652346-v', 2), SenseInfo('00618451-v', 2), SenseInfo('00618878-v', 32), SenseInfo('01026095-v', 7), SenseInfo('00691944-v', 6), SenseInfo('00714531-v', 4), SenseInfo('00652346-v', 2), SenseInfo('00618451-v', 2), SenseInfo('00618878-v', 32), SenseInfo('01026095-v', 7), SenseInfo('00691944-v', 6), SenseInfo('00714531-v', 4), SenseInfo('00652346-v', 2), SenseInfo('00618451-v', 2) ],
"_rivet_n_1_rel" : [ SenseInfo('04343346-n', 0), SenseInfo('04095342-n', 0) ],
"_overnight_a_1_rel" : [ SenseInfo('01441530-a', 2), SenseInfo('01441530-a', 2), SenseInfo('01441530-a', 2) ],
"_renter_n_1_rel" : [ SenseInfo('10700201-n', 0), SenseInfo('10520804-n', 0) ],
"_acclimate_v_to_rel" : [ SenseInfo('00393677-v', 0), SenseInfo('00393677-v', 0) ],
"_prospecting_n_1_rel" : [  ],
"_left-wing_a_1_rel" : [ SenseInfo('02031335-a', 0), SenseInfo('02031335-a', 0) ],
"_pickler_n_1_rel" : [  ],
"_unemployed_n_1_rel" : [ SenseInfo('08477307-n', 0) ],
"_borderline_x_deg_rel" : [ SenseInfo('01496311-a', 1), SenseInfo('08512736-n', 0) ],
"_vaccine_n_1_rel" : [ SenseInfo('04517535-n', 1) ],
"_fit_v_in_rel" : [ SenseInfo('02702830-v', 14), SenseInfo('02659763-v', 11), SenseInfo('02667900-v', 9), SenseInfo('00300537-v', 7), SenseInfo('00300113-v', 5), SenseInfo('02657219-v', 4), SenseInfo('02735753-v', 1), SenseInfo('02339413-v', 1), SenseInfo('00456740-v', 0), SenseInfo('02702830-v', 14), SenseInfo('02659763-v', 11), SenseInfo('02667900-v', 9), SenseInfo('00300537-v', 7), SenseInfo('00300113-v', 5), SenseInfo('02657219-v', 4), SenseInfo('02735753-v', 1), SenseInfo('02339413-v', 1), SenseInfo('00456740-v', 0), SenseInfo('02702830-v', 14), SenseInfo('02659763-v', 11), SenseInfo('02667900-v', 9), SenseInfo('00300537-v', 7), SenseInfo('00300113-v', 5), SenseInfo('02657219-v', 4), SenseInfo('02735753-v', 1), SenseInfo('02339413-v', 1), SenseInfo('00456740-v', 0) ],
"_liberalism_n_1_rel" : [ SenseInfo('06218623-n', 6), SenseInfo('05995576-n', 1) ],
"_mutton_n_1_rel" : [ SenseInfo('07666733-n', 2) ],
"_slow_a_1_rel" : [ SenseInfo('00980527-a', 23), SenseInfo('00982602-a', 3), SenseInfo('00440579-a', 1), SenseInfo('00983722-a', 0), SenseInfo('01345307-a', 0), SenseInfo('00036998-a', 0), SenseInfo('00980527-a', 23), SenseInfo('00982602-a', 3), SenseInfo('00440579-a', 1), SenseInfo('00983722-a', 0), SenseInfo('01345307-a', 0), SenseInfo('00036998-a', 0), SenseInfo('00980527-a', 23), SenseInfo('00982602-a', 3), SenseInfo('00440579-a', 1), SenseInfo('00983722-a', 0), SenseInfo('01345307-a', 0), SenseInfo('00036998-a', 0), SenseInfo('00980527-a', 23), SenseInfo('00982602-a', 3), SenseInfo('00440579-a', 1), SenseInfo('00983722-a', 0), SenseInfo('01345307-a', 0), SenseInfo('00036998-a', 0), SenseInfo('00980527-a', 23), SenseInfo('00982602-a', 3), SenseInfo('00440579-a', 1), SenseInfo('00983722-a', 0), SenseInfo('01345307-a', 0), SenseInfo('00036998-a', 0), SenseInfo('00980527-a', 23), SenseInfo('00982602-a', 3), SenseInfo('00440579-a', 1), SenseInfo('00983722-a', 0), SenseInfo('01345307-a', 0), SenseInfo('00036998-a', 0) ],
"_bomb_v_out_rel" : [ SenseInfo('01131902-v', 3), SenseInfo('02523521-v', 0) ],
"_desperate_n_1_rel" : [ SenseInfo('10008535-n', 1) ],
"_reproducibility_n_of_rel" : [ SenseInfo('04806169-n', 2) ],
"_natal_a_1_rel" : [ SenseInfo('02767378-a', 1), SenseInfo('02767514-a', 0) ],
"_as+if_x_rel" : [  ],
"_garbled_a_1_rel" : [ SenseInfo('00465221-a', 1) ],
"_documentation_n_of_rel" : [ SenseInfo('06650431-n', 0), SenseInfo('06588326-n', 0), SenseInfo('00154433-n', 0) ],
"_empire_n_1_rel" : [ SenseInfo('08557482-n', 3), SenseInfo('08052413-n', 1), SenseInfo('08405723-n', 0), SenseInfo('08058937-n', 0), SenseInfo('07740597-n', 0) ],
"_curse_n_1_rel" : [ SenseInfo('07125096-n', 5), SenseInfo('07233634-n', 1), SenseInfo('07160424-n', 1), SenseInfo('14445226-n', 0), SenseInfo('07420354-n', 0) ],
"_argumentation_n_1_rel" : [ SenseInfo('07140978-n', 0), SenseInfo('05773049-n', 0) ],
"_mourn_v_1_rel" : [ SenseInfo('01797051-v', 6), SenseInfo('01797204-v', 1) ],
"_certain_q_rel" : [  ],
"_permutation_n_of_rel" : [ SenseInfo('07443761-n', 0), SenseInfo('00870312-n', 0), SenseInfo('00399223-n', 0), SenseInfo('00339646-n', 0) ],
"_far+away_a_1_rel" : [ SenseInfo('00443274-a', 5), SenseInfo('00450915-a', 0) ],
"_warfare_n_1_rel" : [ SenseInfo('00973077-n', 9), SenseInfo('01236296-n', 1) ],
"_auction_v_off_rel" : [ SenseInfo('02244773-v', 0) ],
"_intermediary_a_1_rel" : [ SenseInfo('09624559-n', 1) ],
"_mammal_n_1_rel" : [ SenseInfo('01861778-n', 3), SenseInfo('01861778-n', 3) ],
"_timberline_n_1_rel" : [ SenseInfo('08547655-n', 0) ],
"_unknown_a_1_rel" : [ SenseInfo('01376894-a', 13), SenseInfo('00120784-a', 2), SenseInfo('02370625-a', 1), SenseInfo('01122595-a', 1), SenseInfo('00966753-a', 0), SenseInfo('01376894-a', 13), SenseInfo('00120784-a', 2), SenseInfo('02370625-a', 1), SenseInfo('01122595-a', 1), SenseInfo('00966753-a', 0) ],
"_extinction_n_1_rel" : [ SenseInfo('14012173-n', 0), SenseInfo('13963032-n', 0), SenseInfo('13478342-n', 0), SenseInfo('07332691-n', 0), SenseInfo('05758692-n', 0), SenseInfo('00229934-n', 0) ],
"_man+and+wife_n_1_rel" : [ SenseInfo('07989373-n', 1) ],
"_strike_v_off_rel" : [ SenseInfo('01410223-v', 18), SenseInfo('01767949-v', 16), SenseInfo('01236164-v', 14), SenseInfo('01123887-v', 7), SenseInfo('00923622-v', 5), SenseInfo('01209135-v', 4), SenseInfo('02412647-v', 3), SenseInfo('02611976-v', 2), SenseInfo('02526811-v', 2), SenseInfo('01209426-v', 2), SenseInfo('00143540-v', 2), SenseInfo('02286687-v', 1), SenseInfo('01675073-v', 1), SenseInfo('01549420-v', 1), SenseInfo('02108791-v', 0), SenseInfo('02104161-v', 0), SenseInfo('01982395-v', 0), SenseInfo('01639105-v', 0), SenseInfo('01308008-v', 0), SenseInfo('01228235-v', 0), SenseInfo('00635904-v', 0), SenseInfo('01410223-v', 18), SenseInfo('01767949-v', 16), SenseInfo('01236164-v', 14), SenseInfo('01123887-v', 7), SenseInfo('00923622-v', 5), SenseInfo('01209135-v', 4), SenseInfo('02412647-v', 3), SenseInfo('02611976-v', 2), SenseInfo('02526811-v', 2), SenseInfo('01209426-v', 2), SenseInfo('00143540-v', 2), SenseInfo('02286687-v', 1), SenseInfo('01675073-v', 1), SenseInfo('01549420-v', 1), SenseInfo('02108791-v', 0), SenseInfo('02104161-v', 0), SenseInfo('01982395-v', 0), SenseInfo('01639105-v', 0), SenseInfo('01308008-v', 0), SenseInfo('01228235-v', 0), SenseInfo('00635904-v', 0) ],
"_radius_n_1_rel" : [ SenseInfo('05102101-n', 4), SenseInfo('13871538-n', 1), SenseInfo('08628578-n', 1), SenseInfo('05593318-n', 0), SenseInfo('04283378-n', 0) ],
"_bloom_v_1_rel" : [ SenseInfo('00294245-v', 11) ],
"_broad_a_1_rel" : [ SenseInfo('02560548-a', 14), SenseInfo('00526062-a', 12), SenseInfo('01101891-a', 5), SenseInfo('00428878-a', 2), SenseInfo('01211531-a', 1), SenseInfo('01384212-a', 0), SenseInfo('01287160-a', 0), SenseInfo('00286837-a', 0), SenseInfo('02560548-a', 14), SenseInfo('00526062-a', 12), SenseInfo('01101891-a', 5), SenseInfo('00428878-a', 2), SenseInfo('01211531-a', 1), SenseInfo('01384212-a', 0), SenseInfo('01287160-a', 0), SenseInfo('00286837-a', 0), SenseInfo('02560548-a', 14), SenseInfo('00526062-a', 12), SenseInfo('01101891-a', 5), SenseInfo('00428878-a', 2), SenseInfo('01211531-a', 1), SenseInfo('01384212-a', 0), SenseInfo('01287160-a', 0), SenseInfo('00286837-a', 0), SenseInfo('02560548-a', 14), SenseInfo('00526062-a', 12), SenseInfo('01101891-a', 5), SenseInfo('00428878-a', 2), SenseInfo('01211531-a', 1), SenseInfo('01384212-a', 0), SenseInfo('01287160-a', 0), SenseInfo('00286837-a', 0) ],
"_loud_a_1_rel" : [ SenseInfo('01452593-a', 50), SenseInfo('02393791-a', 1), SenseInfo('01458736-a', 0), SenseInfo('01452593-a', 50), SenseInfo('02393791-a', 1), SenseInfo('01458736-a', 0), SenseInfo('01452593-a', 50), SenseInfo('02393791-a', 1), SenseInfo('01458736-a', 0), SenseInfo('01452593-a', 50), SenseInfo('02393791-a', 1), SenseInfo('01458736-a', 0) ],
"_iranian_a_1_rel" : [ SenseInfo('03075191-a', 0) ],
"_durable_a_1_rel" : [ SenseInfo('01439496-a', 1), SenseInfo('02124096-a', 0), SenseInfo('01754049-a', 0) ],
"_cleaner_n_of_rel" : [ SenseInfo('03040587-n', 4), SenseInfo('09927305-n', 0), SenseInfo('09927089-n', 0) ],
"_bourbon_n_1_rel" : [ SenseInfo('09869706-n', 7), SenseInfo('07906718-n', 1), SenseInfo('09869578-n', 0), SenseInfo('08154012-n', 0) ],
"_forsake_v_1_rel" : [ SenseInfo('00614057-v', 4) ],
"_outset_n_1_rel" : [ SenseInfo('15265518-n', 4) ],
"_help_v_along_rel" : [ SenseInfo('02547586-v', 183), SenseInfo('00082081-v', 23), SenseInfo('02735897-v', 19), SenseInfo('02726164-v', 5), SenseInfo('01181295-v', 2), SenseInfo('02555434-v', 0), SenseInfo('01193569-v', 0), SenseInfo('00206998-v', 0) ],
"_email_v_1_rel" : [ SenseInfo('01032451-v', 0), SenseInfo('01032451-v', 0), SenseInfo('01032451-v', 0), SenseInfo('01032451-v', 0), SenseInfo('01032451-v', 0), SenseInfo('01032451-v', 0), SenseInfo('01032451-v', 0), SenseInfo('01032451-v', 0) ],
"_battlefield_n_1_rel" : [ SenseInfo('08506641-n', 5) ],
"_raid_v_1_rel" : [ SenseInfo('02494850-v', 2), SenseInfo('02020027-v', 2), SenseInfo('02275152-v', 0), SenseInfo('01318081-v', 0) ],
"_scotch_v_1_rel" : [ SenseInfo('02558172-v', 0), SenseInfo('01276080-v', 0) ],
"_vocation_n_1_rel" : [ SenseInfo('00583246-n', 2), SenseInfo('08403631-n', 0) ],
"_awful_a_1_rel" : [ SenseInfo('01126291-a', 10), SenseInfo('00193799-a', 4), SenseInfo('01587077-a', 0), SenseInfo('02012157-a', 0), SenseInfo('01677200-a', 0), SenseInfo('01282510-a', 0), SenseInfo('01126291-a', 10), SenseInfo('00193799-a', 4), SenseInfo('01587077-a', 0), SenseInfo('02012157-a', 0), SenseInfo('01677200-a', 0), SenseInfo('01282510-a', 0), SenseInfo('01126291-a', 10), SenseInfo('00193799-a', 4), SenseInfo('01587077-a', 0), SenseInfo('02012157-a', 0), SenseInfo('01677200-a', 0), SenseInfo('01282510-a', 0), SenseInfo('01126291-a', 10), SenseInfo('00193799-a', 4), SenseInfo('01587077-a', 0), SenseInfo('02012157-a', 0), SenseInfo('01677200-a', 0), SenseInfo('01282510-a', 0), SenseInfo('01126291-a', 10), SenseInfo('00193799-a', 4), SenseInfo('01587077-a', 0), SenseInfo('02012157-a', 0), SenseInfo('01677200-a', 0), SenseInfo('01282510-a', 0) ],
"_sac_n_1_rel" : [ SenseInfo('13914473-n', 0), SenseInfo('13092722-n', 0), SenseInfo('09667715-n', 0), SenseInfo('05515670-n', 0) ],
"_african_a_1_rel" : [ SenseInfo('02941790-a', 5) ],
"_eject_v_1_rel" : [ SenseInfo('01468576-v', 2), SenseInfo('00104868-v', 1), SenseInfo('02076999-v', 0), SenseInfo('01375637-v', 0) ],
"_jobless_a_1_rel" : [ SenseInfo('00865007-a', 0) ],
"_lamination_n_of_rel" : [ SenseInfo('03635932-n', 0), SenseInfo('00926923-n', 0) ],
"_giddy_a_1_rel" : [ SenseInfo('02544048-a', 0), SenseInfo('02120828-a', 0), SenseInfo('02544048-a', 0), SenseInfo('02120828-a', 0), SenseInfo('02544048-a', 0), SenseInfo('02120828-a', 0) ],
"_rivet_v_1_rel" : [ SenseInfo('00722232-v', 2), SenseInfo('01367266-v', 0), SenseInfo('00722675-v', 0), SenseInfo('00722232-v', 2), SenseInfo('01367266-v', 0), SenseInfo('00722675-v', 0) ],
"_drunken_a_1_rel" : [ SenseInfo('00798491-a', 4) ],
"_recyclable_n_1_rel" : [ SenseInfo('02496425-a', 0) ],
"_holler_v_1_rel" : [ SenseInfo('00915423-v', 3), SenseInfo('00913065-v', 2), SenseInfo('00910973-v', 1) ],
"_stratagem_n_1_rel" : [ SenseInfo('00172490-n', 1), SenseInfo('05905802-n', 0) ],
"_ways_n_1_rel" : [ SenseInfo('04928903-n', 183), SenseInfo('00172710-n', 61), SenseInfo('08679972-n', 40), SenseInfo('13939604-n', 28), SenseInfo('00415676-n', 19), SenseInfo('04564698-n', 16), SenseInfo('00312691-n', 12), SenseInfo('13777764-n', 10), SenseInfo('05084733-n', 7), SenseInfo('05791764-n', 3), SenseInfo('05839910-n', 1), SenseInfo('13285973-n', 0) ],
"_recreant_a_1_rel" : [ SenseInfo('00963858-a', 0), SenseInfo('00265496-a', 0) ],
"_gauche_a_1_rel" : [ SenseInfo('00851329-a', 1) ],
"_hydrometer_n_1_rel" : [ SenseInfo('03553486-n', 0) ],
"_output_v_1_rel" : [ SenseInfo('01622795-v', 1), SenseInfo('01622795-v', 1) ],
"_engine_n_1_rel" : [ SenseInfo('03287733-n', 9), SenseInfo('11417561-n', 2), SenseInfo('03684823-n', 1), SenseInfo('03288003-n', 0) ],
"_sultan_n_1_rel" : [ SenseInfo('10674315-n', 1) ],
"_pixel_n_1_rel" : [ SenseInfo('03952277-n', 0) ],
"_spacewalk_v_1_rel" : [ SenseInfo('01906202-v', 0) ],
"_accommodating_a_1_rel" : [ SenseInfo('00020787-a', 0), SenseInfo('01195963-a', 0) ],
"_rain_n_1_rel" : [ SenseInfo('11501381-n', 25), SenseInfo('15008607-n', 5), SenseInfo('05045208-n', 0) ],
"_a+full_x_deg_rel" : [  ],
"_burst_v_1_rel" : [ SenseInfo('00309310-v', 11), SenseInfo('01785395-v', 7), SenseInfo('00306017-v', 7), SenseInfo('01964634-v', 4), SenseInfo('02715595-v', 2), SenseInfo('00424224-v', 2), SenseInfo('01989562-v', 0), SenseInfo('00333594-v', 0), SenseInfo('00309310-v', 11), SenseInfo('01785395-v', 7), SenseInfo('00306017-v', 7), SenseInfo('01964634-v', 4), SenseInfo('02715595-v', 2), SenseInfo('00424224-v', 2), SenseInfo('01989562-v', 0), SenseInfo('00333594-v', 0) ],
"_attorney_n_1_rel" : [ SenseInfo('10249950-n', 8) ],
"_strong_a_1_rel" : [ SenseInfo('02321009-a', 58), SenseInfo('01513512-a', 9), SenseInfo('01826979-a', 3), SenseInfo('01824244-a', 0), SenseInfo('02526124-a', 0), SenseInfo('02275412-a', 0), SenseInfo('01961786-a', 0), SenseInfo('01158974-a', 0), SenseInfo('01068609-a', 0), SenseInfo('00842199-a', 0), SenseInfo('02321009-a', 58), SenseInfo('01513512-a', 9), SenseInfo('01826979-a', 3), SenseInfo('01824244-a', 0), SenseInfo('02526124-a', 0), SenseInfo('02275412-a', 0), SenseInfo('01961786-a', 0), SenseInfo('01158974-a', 0), SenseInfo('01068609-a', 0), SenseInfo('00842199-a', 0), SenseInfo('02321009-a', 58), SenseInfo('01513512-a', 9), SenseInfo('01826979-a', 3), SenseInfo('01824244-a', 0), SenseInfo('02526124-a', 0), SenseInfo('02275412-a', 0), SenseInfo('01961786-a', 0), SenseInfo('01158974-a', 0), SenseInfo('01068609-a', 0), SenseInfo('00842199-a', 0), SenseInfo('02321009-a', 58), SenseInfo('01513512-a', 9), SenseInfo('01826979-a', 3), SenseInfo('01824244-a', 0), SenseInfo('02526124-a', 0), SenseInfo('02275412-a', 0), SenseInfo('01961786-a', 0), SenseInfo('01158974-a', 0), SenseInfo('01068609-a', 0), SenseInfo('00842199-a', 0) ],
"_dictate_n_1_rel" : [ SenseInfo('06663940-n', 1), SenseInfo('05871245-n', 1) ],
"_wilco_a_1_rel" : [  ],
"_jet+lag_n_1_rel" : [ SenseInfo('14017033-n', 0) ],
"_neuroscience_n_1_rel" : [ SenseInfo('06081833-n', 0) ],
"_foremast_n_1_rel" : [ SenseInfo('03382856-n', 0) ],
"_ferment_v_1_rel" : [ SenseInfo('01763303-v', 0), SenseInfo('01761533-v', 0), SenseInfo('00458754-v', 0), SenseInfo('00458471-v', 0) ],
"_sustainability_n_1_rel" : [ SenseInfo('05029594-n', 0) ],
"_portray_v_1_rel" : [ SenseInfo('00988890-v', 9), SenseInfo('01688256-v', 3), SenseInfo('01723690-v', 2), SenseInfo('01688771-v', 0) ],
"_businesswoman_n_1_rel" : [ SenseInfo('09882615-n', 0) ],
"_handbag_n_1_rel" : [ SenseInfo('02774152-n', 3) ],
"_flee_v_from_rel" : [ SenseInfo('02075462-v', 37), SenseInfo('02075462-v', 37), SenseInfo('02075462-v', 37) ],
"_fortuitous_a_1_rel" : [ SenseInfo('01339203-a', 0), SenseInfo('01048587-a', 0) ],
"_label_v_as_rel" : [ SenseInfo('01029852-v', 8), SenseInfo('01588493-v', 3), SenseInfo('00971650-v', 3), SenseInfo('00651480-v', 1), SenseInfo('00650932-v', 0), SenseInfo('01029852-v', 8), SenseInfo('01588493-v', 3), SenseInfo('00971650-v', 3), SenseInfo('00651480-v', 1), SenseInfo('00650932-v', 0) ],
"_coat_v_1_rel" : [ SenseInfo('01264283-v', 3), SenseInfo('00051511-v', 1), SenseInfo('01262321-v', 0) ],
"_real_a_1_rel" : [ SenseInfo('01932973-a', 54), SenseInfo('01937994-a', 14), SenseInfo('02119716-a', 4), SenseInfo('00013662-a', 3), SenseInfo('02460964-a', 1), SenseInfo('01939596-a', 0), SenseInfo('00625393-a', 0), SenseInfo('02392406-a', 0), SenseInfo('01941604-a', 0) ],
"_deposit_n_of_rel" : [ SenseInfo('11445395-n', 1), SenseInfo('09428967-n', 1), SenseInfo('13462191-n', 0), SenseInfo('13381145-n', 0), SenseInfo('13349834-n', 0), SenseInfo('13349662-n', 0), SenseInfo('06685860-n', 0), SenseInfo('03177349-n', 0), SenseInfo('00372448-n', 0) ],
"_crayon_n_1_rel" : [ SenseInfo('03128248-n', 0) ],
"_glimmer_v_1_rel" : [ SenseInfo('02160779-v', 0) ],
"_corner_v_2_rel" : [ SenseInfo('02442924-v', 1), SenseInfo('01934205-v', 0), SenseInfo('01909275-v', 0) ],
"_depopulate_v_cause_rel" : [ SenseInfo('00531302-v', 0) ],
"_pump_v_1_rel" : [ SenseInfo('01225684-v', 4), SenseInfo('01155307-v', 3), SenseInfo('01853310-v', 1), SenseInfo('02356113-v', 0), SenseInfo('02068324-v', 0), SenseInfo('01853192-v', 0), SenseInfo('01853069-v', 0), SenseInfo('00788057-v', 0), SenseInfo('01225684-v', 4), SenseInfo('01155307-v', 3), SenseInfo('01853310-v', 1), SenseInfo('02356113-v', 0), SenseInfo('02068324-v', 0), SenseInfo('01853192-v', 0), SenseInfo('01853069-v', 0), SenseInfo('00788057-v', 0) ],
"_severe_a_1_rel" : [ SenseInfo('01513050-a', 8), SenseInfo('02322512-a', 3), SenseInfo('01792387-a', 2), SenseInfo('01301316-a', 1), SenseInfo('00651039-a', 1), SenseInfo('01129185-a', 0), SenseInfo('01513050-a', 8), SenseInfo('02322512-a', 3), SenseInfo('01792387-a', 2), SenseInfo('01301316-a', 1), SenseInfo('00651039-a', 1), SenseInfo('01129185-a', 0) ],
"_data-mine_v_1_rel" : [  ],
"_microfiber_n_1_rel" : [  ],
"_bound_a_1_rel" : [ SenseInfo('00252954-a', 4), SenseInfo('01058854-a', 3), SenseInfo('00256636-a', 2), SenseInfo('00340626-a', 2), SenseInfo('01955494-a', 1), SenseInfo('01682822-a', 1), SenseInfo('02371495-a', 0), SenseInfo('01064806-a', 0), SenseInfo('00638396-a', 0) ],
"_impregnation_n_of_rel" : [ SenseInfo('14916796-n', 0), SenseInfo('13496517-n', 0), SenseInfo('07436986-n', 0) ],
"_roll_v_up_rel" : [ SenseInfo('01866192-v', 22), SenseInfo('01887020-v', 10), SenseInfo('02687251-v', 7), SenseInfo('01391280-v', 6), SenseInfo('02198014-v', 2), SenseInfo('01522276-v', 2), SenseInfo('01526139-v', 1), SenseInfo('00143204-v', 1), SenseInfo('00100410-v', 1), SenseInfo('02322596-v', 0), SenseInfo('01901783-v', 0), SenseInfo('01881180-v', 0), SenseInfo('01875684-v', 0), SenseInfo('01866610-v', 0), SenseInfo('01055978-v', 0), SenseInfo('00324427-v', 0), SenseInfo('00125289-v', 0), SenseInfo('00125078-v', 0) ],
"_a+trifle_a_1_rel" : [  ],
"_consanguinity_n_1_rel" : [ SenseInfo('13813591-n', 0) ],
"_militia_n_1_rel" : [ SenseInfo('08390511-n', 5), SenseInfo('08390731-n', 0) ],
"_candidate_n_1_rel" : [ SenseInfo('09889691-n', 20), SenseInfo('09890749-n', 5) ],
"_neuter_a_1_rel" : [ SenseInfo('01486327-a', 0), SenseInfo('02136522-a', 0) ],
"_trivial_a_1_rel" : [ SenseInfo('01280908-a', 4), SenseInfo('02165432-a', 0), SenseInfo('02121735-a', 0) ],
"_angry_a_at_rel" : [ SenseInfo('00113818-a', 17), SenseInfo('00304144-a', 1), SenseInfo('01173697-a', 0), SenseInfo('00113818-a', 17), SenseInfo('00304144-a', 1), SenseInfo('01173697-a', 0), SenseInfo('00113818-a', 17), SenseInfo('00304144-a', 1), SenseInfo('01173697-a', 0), SenseInfo('00113818-a', 17), SenseInfo('00304144-a', 1), SenseInfo('01173697-a', 0), SenseInfo('00113818-a', 17), SenseInfo('00304144-a', 1), SenseInfo('01173697-a', 0), SenseInfo('00113818-a', 17), SenseInfo('00304144-a', 1), SenseInfo('01173697-a', 0), SenseInfo('00113818-a', 17), SenseInfo('00304144-a', 1), SenseInfo('01173697-a', 0) ],
"_center_n_of_rel" : [ SenseInfo('08523483-n', 56), SenseInfo('02994219-n', 10), SenseInfo('02993546-n', 6), SenseInfo('08521816-n', 5), SenseInfo('05921123-n', 3), SenseInfo('05812038-n', 3), SenseInfo('05463533-n', 3), SenseInfo('08481832-n', 2), SenseInfo('09904556-n', 1), SenseInfo('09904321-n', 1), SenseInfo('08514034-n', 1), SenseInfo('08416523-n', 1), SenseInfo('09904708-n', 0), SenseInfo('07602650-n', 0), SenseInfo('03965456-n', 0), SenseInfo('00728464-n', 0), SenseInfo('00727500-n', 0), SenseInfo('00725506-n', 0), SenseInfo('08523483-n', 56), SenseInfo('02994219-n', 10), SenseInfo('02993546-n', 6), SenseInfo('08521816-n', 5), SenseInfo('05921123-n', 3), SenseInfo('05812038-n', 3), SenseInfo('05463533-n', 3), SenseInfo('08481832-n', 2), SenseInfo('09904556-n', 1), SenseInfo('09904321-n', 1), SenseInfo('08514034-n', 1), SenseInfo('08416523-n', 1), SenseInfo('09904708-n', 0), SenseInfo('07602650-n', 0), SenseInfo('03965456-n', 0), SenseInfo('00728464-n', 0), SenseInfo('00727500-n', 0), SenseInfo('00725506-n', 0), SenseInfo('08523483-n', 56), SenseInfo('02994219-n', 10), SenseInfo('02993546-n', 6), SenseInfo('08521816-n', 5), SenseInfo('05921123-n', 3), SenseInfo('05812038-n', 3), SenseInfo('05463533-n', 3), SenseInfo('08481832-n', 2), SenseInfo('09904556-n', 1), SenseInfo('09904321-n', 1), SenseInfo('08514034-n', 1), SenseInfo('08416523-n', 1), SenseInfo('09904708-n', 0), SenseInfo('07602650-n', 0), SenseInfo('03965456-n', 0), SenseInfo('00728464-n', 0), SenseInfo('00727500-n', 0), SenseInfo('00725506-n', 0) ],
"_shore_v_up_rel" : [ SenseInfo('02710981-v', 0), SenseInfo('01981436-v', 0), SenseInfo('01219004-v', 0) ],
"_forego_v_1_rel" : [ SenseInfo('02712443-v', 3), SenseInfo('02534062-v', 0), SenseInfo('02303331-v', 0) ],
"_fillet_n_1_rel" : [ SenseInfo('07660065-n', 0), SenseInfo('07655337-n', 0), SenseInfo('05475562-n', 0), SenseInfo('04383696-n', 0), SenseInfo('03338143-n', 0) ],
"_alarm_v_2_rel" : [ SenseInfo('01782650-v', 2), SenseInfo('00872414-v', 1) ],
"_handfast_a_1_rel" : [  ],
"_cumbersome_a_1_rel" : [ SenseInfo('02564330-a', 2), SenseInfo('01001180-a', 0) ],
"_extra_x_deg_rel" : [ SenseInfo('01581305-a', 4), SenseInfo('10676569-n', 0), SenseInfo('06597349-n', 0), SenseInfo('03307981-n', 0), SenseInfo('00084759-r', 0), SenseInfo('02367319-a', 0), SenseInfo('00048858-a', 0) ],
"_gnaw_v_away_rel" : [ SenseInfo('01445597-v', 2), SenseInfo('00275253-v', 1) ],
"_gleam_v_1_rel" : [ SenseInfo('02162947-v', 3), SenseInfo('02160779-v', 3), SenseInfo('00423575-v', 1) ],
"_cloudberry_n_1_rel" : [ SenseInfo('12657294-n', 0) ],
"_survive_v_1_rel" : [ SenseInfo('02618149-v', 20), SenseInfo('02619924-v', 8), SenseInfo('02616713-v', 5), SenseInfo('02619739-v', 0) ],
"_magnificence_n_1_rel" : [ SenseInfo('04729328-n', 1), SenseInfo('04814238-n', 0) ],
"_stand_v_in_rel" : [ SenseInfo('01546111-v', 169), SenseInfo('02611373-v', 53), SenseInfo('02734488-v', 38), SenseInfo('02702120-v', 18), SenseInfo('00668099-v', 9), SenseInfo('00670991-v', 8), SenseInfo('02707125-v', 5), SenseInfo('02703018-v', 3), SenseInfo('02702368-v', 2), SenseInfo('01546768-v', 1), SenseInfo('01115916-v', 1), SenseInfo('01428203-v', 0) ],
"_equipment_n_1_rel" : [ SenseInfo('03294048-n', 48) ],
"_ambient_a_1_rel" : [ SenseInfo('00447753-a', 0) ],
"_enquire_v_1_rel" : [ SenseInfo('00784342-v', 1), SenseInfo('00785962-v', 0), SenseInfo('00729378-v', 0), SenseInfo('00784342-v', 1), SenseInfo('00785962-v', 0), SenseInfo('00729378-v', 0), SenseInfo('00784342-v', 1), SenseInfo('00785962-v', 0), SenseInfo('00729378-v', 0) ],
"_dock_n_1_rel" : [ SenseInfo('03217191-n', 2), SenseInfo('12603959-n', 0), SenseInfo('03933529-n', 0), SenseInfo('03217333-n', 0), SenseInfo('03216828-n', 0), SenseInfo('02158972-n', 0), SenseInfo('02158066-n', 0) ],
"_sweaty_a_1_rel" : [  ],
"_demonstrable_a_1_rel" : [ SenseInfo('00591147-a', 1), SenseInfo('01619105-a', 0), SenseInfo('00591147-a', 1), SenseInfo('01619105-a', 0) ],
"_unmotivated_a_1_rel" : [ SenseInfo('01558912-a', 0), SenseInfo('01558912-a', 0) ],
"_flatulence_n_1_rel" : [ SenseInfo('14035695-n', 0), SenseInfo('07090573-n', 0) ],
"_erode_v_1_rel" : [ SenseInfo('00275253-v', 1), SenseInfo('00274724-v', 1) ],
"_grey_v_out_rel" : [ SenseInfo('00289679-v', 0), SenseInfo('00289392-v', 0), SenseInfo('00289679-v', 0), SenseInfo('00289392-v', 0) ],
"_immobile_a_1_rel" : [ SenseInfo('01525116-a', 0), SenseInfo('01059711-a', 0) ],
"_epispastic_a_1_rel" : [  ],
"_tutorial_n_1_rel" : [ SenseInfo('07148022-n', 1) ],
"_black_v_1_rel" : [ SenseInfo('00280532-v', 0) ],
"_project_n_1_rel" : [ SenseInfo('00795720-n', 23), SenseInfo('05910453-n', 1), SenseInfo('00795720-n', 23), SenseInfo('05910453-n', 1), SenseInfo('00795720-n', 23), SenseInfo('05910453-n', 1) ],
"_hillcrest_n_1_rel" : [  ],
"_coincident_a_1_rel" : [ SenseInfo('02378496-a', 0), SenseInfo('00561757-a', 0) ],
"_seal_v_off_rel" : [ SenseInfo('01354006-v', 3), SenseInfo('01353405-v', 3), SenseInfo('00698732-v', 2), SenseInfo('01356582-v', 0), SenseInfo('01269008-v', 0), SenseInfo('01143498-v', 0) ],
"_discriminate_a_1_rel" : [ SenseInfo('00773579-a', 0) ],
"_calculus_n_1_rel" : [ SenseInfo('09230768-n', 1), SenseInfo('09454925-n', 0), SenseInfo('06013741-n', 0) ],
"_constitutive_a_1_rel" : [ SenseInfo('00901345-a', 0) ],
"_flake_v_off_rel" : [ SenseInfo('01585276-v', 1), SenseInfo('01336440-v', 0), SenseInfo('01259951-v', 0), SenseInfo('01585276-v', 1), SenseInfo('01336440-v', 0), SenseInfo('01259951-v', 0) ],
"_clergyman_n_1_rel" : [ SenseInfo('09927451-n', 13) ],
"_in+particular_a_1_rel" : [  ],
"_irresolution_n_1_rel" : [ SenseInfo('05699172-n', 1), SenseInfo('04866465-n', 0) ],
"_pun_n_1_rel" : [ SenseInfo('06781581-n', 1) ],
"_mark_v_out_rel" : [ SenseInfo('01588493-v', 13), SenseInfo('00921738-v', 13), SenseInfo('00651991-v', 13), SenseInfo('00612612-v', 9), SenseInfo('00508032-v', 5), SenseInfo('02508245-v', 2), SenseInfo('02118476-v', 2), SenseInfo('01551195-v', 1), SenseInfo('01275762-v', 0), SenseInfo('01062395-v', 0), SenseInfo('01004062-v', 0), SenseInfo('00800750-v', 0), SenseInfo('00662182-v', 0), SenseInfo('00657728-v', 0), SenseInfo('00190023-v', 0) ],
"_macro_n_1_rel" : [ SenseInfo('06586886-n', 0) ],
"_ton_n_1_rel" : [ SenseInfo('13721529-n', 10), SenseInfo('13721387-n', 0), SenseInfo('13721529-n', 10), SenseInfo('13721387-n', 0) ],
"_boggy_a_1_rel" : [ SenseInfo('02548066-a', 0), SenseInfo('02548066-a', 0), SenseInfo('02548066-a', 0) ],
"_shortage_n_of_rel" : [ SenseInfo('05114371-n', 4), SenseInfo('14449865-n', 2) ],
"_spray_v_with_rel" : [ SenseInfo('01373844-v', 3), SenseInfo('01372682-v', 2), SenseInfo('01373551-v', 0), SenseInfo('01373844-v', 3), SenseInfo('01372682-v', 2), SenseInfo('01373551-v', 0), SenseInfo('01373844-v', 3), SenseInfo('01372682-v', 2), SenseInfo('01373551-v', 0) ],
"_visa_n_1_rel" : [ SenseInfo('06687883-n', 0) ],
"_out+of_p_rel" : [ SenseInfo('00233573-r', 0), SenseInfo('00233573-r', 0) ],
"_brace_v_1_rel" : [ SenseInfo('01806109-v', 2), SenseInfo('01219993-v', 2), SenseInfo('01219706-v', 1), SenseInfo('00022686-v', 0), SenseInfo('01806109-v', 2), SenseInfo('01219993-v', 2), SenseInfo('01219706-v', 1), SenseInfo('00022686-v', 0), SenseInfo('01806109-v', 2), SenseInfo('01219993-v', 2), SenseInfo('01219706-v', 1), SenseInfo('00022686-v', 0), SenseInfo('01806109-v', 2), SenseInfo('01219993-v', 2), SenseInfo('01219706-v', 1), SenseInfo('00022686-v', 0), SenseInfo('01806109-v', 2), SenseInfo('01219993-v', 2), SenseInfo('01219706-v', 1), SenseInfo('00022686-v', 0) ],
"_bundesbahn_n_1_rel" : [  ],
"_slam_v_on_rel" : [ SenseInfo('01242832-v', 8), SenseInfo('01242391-v', 8), SenseInfo('01897885-v', 0), SenseInfo('01242689-v', 0) ],
"_discotheque_n_1_rel" : [ SenseInfo('03206282-n', 0) ],
"_derailer_n_1_rel" : [  ],
"_pulverize_v_1_rel" : [ SenseInfo('00332154-v', 1), SenseInfo('01656458-v', 0), SenseInfo('00332445-v', 0) ],
"_crumple_v_cause_rel" : [ SenseInfo('02041877-v', 1), SenseInfo('01279186-v', 0), SenseInfo('01278817-v', 0), SenseInfo('00564857-v', 0) ],
"_a+great+deal_a_1_rel" : [  ],
"_want_v_back_rel" : [ SenseInfo('01825237-v', 389), SenseInfo('01188725-v', 15), SenseInfo('01317064-v', 3), SenseInfo('00709205-v', 2), SenseInfo('02632567-v', 0) ],
"_tar_n_1_rel" : [ SenseInfo('14911704-n', 1), SenseInfo('10294602-n', 0) ],
"_tweak_v_1_rel" : [ SenseInfo('01592669-v', 0), SenseInfo('01592456-v', 0), SenseInfo('00302763-v', 0) ],
"_attendance_n_1_rel" : [ SenseInfo('01233397-n', 2), SenseInfo('15284999-n', 0), SenseInfo('08185063-n', 0) ],
"_bedclothes_n_1_rel" : [ SenseInfo('02820210-n', 0) ],
"_opportunistic_a_1_rel" : [ SenseInfo('00931974-a', 1) ],
"_heed_v_1_rel" : [ SenseInfo('02571901-v', 7) ],
"_favorable_a_1_rel" : [ SenseInfo('00995775-a', 4), SenseInfo('00995119-a', 1), SenseInfo('00177547-a', 1), SenseInfo('01246801-a', 0), SenseInfo('00604978-a', 0), SenseInfo('00995775-a', 4), SenseInfo('00995119-a', 1), SenseInfo('00177547-a', 1), SenseInfo('01246801-a', 0), SenseInfo('00604978-a', 0), SenseInfo('00995775-a', 4), SenseInfo('00995119-a', 1), SenseInfo('00177547-a', 1), SenseInfo('01246801-a', 0), SenseInfo('00604978-a', 0), SenseInfo('00995775-a', 4), SenseInfo('00995119-a', 1), SenseInfo('00177547-a', 1), SenseInfo('01246801-a', 0), SenseInfo('00604978-a', 0) ],
"_janitorial_a_1_rel" : [  ],
"_octogenarian_n_1_rel" : [ SenseInfo('10370286-n', 0) ],
"_nomination_n_of-for_rel" : [ SenseInfo('00164152-n', 3), SenseInfo('13926535-n', 0), SenseInfo('07240925-n', 0), SenseInfo('00164152-n', 3), SenseInfo('13926535-n', 0), SenseInfo('07240925-n', 0) ],
"_grandsire_n_1_rel" : [  ],
"_jack_v_up_rel" : [ SenseInfo('01219544-v', 0), SenseInfo('01145365-v', 0) ],
"_savage_n_1_rel" : [ SenseInfo('10553402-n', 2), SenseInfo('09845589-n', 0) ],
"_martyr_n_1_rel" : [ SenseInfo('10296618-n', 8), SenseInfo('10296832-n', 0) ],
"_imperative_a_to_rel" : [ SenseInfo('00712419-a', 2), SenseInfo('03094404-a', 0), SenseInfo('00712419-a', 2), SenseInfo('03094404-a', 0), SenseInfo('00712419-a', 2), SenseInfo('03094404-a', 0), SenseInfo('00712419-a', 2), SenseInfo('03094404-a', 0) ],
"_massage_n_of_rel" : [ SenseInfo('00659048-n', 1) ],
"_kJ_n_1_rel" : [  ],
"_gamer_n_1_rel" : [  ],
"_sour_v_on_rel" : [ SenseInfo('00458471-v', 2), SenseInfo('02196690-v', 1), SenseInfo('00458471-v', 2), SenseInfo('02196690-v', 1) ],
"_East+Anglian_a_1_rel" : [  ],
"_glimpse_n_1_rel" : [ SenseInfo('00877625-n', 6), SenseInfo('05934396-n', 1), SenseInfo('06802444-n', 0) ],
"_at+all_x_deg_rel" : [ SenseInfo('00056729-r', 81) ],
"_drag_v_on_rel" : [ SenseInfo('01453433-v', 16), SenseInfo('01454810-v', 13), SenseInfo('02677797-v', 1), SenseInfo('02099544-v', 1), SenseInfo('02058756-v', 1), SenseInfo('01199009-v', 1), SenseInfo('02101789-v', 0), SenseInfo('01917845-v', 0), SenseInfo('01244692-v', 0), SenseInfo('00783689-v', 0), SenseInfo('00341757-v', 0), SenseInfo('01453433-v', 16), SenseInfo('01454810-v', 13), SenseInfo('02677797-v', 1), SenseInfo('02099544-v', 1), SenseInfo('02058756-v', 1), SenseInfo('01199009-v', 1), SenseInfo('02101789-v', 0), SenseInfo('01917845-v', 0), SenseInfo('01244692-v', 0), SenseInfo('00783689-v', 0), SenseInfo('00341757-v', 0) ],
"_teachers_a_1_rel" : [  ],
"_damn_x_deg_rel" : [ SenseInfo('00670530-a', 19), SenseInfo('00865958-v', 7), SenseInfo('00025144-r', 2), SenseInfo('00669942-a', 2), SenseInfo('05140793-n', 1) ],
"_poplin_n_1_rel" : [ SenseInfo('03983612-n', 1) ],
"_host_n_of-to_rel" : [ SenseInfo('10187130-n', 8), SenseInfo('08182962-n', 6), SenseInfo('01385527-n', 4), SenseInfo('10299250-n', 3), SenseInfo('08183802-n', 2), SenseInfo('08481184-n', 1), SenseInfo('10187356-n', 0), SenseInfo('10186774-n', 0), SenseInfo('07683138-n', 0), SenseInfo('04175147-n', 0), SenseInfo('10187130-n', 8), SenseInfo('08182962-n', 6), SenseInfo('01385527-n', 4), SenseInfo('10299250-n', 3), SenseInfo('08183802-n', 2), SenseInfo('08481184-n', 1), SenseInfo('10187356-n', 0), SenseInfo('10186774-n', 0), SenseInfo('07683138-n', 0), SenseInfo('04175147-n', 0), SenseInfo('10187130-n', 8), SenseInfo('08182962-n', 6), SenseInfo('01385527-n', 4), SenseInfo('10299250-n', 3), SenseInfo('08183802-n', 2), SenseInfo('08481184-n', 1), SenseInfo('10187356-n', 0), SenseInfo('10186774-n', 0), SenseInfo('07683138-n', 0), SenseInfo('04175147-n', 0) ],
"_schedule_v_1_rel" : [ SenseInfo('00678282-v', 21), SenseInfo('00794981-v', 6), SenseInfo('00678282-v', 21), SenseInfo('00794981-v', 6) ],
"_basic_a_1_rel" : [ SenseInfo('01855764-a', 45), SenseInfo('02295298-a', 17), SenseInfo('01011753-a', 0), SenseInfo('00026168-a', 0), SenseInfo('01855764-a', 45), SenseInfo('02295298-a', 17), SenseInfo('01011753-a', 0), SenseInfo('00026168-a', 0), SenseInfo('01855764-a', 45), SenseInfo('02295298-a', 17), SenseInfo('01011753-a', 0), SenseInfo('00026168-a', 0) ],
"_beep_v_1_rel" : [ SenseInfo('02183175-v', 0), SenseInfo('00791372-v', 0) ],
"_set_v_forth_rel" : [ SenseInfo('01494310-v', 30), SenseInfo('00699815-v', 29), SenseInfo('00947077-v', 12), SenseInfo('01062395-v', 10), SenseInfo('00298896-v', 9), SenseInfo('01607445-v', 6), SenseInfo('00406243-v', 5), SenseInfo('00298556-v', 5), SenseInfo('01711749-v', 3), SenseInfo('01970646-v', 2), SenseInfo('01706129-v', 2), SenseInfo('01567275-v', 2), SenseInfo('01628899-v', 1), SenseInfo('00442669-v', 1), SenseInfo('01744888-v', 0), SenseInfo('01613239-v', 0), SenseInfo('01530273-v', 0), SenseInfo('01247322-v', 0), SenseInfo('01115006-v', 0), SenseInfo('00673448-v', 0), SenseInfo('00408085-v', 0), SenseInfo('00407848-v', 0), SenseInfo('00296178-v', 0), SenseInfo('00056188-v', 0), SenseInfo('00038849-v', 0) ],
"_skirt_v_1_rel" : [ SenseInfo('00809654-v', 2), SenseInfo('02052090-v', 1), SenseInfo('02703711-v', 0), SenseInfo('01467370-v', 0) ],
"_most+of+all_a_1_rel" : [  ],
"_tire_v_1_rel" : [ SenseInfo('00076114-v', 3), SenseInfo('00075021-v', 3), SenseInfo('02280869-v', 0), SenseInfo('01821884-v', 0), SenseInfo('00076114-v', 3), SenseInfo('00075021-v', 3), SenseInfo('02280869-v', 0), SenseInfo('01821884-v', 0), SenseInfo('00076114-v', 3), SenseInfo('00075021-v', 3), SenseInfo('02280869-v', 0), SenseInfo('01821884-v', 0), SenseInfo('00076114-v', 3), SenseInfo('00075021-v', 3), SenseInfo('02280869-v', 0), SenseInfo('01821884-v', 0), SenseInfo('00076114-v', 3), SenseInfo('00075021-v', 3), SenseInfo('02280869-v', 0), SenseInfo('01821884-v', 0) ],
"_sacrifice_v_1_rel" : [ SenseInfo('02343595-v', 10), SenseInfo('01326093-v', 1), SenseInfo('02343961-v', 0), SenseInfo('02325558-v', 0) ],
"_orthodox_a_1_rel" : [ SenseInfo('02953420-a', 3), SenseInfo('01689880-a', 3), SenseInfo('02953598-a', 0) ],
"_upstream+of_p_rel" : [  ],
"_spill_v_out_rel" : [ SenseInfo('01542207-v', 2), SenseInfo('02069888-v', 1), SenseInfo('01541579-v', 1), SenseInfo('01541803-v', 0), SenseInfo('00952841-v', 0), SenseInfo('00429642-v', 0) ],
"_inflexible_a_1_rel" : [ SenseInfo('01024597-a', 1), SenseInfo('01025913-a', 0), SenseInfo('01023289-a', 0), SenseInfo('01029151-a', 0) ],
"_remember_v_of_rel" : [ SenseInfo('00607780-v', 106), SenseInfo('00609683-v', 53), SenseInfo('00611256-v', 23), SenseInfo('02356567-v', 2), SenseInfo('00882802-v', 0), SenseInfo('00882523-v', 0), SenseInfo('00611802-v', 0), SenseInfo('00611481-v', 0) ],
"_seal_n_1_rel" : [ SenseInfo('04160036-n', 3), SenseInfo('04159058-n', 1), SenseInfo('14766040-n', 0), SenseInfo('10348526-n', 0), SenseInfo('06855985-n', 0), SenseInfo('06705984-n', 0), SenseInfo('04159545-n', 0), SenseInfo('04159354-n', 0), SenseInfo('02076196-n', 0) ],
"_degenerate_v_1_rel" : [ SenseInfo('00092293-v', 0) ],
"_tug_v_1_rel" : [ SenseInfo('01452918-v', 7), SenseInfo('02406916-v', 0), SenseInfo('01454636-v', 0), SenseInfo('01454246-v', 0), SenseInfo('01453256-v', 0), SenseInfo('01453109-v', 0), SenseInfo('01091298-v', 0), SenseInfo('01452918-v', 7), SenseInfo('02406916-v', 0), SenseInfo('01454636-v', 0), SenseInfo('01454246-v', 0), SenseInfo('01453256-v', 0), SenseInfo('01453109-v', 0), SenseInfo('01091298-v', 0) ],
"_associate_v_to_rel" : [ SenseInfo('00713167-v', 25), SenseInfo('02589245-v', 3), SenseInfo('02470175-v', 1) ],
"_horticultural_a_1_rel" : [ SenseInfo('02927048-a', 0) ],
"_violate_v_1_rel" : [ SenseInfo('02668523-v', 7), SenseInfo('02566528-v', 5), SenseInfo('01207688-v', 1), SenseInfo('02568065-v', 0), SenseInfo('02567519-v', 0), SenseInfo('01565472-v', 0) ],
"_third_a_1_rel" : [ SenseInfo('02202307-a', 73), SenseInfo('02202307-a', 73), SenseInfo('02202307-a', 73), SenseInfo('02202307-a', 73) ],
"_waffle_v_1_rel" : [ SenseInfo('02640440-v', 0) ],
"_mediate_v_1_rel" : [ SenseInfo('00760956-v', 1), SenseInfo('02691890-v', 0) ],
"_recess_n_1_rel" : [ SenseInfo('14013646-n', 0), SenseInfo('13872421-n', 0), SenseInfo('09313716-n', 0), SenseInfo('04061969-n', 0), SenseInfo('01062997-n', 0) ],
"_full-time_a_1_rel" : [ SenseInfo('01089136-a', 11), SenseInfo('01089136-a', 11), SenseInfo('01089136-a', 11), SenseInfo('01089136-a', 11) ],
"_differentiate_v_1_rel" : [ SenseInfo('00650353-v', 4), SenseInfo('00651991-v', 1), SenseInfo('00642803-v', 0), SenseInfo('00119524-v', 0), SenseInfo('00119266-v', 0), SenseInfo('00119074-v', 0) ],
"_short_a_1_rel" : [ SenseInfo('01442186-a', 43), SenseInfo('01436003-a', 21), SenseInfo('02386612-a', 7), SenseInfo('02336904-a', 3), SenseInfo('02006031-a', 0), SenseInfo('01444620-a', 0), SenseInfo('01444230-a', 0), SenseInfo('02337329-a', 0), SenseInfo('01896046-a', 0), SenseInfo('00709021-a', 0), SenseInfo('00640660-a', 0), SenseInfo('01442186-a', 43), SenseInfo('01436003-a', 21), SenseInfo('02386612-a', 7), SenseInfo('02336904-a', 3), SenseInfo('02006031-a', 0), SenseInfo('01444620-a', 0), SenseInfo('01444230-a', 0), SenseInfo('02337329-a', 0), SenseInfo('01896046-a', 0), SenseInfo('00709021-a', 0), SenseInfo('00640660-a', 0), SenseInfo('01442186-a', 43), SenseInfo('01436003-a', 21), SenseInfo('02386612-a', 7), SenseInfo('02336904-a', 3), SenseInfo('02006031-a', 0), SenseInfo('01444620-a', 0), SenseInfo('01444230-a', 0), SenseInfo('02337329-a', 0), SenseInfo('01896046-a', 0), SenseInfo('00709021-a', 0), SenseInfo('00640660-a', 0) ],
"_have_v_qmodal_rel" : [ SenseInfo('02203362-v', 1202), SenseInfo('02630189-v', 377), SenseInfo('02108026-v', 220), SenseInfo('02204692-v', 143), SenseInfo('00120796-v', 64), SenseInfo('01156834-v', 42), SenseInfo('02378453-v', 31), SenseInfo('01733477-v', 30), SenseInfo('02205098-v', 28), SenseInfo('02740745-v', 25), SenseInfo('00121046-v', 25), SenseInfo('00065370-v', 11), SenseInfo('00770437-v', 8), SenseInfo('02236124-v', 7), SenseInfo('02210119-v', 7), SenseInfo('00065639-v', 5), SenseInfo('02355596-v', 3), SenseInfo('00056930-v', 3), SenseInfo('01427127-v', 2), SenseInfo('02203362-v', 1202), SenseInfo('02630189-v', 377), SenseInfo('02108026-v', 220), SenseInfo('02204692-v', 143), SenseInfo('00120796-v', 64), SenseInfo('01156834-v', 42), SenseInfo('02378453-v', 31), SenseInfo('01733477-v', 30), SenseInfo('02205098-v', 28), SenseInfo('02740745-v', 25), SenseInfo('00121046-v', 25), SenseInfo('00065370-v', 11), SenseInfo('00770437-v', 8), SenseInfo('02236124-v', 7), SenseInfo('02210119-v', 7), SenseInfo('00065639-v', 5), SenseInfo('02355596-v', 3), SenseInfo('00056930-v', 3), SenseInfo('01427127-v', 2) ],
"_snow_v_under_rel" : [ SenseInfo('02758977-v', 10), SenseInfo('00839194-v', 0) ],
"_inferiority_n_1_rel" : [ SenseInfo('13951444-n', 1), SenseInfo('04730580-n', 1), SenseInfo('05165175-n', 0) ],
"_slick_n_1_rel" : [ SenseInfo('04947628-n', 1), SenseInfo('06596727-n', 0), SenseInfo('04237654-n', 0), SenseInfo('04237565-n', 0) ],
"_plot_n_of_rel" : [ SenseInfo('05907682-n', 9), SenseInfo('08674739-n', 6), SenseInfo('06373314-n', 5), SenseInfo('07000065-n', 0) ],
"_glossy_a_1_rel" : [ SenseInfo('01120010-a', 0), SenseInfo('00281657-a', 0), SenseInfo('00168039-a', 0), SenseInfo('01120010-a', 0), SenseInfo('00281657-a', 0), SenseInfo('00168039-a', 0), SenseInfo('01120010-a', 0), SenseInfo('00281657-a', 0), SenseInfo('00168039-a', 0) ],
"_hot_v_up_rel" : [  ],
"_comparable_a_1_rel" : [ SenseInfo('00503982-a', 11), SenseInfo('02063554-a', 1), SenseInfo('00503982-a', 11), SenseInfo('02063554-a', 1) ],
"_funky_a_1_rel" : [ SenseInfo('01053634-a', 0), SenseInfo('00855158-a', 0), SenseInfo('00609750-a', 0), SenseInfo('00266228-a', 0), SenseInfo('01053634-a', 0), SenseInfo('00855158-a', 0), SenseInfo('00609750-a', 0), SenseInfo('00266228-a', 0), SenseInfo('01053634-a', 0), SenseInfo('00855158-a', 0), SenseInfo('00609750-a', 0), SenseInfo('00266228-a', 0) ],
"_skid_n_1_rel" : [ SenseInfo('04228844-n', 0), SenseInfo('02890940-n', 0), SenseInfo('00329031-n', 0) ],
"_confess_v_1_rel" : [ SenseInfo('00819508-v', 10), SenseInfo('00818553-v', 3), SenseInfo('00818805-v', 0) ],
"_eclecticism_n_1_rel" : [ SenseInfo('05788713-n', 0) ],
"_relative_a_to_rel" : [ SenseInfo('00006032-a', 25), SenseInfo('00482673-a', 1) ],
"_aquatic_a_1_rel" : [ SenseInfo('02636582-a', 0), SenseInfo('00124077-a', 0) ],
"_noninteractive_a_1_rel" : [  ],
"_responsible_a_for_rel" : [ SenseInfo('01996377-a', 9), SenseInfo('00324878-a', 1), SenseInfo('02465350-a', 0), SenseInfo('01996377-a', 9), SenseInfo('00324878-a', 1), SenseInfo('02465350-a', 0), SenseInfo('01996377-a', 9), SenseInfo('00324878-a', 1), SenseInfo('02465350-a', 0), SenseInfo('01996377-a', 9), SenseInfo('00324878-a', 1), SenseInfo('02465350-a', 0) ],
"_receivable_a_1_rel" : [ SenseInfo('00137277-a', 0), SenseInfo('00137277-a', 0) ],
"_playground_n_1_rel" : [ SenseInfo('08640739-n', 1), SenseInfo('03963645-n', 0) ],
"_shake_v_out_rel" : [ SenseInfo('01889610-v', 42), SenseInfo('00014034-v', 14), SenseInfo('01891638-v', 8), SenseInfo('01875295-v', 6), SenseInfo('00167385-v', 6), SenseInfo('01761706-v', 2), SenseInfo('02073545-v', 1), SenseInfo('00559556-v', 1), SenseInfo('00992518-v', 0) ],
"_shopper_n_1_rel" : [ SenseInfo('10592397-n', 1), SenseInfo('10592595-n', 0) ],
"_overgrown_a_with_rel" : [ SenseInfo('01697235-a', 1), SenseInfo('02574092-a', 0) ],
"_build_v_1_rel" : [ SenseInfo('01654628-v', 123), SenseInfo('00252990-v', 11), SenseInfo('01655505-v', 4), SenseInfo('00447158-v', 1), SenseInfo('02443424-v', 0), SenseInfo('01739099-v', 0), SenseInfo('01685601-v', 0), SenseInfo('00637115-v', 0), SenseInfo('00253277-v', 0), SenseInfo('00226882-v', 0), SenseInfo('01654628-v', 123), SenseInfo('00252990-v', 11), SenseInfo('01655505-v', 4), SenseInfo('00447158-v', 1), SenseInfo('02443424-v', 0), SenseInfo('01739099-v', 0), SenseInfo('01685601-v', 0), SenseInfo('00637115-v', 0), SenseInfo('00253277-v', 0), SenseInfo('00226882-v', 0), SenseInfo('01654628-v', 123), SenseInfo('00252990-v', 11), SenseInfo('01655505-v', 4), SenseInfo('00447158-v', 1), SenseInfo('02443424-v', 0), SenseInfo('01739099-v', 0), SenseInfo('01685601-v', 0), SenseInfo('00637115-v', 0), SenseInfo('00253277-v', 0), SenseInfo('00226882-v', 0) ],
"_syrupy_a_1_rel" : [ SenseInfo('02368566-a', 1), SenseInfo('02417028-a', 0), SenseInfo('02338037-a', 0) ],
"_deliver_v_to_rel" : [ SenseInfo('00989602-v', 21), SenseInfo('01438304-v', 15), SenseInfo('02293321-v', 6), SenseInfo('02551144-v', 3), SenseInfo('02503365-v', 2), SenseInfo('01062253-v', 1), SenseInfo('00989869-v', 1), SenseInfo('02551602-v', 0), SenseInfo('02358327-v', 0), SenseInfo('02235229-v', 0), SenseInfo('01509079-v', 0), SenseInfo('00056930-v', 0), SenseInfo('00989602-v', 21), SenseInfo('01438304-v', 15), SenseInfo('02293321-v', 6), SenseInfo('02551144-v', 3), SenseInfo('02503365-v', 2), SenseInfo('01062253-v', 1), SenseInfo('00989869-v', 1), SenseInfo('02551602-v', 0), SenseInfo('02358327-v', 0), SenseInfo('02235229-v', 0), SenseInfo('01509079-v', 0), SenseInfo('00056930-v', 0) ],
"_guideline_n_1_rel" : [ SenseInfo('06802138-n', 0), SenseInfo('05912552-n', 0), SenseInfo('05848541-n', 0) ],
"_subsist_v_on_rel" : [ SenseInfo('02616713-v', 1) ],
"_scuffle_n_1_rel" : [ SenseInfo('01172441-n', 3), SenseInfo('04156591-n', 0), SenseInfo('00789391-n', 0) ],
"_billow_n_1_rel" : [ SenseInfo('07348545-n', 0) ],
"_trifle_n_1_rel" : [ SenseInfo('07613480-n', 0), SenseInfo('05820462-n', 0), SenseInfo('04486445-n', 0) ],
"_subset_n_of_rel" : [ SenseInfo('08001209-n', 0), SenseInfo('08001209-n', 0) ],
"_multi_a_1_rel" : [  ],
"_precaution_n_against_rel" : [ SenseInfo('00822970-n', 5), SenseInfo('04664314-n', 2), SenseInfo('05615869-n', 1) ],
"_forestation_n_of_rel" : [  ],
"_compound_v_1_rel" : [ SenseInfo('00227165-v', 6), SenseInfo('00193486-v', 3), SenseInfo('02265881-v', 0), SenseInfo('01657828-v', 0), SenseInfo('01461328-v', 0) ],
"_measurable_a_1_rel" : [ SenseInfo('01498769-a', 4), SenseInfo('01279310-a', 1) ],
"_construe_v_as_rel" : [ SenseInfo('00623151-v', 5), SenseInfo('00623151-v', 5) ],
"_exhibition_n_of_rel" : [ SenseInfo('00522145-n', 8), SenseInfo('08407619-n', 4) ],
"_tat_n_1_rel" : [ SenseInfo('04818460-n', 0), SenseInfo('01008097-n', 0) ],
"_definitive_a_1_rel" : [ SenseInfo('00940969-a', 2), SenseInfo('02295098-a', 0), SenseInfo('00550574-a', 0), SenseInfo('00940969-a', 2), SenseInfo('02295098-a', 0), SenseInfo('00550574-a', 0) ],
"_enterprising_a_1_rel" : [ SenseInfo('00884778-a', 3) ],
"_bed_v_1_rel" : [ SenseInfo('02337066-v', 0), SenseInfo('01567653-v', 0), SenseInfo('01500082-v', 0), SenseInfo('01426397-v', 0), SenseInfo('00017865-v', 0) ],
"_harder_a_for_rel" : [  ],
"_wallpaper_v_1_rel" : [ SenseInfo('01268112-v', 0) ],
"_accede_v_to_rel" : [ SenseInfo('00878348-v', 1), SenseInfo('02381397-v', 0), SenseInfo('00804139-v', 0) ],
"_nonmetal_a_1_rel" : [ SenseInfo('01529293-a', 0) ],
"_coinciding_a_1_rel" : [ SenseInfo('02378496-a', 0), SenseInfo('02378496-a', 0) ],
"_underutilize_v_1_rel" : [  ],
"_boggling_a_1_rel" : [  ],
"_magician_n_1_rel" : [ SenseInfo('10280674-n', 5), SenseInfo('10625860-n', 0) ],
"_carol_n_1_rel" : [ SenseInfo('07035747-n', 0), SenseInfo('00546613-n', 0) ],
"_chromatogram_n_1_rel" : [ SenseInfo('03026741-n', 1) ],
"_homeless_a_1_rel" : [ SenseInfo('02127693-a', 0), SenseInfo('01050603-a', 0) ],
"_edit_n_1_rel" : [  ],
"_cock_n_1_rel" : [ SenseInfo('05526713-n', 0), SenseInfo('04327682-n', 0), SenseInfo('03481824-n', 0), SenseInfo('01792158-n', 0), SenseInfo('01514668-n', 0) ],
"_perverse_a_for_rel" : [ SenseInfo('01818820-a', 2), SenseInfo('01613839-a', 0), SenseInfo('00621524-a', 0), SenseInfo('01818820-a', 2), SenseInfo('01613839-a', 0), SenseInfo('00621524-a', 0), SenseInfo('01818820-a', 2), SenseInfo('01613839-a', 0), SenseInfo('00621524-a', 0) ],
"_point_n_1_rel" : [ SenseInfo('05865998-n', 51), SenseInfo('08620061-n', 21), SenseInfo('06606808-n', 20), SenseInfo('05817845-n', 17), SenseInfo('13939892-n', 16), SenseInfo('15180528-n', 9), SenseInfo('05984066-n', 6), SenseInfo('13902482-n', 3), SenseInfo('13911872-n', 2), SenseInfo('13610162-n', 2), SenseInfo('09396465-n', 2), SenseInfo('06482401-n', 2), SenseInfo('13794885-n', 1), SenseInfo('04731925-n', 1), SenseInfo('03974215-n', 1), SenseInfo('13830305-n', 0), SenseInfo('13712286-n', 0), SenseInfo('13400150-n', 0), SenseInfo('06843520-n', 0), SenseInfo('06822034-n', 0), SenseInfo('06812289-n', 0), SenseInfo('05071556-n', 0), SenseInfo('04732067-n', 0), SenseInfo('03974769-n', 0), SenseInfo('03974671-n', 0), SenseInfo('03213826-n', 0), SenseInfo('05865998-n', 51), SenseInfo('08620061-n', 21), SenseInfo('06606808-n', 20), SenseInfo('05817845-n', 17), SenseInfo('13939892-n', 16), SenseInfo('15180528-n', 9), SenseInfo('05984066-n', 6), SenseInfo('13902482-n', 3), SenseInfo('13911872-n', 2), SenseInfo('13610162-n', 2), SenseInfo('09396465-n', 2), SenseInfo('06482401-n', 2), SenseInfo('13794885-n', 1), SenseInfo('04731925-n', 1), SenseInfo('03974215-n', 1), SenseInfo('13830305-n', 0), SenseInfo('13712286-n', 0), SenseInfo('13400150-n', 0), SenseInfo('06843520-n', 0), SenseInfo('06822034-n', 0), SenseInfo('06812289-n', 0), SenseInfo('05071556-n', 0), SenseInfo('04732067-n', 0), SenseInfo('03974769-n', 0), SenseInfo('03974671-n', 0), SenseInfo('03213826-n', 0) ],
"_intransitive_n_1_rel" : [ SenseInfo('06331641-n', 0) ],
"_detonate_v_cause_rel" : [ SenseInfo('00306723-v', 3), SenseInfo('00306298-v', 0) ],
"_grownup_n_1_rel" : [ SenseInfo('09605289-n', 4), SenseInfo('09605289-n', 4) ],
"_crossover_n_1_rel" : [ SenseInfo('13454130-n', 0), SenseInfo('09980805-n', 0), SenseInfo('07032753-n', 0), SenseInfo('03137228-n', 0) ],
"_unfortunate_a_1_rel" : [ SenseInfo('01049462-a', 7), SenseInfo('00176838-a', 3), SenseInfo('01001547-a', 0), SenseInfo('01049462-a', 7), SenseInfo('00176838-a', 3), SenseInfo('01001547-a', 0), SenseInfo('01049462-a', 7), SenseInfo('00176838-a', 3), SenseInfo('01001547-a', 0), SenseInfo('01049462-a', 7), SenseInfo('00176838-a', 3), SenseInfo('01001547-a', 0), SenseInfo('01049462-a', 7), SenseInfo('00176838-a', 3), SenseInfo('01001547-a', 0), SenseInfo('01049462-a', 7), SenseInfo('00176838-a', 3), SenseInfo('01001547-a', 0), SenseInfo('01049462-a', 7), SenseInfo('00176838-a', 3), SenseInfo('01001547-a', 0), SenseInfo('01049462-a', 7), SenseInfo('00176838-a', 3), SenseInfo('01001547-a', 0), SenseInfo('01049462-a', 7), SenseInfo('00176838-a', 3), SenseInfo('01001547-a', 0) ],
"_structure_n_1_rel" : [ SenseInfo('04341686-n', 24), SenseInfo('04931965-n', 13), SenseInfo('05726345-n', 7), SenseInfo('05225602-n', 3), SenseInfo('08378819-n', 0) ],
"_scarf_n_1_rel" : [ SenseInfo('04143897-n', 2), SenseInfo('04144241-n', 0) ],
"_promontory_n_1_rel" : [ SenseInfo('09399592-n', 0) ],
"_pierce_v_1_rel" : [ SenseInfo('01442361-v', 2), SenseInfo('01769693-v', 1), SenseInfo('02135487-v', 0), SenseInfo('01441510-v', 0), SenseInfo('01441100-v', 0) ],
"_downstairs_p_rel" : [ SenseInfo('00094396-r', 6), SenseInfo('02494092-a', 0) ],
"_dispute_n_1_rel" : [ SenseInfo('07181935-n', 4), SenseInfo('01170813-n', 0), SenseInfo('07181935-n', 4), SenseInfo('01170813-n', 0) ],
"_technology_n_1_rel" : [ SenseInfo('00949619-n', 12), SenseInfo('06125041-n', 2) ],
"_disk_n_1_rel" : [ SenseInfo('13875185-n', 12), SenseInfo('03208556-n', 4), SenseInfo('03924069-n', 0), SenseInfo('03706653-n', 0), SenseInfo('13875185-n', 12), SenseInfo('03208556-n', 4), SenseInfo('03924069-n', 0), SenseInfo('03706653-n', 0), SenseInfo('13875185-n', 12), SenseInfo('03208556-n', 4), SenseInfo('03924069-n', 0), SenseInfo('03706653-n', 0) ],
"_changeover_n_1_rel" : [ SenseInfo('07415730-n', 0) ],
"_annual_a_1_rel" : [ SenseInfo('00678024-a', 1), SenseInfo('01969150-a', 0), SenseInfo('00678024-a', 1), SenseInfo('01969150-a', 0) ],
"_king_n_of_rel" : [ SenseInfo('10231515-n', 19), SenseInfo('10235024-n', 1), SenseInfo('09840217-n', 1), SenseInfo('14435670-n', 0), SenseInfo('11105463-n', 0), SenseInfo('11105298-n', 0), SenseInfo('11105054-n', 0), SenseInfo('03618339-n', 0), SenseInfo('03618219-n', 0), SenseInfo('03618101-n', 0), SenseInfo('10231515-n', 19), SenseInfo('10235024-n', 1), SenseInfo('09840217-n', 1), SenseInfo('14435670-n', 0), SenseInfo('11105463-n', 0), SenseInfo('11105298-n', 0), SenseInfo('11105054-n', 0), SenseInfo('03618339-n', 0), SenseInfo('03618219-n', 0), SenseInfo('03618101-n', 0) ],
"_earmark_v_for_rel" : [ SenseInfo('00724150-v', 0), SenseInfo('00724150-v', 0) ],
"_beginning_n_1_rel" : [ SenseInfo('07290905-n', 18), SenseInfo('15265518-n', 8), SenseInfo('05868051-n', 6), SenseInfo('08507558-n', 2), SenseInfo('00235435-n', 2) ],
"_corrective_a_1_rel" : [ SenseInfo('01300661-a', 0), SenseInfo('00232754-a', 0) ],
"_well-behaved_a_1_rel" : [ SenseInfo('01125241-a', 0), SenseInfo('01125241-a', 0) ],
"_combatant_n_1_rel" : [ SenseInfo('09939313-n', 0) ],
"_as+to_p_sel_rel" : [  ],
"_boat_v_1_rel" : [ SenseInfo('01944692-v', 0) ],
"_with_x_subord_rel" : [  ],
"_spout_n_1_rel" : [ SenseInfo('04287153-n', 0) ],
"_crystallize_v_cause_rel" : [ SenseInfo('00143704-v', 2), SenseInfo('00621058-v', 1), SenseInfo('00445940-v', 1), SenseInfo('00443670-v', 0), SenseInfo('00143704-v', 2), SenseInfo('00621058-v', 1), SenseInfo('00445940-v', 1), SenseInfo('00443670-v', 0) ],
"_patter_n_1_rel" : [ SenseInfo('07013400-n', 2), SenseInfo('07389170-n', 0) ],
"_hit_n_1_rel" : [ SenseInfo('00043902-n', 15), SenseInfo('00125629-n', 2), SenseInfo('00064504-n', 1), SenseInfo('07302542-n', 0), SenseInfo('03522559-n', 0), SenseInfo('01250335-n', 0), SenseInfo('00145779-n', 0) ],
"_unveil_v_1_rel" : [ SenseInfo('01483478-v', 1), SenseInfo('02143283-v', 0), SenseInfo('01483655-v', 0) ],
"_tail_v_1_rel" : [ SenseInfo('02001858-v', 0), SenseInfo('01556178-v', 0), SenseInfo('01321796-v', 0) ],
"_group_v_cause-into_rel" : [ SenseInfo('00656576-v', 4), SenseInfo('01089878-v', 1), SenseInfo('00656576-v', 4), SenseInfo('01089878-v', 1) ],
"_southerner_n_1_rel" : [ SenseInfo('10628222-n', 19) ],
"_piss_v_off_rel" : [ SenseInfo('00072012-v', 1) ],
"_not+just_x_deg_rel" : [ SenseInfo('00004722-r', 162), SenseInfo('00158309-r', 95), SenseInfo('00033308-r', 52), SenseInfo('00246296-r', 33), SenseInfo('00002621-r', 13), SenseInfo('01369663-a', 4), SenseInfo('00958151-a', 0), SenseInfo('00956131-a', 0), SenseInfo('00002950-r', 0), SenseInfo('02036934-a', 0) ],
"_discount_v_1_rel" : [ SenseInfo('00800930-v', 3), SenseInfo('02319428-v', 0) ],
"_stick_v_out_rel" : [ SenseInfo('01528069-v', 5), SenseInfo('01857392-v', 2), SenseInfo('01356750-v', 2), SenseInfo('02754032-v', 0), SenseInfo('02647798-v', 0), SenseInfo('02638845-v', 0), SenseInfo('02638630-v', 0), SenseInfo('01667969-v', 0), SenseInfo('01614581-v', 0), SenseInfo('01614426-v', 0), SenseInfo('01614235-v', 0), SenseInfo('01441993-v', 0), SenseInfo('01441793-v', 0), SenseInfo('01220885-v', 0), SenseInfo('00748084-v', 0), SenseInfo('00622384-v', 0), SenseInfo('01528069-v', 5), SenseInfo('01857392-v', 2), SenseInfo('01356750-v', 2), SenseInfo('02754032-v', 0), SenseInfo('02647798-v', 0), SenseInfo('02638845-v', 0), SenseInfo('02638630-v', 0), SenseInfo('01667969-v', 0), SenseInfo('01614581-v', 0), SenseInfo('01614426-v', 0), SenseInfo('01614235-v', 0), SenseInfo('01441993-v', 0), SenseInfo('01441793-v', 0), SenseInfo('01220885-v', 0), SenseInfo('00748084-v', 0), SenseInfo('00622384-v', 0) ],
"_empirical_a_1_rel" : [ SenseInfo('00858917-a', 4), SenseInfo('03063305-a', 0) ],
"_congratulate_v_on_rel" : [ SenseInfo('00881661-v', 5), SenseInfo('00881998-v', 3), SenseInfo('01772498-v', 1), SenseInfo('00883847-v', 0), SenseInfo('00881661-v', 5), SenseInfo('00881998-v', 3), SenseInfo('01772498-v', 1), SenseInfo('00883847-v', 0) ],
"_sameness_n_1_rel" : [ SenseInfo('04742535-n', 3), SenseInfo('04740326-n', 0) ],
"_compact_n_1_rel" : [ SenseInfo('03078995-n', 1), SenseInfo('06772260-n', 0), SenseInfo('03079136-n', 0) ],
"_do-it-yourself_a_1_rel" : [ SenseInfo('00674476-a', 2), SenseInfo('00674476-a', 2) ],
"_shin_v_up_rel" : [ SenseInfo('01921772-v', 0) ],
"_tour_n_of_rel" : [ SenseInfo('00310666-n', 3), SenseInfo('15292069-n', 1), SenseInfo('15293590-n', 0), SenseInfo('00310666-n', 3), SenseInfo('15292069-n', 1), SenseInfo('15293590-n', 0) ],
"_milliliter_n_1_rel" : [ SenseInfo('13623636-n', 2), SenseInfo('13623636-n', 2), SenseInfo('13623636-n', 2) ],
"_govern_v_1_rel" : [ SenseInfo('02511551-v', 11), SenseInfo('02442205-v', 8), SenseInfo('02586619-v', 3), SenseInfo('02628647-v', 0), SenseInfo('02511551-v', 11), SenseInfo('02442205-v', 8), SenseInfo('02586619-v', 3), SenseInfo('02628647-v', 0) ],
"_under_p_rel" : [ SenseInfo('00486509-r', 2), SenseInfo('01207546-a', 2), SenseInfo('00793682-a', 1), SenseInfo('00486694-r', 0), SenseInfo('00486605-r', 0), SenseInfo('00486384-r', 0), SenseInfo('00486296-r', 0), SenseInfo('00486223-r', 0), SenseInfo('00486157-r', 0), SenseInfo('00486067-r', 0) ],
"_handful_n_of_rel" : [ SenseInfo('13771154-n', 4), SenseInfo('13767350-n', 4), SenseInfo('13771154-n', 4), SenseInfo('13767350-n', 4) ],
"_junkyard_n_1_rel" : [ SenseInfo('08586978-n', 1) ],
"_flavour_n_1_rel" : [ SenseInfo('14526182-n', 0), SenseInfo('05844282-n', 0), SenseInfo('05715864-n', 0) ],
"_wellness_n_1_rel" : [ SenseInfo('14447908-n', 0) ],
"_curve_n_1_rel" : [ SenseInfo('13867641-n', 20), SenseInfo('07000941-n', 10), SenseInfo('00107875-n', 1), SenseInfo('05072663-n', 0), SenseInfo('02829696-n', 0) ],
"_fasten_v_cause-to_rel" : [ SenseInfo('01340439-v', 13), SenseInfo('01343892-v', 4), SenseInfo('01290133-v', 2), SenseInfo('00420132-v', 0), SenseInfo('01340439-v', 13), SenseInfo('01343892-v', 4), SenseInfo('01290133-v', 2), SenseInfo('00420132-v', 0) ],
"_sickness_n_1_rel" : [ SenseInfo('14061805-n', 4), SenseInfo('14473054-n', 0), SenseInfo('14359952-n', 0) ],
"_afford_v_with_rel" : [ SenseInfo('01192628-v', 24), SenseInfo('02339171-v', 13), SenseInfo('02744451-v', 0), SenseInfo('02358034-v', 0) ],
"_lode_n_1_rel" : [ SenseInfo('11446067-n', 0) ],
"_slacks_n_1_rel" : [ SenseInfo('04233715-n', 4), SenseInfo('04233715-n', 4) ],
"_choke_v_up_rel" : [ SenseInfo('00002724-v', 8), SenseInfo('01570562-v', 2), SenseInfo('01570744-v', 1), SenseInfo('00077950-v', 1), SenseInfo('00077698-v', 1), SenseInfo('02529669-v', 0), SenseInfo('02423999-v', 0), SenseInfo('01478603-v', 0), SenseInfo('01476180-v', 0), SenseInfo('00391203-v', 0), SenseInfo('00391021-v', 0), SenseInfo('00358431-v', 0), SenseInfo('00173159-v', 0), SenseInfo('00077606-v', 0), SenseInfo('00002724-v', 8), SenseInfo('01570562-v', 2), SenseInfo('01570744-v', 1), SenseInfo('00077950-v', 1), SenseInfo('00077698-v', 1), SenseInfo('02529669-v', 0), SenseInfo('02423999-v', 0), SenseInfo('01478603-v', 0), SenseInfo('01476180-v', 0), SenseInfo('00391203-v', 0), SenseInfo('00391021-v', 0), SenseInfo('00358431-v', 0), SenseInfo('00173159-v', 0), SenseInfo('00077606-v', 0) ],
"_pinch_n_1_rel" : [ SenseInfo('14409371-n', 0), SenseInfo('14295140-n', 0), SenseInfo('13774115-n', 0), SenseInfo('07417405-n', 0), SenseInfo('00842281-n', 0), SenseInfo('00357275-n', 0), SenseInfo('00088725-n', 0) ],
"_feeble_a_1_rel" : [ SenseInfo('02325304-a', 4), SenseInfo('02325097-a', 0), SenseInfo('02040233-a', 0), SenseInfo('01827766-a', 0), SenseInfo('02325304-a', 4), SenseInfo('02325097-a', 0), SenseInfo('02040233-a', 0), SenseInfo('01827766-a', 0), SenseInfo('02325304-a', 4), SenseInfo('02325097-a', 0), SenseInfo('02040233-a', 0), SenseInfo('01827766-a', 0) ],
"_neutralism_n_1_rel" : [ SenseInfo('06662712-n', 4) ],
"_tuckered+out_a_1_rel" : [  ],
"_triage_n_1_rel" : [ SenseInfo('01017167-n', 0) ],
"_silhouette_n_1_rel" : [ SenseInfo('08613345-n', 5), SenseInfo('04219277-n', 0) ],
"_assault_v_1_rel" : [ SenseInfo('01120069-v', 7), SenseInfo('02567519-v', 0), SenseInfo('00862683-v', 0) ],
"_rectangle_n_1_rel" : [ SenseInfo('13883346-n', 1) ],
"_append_v_1_rel" : [ SenseInfo('01328705-v', 1), SenseInfo('01328513-v', 0), SenseInfo('01027174-v', 0) ],
"_sneeze_v_1_rel" : [ SenseInfo('00004819-v', 0) ],
"_drift_v_off_rel" : [ SenseInfo('01902783-v', 6), SenseInfo('01925694-v', 3), SenseInfo('01881180-v', 3), SenseInfo('02662821-v', 0), SenseInfo('02617338-v', 0), SenseInfo('01903218-v', 0), SenseInfo('01874875-v', 0), SenseInfo('01576779-v', 0), SenseInfo('00572502-v', 0), SenseInfo('00571390-v', 0) ],
"_intemperance_n_1_rel" : [ SenseInfo('04885271-n', 0), SenseInfo('00748011-n', 0), SenseInfo('00747671-n', 0) ],
"_flunk_v_out+of_rel" : [ SenseInfo('02523521-v', 0) ],
"_side_n_1_rel" : [ SenseInfo('08649345-n', 91), SenseInfo('08408709-n', 25), SenseInfo('05551318-n', 18), SenseInfo('08510666-n', 12), SenseInfo('04213626-n', 11), SenseInfo('05852553-n', 5), SenseInfo('08649167-n', 3), SenseInfo('08102282-n', 1), SenseInfo('07655626-n', 1), SenseInfo('06783265-n', 1), SenseInfo('09437454-n', 0), SenseInfo('07442569-n', 0) ],
"_thunder_v_2_rel" : [ SenseInfo('02088792-v', 2), SenseInfo('00915605-v', 1), SenseInfo('02770535-v', 0), SenseInfo('01046587-v', 0) ],
"_putty_n_1_rel" : [ SenseInfo('14703797-n', 0) ],
"_engrossing_a_1_rel" : [ SenseInfo('01344171-a', 2), SenseInfo('01344171-a', 2) ],
"_press_n_1_rel" : [ SenseInfo('14451349-n', 1), SenseInfo('06263369-n', 1), SenseInfo('04000311-n', 1), SenseInfo('08183398-n', 0), SenseInfo('04550184-n', 0), SenseInfo('04000480-n', 0), SenseInfo('03999992-n', 0), SenseInfo('00627013-n', 0), SenseInfo('00113113-n', 0), SenseInfo('14451349-n', 1), SenseInfo('06263369-n', 1), SenseInfo('04000311-n', 1), SenseInfo('08183398-n', 0), SenseInfo('04550184-n', 0), SenseInfo('04000480-n', 0), SenseInfo('03999992-n', 0), SenseInfo('00627013-n', 0), SenseInfo('00113113-n', 0) ],
"_last_a_1_rel" : [ SenseInfo('01730329-a', 109), SenseInfo('01013279-a', 45), SenseInfo('01010271-a', 26), SenseInfo('01412912-a', 2), SenseInfo('00004296-a', 2), SenseInfo('01579128-a', 1), SenseInfo('01212095-a', 1), SenseInfo('00349894-a', 0), SenseInfo('00230076-a', 0), SenseInfo('01730329-a', 109), SenseInfo('01013279-a', 45), SenseInfo('01010271-a', 26), SenseInfo('01412912-a', 2), SenseInfo('00004296-a', 2), SenseInfo('01579128-a', 1), SenseInfo('01212095-a', 1), SenseInfo('00349894-a', 0), SenseInfo('00230076-a', 0), SenseInfo('01730329-a', 109), SenseInfo('01013279-a', 45), SenseInfo('01010271-a', 26), SenseInfo('01412912-a', 2), SenseInfo('00004296-a', 2), SenseInfo('01579128-a', 1), SenseInfo('01212095-a', 1), SenseInfo('00349894-a', 0), SenseInfo('00230076-a', 0), SenseInfo('01730329-a', 109), SenseInfo('01013279-a', 45), SenseInfo('01010271-a', 26), SenseInfo('01412912-a', 2), SenseInfo('00004296-a', 2), SenseInfo('01579128-a', 1), SenseInfo('01212095-a', 1), SenseInfo('00349894-a', 0), SenseInfo('00230076-a', 0) ],
"_goalkeeper_n_1_rel" : [ SenseInfo('10134001-n', 0), SenseInfo('00464037-n', 0) ],
"_congruent_a_1_rel" : [ SenseInfo('00562116-a', 0), SenseInfo('00561600-a', 0) ],
"_defile_v_1_rel" : [ SenseInfo('01537959-v', 0), SenseInfo('01537409-v', 0), SenseInfo('00492410-v', 0) ],
"_particle_n_of_rel" : [ SenseInfo('14585519-n', 33), SenseInfo('09386422-n', 18), SenseInfo('06326406-n', 1) ],
"_wrong_a_with_rel" : [ SenseInfo('00632438-a', 15), SenseInfo('02035337-a', 12), SenseInfo('00136185-a', 9), SenseInfo('01092371-a', 5), SenseInfo('00633778-a', 0), SenseInfo('01881478-a', 0), SenseInfo('01694081-a', 0), SenseInfo('01662119-a', 0), SenseInfo('00023854-a', 0), SenseInfo('00632438-a', 15), SenseInfo('02035337-a', 12), SenseInfo('00136185-a', 9), SenseInfo('01092371-a', 5), SenseInfo('00633778-a', 0), SenseInfo('01881478-a', 0), SenseInfo('01694081-a', 0), SenseInfo('01662119-a', 0), SenseInfo('00023854-a', 0), SenseInfo('00632438-a', 15), SenseInfo('02035337-a', 12), SenseInfo('00136185-a', 9), SenseInfo('01092371-a', 5), SenseInfo('00633778-a', 0), SenseInfo('01881478-a', 0), SenseInfo('01694081-a', 0), SenseInfo('01662119-a', 0), SenseInfo('00023854-a', 0), SenseInfo('00632438-a', 15), SenseInfo('02035337-a', 12), SenseInfo('00136185-a', 9), SenseInfo('01092371-a', 5), SenseInfo('00633778-a', 0), SenseInfo('01881478-a', 0), SenseInfo('01694081-a', 0), SenseInfo('01662119-a', 0), SenseInfo('00023854-a', 0) ],
"_hit_v_1_rel" : [ SenseInfo('01405044-v', 25), SenseInfo('01236164-v', 21), SenseInfo('01400044-v', 18), SenseInfo('02020590-v', 9), SenseInfo('01209135-v', 8), SenseInfo('01137138-v', 8), SenseInfo('02206462-v', 3), SenseInfo('01111816-v', 3), SenseInfo('02108791-v', 2), SenseInfo('01123887-v', 2), SenseInfo('02482425-v', 0), SenseInfo('02104161-v', 0), SenseInfo('02006834-v', 0), SenseInfo('01209426-v', 0), SenseInfo('01157421-v', 0), SenseInfo('01152396-v', 0), SenseInfo('00781903-v', 0) ],
"_vogue_n_1_rel" : [ SenseInfo('05750163-n', 2), SenseInfo('14411884-n', 0) ],
"_crab_n_1_rel" : [ SenseInfo('01976957-n', 1), SenseInfo('09974054-n', 0), SenseInfo('09752657-n', 0), SenseInfo('08686658-n', 0), SenseInfo('07787715-n', 0), SenseInfo('02185167-n', 0), SenseInfo('00445529-n', 0) ],
"_expectancy_n_1_rel" : [ SenseInfo('07511080-n', 1), SenseInfo('05951323-n', 1) ],
"_imbed_v_1_rel" : [ SenseInfo('01528821-v', 3) ],
"_vertigo_n_1_rel" : [ SenseInfo('14372513-n', 1) ],
"_lavish_a_1_rel" : [ SenseInfo('01111965-a', 2), SenseInfo('02025274-a', 0) ],
"_terminology_n_1_rel" : [ SenseInfo('06304059-n', 2) ],
"_closure_n_of_rel" : [ SenseInfo('00281462-n', 1), SenseInfo('06666829-n', 0), SenseInfo('06249421-n', 0), SenseInfo('05789089-n', 0), SenseInfo('02853449-n', 0), SenseInfo('01074694-n', 0), SenseInfo('00229260-n', 0) ],
"_lighter_n_1_rel" : [ SenseInfo('15101361-n', 0), SenseInfo('03666591-n', 0), SenseInfo('02792552-n', 0) ],
"_skerry_n_1_rel" : [  ],
"_sometimes_a_1_rel" : [  ],
"_protein_n_1_rel" : [ SenseInfo('14728724-n', 23) ],
"_armchair_n_1_rel" : [ SenseInfo('02738535-n', 3) ],
"_disease_n_1_rel" : [ SenseInfo('14070360-n', 26) ],
"_latter_n_1_rel" : [ SenseInfo('13846708-n', 0) ],
"_cicada_n_1_rel" : [ SenseInfo('02256656-n', 1) ],
"_arsenic_n_1_rel" : [ SenseInfo('14768201-n', 1), SenseInfo('14629149-n', 0) ],
"_cottage_n_1_rel" : [ SenseInfo('02919792-n', 4), SenseInfo('02919792-n', 4) ],
"_belay_v_1_rel" : [ SenseInfo('01342755-v', 0), SenseInfo('01342636-v', 0) ],
"_intermission_n_1_rel" : [ SenseInfo('01063578-n', 1), SenseInfo('15271008-n', 0) ],
"_improper_a_for_rel" : [ SenseInfo('01880531-a', 0), SenseInfo('01961410-a', 0), SenseInfo('00136185-a', 0), SenseInfo('01880531-a', 0), SenseInfo('01961410-a', 0), SenseInfo('00136185-a', 0), SenseInfo('01880531-a', 0), SenseInfo('01961410-a', 0), SenseInfo('00136185-a', 0) ],
"_costings_n_1_rel" : [ SenseInfo('00619142-n', 0), SenseInfo('00619142-n', 0) ],
"_regeneration_n_of_rel" : [ SenseInfo('13548734-n', 0), SenseInfo('13539262-n', 0), SenseInfo('01047937-n', 0), SenseInfo('00269963-n', 0) ],
"_authoritarian_n_1_rel" : [ SenseInfo('09824135-n', 0) ],
"_quite_a_1_rel" : [  ],
"_catastrophic_a_1_rel" : [ SenseInfo('01161635-a', 1), SenseInfo('01161635-a', 1) ],
"_agitate_v_for_rel" : [ SenseInfo('02585050-v', 2), SenseInfo('01762528-v', 1), SenseInfo('02589576-v', 0), SenseInfo('01893988-v', 0), SenseInfo('01889610-v', 0), SenseInfo('01419473-v', 0) ],
"_potential_a_1_rel" : [ SenseInfo('00044353-a', 7), SenseInfo('01884176-a', 6), SenseInfo('00044353-a', 7), SenseInfo('01884176-a', 6), SenseInfo('00044353-a', 7), SenseInfo('01884176-a', 6), SenseInfo('00044353-a', 7), SenseInfo('01884176-a', 6), SenseInfo('00044353-a', 7), SenseInfo('01884176-a', 6) ],
"_germane_a_to_rel" : [ SenseInfo('01975671-a', 0) ],
"_artistical_a_1_rel" : [  ],
"_roller_n_1_rel" : [ SenseInfo('00129435-n', 1), SenseInfo('07349532-n', 0), SenseInfo('04101701-n', 0), SenseInfo('04101497-n', 0), SenseInfo('03150232-n', 0), SenseInfo('01826364-n', 0), SenseInfo('01814755-n', 0) ],
"_announcement_n_of_rel" : [ SenseInfo('06726158-n', 4), SenseInfo('06746580-n', 3), SenseInfo('06726158-n', 4), SenseInfo('06746580-n', 3) ],
"_manuscript_n_of_rel" : [ SenseInfo('06406979-n', 2), SenseInfo('06407221-n', 0) ],
"_minimalist_n_1_rel" : [ SenseInfo('10320354-n', 0), SenseInfo('10320230-n', 0) ],
"_clip_v_on_rel" : [ SenseInfo('01456463-v', 2), SenseInfo('01901447-v', 0), SenseInfo('01367616-v', 0), SenseInfo('01321002-v', 0), SenseInfo('00292877-v', 0) ],
"_romancer_n_1_rel" : [  ],
"_comeliness_n_1_rel" : [ SenseInfo('04685396-n', 0) ],
"_chatter_v_on_rel" : [ SenseInfo('02185861-v', 1), SenseInfo('01553869-v', 1), SenseInfo('01038666-v', 1), SenseInfo('01036804-v', 1), SenseInfo('01037303-v', 0), SenseInfo('02185861-v', 1), SenseInfo('01553869-v', 1), SenseInfo('01038666-v', 1), SenseInfo('01036804-v', 1), SenseInfo('01037303-v', 0) ],
"_usher_n_1_rel" : [ SenseInfo('11357879-n', 0), SenseInfo('10742111-n', 0), SenseInfo('10741821-n', 0) ],
"_light_a_of_rel" : [ SenseInfo('01186408-a', 14), SenseInfo('00408660-a', 9), SenseInfo('01193046-a', 4), SenseInfo('01190993-a', 3), SenseInfo('01190316-a', 3), SenseInfo('00269989-a', 3), SenseInfo('02320442-a', 2), SenseInfo('01182414-a', 2), SenseInfo('00503527-a', 2), SenseInfo('01906464-a', 1), SenseInfo('01192393-a', 1), SenseInfo('00712186-a', 1), SenseInfo('01191876-a', 0), SenseInfo('01191448-a', 0), SenseInfo('02544525-a', 0), SenseInfo('02414188-a', 0), SenseInfo('02401863-a', 0), SenseInfo('02337329-a', 0), SenseInfo('02165318-a', 0), SenseInfo('02121572-a', 0), SenseInfo('02121424-a', 0), SenseInfo('01188186-a', 0), SenseInfo('00993117-a', 0), SenseInfo('00693570-a', 0), SenseInfo('00361837-a', 0), SenseInfo('01186408-a', 14), SenseInfo('00408660-a', 9), SenseInfo('01193046-a', 4), SenseInfo('01190993-a', 3), SenseInfo('01190316-a', 3), SenseInfo('00269989-a', 3), SenseInfo('02320442-a', 2), SenseInfo('01182414-a', 2), SenseInfo('00503527-a', 2), SenseInfo('01906464-a', 1), SenseInfo('01192393-a', 1), SenseInfo('00712186-a', 1), SenseInfo('01191876-a', 0), SenseInfo('01191448-a', 0), SenseInfo('02544525-a', 0), SenseInfo('02414188-a', 0), SenseInfo('02401863-a', 0), SenseInfo('02337329-a', 0), SenseInfo('02165318-a', 0), SenseInfo('02121572-a', 0), SenseInfo('02121424-a', 0), SenseInfo('01188186-a', 0), SenseInfo('00993117-a', 0), SenseInfo('00693570-a', 0), SenseInfo('00361837-a', 0) ],
"_sufficient_a_1_rel" : [ SenseInfo('02335828-a', 30) ],
"_man_n_1_rel" : [ SenseInfo('10287213-n', 749), SenseInfo('10582746-n', 346), SenseInfo('10289039-n', 87), SenseInfo('02472293-n', 29), SenseInfo('10289176-n', 4), SenseInfo('10288763-n', 3), SenseInfo('10745332-n', 0), SenseInfo('10288516-n', 0), SenseInfo('08887716-n', 0), SenseInfo('03716327-n', 0), SenseInfo('02472987-n', 0), SenseInfo('10287213-n', 749), SenseInfo('10582746-n', 346), SenseInfo('10289039-n', 87), SenseInfo('02472293-n', 29), SenseInfo('10289176-n', 4), SenseInfo('10288763-n', 3), SenseInfo('10745332-n', 0), SenseInfo('10288516-n', 0), SenseInfo('08887716-n', 0), SenseInfo('03716327-n', 0), SenseInfo('02472987-n', 0) ],
"_attainment_n_of_rel" : [ SenseInfo('00062806-n', 1), SenseInfo('00048656-n', 1), SenseInfo('05637558-n', 0) ],
"_representative_n_of_rel" : [ SenseInfo('10522035-n', 8), SenseInfo('10638385-n', 4), SenseInfo('09955781-n', 4), SenseInfo('05820620-n', 0), SenseInfo('10522035-n', 8), SenseInfo('10638385-n', 4), SenseInfo('09955781-n', 4), SenseInfo('05820620-n', 0) ],
"_jordanian_n_1_rel" : [ SenseInfo('09718811-n', 0) ],
"_far_a_from_rel" : [ SenseInfo('00442361-a', 20), SenseInfo('01434717-a', 5), SenseInfo('02032386-a', 1), SenseInfo('01535481-a', 0), SenseInfo('00442361-a', 20), SenseInfo('01434717-a', 5), SenseInfo('02032386-a', 1), SenseInfo('01535481-a', 0), SenseInfo('00442361-a', 20), SenseInfo('01434717-a', 5), SenseInfo('02032386-a', 1), SenseInfo('01535481-a', 0), SenseInfo('00442361-a', 20), SenseInfo('01434717-a', 5), SenseInfo('02032386-a', 1), SenseInfo('01535481-a', 0), SenseInfo('00442361-a', 20), SenseInfo('01434717-a', 5), SenseInfo('02032386-a', 1), SenseInfo('01535481-a', 0), SenseInfo('00442361-a', 20), SenseInfo('01434717-a', 5), SenseInfo('02032386-a', 1), SenseInfo('01535481-a', 0), SenseInfo('00442361-a', 20), SenseInfo('01434717-a', 5), SenseInfo('02032386-a', 1), SenseInfo('01535481-a', 0) ],
"_sad_a_1_rel" : [ SenseInfo('01361863-a', 9), SenseInfo('01366277-a', 0), SenseInfo('01126841-a', 0), SenseInfo('01361863-a', 9), SenseInfo('01366277-a', 0), SenseInfo('01126841-a', 0), SenseInfo('01361863-a', 9), SenseInfo('01366277-a', 0), SenseInfo('01126841-a', 0), SenseInfo('01361863-a', 9), SenseInfo('01366277-a', 0), SenseInfo('01126841-a', 0), SenseInfo('01361863-a', 9), SenseInfo('01366277-a', 0), SenseInfo('01126841-a', 0), SenseInfo('01361863-a', 9), SenseInfo('01366277-a', 0), SenseInfo('01126841-a', 0), SenseInfo('01361863-a', 9), SenseInfo('01366277-a', 0), SenseInfo('01126841-a', 0), SenseInfo('01361863-a', 9), SenseInfo('01366277-a', 0), SenseInfo('01126841-a', 0), SenseInfo('01361863-a', 9), SenseInfo('01366277-a', 0), SenseInfo('01126841-a', 0) ],
"_laden_a_with_rel" : [ SenseInfo('01085661-a', 3), SenseInfo('00869972-a', 0) ],
"_ale_n_1_rel" : [ SenseInfo('07889510-n', 0) ],
"_yogurt_n_1_rel" : [ SenseInfo('07849336-n', 0) ],
"_maternal_a_1_rel" : [ SenseInfo('01734884-a', 1), SenseInfo('02759367-a', 0), SenseInfo('01722529-a', 0), SenseInfo('01972349-a', 0) ],
"_emblematic_a_of_rel" : [ SenseInfo('01982186-a', 3), SenseInfo('02469119-a', 0) ],
"_Lappish_a_1_rel" : [  ],
"_boo_v_1_rel" : [ SenseInfo('00862225-v', 1) ],
"_wobble_v_1_rel" : [ SenseInfo('01869003-v', 5), SenseInfo('01884974-v', 0), SenseInfo('01871546-v', 0) ],
"_part_n_i_rel" : [ SenseInfo('13809207-n', 113), SenseInfo('03892891-n', 24), SenseInfo('09385911-n', 19), SenseInfo('05671974-n', 19), SenseInfo('08630039-n', 15), SenseInfo('00720565-n', 13), SenseInfo('05929008-n', 9), SenseInfo('13285176-n', 8), SenseInfo('05867413-n', 7), SenseInfo('05256358-n', 3), SenseInfo('07030718-n', 2), SenseInfo('00787465-n', 2) ],
"_realize_v_1_rel" : [ SenseInfo('00728617-v', 48), SenseInfo('00591115-v', 37), SenseInfo('01644746-v', 8), SenseInfo('02289295-v', 2), SenseInfo('02244603-v', 0), SenseInfo('01707495-v', 0), SenseInfo('00728617-v', 48), SenseInfo('00591115-v', 37), SenseInfo('01644746-v', 8), SenseInfo('02289295-v', 2), SenseInfo('02244603-v', 0), SenseInfo('01707495-v', 0), SenseInfo('00728617-v', 48), SenseInfo('00591115-v', 37), SenseInfo('01644746-v', 8), SenseInfo('02289295-v', 2), SenseInfo('02244603-v', 0), SenseInfo('01707495-v', 0), SenseInfo('00728617-v', 48), SenseInfo('00591115-v', 37), SenseInfo('01644746-v', 8), SenseInfo('02289295-v', 2), SenseInfo('02244603-v', 0), SenseInfo('01707495-v', 0) ],
"_utilize_v_1_rel" : [ SenseInfo('01158872-v', 15), SenseInfo('00161872-v', 0), SenseInfo('01158872-v', 15), SenseInfo('00161872-v', 0) ],
"_talk_v_up_rel" : [ SenseInfo('00962447-v', 108), SenseInfo('00941990-v', 26), SenseInfo('00963570-v', 8), SenseInfo('00952841-v', 4), SenseInfo('00937208-v', 2), SenseInfo('00830761-v', 0) ],
"_in+law_n_1_rel" : [ SenseInfo('10207169-n', 0), SenseInfo('10207169-n', 0) ],
"_spark_v_off_rel" : [ SenseInfo('01643657-v', 5), SenseInfo('02766687-v', 1) ],
"_resolve_n_1_rel" : [ SenseInfo('04861486-n', 1), SenseInfo('06511874-n', 0) ],
"_horn_v_in_rel" : [ SenseInfo('01445027-v', 0), SenseInfo('01445027-v', 0) ],
"_cunning_a_1_rel" : [ SenseInfo('00167278-a', 0), SenseInfo('00148078-a', 0), SenseInfo('00061885-a', 0) ],
"_positive_n_1_rel" : [ SenseInfo('06322468-n', 0), SenseInfo('03987509-n', 0), SenseInfo('06322468-n', 0), SenseInfo('03987509-n', 0) ],
"_ore_n_1_rel" : [ SenseInfo('14688500-n', 3), SenseInfo('13682450-n', 0) ],
"_agony_n_1_rel" : [ SenseInfo('07495551-n', 5), SenseInfo('14324274-n', 4) ],
"_englishman_n_1_rel" : [ SenseInfo('09701603-n', 5) ],
"_bottle_v_1_rel" : [ SenseInfo('02283080-v', 0), SenseInfo('01502279-v', 0) ],
"_laptop_n_1_rel" : [ SenseInfo('03642806-n', 0), SenseInfo('03642806-n', 0) ],
"_engage_v_in_rel" : [ SenseInfo('02375131-v', 31), SenseInfo('00600370-v', 9), SenseInfo('02409412-v', 2), SenseInfo('02401399-v', 1), SenseInfo('00886602-v', 1), SenseInfo('00220115-v', 1), SenseInfo('02376089-v', 0), SenseInfo('02240151-v', 0), SenseInfo('02208537-v', 0), SenseInfo('01510827-v', 0), SenseInfo('02375131-v', 31), SenseInfo('00600370-v', 9), SenseInfo('02409412-v', 2), SenseInfo('02401399-v', 1), SenseInfo('00886602-v', 1), SenseInfo('00220115-v', 1), SenseInfo('02376089-v', 0), SenseInfo('02240151-v', 0), SenseInfo('02208537-v', 0), SenseInfo('01510827-v', 0) ],
"_tony_a_1_rel" : [  ],
"_serious_a_1_rel" : [ SenseInfo('02118379-a', 29), SenseInfo('01279611-a', 10), SenseInfo('00651039-a', 4), SenseInfo('01333477-a', 3), SenseInfo('02123314-a', 0), SenseInfo('00748359-a', 0), SenseInfo('02118379-a', 29), SenseInfo('01279611-a', 10), SenseInfo('00651039-a', 4), SenseInfo('01333477-a', 3), SenseInfo('02123314-a', 0), SenseInfo('00748359-a', 0) ],
"_post-_a_1_rel" : [  ],
"_supernatural_a_1_rel" : [ SenseInfo('01574446-a', 3) ],
"_imposing_a_1_rel" : [ SenseInfo('01283508-a', 1), SenseInfo('00752110-a', 0), SenseInfo('01283508-a', 1), SenseInfo('00752110-a', 0) ],
"_major_a_1_rel" : [ SenseInfo('01472628-a', 38), SenseInfo('01471538-a', 25), SenseInfo('01471002-a', 22), SenseInfo('01472351-a', 1), SenseInfo('01472098-a', 1), SenseInfo('01473680-a', 0), SenseInfo('01471848-a', 0), SenseInfo('02100236-a', 0) ],
"_doubt_n_1_rel" : [ SenseInfo('05698247-n', 26), SenseInfo('04757522-n', 4), SenseInfo('05698247-n', 26), SenseInfo('04757522-n', 4) ],
"_login_n_1_rel" : [  ],
"_wild_a_1_rel" : [ SenseInfo('02390335-a', 29), SenseInfo('02389220-a', 5), SenseInfo('01727303-a', 5), SenseInfo('00601650-a', 2), SenseInfo('01514141-a', 1), SenseInfo('02353211-a', 0), SenseInfo('02077625-a', 0), SenseInfo('02059811-a', 0), SenseInfo('01942732-a', 0), SenseInfo('01243102-a', 0), SenseInfo('00886448-a', 0), SenseInfo('00412788-a', 0), SenseInfo('00304144-a', 0), SenseInfo('02390335-a', 29), SenseInfo('02389220-a', 5), SenseInfo('01727303-a', 5), SenseInfo('00601650-a', 2), SenseInfo('01514141-a', 1), SenseInfo('02353211-a', 0), SenseInfo('02077625-a', 0), SenseInfo('02059811-a', 0), SenseInfo('01942732-a', 0), SenseInfo('01243102-a', 0), SenseInfo('00886448-a', 0), SenseInfo('00412788-a', 0), SenseInfo('00304144-a', 0), SenseInfo('02390335-a', 29), SenseInfo('02389220-a', 5), SenseInfo('01727303-a', 5), SenseInfo('00601650-a', 2), SenseInfo('01514141-a', 1), SenseInfo('02353211-a', 0), SenseInfo('02077625-a', 0), SenseInfo('02059811-a', 0), SenseInfo('01942732-a', 0), SenseInfo('01243102-a', 0), SenseInfo('00886448-a', 0), SenseInfo('00412788-a', 0), SenseInfo('00304144-a', 0), SenseInfo('02390335-a', 29), SenseInfo('02389220-a', 5), SenseInfo('01727303-a', 5), SenseInfo('00601650-a', 2), SenseInfo('01514141-a', 1), SenseInfo('02353211-a', 0), SenseInfo('02077625-a', 0), SenseInfo('02059811-a', 0), SenseInfo('01942732-a', 0), SenseInfo('01243102-a', 0), SenseInfo('00886448-a', 0), SenseInfo('00412788-a', 0), SenseInfo('00304144-a', 0), SenseInfo('02390335-a', 29), SenseInfo('02389220-a', 5), SenseInfo('01727303-a', 5), SenseInfo('00601650-a', 2), SenseInfo('01514141-a', 1), SenseInfo('02353211-a', 0), SenseInfo('02077625-a', 0), SenseInfo('02059811-a', 0), SenseInfo('01942732-a', 0), SenseInfo('01243102-a', 0), SenseInfo('00886448-a', 0), SenseInfo('00412788-a', 0), SenseInfo('00304144-a', 0) ],
"_toot_n_of_rel" : [ SenseInfo('07398276-n', 0), SenseInfo('00511041-n', 0) ],
"_rollback_n_1_rel" : [ SenseInfo('00980779-n', 0), SenseInfo('00362258-n', 0) ],
"_canopy_n_1_rel" : [ SenseInfo('02952237-n', 0), SenseInfo('02952109-n', 0), SenseInfo('02951843-n', 0) ],
"_coroner_n_1_rel" : [ SenseInfo('09965985-n', 5) ],
"_snowscooter_n_1_rel" : [  ],
"_peneplain_n_1_rel" : [ SenseInfo('09388653-n', 0) ],
"_arc_v_cause_rel" : [ SenseInfo('02034986-v', 0) ],
"_background_n_1_rel" : [ SenseInfo('04921417-n', 8), SenseInfo('05933834-n', 5), SenseInfo('05823517-n', 5), SenseInfo('07430480-n', 2), SenseInfo('07285191-n', 2), SenseInfo('14513259-n', 1), SenseInfo('02769075-n', 0), SenseInfo('02768864-n', 0) ],
"_scientist_n_1_rel" : [ SenseInfo('10560637-n', 7) ],
"_rival_n_1_rel" : [ SenseInfo('10533013-n', 1) ],
"_grandfather_v_in_rel" : [  ],
"_preferment_n_1_rel" : [ SenseInfo('00198631-n', 1), SenseInfo('07237647-n', 0) ],
"_abeam_p_rel" : [ SenseInfo('00075881-r', 0) ],
"_inform_v_on_rel" : [ SenseInfo('00831651-v', 46), SenseInfo('00522613-v', 2), SenseInfo('00833199-v', 1) ],
"_rinse_v_1_rel" : [ SenseInfo('01536168-v', 1), SenseInfo('01270199-v', 1), SenseInfo('00037138-v', 0) ],
"_adaptive_a_1_rel" : [ SenseInfo('00046109-a', 0) ],
"_couple_n_1_rel" : [ SenseInfo('07985628-n', 13), SenseInfo('07988857-n', 9), SenseInfo('13771290-n', 6), SenseInfo('13743605-n', 2), SenseInfo('09257563-n', 0) ],
"_lineament_n_1_rel" : [ SenseInfo('05849284-n', 0), SenseInfo('05601758-n', 0) ],
"_fray_n_1_rel" : [ SenseInfo('01176335-n', 0) ],
"_shore_n_1_rel" : [ SenseInfo('09433442-n', 18), SenseInfo('04204468-n', 0), SenseInfo('09433442-n', 18), SenseInfo('04204468-n', 0) ],
"_complex_a_1_rel" : [ SenseInfo('02176178-a', 28) ],
"_gape_v_at_rel" : [ SenseInfo('02164531-v', 1), SenseInfo('02718750-v', 0), SenseInfo('02164531-v', 1), SenseInfo('02718750-v', 0) ],
"_fille+de+chambre_n_1_rel" : [ SenseInfo('09906293-n', 6), SenseInfo('09906293-n', 6), SenseInfo('09906293-n', 6) ],
"_always_a_1_rel" : [  ],
"_victor_n_1_rel" : [ SenseInfo('10752930-n', 1), SenseInfo('10782940-n', 0) ],
"_sporadic_a_1_rel" : [ SenseInfo('00593374-a', 3), SenseInfo('00593374-a', 3) ],
"_mighty_a_1_rel" : [ SenseInfo('01826575-a', 10), SenseInfo('01826575-a', 10), SenseInfo('01826575-a', 10), SenseInfo('01826575-a', 10) ],
"_blow_v_away_rel" : [ SenseInfo('00007012-v', 6), SenseInfo('02769241-v', 5), SenseInfo('00034948-v', 3), SenseInfo('01902783-v', 2), SenseInfo('02135877-v', 1), SenseInfo('00477247-v', 1), SenseInfo('02527651-v', 0), SenseInfo('02268351-v', 0), SenseInfo('02266148-v', 0), SenseInfo('02178340-v', 0), SenseInfo('02135727-v', 0), SenseInfo('02117170-v', 0), SenseInfo('02101046-v', 0), SenseInfo('02100632-v', 0), SenseInfo('02068745-v', 0), SenseInfo('01849054-v', 0), SenseInfo('01545208-v', 0), SenseInfo('00934965-v', 0), SenseInfo('00883226-v', 0), SenseInfo('00779804-v', 0), SenseInfo('00435294-v', 0), SenseInfo('00310155-v', 0) ],
"_technological_a_1_rel" : [ SenseInfo('02084979-a', 6), SenseInfo('02809692-a', 3) ],
"_fragrance_n_1_rel" : [ SenseInfo('05714466-n', 1), SenseInfo('04980463-n', 0) ],
"_typical_a_of-for_rel" : [ SenseInfo('02468635-a', 26), SenseInfo('00357556-a', 2), SenseInfo('01595440-a', 0), SenseInfo('02468635-a', 26), SenseInfo('00357556-a', 2), SenseInfo('01595440-a', 0), SenseInfo('02468635-a', 26), SenseInfo('00357556-a', 2), SenseInfo('01595440-a', 0), SenseInfo('02468635-a', 26), SenseInfo('00357556-a', 2), SenseInfo('01595440-a', 0), SenseInfo('02468635-a', 26), SenseInfo('00357556-a', 2), SenseInfo('01595440-a', 0), SenseInfo('02468635-a', 26), SenseInfo('00357556-a', 2), SenseInfo('01595440-a', 0) ],
"_just+about_a_1_rel" : [  ],
"_concentrate_v_on_rel" : [ SenseInfo('00237511-v', 8), SenseInfo('00722232-v', 4), SenseInfo('00405236-v', 4), SenseInfo('00244625-v', 2), SenseInfo('02032934-v', 1), SenseInfo('00365188-v', 0), SenseInfo('00237259-v', 0), SenseInfo('00236999-v', 0), SenseInfo('00237511-v', 8), SenseInfo('00722232-v', 4), SenseInfo('00405236-v', 4), SenseInfo('00244625-v', 2), SenseInfo('02032934-v', 1), SenseInfo('00365188-v', 0), SenseInfo('00237259-v', 0), SenseInfo('00236999-v', 0), SenseInfo('00237511-v', 8), SenseInfo('00722232-v', 4), SenseInfo('00405236-v', 4), SenseInfo('00244625-v', 2), SenseInfo('02032934-v', 1), SenseInfo('00365188-v', 0), SenseInfo('00237259-v', 0), SenseInfo('00236999-v', 0) ],
"_postmark_v_1_rel" : [ SenseInfo('01274104-v', 0), SenseInfo('01274104-v', 0) ],
"_network_v_1_rel" : [ SenseInfo('01032840-v', 0) ],
"_cup_n_of_rel" : [ SenseInfo('03147509-n', 14), SenseInfo('13766733-n', 7), SenseInfo('13904665-n', 2), SenseInfo('13619168-n', 0), SenseInfo('12267841-n', 0), SenseInfo('07930864-n', 0), SenseInfo('03148130-n', 0), SenseInfo('03147901-n', 0) ],
"_uncover_v_1_rel" : [ SenseInfo('02143283-v', 4), SenseInfo('01339505-v', 1) ],
"_oncogene_n_1_rel" : [ SenseInfo('05440410-n', 0) ],
"_verbose_a_1_rel" : [ SenseInfo('00549236-a', 0) ],
"_clear-cut_a_1_rel" : [ SenseInfo('00429016-a', 2), SenseInfo('01290028-a', 0), SenseInfo('00780011-a', 0), SenseInfo('00429016-a', 2), SenseInfo('01290028-a', 0), SenseInfo('00780011-a', 0) ],
"_ferocious_a_1_rel" : [ SenseInfo('02511528-a', 1) ],
"_hinge_v_on_rel" : [ SenseInfo('01297174-v', 0) ],
"_bulb_n_1_rel" : [ SenseInfo('13134059-n', 2), SenseInfo('03665924-n', 2), SenseInfo('02915480-n', 1), SenseInfo('13864035-n', 0), SenseInfo('05495172-n', 0), SenseInfo('05227079-n', 0) ],
"_face_v_up_rel" : [ SenseInfo('00812298-v', 56), SenseInfo('01078783-v', 33), SenseInfo('02693319-v', 14), SenseInfo('02693691-v', 4), SenseInfo('01908365-v', 4), SenseInfo('01066433-v', 3), SenseInfo('02137907-v', 0), SenseInfo('01271936-v', 0), SenseInfo('01271189-v', 0), SenseInfo('00812298-v', 56), SenseInfo('01078783-v', 33), SenseInfo('02693319-v', 14), SenseInfo('02693691-v', 4), SenseInfo('01908365-v', 4), SenseInfo('01066433-v', 3), SenseInfo('02137907-v', 0), SenseInfo('01271936-v', 0), SenseInfo('01271189-v', 0) ],
"_decisive_a_1_rel" : [ SenseInfo('00684480-a', 8), SenseInfo('00701178-a', 1), SenseInfo('00685638-a', 0), SenseInfo('00656132-a', 0), SenseInfo('00684480-a', 8), SenseInfo('00701178-a', 1), SenseInfo('00685638-a', 0), SenseInfo('00656132-a', 0) ],
"_contest_v_1_rel" : [ SenseInfo('00869596-v', 3) ],
"_dormitory_n_1_rel" : [ SenseInfo('03224893-n', 2), SenseInfo('03225108-n', 0) ],
"_zap_v_1_rel" : [ SenseInfo('01768935-v', 0), SenseInfo('01325288-v', 0), SenseInfo('01133288-v', 0), SenseInfo('00321936-v', 0) ],
"_addicted_a_1_rel" : [ SenseInfo('00047029-a', 1) ],
"_vole_n_1_rel" : [ SenseInfo('02339376-n', 0), SenseInfo('02339376-n', 0) ],
"_guard_v_1_rel" : [ SenseInfo('02456031-v', 6), SenseInfo('01129337-v', 6), SenseInfo('01129876-v', 2), SenseInfo('02599878-v', 0) ],
"_scattered_a_1_rel" : [ SenseInfo('00542099-a', 7), SenseInfo('00465221-a', 0) ],
"_linden_n_1_rel" : [ SenseInfo('12203331-n', 1), SenseInfo('12202936-n', 0) ],
"_stereotype_n_1_rel" : [ SenseInfo('05927586-n', 6) ],
"_town_n_1_rel" : [ SenseInfo('08665504-n', 67), SenseInfo('08226514-n', 8), SenseInfo('08672199-n', 4), SenseInfo('11346710-n', 0), SenseInfo('08665504-n', 67), SenseInfo('08226514-n', 8), SenseInfo('08672199-n', 4), SenseInfo('11346710-n', 0), SenseInfo('08665504-n', 67), SenseInfo('08226514-n', 8), SenseInfo('08672199-n', 4), SenseInfo('11346710-n', 0) ],
"_fritter_v_away_rel" : [ SenseInfo('01195804-v', 0) ],
"_vision_n_1_rel" : [ SenseInfo('05768252-n', 13), SenseInfo('05654362-n', 8), SenseInfo('05713524-n', 7), SenseInfo('05625465-n', 2), SenseInfo('07288485-n', 1), SenseInfo('05768252-n', 13), SenseInfo('05654362-n', 8), SenseInfo('05713524-n', 7), SenseInfo('05625465-n', 2), SenseInfo('07288485-n', 1) ],
"_lean-to_n_1_rel" : [ SenseInfo('03652729-n', 0), SenseInfo('03652729-n', 0) ],
"_oblong_a_1_rel" : [ SenseInfo('02169591-a', 0), SenseInfo('01435507-a', 0) ],
"_amusing_a_1_rel" : [ SenseInfo('01344485-a', 0), SenseInfo('01265308-a', 0) ],
"_hindmost_n_1_rel" : [ SenseInfo('00197773-a', 0) ],
"_dictation_n_1_rel" : [ SenseInfo('07168131-n', 0), SenseInfo('07160635-n', 0), SenseInfo('06387332-n', 0) ],
"_left+over_a_1_rel" : [ SenseInfo('00926505-a', 0), SenseInfo('00926505-a', 0) ],
"_facet_n_1_rel" : [ SenseInfo('05850624-n', 3), SenseInfo('13913164-n', 0) ],
"_shipowner_n_1_rel" : [ SenseInfo('10590239-n', 0) ],
"_footballing_n_1_rel" : [  ],
"_disintegrative_a_1_rel" : [ SenseInfo('01331878-a', 1) ],
"_twiddle_v_1_rel" : [ SenseInfo('02048891-v', 1), SenseInfo('01224211-v', 0) ],
"_artwork_n_1_rel" : [ SenseInfo('06998748-n', 0) ],
"_guardian_n_1_rel" : [ SenseInfo('09614684-n', 4) ],
"_misery_n_1_rel" : [ SenseInfo('14448333-n', 8), SenseInfo('07533978-n', 0) ],
"_pace_n_i_rel" : [ SenseInfo('15280497-n', 10), SenseInfo('13757249-n', 6), SenseInfo('05058580-n', 4), SenseInfo('00285889-n', 1), SenseInfo('15283097-n', 0), SenseInfo('13650447-n', 0) ],
"_mixture_n_of_rel" : [ SenseInfo('14586258-n', 11), SenseInfo('07882497-n', 3), SenseInfo('08398773-n', 2), SenseInfo('07374756-n', 1), SenseInfo('00380083-n', 0) ],
"_hey_a_1_rel" : [  ],
"_dote_v_on_rel" : [ SenseInfo('02697610-v', 0), SenseInfo('01777459-v', 0), SenseInfo('02697610-v', 0), SenseInfo('01777459-v', 0), SenseInfo('02697610-v', 0), SenseInfo('01777459-v', 0) ],
"_director_n_of_rel" : [ SenseInfo('10014939-n', 18), SenseInfo('10015485-n', 6), SenseInfo('10015215-n', 6), SenseInfo('10088200-n', 0), SenseInfo('09952539-n', 0), SenseInfo('10014939-n', 18), SenseInfo('10015485-n', 6), SenseInfo('10015215-n', 6), SenseInfo('10088200-n', 0), SenseInfo('09952539-n', 0) ],
"_road_n_1_rel" : [ SenseInfo('04096066-n', 94), SenseInfo('00174003-n', 2), SenseInfo('04096066-n', 94), SenseInfo('00174003-n', 2), SenseInfo('04096066-n', 94), SenseInfo('00174003-n', 2), SenseInfo('04096066-n', 94), SenseInfo('00174003-n', 2) ],
"_look_v_seem-to_rel" : [ SenseInfo('02130524-v', 274), SenseInfo('02133435-v', 126), SenseInfo('00033599-v', 25), SenseInfo('02153709-v', 8), SenseInfo('02693319-v', 1), SenseInfo('02549581-v', 1), SenseInfo('00929362-v', 1), SenseInfo('00720063-v', 1), SenseInfo('02658447-v', 0), SenseInfo('00712708-v', 0), SenseInfo('02130524-v', 274), SenseInfo('02133435-v', 126), SenseInfo('00033599-v', 25), SenseInfo('02153709-v', 8), SenseInfo('02693319-v', 1), SenseInfo('02549581-v', 1), SenseInfo('00929362-v', 1), SenseInfo('00720063-v', 1), SenseInfo('02658447-v', 0), SenseInfo('00712708-v', 0) ],
"_spin_v_around_rel" : [ SenseInfo('02046755-v', 11), SenseInfo('02068062-v', 5), SenseInfo('02048051-v', 0), SenseInfo('01639500-v', 0), SenseInfo('01639364-v', 0), SenseInfo('01518772-v', 0), SenseInfo('00953700-v', 0), SenseInfo('00318706-v', 0) ],
"_forthwith_a_1_rel" : [  ],
"_coffee_n_1_rel" : [ SenseInfo('07929519-n', 46), SenseInfo('12662772-n', 0), SenseInfo('07929351-n', 0), SenseInfo('04972451-n', 0) ],
"_lurch_n_1_rel" : [ SenseInfo('00289388-n', 1), SenseInfo('07476282-n', 0), SenseInfo('00337210-n', 0), SenseInfo('00290276-n', 0) ],
"_morpheme_n_1_rel" : [ SenseInfo('06306233-n', 0) ],
"_somatic_a_1_rel" : [ SenseInfo('01778935-a', 4) ],
"_half-hour_n_1_rel" : [ SenseInfo('15228162-n', 6), SenseInfo('15228162-n', 6) ],
"_mistake_n_1_rel" : [ SenseInfo('00070965-n', 13), SenseInfo('05895723-n', 6), SenseInfo('06769392-n', 2) ],
"_guess_v_at_rel" : [ SenseInfo('00631737-v', 42), SenseInfo('00916909-v', 10), SenseInfo('00672433-v', 6), SenseInfo('00636061-v', 6) ],
"_compress_v_1_rel" : [ SenseInfo('01389329-v', 6), SenseInfo('01387786-v', 2) ],
"_smugglers_a_1_rel" : [  ],
"_glycol_n_1_rel" : [ SenseInfo('14851850-n', 0), SenseInfo('14835980-n', 0), SenseInfo('14851850-n', 0), SenseInfo('14835980-n', 0), SenseInfo('14851850-n', 0), SenseInfo('14835980-n', 0) ],
"_rim_v_1_rel" : [ SenseInfo('02687596-v', 1), SenseInfo('02329999-v', 0), SenseInfo('01866497-v', 0) ],
"_anniversary_n_of_rel" : [ SenseInfo('15249799-n', 5) ],
"_squeak_v_1_rel" : [ SenseInfo('02171664-v', 3), SenseInfo('02171664-v', 3) ],
"_fury_n_1_rel" : [ SenseInfo('07516997-n', 4), SenseInfo('14391876-n', 3), SenseInfo('05037813-n', 3), SenseInfo('09506337-n', 0) ],
"_coastal_a_1_rel" : [ SenseInfo('02698782-a', 1), SenseInfo('00462909-a', 1) ],
"_instruct_v_on_rel" : [ SenseInfo('00829107-v', 9), SenseInfo('00749963-v', 9), SenseInfo('00831074-v', 0), SenseInfo('00829107-v', 9), SenseInfo('00749963-v', 9), SenseInfo('00831074-v', 0), SenseInfo('00829107-v', 9), SenseInfo('00749963-v', 9), SenseInfo('00831074-v', 0) ],
"_differing_a_1_rel" : [  ],
"_abaft_p_rel" : [ SenseInfo('00275409-r', 0), SenseInfo('00275409-r', 0) ],
"_dread_n_of_rel" : [ SenseInfo('07521674-n', 1), SenseInfo('07521674-n', 1) ],
"_sound_n_of_rel" : [ SenseInfo('04981139-n', 36), SenseInfo('05718254-n', 16), SenseInfo('11480930-n', 11), SenseInfo('07371293-n', 11), SenseInfo('06278136-n', 6), SenseInfo('07111047-n', 1), SenseInfo('09446115-n', 0), SenseInfo('09440186-n', 0) ],
"_at+worst_x_rel" : [ SenseInfo('00105908-r', 1) ],
"_inconvenient_a_1_rel" : [ SenseInfo('00605128-a', 1), SenseInfo('01662384-a', 0), SenseInfo('00605128-a', 1), SenseInfo('01662384-a', 0) ],
"_bioinformatics_n_1_rel" : [  ],
"_a+fig_a_1_rel" : [  ],
"_midge_n_1_rel" : [ SenseInfo('02203152-n', 0) ],
"_creativity_n_1_rel" : [ SenseInfo('05624700-n', 2) ],
"_sil+vous+plait_a_1_rel" : [  ],
"_inaccessible_a_1_rel" : [ SenseInfo('00019874-a', 0), SenseInfo('00186193-a', 0) ],
"_recitation_n_of_rel" : [ SenseInfo('07235218-n', 0), SenseInfo('07234881-n', 0), SenseInfo('01232246-n', 0), SenseInfo('00894552-n', 0) ],
"_clatter_v_1_rel" : [ SenseInfo('02172127-v', 6) ],
"_pit+bull_n_1_rel" : [  ],
"_ease_v_up_rel" : [ SenseInfo('01834213-v', 4), SenseInfo('00082308-v', 4), SenseInfo('00518395-v', 3), SenseInfo('01815185-v', 1) ],
"_conjure_v_1_rel" : [ SenseInfo('01629958-v', 0), SenseInfo('00759657-v', 0), SenseInfo('00706975-v', 0) ],
"_precinct_n_1_rel" : [ SenseInfo('08538426-n', 1) ],
"_crow_v_1_rel" : [ SenseInfo('00883635-v', 2), SenseInfo('00857517-v', 2), SenseInfo('00857653-v', 1), SenseInfo('00883635-v', 2), SenseInfo('00857517-v', 2), SenseInfo('00857653-v', 1) ],
"_wobbly_n_1_rel" : [ SenseInfo('10786892-n', 0) ],
"_propagate_v_1_rel" : [ SenseInfo('02230447-v', 0), SenseInfo('02085573-v', 0), SenseInfo('01436139-v', 0), SenseInfo('01380122-v', 0), SenseInfo('01379256-v', 0), SenseInfo('00968211-v', 0), SenseInfo('00055871-v', 0), SenseInfo('00055539-v', 0), SenseInfo('02230447-v', 0), SenseInfo('02085573-v', 0), SenseInfo('01436139-v', 0), SenseInfo('01380122-v', 0), SenseInfo('01379256-v', 0), SenseInfo('00968211-v', 0), SenseInfo('00055871-v', 0), SenseInfo('00055539-v', 0) ],
"_altogether_a_1_rel" : [ SenseInfo('14456586-n', 0) ],
"_inch_n_1_rel" : [ SenseInfo('13649791-n', 49), SenseInfo('13713300-n', 6) ],
"_back_v_1_rel" : [ SenseInfo('02453889-v', 7), SenseInfo('01997119-v', 6), SenseInfo('02556817-v', 4), SenseInfo('01997512-v', 4), SenseInfo('02217695-v', 2), SenseInfo('02693965-v', 0), SenseInfo('01139104-v', 0), SenseInfo('00560628-v', 0), SenseInfo('00223109-v', 0), SenseInfo('00185857-v', 0), SenseInfo('02453889-v', 7), SenseInfo('01997119-v', 6), SenseInfo('02556817-v', 4), SenseInfo('01997512-v', 4), SenseInfo('02217695-v', 2), SenseInfo('02693965-v', 0), SenseInfo('01139104-v', 0), SenseInfo('00560628-v', 0), SenseInfo('00223109-v', 0), SenseInfo('00185857-v', 0) ],
"_nestle_v_1_rel" : [ SenseInfo('01424948-v', 5), SenseInfo('02691354-v', 0), SenseInfo('01425348-v', 0), SenseInfo('01424948-v', 5), SenseInfo('02691354-v', 0), SenseInfo('01425348-v', 0) ],
"_elaborate_v_on_rel" : [ SenseInfo('00955601-v', 7), SenseInfo('01625343-v', 0), SenseInfo('00400883-v', 0), SenseInfo('00251463-v', 0) ],
"_decree_n_1_rel" : [ SenseInfo('06539770-n', 4), SenseInfo('06539770-n', 4) ],
"_flip_v_around_rel" : [ SenseInfo('01893079-v', 3), SenseInfo('01510173-v', 1), SenseInfo('02153023-v', 0), SenseInfo('01893601-v', 0), SenseInfo('01893465-v', 0), SenseInfo('01512625-v', 0), SenseInfo('01241614-v', 0), SenseInfo('01222958-v', 0), SenseInfo('00717921-v', 0), SenseInfo('00584810-v', 0), SenseInfo('00121678-v', 0) ],
"_lubricant_n_1_rel" : [ SenseInfo('14890659-n', 0), SenseInfo('14890659-n', 0), SenseInfo('14890659-n', 0) ],
"_gulp_v_1_rel" : [ SenseInfo('01202068-v', 5), SenseInfo('01067002-v', 1) ],
"_hammer_n_1_rel" : [ SenseInfo('03481824-n', 2), SenseInfo('03481172-n', 2), SenseInfo('05325943-n', 0), SenseInfo('03715669-n', 0), SenseInfo('03482001-n', 0), SenseInfo('03481674-n', 0), SenseInfo('03481521-n', 0), SenseInfo('01175316-n', 0) ],
"_schoolhouse_n_1_rel" : [ SenseInfo('04146050-n', 3) ],
"_handle_v_1_rel" : [ SenseInfo('02436349-v', 41), SenseInfo('02514187-v', 15), SenseInfo('01033527-v', 4), SenseInfo('01210737-v', 3), SenseInfo('01224415-v', 1), SenseInfo('01804414-v', 0) ],
"_rotator_n_1_rel" : [  ],
"_home-built_a_1_rel" : [  ],
"_humankind_n_1_rel" : [ SenseInfo('02472987-n', 0) ],
"_discount_v_as_rel" : [ SenseInfo('00800930-v', 3), SenseInfo('02319428-v', 0), SenseInfo('00800930-v', 3), SenseInfo('02319428-v', 0) ],
"_luxuriance_n_1_rel" : [ SenseInfo('05116243-n', 0) ],
"_potting+soil_n_1_rel" : [  ],
"_ramshackle_a_1_rel" : [ SenseInfo('00679717-a', 0) ],
"_mute_a_1_rel" : [ SenseInfo('00152285-a', 3), SenseInfo('00151855-a', 0) ],
"_censorship_n_of_rel" : [ SenseInfo('00821083-n', 1), SenseInfo('00397347-n', 0) ],
"_crowd_v_1_rel" : [ SenseInfo('02028722-v', 6), SenseInfo('02649305-v', 3), SenseInfo('02027612-v', 2), SenseInfo('02054864-v', 1), SenseInfo('02028722-v', 6), SenseInfo('02649305-v', 3), SenseInfo('02027612-v', 2), SenseInfo('02054864-v', 1) ],
"_farmers+market_n_1_rel" : [  ],
"_lath_n_1_rel" : [ SenseInfo('03646148-n', 0) ],
"_pact_n_1_rel" : [ SenseInfo('06773434-n', 1), SenseInfo('06773434-n', 1), SenseInfo('06773434-n', 1) ],
"_large_a_1_rel" : [ SenseInfo('01382086-a', 139), SenseInfo('02163307-a', 2), SenseInfo('02016881-a', 0), SenseInfo('01114658-a', 0), SenseInfo('00579622-a', 0), SenseInfo('00527870-a', 0), SenseInfo('00173391-a', 0), SenseInfo('01382086-a', 139), SenseInfo('02163307-a', 2), SenseInfo('02016881-a', 0), SenseInfo('01114658-a', 0), SenseInfo('00579622-a', 0), SenseInfo('00527870-a', 0), SenseInfo('00173391-a', 0), SenseInfo('01382086-a', 139), SenseInfo('02163307-a', 2), SenseInfo('02016881-a', 0), SenseInfo('01114658-a', 0), SenseInfo('00579622-a', 0), SenseInfo('00527870-a', 0), SenseInfo('00173391-a', 0) ],
"_disparage_v_1_rel" : [ SenseInfo('00845909-v', 0), SenseInfo('00845909-v', 0) ],
"_crumb_n_1_rel" : [ SenseInfo('13760980-n', 0), SenseInfo('10539715-n', 0), SenseInfo('07622261-n', 0) ],
"_form_n_of_rel" : [ SenseInfo('06290637-n', 96), SenseInfo('05839024-n', 62), SenseInfo('05930736-n', 40), SenseInfo('05064037-n', 23), SenseInfo('05217168-n', 19), SenseInfo('00027807-n', 8), SenseInfo('04677514-n', 3), SenseInfo('06473563-n', 2), SenseInfo('08111157-n', 1), SenseInfo('07092356-n', 1), SenseInfo('04930478-n', 1), SenseInfo('14480065-n', 0), SenseInfo('08238463-n', 0), SenseInfo('05200670-n', 0), SenseInfo('03717921-n', 0), SenseInfo('03384535-n', 0), SenseInfo('06290637-n', 96), SenseInfo('05839024-n', 62), SenseInfo('05930736-n', 40), SenseInfo('05064037-n', 23), SenseInfo('05217168-n', 19), SenseInfo('00027807-n', 8), SenseInfo('04677514-n', 3), SenseInfo('06473563-n', 2), SenseInfo('08111157-n', 1), SenseInfo('07092356-n', 1), SenseInfo('04930478-n', 1), SenseInfo('14480065-n', 0), SenseInfo('08238463-n', 0), SenseInfo('05200670-n', 0), SenseInfo('03717921-n', 0), SenseInfo('03384535-n', 0) ],
"_on-shore_a_1_rel" : [ SenseInfo('00464195-a', 1), SenseInfo('00125068-a', 0), SenseInfo('00464195-a', 1), SenseInfo('00125068-a', 0), SenseInfo('00464195-a', 1), SenseInfo('00125068-a', 0) ],
"_jockey_n_1_rel" : [ SenseInfo('10223177-n', 1), SenseInfo('10223294-n', 0) ],
"_give_v_1_rel" : [ SenseInfo('02316868-v', 179), SenseInfo('02339171-v', 160), SenseInfo('02199590-v', 96), SenseInfo('02235842-v', 78), SenseInfo('01060494-v', 32), SenseInfo('01733477-v', 29), SenseInfo('01060317-v', 24), SenseInfo('02200686-v', 20), SenseInfo('01629403-v', 18), SenseInfo('00732224-v', 18), SenseInfo('01629000-v', 16), SenseInfo('02296153-v', 14), SenseInfo('01647672-v', 14), SenseInfo('02200498-v', 12), SenseInfo('02562901-v', 10), SenseInfo('02343595-v', 10), SenseInfo('02230772-v', 10), SenseInfo('00887463-v', 8), SenseInfo('02309374-v', 5), SenseInfo('02309165-v', 5), SenseInfo('01060746-v', 5), SenseInfo('02317094-v', 4), SenseInfo('01848465-v', 4), SenseInfo('01178565-v', 4), SenseInfo('02308741-v', 3), SenseInfo('01989053-v', 1), SenseInfo('00673571-v', 1), SenseInfo('02564052-v', 0), SenseInfo('02359553-v', 0), SenseInfo('02358034-v', 0), SenseInfo('01716283-v', 0), SenseInfo('01716112-v', 0), SenseInfo('01449796-v', 0), SenseInfo('01175810-v', 0), SenseInfo('01069638-v', 0), SenseInfo('00944247-v', 0), SenseInfo('00888009-v', 0), SenseInfo('00878876-v', 0), SenseInfo('00771806-v', 0), SenseInfo('00748972-v', 0), SenseInfo('00748616-v', 0), SenseInfo('00341184-v', 0), SenseInfo('00108747-v', 0), SenseInfo('00108604-v', 0), SenseInfo('02316868-v', 179), SenseInfo('02339171-v', 160), SenseInfo('02199590-v', 96), SenseInfo('02235842-v', 78), SenseInfo('01060494-v', 32), SenseInfo('01733477-v', 29), SenseInfo('01060317-v', 24), SenseInfo('02200686-v', 20), SenseInfo('01629403-v', 18), SenseInfo('00732224-v', 18), SenseInfo('01629000-v', 16), SenseInfo('02296153-v', 14), SenseInfo('01647672-v', 14), SenseInfo('02200498-v', 12), SenseInfo('02562901-v', 10), SenseInfo('02343595-v', 10), SenseInfo('02230772-v', 10), SenseInfo('00887463-v', 8), SenseInfo('02309374-v', 5), SenseInfo('02309165-v', 5), SenseInfo('01060746-v', 5), SenseInfo('02317094-v', 4), SenseInfo('01848465-v', 4), SenseInfo('01178565-v', 4), SenseInfo('02308741-v', 3), SenseInfo('01989053-v', 1), SenseInfo('00673571-v', 1), SenseInfo('02564052-v', 0), SenseInfo('02359553-v', 0), SenseInfo('02358034-v', 0), SenseInfo('01716283-v', 0), SenseInfo('01716112-v', 0), SenseInfo('01449796-v', 0), SenseInfo('01175810-v', 0), SenseInfo('01069638-v', 0), SenseInfo('00944247-v', 0), SenseInfo('00888009-v', 0), SenseInfo('00878876-v', 0), SenseInfo('00771806-v', 0), SenseInfo('00748972-v', 0), SenseInfo('00748616-v', 0), SenseInfo('00341184-v', 0), SenseInfo('00108747-v', 0), SenseInfo('00108604-v', 0), SenseInfo('02316868-v', 179), SenseInfo('02339171-v', 160), SenseInfo('02199590-v', 96), SenseInfo('02235842-v', 78), SenseInfo('01060494-v', 32), SenseInfo('01733477-v', 29), SenseInfo('01060317-v', 24), SenseInfo('02200686-v', 20), SenseInfo('01629403-v', 18), SenseInfo('00732224-v', 18), SenseInfo('01629000-v', 16), SenseInfo('02296153-v', 14), SenseInfo('01647672-v', 14), SenseInfo('02200498-v', 12), SenseInfo('02562901-v', 10), SenseInfo('02343595-v', 10), SenseInfo('02230772-v', 10), SenseInfo('00887463-v', 8), SenseInfo('02309374-v', 5), SenseInfo('02309165-v', 5), SenseInfo('01060746-v', 5), SenseInfo('02317094-v', 4), SenseInfo('01848465-v', 4), SenseInfo('01178565-v', 4), SenseInfo('02308741-v', 3), SenseInfo('01989053-v', 1), SenseInfo('00673571-v', 1), SenseInfo('02564052-v', 0), SenseInfo('02359553-v', 0), SenseInfo('02358034-v', 0), SenseInfo('01716283-v', 0), SenseInfo('01716112-v', 0), SenseInfo('01449796-v', 0), SenseInfo('01175810-v', 0), SenseInfo('01069638-v', 0), SenseInfo('00944247-v', 0), SenseInfo('00888009-v', 0), SenseInfo('00878876-v', 0), SenseInfo('00771806-v', 0), SenseInfo('00748972-v', 0), SenseInfo('00748616-v', 0), SenseInfo('00341184-v', 0), SenseInfo('00108747-v', 0), SenseInfo('00108604-v', 0), SenseInfo('02316868-v', 179), SenseInfo('02339171-v', 160), SenseInfo('02199590-v', 96), SenseInfo('02235842-v', 78), SenseInfo('01060494-v', 32), SenseInfo('01733477-v', 29), SenseInfo('01060317-v', 24), SenseInfo('02200686-v', 20), SenseInfo('01629403-v', 18), SenseInfo('00732224-v', 18), SenseInfo('01629000-v', 16), SenseInfo('02296153-v', 14), SenseInfo('01647672-v', 14), SenseInfo('02200498-v', 12), SenseInfo('02562901-v', 10), SenseInfo('02343595-v', 10), SenseInfo('02230772-v', 10), SenseInfo('00887463-v', 8), SenseInfo('02309374-v', 5), SenseInfo('02309165-v', 5), SenseInfo('01060746-v', 5), SenseInfo('02317094-v', 4), SenseInfo('01848465-v', 4), SenseInfo('01178565-v', 4), SenseInfo('02308741-v', 3), SenseInfo('01989053-v', 1), SenseInfo('00673571-v', 1), SenseInfo('02564052-v', 0), SenseInfo('02359553-v', 0), SenseInfo('02358034-v', 0), SenseInfo('01716283-v', 0), SenseInfo('01716112-v', 0), SenseInfo('01449796-v', 0), SenseInfo('01175810-v', 0), SenseInfo('01069638-v', 0), SenseInfo('00944247-v', 0), SenseInfo('00888009-v', 0), SenseInfo('00878876-v', 0), SenseInfo('00771806-v', 0), SenseInfo('00748972-v', 0), SenseInfo('00748616-v', 0), SenseInfo('00341184-v', 0), SenseInfo('00108747-v', 0), SenseInfo('00108604-v', 0) ],
"_suspend_v_1_rel" : [ SenseInfo('01481154-v', 8), SenseInfo('00148763-v', 4), SenseInfo('02502037-v', 2), SenseInfo('00363493-v', 2), SenseInfo('00542668-v', 1), SenseInfo('02643740-v', 0) ],
"_penalty_n_for_rel" : [ SenseInfo('01160342-n', 6), SenseInfo('13300555-n', 1), SenseInfo('05164845-n', 1), SenseInfo('05163189-n', 0) ],
"_deliberate_v_1_rel" : [ SenseInfo('00813044-v', 0), SenseInfo('00812580-v', 0), SenseInfo('00813044-v', 0), SenseInfo('00812580-v', 0) ],
"_usual_a_for_rel" : [ SenseInfo('00489108-a', 29), SenseInfo('00970610-a', 2), SenseInfo('00489108-a', 29), SenseInfo('00970610-a', 2), SenseInfo('00489108-a', 29), SenseInfo('00970610-a', 2), SenseInfo('00489108-a', 29), SenseInfo('00970610-a', 2), SenseInfo('00489108-a', 29), SenseInfo('00970610-a', 2), SenseInfo('00489108-a', 29), SenseInfo('00970610-a', 2) ],
"_diagram_v_1_rel" : [ SenseInfo('01693453-v', 1) ],
"_lake_n_1_rel" : [ SenseInfo('09328904-n', 3), SenseInfo('14991106-n', 0), SenseInfo('14991004-n', 0), SenseInfo('09328904-n', 3), SenseInfo('14991106-n', 0), SenseInfo('14991004-n', 0) ],
"_chasseur_n_1_rel" : [  ],
"_blanket_v_1_rel" : [ SenseInfo('01359007-v', 1), SenseInfo('02749405-v', 0) ],
"_giggle_v_at_rel" : [ SenseInfo('00030142-v', 4) ],
"_merchandise_n_1_rel" : [ SenseInfo('03748886-n', 4) ],
"_good_n_1_rel" : [ SenseInfo('05159725-n', 11), SenseInfo('04849241-n', 9), SenseInfo('05142180-n', 6), SenseInfo('03076708-n', 0) ],
"_implacable_a_1_rel" : [ SenseInfo('01785180-a', 2) ],
"_too+bad_a_1_rel" : [ SenseInfo('01052038-a', 5) ],
"_airport_n_1_rel" : [ SenseInfo('02692232-n', 4), SenseInfo('02692232-n', 4) ],
"_entourage_n_1_rel" : [ SenseInfo('08429167-n', 0) ],
"_unite_v_cause_rel" : [ SenseInfo('02469835-v', 7), SenseInfo('00367685-v', 7), SenseInfo('02631163-v', 0), SenseInfo('02622234-v', 0), SenseInfo('02603056-v', 0), SenseInfo('00243124-v', 0) ],
"_coop_n_1_rel" : [ SenseInfo('03016389-n', 2), SenseInfo('02936714-n', 0) ],
"_suffix_n_1_rel" : [ SenseInfo('06308987-n', 2) ],
"_purpose_n_1_rel" : [ SenseInfo('05982152-n', 75), SenseInfo('05149325-n', 26), SenseInfo('04864200-n', 5), SenseInfo('05982152-n', 75), SenseInfo('05149325-n', 26), SenseInfo('04864200-n', 5) ],
"_lamb_v_1_rel" : [ SenseInfo('00058265-v', 0) ],
"_splint_n_1_rel" : [ SenseInfo('09442723-n', 0), SenseInfo('04282494-n', 0) ],
"_infancy_n_1_rel" : [ SenseInfo('15145586-n', 3), SenseInfo('14427239-n', 0) ],
"_up+to+date_a_1_rel" : [ SenseInfo('00668208-a', 3), SenseInfo('00972642-a', 0), SenseInfo('00668208-a', 3), SenseInfo('00972642-a', 0), SenseInfo('00668208-a', 3), SenseInfo('00972642-a', 0), SenseInfo('00668208-a', 3), SenseInfo('00972642-a', 0), SenseInfo('00668208-a', 3), SenseInfo('00972642-a', 0), SenseInfo('00668208-a', 3), SenseInfo('00972642-a', 0), SenseInfo('00668208-a', 3), SenseInfo('00972642-a', 0), SenseInfo('00668208-a', 3), SenseInfo('00972642-a', 0) ],
"_shave_n_1_rel" : [ SenseInfo('00254769-n', 0) ],
"_irksome_a_1_rel" : [ SenseInfo('01345307-a', 1) ],
"_roster_n_of_rel" : [ SenseInfo('06495000-n', 2) ],
"_cheesy_a_1_rel" : [ SenseInfo('02346013-a', 0) ],
"_less+than_p_rel" : [  ],
"_skin_n_1_rel" : [ SenseInfo('05238282-n', 11), SenseInfo('04230093-n', 3), SenseInfo('01895735-n', 3), SenseInfo('13962048-n', 2), SenseInfo('07738353-n', 0), SenseInfo('04230221-n', 0) ],
"_saddle_v_up_rel" : [ SenseInfo('01492422-v', 1), SenseInfo('01490814-v', 1), SenseInfo('00750532-v', 1), SenseInfo('01492422-v', 1), SenseInfo('01490814-v', 1), SenseInfo('00750532-v', 1) ],
"_relief_n_1_rel" : [ SenseInfo('07493280-n', 12), SenseInfo('14445749-n', 8), SenseInfo('13290991-n', 5), SenseInfo('10648237-n', 3), SenseInfo('01209220-n', 3), SenseInfo('15274074-n', 1), SenseInfo('07357101-n', 1), SenseInfo('01088168-n', 1), SenseInfo('00354884-n', 1), SenseInfo('04073669-n', 0), SenseInfo('01075567-n', 0), SenseInfo('07493280-n', 12), SenseInfo('14445749-n', 8), SenseInfo('13290991-n', 5), SenseInfo('10648237-n', 3), SenseInfo('01209220-n', 3), SenseInfo('15274074-n', 1), SenseInfo('07357101-n', 1), SenseInfo('01088168-n', 1), SenseInfo('00354884-n', 1), SenseInfo('04073669-n', 0), SenseInfo('01075567-n', 0), SenseInfo('07493280-n', 12), SenseInfo('14445749-n', 8), SenseInfo('13290991-n', 5), SenseInfo('10648237-n', 3), SenseInfo('01209220-n', 3), SenseInfo('15274074-n', 1), SenseInfo('07357101-n', 1), SenseInfo('01088168-n', 1), SenseInfo('00354884-n', 1), SenseInfo('04073669-n', 0), SenseInfo('01075567-n', 0), SenseInfo('07493280-n', 12), SenseInfo('14445749-n', 8), SenseInfo('13290991-n', 5), SenseInfo('10648237-n', 3), SenseInfo('01209220-n', 3), SenseInfo('15274074-n', 1), SenseInfo('07357101-n', 1), SenseInfo('01088168-n', 1), SenseInfo('00354884-n', 1), SenseInfo('04073669-n', 0), SenseInfo('01075567-n', 0) ],
"_avoid_v_1_rel" : [ SenseInfo('00811375-v', 24), SenseInfo('02453321-v', 22), SenseInfo('02463510-v', 18), SenseInfo('01189823-v', 1), SenseInfo('02478059-v', 0), SenseInfo('00811375-v', 24), SenseInfo('02453321-v', 22), SenseInfo('02463510-v', 18), SenseInfo('01189823-v', 1), SenseInfo('02478059-v', 0) ],
"_try_v_for_rel" : [ SenseInfo('02530167-v', 342), SenseInfo('02531625-v', 16), SenseInfo('02501278-v', 4), SenseInfo('01195299-v', 2), SenseInfo('02500902-v', 0), SenseInfo('01798782-v', 0), SenseInfo('01798452-v', 0), SenseInfo('00444975-v', 0), SenseInfo('00047317-v', 0) ],
"_muscular_a_1_rel" : [ SenseInfo('02882570-a', 6), SenseInfo('00828336-a', 3), SenseInfo('01826828-a', 1), SenseInfo('02321809-a', 0) ],
"_gaze_v_on_rel" : [ SenseInfo('02132745-v', 25) ],
"_gum_v_up_rel" : [ SenseInfo('01364019-v', 0), SenseInfo('01175224-v', 0), SenseInfo('00586387-v', 0), SenseInfo('00069166-v', 0) ],
"_jumper_n_1_rel" : [ SenseInfo('10226993-n', 0), SenseInfo('10226803-n', 0), SenseInfo('04370048-n', 0), SenseInfo('03604763-n', 0), SenseInfo('03604629-n', 0), SenseInfo('03604536-n', 0), SenseInfo('03604400-n', 0), SenseInfo('00111503-n', 0) ],
"_scream_v_at_rel" : [ SenseInfo('00913065-v', 25), SenseInfo('00912833-v', 2), SenseInfo('02173336-v', 1) ],
"_scapular_a_1_rel" : [ SenseInfo('02792550-a', 0) ],
"_inactivation_n_1_rel" : [ SenseInfo('13496771-n', 0), SenseInfo('00233795-n', 0) ],
"_cockroach_n_1_rel" : [ SenseInfo('02233338-n', 1) ],
"_punctilio_n_1_rel" : [ SenseInfo('06666729-n', 0), SenseInfo('01204623-n', 0) ],
"_extra_x_rel" : [ SenseInfo('01581305-a', 4), SenseInfo('10676569-n', 0), SenseInfo('06597349-n', 0), SenseInfo('03307981-n', 0), SenseInfo('00084759-r', 0), SenseInfo('02367319-a', 0), SenseInfo('00048858-a', 0) ],
"_buck_v_up_rel" : [ SenseInfo('02531500-v', 2), SenseInfo('02378851-v', 1), SenseInfo('02055267-v', 0), SenseInfo('01884383-v', 0) ],
"_period_a_1_rel" : [ SenseInfo('15113229-n', 94), SenseInfo('15289779-n', 2), SenseInfo('15258281-n', 0), SenseInfo('15247518-n', 0), SenseInfo('15144178-n', 0), SenseInfo('13513747-n', 0), SenseInfo('06843520-n', 0) ],
"_oxacid_n_1_rel" : [  ],
"_cub_n_1_rel" : [ SenseInfo('09981834-n', 0), SenseInfo('09871229-n', 0), SenseInfo('01322685-n', 0) ],
"_oar_n_1_rel" : [ SenseInfo('03837422-n', 0) ],
"_dollar-for-dollar_a_1_rel" : [  ],
"_regroup_v_1_rel" : [ SenseInfo('02433381-v', 1), SenseInfo('00656825-v', 0) ],
"_dislike_v_1_rel" : [ SenseInfo('01776727-v', 13), SenseInfo('01776727-v', 13), SenseInfo('01776727-v', 13), SenseInfo('01776727-v', 13) ],
"_skinny_a_1_rel" : [ SenseInfo('00990192-a', 2), SenseInfo('02935913-a', 0), SenseInfo('01448178-a', 0), SenseInfo('01113225-a', 0), SenseInfo('00990192-a', 2), SenseInfo('02935913-a', 0), SenseInfo('01448178-a', 0), SenseInfo('01113225-a', 0), SenseInfo('00990192-a', 2), SenseInfo('02935913-a', 0), SenseInfo('01448178-a', 0), SenseInfo('01113225-a', 0) ],
"_catch_v_1_rel" : [ SenseInfo('00725748-v', 19), SenseInfo('02117955-v', 14), SenseInfo('01401115-v', 10), SenseInfo('01439190-v', 8), SenseInfo('01215421-v', 8), SenseInfo('01327816-v', 7), SenseInfo('01505958-v', 6), SenseInfo('01480149-v', 4), SenseInfo('02018372-v', 3), SenseInfo('02248299-v', 2), SenseInfo('01155090-v', 2), SenseInfo('00543016-v', 2), SenseInfo('02510905-v', 1), SenseInfo('02189168-v', 1), SenseInfo('02150948-v', 1), SenseInfo('01328012-v', 1), SenseInfo('00599835-v', 1), SenseInfo('00589904-v', 1), SenseInfo('00087988-v', 1), SenseInfo('02761134-v', 0), SenseInfo('02189398-v', 0), SenseInfo('02109645-v', 0), SenseInfo('01806505-v', 0), SenseInfo('01738107-v', 0), SenseInfo('01480469-v', 0), SenseInfo('01380366-v', 0), SenseInfo('01082454-v', 0), SenseInfo('00726009-v', 0), SenseInfo('00460357-v', 0), SenseInfo('00725748-v', 19), SenseInfo('02117955-v', 14), SenseInfo('01401115-v', 10), SenseInfo('01439190-v', 8), SenseInfo('01215421-v', 8), SenseInfo('01327816-v', 7), SenseInfo('01505958-v', 6), SenseInfo('01480149-v', 4), SenseInfo('02018372-v', 3), SenseInfo('02248299-v', 2), SenseInfo('01155090-v', 2), SenseInfo('00543016-v', 2), SenseInfo('02510905-v', 1), SenseInfo('02189168-v', 1), SenseInfo('02150948-v', 1), SenseInfo('01328012-v', 1), SenseInfo('00599835-v', 1), SenseInfo('00589904-v', 1), SenseInfo('00087988-v', 1), SenseInfo('02761134-v', 0), SenseInfo('02189398-v', 0), SenseInfo('02109645-v', 0), SenseInfo('01806505-v', 0), SenseInfo('01738107-v', 0), SenseInfo('01480469-v', 0), SenseInfo('01380366-v', 0), SenseInfo('01082454-v', 0), SenseInfo('00726009-v', 0), SenseInfo('00460357-v', 0) ],
"_bi-text_n_1_rel" : [  ],
"_turn_v_into_rel" : [ SenseInfo('01907258-v', 187), SenseInfo('00146138-v', 21), SenseInfo('02626604-v', 12), SenseInfo('02089984-v', 8), SenseInfo('00138508-v', 7), SenseInfo('01909812-v', 5), SenseInfo('00125841-v', 5), SenseInfo('01436518-v', 2), SenseInfo('02096167-v', 1), SenseInfo('02089420-v', 1), SenseInfo('01952208-v', 1), SenseInfo('01741864-v', 1), SenseInfo('01584450-v', 1), SenseInfo('00282523-v', 1), SenseInfo('00091124-v', 1), SenseInfo('02626934-v', 0), SenseInfo('02562425-v', 0), SenseInfo('02211948-v', 0), SenseInfo('02090435-v', 0), SenseInfo('01951937-v', 0), SenseInfo('01280014-v', 0), SenseInfo('01225215-v', 0), SenseInfo('01151889-v', 0), SenseInfo('00794640-v', 0), SenseInfo('00458471-v', 0), SenseInfo('00248387-v', 0), SenseInfo('01907258-v', 187), SenseInfo('00146138-v', 21), SenseInfo('02626604-v', 12), SenseInfo('02089984-v', 8), SenseInfo('00138508-v', 7), SenseInfo('01909812-v', 5), SenseInfo('00125841-v', 5), SenseInfo('01436518-v', 2), SenseInfo('02096167-v', 1), SenseInfo('02089420-v', 1), SenseInfo('01952208-v', 1), SenseInfo('01741864-v', 1), SenseInfo('01584450-v', 1), SenseInfo('00282523-v', 1), SenseInfo('00091124-v', 1), SenseInfo('02626934-v', 0), SenseInfo('02562425-v', 0), SenseInfo('02211948-v', 0), SenseInfo('02090435-v', 0), SenseInfo('01951937-v', 0), SenseInfo('01280014-v', 0), SenseInfo('01225215-v', 0), SenseInfo('01151889-v', 0), SenseInfo('00794640-v', 0), SenseInfo('00458471-v', 0), SenseInfo('00248387-v', 0) ],
"_centrifugal_a_1_rel" : [ SenseInfo('00332375-a', 0), SenseInfo('00335225-a', 0), SenseInfo('00334245-a', 0) ],
"_main_n_1_rel" : [ SenseInfo('09345932-n', 0), SenseInfo('03711145-n', 0) ],
"_clothe_v_in_rel" : [ SenseInfo('00047945-v', 4), SenseInfo('02386675-v', 2), SenseInfo('01617034-v', 0), SenseInfo('00047945-v', 4), SenseInfo('02386675-v', 2), SenseInfo('01617034-v', 0) ],
"_popularism_n_1_rel" : [ SenseInfo('07025302-n', 1) ],
"_air_n_1_rel" : [ SenseInfo('14841267-n', 42), SenseInfo('08653314-n', 29), SenseInfo('04727214-n', 9), SenseInfo('11431754-n', 3), SenseInfo('08499057-n', 1), SenseInfo('14842703-n', 0), SenseInfo('07028373-n', 0), SenseInfo('06255354-n', 0), SenseInfo('00300441-n', 0) ],
"_spherical_a_1_rel" : [ SenseInfo('02800689-a', 5), SenseInfo('02041229-a', 1) ],
"_stash_v_1_rel" : [ SenseInfo('02305856-v', 0), SenseInfo('02305856-v', 0) ],
"_nurse_n_1_rel" : [ SenseInfo('10366966-n', 2), SenseInfo('10345100-n', 1) ],
"_saint+bernard_n_1_rel" : [ SenseInfo('02109525-n', 0) ],
"_maltese_a_1_rel" : [ SenseInfo('03083842-a', 0) ],
"_clerical_a_1_rel" : [ SenseInfo('02698031-a', 3), SenseInfo('02697911-a', 1), SenseInfo('02556229-a', 0) ],
"_as+is_p_rel" : [  ],
"_creeper_n_1_rel" : [ SenseInfo('13102648-n', 1), SenseInfo('09976119-n', 0), SenseInfo('01589286-n', 0) ],
"_legislature_n_1_rel" : [ SenseInfo('08163273-n', 5) ],
"_all+the+while_x_rel" : [  ],
"_rig_v_up_rel" : [ SenseInfo('02573127-v', 1), SenseInfo('02351239-v', 1), SenseInfo('01286151-v', 1), SenseInfo('00408085-v', 0) ],
"_bivouac_n_1_rel" : [ SenseInfo('02944826-n', 1), SenseInfo('08518171-n', 0) ],
"_transform_v_into_rel" : [ SenseInfo('00544011-v', 14), SenseInfo('00382635-v', 10), SenseInfo('00381601-v', 3), SenseInfo('00383542-v', 0), SenseInfo('00382256-v', 0), SenseInfo('00382010-v', 0), SenseInfo('00381850-v', 0), SenseInfo('00544011-v', 14), SenseInfo('00382635-v', 10), SenseInfo('00381601-v', 3), SenseInfo('00383542-v', 0), SenseInfo('00382256-v', 0), SenseInfo('00382010-v', 0), SenseInfo('00381850-v', 0) ],
"_assure_v_of_rel" : [ SenseInfo('00890590-v', 20), SenseInfo('01019643-v', 9), SenseInfo('00776268-v', 9), SenseInfo('00662589-v', 6), SenseInfo('01766407-v', 2), SenseInfo('00884011-v', 1), SenseInfo('00890590-v', 20), SenseInfo('01019643-v', 9), SenseInfo('00776268-v', 9), SenseInfo('00662589-v', 6), SenseInfo('01766407-v', 2), SenseInfo('00884011-v', 1), SenseInfo('00890590-v', 20), SenseInfo('01019643-v', 9), SenseInfo('00776268-v', 9), SenseInfo('00662589-v', 6), SenseInfo('01766407-v', 2), SenseInfo('00884011-v', 1), SenseInfo('00890590-v', 20), SenseInfo('01019643-v', 9), SenseInfo('00776268-v', 9), SenseInfo('00662589-v', 6), SenseInfo('01766407-v', 2), SenseInfo('00884011-v', 1) ],
"_newsletter_n_of_rel" : [ SenseInfo('06681976-n', 2) ],
"_listing_n_of_rel" : [ SenseInfo('06481320-n', 0), SenseInfo('01011166-n', 0) ],
"_hound_v_1_rel" : [ SenseInfo('02003601-v', 0) ],
"_peaky_a_1_rel" : [ SenseInfo('01214255-a', 1), SenseInfo('01214255-a', 1), SenseInfo('01214255-a', 1) ],
"_buffet_v_1_rel" : [ SenseInfo('01417705-v', 3), SenseInfo('01417578-v', 0) ],
"_interpret_v_1_rel" : [ SenseInfo('00623151-v', 17), SenseInfo('00938247-v', 10), SenseInfo('01732172-v', 2), SenseInfo('01686132-v', 2), SenseInfo('00959827-v', 1), SenseInfo('00593852-v', 1) ],
"_blank_v_on_rel" : [ SenseInfo('02451261-v', 0) ],
"_front_v_1_rel" : [ SenseInfo('02693319-v', 2), SenseInfo('01079172-v', 2) ],
"_amorphous_a_1_rel" : [ SenseInfo('02151837-a', 4), SenseInfo('01680283-a', 0), SenseInfo('00269580-a', 0) ],
"_brandy_n_1_rel" : [ SenseInfo('07903208-n', 3) ],
"_consolidate_v_1_rel" : [ SenseInfo('00242580-v', 3), SenseInfo('00165450-v', 1), SenseInfo('00242747-v', 0), SenseInfo('00165789-v', 0), SenseInfo('00165618-v', 0) ],
"_arrest_v_prd_rel" : [ SenseInfo('01215137-v', 20), SenseInfo('01131473-v', 2), SenseInfo('01505958-v', 1), SenseInfo('01859586-v', 0) ],
"_prepared_a_1_rel" : [ SenseInfo('01843380-a', 14), SenseInfo('02565425-a', 1), SenseInfo('01095085-a', 0), SenseInfo('01843380-a', 14), SenseInfo('02565425-a', 1), SenseInfo('01095085-a', 0) ],
"_owing+to_p_rel" : [  ],
"_serve_n_1_rel" : [ SenseInfo('00568430-n', 0) ],
"_Gaussian_n_1_rel" : [  ],
"_whew_a_1_rel" : [  ],
"_shapeliness_n_1_rel" : [ SenseInfo('04686748-n', 0) ],
"_rehash_v_1_rel" : [ SenseInfo('01162629-v', 1), SenseInfo('01009097-v', 0) ],
"_blush_n_1_rel" : [ SenseInfo('14050871-n', 0), SenseInfo('00118268-n', 0) ],
"_onboard_a_1_rel" : [  ],
"_attest_v_to_rel" : [ SenseInfo('00820976-v', 2), SenseInfo('00820352-v', 1), SenseInfo('01014821-v', 0), SenseInfo('00820611-v', 0) ],
"_underlie_v_1_rel" : [ SenseInfo('02664575-v', 8), SenseInfo('02693088-v', 0), SenseInfo('02664575-v', 8), SenseInfo('02693088-v', 0), SenseInfo('02664575-v', 8), SenseInfo('02693088-v', 0) ],
"_blindness_n_1_rel" : [ SenseInfo('14126660-n', 7) ],
"_protestant_a_1_rel" : [ SenseInfo('02952622-a', 27), SenseInfo('00514175-a', 0) ],
"_shorts_n_1_rel" : [ SenseInfo('04205318-n', 0), SenseInfo('03234164-n', 0), SenseInfo('04205318-n', 0), SenseInfo('03234164-n', 0) ],
"_solitaire_n_1_rel" : [ SenseInfo('04259364-n', 0), SenseInfo('01811542-n', 0), SenseInfo('01561181-n', 0), SenseInfo('00495524-n', 0) ],
"_woodcutting_n_1_rel" : [  ],
"_motorcycle_n_1_rel" : [ SenseInfo('03790512-n', 0) ],
"_mindset_n_1_rel" : [ SenseInfo('06195839-n', 0) ],
"_erase_v_1_rel" : [ SenseInfo('00479391-v', 5), SenseInfo('01548718-v', 0), SenseInfo('00999815-v', 0) ],
"_elongate_v_1_rel" : [ SenseInfo('00318816-v', 1) ],
"_omission_n_of_rel" : [ SenseInfo('00074624-n', 2), SenseInfo('14423614-n', 1), SenseInfo('13524399-n', 1), SenseInfo('05706954-n', 0) ],
"_chaotic_a_1_rel" : [ SenseInfo('01669507-a', 2), SenseInfo('02390569-a', 1), SenseInfo('02691237-a', 0) ],
"_commune_n_1_rel" : [ SenseInfo('08541609-n', 5), SenseInfo('08375369-n', 1) ],
"_quack_n_1_rel" : [ SenseInfo('10497202-n', 14), SenseInfo('07390762-n', 0) ],
"_archbishop_n_1_rel" : [ SenseInfo('09805151-n', 5) ],
"_mayor_n_of_rel" : [ SenseInfo('10303814-n', 9), SenseInfo('10303814-n', 9) ],
"_refinance_v_1_rel" : [ SenseInfo('02218546-v', 1) ],
"_domination_n_of_rel" : [ SenseInfo('01128390-n', 6), SenseInfo('14442530-n', 1) ],
"_scribble_n_1_rel" : [ SenseInfo('06404147-n', 0), SenseInfo('04155310-n', 0) ],
"_kneel_v_1_rel" : [ SenseInfo('01545649-v', 9) ],
"_conflicted_a_1_rel" : [  ],
"_percipient_n_1_rel" : [ SenseInfo('09626589-n', 0) ],
"_upheaval_n_1_rel" : [ SenseInfo('13979173-n', 2), SenseInfo('13977732-n', 0), SenseInfo('07375781-n', 0), SenseInfo('00554300-n', 0) ],
"_daughter_n_1_rel" : [ SenseInfo('09992837-n', 23) ],
"_rage_v_1_rel" : [ SenseInfo('02723016-v', 4), SenseInfo('02722902-v', 4), SenseInfo('01796033-v', 1), SenseInfo('02723016-v', 4), SenseInfo('02722902-v', 4), SenseInfo('01796033-v', 1) ],
"_repellent_a_1_rel" : [ SenseInfo('01804422-a', 0), SenseInfo('01625893-a', 0), SenseInfo('00007990-a', 0) ],
"_bulldog_n_1_rel" : [ SenseInfo('02108672-n', 0) ],
"_brochure_n_of_rel" : [ SenseInfo('06413889-n', 0) ],
"_aspiring_a_1_rel" : [ SenseInfo('00104533-a', 0) ],
"_punch_v_1_rel" : [ SenseInfo('01415285-v', 3), SenseInfo('01575536-v', 1), SenseInfo('01442779-v', 0) ],
"_intensify_v_1_rel" : [ SenseInfo('00290302-v', 3), SenseInfo('00227165-v', 2), SenseInfo('00226566-v', 2), SenseInfo('00574735-v', 0) ],
"_make_v_up_rel" : [ SenseInfo('02560585-v', 508), SenseInfo('00120316-v', 459), SenseInfo('01617192-v', 243), SenseInfo('00770437-v', 85), SenseInfo('01645601-v', 78), SenseInfo('01621555-v', 52), SenseInfo('00730758-v', 33), SenseInfo('01646075-v', 17), SenseInfo('01640207-v', 16), SenseInfo('02289295-v', 14), SenseInfo('01619014-v', 14), SenseInfo('02621395-v', 12), SenseInfo('02022162-v', 12), SenseInfo('02674708-v', 10), SenseInfo('01653873-v', 9), SenseInfo('01755816-v', 8), SenseInfo('01654628-v', 5), SenseInfo('00556855-v', 5), SenseInfo('00012267-v', 5), SenseInfo('02396716-v', 4), SenseInfo('02355596-v', 4), SenseInfo('02020590-v', 4), SenseInfo('00665476-v', 4), SenseInfo('02582921-v', 3), SenseInfo('02598483-v', 2), SenseInfo('01733477-v', 2), SenseInfo('00276068-v', 2), SenseInfo('02075857-v', 1), SenseInfo('00074038-v', 1), SenseInfo('02748759-v', 0), SenseInfo('02748627-v', 0), SenseInfo('02745332-v', 0), SenseInfo('02665124-v', 0), SenseInfo('02621133-v', 0), SenseInfo('02134050-v', 0), SenseInfo('02051031-v', 0), SenseInfo('02021532-v', 0), SenseInfo('01755504-v', 0), SenseInfo('01664172-v', 0), SenseInfo('01428578-v', 0), SenseInfo('00891038-v', 0), SenseInfo('00838524-v', 0), SenseInfo('00698256-v', 0), SenseInfo('00698104-v', 0), SenseInfo('00562182-v', 0), SenseInfo('00562067-v', 0), SenseInfo('00545953-v', 0), SenseInfo('00107369-v', 0), SenseInfo('00072012-v', 0), SenseInfo('02560585-v', 508), SenseInfo('00120316-v', 459), SenseInfo('01617192-v', 243), SenseInfo('00770437-v', 85), SenseInfo('01645601-v', 78), SenseInfo('01621555-v', 52), SenseInfo('00730758-v', 33), SenseInfo('01646075-v', 17), SenseInfo('01640207-v', 16), SenseInfo('02289295-v', 14), SenseInfo('01619014-v', 14), SenseInfo('02621395-v', 12), SenseInfo('02022162-v', 12), SenseInfo('02674708-v', 10), SenseInfo('01653873-v', 9), SenseInfo('01755816-v', 8), SenseInfo('01654628-v', 5), SenseInfo('00556855-v', 5), SenseInfo('00012267-v', 5), SenseInfo('02396716-v', 4), SenseInfo('02355596-v', 4), SenseInfo('02020590-v', 4), SenseInfo('00665476-v', 4), SenseInfo('02582921-v', 3), SenseInfo('02598483-v', 2), SenseInfo('01733477-v', 2), SenseInfo('00276068-v', 2), SenseInfo('02075857-v', 1), SenseInfo('00074038-v', 1), SenseInfo('02748759-v', 0), SenseInfo('02748627-v', 0), SenseInfo('02745332-v', 0), SenseInfo('02665124-v', 0), SenseInfo('02621133-v', 0), SenseInfo('02134050-v', 0), SenseInfo('02051031-v', 0), SenseInfo('02021532-v', 0), SenseInfo('01755504-v', 0), SenseInfo('01664172-v', 0), SenseInfo('01428578-v', 0), SenseInfo('00891038-v', 0), SenseInfo('00838524-v', 0), SenseInfo('00698256-v', 0), SenseInfo('00698104-v', 0), SenseInfo('00562182-v', 0), SenseInfo('00562067-v', 0), SenseInfo('00545953-v', 0), SenseInfo('00107369-v', 0), SenseInfo('00072012-v', 0) ],
"_dean_n_1_rel" : [ SenseInfo('09996784-n', 1), SenseInfo('10926066-n', 0), SenseInfo('09997068-n', 0), SenseInfo('09996920-n', 0) ],
"_gatekeeper_n_1_rel" : [ SenseInfo('10122128-n', 0), SenseInfo('10026553-n', 0) ],
"_shipping+out_n_of_rel" : [  ],
"_consonant_n_1_rel" : [ SenseInfo('07115021-n', 4), SenseInfo('07115381-n', 2) ],
"_resurrect_v_1_rel" : [ SenseInfo('00098517-v', 1), SenseInfo('00168910-v', 0), SenseInfo('00098770-v', 0) ],
"_noticeable_a_1_rel" : [ SenseInfo('01286799-a', 2), SenseInfo('01746995-a', 1), SenseInfo('01614778-a', 0), SenseInfo('02323204-a', 0), SenseInfo('01286799-a', 2), SenseInfo('01746995-a', 1), SenseInfo('01614778-a', 0), SenseInfo('02323204-a', 0), SenseInfo('01286799-a', 2), SenseInfo('01746995-a', 1), SenseInfo('01614778-a', 0), SenseInfo('02323204-a', 0) ],
"_procrastinator_n_1_rel" : [ SenseInfo('10478626-n', 0) ],
"_anti+cancer_a_1_rel" : [ SenseInfo('02629410-a', 0) ],
"_glaze_v_1_rel" : [ SenseInfo('01269521-v', 6), SenseInfo('00125447-v', 1), SenseInfo('02335363-v', 0), SenseInfo('02196378-v', 0) ],
"_list_n_of_rel" : [ SenseInfo('06481320-n', 64), SenseInfo('05068080-n', 1), SenseInfo('06481320-n', 64), SenseInfo('05068080-n', 1) ],
"_wilderness_n_1_rel" : [ SenseInfo('14413831-n', 0), SenseInfo('09479424-n', 0), SenseInfo('08683548-n', 0), SenseInfo('05116730-n', 0) ],
"_gun_v_for_rel" : [ SenseInfo('01136614-v', 0) ],
"_franciscan_a_1_rel" : [ SenseInfo('03066658-a', 0) ],
"_deprotection_n_1_rel" : [  ],
"_long-hand_n_1_rel" : [ SenseInfo('06350274-n', 1), SenseInfo('06350274-n', 1), SenseInfo('06350274-n', 1) ],
"_farmland_n_1_rel" : [ SenseInfo('08569482-n', 1), SenseInfo('09260907-n', 0) ],
"_sort_n_of_rel" : [ SenseInfo('05839024-n', 65), SenseInfo('04746262-n', 2), SenseInfo('10626722-n', 1), SenseInfo('13558696-n', 0), SenseInfo('05839024-n', 65), SenseInfo('04746262-n', 2), SenseInfo('10626722-n', 1), SenseInfo('13558696-n', 0) ],
"_nervousness_n_1_rel" : [ SenseInfo('07525760-n', 1), SenseInfo('14375576-n', 0), SenseInfo('04624959-n', 0), SenseInfo('07525760-n', 1), SenseInfo('14375576-n', 0), SenseInfo('04624959-n', 0) ],
"_assemble_v_1_rel" : [ SenseInfo('01656788-v', 15), SenseInfo('02428924-v', 13), SenseInfo('02598143-v', 1) ],
"_kaleidoscope_n_1_rel" : [ SenseInfo('05931827-n', 0), SenseInfo('03607756-n', 0) ],
"_humility_n_1_rel" : [ SenseInfo('04889527-n', 2), SenseInfo('07509131-n', 1) ],
"_ornery_a_1_rel" : [ SenseInfo('01135673-a', 4), SenseInfo('01135673-a', 4), SenseInfo('01135673-a', 4) ],
"_nominal_a_1_rel" : [ SenseInfo('02769128-a', 1), SenseInfo('01496592-a', 1), SenseInfo('02768958-a', 0), SenseInfo('01939784-a', 0), SenseInfo('01099810-a', 0), SenseInfo('01043374-a', 0), SenseInfo('02769128-a', 1), SenseInfo('01496592-a', 1), SenseInfo('02768958-a', 0), SenseInfo('01939784-a', 0), SenseInfo('01099810-a', 0), SenseInfo('01043374-a', 0) ],
"_typo_n_1_rel" : [ SenseInfo('06769670-n', 0) ],
"_least+square_n_1_rel" : [  ],
"_marshall_n_1_rel" : [ SenseInfo('11159214-n', 0), SenseInfo('11158982-n', 0), SenseInfo('11158754-n', 0), SenseInfo('10296176-n', 0), SenseInfo('10295951-n', 0) ],
"_finish_v_off_rel" : [ SenseInfo('00484166-v', 44), SenseInfo('00352558-v', 12), SenseInfo('02609764-v', 8), SenseInfo('01265989-v', 3), SenseInfo('01196802-v', 2), SenseInfo('00351963-v', 0), SenseInfo('00484166-v', 44), SenseInfo('00352558-v', 12), SenseInfo('02609764-v', 8), SenseInfo('01265989-v', 3), SenseInfo('01196802-v', 2), SenseInfo('00351963-v', 0) ],
"_alehouse_n_1_rel" : [ SenseInfo('02696165-n', 0) ],
"_consult_v_1_rel" : [ SenseInfo('00877559-v', 15), SenseInfo('00877083-v', 4), SenseInfo('00876665-v', 2), SenseInfo('00876442-v', 0) ],
"_consequence_n_of_rel" : [ SenseInfo('11410625-n', 18), SenseInfo('07294019-n', 4), SenseInfo('05170574-n', 3), SenseInfo('11410625-n', 18), SenseInfo('07294019-n', 4), SenseInfo('05170574-n', 3) ],
"_alert_a_1_rel" : [ SenseInfo('00091311-a', 7), SenseInfo('00874226-a', 0), SenseInfo('00190653-a', 0) ],
"_very+much_a_1_rel" : [  ],
"_nursery_n_1_rel" : [ SenseInfo('03836062-n', 2), SenseInfo('03457902-n', 0) ],
"_loose_a_with_rel" : [ SenseInfo('00503321-a', 2), SenseInfo('00600725-a', 2), SenseInfo('01446749-a', 1), SenseInfo('01634027-a', 1), SenseInfo('00916199-a', 1), SenseInfo('00638841-a', 1), SenseInfo('00159381-a', 0), SenseInfo('02404421-a', 0), SenseInfo('02232112-a', 0), SenseInfo('01998835-a', 0), SenseInfo('01739582-a', 0), SenseInfo('01062114-a', 0), SenseInfo('00361837-a', 0) ],
"_ecclesiastical_a_1_rel" : [ SenseInfo('02899486-a', 3) ],
"_nondelivery_n_of_rel" : [  ],
"_metric_n_1_rel" : [ SenseInfo('13784906-n', 0), SenseInfo('13604275-n', 0), SenseInfo('13577171-n', 0) ],
"_gauloise_n_1_rel" : [  ],
"_market_n_1_rel" : [ SenseInfo('01097292-n', 12), SenseInfo('08424951-n', 9), SenseInfo('03461385-n', 4), SenseInfo('08072837-n', 2), SenseInfo('03722288-n', 0), SenseInfo('01097292-n', 12), SenseInfo('08424951-n', 9), SenseInfo('03461385-n', 4), SenseInfo('08072837-n', 2), SenseInfo('03722288-n', 0), SenseInfo('01097292-n', 12), SenseInfo('08424951-n', 9), SenseInfo('03461385-n', 4), SenseInfo('08072837-n', 2), SenseInfo('03722288-n', 0), SenseInfo('01097292-n', 12), SenseInfo('08424951-n', 9), SenseInfo('03461385-n', 4), SenseInfo('08072837-n', 2), SenseInfo('03722288-n', 0) ],
"_workshop_n_1_rel" : [ SenseInfo('04603081-n', 6), SenseInfo('00892413-n', 2) ],
"_institutionalize_v_1_rel" : [ SenseInfo('02348568-v', 1) ],
"_bump_n_1_rel" : [ SenseInfo('14289504-n', 0), SenseInfo('13894434-n', 0), SenseInfo('07338681-n', 0) ],
"_remedy_v_1_rel" : [ SenseInfo('00199912-v', 3), SenseInfo('00082563-v', 0) ],
"_substitute_v_for_rel" : [ SenseInfo('02257767-v', 13), SenseInfo('02258617-v', 5), SenseInfo('02394662-v', 0), SenseInfo('02257767-v', 13), SenseInfo('02258617-v', 5), SenseInfo('02394662-v', 0) ],
"_abetment_n_1_rel" : [ SenseInfo('07251619-n', 0) ],
"_wonder_v_about_rel" : [ SenseInfo('00729378-v', 58), SenseInfo('00925110-v', 41), SenseInfo('00925490-v', 2) ],
"_riffle_v_1_rel" : [ SenseInfo('01591357-v', 1), SenseInfo('02153023-v', 0), SenseInfo('02040054-v', 0), SenseInfo('01419160-v', 0) ],
"_street_n_1_rel" : [ SenseInfo('04334599-n', 86), SenseInfo('04335209-n', 3), SenseInfo('14516256-n', 2), SenseInfo('14485811-n', 0), SenseInfo('08225426-n', 0), SenseInfo('04334599-n', 86), SenseInfo('04335209-n', 3), SenseInfo('14516256-n', 2), SenseInfo('14485811-n', 0), SenseInfo('08225426-n', 0) ],
"_stir_n_1_rel" : [ SenseInfo('13978166-n', 0), SenseInfo('07514345-n', 0), SenseInfo('00555138-n', 0) ],
"_very+much_x_deg_rel" : [ SenseInfo('00059171-r', 14) ],
"_shower_v_with_rel" : [ SenseInfo('02264601-v', 2), SenseInfo('01372994-v', 2), SenseInfo('00035259-v', 2), SenseInfo('02757651-v', 0), SenseInfo('01184333-v', 0) ],
"_sloganeering_n_1_rel" : [ SenseInfo('07246469-n', 1) ],
"_turn+around_n_1_rel" : [ SenseInfo('15137295-n', 0), SenseInfo('05789808-n', 0), SenseInfo('04499660-n', 0), SenseInfo('01144555-n', 0), SenseInfo('00346693-n', 0) ],
"_unrelated_a_to_rel" : [ SenseInfo('01974740-a', 2), SenseInfo('01972596-a', 0), SenseInfo('01974740-a', 2), SenseInfo('01972596-a', 0), SenseInfo('01974740-a', 2), SenseInfo('01972596-a', 0) ],
"_superintendent_n_1_rel" : [ SenseInfo('10388732-n', 4), SenseInfo('10675721-n', 0) ],
"_strip_v_off_rel" : [ SenseInfo('02314275-v', 7), SenseInfo('00049900-v', 2), SenseInfo('01263479-v', 1), SenseInfo('00488617-v', 1), SenseInfo('00194912-v', 1), SenseInfo('02344568-v', 0), SenseInfo('01608706-v', 0), SenseInfo('01263659-v', 0), SenseInfo('00194812-v', 0), SenseInfo('00194696-v', 0), SenseInfo('00194534-v', 0), SenseInfo('00194079-v', 0), SenseInfo('00177243-v', 0) ],
"_channelize_v_1_rel" : [ SenseInfo('01931768-v', 0), SenseInfo('01757021-v', 0), SenseInfo('01435380-v', 0), SenseInfo('01369059-v', 0) ],
"_upstart_n_1_rel" : [ SenseInfo('10741152-n', 0), SenseInfo('10740868-n', 0), SenseInfo('00438338-n', 0) ],
"_land_v_cause_rel" : [ SenseInfo('01979901-v', 16), SenseInfo('01981036-v', 4), SenseInfo('00135857-v', 3), SenseInfo('02087156-v', 2), SenseInfo('02358527-v', 1), SenseInfo('01981436-v', 0), SenseInfo('01981279-v', 0) ],
"_taxi_v_1_rel" : [ SenseInfo('01948872-v', 2), SenseInfo('01949007-v', 0) ],
"_fish_v_for_rel" : [ SenseInfo('01319346-v', 2), SenseInfo('01140794-v', 1) ],
"_lazy_a_1_rel" : [ SenseInfo('00981304-a', 4), SenseInfo('00294579-a', 2), SenseInfo('00981304-a', 4), SenseInfo('00294579-a', 2), SenseInfo('00981304-a', 4), SenseInfo('00294579-a', 2), SenseInfo('00981304-a', 4), SenseInfo('00294579-a', 2) ],
"_opportunity_n_1_rel" : [ SenseInfo('14483917-n', 67), SenseInfo('14483917-n', 67), SenseInfo('14483917-n', 67) ],
"_aggression_n_1_rel" : [ SenseInfo('04658268-n', 2), SenseInfo('07548567-n', 1), SenseInfo('00964569-n', 1), SenseInfo('01237167-n', 0), SenseInfo('01221611-n', 0) ],
"_undersecretary_n_1_rel" : [ SenseInfo('10736788-n', 1) ],
"_formerly_x_deg_rel" : [ SenseInfo('00118965-r', 7) ],
"_atomic_a_1_rel" : [ SenseInfo('02884619-a', 4), SenseInfo('00610532-a', 1), SenseInfo('01392071-a', 0) ],
"_gown_n_1_rel" : [ SenseInfo('03450230-n', 5), SenseInfo('08286342-n', 0), SenseInfo('03824381-n', 0), SenseInfo('03450734-n', 0), SenseInfo('03450516-n', 0) ],
"_initiate_v_into_rel" : [ SenseInfo('01628449-v', 9), SenseInfo('01641914-v', 3), SenseInfo('02390470-v', 2), SenseInfo('00964911-v', 0), SenseInfo('00539546-v', 0), SenseInfo('01628449-v', 9), SenseInfo('01641914-v', 3), SenseInfo('02390470-v', 2), SenseInfo('00964911-v', 0), SenseInfo('00539546-v', 0) ],
"_external_a_1_rel" : [ SenseInfo('00948103-a', 9), SenseInfo('01350225-a', 2), SenseInfo('01037885-a', 2), SenseInfo('00951003-a', 0), SenseInfo('00948103-a', 9), SenseInfo('01350225-a', 2), SenseInfo('01037885-a', 2), SenseInfo('00951003-a', 0) ],
"_bend_v_over_rel" : [ SenseInfo('02035919-v', 23), SenseInfo('02033137-v', 11), SenseInfo('01280014-v', 5), SenseInfo('02062632-v', 3), SenseInfo('02034300-v', 1), SenseInfo('01280488-v', 0) ],
"_saturation_n_of_rel" : [ SenseInfo('13496517-n', 2), SenseInfo('00402671-n', 1), SenseInfo('13925188-n', 0), SenseInfo('04975340-n', 0) ],
"_ulcerative_a_1_rel" : [ SenseInfo('03142636-a', 0) ],
"_confront_v_1_rel" : [ SenseInfo('01078783-v', 24), SenseInfo('00812298-v', 11), SenseInfo('01066433-v', 7), SenseInfo('02742638-v', 4) ],
"_wax_n_1_rel" : [ SenseInfo('15094294-n', 7) ],
"_sow_v_1_rel" : [ SenseInfo('01500873-v', 5), SenseInfo('00969370-v', 1), SenseInfo('01501347-v', 0) ],
"_conducive_a_to_rel" : [ SenseInfo('00323426-a', 0) ],
"_puff_v_out_rel" : [ SenseInfo('01198616-v', 2), SenseInfo('01199009-v', 1), SenseInfo('00005526-v', 1), SenseInfo('01812197-v', 0), SenseInfo('01065272-v', 0), SenseInfo('00797303-v', 0), SenseInfo('00263682-v', 0), SenseInfo('00006802-v', 0) ],
"_case_n_of_rel" : [ SenseInfo('07308889-n', 72), SenseInfo('13943400-n', 39), SenseInfo('01182654-n', 19), SenseInfo('05817743-n', 11), SenseInfo('02974697-n', 7), SenseInfo('09898892-n', 5), SenseInfo('10668666-n', 3), SenseInfo('06784966-n', 3), SenseInfo('06649426-n', 3), SenseInfo('13766436-n', 2), SenseInfo('06310945-n', 1), SenseInfo('14015996-n', 0), SenseInfo('09909060-n', 0), SenseInfo('06825399-n', 0), SenseInfo('05238036-n', 0), SenseInfo('04190747-n', 0), SenseInfo('02977619-n', 0), SenseInfo('02975589-n', 0), SenseInfo('02975412-n', 0), SenseInfo('02975212-n', 0), SenseInfo('07308889-n', 72), SenseInfo('13943400-n', 39), SenseInfo('01182654-n', 19), SenseInfo('05817743-n', 11), SenseInfo('02974697-n', 7), SenseInfo('09898892-n', 5), SenseInfo('10668666-n', 3), SenseInfo('06784966-n', 3), SenseInfo('06649426-n', 3), SenseInfo('13766436-n', 2), SenseInfo('06310945-n', 1), SenseInfo('14015996-n', 0), SenseInfo('09909060-n', 0), SenseInfo('06825399-n', 0), SenseInfo('05238036-n', 0), SenseInfo('04190747-n', 0), SenseInfo('02977619-n', 0), SenseInfo('02975589-n', 0), SenseInfo('02975412-n', 0), SenseInfo('02975212-n', 0) ],
"_collective_a_1_rel" : [ SenseInfo('02112701-a', 7), SenseInfo('00466808-a', 0), SenseInfo('00298293-a', 0), SenseInfo('02112701-a', 7), SenseInfo('00466808-a', 0), SenseInfo('00298293-a', 0) ],
"_answering_a_1_rel" : [ SenseInfo('01999608-a', 1) ],
"_itchy_a_1_rel" : [ SenseInfo('02406166-a', 0), SenseInfo('01712327-a', 0) ],
"_dangerous_a_for_rel" : [ SenseInfo('02058794-a', 22), SenseInfo('00651039-a', 1), SenseInfo('02058794-a', 22), SenseInfo('00651039-a', 1), SenseInfo('02058794-a', 22), SenseInfo('00651039-a', 1) ],
"_stickpin_n_1_rel" : [ SenseInfo('04318690-n', 1) ],
"_outside_p_rel" : [ SenseInfo('00110659-r', 15), SenseInfo('08613593-n', 7), SenseInfo('00110919-r', 6), SenseInfo('01692969-a', 5), SenseInfo('01350225-a', 5), SenseInfo('00948514-a', 4), SenseInfo('01692222-a', 3), SenseInfo('01347749-a', 3), SenseInfo('00952761-a', 3), SenseInfo('01037885-a', 2), SenseInfo('08613472-n', 1), SenseInfo('01413084-a', 0), SenseInfo('00950002-a', 0), SenseInfo('00023655-a', 0) ],
"_spawn_n_1_rel" : [ SenseInfo('01461315-n', 0) ],
"_nonstop_a_1_rel" : [ SenseInfo('00761449-a', 0), SenseInfo('00595147-a', 0), SenseInfo('00761449-a', 0), SenseInfo('00595147-a', 0) ],
"_arithmetic_a_1_rel" : [ SenseInfo('03044869-a', 0) ],
"_wash_v_away_rel" : [ SenseInfo('01270199-v', 13), SenseInfo('00036362-v', 9), SenseInfo('01535246-v', 7), SenseInfo('02098179-v', 2), SenseInfo('02742842-v', 0), SenseInfo('02703153-v', 0), SenseInfo('01536344-v', 0), SenseInfo('01269844-v', 0), SenseInfo('00557686-v', 0), SenseInfo('00274942-v', 0), SenseInfo('00217956-v', 0), SenseInfo('00217576-v', 0), SenseInfo('00036178-v', 0), SenseInfo('01270199-v', 13), SenseInfo('00036362-v', 9), SenseInfo('01535246-v', 7), SenseInfo('02098179-v', 2), SenseInfo('02742842-v', 0), SenseInfo('02703153-v', 0), SenseInfo('01536344-v', 0), SenseInfo('01269844-v', 0), SenseInfo('00557686-v', 0), SenseInfo('00274942-v', 0), SenseInfo('00217956-v', 0), SenseInfo('00217576-v', 0), SenseInfo('00036178-v', 0) ],
"_amythest_n_1_rel" : [  ],
"_debit_v_1_rel" : [ SenseInfo('02265560-v', 0) ],
"_spectator_n_1_rel" : [ SenseInfo('10633450-n', 12), SenseInfo('04272389-n', 1) ],
"_claim_v_1_rel" : [ SenseInfo('00756338-v', 34), SenseInfo('02275365-v', 14), SenseInfo('01018352-v', 9), SenseInfo('00758333-v', 4), SenseInfo('00756076-v', 1), SenseInfo('00756338-v', 34), SenseInfo('02275365-v', 14), SenseInfo('01018352-v', 9), SenseInfo('00758333-v', 4), SenseInfo('00756076-v', 1), SenseInfo('00756338-v', 34), SenseInfo('02275365-v', 14), SenseInfo('01018352-v', 9), SenseInfo('00758333-v', 4), SenseInfo('00756076-v', 1), SenseInfo('00756338-v', 34), SenseInfo('02275365-v', 14), SenseInfo('01018352-v', 9), SenseInfo('00758333-v', 4), SenseInfo('00756076-v', 1) ],
"_make_v_1_rel" : [ SenseInfo('02560585-v', 508), SenseInfo('00120316-v', 459), SenseInfo('01617192-v', 243), SenseInfo('00770437-v', 85), SenseInfo('01645601-v', 78), SenseInfo('01621555-v', 52), SenseInfo('00730758-v', 33), SenseInfo('01646075-v', 17), SenseInfo('01640207-v', 16), SenseInfo('02289295-v', 14), SenseInfo('01619014-v', 14), SenseInfo('02621395-v', 12), SenseInfo('02022162-v', 12), SenseInfo('02674708-v', 10), SenseInfo('01653873-v', 9), SenseInfo('01755816-v', 8), SenseInfo('01654628-v', 5), SenseInfo('00556855-v', 5), SenseInfo('00012267-v', 5), SenseInfo('02396716-v', 4), SenseInfo('02355596-v', 4), SenseInfo('02020590-v', 4), SenseInfo('00665476-v', 4), SenseInfo('02582921-v', 3), SenseInfo('02598483-v', 2), SenseInfo('01733477-v', 2), SenseInfo('00276068-v', 2), SenseInfo('02075857-v', 1), SenseInfo('00074038-v', 1), SenseInfo('02748759-v', 0), SenseInfo('02748627-v', 0), SenseInfo('02745332-v', 0), SenseInfo('02665124-v', 0), SenseInfo('02621133-v', 0), SenseInfo('02134050-v', 0), SenseInfo('02051031-v', 0), SenseInfo('02021532-v', 0), SenseInfo('01755504-v', 0), SenseInfo('01664172-v', 0), SenseInfo('01428578-v', 0), SenseInfo('00891038-v', 0), SenseInfo('00838524-v', 0), SenseInfo('00698256-v', 0), SenseInfo('00698104-v', 0), SenseInfo('00562182-v', 0), SenseInfo('00562067-v', 0), SenseInfo('00545953-v', 0), SenseInfo('00107369-v', 0), SenseInfo('00072012-v', 0), SenseInfo('02560585-v', 508), SenseInfo('00120316-v', 459), SenseInfo('01617192-v', 243), SenseInfo('00770437-v', 85), SenseInfo('01645601-v', 78), SenseInfo('01621555-v', 52), SenseInfo('00730758-v', 33), SenseInfo('01646075-v', 17), SenseInfo('01640207-v', 16), SenseInfo('02289295-v', 14), SenseInfo('01619014-v', 14), SenseInfo('02621395-v', 12), SenseInfo('02022162-v', 12), SenseInfo('02674708-v', 10), SenseInfo('01653873-v', 9), SenseInfo('01755816-v', 8), SenseInfo('01654628-v', 5), SenseInfo('00556855-v', 5), SenseInfo('00012267-v', 5), SenseInfo('02396716-v', 4), SenseInfo('02355596-v', 4), SenseInfo('02020590-v', 4), SenseInfo('00665476-v', 4), SenseInfo('02582921-v', 3), SenseInfo('02598483-v', 2), SenseInfo('01733477-v', 2), SenseInfo('00276068-v', 2), SenseInfo('02075857-v', 1), SenseInfo('00074038-v', 1), SenseInfo('02748759-v', 0), SenseInfo('02748627-v', 0), SenseInfo('02745332-v', 0), SenseInfo('02665124-v', 0), SenseInfo('02621133-v', 0), SenseInfo('02134050-v', 0), SenseInfo('02051031-v', 0), SenseInfo('02021532-v', 0), SenseInfo('01755504-v', 0), SenseInfo('01664172-v', 0), SenseInfo('01428578-v', 0), SenseInfo('00891038-v', 0), SenseInfo('00838524-v', 0), SenseInfo('00698256-v', 0), SenseInfo('00698104-v', 0), SenseInfo('00562182-v', 0), SenseInfo('00562067-v', 0), SenseInfo('00545953-v', 0), SenseInfo('00107369-v', 0), SenseInfo('00072012-v', 0), SenseInfo('02560585-v', 508), SenseInfo('00120316-v', 459), SenseInfo('01617192-v', 243), SenseInfo('00770437-v', 85), SenseInfo('01645601-v', 78), SenseInfo('01621555-v', 52), SenseInfo('00730758-v', 33), SenseInfo('01646075-v', 17), SenseInfo('01640207-v', 16), SenseInfo('02289295-v', 14), SenseInfo('01619014-v', 14), SenseInfo('02621395-v', 12), SenseInfo('02022162-v', 12), SenseInfo('02674708-v', 10), SenseInfo('01653873-v', 9), SenseInfo('01755816-v', 8), SenseInfo('01654628-v', 5), SenseInfo('00556855-v', 5), SenseInfo('00012267-v', 5), SenseInfo('02396716-v', 4), SenseInfo('02355596-v', 4), SenseInfo('02020590-v', 4), SenseInfo('00665476-v', 4), SenseInfo('02582921-v', 3), SenseInfo('02598483-v', 2), SenseInfo('01733477-v', 2), SenseInfo('00276068-v', 2), SenseInfo('02075857-v', 1), SenseInfo('00074038-v', 1), SenseInfo('02748759-v', 0), SenseInfo('02748627-v', 0), SenseInfo('02745332-v', 0), SenseInfo('02665124-v', 0), SenseInfo('02621133-v', 0), SenseInfo('02134050-v', 0), SenseInfo('02051031-v', 0), SenseInfo('02021532-v', 0), SenseInfo('01755504-v', 0), SenseInfo('01664172-v', 0), SenseInfo('01428578-v', 0), SenseInfo('00891038-v', 0), SenseInfo('00838524-v', 0), SenseInfo('00698256-v', 0), SenseInfo('00698104-v', 0), SenseInfo('00562182-v', 0), SenseInfo('00562067-v', 0), SenseInfo('00545953-v', 0), SenseInfo('00107369-v', 0), SenseInfo('00072012-v', 0), SenseInfo('02560585-v', 508), SenseInfo('00120316-v', 459), SenseInfo('01617192-v', 243), SenseInfo('00770437-v', 85), SenseInfo('01645601-v', 78), SenseInfo('01621555-v', 52), SenseInfo('00730758-v', 33), SenseInfo('01646075-v', 17), SenseInfo('01640207-v', 16), SenseInfo('02289295-v', 14), SenseInfo('01619014-v', 14), SenseInfo('02621395-v', 12), SenseInfo('02022162-v', 12), SenseInfo('02674708-v', 10), SenseInfo('01653873-v', 9), SenseInfo('01755816-v', 8), SenseInfo('01654628-v', 5), SenseInfo('00556855-v', 5), SenseInfo('00012267-v', 5), SenseInfo('02396716-v', 4), SenseInfo('02355596-v', 4), SenseInfo('02020590-v', 4), SenseInfo('00665476-v', 4), SenseInfo('02582921-v', 3), SenseInfo('02598483-v', 2), SenseInfo('01733477-v', 2), SenseInfo('00276068-v', 2), SenseInfo('02075857-v', 1), SenseInfo('00074038-v', 1), SenseInfo('02748759-v', 0), SenseInfo('02748627-v', 0), SenseInfo('02745332-v', 0), SenseInfo('02665124-v', 0), SenseInfo('02621133-v', 0), SenseInfo('02134050-v', 0), SenseInfo('02051031-v', 0), SenseInfo('02021532-v', 0), SenseInfo('01755504-v', 0), SenseInfo('01664172-v', 0), SenseInfo('01428578-v', 0), SenseInfo('00891038-v', 0), SenseInfo('00838524-v', 0), SenseInfo('00698256-v', 0), SenseInfo('00698104-v', 0), SenseInfo('00562182-v', 0), SenseInfo('00562067-v', 0), SenseInfo('00545953-v', 0), SenseInfo('00107369-v', 0), SenseInfo('00072012-v', 0), SenseInfo('02560585-v', 508), SenseInfo('00120316-v', 459), SenseInfo('01617192-v', 243), SenseInfo('00770437-v', 85), SenseInfo('01645601-v', 78), SenseInfo('01621555-v', 52), SenseInfo('00730758-v', 33), SenseInfo('01646075-v', 17), SenseInfo('01640207-v', 16), SenseInfo('02289295-v', 14), SenseInfo('01619014-v', 14), SenseInfo('02621395-v', 12), SenseInfo('02022162-v', 12), SenseInfo('02674708-v', 10), SenseInfo('01653873-v', 9), SenseInfo('01755816-v', 8), SenseInfo('01654628-v', 5), SenseInfo('00556855-v', 5), SenseInfo('00012267-v', 5), SenseInfo('02396716-v', 4), SenseInfo('02355596-v', 4), SenseInfo('02020590-v', 4), SenseInfo('00665476-v', 4), SenseInfo('02582921-v', 3), SenseInfo('02598483-v', 2), SenseInfo('01733477-v', 2), SenseInfo('00276068-v', 2), SenseInfo('02075857-v', 1), SenseInfo('00074038-v', 1), SenseInfo('02748759-v', 0), SenseInfo('02748627-v', 0), SenseInfo('02745332-v', 0), SenseInfo('02665124-v', 0), SenseInfo('02621133-v', 0), SenseInfo('02134050-v', 0), SenseInfo('02051031-v', 0), SenseInfo('02021532-v', 0), SenseInfo('01755504-v', 0), SenseInfo('01664172-v', 0), SenseInfo('01428578-v', 0), SenseInfo('00891038-v', 0), SenseInfo('00838524-v', 0), SenseInfo('00698256-v', 0), SenseInfo('00698104-v', 0), SenseInfo('00562182-v', 0), SenseInfo('00562067-v', 0), SenseInfo('00545953-v', 0), SenseInfo('00107369-v', 0), SenseInfo('00072012-v', 0), SenseInfo('02560585-v', 508), SenseInfo('00120316-v', 459), SenseInfo('01617192-v', 243), SenseInfo('00770437-v', 85), SenseInfo('01645601-v', 78), SenseInfo('01621555-v', 52), SenseInfo('00730758-v', 33), SenseInfo('01646075-v', 17), SenseInfo('01640207-v', 16), SenseInfo('02289295-v', 14), SenseInfo('01619014-v', 14), SenseInfo('02621395-v', 12), SenseInfo('02022162-v', 12), SenseInfo('02674708-v', 10), SenseInfo('01653873-v', 9), SenseInfo('01755816-v', 8), SenseInfo('01654628-v', 5), SenseInfo('00556855-v', 5), SenseInfo('00012267-v', 5), SenseInfo('02396716-v', 4), SenseInfo('02355596-v', 4), SenseInfo('02020590-v', 4), SenseInfo('00665476-v', 4), SenseInfo('02582921-v', 3), SenseInfo('02598483-v', 2), SenseInfo('01733477-v', 2), SenseInfo('00276068-v', 2), SenseInfo('02075857-v', 1), SenseInfo('00074038-v', 1), SenseInfo('02748759-v', 0), SenseInfo('02748627-v', 0), SenseInfo('02745332-v', 0), SenseInfo('02665124-v', 0), SenseInfo('02621133-v', 0), SenseInfo('02134050-v', 0), SenseInfo('02051031-v', 0), SenseInfo('02021532-v', 0), SenseInfo('01755504-v', 0), SenseInfo('01664172-v', 0), SenseInfo('01428578-v', 0), SenseInfo('00891038-v', 0), SenseInfo('00838524-v', 0), SenseInfo('00698256-v', 0), SenseInfo('00698104-v', 0), SenseInfo('00562182-v', 0), SenseInfo('00562067-v', 0), SenseInfo('00545953-v', 0), SenseInfo('00107369-v', 0), SenseInfo('00072012-v', 0), SenseInfo('02560585-v', 508), SenseInfo('00120316-v', 459), SenseInfo('01617192-v', 243), SenseInfo('00770437-v', 85), SenseInfo('01645601-v', 78), SenseInfo('01621555-v', 52), SenseInfo('00730758-v', 33), SenseInfo('01646075-v', 17), SenseInfo('01640207-v', 16), SenseInfo('02289295-v', 14), SenseInfo('01619014-v', 14), SenseInfo('02621395-v', 12), SenseInfo('02022162-v', 12), SenseInfo('02674708-v', 10), SenseInfo('01653873-v', 9), SenseInfo('01755816-v', 8), SenseInfo('01654628-v', 5), SenseInfo('00556855-v', 5), SenseInfo('00012267-v', 5), SenseInfo('02396716-v', 4), SenseInfo('02355596-v', 4), SenseInfo('02020590-v', 4), SenseInfo('00665476-v', 4), SenseInfo('02582921-v', 3), SenseInfo('02598483-v', 2), SenseInfo('01733477-v', 2), SenseInfo('00276068-v', 2), SenseInfo('02075857-v', 1), SenseInfo('00074038-v', 1), SenseInfo('02748759-v', 0), SenseInfo('02748627-v', 0), SenseInfo('02745332-v', 0), SenseInfo('02665124-v', 0), SenseInfo('02621133-v', 0), SenseInfo('02134050-v', 0), SenseInfo('02051031-v', 0), SenseInfo('02021532-v', 0), SenseInfo('01755504-v', 0), SenseInfo('01664172-v', 0), SenseInfo('01428578-v', 0), SenseInfo('00891038-v', 0), SenseInfo('00838524-v', 0), SenseInfo('00698256-v', 0), SenseInfo('00698104-v', 0), SenseInfo('00562182-v', 0), SenseInfo('00562067-v', 0), SenseInfo('00545953-v', 0), SenseInfo('00107369-v', 0), SenseInfo('00072012-v', 0), SenseInfo('02560585-v', 508), SenseInfo('00120316-v', 459), SenseInfo('01617192-v', 243), SenseInfo('00770437-v', 85), SenseInfo('01645601-v', 78), SenseInfo('01621555-v', 52), SenseInfo('00730758-v', 33), SenseInfo('01646075-v', 17), SenseInfo('01640207-v', 16), SenseInfo('02289295-v', 14), SenseInfo('01619014-v', 14), SenseInfo('02621395-v', 12), SenseInfo('02022162-v', 12), SenseInfo('02674708-v', 10), SenseInfo('01653873-v', 9), SenseInfo('01755816-v', 8), SenseInfo('01654628-v', 5), SenseInfo('00556855-v', 5), SenseInfo('00012267-v', 5), SenseInfo('02396716-v', 4), SenseInfo('02355596-v', 4), SenseInfo('02020590-v', 4), SenseInfo('00665476-v', 4), SenseInfo('02582921-v', 3), SenseInfo('02598483-v', 2), SenseInfo('01733477-v', 2), SenseInfo('00276068-v', 2), SenseInfo('02075857-v', 1), SenseInfo('00074038-v', 1), SenseInfo('02748759-v', 0), SenseInfo('02748627-v', 0), SenseInfo('02745332-v', 0), SenseInfo('02665124-v', 0), SenseInfo('02621133-v', 0), SenseInfo('02134050-v', 0), SenseInfo('02051031-v', 0), SenseInfo('02021532-v', 0), SenseInfo('01755504-v', 0), SenseInfo('01664172-v', 0), SenseInfo('01428578-v', 0), SenseInfo('00891038-v', 0), SenseInfo('00838524-v', 0), SenseInfo('00698256-v', 0), SenseInfo('00698104-v', 0), SenseInfo('00562182-v', 0), SenseInfo('00562067-v', 0), SenseInfo('00545953-v', 0), SenseInfo('00107369-v', 0), SenseInfo('00072012-v', 0) ],
"_level_v_cause_rel" : [ SenseInfo('01152896-v', 4), SenseInfo('01661804-v', 1), SenseInfo('01307142-v', 1), SenseInfo('01152214-v', 0), SenseInfo('00964237-v', 0), SenseInfo('00356649-v', 0) ],
"_bugle_n_1_rel" : [ SenseInfo('02912894-n', 3), SenseInfo('12840749-n', 0), SenseInfo('02913035-n', 0) ],
"_thorax_n_1_rel" : [ SenseInfo('05553618-n', 0), SenseInfo('05552607-n', 0), SenseInfo('02665543-n', 0) ],
"_rains_n_1_rel" : [ SenseInfo('11501381-n', 25), SenseInfo('15008607-n', 5), SenseInfo('05045208-n', 0), SenseInfo('11501381-n', 25), SenseInfo('15008607-n', 5), SenseInfo('05045208-n', 0) ],
"_get_v_state_rel" : [ SenseInfo('02210855-v', 235), SenseInfo('00149583-v', 157), SenseInfo('00120796-v', 82), SenseInfo('00522751-v', 64), SenseInfo('02005948-v', 58), SenseInfo('01433294-v', 45), SenseInfo('02108026-v', 36), SenseInfo('01153947-v', 14), SenseInfo('02355596-v', 9), SenseInfo('00770437-v', 7), SenseInfo('01215421-v', 4), SenseInfo('00094460-v', 4), SenseInfo('00087736-v', 4), SenseInfo('01066036-v', 3), SenseInfo('00120316-v', 3), SenseInfo('01026975-v', 2), SenseInfo('00589904-v', 2), SenseInfo('01505958-v', 1), SenseInfo('01401115-v', 1), SenseInfo('00639849-v', 1), SenseInfo('02359340-v', 0), SenseInfo('02208265-v', 0), SenseInfo('02189398-v', 0), SenseInfo('02109645-v', 0), SenseInfo('02108654-v', 0), SenseInfo('02010864-v', 0), SenseInfo('02006573-v', 0), SenseInfo('01771194-v', 0), SenseInfo('01771039-v', 0), SenseInfo('01738107-v', 0), SenseInfo('01643297-v', 0), SenseInfo('01565211-v', 0), SenseInfo('00622384-v', 0), SenseInfo('00345761-v', 0), SenseInfo('00065639-v', 0), SenseInfo('00054628-v', 0), SenseInfo('02210855-v', 235), SenseInfo('00149583-v', 157), SenseInfo('00120796-v', 82), SenseInfo('00522751-v', 64), SenseInfo('02005948-v', 58), SenseInfo('01433294-v', 45), SenseInfo('02108026-v', 36), SenseInfo('01153947-v', 14), SenseInfo('02355596-v', 9), SenseInfo('00770437-v', 7), SenseInfo('01215421-v', 4), SenseInfo('00094460-v', 4), SenseInfo('00087736-v', 4), SenseInfo('01066036-v', 3), SenseInfo('00120316-v', 3), SenseInfo('01026975-v', 2), SenseInfo('00589904-v', 2), SenseInfo('01505958-v', 1), SenseInfo('01401115-v', 1), SenseInfo('00639849-v', 1), SenseInfo('02359340-v', 0), SenseInfo('02208265-v', 0), SenseInfo('02189398-v', 0), SenseInfo('02109645-v', 0), SenseInfo('02108654-v', 0), SenseInfo('02010864-v', 0), SenseInfo('02006573-v', 0), SenseInfo('01771194-v', 0), SenseInfo('01771039-v', 0), SenseInfo('01738107-v', 0), SenseInfo('01643297-v', 0), SenseInfo('01565211-v', 0), SenseInfo('00622384-v', 0), SenseInfo('00345761-v', 0), SenseInfo('00065639-v', 0), SenseInfo('00054628-v', 0), SenseInfo('02210855-v', 235), SenseInfo('00149583-v', 157), SenseInfo('00120796-v', 82), SenseInfo('00522751-v', 64), SenseInfo('02005948-v', 58), SenseInfo('01433294-v', 45), SenseInfo('02108026-v', 36), SenseInfo('01153947-v', 14), SenseInfo('02355596-v', 9), SenseInfo('00770437-v', 7), SenseInfo('01215421-v', 4), SenseInfo('00094460-v', 4), SenseInfo('00087736-v', 4), SenseInfo('01066036-v', 3), SenseInfo('00120316-v', 3), SenseInfo('01026975-v', 2), SenseInfo('00589904-v', 2), SenseInfo('01505958-v', 1), SenseInfo('01401115-v', 1), SenseInfo('00639849-v', 1), SenseInfo('02359340-v', 0), SenseInfo('02208265-v', 0), SenseInfo('02189398-v', 0), SenseInfo('02109645-v', 0), SenseInfo('02108654-v', 0), SenseInfo('02010864-v', 0), SenseInfo('02006573-v', 0), SenseInfo('01771194-v', 0), SenseInfo('01771039-v', 0), SenseInfo('01738107-v', 0), SenseInfo('01643297-v', 0), SenseInfo('01565211-v', 0), SenseInfo('00622384-v', 0), SenseInfo('00345761-v', 0), SenseInfo('00065639-v', 0), SenseInfo('00054628-v', 0) ],
"_evaporator_n_1_rel" : [  ],
"_russian_a_1_rel" : [ SenseInfo('02957276-a', 22) ],
"_shatter_v_1_rel" : [ SenseInfo('00333758-v', 12), SenseInfo('00334050-v', 0), SenseInfo('00333907-v', 0) ],
"_lump_v_in_rel" : [ SenseInfo('01385920-v', 2), SenseInfo('00657016-v', 0) ],
"_righto_a_1_rel" : [  ],
"_spot_n_of_rel" : [ SenseInfo('08664443-n', 23), SenseInfo('06396644-n', 2), SenseInfo('04731925-n', 2), SenseInfo('04694441-n', 2), SenseInfo('04682462-n', 2), SenseInfo('06396468-n', 1), SenseInfo('04286128-n', 1), SenseInfo('00586262-n', 1), SenseInfo('14082186-n', 0), SenseInfo('13761407-n', 0), SenseInfo('07271942-n', 0), SenseInfo('04286575-n', 0), SenseInfo('04286307-n', 0), SenseInfo('00072261-n', 0) ],
"_conceit_n_1_rel" : [ SenseInfo('07508996-n', 1), SenseInfo('07106113-n', 0), SenseInfo('07088868-n', 0), SenseInfo('07068473-n', 0), SenseInfo('04887129-n', 0) ],
"_judge_n_of_rel" : [ SenseInfo('10225219-n', 6), SenseInfo('10066732-n', 3) ],
"_spinoff_n_1_rel" : [  ],
"_slovak_a_1_rel" : [ SenseInfo('09699536-n', 0), SenseInfo('06944820-n', 0) ],
"_curtain_v_off_rel" : [ SenseInfo('02353537-v', 0) ],
"_intensity_n_1_rel" : [ SenseInfo('05099796-n', 29), SenseInfo('05036394-n', 12), SenseInfo('04990220-n', 0), SenseInfo('04975340-n', 0) ],
"_drop-dead_x_deg_rel" : [ SenseInfo('00358431-v', 2), SenseInfo('00358431-v', 2) ],
"_pal_n_1_rel" : [ SenseInfo('09877951-n', 0) ],
"_calorie_n_1_rel" : [ SenseInfo('13726562-n', 0), SenseInfo('13726296-n', 0) ],
"_purse_v_1_rel" : [ SenseInfo('00145902-v', 2), SenseInfo('01279305-v', 0) ],
"_boatshed_n_1_rel" : [  ],
"_quarter-mile_n_1_rel" : [ SenseInfo('13651931-n', 2), SenseInfo('13651931-n', 2) ],
"_hardcover_n_1_rel" : [ SenseInfo('03492391-n', 0) ],
"_pole_n_1_rel" : [ SenseInfo('03976657-n', 6), SenseInfo('09727627-n', 4), SenseInfo('05950559-n', 2), SenseInfo('13650921-n', 0), SenseInfo('13614679-n', 0), SenseInfo('08621099-n', 0), SenseInfo('08620881-n', 0), SenseInfo('04413151-n', 0), SenseInfo('03977158-n', 0), SenseInfo('03976960-n', 0) ],
"_defraud_v_of_rel" : [ SenseInfo('02572119-v', 2), SenseInfo('02572119-v', 2) ],
"_stump_v_1_rel" : [ SenseInfo('00620379-v', 1), SenseInfo('01925338-v', 0), SenseInfo('01094384-v', 0), SenseInfo('00195221-v', 0) ],
"_prop_v_up_rel" : [ SenseInfo('01219004-v', 1) ],
"_hairy_a_1_rel" : [ SenseInfo('00212173-a', 2), SenseInfo('00196122-a', 0), SenseInfo('00212173-a', 2), SenseInfo('00196122-a', 0), SenseInfo('00212173-a', 2), SenseInfo('00196122-a', 0) ],
"_violent_n_1_rel" : [ SenseInfo('02510879-a', 8), SenseInfo('01570747-a', 1), SenseInfo('01514141-a', 1), SenseInfo('01511854-a', 0), SenseInfo('00248560-a', 0) ],
"_executive_n_1_rel" : [ SenseInfo('10069645-n', 3), SenseInfo('08165455-n', 1), SenseInfo('09770472-n', 0), SenseInfo('10069645-n', 3), SenseInfo('08165455-n', 1), SenseInfo('09770472-n', 0) ],
"_elevation_n_of_rel" : [ SenseInfo('07370671-n', 2), SenseInfo('13940456-n', 1), SenseInfo('13836550-n', 1), SenseInfo('09366317-n', 0), SenseInfo('05131283-n', 0), SenseInfo('05086903-n', 0), SenseInfo('03281052-n', 0), SenseInfo('00373544-n', 0) ],
"_given_n_1_rel" : [ SenseInfo('05893356-n', 1) ],
"_lacquer_n_1_rel" : [ SenseInfo('14928729-n', 0), SenseInfo('03631811-n', 0) ],
"_flower_v_1_rel" : [ SenseInfo('00294245-v', 1) ],
"_malaysian_a_1_rel" : [ SenseInfo('03083417-a', 0) ],
"_viz_p_rel" : [  ],
"_stroke_v_1_rel" : [ SenseInfo('01225970-v', 4), SenseInfo('01124608-v', 1), SenseInfo('01124722-v', 0), SenseInfo('00880658-v', 0) ],
"_howl_v_1_rel" : [ SenseInfo('01046932-v', 3), SenseInfo('01047381-v', 0), SenseInfo('01046059-v', 0), SenseInfo('00029836-v', 0) ],
"_coptic_a_1_rel" : [ SenseInfo('03056463-a', 0) ],
"_fetal_a_1_rel" : [ SenseInfo('02892819-a', 0) ],
"_chime_v_1_rel" : [ SenseInfo('02182342-v', 0) ],
"_laugh_v_off_rel" : [ SenseInfo('00031820-v', 64) ],
"_barbeque_v_1_rel" : [ SenseInfo('00324806-v', 0) ],
"_attentive_a_1_rel" : [ SenseInfo('00163592-a', 2), SenseInfo('01194483-a', 0), SenseInfo('00163592-a', 2), SenseInfo('01194483-a', 0) ],
"_cinch_n_1_rel" : [ SenseInfo('00575365-n', 2), SenseInfo('03031756-n', 0), SenseInfo('00498427-n', 0), SenseInfo('00575365-n', 2), SenseInfo('03031756-n', 0), SenseInfo('00498427-n', 0), SenseInfo('00575365-n', 2), SenseInfo('03031756-n', 0), SenseInfo('00498427-n', 0) ],
"_surprise_v_1_rel" : [ SenseInfo('00725274-v', 22), SenseInfo('02596493-v', 1), SenseInfo('01126051-v', 0), SenseInfo('00725274-v', 22), SenseInfo('02596493-v', 1), SenseInfo('01126051-v', 0), SenseInfo('00725274-v', 22), SenseInfo('02596493-v', 1), SenseInfo('01126051-v', 0), SenseInfo('00725274-v', 22), SenseInfo('02596493-v', 1), SenseInfo('01126051-v', 0), SenseInfo('00725274-v', 22), SenseInfo('02596493-v', 1), SenseInfo('01126051-v', 0), SenseInfo('00725274-v', 22), SenseInfo('02596493-v', 1), SenseInfo('01126051-v', 0) ],
"_moron_n_1_rel" : [ SenseInfo('10197525-n', 0), SenseInfo('08713285-n', 0) ],
"_correction_n_of-to_rel" : [ SenseInfo('00258854-n', 2), SenseInfo('13755957-n', 1), SenseInfo('06428537-n', 1), SenseInfo('06714288-n', 0), SenseInfo('05111511-n', 0), SenseInfo('01161821-n', 0), SenseInfo('00662527-n', 0), SenseInfo('00258854-n', 2), SenseInfo('13755957-n', 1), SenseInfo('06428537-n', 1), SenseInfo('06714288-n', 0), SenseInfo('05111511-n', 0), SenseInfo('01161821-n', 0), SenseInfo('00662527-n', 0) ],
"_suggest_v_to_rel" : [ SenseInfo('00875394-v', 57), SenseInfo('00927430-v', 21), SenseInfo('00930806-v', 19), SenseInfo('00928232-v', 14), SenseInfo('00930368-v', 12), SenseInfo('00875394-v', 57), SenseInfo('00927430-v', 21), SenseInfo('00930806-v', 19), SenseInfo('00928232-v', 14), SenseInfo('00930368-v', 12), SenseInfo('00875394-v', 57), SenseInfo('00927430-v', 21), SenseInfo('00930806-v', 19), SenseInfo('00928232-v', 14), SenseInfo('00930368-v', 12), SenseInfo('00875394-v', 57), SenseInfo('00927430-v', 21), SenseInfo('00930806-v', 19), SenseInfo('00928232-v', 14), SenseInfo('00930368-v', 12), SenseInfo('00875394-v', 57), SenseInfo('00927430-v', 21), SenseInfo('00930806-v', 19), SenseInfo('00928232-v', 14), SenseInfo('00930368-v', 12), SenseInfo('00875394-v', 57), SenseInfo('00927430-v', 21), SenseInfo('00930806-v', 19), SenseInfo('00928232-v', 14), SenseInfo('00930368-v', 12) ],
"_energetic_a_1_rel" : [ SenseInfo('00873603-a', 4), SenseInfo('00885099-a', 1), SenseInfo('00873603-a', 4), SenseInfo('00885099-a', 1) ],
"_hole_v_1_rel" : [ SenseInfo('01408153-v', 0), SenseInfo('01282023-v', 0) ],
"_total_v_up_rel" : [ SenseInfo('02645007-v', 16), SenseInfo('00949288-v', 2), SenseInfo('00259382-v', 0) ],
"_toboggan_n_1_rel" : [ SenseInfo('04443433-n', 0) ],
"_hold_v_back_rel" : [ SenseInfo('02681795-v', 79), SenseInfo('01216670-v', 65), SenseInfo('01733477-v', 62), SenseInfo('02203362-v', 26), SenseInfo('00693780-v', 20), SenseInfo('01773130-v', 17), SenseInfo('01301410-v', 17), SenseInfo('02283324-v', 14), SenseInfo('02302220-v', 9), SenseInfo('01217043-v', 9), SenseInfo('02700867-v', 7), SenseInfo('02732798-v', 3), SenseInfo('02683489-v', 3), SenseInfo('01601234-v', 3), SenseInfo('02648502-v', 2), SenseInfo('00683771-v', 2), SenseInfo('02746275-v', 1), SenseInfo('02701210-v', 1), SenseInfo('02498320-v', 1), SenseInfo('01129876-v', 1), SenseInfo('00885217-v', 1), SenseInfo('00736586-v', 1), SenseInfo('00607000-v', 1), SenseInfo('02706816-v', 0), SenseInfo('02676789-v', 0), SenseInfo('02643574-v', 0), SenseInfo('02510337-v', 0), SenseInfo('02450989-v', 0), SenseInfo('02441897-v', 0), SenseInfo('01859586-v', 0), SenseInfo('01334744-v', 0), SenseInfo('01205153-v', 0), SenseInfo('01151753-v', 0), SenseInfo('00822367-v', 0), SenseInfo('00805376-v', 0), SenseInfo('00004492-v', 0), SenseInfo('02681795-v', 79), SenseInfo('01216670-v', 65), SenseInfo('01733477-v', 62), SenseInfo('02203362-v', 26), SenseInfo('00693780-v', 20), SenseInfo('01773130-v', 17), SenseInfo('01301410-v', 17), SenseInfo('02283324-v', 14), SenseInfo('02302220-v', 9), SenseInfo('01217043-v', 9), SenseInfo('02700867-v', 7), SenseInfo('02732798-v', 3), SenseInfo('02683489-v', 3), SenseInfo('01601234-v', 3), SenseInfo('02648502-v', 2), SenseInfo('00683771-v', 2), SenseInfo('02746275-v', 1), SenseInfo('02701210-v', 1), SenseInfo('02498320-v', 1), SenseInfo('01129876-v', 1), SenseInfo('00885217-v', 1), SenseInfo('00736586-v', 1), SenseInfo('00607000-v', 1), SenseInfo('02706816-v', 0), SenseInfo('02676789-v', 0), SenseInfo('02643574-v', 0), SenseInfo('02510337-v', 0), SenseInfo('02450989-v', 0), SenseInfo('02441897-v', 0), SenseInfo('01859586-v', 0), SenseInfo('01334744-v', 0), SenseInfo('01205153-v', 0), SenseInfo('01151753-v', 0), SenseInfo('00822367-v', 0), SenseInfo('00805376-v', 0), SenseInfo('00004492-v', 0) ],
"_distinctive_a_1_rel" : [ SenseInfo('00357556-a', 5), SenseInfo('01272718-a', 3) ],
"_wrangle_v_1_rel" : [ SenseInfo('00774344-v', 3), SenseInfo('02652376-v', 0) ],
"_apart_p_rel" : [ SenseInfo('00181075-r', 18), SenseInfo('00180756-r', 10), SenseInfo('00234389-r', 1), SenseInfo('00567860-a', 1), SenseInfo('00234201-r', 0), SenseInfo('00181253-r', 0), SenseInfo('00180944-r', 0), SenseInfo('02110161-a', 0) ],
"_playwright_n_1_rel" : [ SenseInfo('10030277-n', 4) ],
"_onward_a_1_rel" : [  ],
"_fulfillment_n_of_rel" : [ SenseInfo('07532112-n', 3), SenseInfo('00062451-n', 2) ],
"_mournful_a_1_rel" : [ SenseInfo('01366157-a', 2), SenseInfo('01362387-a', 0) ],
"_keep_n_1_rel" : [ SenseInfo('13365286-n', 0), SenseInfo('03610098-n', 0), SenseInfo('03525252-n', 0) ],
"_discard_n_1_rel" : [ SenseInfo('09267490-n', 0), SenseInfo('00091503-n', 0), SenseInfo('00091234-n', 0) ],
"_neutralize_v_1_rel" : [ SenseInfo('02535896-v', 3), SenseInfo('00470084-v', 1), SenseInfo('02543874-v', 0), SenseInfo('01327301-v', 0), SenseInfo('01117931-v', 0), SenseInfo('00469904-v', 0) ],
"_random_a_1_rel" : [ SenseInfo('01924316-a', 5), SenseInfo('01924316-a', 5) ],
"_stereotype_v_1_rel" : [ SenseInfo('00656292-v', 0) ],
"_gold_a_1_rel" : [ SenseInfo('01528730-a', 2), SenseInfo('00369941-a', 2) ],
"_garage_n_1_rel" : [ SenseInfo('03416489-n', 12), SenseInfo('03416640-n', 0) ],
"_impediment_n_1_rel" : [ SenseInfo('05689249-n', 0), SenseInfo('03839993-n', 0) ],
"_overrun_n_1_rel" : [ SenseInfo('00914343-n', 0) ],
"_serbian_a_1_rel" : [ SenseInfo('02963942-a', 0) ],
"_pull_v_down_rel" : [ SenseInfo('01448100-v', 44), SenseInfo('01505254-v', 8), SenseInfo('02057499-v', 6), SenseInfo('01609287-v', 3), SenseInfo('02582615-v', 2), SenseInfo('01995211-v', 2), SenseInfo('02057337-v', 1), SenseInfo('00071803-v', 1), SenseInfo('02103162-v', 0), SenseInfo('01947247-v', 0), SenseInfo('01858573-v', 0), SenseInfo('01573276-v', 0), SenseInfo('01407059-v', 0), SenseInfo('01384275-v', 0), SenseInfo('01351170-v', 0), SenseInfo('01148710-v', 0), SenseInfo('00571596-v', 0) ],
"_hillside_n_1_rel" : [ SenseInfo('09303528-n', 3), SenseInfo('09303528-n', 3) ],
"_take_v_to_rel" : [ SenseInfo('02599636-v', 92), SenseInfo('02267989-v', 74), SenseInfo('01999798-v', 73), SenseInfo('01214265-v', 50), SenseInfo('00524682-v', 38), SenseInfo('00624476-v', 36), SenseInfo('02077656-v', 32), SenseInfo('02205272-v', 28), SenseInfo('01842690-v', 26), SenseInfo('00674607-v', 26), SenseInfo('02236124-v', 25), SenseInfo('02394183-v', 22), SenseInfo('00734054-v', 22), SenseInfo('02627934-v', 21), SenseInfo('02109045-v', 21), SenseInfo('01002740-v', 16), SenseInfo('00173338-v', 16), SenseInfo('01156834-v', 15), SenseInfo('00669762-v', 15), SenseInfo('02209936-v', 14), SenseInfo('02206619-v', 13), SenseInfo('01982395-v', 10), SenseInfo('02236624-v', 8), SenseInfo('00523095-v', 7), SenseInfo('00599992-v', 6), SenseInfo('00756076-v', 5), SenseInfo('02075857-v', 4), SenseInfo('01151110-v', 4), SenseInfo('00557404-v', 4), SenseInfo('02717102-v', 2), SenseInfo('02208537-v', 2), SenseInfo('02209745-v', 1), SenseInfo('02208118-v', 1), SenseInfo('02201138-v', 1), SenseInfo('01427127-v', 1), SenseInfo('00758333-v', 1), SenseInfo('02741546-v', 0), SenseInfo('02701210-v', 0), SenseInfo('02590253-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01100830-v', 0), SenseInfo('00087736-v', 0) ],
"_forfeit_a_1_rel" : [ SenseInfo('01452385-a', 1) ],
"_tread_v_1_rel" : [ SenseInfo('02091410-v', 3), SenseInfo('01929467-v', 3), SenseInfo('01594664-v', 1), SenseInfo('01219867-v', 1), SenseInfo('02309513-v', 0), SenseInfo('01427907-v', 0) ],
"_zookeeper_n_1_rel" : [  ],
"_winding_n_1_rel" : [ SenseInfo('00345641-n', 0) ],
"_abacus_n_1_rel" : [ SenseInfo('02666347-n', 0), SenseInfo('02666196-n', 0) ],
"_trombone_n_1_rel" : [ SenseInfo('04487394-n', 0) ],
"_meagerly_a_1_rel" : [ SenseInfo('00106456-a', 0) ],
"_limit_v_down_rel" : [ SenseInfo('00233335-v', 23), SenseInfo('00235368-v', 6), SenseInfo('00947077-v', 0), SenseInfo('00233335-v', 23), SenseInfo('00235368-v', 6), SenseInfo('00947077-v', 0) ],
"_obese_a_1_rel" : [ SenseInfo('00987180-a', 0) ],
"_average_v_out_rel" : [ SenseInfo('02645389-v', 15), SenseInfo('02527294-v', 2), SenseInfo('00639998-v', 1), SenseInfo('02645389-v', 15), SenseInfo('02527294-v', 2), SenseInfo('00639998-v', 1) ],
"_renewed_a_1_rel" : [ SenseInfo('02013758-a', 1) ],
"_space_n_of_rel" : [ SenseInfo('00028651-n', 24), SenseInfo('13910384-n', 16), SenseInfo('08652970-n', 12), SenseInfo('08500433-n', 4), SenseInfo('06839190-n', 2), SenseInfo('15172212-n', 1), SenseInfo('06389553-n', 1), SenseInfo('06862202-n', 0), SenseInfo('04030655-n', 0), SenseInfo('00028651-n', 24), SenseInfo('13910384-n', 16), SenseInfo('08652970-n', 12), SenseInfo('08500433-n', 4), SenseInfo('06839190-n', 2), SenseInfo('15172212-n', 1), SenseInfo('06389553-n', 1), SenseInfo('06862202-n', 0), SenseInfo('04030655-n', 0) ],
"_forestall_v_1_rel" : [ SenseInfo('02452885-v', 4), SenseInfo('02565491-v', 0) ],
"_prosperity_n_1_rel" : [ SenseInfo('14489699-n', 3), SenseInfo('14474052-n', 1) ],
"_face+first_a_1_rel" : [  ],
"_commoner_n_1_rel" : [ SenseInfo('09610405-n', 1) ],
"_construct_n_1_rel" : [ SenseInfo('05835747-n', 0) ],
"_ounce_n_1_rel" : [ SenseInfo('13722522-n', 4), SenseInfo('13719922-n', 0), SenseInfo('02128757-n', 0), SenseInfo('13722522-n', 4), SenseInfo('13719922-n', 0), SenseInfo('02128757-n', 0), SenseInfo('13722522-n', 4), SenseInfo('13719922-n', 0), SenseInfo('02128757-n', 0) ],
"_grudge_v_1_rel" : [ SenseInfo('01774005-v', 0), SenseInfo('01773734-v', 0) ],
"_ss_n_ttl_rel" : [ SenseInfo('15235126-n', 0), SenseInfo('14656219-n', 0), SenseInfo('13833375-n', 0), SenseInfo('13637240-n', 0), SenseInfo('06833112-n', 0), SenseInfo('05012585-n', 0), SenseInfo('15235126-n', 0), SenseInfo('14656219-n', 0), SenseInfo('13833375-n', 0), SenseInfo('13637240-n', 0), SenseInfo('06833112-n', 0), SenseInfo('05012585-n', 0) ],
"_shy_v_1_rel" : [ SenseInfo('01910680-v', 1), SenseInfo('01509492-v', 0) ],
"_today_a_1_rel" : [ SenseInfo('15262921-n', 69), SenseInfo('15156001-n', 13), SenseInfo('15262921-n', 69), SenseInfo('15156001-n', 13) ],
"_homicidal_a_1_rel" : [ SenseInfo('00248837-a', 1) ],
"_melancholy_a_1_rel" : [ SenseInfo('01362684-a', 3), SenseInfo('00365261-a', 0) ],
"_pacemaker_n_1_rel" : [ SenseInfo('05938633-n', 0), SenseInfo('05389460-n', 0), SenseInfo('03870290-n', 0), SenseInfo('02388143-n', 0) ],
"_sanity_n_1_rel" : [ SenseInfo('14379501-n', 1) ],
"_softwood_n_1_rel" : [ SenseInfo('15100257-n', 0) ],
"_insidious_a_1_rel" : [ SenseInfo('02097884-a', 0), SenseInfo('02060106-a', 0), SenseInfo('01162406-a', 0) ],
"_indisputable_a_1_rel" : [ SenseInfo('00721636-a', 0), SenseInfo('00335895-a', 0) ],
"_minimal_a_1_rel" : [ SenseInfo('01496021-a', 24), SenseInfo('01496021-a', 24) ],
"_carriage_n_1_rel" : [ SenseInfo('03895866-n', 2), SenseInfo('02968473-n', 2), SenseInfo('05002822-n', 0), SenseInfo('02969010-n', 0), SenseInfo('02766534-n', 0) ],
"_take_v_out+of_rel" : [ SenseInfo('02599636-v', 92), SenseInfo('02267989-v', 74), SenseInfo('01999798-v', 73), SenseInfo('01214265-v', 50), SenseInfo('00524682-v', 38), SenseInfo('00624476-v', 36), SenseInfo('02077656-v', 32), SenseInfo('02205272-v', 28), SenseInfo('01842690-v', 26), SenseInfo('00674607-v', 26), SenseInfo('02236124-v', 25), SenseInfo('02394183-v', 22), SenseInfo('00734054-v', 22), SenseInfo('02627934-v', 21), SenseInfo('02109045-v', 21), SenseInfo('01002740-v', 16), SenseInfo('00173338-v', 16), SenseInfo('01156834-v', 15), SenseInfo('00669762-v', 15), SenseInfo('02209936-v', 14), SenseInfo('02206619-v', 13), SenseInfo('01982395-v', 10), SenseInfo('02236624-v', 8), SenseInfo('00523095-v', 7), SenseInfo('00599992-v', 6), SenseInfo('00756076-v', 5), SenseInfo('02075857-v', 4), SenseInfo('01151110-v', 4), SenseInfo('00557404-v', 4), SenseInfo('02717102-v', 2), SenseInfo('02208537-v', 2), SenseInfo('02209745-v', 1), SenseInfo('02208118-v', 1), SenseInfo('02201138-v', 1), SenseInfo('01427127-v', 1), SenseInfo('00758333-v', 1), SenseInfo('02741546-v', 0), SenseInfo('02701210-v', 0), SenseInfo('02590253-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01100830-v', 0), SenseInfo('00087736-v', 0) ],
"_customs_n_1_rel" : [ SenseInfo('00413239-n', 4), SenseInfo('05667404-n', 3), SenseInfo('13317002-n', 0), SenseInfo('01096873-n', 0) ],
"_blow_v_off_rel" : [ SenseInfo('00007012-v', 6), SenseInfo('02769241-v', 5), SenseInfo('00034948-v', 3), SenseInfo('01902783-v', 2), SenseInfo('02135877-v', 1), SenseInfo('00477247-v', 1), SenseInfo('02527651-v', 0), SenseInfo('02268351-v', 0), SenseInfo('02266148-v', 0), SenseInfo('02178340-v', 0), SenseInfo('02135727-v', 0), SenseInfo('02117170-v', 0), SenseInfo('02101046-v', 0), SenseInfo('02100632-v', 0), SenseInfo('02068745-v', 0), SenseInfo('01849054-v', 0), SenseInfo('01545208-v', 0), SenseInfo('00934965-v', 0), SenseInfo('00883226-v', 0), SenseInfo('00779804-v', 0), SenseInfo('00435294-v', 0), SenseInfo('00310155-v', 0) ],
"_weigh_v_in_rel" : [ SenseInfo('02704818-v', 17), SenseInfo('00950431-v', 4), SenseInfo('02704617-v', 2), SenseInfo('02645839-v', 1), SenseInfo('02646064-v', 0) ],
"_shortly+after_a_1_rel" : [  ],
"_loose_a_1_rel" : [ SenseInfo('00503321-a', 2), SenseInfo('00600725-a', 2), SenseInfo('01446749-a', 1), SenseInfo('01634027-a', 1), SenseInfo('00916199-a', 1), SenseInfo('00638841-a', 1), SenseInfo('00159381-a', 0), SenseInfo('02404421-a', 0), SenseInfo('02232112-a', 0), SenseInfo('01998835-a', 0), SenseInfo('01739582-a', 0), SenseInfo('01062114-a', 0), SenseInfo('00361837-a', 0), SenseInfo('00503321-a', 2), SenseInfo('00600725-a', 2), SenseInfo('01446749-a', 1), SenseInfo('01634027-a', 1), SenseInfo('00916199-a', 1), SenseInfo('00638841-a', 1), SenseInfo('00159381-a', 0), SenseInfo('02404421-a', 0), SenseInfo('02232112-a', 0), SenseInfo('01998835-a', 0), SenseInfo('01739582-a', 0), SenseInfo('01062114-a', 0), SenseInfo('00361837-a', 0), SenseInfo('00503321-a', 2), SenseInfo('00600725-a', 2), SenseInfo('01446749-a', 1), SenseInfo('01634027-a', 1), SenseInfo('00916199-a', 1), SenseInfo('00638841-a', 1), SenseInfo('00159381-a', 0), SenseInfo('02404421-a', 0), SenseInfo('02232112-a', 0), SenseInfo('01998835-a', 0), SenseInfo('01739582-a', 0), SenseInfo('01062114-a', 0), SenseInfo('00361837-a', 0) ],
"_ching_n_1_rel" : [  ],
"_confine_v_to_rel" : [ SenseInfo('00233335-v', 5), SenseInfo('00235368-v', 4), SenseInfo('01347298-v', 3), SenseInfo('02711114-v', 0), SenseInfo('02495038-v', 0), SenseInfo('01301410-v', 0), SenseInfo('00233335-v', 5), SenseInfo('00235368-v', 4), SenseInfo('01347298-v', 3), SenseInfo('02711114-v', 0), SenseInfo('02495038-v', 0), SenseInfo('01301410-v', 0) ],
"_toilette_n_1_rel" : [ SenseInfo('00828704-n', 0) ],
"_betwixt_p_rel" : [ SenseInfo('00498387-r', 0) ],
"_commotion_n_1_rel" : [ SenseInfo('13977366-n', 6), SenseInfo('00553823-n', 2), SenseInfo('07442068-n', 0) ],
"_coordinate_n_1_rel" : [ SenseInfo('06010930-n', 2), SenseInfo('06010930-n', 2), SenseInfo('06010930-n', 2) ],
"_hem_n_1_rel" : [ SenseInfo('03513627-n', 3), SenseInfo('07126521-n', 0) ],
"_lotus_n_1_rel" : [ SenseInfo('11717399-n', 1), SenseInfo('12545090-n', 0), SenseInfo('11715810-n', 0) ],
"_accountant_n_1_rel" : [ SenseInfo('09761403-n', 1) ],
"_sponge_v_1_rel" : [ SenseInfo('01392663-v', 2), SenseInfo('02270404-v', 0), SenseInfo('01549057-v', 0), SenseInfo('01393611-v', 0), SenseInfo('01383646-v', 0) ],
"_yup_a_1_rel" : [  ],
"_hairbrush_n_1_rel" : [ SenseInfo('03475581-n', 0) ],
"_buts_n_1_rel" : [  ],
"_monkey_n_1_rel" : [ SenseInfo('02484322-n', 8), SenseInfo('10200047-n', 0) ],
"_snuggle_v_down_rel" : [ SenseInfo('01424948-v', 3), SenseInfo('01425348-v', 0) ],
"_acquisition_n_of_rel" : [ SenseInfo('00077419-n', 11), SenseInfo('13253255-n', 0), SenseInfo('05752544-n', 0), SenseInfo('05637558-n', 0), SenseInfo('00077419-n', 11), SenseInfo('13253255-n', 0), SenseInfo('05752544-n', 0), SenseInfo('05637558-n', 0), SenseInfo('00077419-n', 11), SenseInfo('13253255-n', 0), SenseInfo('05752544-n', 0), SenseInfo('05637558-n', 0) ],
"_check_v_1_rel" : [ SenseInfo('00661824-v', 27), SenseInfo('02533282-v', 7), SenseInfo('00662589-v', 6), SenseInfo('02510337-v', 5), SenseInfo('01861403-v', 1), SenseInfo('00662182-v', 1), SenseInfo('00440286-v', 1), SenseInfo('02658283-v', 0), SenseInfo('02657219-v', 0), SenseInfo('02557638-v', 0), SenseInfo('02553697-v', 0), SenseInfo('02347905-v', 0), SenseInfo('02347447-v', 0), SenseInfo('01861767-v', 0), SenseInfo('01861622-v', 0), SenseInfo('01692978-v', 0), SenseInfo('01139756-v', 0), SenseInfo('01131473-v', 0), SenseInfo('01114764-v', 0), SenseInfo('01064999-v', 0), SenseInfo('00920336-v', 0), SenseInfo('00663353-v', 0), SenseInfo('00354634-v', 0), SenseInfo('00336539-v', 0), SenseInfo('00336260-v', 0), SenseInfo('00661824-v', 27), SenseInfo('02533282-v', 7), SenseInfo('00662589-v', 6), SenseInfo('02510337-v', 5), SenseInfo('01861403-v', 1), SenseInfo('00662182-v', 1), SenseInfo('00440286-v', 1), SenseInfo('02658283-v', 0), SenseInfo('02657219-v', 0), SenseInfo('02557638-v', 0), SenseInfo('02553697-v', 0), SenseInfo('02347905-v', 0), SenseInfo('02347447-v', 0), SenseInfo('01861767-v', 0), SenseInfo('01861622-v', 0), SenseInfo('01692978-v', 0), SenseInfo('01139756-v', 0), SenseInfo('01131473-v', 0), SenseInfo('01114764-v', 0), SenseInfo('01064999-v', 0), SenseInfo('00920336-v', 0), SenseInfo('00663353-v', 0), SenseInfo('00354634-v', 0), SenseInfo('00336539-v', 0), SenseInfo('00336260-v', 0), SenseInfo('00661824-v', 27), SenseInfo('02533282-v', 7), SenseInfo('00662589-v', 6), SenseInfo('02510337-v', 5), SenseInfo('01861403-v', 1), SenseInfo('00662182-v', 1), SenseInfo('00440286-v', 1), SenseInfo('02658283-v', 0), SenseInfo('02657219-v', 0), SenseInfo('02557638-v', 0), SenseInfo('02553697-v', 0), SenseInfo('02347905-v', 0), SenseInfo('02347447-v', 0), SenseInfo('01861767-v', 0), SenseInfo('01861622-v', 0), SenseInfo('01692978-v', 0), SenseInfo('01139756-v', 0), SenseInfo('01131473-v', 0), SenseInfo('01114764-v', 0), SenseInfo('01064999-v', 0), SenseInfo('00920336-v', 0), SenseInfo('00663353-v', 0), SenseInfo('00354634-v', 0), SenseInfo('00336539-v', 0), SenseInfo('00336260-v', 0), SenseInfo('00661824-v', 27), SenseInfo('02533282-v', 7), SenseInfo('00662589-v', 6), SenseInfo('02510337-v', 5), SenseInfo('01861403-v', 1), SenseInfo('00662182-v', 1), SenseInfo('00440286-v', 1), SenseInfo('02658283-v', 0), SenseInfo('02657219-v', 0), SenseInfo('02557638-v', 0), SenseInfo('02553697-v', 0), SenseInfo('02347905-v', 0), SenseInfo('02347447-v', 0), SenseInfo('01861767-v', 0), SenseInfo('01861622-v', 0), SenseInfo('01692978-v', 0), SenseInfo('01139756-v', 0), SenseInfo('01131473-v', 0), SenseInfo('01114764-v', 0), SenseInfo('01064999-v', 0), SenseInfo('00920336-v', 0), SenseInfo('00663353-v', 0), SenseInfo('00354634-v', 0), SenseInfo('00336539-v', 0), SenseInfo('00336260-v', 0) ],
"_wonderfully_x_deg_rel" : [ SenseInfo('00183090-r', 3) ],
"_ripen_v_1_rel" : [ SenseInfo('00249969-v', 1), SenseInfo('00249852-v', 1) ],
"_conclusion_n_of_rel" : [ SenseInfo('05838176-n', 29), SenseInfo('05781541-n', 5), SenseInfo('15267536-n', 1), SenseInfo('07291312-n', 1), SenseInfo('06753030-n', 1), SenseInfo('00209943-n', 1), SenseInfo('07177622-n', 0), SenseInfo('06398401-n', 0), SenseInfo('00162632-n', 0), SenseInfo('05838176-n', 29), SenseInfo('05781541-n', 5), SenseInfo('15267536-n', 1), SenseInfo('07291312-n', 1), SenseInfo('06753030-n', 1), SenseInfo('00209943-n', 1), SenseInfo('07177622-n', 0), SenseInfo('06398401-n', 0), SenseInfo('00162632-n', 0) ],
"_step_v_up_rel" : [ SenseInfo('01928838-v', 23), SenseInfo('02091410-v', 7), SenseInfo('02563616-v', 0), SenseInfo('02516594-v', 0), SenseInfo('02330247-v', 0), SenseInfo('02091885-v', 0), SenseInfo('02091689-v', 0), SenseInfo('01256487-v', 0), SenseInfo('00490722-v', 0), SenseInfo('00124659-v', 0), SenseInfo('01928838-v', 23), SenseInfo('02091410-v', 7), SenseInfo('02563616-v', 0), SenseInfo('02516594-v', 0), SenseInfo('02330247-v', 0), SenseInfo('02091885-v', 0), SenseInfo('02091689-v', 0), SenseInfo('01256487-v', 0), SenseInfo('00490722-v', 0), SenseInfo('00124659-v', 0) ],
"_smell_v_2_rel" : [ SenseInfo('02124748-v', 14), SenseInfo('02123672-v', 12), SenseInfo('02124332-v', 3), SenseInfo('02194723-v', 0), SenseInfo('00589469-v', 0) ],
"_rattlesnake_n_1_rel" : [ SenseInfo('01754876-n', 6) ],
"_invention_n_of_rel" : [ SenseInfo('05633385-n', 6), SenseInfo('03582658-n', 6), SenseInfo('00940412-n', 3) ],
"_baroque_a_1_rel" : [ SenseInfo('01794995-a', 1), SenseInfo('02974023-a', 0) ],
"_modernization_n_of_rel" : [ SenseInfo('00264913-n', 8), SenseInfo('06408990-n', 0) ],
"_advent_n_1_rel" : [ SenseInfo('00048828-n', 1), SenseInfo('15241507-n', 0), SenseInfo('07322550-n', 0) ],
"_unmarked_a_1_rel" : [ SenseInfo('01481135-a', 0), SenseInfo('01608848-a', 0), SenseInfo('01481135-a', 0), SenseInfo('01608848-a', 0) ],
"_biliary_a_1_rel" : [ SenseInfo('02664067-a', 0), SenseInfo('02663950-a', 0) ],
"_kettle_n_1_rel" : [ SenseInfo('03612814-n', 1), SenseInfo('13768154-n', 0), SenseInfo('09325038-n', 0), SenseInfo('03612965-n', 0) ],
"_correspondent_n_1_rel" : [ SenseInfo('09966554-n', 3), SenseInfo('09966710-n', 2) ],
"_parkland_n_1_rel" : [ SenseInfo('08615149-n', 0) ],
"_limitation_n_1_rel" : [ SenseInfo('05846355-n', 3), SenseInfo('05162455-n', 3), SenseInfo('13758296-n', 1), SenseInfo('15224293-n', 0), SenseInfo('00808182-n', 0) ],
"_jumpy_a_1_rel" : [ SenseInfo('02406370-a', 1), SenseInfo('02243567-a', 0) ],
"_rhythm_n_1_rel" : [ SenseInfo('07086518-n', 7), SenseInfo('04768028-n', 6), SenseInfo('15287830-n', 1), SenseInfo('07086323-n', 1), SenseInfo('00853145-n', 1) ],
"_album_n_1_rel" : [ SenseInfo('06591815-n', 2), SenseInfo('02695079-n', 1) ],
"_leave_v_home_rel" : [ SenseInfo('02009433-v', 146), SenseInfo('00613683-v', 63), SenseInfo('02729414-v', 56), SenseInfo('00136991-v', 27), SenseInfo('02015598-v', 20), SenseInfo('02721438-v', 19), SenseInfo('02635659-v', 16), SenseInfo('02383440-v', 14), SenseInfo('02356230-v', 8), SenseInfo('02229055-v', 7), SenseInfo('02730135-v', 5), SenseInfo('00360092-v', 5), SenseInfo('02296153-v', 3), SenseInfo('00613018-v', 3) ],
"_except_v_1_rel" : [ SenseInfo('00807941-v', 1), SenseInfo('00615774-v', 1) ],
"_bile_n_1_rel" : [ SenseInfo('05406570-n', 1) ],
"_belt_v_out_rel" : [ SenseInfo('01704030-v', 1), SenseInfo('01415162-v', 1), SenseInfo('01366061-v', 0) ],
"_i+e_p_rel" : [ SenseInfo('06571538-n', 0), SenseInfo('00191579-r', 0), SenseInfo('06571538-n', 0), SenseInfo('00191579-r', 0), SenseInfo('06571538-n', 0), SenseInfo('00191579-r', 0), SenseInfo('06571538-n', 0), SenseInfo('00191579-r', 0), SenseInfo('06571538-n', 0), SenseInfo('00191579-r', 0), SenseInfo('06571538-n', 0), SenseInfo('00191579-r', 0), SenseInfo('06571538-n', 0), SenseInfo('00191579-r', 0), SenseInfo('06571538-n', 0), SenseInfo('00191579-r', 0), SenseInfo('06571538-n', 0), SenseInfo('00191579-r', 0), SenseInfo('06571538-n', 0), SenseInfo('00191579-r', 0), SenseInfo('06571538-n', 0), SenseInfo('00191579-r', 0), SenseInfo('06571538-n', 0), SenseInfo('00191579-r', 0), SenseInfo('06571538-n', 0), SenseInfo('00191579-r', 0), SenseInfo('06571538-n', 0), SenseInfo('00191579-r', 0), SenseInfo('06571538-n', 0), SenseInfo('00191579-r', 0), SenseInfo('06571538-n', 0), SenseInfo('00191579-r', 0), SenseInfo('06571538-n', 0), SenseInfo('00191579-r', 0), SenseInfo('06571538-n', 0), SenseInfo('00191579-r', 0), SenseInfo('06571538-n', 0), SenseInfo('00191579-r', 0), SenseInfo('06571538-n', 0), SenseInfo('00191579-r', 0), SenseInfo('06571538-n', 0), SenseInfo('00191579-r', 0), SenseInfo('06571538-n', 0), SenseInfo('00191579-r', 0), SenseInfo('06571538-n', 0), SenseInfo('00191579-r', 0), SenseInfo('06571538-n', 0), SenseInfo('00191579-r', 0) ],
"_cordless_a_1_rel" : [ SenseInfo('02703911-a', 0) ],
"_suppose_v_1_rel" : [ SenseInfo('00917300-v', 34), SenseInfo('00631737-v', 31), SenseInfo('00633443-v', 17), SenseInfo('00716531-v', 0), SenseInfo('00716345-v', 0), SenseInfo('00917300-v', 34), SenseInfo('00631737-v', 31), SenseInfo('00633443-v', 17), SenseInfo('00716531-v', 0), SenseInfo('00716345-v', 0), SenseInfo('00917300-v', 34), SenseInfo('00631737-v', 31), SenseInfo('00633443-v', 17), SenseInfo('00716531-v', 0), SenseInfo('00716345-v', 0), SenseInfo('00917300-v', 34), SenseInfo('00631737-v', 31), SenseInfo('00633443-v', 17), SenseInfo('00716531-v', 0), SenseInfo('00716345-v', 0), SenseInfo('00917300-v', 34), SenseInfo('00631737-v', 31), SenseInfo('00633443-v', 17), SenseInfo('00716531-v', 0), SenseInfo('00716345-v', 0), SenseInfo('00917300-v', 34), SenseInfo('00631737-v', 31), SenseInfo('00633443-v', 17), SenseInfo('00716531-v', 0), SenseInfo('00716345-v', 0), SenseInfo('00917300-v', 34), SenseInfo('00631737-v', 31), SenseInfo('00633443-v', 17), SenseInfo('00716531-v', 0), SenseInfo('00716345-v', 0), SenseInfo('00917300-v', 34), SenseInfo('00631737-v', 31), SenseInfo('00633443-v', 17), SenseInfo('00716531-v', 0), SenseInfo('00716345-v', 0), SenseInfo('00917300-v', 34), SenseInfo('00631737-v', 31), SenseInfo('00633443-v', 17), SenseInfo('00716531-v', 0), SenseInfo('00716345-v', 0) ],
"_suspicion_n_1_rel" : [ SenseInfo('05919034-n', 11), SenseInfo('05698791-n', 2), SenseInfo('13982839-n', 0), SenseInfo('04895979-n', 0), SenseInfo('05919034-n', 11), SenseInfo('05698791-n', 2), SenseInfo('13982839-n', 0), SenseInfo('04895979-n', 0) ],
"_barbarism_n_1_rel" : [ SenseInfo('00424934-n', 0) ],
"_easy_a_for_rel" : [ SenseInfo('00749230-a', 62), SenseInfo('01272176-a', 4), SenseInfo('00822115-a', 1), SenseInfo('01808139-a', 1), SenseInfo('01192035-a', 1), SenseInfo('02364721-a', 0), SenseInfo('02022556-a', 0), SenseInfo('01144571-a', 0), SenseInfo('00477553-a', 0), SenseInfo('00361837-a', 0), SenseInfo('00184075-a', 0), SenseInfo('00015097-a', 0), SenseInfo('00749230-a', 62), SenseInfo('01272176-a', 4), SenseInfo('00822115-a', 1), SenseInfo('01808139-a', 1), SenseInfo('01192035-a', 1), SenseInfo('02364721-a', 0), SenseInfo('02022556-a', 0), SenseInfo('01144571-a', 0), SenseInfo('00477553-a', 0), SenseInfo('00361837-a', 0), SenseInfo('00184075-a', 0), SenseInfo('00015097-a', 0), SenseInfo('00749230-a', 62), SenseInfo('01272176-a', 4), SenseInfo('00822115-a', 1), SenseInfo('01808139-a', 1), SenseInfo('01192035-a', 1), SenseInfo('02364721-a', 0), SenseInfo('02022556-a', 0), SenseInfo('01144571-a', 0), SenseInfo('00477553-a', 0), SenseInfo('00361837-a', 0), SenseInfo('00184075-a', 0), SenseInfo('00015097-a', 0), SenseInfo('00749230-a', 62), SenseInfo('01272176-a', 4), SenseInfo('00822115-a', 1), SenseInfo('01808139-a', 1), SenseInfo('01192035-a', 1), SenseInfo('02364721-a', 0), SenseInfo('02022556-a', 0), SenseInfo('01144571-a', 0), SenseInfo('00477553-a', 0), SenseInfo('00361837-a', 0), SenseInfo('00184075-a', 0), SenseInfo('00015097-a', 0), SenseInfo('00749230-a', 62), SenseInfo('01272176-a', 4), SenseInfo('00822115-a', 1), SenseInfo('01808139-a', 1), SenseInfo('01192035-a', 1), SenseInfo('02364721-a', 0), SenseInfo('02022556-a', 0), SenseInfo('01144571-a', 0), SenseInfo('00477553-a', 0), SenseInfo('00361837-a', 0), SenseInfo('00184075-a', 0), SenseInfo('00015097-a', 0), SenseInfo('00749230-a', 62), SenseInfo('01272176-a', 4), SenseInfo('00822115-a', 1), SenseInfo('01808139-a', 1), SenseInfo('01192035-a', 1), SenseInfo('02364721-a', 0), SenseInfo('02022556-a', 0), SenseInfo('01144571-a', 0), SenseInfo('00477553-a', 0), SenseInfo('00361837-a', 0), SenseInfo('00184075-a', 0), SenseInfo('00015097-a', 0), SenseInfo('00749230-a', 62), SenseInfo('01272176-a', 4), SenseInfo('00822115-a', 1), SenseInfo('01808139-a', 1), SenseInfo('01192035-a', 1), SenseInfo('02364721-a', 0), SenseInfo('02022556-a', 0), SenseInfo('01144571-a', 0), SenseInfo('00477553-a', 0), SenseInfo('00361837-a', 0), SenseInfo('00184075-a', 0), SenseInfo('00015097-a', 0) ],
"_hector_v_1_rel" : [ SenseInfo('01781520-v', 0) ],
"_pull_v_on_rel" : [ SenseInfo('01448100-v', 44), SenseInfo('01505254-v', 8), SenseInfo('02057499-v', 6), SenseInfo('01609287-v', 3), SenseInfo('02582615-v', 2), SenseInfo('01995211-v', 2), SenseInfo('02057337-v', 1), SenseInfo('00071803-v', 1), SenseInfo('02103162-v', 0), SenseInfo('01947247-v', 0), SenseInfo('01858573-v', 0), SenseInfo('01573276-v', 0), SenseInfo('01407059-v', 0), SenseInfo('01384275-v', 0), SenseInfo('01351170-v', 0), SenseInfo('01148710-v', 0), SenseInfo('00571596-v', 0) ],
"_pastel_a_1_rel" : [ SenseInfo('00707087-a', 1), SenseInfo('00409207-a', 1) ],
"_citizen_n_1_rel" : [ SenseInfo('09923673-n', 29) ],
"_align_v_cause_rel" : [ SenseInfo('00464321-v', 2), SenseInfo('02658867-v', 1), SenseInfo('00733632-v', 1), SenseInfo('00466053-v', 0) ],
"_trade_n_of-with_rel" : [ SenseInfo('01091905-n', 16), SenseInfo('00606370-n', 16), SenseInfo('01096454-n', 6), SenseInfo('01110274-n', 3), SenseInfo('08436562-n', 2), SenseInfo('11519949-n', 0), SenseInfo('01109687-n', 0), SenseInfo('01091905-n', 16), SenseInfo('00606370-n', 16), SenseInfo('01096454-n', 6), SenseInfo('01110274-n', 3), SenseInfo('08436562-n', 2), SenseInfo('11519949-n', 0), SenseInfo('01109687-n', 0) ],
"_orchestra_n_1_rel" : [ SenseInfo('08248157-n', 10), SenseInfo('03853178-n', 1) ],
"_approximate_v_1_rel" : [ SenseInfo('02666060-v', 5), SenseInfo('00672433-v', 2) ],
"_suffocate_v_cause_rel" : [ SenseInfo('01569181-v', 3), SenseInfo('01476180-v', 0), SenseInfo('00391203-v', 0), SenseInfo('00391021-v', 0), SenseInfo('00359511-v', 0), SenseInfo('00106412-v', 0), SenseInfo('00077698-v', 0) ],
"_sacred_a_1_rel" : [ SenseInfo('02055062-a', 4), SenseInfo('02587261-a', 1), SenseInfo('02054310-a', 1), SenseInfo('02054610-a', 0), SenseInfo('00519823-a', 0) ],
"_atheist_n_1_rel" : [ SenseInfo('09820044-n', 1) ],
"_show_v_through_rel" : [ SenseInfo('02148788-v', 136), SenseInfo('00664788-v', 63), SenseInfo('01015244-v', 57), SenseInfo('02137132-v', 43), SenseInfo('01686956-v', 32), SenseInfo('00943837-v', 24), SenseInfo('00923793-v', 24), SenseInfo('02139544-v', 11), SenseInfo('00922867-v', 7), SenseInfo('00923307-v', 6), SenseInfo('02000547-v', 2), SenseInfo('01086549-v', 0) ],
"_pheasant_n_1_rel" : [ SenseInfo('01803078-n', 2), SenseInfo('07647602-n', 0) ],
"_compress_n_1_rel" : [ SenseInfo('03082450-n', 2) ],
"_print_v_out_rel" : [ SenseInfo('01745722-v', 12), SenseInfo('01746715-v', 1), SenseInfo('01749184-v', 0), SenseInfo('01747945-v', 0) ],
"_pants_n_1_rel" : [ SenseInfo('07388706-n', 0), SenseInfo('04489008-n', 0), SenseInfo('00837098-n', 0), SenseInfo('07388706-n', 0), SenseInfo('04489008-n', 0), SenseInfo('00837098-n', 0) ],
"_divorce_v_1_rel" : [ SenseInfo('02430580-v', 4), SenseInfo('02490634-v', 2) ],
"_psst_a_1_rel" : [  ],
"_nutrient_n_1_rel" : [ SenseInfo('00021265-n', 1), SenseInfo('00021734-n', 0), SenseInfo('00021265-n', 1), SenseInfo('00021734-n', 0), SenseInfo('00021265-n', 1), SenseInfo('00021734-n', 0) ],
"_dazzle_n_1_rel" : [ SenseInfo('04952821-n', 0) ],
"_let_v_1_rel" : [ SenseInfo('02423183-v', 219), SenseInfo('00771490-v', 15), SenseInfo('00802318-v', 2), SenseInfo('00120796-v', 2), SenseInfo('00496673-v', 1), SenseInfo('02208903-v', 0), SenseInfo('02423183-v', 219), SenseInfo('00771490-v', 15), SenseInfo('00802318-v', 2), SenseInfo('00120796-v', 2), SenseInfo('00496673-v', 1), SenseInfo('02208903-v', 0), SenseInfo('02423183-v', 219), SenseInfo('00771490-v', 15), SenseInfo('00802318-v', 2), SenseInfo('00120796-v', 2), SenseInfo('00496673-v', 1), SenseInfo('02208903-v', 0) ],
"_fir_n_1_rel" : [ SenseInfo('11620912-n', 0), SenseInfo('11620673-n', 0) ],
"_kind_a_of_rel" : [ SenseInfo('01372049-a', 4), SenseInfo('01242282-a', 0), SenseInfo('01041209-a', 0), SenseInfo('01372049-a', 4), SenseInfo('01242282-a', 0), SenseInfo('01041209-a', 0), SenseInfo('01372049-a', 4), SenseInfo('01242282-a', 0), SenseInfo('01041209-a', 0), SenseInfo('01372049-a', 4), SenseInfo('01242282-a', 0), SenseInfo('01041209-a', 0), SenseInfo('01372049-a', 4), SenseInfo('01242282-a', 0), SenseInfo('01041209-a', 0), SenseInfo('01372049-a', 4), SenseInfo('01242282-a', 0), SenseInfo('01041209-a', 0), SenseInfo('01372049-a', 4), SenseInfo('01242282-a', 0), SenseInfo('01041209-a', 0) ],
"_drill_v_1_rel" : [ SenseInfo('01443021-v', 21), SenseInfo('00603981-v', 5), SenseInfo('00606093-v', 1), SenseInfo('00606335-v', 0), SenseInfo('00604094-v', 0) ],
"_galore_a_1_rel" : [ SenseInfo('01552162-a', 0), SenseInfo('00014358-a', 0) ],
"_up+for+grabs_a_1_rel" : [  ],
"_momentum_n_1_rel" : [ SenseInfo('05035820-n', 7), SenseInfo('05029137-n', 2) ],
"_fare_n_1_rel" : [ SenseInfo('05911124-n', 2), SenseInfo('13308147-n', 0), SenseInfo('10078643-n', 0), SenseInfo('07560652-n', 0) ],
"_shipbuilding_n_1_rel" : [ SenseInfo('00912822-n', 1) ],
"_spreadsheet_n_1_rel" : [ SenseInfo('06579952-n', 0) ],
"_wasteful_a_1_rel" : [ SenseInfo('00841159-a', 2), SenseInfo('02422068-a', 0), SenseInfo('00588655-a', 0) ],
"_rip_n_1_rel" : [ SenseInfo('10505942-n', 0), SenseInfo('09410928-n', 0), SenseInfo('07404584-n', 0), SenseInfo('00391407-n', 0) ],
"_unusually_x_deg_rel" : [ SenseInfo('00107230-r', 3) ],
"_express_n_1_rel" : [ SenseInfo('06265475-n', 0), SenseInfo('03306385-n', 0), SenseInfo('01106460-n', 0) ],
"_include_v_1_rel" : [ SenseInfo('02632940-v', 234), SenseInfo('00684838-v', 32), SenseInfo('00183879-v', 18), SenseInfo('02449847-v', 8), SenseInfo('02632940-v', 234), SenseInfo('00684838-v', 32), SenseInfo('00183879-v', 18), SenseInfo('02449847-v', 8), SenseInfo('02632940-v', 234), SenseInfo('00684838-v', 32), SenseInfo('00183879-v', 18), SenseInfo('02449847-v', 8) ],
"_unknowing_a_1_rel" : [ SenseInfo('01308894-a', 0) ],
"_leaflet_n_1_rel" : [ SenseInfo('05389625-n', 1), SenseInfo('13154077-n', 0), SenseInfo('06413889-n', 0) ],
"_russophile_n_1_rel" : [  ],
"_come_v_over_rel" : [ SenseInfo('01849221-v', 276), SenseInfo('02005948-v', 235), SenseInfo('00341917-v', 147), SenseInfo('00542120-v', 41), SenseInfo('02625339-v', 40), SenseInfo('00342812-v', 11), SenseInfo('02743921-v', 9), SenseInfo('02743214-v', 7), SenseInfo('02686805-v', 6), SenseInfo('02743565-v', 3), SenseInfo('01839690-v', 3), SenseInfo('02729963-v', 2), SenseInfo('00344886-v', 2), SenseInfo('02645007-v', 1), SenseInfo('02627363-v', 1), SenseInfo('02006709-v', 1), SenseInfo('00723349-v', 1), SenseInfo('02737187-v', 0), SenseInfo('02617567-v', 0), SenseInfo('02197360-v', 0), SenseInfo('00659984-v', 0) ],
"_sincere_a_1_rel" : [ SenseInfo('02179279-a', 6), SenseInfo('02118840-a', 0), SenseInfo('02179279-a', 6), SenseInfo('02118840-a', 0), SenseInfo('02179279-a', 6), SenseInfo('02118840-a', 0), SenseInfo('02179279-a', 6), SenseInfo('02118840-a', 0) ],
"_impudent_a_1_rel" : [ SenseInfo('01996051-a', 2), SenseInfo('00205295-a', 1), SenseInfo('01996051-a', 2), SenseInfo('00205295-a', 1) ],
"_grassland_n_1_rel" : [ SenseInfo('08598301-n', 0) ],
"_sadden_v_1_rel" : [ SenseInfo('01813053-v', 1), SenseInfo('01813393-v', 0) ],
"_knuckle_v_under_rel" : [ SenseInfo('01605291-v', 0), SenseInfo('01605169-v', 0) ],
"_repayment_n_of_rel" : [ SenseInfo('01121690-n', 1), SenseInfo('13299651-n', 0) ],
"_curse_v_1_rel" : [ SenseInfo('00865387-v', 17), SenseInfo('00866314-v', 10), SenseInfo('00865958-v', 2), SenseInfo('01030397-v', 0) ],
"_salary_n_1_rel" : [ SenseInfo('13279262-n', 10) ],
"_gobble_v_up_rel" : [ SenseInfo('01173933-v', 2), SenseInfo('01058426-v', 1) ],
"_counter+narcotics_a_1_rel" : [  ],
"_unsubscribe_v_1_rel" : [  ],
"_blare_n_1_rel" : [ SenseInfo('07377473-n', 1) ],
"_seclude_v_1_rel" : [ SenseInfo('00495998-v', 1) ],
"_robin_n_1_rel" : [ SenseInfo('01562265-n', 0), SenseInfo('01558993-n', 0) ],
"_abuse_n_of_rel" : [ SenseInfo('00419908-n', 1), SenseInfo('06715223-n', 0), SenseInfo('00947719-n', 0) ],
"_morbid_a_1_rel" : [ SenseInfo('02559862-a', 0), SenseInfo('01626440-a', 0), SenseInfo('01176246-a', 0) ],
"_mini+disc_n_1_rel" : [  ],
"_state+of+the+art_a_1_rel" : [ SenseInfo('01876780-a', 0), SenseInfo('01876780-a', 0) ],
"_reply_n_of_rel" : [ SenseInfo('06746005-n', 21), SenseInfo('07199565-n', 2), SenseInfo('06746005-n', 21), SenseInfo('07199565-n', 2) ],
"_cure_n_1_rel" : [ SenseInfo('04074482-n', 8) ],
"_launch_v_1_rel" : [ SenseInfo('02427103-v', 10), SenseInfo('01514655-v', 6), SenseInfo('01515415-v', 4), SenseInfo('00347918-v', 2), SenseInfo('01515196-v', 0), SenseInfo('01253363-v', 0) ],
"_limonite_n_1_rel" : [ SenseInfo('14937801-n', 0) ],
"_illustrative_a_1_rel" : [ SenseInfo('01305123-a', 2), SenseInfo('01323962-a', 0) ],
"little-few_a_rel" : [  ],
"_lid_n_1_rel" : [ SenseInfo('05313822-n', 4), SenseInfo('03661340-n', 0), SenseInfo('03497657-n', 0) ],
"_evolve_v_1_rel" : [ SenseInfo('01738597-v', 3), SenseInfo('00251064-v', 3), SenseInfo('00545557-v', 1) ],
"_mountain_n_1_rel" : [ SenseInfo('09359803-n', 17), SenseInfo('13774404-n', 0), SenseInfo('09359803-n', 17), SenseInfo('13774404-n', 0) ],
"_communal_a_1_rel" : [ SenseInfo('00493012-a', 2), SenseInfo('02700918-a', 1), SenseInfo('00493012-a', 2), SenseInfo('02700918-a', 1) ],
"_accompany_v_1_rel" : [ SenseInfo('02716165-v', 20), SenseInfo('02025550-v', 8), SenseInfo('01728355-v', 3), SenseInfo('02716767-v', 1) ],
"_sicken_v_cause_rel" : [ SenseInfo('01808374-v', 2), SenseInfo('00087454-v', 1), SenseInfo('02195191-v', 0), SenseInfo('00088209-v', 0) ],
"_messed+up_a_1_rel" : [  ],
"_collective_n_1_rel" : [ SenseInfo('08056601-n', 1) ],
"_residence_n_1_rel" : [ SenseInfo('08558963-n', 11), SenseInfo('04079244-n', 2), SenseInfo('01053920-n', 2), SenseInfo('03719053-n', 1), SenseInfo('08558963-n', 11), SenseInfo('04079244-n', 2), SenseInfo('01053920-n', 2), SenseInfo('03719053-n', 1) ],
"_junk_n_1_rel" : [ SenseInfo('14857897-n', 1), SenseInfo('03603594-n', 0) ],
"_braid_n_1_rel" : [ SenseInfo('05259512-n', 1), SenseInfo('02889035-n', 0) ],
"_obligation_n_1_rel" : [ SenseInfo('01129920-n', 14), SenseInfo('14490110-n', 1), SenseInfo('13782033-n', 0), SenseInfo('13398241-n', 0), SenseInfo('06773150-n', 0), SenseInfo('01129920-n', 14), SenseInfo('14490110-n', 1), SenseInfo('13782033-n', 0), SenseInfo('13398241-n', 0), SenseInfo('06773150-n', 0) ],
"_dorm_n_1_rel" : [ SenseInfo('03224893-n', 0) ],
"_shovel_n_1_rel" : [ SenseInfo('04208210-n', 2), SenseInfo('13769870-n', 0), SenseInfo('04208427-n', 0), SenseInfo('03996416-n', 0) ],
"_steal_v_from_rel" : [ SenseInfo('02321757-v', 23), SenseInfo('01888295-v', 4), SenseInfo('01111458-v', 3), SenseInfo('02321757-v', 23), SenseInfo('01888295-v', 4), SenseInfo('01111458-v', 3) ],
"_proceeds_n_1_rel" : [ SenseInfo('13260190-n', 3), SenseInfo('13260190-n', 3) ],
"_cream_a_1_rel" : [ SenseInfo('08387035-n', 2), SenseInfo('07847198-n', 0), SenseInfo('03128519-n', 0) ],
"_silverwork_n_1_rel" : [ SenseInfo('04221586-n', 0) ],
"_telling_a_for_rel" : [ SenseInfo('01305344-a', 1), SenseInfo('01770392-a', 0), SenseInfo('00835292-a', 0), SenseInfo('01305344-a', 1), SenseInfo('01770392-a', 0), SenseInfo('00835292-a', 0), SenseInfo('01305344-a', 1), SenseInfo('01770392-a', 0), SenseInfo('00835292-a', 0) ],
"_breakup_n_1_rel" : [ SenseInfo('00215314-n', 2), SenseInfo('07331400-n', 1), SenseInfo('00215314-n', 2), SenseInfo('07331400-n', 1), SenseInfo('00215314-n', 2), SenseInfo('07331400-n', 1) ],
"_electrode_n_1_rel" : [ SenseInfo('03274796-n', 3) ],
"_truss_v_up_rel" : [ SenseInfo('01287797-v', 0), SenseInfo('01286913-v', 0), SenseInfo('01219397-v', 0) ],
"_formation_n_of_rel" : [ SenseInfo('08426461-n', 7), SenseInfo('00925207-n', 4), SenseInfo('00237078-n', 4), SenseInfo('09287968-n', 3), SenseInfo('03385117-n', 3), SenseInfo('13483488-n', 0), SenseInfo('00927516-n', 0) ],
"_border_v_1_rel" : [ SenseInfo('01467370-v', 3), SenseInfo('02710673-v', 1), SenseInfo('01586850-v', 1), SenseInfo('02361600-v', 0), SenseInfo('01466978-v', 0) ],
"_basement_n_1_rel" : [ SenseInfo('02800497-n', 18), SenseInfo('02800675-n', 0) ],
"_ruby_n_1_rel" : [ SenseInfo('13372262-n', 1), SenseInfo('15008142-n', 0), SenseInfo('04963588-n', 0) ],
"_backpacker_n_1_rel" : [ SenseInfo('09830629-n', 0) ],
"_diskette_n_1_rel" : [ SenseInfo('03209910-n', 0) ],
"_community_n_of_rel" : [ SenseInfo('08223802-n', 67), SenseInfo('13240839-n', 4), SenseInfo('08224274-n', 2), SenseInfo('13971382-n', 1), SenseInfo('08553535-n', 0), SenseInfo('07941729-n', 0) ],
"_won_n_1_rel" : [ SenseInfo('13709360-n', 0), SenseInfo('13708992-n', 0) ],
"_behalf_n_1_rel" : [ SenseInfo('00721660-n', 4), SenseInfo('05143300-n', 2) ],
"_lettings_n_1_rel" : [ SenseInfo('13248393-n', 0), SenseInfo('13248393-n', 0) ],
"_plaque_n_1_rel" : [ SenseInfo('05244239-n', 2), SenseInfo('02892201-n', 1) ],
"_meaty_a_1_rel" : [ SenseInfo('01499457-a', 1), SenseInfo('01497245-a', 0) ],
"_forecaster_n_1_rel" : [ SenseInfo('10102506-n', 0) ],
"_tad_n_1_rel" : [ SenseInfo('13763185-n', 0) ],
"_nanometer_n_1_rel" : [ SenseInfo('13658278-n', 0), SenseInfo('13658278-n', 0), SenseInfo('13658278-n', 0), SenseInfo('13658278-n', 0) ],
"_klaxon_n_1_rel" : [ SenseInfo('03622058-n', 0) ],
"_distressingly_x_deg_rel" : [ SenseInfo('00114609-r', 0) ],
"_sequence_n_of_rel" : [ SenseInfo('08459252-n', 13), SenseInfo('05044822-n', 3), SenseInfo('04173172-n', 3), SenseInfo('01010458-n', 3), SenseInfo('07342383-n', 0) ],
"_intolerant_a_of_rel" : [ SenseInfo('02436622-a', 0), SenseInfo('00288237-a', 0) ],
"_blow_v_out_rel" : [ SenseInfo('00007012-v', 6), SenseInfo('02769241-v', 5), SenseInfo('00034948-v', 3), SenseInfo('01902783-v', 2), SenseInfo('02135877-v', 1), SenseInfo('00477247-v', 1), SenseInfo('02527651-v', 0), SenseInfo('02268351-v', 0), SenseInfo('02266148-v', 0), SenseInfo('02178340-v', 0), SenseInfo('02135727-v', 0), SenseInfo('02117170-v', 0), SenseInfo('02101046-v', 0), SenseInfo('02100632-v', 0), SenseInfo('02068745-v', 0), SenseInfo('01849054-v', 0), SenseInfo('01545208-v', 0), SenseInfo('00934965-v', 0), SenseInfo('00883226-v', 0), SenseInfo('00779804-v', 0), SenseInfo('00435294-v', 0), SenseInfo('00310155-v', 0) ],
"_solo_n_1_rel" : [ SenseInfo('01257418-n', 1), SenseInfo('07040939-n', 0), SenseInfo('00304729-n', 0) ],
"_combat_v_1_rel" : [ SenseInfo('01092366-v', 7) ],
"_busbar_n_1_rel" : [ SenseInfo('02924713-n', 0) ],
"_hard-to-use_a_1_rel" : [  ],
"_build_n_1_rel" : [ SenseInfo('04998530-n', 2), SenseInfo('05217168-n', 0) ],
"_knock_v_up_rel" : [ SenseInfo('01238640-v', 7), SenseInfo('01414467-v', 6), SenseInfo('01239619-v', 4), SenseInfo('02185373-v', 0), SenseInfo('02178866-v', 0), SenseInfo('00826509-v', 0) ],
"_declining_a_1_rel" : [  ],
"_fond_a_of_rel" : [ SenseInfo('01464700-a', 3), SenseInfo('01464433-a', 1), SenseInfo('01292683-a', 1), SenseInfo('02571903-a', 0) ],
"_wearer_n_1_rel" : [ SenseInfo('10771809-n', 1) ],
"_hydrobiology_n_1_rel" : [  ],
"_greenhouse_n_1_rel" : [ SenseInfo('03457902-n', 1) ],
"_fuck_v_up_rel" : [ SenseInfo('01426397-v', 0), SenseInfo('01426397-v', 0) ],
"_arrange_v_1_rel" : [ SenseInfo('01463963-v', 13), SenseInfo('01021629-v', 7), SenseInfo('01648126-v', 3), SenseInfo('01745141-v', 2), SenseInfo('00038849-v', 2), SenseInfo('01706129-v', 0), SenseInfo('00735571-v', 0), SenseInfo('01463963-v', 13), SenseInfo('01021629-v', 7), SenseInfo('01648126-v', 3), SenseInfo('01745141-v', 2), SenseInfo('00038849-v', 2), SenseInfo('01706129-v', 0), SenseInfo('00735571-v', 0), SenseInfo('01463963-v', 13), SenseInfo('01021629-v', 7), SenseInfo('01648126-v', 3), SenseInfo('01745141-v', 2), SenseInfo('00038849-v', 2), SenseInfo('01706129-v', 0), SenseInfo('00735571-v', 0) ],
"_insulate_v_1_rel" : [ SenseInfo('00495038-v', 2), SenseInfo('00494269-v', 2) ],
"_cajole_v_1_rel" : [ SenseInfo('00768778-v', 0), SenseInfo('00768778-v', 0) ],
"_nature_n_1_rel" : [ SenseInfo('04726724-n', 41), SenseInfo('09503682-n', 12), SenseInfo('09366762-n', 9), SenseInfo('04623113-n', 3), SenseInfo('05840431-n', 0), SenseInfo('04726724-n', 41), SenseInfo('09503682-n', 12), SenseInfo('09366762-n', 9), SenseInfo('04623113-n', 3), SenseInfo('05840431-n', 0) ],
"_litharge_n_1_rel" : [  ],
"_hinge_v_1_rel" : [ SenseInfo('01297174-v', 0) ],
"_carnivor_n_1_rel" : [  ],
"_embassy_n_1_rel" : [ SenseInfo('03282295-n', 1), SenseInfo('08402828-n', 0) ],
"_vietnamese_a_1_rel" : [ SenseInfo('03129222-a', 0) ],
"_too_x_comp_rel" : [ SenseInfo('00047392-r', 180), SenseInfo('00047534-r', 117) ],
"_pinhead_n_1_rel" : [ SenseInfo('10039391-n', 0), SenseInfo('03942920-n', 0) ],
"_goalgetter_n_1_rel" : [  ],
"_real+language_n_1_rel" : [  ],
"_environmental_a_1_rel" : [ SenseInfo('02943303-a', 1), SenseInfo('02943151-a', 0), SenseInfo('02943303-a', 1), SenseInfo('02943151-a', 0) ],
"_volleyball_n_1_rel" : [ SenseInfo('00480211-n', 1), SenseInfo('04540053-n', 0) ],
"_r2_n_1_rel" : [  ],
"_triviality_n_1_rel" : [ SenseInfo('05173205-n', 1), SenseInfo('05820462-n', 0), SenseInfo('04486445-n', 0) ],
"_a+half_x_rel" : [  ],
"_burglary_n_of_rel" : [ SenseInfo('00785045-n', 2) ],
"_palatalization_n_1_rel" : [  ],
"_typical_a_1_rel" : [ SenseInfo('02468635-a', 26), SenseInfo('00357556-a', 2), SenseInfo('01595440-a', 0) ],
"_pass_v_on_rel" : [ SenseInfo('02050132-v', 32), SenseInfo('02051694-v', 31), SenseInfo('02466670-v', 29), SenseInfo('02072849-v', 17), SenseInfo('02230772-v', 13), SenseInfo('02685951-v', 8), SenseInfo('02049696-v', 8), SenseInfo('00339934-v', 7), SenseInfo('02523351-v', 4), SenseInfo('02708420-v', 3), SenseInfo('01212230-v', 3), SenseInfo('00742320-v', 3), SenseInfo('00421691-v', 3), SenseInfo('02525044-v', 2), SenseInfo('02669081-v', 1), SenseInfo('02523953-v', 1), SenseInfo('02423513-v', 1), SenseInfo('02221635-v', 1), SenseInfo('01972131-v', 1), SenseInfo('02231473-v', 0), SenseInfo('02229550-v', 0), SenseInfo('02052476-v', 0), SenseInfo('00803325-v', 0), SenseInfo('00358431-v', 0), SenseInfo('00072989-v', 0), SenseInfo('02050132-v', 32), SenseInfo('02051694-v', 31), SenseInfo('02466670-v', 29), SenseInfo('02072849-v', 17), SenseInfo('02230772-v', 13), SenseInfo('02685951-v', 8), SenseInfo('02049696-v', 8), SenseInfo('00339934-v', 7), SenseInfo('02523351-v', 4), SenseInfo('02708420-v', 3), SenseInfo('01212230-v', 3), SenseInfo('00742320-v', 3), SenseInfo('00421691-v', 3), SenseInfo('02525044-v', 2), SenseInfo('02669081-v', 1), SenseInfo('02523953-v', 1), SenseInfo('02423513-v', 1), SenseInfo('02221635-v', 1), SenseInfo('01972131-v', 1), SenseInfo('02231473-v', 0), SenseInfo('02229550-v', 0), SenseInfo('02052476-v', 0), SenseInfo('00803325-v', 0), SenseInfo('00358431-v', 0), SenseInfo('00072989-v', 0) ],
"_experiment_n_1_rel" : [ SenseInfo('00639556-n', 59), SenseInfo('05798043-n', 12), SenseInfo('00785959-n', 7) ],
"_bash_v_1_rel" : [ SenseInfo('01397088-v', 0) ],
"_doctor_v_1_rel" : [ SenseInfo('00488430-v', 1), SenseInfo('00080304-v', 1), SenseInfo('00260648-v', 0) ],
"_inspect_v_1_rel" : [ SenseInfo('02165543-v', 13), SenseInfo('01844048-v', 1), SenseInfo('00697062-v', 0) ],
"_premises_n_1_rel" : [ SenseInfo('06753800-n', 1), SenseInfo('06753800-n', 1), SenseInfo('06753800-n', 1) ],
"_lounge_n_1_rel" : [ SenseInfo('04256520-n', 0), SenseInfo('03691817-n', 0) ],
"_slam_v_cause_rel" : [ SenseInfo('01242832-v', 8), SenseInfo('01242391-v', 8), SenseInfo('01897885-v', 0), SenseInfo('01242689-v', 0) ],
"_negatory_a_1_rel" : [  ],
"_patter_v_1_rel" : [ SenseInfo('02757828-v', 0), SenseInfo('02185187-v', 0) ],
"_availability_n_1_rel" : [ SenseInfo('04718999-n', 3) ],
"_scrutinize_v_1_rel" : [ SenseInfo('02153387-v', 6), SenseInfo('00697062-v', 0) ],
"_ancestor_n_1_rel" : [ SenseInfo('09792555-n', 2) ],
"_interrogate_v_1_rel" : [ SenseInfo('00973530-v', 0), SenseInfo('00788184-v', 0) ],
"_back+order_v_1_rel" : [  ],
"_incalculable_a_1_rel" : [ SenseInfo('00301777-a', 1) ],
"_unable_a_1_rel" : [ SenseInfo('00002098-a', 20), SenseInfo('00307794-a', 5), SenseInfo('01825080-a', 0), SenseInfo('00002098-a', 20), SenseInfo('00307794-a', 5), SenseInfo('01825080-a', 0), SenseInfo('00002098-a', 20), SenseInfo('00307794-a', 5), SenseInfo('01825080-a', 0), SenseInfo('00002098-a', 20), SenseInfo('00307794-a', 5), SenseInfo('01825080-a', 0) ],
"_clown_v_around_rel" : [ SenseInfo('00105778-v', 0) ],
"_down+payment_n_1_rel" : [ SenseInfo('13349834-n', 0), SenseInfo('13349834-n', 0) ],
"_help_v_1_rel" : [ SenseInfo('02547586-v', 183), SenseInfo('00082081-v', 23), SenseInfo('02735897-v', 19), SenseInfo('02726164-v', 5), SenseInfo('01181295-v', 2), SenseInfo('02555434-v', 0), SenseInfo('01193569-v', 0), SenseInfo('00206998-v', 0), SenseInfo('02547586-v', 183), SenseInfo('00082081-v', 23), SenseInfo('02735897-v', 19), SenseInfo('02726164-v', 5), SenseInfo('01181295-v', 2), SenseInfo('02555434-v', 0), SenseInfo('01193569-v', 0), SenseInfo('00206998-v', 0) ],
"_peak_n_1_rel" : [ SenseInfo('13653902-n', 3), SenseInfo('15295045-n', 2), SenseInfo('13940456-n', 2), SenseInfo('08617963-n', 2), SenseInfo('13902482-n', 0), SenseInfo('08677801-n', 0), SenseInfo('02838728-n', 0), SenseInfo('13653902-n', 3), SenseInfo('15295045-n', 2), SenseInfo('13940456-n', 2), SenseInfo('08617963-n', 2), SenseInfo('13902482-n', 0), SenseInfo('08677801-n', 0), SenseInfo('02838728-n', 0), SenseInfo('13653902-n', 3), SenseInfo('15295045-n', 2), SenseInfo('13940456-n', 2), SenseInfo('08617963-n', 2), SenseInfo('13902482-n', 0), SenseInfo('08677801-n', 0), SenseInfo('02838728-n', 0) ],
"_squander_v_1_rel" : [ SenseInfo('02268351-v', 0), SenseInfo('01158181-v', 0) ],
"_to+do+with_p_rel" : [  ],
"_enervating_a_1_rel" : [ SenseInfo('01358096-a', 1) ],
"_lustful_a_1_rel" : [ SenseInfo('02133779-a', 0), SenseInfo('02133207-a', 0), SenseInfo('01727133-a', 0) ],
"_opt_v_out_rel" : [ SenseInfo('00679389-v', 0) ],
"_manager_n_of_rel" : [ SenseInfo('10014939-n', 29), SenseInfo('09931640-n', 21), SenseInfo('10014939-n', 29), SenseInfo('09931640-n', 21) ],
"_charge_v_off_rel" : [ SenseInfo('01121719-v', 16), SenseInfo('00843468-v', 10), SenseInfo('02320374-v', 7), SenseInfo('02055267-v', 6), SenseInfo('02475922-v', 4), SenseInfo('00869931-v', 3), SenseInfo('00843959-v', 3), SenseInfo('01488956-v', 2), SenseInfo('02321046-v', 1), SenseInfo('02348568-v', 0), SenseInfo('02347637-v', 0), SenseInfo('02317289-v', 0), SenseInfo('01985424-v', 0), SenseInfo('01762528-v', 0), SenseInfo('01685960-v', 0), SenseInfo('01490336-v', 0), SenseInfo('01152214-v', 0), SenseInfo('00750532-v', 0), SenseInfo('00750345-v', 0), SenseInfo('00750172-v', 0), SenseInfo('00727991-v', 0), SenseInfo('00700517-v', 0), SenseInfo('00518115-v', 0), SenseInfo('00517847-v', 0), SenseInfo('00498016-v', 0) ],
"_arithmetic_n_1_rel" : [ SenseInfo('06004067-n', 4) ],
"_godhead_n_1_rel" : [ SenseInfo('09536363-n', 0) ],
"_stardom_n_1_rel" : [ SenseInfo('13948766-n', 1) ],
"_soundproof_a_1_rel" : [ SenseInfo('01775420-a', 1) ],
"_regularity_n_1_rel" : [ SenseInfo('05065211-n', 1), SenseInfo('04767347-n', 1) ],
"_holler_n_1_rel" : [ SenseInfo('07121361-n', 1), SenseInfo('09305031-n', 0) ],
"_give_v_yield_rel" : [ SenseInfo('02316868-v', 179), SenseInfo('02339171-v', 160), SenseInfo('02199590-v', 96), SenseInfo('02235842-v', 78), SenseInfo('01060494-v', 32), SenseInfo('01733477-v', 29), SenseInfo('01060317-v', 24), SenseInfo('02200686-v', 20), SenseInfo('01629403-v', 18), SenseInfo('00732224-v', 18), SenseInfo('01629000-v', 16), SenseInfo('02296153-v', 14), SenseInfo('01647672-v', 14), SenseInfo('02200498-v', 12), SenseInfo('02562901-v', 10), SenseInfo('02343595-v', 10), SenseInfo('02230772-v', 10), SenseInfo('00887463-v', 8), SenseInfo('02309374-v', 5), SenseInfo('02309165-v', 5), SenseInfo('01060746-v', 5), SenseInfo('02317094-v', 4), SenseInfo('01848465-v', 4), SenseInfo('01178565-v', 4), SenseInfo('02308741-v', 3), SenseInfo('01989053-v', 1), SenseInfo('00673571-v', 1), SenseInfo('02564052-v', 0), SenseInfo('02359553-v', 0), SenseInfo('02358034-v', 0), SenseInfo('01716283-v', 0), SenseInfo('01716112-v', 0), SenseInfo('01449796-v', 0), SenseInfo('01175810-v', 0), SenseInfo('01069638-v', 0), SenseInfo('00944247-v', 0), SenseInfo('00888009-v', 0), SenseInfo('00878876-v', 0), SenseInfo('00771806-v', 0), SenseInfo('00748972-v', 0), SenseInfo('00748616-v', 0), SenseInfo('00341184-v', 0), SenseInfo('00108747-v', 0), SenseInfo('00108604-v', 0), SenseInfo('02316868-v', 179), SenseInfo('02339171-v', 160), SenseInfo('02199590-v', 96), SenseInfo('02235842-v', 78), SenseInfo('01060494-v', 32), SenseInfo('01733477-v', 29), SenseInfo('01060317-v', 24), SenseInfo('02200686-v', 20), SenseInfo('01629403-v', 18), SenseInfo('00732224-v', 18), SenseInfo('01629000-v', 16), SenseInfo('02296153-v', 14), SenseInfo('01647672-v', 14), SenseInfo('02200498-v', 12), SenseInfo('02562901-v', 10), SenseInfo('02343595-v', 10), SenseInfo('02230772-v', 10), SenseInfo('00887463-v', 8), SenseInfo('02309374-v', 5), SenseInfo('02309165-v', 5), SenseInfo('01060746-v', 5), SenseInfo('02317094-v', 4), SenseInfo('01848465-v', 4), SenseInfo('01178565-v', 4), SenseInfo('02308741-v', 3), SenseInfo('01989053-v', 1), SenseInfo('00673571-v', 1), SenseInfo('02564052-v', 0), SenseInfo('02359553-v', 0), SenseInfo('02358034-v', 0), SenseInfo('01716283-v', 0), SenseInfo('01716112-v', 0), SenseInfo('01449796-v', 0), SenseInfo('01175810-v', 0), SenseInfo('01069638-v', 0), SenseInfo('00944247-v', 0), SenseInfo('00888009-v', 0), SenseInfo('00878876-v', 0), SenseInfo('00771806-v', 0), SenseInfo('00748972-v', 0), SenseInfo('00748616-v', 0), SenseInfo('00341184-v', 0), SenseInfo('00108747-v', 0), SenseInfo('00108604-v', 0) ],
"_more+or+less_a_1_rel" : [  ],
"_flurried_a_1_rel" : [  ],
"_lease_n_1_rel" : [ SenseInfo('13248393-n', 1), SenseInfo('06523132-n', 1), SenseInfo('15274863-n', 0) ],
"_eco-friendly_a_1_rel" : [  ],
"_caricature_n_1_rel" : [ SenseInfo('06780069-n', 0) ],
"_hunch_v_up_rel" : [ SenseInfo('02035559-v', 2) ],
"_archaeological_a_1_rel" : [ SenseInfo('02638392-a', 0) ],
"_canyon_n_1_rel" : [ SenseInfo('09233446-n', 5) ],
"_footbridge_n_1_rel" : [ SenseInfo('03379828-n', 1) ],
"_disk_v_1_rel" : [ SenseInfo('01742415-v', 1) ],
"_disapprove_v_1_rel" : [ SenseInfo('00674340-v', 5), SenseInfo('00807178-v', 2) ],
"_octopus_n_1_rel" : [ SenseInfo('07782365-n', 0), SenseInfo('01970164-n', 0) ],
"_lieutenant_n_1_rel" : [ SenseInfo('10259348-n', 41), SenseInfo('10259225-n', 7), SenseInfo('10005280-n', 1), SenseInfo('10259527-n', 0), SenseInfo('10259348-n', 41), SenseInfo('10259225-n', 7), SenseInfo('10005280-n', 1), SenseInfo('10259527-n', 0) ],
"_oil_n_1_rel" : [ SenseInfo('14966667-n', 10), SenseInfo('03843092-n', 5), SenseInfo('14980579-n', 0), SenseInfo('07673397-n', 0) ],
"_alternative_a_1_rel" : [ SenseInfo('01853934-a', 4), SenseInfo('00564667-a', 1), SenseInfo('00608668-a', 0), SenseInfo('01853934-a', 4), SenseInfo('00564667-a', 1), SenseInfo('00608668-a', 0) ],
"_moreover_a_1_rel" : [  ],
"_edge_v_out_rel" : [ SenseInfo('02072501-v', 3), SenseInfo('02361600-v', 0), SenseInfo('01466978-v', 0), SenseInfo('01246843-v', 0) ],
"_legitimate_a_1_rel" : [ SenseInfo('01406640-a', 1), SenseInfo('02499301-a', 1), SenseInfo('01636205-a', 1), SenseInfo('01401224-a', 1), SenseInfo('01406640-a', 1), SenseInfo('02499301-a', 1), SenseInfo('01636205-a', 1), SenseInfo('01401224-a', 1) ],
"_vitamin_n_1_rel" : [ SenseInfo('15089258-n', 3) ],
"_gummy_a_1_rel" : [ SenseInfo('00053691-a', 1), SenseInfo('00054278-a', 0), SenseInfo('00053691-a', 1), SenseInfo('00054278-a', 0), SenseInfo('00053691-a', 1), SenseInfo('00054278-a', 0) ],
"_blog_n_1_rel" : [ SenseInfo('06402202-n', 0) ],
"_vicarage_n_1_rel" : [ SenseInfo('03892557-n', 0) ],
"_cuttlefish_n_1_rel" : [ SenseInfo('01972541-n', 0) ],
"_shear_v_1_rel" : [ SenseInfo('01320513-v', 3), SenseInfo('01560369-v', 0), SenseInfo('01320816-v', 0), SenseInfo('00587124-v', 0) ],
"_rash_n_of_rel" : [ SenseInfo('14321953-n', 0), SenseInfo('08459087-n', 0), SenseInfo('14321953-n', 0), SenseInfo('08459087-n', 0) ],
"_incompatible_a_1_rel" : [ SenseInfo('00508192-a', 2), SenseInfo('00623565-a', 0), SenseInfo('00561036-a', 0), SenseInfo('00509206-a', 0), SenseInfo('02382572-a', 0), SenseInfo('01487352-a', 0), SenseInfo('00578523-a', 0), SenseInfo('00562909-a', 0), SenseInfo('00509896-a', 0) ],
"_pricing_n_1_rel" : [ SenseInfo('05736736-n', 3) ],
"_across_p_rel" : [ SenseInfo('00272951-r', 4), SenseInfo('00272844-r', 1), SenseInfo('00272951-r', 4), SenseInfo('00272844-r', 1), SenseInfo('00272951-r', 4), SenseInfo('00272844-r', 1) ],
"_rabbi_n_1_rel" : [ SenseInfo('10502329-n', 6), SenseInfo('06341609-n', 0) ],
"_brief_v_1_rel" : [ SenseInfo('00831273-v', 1), SenseInfo('00831273-v', 1) ],
"_foreground_n_1_rel" : [ SenseInfo('05934278-n', 2), SenseInfo('03382708-n', 0) ],
"_canine_n_1_rel" : [ SenseInfo('05307091-n', 0), SenseInfo('02083346-n', 0) ],
"_other_a_1_rel" : [ SenseInfo('02069355-a', 483), SenseInfo('01730820-a', 8), SenseInfo('01729384-a', 0), SenseInfo('00969333-a', 0), SenseInfo('02069355-a', 483), SenseInfo('01730820-a', 8), SenseInfo('01729384-a', 0), SenseInfo('00969333-a', 0) ],
"_critter_n_1_rel" : [ SenseInfo('01314663-n', 0) ],
"_whirlpool_n_of_rel" : [ SenseInfo('07433145-n', 0) ],
"_ledger_n_1_rel" : [ SenseInfo('13404248-n', 5), SenseInfo('03165211-n', 1) ],
"_void_a_of_rel" : [ SenseInfo('02500590-a', 1), SenseInfo('01088351-a', 0) ],
"_californian_n_1_rel" : [ SenseInfo('09741612-n', 1) ],
"_quantum_n_1_rel" : [ SenseInfo('05855748-n', 0), SenseInfo('05855517-n', 0) ],
"_caduceus_n_1_rel" : [ SenseInfo('06884520-n', 0) ],
"_firemens_a_1_rel" : [  ],
"_runtime_n_1_rel" : [  ],
"_explicitly_x_deg_rel" : [ SenseInfo('00367418-r', 1) ],
"_revel_v_1_rel" : [ SenseInfo('01190948-v', 3), SenseInfo('02491383-v', 0) ],
"_fund_v_1_rel" : [ SenseInfo('02218924-v', 0), SenseInfo('02218635-v', 0), SenseInfo('02216083-v', 0), SenseInfo('02215966-v', 0), SenseInfo('02215790-v', 0), SenseInfo('02215506-v', 0) ],
"_wash_n_1_rel" : [ SenseInfo('04553389-n', 6), SenseInfo('00255710-n', 3), SenseInfo('09474895-n', 2), SenseInfo('13574193-n', 0), SenseInfo('11423197-n', 0), SenseInfo('04553245-n', 0), SenseInfo('03648219-n', 0), SenseInfo('01096674-n', 0) ],
"_congenital_a_1_rel" : [ SenseInfo('01315844-a', 1) ],
"_free_v_from-of_rel" : [ SenseInfo('02421374-v', 6), SenseInfo('02350175-v', 3), SenseInfo('01528522-v', 3), SenseInfo('02564146-v', 1), SenseInfo('02494047-v', 1), SenseInfo('02422026-v', 1), SenseInfo('01475953-v', 1), SenseInfo('00902424-v', 1), SenseInfo('02316304-v', 0), SenseInfo('01757994-v', 0), SenseInfo('00269682-v', 0), SenseInfo('02421374-v', 6), SenseInfo('02350175-v', 3), SenseInfo('01528522-v', 3), SenseInfo('02564146-v', 1), SenseInfo('02494047-v', 1), SenseInfo('02422026-v', 1), SenseInfo('01475953-v', 1), SenseInfo('00902424-v', 1), SenseInfo('02316304-v', 0), SenseInfo('01757994-v', 0), SenseInfo('00269682-v', 0) ],
"_hydraulics_n_1_rel" : [ SenseInfo('06113009-n', 0) ],
"_put_v_up_rel" : [ SenseInfo('01494310-v', 138), SenseInfo('01493741-v', 98), SenseInfo('00981276-v', 28), SenseInfo('01160370-v', 6), SenseInfo('02271137-v', 3), SenseInfo('00673448-v', 2), SenseInfo('02111499-v', 0), SenseInfo('01706375-v', 0), SenseInfo('00735571-v', 0), SenseInfo('01494310-v', 138), SenseInfo('01493741-v', 98), SenseInfo('00981276-v', 28), SenseInfo('01160370-v', 6), SenseInfo('02271137-v', 3), SenseInfo('00673448-v', 2), SenseInfo('02111499-v', 0), SenseInfo('01706375-v', 0), SenseInfo('00735571-v', 0) ],
"_not-too-small_a_1_rel" : [  ],
"_stage_n_1_rel" : [ SenseInfo('15290337-n', 25), SenseInfo('13939892-n', 18), SenseInfo('04296562-n', 15), SenseInfo('07006712-n', 6), SenseInfo('04297098-n', 2), SenseInfo('00306900-n', 2), SenseInfo('08646566-n', 1), SenseInfo('04296949-n', 0) ],
"_approx_x_deg_rel" : [  ],
"_rock-n-roll_n_1_rel" : [  ],
"_kick_v_around_rel" : [ SenseInfo('01371756-v', 11), SenseInfo('01936233-v', 9), SenseInfo('01370561-v', 7), SenseInfo('02048511-v', 0), SenseInfo('01371454-v', 0), SenseInfo('01196524-v', 0), SenseInfo('01112979-v', 0), SenseInfo('00907147-v', 0) ],
"_cut_v_back_rel" : [ SenseInfo('01552519-v', 58), SenseInfo('00429060-v', 18), SenseInfo('02033295-v', 3), SenseInfo('01610834-v', 2), SenseInfo('02422283-v', 1), SenseInfo('01754915-v', 1), SenseInfo('01666717-v', 1), SenseInfo('01413917-v', 1), SenseInfo('01064799-v', 1), SenseInfo('00201722-v', 1), SenseInfo('02613860-v', 0), SenseInfo('02588280-v', 0), SenseInfo('02134232-v', 0), SenseInfo('02101649-v', 0), SenseInfo('01915865-v', 0), SenseInfo('01915730-v', 0), SenseInfo('01860107-v', 0), SenseInfo('01859995-v', 0), SenseInfo('01756563-v', 0), SenseInfo('01756416-v', 0), SenseInfo('01756277-v', 0), SenseInfo('01754737-v', 0), SenseInfo('01713491-v', 0), SenseInfo('01611123-v', 0), SenseInfo('01610990-v', 0), SenseInfo('01555437-v', 0), SenseInfo('01510576-v', 0), SenseInfo('01320424-v', 0), SenseInfo('01319738-v', 0), SenseInfo('01227088-v', 0), SenseInfo('01059564-v', 0), SenseInfo('00561090-v', 0), SenseInfo('00473322-v', 0), SenseInfo('00447654-v', 0), SenseInfo('00429968-v', 0), SenseInfo('00292507-v', 0), SenseInfo('00243900-v', 0), SenseInfo('00226071-v', 0), SenseInfo('00108475-v', 0), SenseInfo('00096136-v', 0), SenseInfo('00061219-v', 0), SenseInfo('01552519-v', 58), SenseInfo('00429060-v', 18), SenseInfo('02033295-v', 3), SenseInfo('01610834-v', 2), SenseInfo('02422283-v', 1), SenseInfo('01754915-v', 1), SenseInfo('01666717-v', 1), SenseInfo('01413917-v', 1), SenseInfo('01064799-v', 1), SenseInfo('00201722-v', 1), SenseInfo('02613860-v', 0), SenseInfo('02588280-v', 0), SenseInfo('02134232-v', 0), SenseInfo('02101649-v', 0), SenseInfo('01915865-v', 0), SenseInfo('01915730-v', 0), SenseInfo('01860107-v', 0), SenseInfo('01859995-v', 0), SenseInfo('01756563-v', 0), SenseInfo('01756416-v', 0), SenseInfo('01756277-v', 0), SenseInfo('01754737-v', 0), SenseInfo('01713491-v', 0), SenseInfo('01611123-v', 0), SenseInfo('01610990-v', 0), SenseInfo('01555437-v', 0), SenseInfo('01510576-v', 0), SenseInfo('01320424-v', 0), SenseInfo('01319738-v', 0), SenseInfo('01227088-v', 0), SenseInfo('01059564-v', 0), SenseInfo('00561090-v', 0), SenseInfo('00473322-v', 0), SenseInfo('00447654-v', 0), SenseInfo('00429968-v', 0), SenseInfo('00292507-v', 0), SenseInfo('00243900-v', 0), SenseInfo('00226071-v', 0), SenseInfo('00108475-v', 0), SenseInfo('00096136-v', 0), SenseInfo('00061219-v', 0), SenseInfo('01552519-v', 58), SenseInfo('00429060-v', 18), SenseInfo('02033295-v', 3), SenseInfo('01610834-v', 2), SenseInfo('02422283-v', 1), SenseInfo('01754915-v', 1), SenseInfo('01666717-v', 1), SenseInfo('01413917-v', 1), SenseInfo('01064799-v', 1), SenseInfo('00201722-v', 1), SenseInfo('02613860-v', 0), SenseInfo('02588280-v', 0), SenseInfo('02134232-v', 0), SenseInfo('02101649-v', 0), SenseInfo('01915865-v', 0), SenseInfo('01915730-v', 0), SenseInfo('01860107-v', 0), SenseInfo('01859995-v', 0), SenseInfo('01756563-v', 0), SenseInfo('01756416-v', 0), SenseInfo('01756277-v', 0), SenseInfo('01754737-v', 0), SenseInfo('01713491-v', 0), SenseInfo('01611123-v', 0), SenseInfo('01610990-v', 0), SenseInfo('01555437-v', 0), SenseInfo('01510576-v', 0), SenseInfo('01320424-v', 0), SenseInfo('01319738-v', 0), SenseInfo('01227088-v', 0), SenseInfo('01059564-v', 0), SenseInfo('00561090-v', 0), SenseInfo('00473322-v', 0), SenseInfo('00447654-v', 0), SenseInfo('00429968-v', 0), SenseInfo('00292507-v', 0), SenseInfo('00243900-v', 0), SenseInfo('00226071-v', 0), SenseInfo('00108475-v', 0), SenseInfo('00096136-v', 0), SenseInfo('00061219-v', 0), SenseInfo('01552519-v', 58), SenseInfo('00429060-v', 18), SenseInfo('02033295-v', 3), SenseInfo('01610834-v', 2), SenseInfo('02422283-v', 1), SenseInfo('01754915-v', 1), SenseInfo('01666717-v', 1), SenseInfo('01413917-v', 1), SenseInfo('01064799-v', 1), SenseInfo('00201722-v', 1), SenseInfo('02613860-v', 0), SenseInfo('02588280-v', 0), SenseInfo('02134232-v', 0), SenseInfo('02101649-v', 0), SenseInfo('01915865-v', 0), SenseInfo('01915730-v', 0), SenseInfo('01860107-v', 0), SenseInfo('01859995-v', 0), SenseInfo('01756563-v', 0), SenseInfo('01756416-v', 0), SenseInfo('01756277-v', 0), SenseInfo('01754737-v', 0), SenseInfo('01713491-v', 0), SenseInfo('01611123-v', 0), SenseInfo('01610990-v', 0), SenseInfo('01555437-v', 0), SenseInfo('01510576-v', 0), SenseInfo('01320424-v', 0), SenseInfo('01319738-v', 0), SenseInfo('01227088-v', 0), SenseInfo('01059564-v', 0), SenseInfo('00561090-v', 0), SenseInfo('00473322-v', 0), SenseInfo('00447654-v', 0), SenseInfo('00429968-v', 0), SenseInfo('00292507-v', 0), SenseInfo('00243900-v', 0), SenseInfo('00226071-v', 0), SenseInfo('00108475-v', 0), SenseInfo('00096136-v', 0), SenseInfo('00061219-v', 0) ],
"_no+more+than_x_rel" : [  ],
"_peach_a_1_rel" : [ SenseInfo('12648045-n', 0), SenseInfo('10613996-n', 0), SenseInfo('07751004-n', 0), SenseInfo('04971675-n', 0) ],
"_chart_n_of_rel" : [ SenseInfo('06999802-n', 7), SenseInfo('03009920-n', 2) ],
"_jolt_n_1_rel" : [ SenseInfo('07339098-n', 1), SenseInfo('00335988-n', 1) ],
"_concave_a_1_rel" : [ SenseInfo('00535452-a', 3) ],
"_hanging_n_1_rel" : [ SenseInfo('03491178-n', 0), SenseInfo('01164874-n', 0), SenseInfo('01017701-n', 0) ],
"_chess_n_1_rel" : [ SenseInfo('12111238-n', 0), SenseInfo('00503237-n', 0) ],
"_rhizome_n_1_rel" : [ SenseInfo('13128582-n', 0) ],
"_espionage_n_1_rel" : [ SenseInfo('00654563-n', 1) ],
"_norwegian_n_1_rel" : [ SenseInfo('09725402-n', 0), SenseInfo('06954303-n', 0) ],
"_origami_n_1_rel" : [ SenseInfo('00936456-n', 0) ],
"_unintentional_a_1_rel" : [ SenseInfo('02566644-a', 0), SenseInfo('01339492-a', 0), SenseInfo('02566644-a', 0), SenseInfo('01339492-a', 0), SenseInfo('02566644-a', 0), SenseInfo('01339492-a', 0) ],
"_bribe_v_1_rel" : [ SenseInfo('02284096-v', 1), SenseInfo('02284096-v', 1) ],
"_freckle_n_1_rel" : [ SenseInfo('05245192-n', 1) ],
"_doctor_n_abb_rel" : [ SenseInfo('10020890-n', 73), SenseInfo('10022111-n', 1), SenseInfo('00432356-n', 1), SenseInfo('10021892-n', 0), SenseInfo('10020890-n', 73), SenseInfo('10022111-n', 1), SenseInfo('00432356-n', 1), SenseInfo('10021892-n', 0) ],
"_rainwear_n_1_rel" : [  ],
"_ballyhoo_n_1_rel" : [ SenseInfo('07248507-n', 1) ],
"_grieve_v_for_rel" : [ SenseInfo('01797347-v', 1), SenseInfo('01797582-v', 0) ],
"_rp_n_1_rel" : [  ],
"_upstairs_p_rel" : [ SenseInfo('00094545-r', 13), SenseInfo('02493951-a', 5), SenseInfo('04515729-n', 0), SenseInfo('00094675-r', 0) ],
"_sprig_n_1_rel" : [ SenseInfo('13163991-n', 0), SenseInfo('04288165-n', 0) ],
"_finish_v_1_rel" : [ SenseInfo('00484166-v', 44), SenseInfo('00352558-v', 12), SenseInfo('02609764-v', 8), SenseInfo('01265989-v', 3), SenseInfo('01196802-v', 2), SenseInfo('00351963-v', 0), SenseInfo('00484166-v', 44), SenseInfo('00352558-v', 12), SenseInfo('02609764-v', 8), SenseInfo('01265989-v', 3), SenseInfo('01196802-v', 2), SenseInfo('00351963-v', 0) ],
"_paradox_n_1_rel" : [ SenseInfo('06724559-n', 3) ],
"_swear_v_at_rel" : [ SenseInfo('00865387-v', 20), SenseInfo('01011031-v', 8), SenseInfo('00889947-v', 2), SenseInfo('01013040-v', 1), SenseInfo('00688377-v', 0) ],
"_survivor_n_1_rel" : [ SenseInfo('10681194-n', 3), SenseInfo('10681060-n', 1), SenseInfo('01324142-n', 1) ],
"_thinkpad_n_1_rel" : [  ],
"_pan_v_1_rel" : [ SenseInfo('01998302-v', 1), SenseInfo('01536508-v', 1), SenseInfo('00846344-v', 0) ],
"_confer_v_on_rel" : [ SenseInfo('00876665-v', 1), SenseInfo('02263346-v', 0), SenseInfo('00876665-v', 1), SenseInfo('02263346-v', 0) ],
"_bonus_n_of_rel" : [ SenseInfo('05829656-n', 1), SenseInfo('13273154-n', 0) ],
"_withdraw_v_1_rel" : [ SenseInfo('01994442-v', 9), SenseInfo('02380009-v', 4), SenseInfo('01511380-v', 4), SenseInfo('02312478-v', 2), SenseInfo('00799076-v', 1), SenseInfo('00495998-v', 1), SenseInfo('02428487-v', 0), SenseInfo('02380760-v', 0), SenseInfo('02311387-v', 0), SenseInfo('01766952-v', 0), SenseInfo('00799383-v', 0), SenseInfo('00173338-v', 0) ],
"_private_n_1_rel" : [ SenseInfo('10476467-n', 12) ],
"_over-the-counter_a_1_rel" : [ SenseInfo('01846204-a', 0), SenseInfo('01418647-a', 0), SenseInfo('01846204-a', 0), SenseInfo('01418647-a', 0), SenseInfo('01846204-a', 0), SenseInfo('01418647-a', 0) ],
"_crooked_a_1_rel" : [ SenseInfo('02311544-a', 2), SenseInfo('02319129-a', 0), SenseInfo('01961048-a', 0), SenseInfo('01239199-a', 0), SenseInfo('02311544-a', 2), SenseInfo('02319129-a', 0), SenseInfo('01961048-a', 0), SenseInfo('01239199-a', 0), SenseInfo('02311544-a', 2), SenseInfo('02319129-a', 0), SenseInfo('01961048-a', 0), SenseInfo('01239199-a', 0) ],
"_teller_n_1_rel" : [ SenseInfo('11335041-n', 0), SenseInfo('10699099-n', 0), SenseInfo('10698970-n', 0), SenseInfo('10345804-n', 0) ],
"_perpendicular_a_1_rel" : [ SenseInfo('01720280-a', 0), SenseInfo('01233347-a', 0), SenseInfo('01145724-a', 0) ],
"_soar_v_1_rel" : [ SenseInfo('01943718-v', 4), SenseInfo('01955808-v', 1), SenseInfo('01943338-v', 1), SenseInfo('00155406-v', 1), SenseInfo('01942959-v', 0) ],
"_sail_n_1_rel" : [ SenseInfo('04127904-n', 1), SenseInfo('00312932-n', 1), SenseInfo('04128413-n', 0) ],
"_flaw_n_1_rel" : [ SenseInfo('14464203-n', 2), SenseInfo('14463826-n', 0), SenseInfo('14463170-n', 0) ],
"_c_a_parens_rel" : [ SenseInfo('02196107-a', 0), SenseInfo('02196107-a', 0) ],
"_bestseller_n_1_rel" : [ SenseInfo('06412497-n', 0), SenseInfo('06412497-n', 0), SenseInfo('06412497-n', 0) ],
"_palm_v_1_rel" : [ SenseInfo('01210737-v', 1) ],
"_left+to+right_p_1_rel" : [  ],
"_construct_v_1_rel" : [ SenseInfo('01654628-v', 28), SenseInfo('01653442-v', 5), SenseInfo('01583142-v', 2), SenseInfo('01757721-v', 0), SenseInfo('01757546-v', 0), SenseInfo('00634090-v', 0), SenseInfo('01654628-v', 28), SenseInfo('01653442-v', 5), SenseInfo('01583142-v', 2), SenseInfo('01757721-v', 0), SenseInfo('01757546-v', 0), SenseInfo('00634090-v', 0) ],
"_intake_n_1_rel" : [ SenseInfo('00838098-n', 5), SenseInfo('03576617-n', 0), SenseInfo('00836788-n', 0) ],
"_rainbow_n_1_rel" : [ SenseInfo('09403427-n', 2), SenseInfo('05950982-n', 0) ],
"_tempting_a_1_rel" : [ SenseInfo('02097480-a', 0), SenseInfo('01358695-a', 0), SenseInfo('02097480-a', 0), SenseInfo('01358695-a', 0), SenseInfo('02097480-a', 0), SenseInfo('01358695-a', 0) ],
"_fall_v_back_rel" : [ SenseInfo('01972298-v', 43), SenseInfo('01970826-v', 21), SenseInfo('00147815-v', 16), SenseInfo('02729963-v', 6), SenseInfo('02756821-v', 4), SenseInfo('02528985-v', 4), SenseInfo('02620213-v', 3), SenseInfo('02611976-v', 3), SenseInfo('02304507-v', 3), SenseInfo('00342443-v', 3), SenseInfo('00151689-v', 3), SenseInfo('02565911-v', 2), SenseInfo('02385153-v', 2), SenseInfo('02358655-v', 2), SenseInfo('02099413-v', 1), SenseInfo('02661015-v', 0), SenseInfo('02566092-v', 0), SenseInfo('02358922-v', 0), SenseInfo('02230056-v', 0), SenseInfo('02229828-v', 0), SenseInfo('02229550-v', 0), SenseInfo('02037839-v', 0), SenseInfo('01984317-v', 0), SenseInfo('01984119-v', 0), SenseInfo('01542668-v', 0), SenseInfo('00561375-v', 0), SenseInfo('00561266-v', 0), SenseInfo('00530177-v', 0), SenseInfo('00360678-v', 0), SenseInfo('00346839-v', 0), SenseInfo('00342314-v', 0), SenseInfo('00342164-v', 0) ],
"_leave_v_off_rel" : [ SenseInfo('02009433-v', 146), SenseInfo('00613683-v', 63), SenseInfo('02729414-v', 56), SenseInfo('00136991-v', 27), SenseInfo('02015598-v', 20), SenseInfo('02721438-v', 19), SenseInfo('02635659-v', 16), SenseInfo('02383440-v', 14), SenseInfo('02356230-v', 8), SenseInfo('02229055-v', 7), SenseInfo('02730135-v', 5), SenseInfo('00360092-v', 5), SenseInfo('02296153-v', 3), SenseInfo('00613018-v', 3), SenseInfo('02009433-v', 146), SenseInfo('00613683-v', 63), SenseInfo('02729414-v', 56), SenseInfo('00136991-v', 27), SenseInfo('02015598-v', 20), SenseInfo('02721438-v', 19), SenseInfo('02635659-v', 16), SenseInfo('02383440-v', 14), SenseInfo('02356230-v', 8), SenseInfo('02229055-v', 7), SenseInfo('02730135-v', 5), SenseInfo('00360092-v', 5), SenseInfo('02296153-v', 3), SenseInfo('00613018-v', 3) ],
"_owners_a_1_rel" : [  ],
"_ask_v_out_rel" : [ SenseInfo('00784342-v', 244), SenseInfo('00752493-v', 165), SenseInfo('00784727-v', 16), SenseInfo('00755745-v', 2), SenseInfo('00897746-v', 1), SenseInfo('02627934-v', 0), SenseInfo('01068565-v', 0) ],
"_cheat_v_out+of_rel" : [ SenseInfo('02573275-v', 2), SenseInfo('01104624-v', 2), SenseInfo('02574516-v', 1), SenseInfo('02576503-v', 0), SenseInfo('02573275-v', 2), SenseInfo('01104624-v', 2), SenseInfo('02574516-v', 1), SenseInfo('02576503-v', 0) ],
"_reproduction_n_of_rel" : [ SenseInfo('13550318-n', 1), SenseInfo('05762483-n', 0), SenseInfo('04076533-n', 0), SenseInfo('01019901-n', 0), SenseInfo('00849523-n', 0) ],
"_farmhand_n_1_rel" : [ SenseInfo('10079399-n', 0) ],
"_expo_n_1_rel" : [ SenseInfo('08407619-n', 0) ],
"_surreal_a_1_rel" : [ SenseInfo('01943067-a', 0), SenseInfo('01939226-a', 0) ],
"_prevalence_n_1_rel" : [ SenseInfo('04765355-n', 1), SenseInfo('13824114-n', 0), SenseInfo('05122099-n', 0) ],
"_fuchsia_a_1_rel" : [ SenseInfo('12343480-n', 0) ],
"_deductible_a_1_rel" : [ SenseInfo('00689673-a', 3) ],
"_peninsula_n_1_rel" : [ SenseInfo('09388848-n', 1) ],
"_metallic_a_1_rel" : [ SenseInfo('01527420-a', 3) ],
"_newcomer_n_1_rel" : [ SenseInfo('10355449-n', 2), SenseInfo('10355688-n', 1) ],
"_brick_v_1_rel" : [  ],
"_serial_n_1_rel" : [ SenseInfo('06621447-n', 0), SenseInfo('06593803-n', 0) ],
"_pressing_a_1_rel" : [ SenseInfo('00713558-a', 3) ],
"_lunacy_n_1_rel" : [ SenseInfo('14395240-n', 0), SenseInfo('00512843-n', 0) ],
"_ne_n_of_rel" : [ SenseInfo('14646152-n', 0), SenseInfo('13831843-n', 0), SenseInfo('09109444-n', 0) ],
"_cost_v_2_rel" : [ SenseInfo('02702508-v', 35), SenseInfo('02628961-v', 16), SenseInfo('02702508-v', 35), SenseInfo('02628961-v', 16), SenseInfo('02702508-v', 35), SenseInfo('02628961-v', 16), SenseInfo('02702508-v', 35), SenseInfo('02628961-v', 16) ],
"_scout_n_1_rel" : [ SenseInfo('10271216-n', 1), SenseInfo('10563183-n', 0), SenseInfo('10562968-n', 0), SenseInfo('10562749-n', 0) ],
"_mushy_a_1_rel" : [ SenseInfo('01154639-a', 0), SenseInfo('00854413-a', 0), SenseInfo('01154639-a', 0), SenseInfo('00854413-a', 0), SenseInfo('01154639-a', 0), SenseInfo('00854413-a', 0) ],
"_milky_a_1_rel" : [ SenseInfo('00434384-a', 0), SenseInfo('00434384-a', 0), SenseInfo('00434384-a', 0) ],
"_replace_v_with_rel" : [ SenseInfo('00162688-v', 24), SenseInfo('02405390-v', 21), SenseInfo('01308381-v', 7), SenseInfo('02257767-v', 6), SenseInfo('00162688-v', 24), SenseInfo('02405390-v', 21), SenseInfo('01308381-v', 7), SenseInfo('02257767-v', 6) ],
"_red+currant_n_1_rel" : [ SenseInfo('12805373-n', 0), SenseInfo('07744682-n', 0) ],
"_elementary+school_n_1_rel" : [ SenseInfo('08412749-n', 1), SenseInfo('08412749-n', 1) ],
"_unexpected_a_1_rel" : [ SenseInfo('00930290-a', 7) ],
"_hammer_v_1_rel" : [ SenseInfo('01416539-v', 4), SenseInfo('01675245-v', 0), SenseInfo('01416539-v', 4), SenseInfo('01675245-v', 0) ],
"_stunt_n_1_rel" : [ SenseInfo('00046344-n', 2), SenseInfo('01319187-n', 0) ],
"_umbrella_n_1_rel" : [ SenseInfo('04507155-n', 2), SenseInfo('00829918-n', 0), SenseInfo('00383071-n', 0) ],
"_pluck_n_1_rel" : [ SenseInfo('04859816-n', 1), SenseInfo('00116008-n', 0) ],
"_orbit_n_1_rel" : [ SenseInfo('08612049-n', 11), SenseInfo('14514039-n', 1), SenseInfo('05125377-n', 1), SenseInfo('08612340-n', 0), SenseInfo('05285275-n', 0) ],
"_pie_n_1_rel" : [ SenseInfo('07625493-n', 2), SenseInfo('06942094-n', 0) ],
"_revolt_v_1_rel" : [ SenseInfo('02583780-v', 0), SenseInfo('02194913-v', 0), SenseInfo('01808374-v', 0) ],
"_compatible_a_with_rel" : [ SenseInfo('00507464-a', 6), SenseInfo('00509039-a', 0), SenseInfo('00509576-a', 0), SenseInfo('00507464-a', 6), SenseInfo('00509039-a', 0), SenseInfo('00509576-a', 0) ],
"_realization_n_1_rel" : [ SenseInfo('05807540-n', 3), SenseInfo('00931847-n', 3), SenseInfo('07039056-n', 0), SenseInfo('01119620-n', 0), SenseInfo('00940043-n', 0), SenseInfo('00061917-n', 0), SenseInfo('05807540-n', 3), SenseInfo('00931847-n', 3), SenseInfo('07039056-n', 0), SenseInfo('01119620-n', 0), SenseInfo('00940043-n', 0), SenseInfo('00061917-n', 0) ],
"_blind-side_v_1_rel" : [ SenseInfo('02596730-v', 0), SenseInfo('01120612-v', 0), SenseInfo('02596730-v', 0), SenseInfo('01120612-v', 0), SenseInfo('02596730-v', 0), SenseInfo('01120612-v', 0) ],
"_demonstration_n_of_rel" : [ SenseInfo('00521562-n', 8), SenseInfo('00521970-n', 5), SenseInfo('01177703-n', 3), SenseInfo('06648046-n', 2), SenseInfo('06879180-n', 0), SenseInfo('00521562-n', 8), SenseInfo('00521970-n', 5), SenseInfo('01177703-n', 3), SenseInfo('06648046-n', 2), SenseInfo('06879180-n', 0) ],
"_idle_a_1_rel" : [ SenseInfo('00294175-a', 4), SenseInfo('02353211-a', 1), SenseInfo('00037188-a', 1), SenseInfo('02121424-a', 0), SenseInfo('01998835-a', 0), SenseInfo('01872265-a', 0), SenseInfo('00865007-a', 0) ],
"_predicament_n_1_rel" : [ SenseInfo('14408646-n', 1) ],
"_heather_n_1_rel" : [ SenseInfo('12233529-n', 0), SenseInfo('04958146-n', 0) ],
"_independence_n_1_rel" : [ SenseInfo('13994148-n', 22), SenseInfo('07474006-n', 1), SenseInfo('09106770-n', 0) ],
"_molest_v_1_rel" : [ SenseInfo('02569495-v', 2), SenseInfo('01789514-v', 0) ],
"_mosque_n_1_rel" : [ SenseInfo('03788195-n', 0), SenseInfo('03788195-n', 0) ],
"_doctorate_n_1_rel" : [ SenseInfo('06702458-n', 1) ],
"_resiliency_n_1_rel" : [ SenseInfo('07350567-n', 0), SenseInfo('05020697-n', 0) ],
"_intermit_v_1_rel" : [ SenseInfo('00779061-v', 0) ],
"_dress_v_down_rel" : [ SenseInfo('00046534-v', 15), SenseInfo('00047945-v', 8), SenseInfo('01266269-v', 2), SenseInfo('00044797-v', 2), SenseInfo('00043683-v', 2), SenseInfo('00542809-v', 1), SenseInfo('02036650-v', 0), SenseInfo('01679433-v', 0), SenseInfo('01466543-v', 0), SenseInfo('01364184-v', 0), SenseInfo('01321002-v', 0), SenseInfo('01262813-v', 0), SenseInfo('00511636-v', 0), SenseInfo('00082714-v', 0), SenseInfo('00045639-v', 0), SenseInfo('00038849-v', 0) ],
"_call_v_on_rel" : [ SenseInfo('01028748-v', 91), SenseInfo('00971015-v', 51), SenseInfo('00789448-v', 38), SenseInfo('00913065-v', 25), SenseInfo('00792471-v', 25), SenseInfo('02487573-v', 9), SenseInfo('02429810-v', 9), SenseInfo('01067995-v', 1), SenseInfo('01062739-v', 1), SenseInfo('00975036-v', 1), SenseInfo('02643421-v', 0), SenseInfo('02601456-v', 0), SenseInfo('02487901-v', 0), SenseInfo('02359061-v', 0), SenseInfo('02300060-v', 0), SenseInfo('01899017-v', 0), SenseInfo('01068793-v', 0), SenseInfo('00917772-v', 0), SenseInfo('00874002-v', 0), SenseInfo('00869393-v', 0), SenseInfo('00822746-v', 0), SenseInfo('00783523-v', 0), SenseInfo('00754156-v', 0), SenseInfo('00753881-v', 0), SenseInfo('00738747-v', 0), SenseInfo('00738583-v', 0), SenseInfo('00691516-v', 0), SenseInfo('00107231-v', 0), SenseInfo('01028748-v', 91), SenseInfo('00971015-v', 51), SenseInfo('00789448-v', 38), SenseInfo('00913065-v', 25), SenseInfo('00792471-v', 25), SenseInfo('02487573-v', 9), SenseInfo('02429810-v', 9), SenseInfo('01067995-v', 1), SenseInfo('01062739-v', 1), SenseInfo('00975036-v', 1), SenseInfo('02643421-v', 0), SenseInfo('02601456-v', 0), SenseInfo('02487901-v', 0), SenseInfo('02359061-v', 0), SenseInfo('02300060-v', 0), SenseInfo('01899017-v', 0), SenseInfo('01068793-v', 0), SenseInfo('00917772-v', 0), SenseInfo('00874002-v', 0), SenseInfo('00869393-v', 0), SenseInfo('00822746-v', 0), SenseInfo('00783523-v', 0), SenseInfo('00754156-v', 0), SenseInfo('00753881-v', 0), SenseInfo('00738747-v', 0), SenseInfo('00738583-v', 0), SenseInfo('00691516-v', 0), SenseInfo('00107231-v', 0) ],
"_associate_v_with_rel" : [ SenseInfo('00713167-v', 25), SenseInfo('02589245-v', 3), SenseInfo('02470175-v', 1), SenseInfo('00713167-v', 25), SenseInfo('02589245-v', 3), SenseInfo('02470175-v', 1) ],
"_inspectorate_n_1_rel" : [ SenseInfo('08414040-n', 0) ],
"_vide+infra_v_1_rel" : [  ],
"_scrunch_v_up_rel" : [ SenseInfo('02184797-v', 0), SenseInfo('01545314-v', 0), SenseInfo('01278427-v', 0) ],
"_paper_n_1_rel" : [ SenseInfo('14974264-n', 30), SenseInfo('06409752-n', 21), SenseInfo('06267145-n', 12), SenseInfo('06255613-n', 4), SenseInfo('06269956-n', 3), SenseInfo('08062970-n', 2), SenseInfo('03822171-n', 0), SenseInfo('14974264-n', 30), SenseInfo('06409752-n', 21), SenseInfo('06267145-n', 12), SenseInfo('06255613-n', 4), SenseInfo('06269956-n', 3), SenseInfo('08062970-n', 2), SenseInfo('03822171-n', 0) ],
"_default_n_1_rel" : [ SenseInfo('00067397-n', 1), SenseInfo('13300411-n', 0), SenseInfo('13300141-n', 0), SenseInfo('05791864-n', 0) ],
"_speeder_n_1_rel" : [ SenseInfo('10634596-n', 0) ],
"_titillate_v_1_rel" : [ SenseInfo('02120140-v', 0), SenseInfo('01816219-v', 0) ],
"_rectory_n_1_rel" : [ SenseInfo('03892557-n', 0) ],
"_nest_n_of_rel" : [ SenseInfo('09369169-n', 14), SenseInfo('03819217-n', 1), SenseInfo('08643729-n', 0), SenseInfo('08244346-n', 0), SenseInfo('03819336-n', 0) ],
"_tonic_n_1_rel" : [ SenseInfo('07929172-n', 0), SenseInfo('07927512-n', 0), SenseInfo('06857726-n', 0), SenseInfo('04451473-n', 0) ],
"_especial_a_1_rel" : [ SenseInfo('00488187-a', 0) ],
"_honorary_a_1_rel" : [ SenseInfo('00821959-a', 0), SenseInfo('00821959-a', 0) ],
"_parachutist_n_1_rel" : [ SenseInfo('10397482-n', 0) ],
"_siphon_n_1_rel" : [ SenseInfo('04224155-n', 0), SenseInfo('01468913-n', 0) ],
"_upgrade_n_of_rel" : [ SenseInfo('09206985-n', 0), SenseInfo('06903255-n', 0), SenseInfo('05795654-n', 0), SenseInfo('05068918-n', 0), SenseInfo('04513686-n', 0), SenseInfo('01267588-n', 0) ],
"_launch_n_1_rel" : [ SenseInfo('03647423-n', 0), SenseInfo('00103140-n', 0) ],
"_tie_v_in_rel" : [ SenseInfo('01285440-v', 13), SenseInfo('01115190-v', 5), SenseInfo('00234217-v', 4), SenseInfo('01354673-v', 2), SenseInfo('00141632-v', 1), SenseInfo('02538086-v', 0), SenseInfo('02489456-v', 0), SenseInfo('01658444-v', 0), SenseInfo('01355411-v', 0), SenseInfo('01285440-v', 13), SenseInfo('01115190-v', 5), SenseInfo('00234217-v', 4), SenseInfo('01354673-v', 2), SenseInfo('00141632-v', 1), SenseInfo('02538086-v', 0), SenseInfo('02489456-v', 0), SenseInfo('01658444-v', 0), SenseInfo('01355411-v', 0) ],
"_work_v_for_rel" : [ SenseInfo('02413480-v', 74), SenseInfo('02410855-v', 62), SenseInfo('02525447-v', 32), SenseInfo('01525666-v', 20), SenseInfo('01668603-v', 9), SenseInfo('00100551-v', 9), SenseInfo('02051031-v', 5), SenseInfo('02594979-v', 4), SenseInfo('02373015-v', 3), SenseInfo('01852468-v', 3), SenseInfo('01629589-v', 3), SenseInfo('02407987-v', 2), SenseInfo('01741446-v', 2), SenseInfo('02751271-v', 0), SenseInfo('02536557-v', 0), SenseInfo('02444159-v', 0), SenseInfo('02436963-v', 0), SenseInfo('02116980-v', 0), SenseInfo('01817574-v', 0), SenseInfo('01659248-v', 0), SenseInfo('01541231-v', 0), SenseInfo('01235355-v', 0), SenseInfo('01162754-v', 0), SenseInfo('00634906-v', 0), SenseInfo('00458754-v', 0), SenseInfo('00458471-v', 0), SenseInfo('00150096-v', 0) ],
"_pelt_n_1_rel" : [ SenseInfo('14764061-n', 0), SenseInfo('01895735-n', 0) ],
"_gummy+bear_n_1_rel" : [  ],
"_captivate_v_1_rel" : [ SenseInfo('01806505-v', 2), SenseInfo('01806505-v', 2), SenseInfo('01806505-v', 2) ],
"_aperture_n_1_rel" : [ SenseInfo('02727141-n', 1), SenseInfo('09201031-n', 0), SenseInfo('02727016-n', 0) ],
"_addressee_n_1_rel" : [ SenseInfo('09769345-n', 0) ],
"_happiness_n_1_rel" : [ SenseInfo('13987423-n', 4), SenseInfo('07526757-n', 2) ],
"_category_n_of_rel" : [ SenseInfo('07997703-n', 17), SenseInfo('05838765-n', 3), SenseInfo('07997703-n', 17), SenseInfo('05838765-n', 3) ],
"_producer_n_of_rel" : [ SenseInfo('10292316-n', 9), SenseInfo('10480018-n', 5), SenseInfo('07328756-n', 2) ],
"_ttab_n_1_rel" : [  ],
"_against_p_sel_rel" : [  ],
"_purse_n_1_rel" : [ SenseInfo('02774152-n', 5), SenseInfo('13413294-n', 1), SenseInfo('04026417-n', 1), SenseInfo('13413159-n', 0) ],
"_cafe_n_1_rel" : [ SenseInfo('02935658-n', 5), SenseInfo('02935658-n', 5), SenseInfo('02935658-n', 5), SenseInfo('02935658-n', 5) ],
"_hepatitis_n_1_rel" : [ SenseInfo('14130354-n', 1) ],
"_dramatic_a_1_rel" : [ SenseInfo('00794825-a', 13), SenseInfo('01284212-a', 5), SenseInfo('02714800-a', 0), SenseInfo('01469161-a', 0), SenseInfo('00794825-a', 13), SenseInfo('01284212-a', 5), SenseInfo('02714800-a', 0), SenseInfo('01469161-a', 0) ],
"_shrill_v_1_rel" : [ SenseInfo('00914420-v', 2) ],
"_allow_v_1_rel" : [ SenseInfo('02423183-v', 65), SenseInfo('00802318-v', 49), SenseInfo('02255462-v', 17), SenseInfo('00724150-v', 8), SenseInfo('02721438-v', 3), SenseInfo('00723545-v', 3), SenseInfo('02745486-v', 0), SenseInfo('02423650-v', 0), SenseInfo('02319669-v', 0), SenseInfo('00802946-v', 0), SenseInfo('02423183-v', 65), SenseInfo('00802318-v', 49), SenseInfo('02255462-v', 17), SenseInfo('00724150-v', 8), SenseInfo('02721438-v', 3), SenseInfo('00723545-v', 3), SenseInfo('02745486-v', 0), SenseInfo('02423650-v', 0), SenseInfo('02319669-v', 0), SenseInfo('00802946-v', 0), SenseInfo('02423183-v', 65), SenseInfo('00802318-v', 49), SenseInfo('02255462-v', 17), SenseInfo('00724150-v', 8), SenseInfo('02721438-v', 3), SenseInfo('00723545-v', 3), SenseInfo('02745486-v', 0), SenseInfo('02423650-v', 0), SenseInfo('02319669-v', 0), SenseInfo('00802946-v', 0), SenseInfo('02423183-v', 65), SenseInfo('00802318-v', 49), SenseInfo('02255462-v', 17), SenseInfo('00724150-v', 8), SenseInfo('02721438-v', 3), SenseInfo('00723545-v', 3), SenseInfo('02745486-v', 0), SenseInfo('02423650-v', 0), SenseInfo('02319669-v', 0), SenseInfo('00802946-v', 0) ],
"_grow_v_to_rel" : [ SenseInfo('00125841-v', 70), SenseInfo('00230746-v', 62), SenseInfo('00231557-v', 32), SenseInfo('00245457-v', 12), SenseInfo('00250181-v', 8), SenseInfo('02624263-v', 7), SenseInfo('01739814-v', 3), SenseInfo('00094460-v', 3), SenseInfo('00543410-v', 2), SenseInfo('00250539-v', 0) ],
"_follow_v_through_rel" : [ SenseInfo('01998432-v', 74), SenseInfo('02712772-v', 50), SenseInfo('02720149-v', 26), SenseInfo('01991931-v', 20), SenseInfo('02542280-v', 18), SenseInfo('02720354-v', 17), SenseInfo('00150776-v', 13), SenseInfo('02720544-v', 12), SenseInfo('02346895-v', 9), SenseInfo('02720697-v', 8), SenseInfo('01744450-v', 8), SenseInfo('00729109-v', 4), SenseInfo('02455407-v', 3), SenseInfo('02406585-v', 2), SenseInfo('01728355-v', 1), SenseInfo('00118764-v', 1), SenseInfo('02625339-v', 0), SenseInfo('02600255-v', 0), SenseInfo('02561697-v', 0), SenseInfo('02445925-v', 0), SenseInfo('02198602-v', 0), SenseInfo('02000868-v', 0), SenseInfo('00589738-v', 0), SenseInfo('00351406-v', 0) ],
"_classify_v_as_rel" : [ SenseInfo('00654625-v', 14), SenseInfo('02508803-v', 0), SenseInfo('00739662-v', 0), SenseInfo('00654625-v', 14), SenseInfo('02508803-v', 0), SenseInfo('00739662-v', 0) ],
"_dorsal_a_1_rel" : [ SenseInfo('00132127-a', 0), SenseInfo('00002312-a', 0) ],
"_fifth_a_1_rel" : [ SenseInfo('02202712-a', 13), SenseInfo('02202712-a', 13), SenseInfo('02202712-a', 13) ],
"_denounce_v_1_rel" : [ SenseInfo('00841580-v', 10), SenseInfo('02508245-v', 2), SenseInfo('00842429-v', 1), SenseInfo('00841986-v', 0) ],
"_pasture_v_cause_rel" : [ SenseInfo('01576478-v', 0), SenseInfo('01576165-v', 0) ],
"_snowplow_v_1_rel" : [  ],
"_slaughter_v_1_rel" : [ SenseInfo('01322854-v', 3), SenseInfo('00479176-v', 2) ],
"_multitude_n_of_rel" : [ SenseInfo('13775093-n', 1), SenseInfo('08182716-n', 0), SenseInfo('08180190-n', 0), SenseInfo('13775093-n', 1), SenseInfo('08182716-n', 0), SenseInfo('08180190-n', 0) ],
"_canal_n_1_rel" : [ SenseInfo('09232317-n', 0), SenseInfo('05250659-n', 0), SenseInfo('02947212-n', 0), SenseInfo('09232317-n', 0), SenseInfo('05250659-n', 0), SenseInfo('02947212-n', 0) ],
"_mantel_n_1_rel" : [ SenseInfo('03719343-n', 2) ],
"_slalom_n_1_rel" : [ SenseInfo('07463950-n', 0) ],
"_winner_n_of_rel" : [ SenseInfo('10782940-n', 2), SenseInfo('10782791-n', 0), SenseInfo('09762821-n', 0) ],
"_double+bill_v_for_rel" : [  ],
"_affiliate_n_of_rel" : [ SenseInfo('09776346-n', 0), SenseInfo('08009478-n', 0) ],
"_limp_v_1_rel" : [ SenseInfo('01917244-v', 3), SenseInfo('01996402-v', 1) ],
"_batalion_n_no_rel" : [  ],
"_cemetery_n_1_rel" : [ SenseInfo('08521623-n', 4), SenseInfo('08521623-n', 4) ],
"_hurtful_a_1_rel" : [ SenseInfo('01374361-a', 0), SenseInfo('01161059-a', 0) ],
"_decided_a_1_rel" : [ SenseInfo('00701299-a', 0) ],
"_mulch_n_1_rel" : [ SenseInfo('03797896-n', 5) ],
"_feminist_a_1_rel" : [ SenseInfo('02839357-a', 0) ],
"_significance_n_1_rel" : [ SenseInfo('05169813-n', 21), SenseInfo('05920791-n', 7), SenseInfo('06601327-n', 2) ],
"_influx_n_1_rel" : [ SenseInfo('13499782-n', 1) ],
"_clear_v_1_rel" : [ SenseInfo('00181664-v', 16), SenseInfo('00195617-v', 5), SenseInfo('02771169-v', 2), SenseInfo('00803325-v', 2), SenseInfo('00195342-v', 2), SenseInfo('02523351-v', 1), SenseInfo('02289134-v', 1), SenseInfo('02156844-v', 1), SenseInfo('02081178-v', 1), SenseInfo('00621058-v', 1), SenseInfo('02422409-v', 0), SenseInfo('02350440-v', 0), SenseInfo('02291548-v', 0), SenseInfo('02291258-v', 0), SenseInfo('02289295-v', 0), SenseInfo('02208409-v', 0), SenseInfo('02053490-v', 0), SenseInfo('00904046-v', 0), SenseInfo('00761454-v', 0), SenseInfo('00549217-v', 0), SenseInfo('00450863-v', 0), SenseInfo('00450691-v', 0), SenseInfo('00450565-v', 0), SenseInfo('00178235-v', 0), SenseInfo('00181664-v', 16), SenseInfo('00195617-v', 5), SenseInfo('02771169-v', 2), SenseInfo('00803325-v', 2), SenseInfo('00195342-v', 2), SenseInfo('02523351-v', 1), SenseInfo('02289134-v', 1), SenseInfo('02156844-v', 1), SenseInfo('02081178-v', 1), SenseInfo('00621058-v', 1), SenseInfo('02422409-v', 0), SenseInfo('02350440-v', 0), SenseInfo('02291548-v', 0), SenseInfo('02291258-v', 0), SenseInfo('02289295-v', 0), SenseInfo('02208409-v', 0), SenseInfo('02053490-v', 0), SenseInfo('00904046-v', 0), SenseInfo('00761454-v', 0), SenseInfo('00549217-v', 0), SenseInfo('00450863-v', 0), SenseInfo('00450691-v', 0), SenseInfo('00450565-v', 0), SenseInfo('00178235-v', 0) ],
"_scribble_v_1_rel" : [ SenseInfo('01006239-v', 1), SenseInfo('01747203-v', 0) ],
"_no+more+than_a_1_rel" : [  ],
"_classic_a_1_rel" : [ SenseInfo('02295098-a', 6), SenseInfo('00413622-a', 0), SenseInfo('00413861-a', 0) ],
"_out+of+core_a_1_rel" : [  ],
"_gesture_v_at_rel" : [ SenseInfo('00992041-v', 3) ],
"_silt_n_1_rel" : [ SenseInfo('15042052-n', 0) ],
"_expound_v_on-upon_rel" : [ SenseInfo('00955601-v', 3), SenseInfo('01001294-v', 0), SenseInfo('00955601-v', 3), SenseInfo('01001294-v', 0) ],
"_especially_x_deg_rel" : [ SenseInfo('00084223-r', 66), SenseInfo('00502710-r', 0) ],
"_snooze_n_1_rel" : [ SenseInfo('00858377-n', 0) ],
"_sidle_v_1_rel" : [ SenseInfo('01869299-v', 2), SenseInfo('01869196-v', 2) ],
"_steeple_n_1_rel" : [ SenseInfo('04312432-n', 12) ],
"_shed_n_1_rel" : [ SenseInfo('04187547-n', 1) ],
"_cineaste_n_1_rel" : [  ],
"_admirable_a_1_rel" : [ SenseInfo('00904290-a', 4), SenseInfo('01807605-a', 2) ],
"_leaf_v_through_rel" : [ SenseInfo('02153023-v', 0), SenseInfo('02089837-v', 0), SenseInfo('00095747-v', 0) ],
"_recreational_a_1_rel" : [ SenseInfo('02787831-a', 1), SenseInfo('01869634-a', 1) ],
"_wake_v_1_rel" : [ SenseInfo('00020133-v', 7), SenseInfo('00018526-v', 3), SenseInfo('01761120-v', 0), SenseInfo('00872747-v', 0), SenseInfo('00018813-v', 0) ],
"_committeeman_n_1_rel" : [ SenseInfo('09944337-n', 3) ],
"_baby_v_1_rel" : [ SenseInfo('02570267-v', 0) ],
"_backwards_a_1_rel" : [  ],
"_buy_v_from_rel" : [ SenseInfo('02207206-v', 102), SenseInfo('02284096-v', 2), SenseInfo('02646757-v', 0), SenseInfo('02212103-v', 0), SenseInfo('00683670-v', 0) ],
"_lunch_v_1_rel" : [ SenseInfo('01185304-v', 1), SenseInfo('01185475-v', 0) ],
"_disparaging_a_1_rel" : [ SenseInfo('00907032-a', 0) ],
"_sight-see_v_1_rel" : [ SenseInfo('01843904-v', 0), SenseInfo('01843904-v', 0), SenseInfo('01843904-v', 0) ],
"_sheaf_n_1_rel" : [ SenseInfo('02919414-n', 1) ],
"_spindle_n_1_rel" : [ SenseInfo('05605498-n', 0), SenseInfo('04277669-n', 0), SenseInfo('04277493-n', 0), SenseInfo('04277352-n', 0), SenseInfo('04276050-n', 0) ],
"_agenda_n_1_rel" : [ SenseInfo('05910940-n', 3), SenseInfo('06485261-n', 0) ],
"_anneal_v_cause_rel" : [ SenseInfo('00303056-v', 0) ],
"_lawyers_a_1_rel" : [  ],
"_install_v_1_rel" : [ SenseInfo('01569566-v', 28), SenseInfo('02384041-v', 1), SenseInfo('01570108-v', 0), SenseInfo('01569566-v', 28), SenseInfo('02384041-v', 1), SenseInfo('01570108-v', 0) ],
"_ferret_n_1_rel" : [ SenseInfo('02443484-n', 0), SenseInfo('02443346-n', 0) ],
"_starter_n_of_rel" : [ SenseInfo('04304375-n', 1), SenseInfo('10649438-n', 0), SenseInfo('10649308-n', 0), SenseInfo('10355449-n', 0), SenseInfo('07581346-n', 0), SenseInfo('03127024-n', 0), SenseInfo('00920727-n', 0) ],
"_tariff_n_1_rel" : [ SenseInfo('13315999-n', 2) ],
"_treehouse_n_1_rel" : [  ],
"_double_v_1_rel" : [ SenseInfo('00246217-v', 12), SenseInfo('01409523-v', 2), SenseInfo('02063309-v', 1), SenseInfo('01525505-v', 1), SenseInfo('02300425-v', 0), SenseInfo('01734502-v', 0) ],
"_syllable_n_1_rel" : [ SenseInfo('06304671-n', 11) ],
"_across-the-board_p_1_rel" : [ SenseInfo('00526062-a', 0), SenseInfo('00526062-a', 0) ],
"_lean_v_1_rel" : [ SenseInfo('02038357-v', 24), SenseInfo('01606574-v', 6), SenseInfo('02719399-v', 3), SenseInfo('00688261-v', 1), SenseInfo('02039013-v', 0) ],
"_bribery_n_1_rel" : [ SenseInfo('00776262-n', 0) ],
"_rude_a_of_rel" : [ SenseInfo('00641944-a', 2), SenseInfo('01950857-a', 1), SenseInfo('00642725-a', 0), SenseInfo('01952643-a', 0), SenseInfo('00818175-a', 0), SenseInfo('00641944-a', 2), SenseInfo('01950857-a', 1), SenseInfo('00642725-a', 0), SenseInfo('01952643-a', 0), SenseInfo('00818175-a', 0), SenseInfo('00641944-a', 2), SenseInfo('01950857-a', 1), SenseInfo('00642725-a', 0), SenseInfo('01952643-a', 0), SenseInfo('00818175-a', 0), SenseInfo('00641944-a', 2), SenseInfo('01950857-a', 1), SenseInfo('00642725-a', 0), SenseInfo('01952643-a', 0), SenseInfo('00818175-a', 0) ],
"_of+course_a_1_rel" : [  ],
"_acquit_v_of_rel" : [ SenseInfo('00904046-v', 1), SenseInfo('02518161-v', 0), SenseInfo('00904046-v', 1), SenseInfo('02518161-v', 0) ],
"_spotty_a_1_rel" : [ SenseInfo('01789481-a', 0), SenseInfo('00578662-a', 0), SenseInfo('01789481-a', 0), SenseInfo('00578662-a', 0), SenseInfo('01789481-a', 0), SenseInfo('00578662-a', 0) ],
"_canteen_n_1_rel" : [ SenseInfo('02952374-n', 12), SenseInfo('02952798-n', 0), SenseInfo('02952674-n', 0), SenseInfo('02952585-n', 0), SenseInfo('02952485-n', 0) ],
"_altitude_n_1_rel" : [ SenseInfo('05131647-n', 3), SenseInfo('13897657-n', 0), SenseInfo('13836550-n', 0) ],
"_precious_a_1_rel" : [ SenseInfo('01462625-a', 7), SenseInfo('02501534-a', 3), SenseInfo('02587556-a', 0), SenseInfo('00148642-a', 0), SenseInfo('01462625-a', 7), SenseInfo('02501534-a', 3), SenseInfo('02587556-a', 0), SenseInfo('00148642-a', 0) ],
"_learn_v_1_rel" : [ SenseInfo('00597915-v', 90), SenseInfo('00598954-v', 53), SenseInfo('00604576-v', 6), SenseInfo('00599992-v', 3), SenseInfo('00829107-v', 2), SenseInfo('00920336-v', 0), SenseInfo('00597915-v', 90), SenseInfo('00598954-v', 53), SenseInfo('00604576-v', 6), SenseInfo('00599992-v', 3), SenseInfo('00829107-v', 2), SenseInfo('00920336-v', 0), SenseInfo('00597915-v', 90), SenseInfo('00598954-v', 53), SenseInfo('00604576-v', 6), SenseInfo('00599992-v', 3), SenseInfo('00829107-v', 2), SenseInfo('00920336-v', 0), SenseInfo('00597915-v', 90), SenseInfo('00598954-v', 53), SenseInfo('00604576-v', 6), SenseInfo('00599992-v', 3), SenseInfo('00829107-v', 2), SenseInfo('00920336-v', 0) ],
"_rye_a_1_rel" : [ SenseInfo('12157179-n', 0), SenseInfo('12134025-n', 0), SenseInfo('07907429-n', 0) ],
"_unrealistic_a_1_rel" : [ SenseInfo('01941999-a', 2), SenseInfo('01941999-a', 2), SenseInfo('01941999-a', 2) ],
"_aquarium_n_1_rel" : [ SenseInfo('02732072-n', 0) ],
"_dig_v_out_rel" : [ SenseInfo('01309701-v', 9), SenseInfo('01311103-v', 5), SenseInfo('02419773-v', 0), SenseInfo('02143756-v', 0), SenseInfo('01899557-v', 0), SenseInfo('01310660-v', 0), SenseInfo('01229976-v', 0), SenseInfo('00588221-v', 0) ],
"_why+then_a_1_rel" : [  ],
"_clinic_n_1_rel" : [ SenseInfo('08054076-n', 0), SenseInfo('07146300-n', 0), SenseInfo('03043274-n', 0) ],
"_fuzz_n_1_rel" : [ SenseInfo('13090091-n', 1), SenseInfo('09879144-n', 0), SenseInfo('05940414-n', 0), SenseInfo('05261894-n', 0) ],
"_scanner_n_of_rel" : [ SenseInfo('10555156-n', 0), SenseInfo('04143140-n', 0), SenseInfo('04142999-n', 0), SenseInfo('04142731-n', 0) ],
"_spun-off_a_1_rel" : [  ],
"_parrot_n_1_rel" : [ SenseInfo('01816887-n', 1), SenseInfo('10401331-n', 0) ],
"_shall_v_modal_rel" : [  ],
"_cringe_n_1_rel" : [  ],
"_herring_n_1_rel" : [ SenseInfo('07784522-n', 0), SenseInfo('02532028-n', 0) ],
"_birdwatch_v_1_rel" : [ SenseInfo('01139865-v', 0) ],
"_invalid_a_1_rel" : [ SenseInfo('02499750-a', 0), SenseInfo('00938210-a', 0) ],
"_carving_n_1_rel" : [ SenseInfo('02973558-n', 2), SenseInfo('00942234-n', 0), SenseInfo('00937656-n', 0) ],
"_sublimation_n_of_rel" : [ SenseInfo('07360293-n', 0), SenseInfo('07297927-n', 0) ],
"_practice_v_upon_rel" : [ SenseInfo('02568672-v', 11), SenseInfo('00606093-v', 7), SenseInfo('01723224-v', 5), SenseInfo('02561332-v', 2), SenseInfo('02375468-v', 0), SenseInfo('02568672-v', 11), SenseInfo('00606093-v', 7), SenseInfo('01723224-v', 5), SenseInfo('02561332-v', 2), SenseInfo('02375468-v', 0) ],
"_poconos_n_1_rel" : [  ],
"_gather_v_coll_rel" : [ SenseInfo('01380638-v', 23), SenseInfo('02428924-v', 7), SenseInfo('00158804-v', 3), SenseInfo('00945125-v', 2), SenseInfo('01330822-v', 1), SenseInfo('02598143-v', 0), SenseInfo('01349893-v', 0), SenseInfo('01316619-v', 0), SenseInfo('00157462-v', 0) ],
"_christian_n_1_rel" : [ SenseInfo('09678009-n', 10) ],
"_precursor_n_1_rel" : [ SenseInfo('14583066-n', 0), SenseInfo('09627117-n', 0), SenseInfo('06802571-n', 0) ],
"_grouping_n_1_rel" : [ SenseInfo('00031264-n', 5), SenseInfo('01012360-n', 1), SenseInfo('05733090-n', 0) ],
"_brightest_n_1_rel" : [  ],
"_fair_a_1_rel" : [ SenseInfo('00956131-a', 10), SenseInfo('01532261-a', 2), SenseInfo('00218440-a', 1), SenseInfo('00955626-a', 0), SenseInfo('01673061-a', 0), SenseInfo('01484342-a', 0), SenseInfo('01404898-a', 0), SenseInfo('00958475-a', 0), SenseInfo('00461091-a', 0), SenseInfo('00244054-a', 0), SenseInfo('00956131-a', 10), SenseInfo('01532261-a', 2), SenseInfo('00218440-a', 1), SenseInfo('00955626-a', 0), SenseInfo('01673061-a', 0), SenseInfo('01484342-a', 0), SenseInfo('01404898-a', 0), SenseInfo('00958475-a', 0), SenseInfo('00461091-a', 0), SenseInfo('00244054-a', 0), SenseInfo('00956131-a', 10), SenseInfo('01532261-a', 2), SenseInfo('00218440-a', 1), SenseInfo('00955626-a', 0), SenseInfo('01673061-a', 0), SenseInfo('01484342-a', 0), SenseInfo('01404898-a', 0), SenseInfo('00958475-a', 0), SenseInfo('00461091-a', 0), SenseInfo('00244054-a', 0), SenseInfo('00956131-a', 10), SenseInfo('01532261-a', 2), SenseInfo('00218440-a', 1), SenseInfo('00955626-a', 0), SenseInfo('01673061-a', 0), SenseInfo('01484342-a', 0), SenseInfo('01404898-a', 0), SenseInfo('00958475-a', 0), SenseInfo('00461091-a', 0), SenseInfo('00244054-a', 0) ],
"_heritage_n_1_rel" : [ SenseInfo('05669797-n', 6), SenseInfo('04921011-n', 2), SenseInfo('13262913-n', 0), SenseInfo('00083585-n', 0) ],
"_hat_n_1_rel" : [ SenseInfo('03497657-n', 30), SenseInfo('00721141-n', 0) ],
"_out_p_sel_rel" : [ SenseInfo('00232862-r', 5), SenseInfo('02061487-a', 3), SenseInfo('00100213-a', 2), SenseInfo('01823948-a', 1), SenseInfo('00129527-n', 0), SenseInfo('00233413-r', 0), SenseInfo('00233295-r', 0), SenseInfo('02334973-a', 0), SenseInfo('01761375-a', 0), SenseInfo('01295946-a', 0), SenseInfo('00974908-a', 0), SenseInfo('00952653-a', 0), SenseInfo('00949797-a', 0), SenseInfo('00572714-a', 0), SenseInfo('00935456-v', 0), SenseInfo('00935264-v', 0), SenseInfo('00935141-v', 0) ],
"_polysemy_n_1_rel" : [ SenseInfo('04825576-n', 0) ],
"_thump_v_1_rel" : [ SenseInfo('01880113-v', 3), SenseInfo('02184610-v', 1), SenseInfo('01414626-v', 1) ],
"_bail_v_out_rel" : [ SenseInfo('02421749-v', 0), SenseInfo('02293732-v', 0), SenseInfo('00890403-v', 0), SenseInfo('00177136-v', 0), SenseInfo('00177011-v', 0) ],
"_barrenness_n_1_rel" : [ SenseInfo('14045347-n', 0), SenseInfo('05148186-n', 0) ],
"_schoolgirl_n_1_rel" : [ SenseInfo('10559603-n', 2) ],
"_mountaineering_n_1_rel" : [ SenseInfo('00325785-n', 0) ],
"_pap_n_1_rel" : [ SenseInfo('06612174-n', 1), SenseInfo('07564796-n', 0), SenseInfo('05554653-n', 0) ],
"_kalanchoe_n_1_rel" : [  ],
"_attest_v_1_rel" : [ SenseInfo('00820976-v', 2), SenseInfo('00820352-v', 1), SenseInfo('01014821-v', 0), SenseInfo('00820611-v', 0), SenseInfo('00820976-v', 2), SenseInfo('00820352-v', 1), SenseInfo('01014821-v', 0), SenseInfo('00820611-v', 0), SenseInfo('00820976-v', 2), SenseInfo('00820352-v', 1), SenseInfo('01014821-v', 0), SenseInfo('00820611-v', 0) ],
"_transverse_a_1_rel" : [ SenseInfo('01445917-a', 4) ],
"_bother_v_1_rel" : [ SenseInfo('02507464-v', 18), SenseInfo('01787955-v', 16), SenseInfo('02507736-v', 8), SenseInfo('02018858-v', 0), SenseInfo('01791535-v', 0), SenseInfo('01791408-v', 0), SenseInfo('02507464-v', 18), SenseInfo('01787955-v', 16), SenseInfo('02507736-v', 8), SenseInfo('02018858-v', 0), SenseInfo('01791535-v', 0), SenseInfo('01791408-v', 0), SenseInfo('02507464-v', 18), SenseInfo('01787955-v', 16), SenseInfo('02507736-v', 8), SenseInfo('02018858-v', 0), SenseInfo('01791535-v', 0), SenseInfo('01791408-v', 0), SenseInfo('02507464-v', 18), SenseInfo('01787955-v', 16), SenseInfo('02507736-v', 8), SenseInfo('02018858-v', 0), SenseInfo('01791535-v', 0), SenseInfo('01791408-v', 0) ],
"_surgical_a_1_rel" : [ SenseInfo('02888968-a', 0), SenseInfo('01169194-a', 0), SenseInfo('00022852-a', 0) ],
"_boot_v_1_rel" : [ SenseInfo('01372556-v', 0), SenseInfo('00098346-v', 0) ],
"_amaze_v_1_rel" : [ SenseInfo('00724832-v', 4), SenseInfo('00622384-v', 1), SenseInfo('00724832-v', 4), SenseInfo('00622384-v', 1) ],
"_suggestive_a_1_rel" : [ SenseInfo('00723542-a', 1), SenseInfo('02091300-a', 0), SenseInfo('00684334-a', 0) ],
"_spoonful_n_1_rel" : [ SenseInfo('13770169-n', 1) ],
"_irrevocable_a_1_rel" : [ SenseInfo('01760670-a', 1) ],
"_stub_n_1_rel" : [ SenseInfo('09449657-n', 1), SenseInfo('09374646-n', 0), SenseInfo('06520429-n', 0), SenseInfo('06507815-n', 0), SenseInfo('02927399-n', 0) ],
"_conflict_v_on_rel" : [ SenseInfo('02667228-v', 2), SenseInfo('02567147-v', 1) ],
"_aground_a_1_rel" : [ SenseInfo('00077449-a', 0) ],
"_buy-in_n_1_rel" : [  ],
"_sulk_v_1_rel" : [ SenseInfo('02719016-v', 0) ],
"_bankers_a_1_rel" : [  ],
"_chain_v_to_rel" : [ SenseInfo('01464931-v', 0), SenseInfo('01288636-v', 0), SenseInfo('01464931-v', 0), SenseInfo('01288636-v', 0) ],
"_specification_n_for_rel" : [ SenseInfo('06725067-n', 1), SenseInfo('07231199-n', 0), SenseInfo('06675338-n', 0), SenseInfo('01149303-n', 0), SenseInfo('06725067-n', 1), SenseInfo('07231199-n', 0), SenseInfo('06675338-n', 0), SenseInfo('01149303-n', 0) ],
"_ongoing_a_1_rel" : [ SenseInfo('00667822-a', 0), SenseInfo('00667822-a', 0), SenseInfo('00667822-a', 0) ],
"_homing_a_1_rel" : [ SenseInfo('01685231-a', 0) ],
"_dichondra_n_1_rel" : [ SenseInfo('12826143-n', 1) ],
"_top+to+bottom_p_rel" : [  ],
"_fool_v_1_rel" : [ SenseInfo('02576349-v', 6), SenseInfo('01195804-v', 0), SenseInfo('00854904-v', 0), SenseInfo('00854150-v', 0), SenseInfo('02576349-v', 6), SenseInfo('01195804-v', 0), SenseInfo('00854904-v', 0), SenseInfo('00854150-v', 0) ],
"_bar_n_1_rel" : [ SenseInfo('02796995-n', 10), SenseInfo('02789487-n', 4), SenseInfo('02788689-n', 4), SenseInfo('06864725-n', 1), SenseInfo('02789271-n', 1), SenseInfo('01077350-n', 1), SenseInfo('13711855-n', 0), SenseInfo('09214060-n', 0), SenseInfo('08112402-n', 0), SenseInfo('04683136-n', 0), SenseInfo('02937469-n', 0), SenseInfo('02907391-n', 0), SenseInfo('02790154-n', 0), SenseInfo('02790012-n', 0), SenseInfo('02789770-n', 0) ],
"_pharmacist_n_1_rel" : [ SenseInfo('10421470-n', 1) ],
"_flatter_v_1_rel" : [ SenseInfo('00880227-v', 7), SenseInfo('00880227-v', 7), SenseInfo('00880227-v', 7), SenseInfo('00880227-v', 7) ],
"_seller_n_of_rel" : [ SenseInfo('10577284-n', 0) ],
"_teensy_a_1_rel" : [ SenseInfo('01392633-a', 1), SenseInfo('01392633-a', 1), SenseInfo('01392633-a', 1) ],
"_relay_n_of_rel" : [ SenseInfo('00318567-n', 1), SenseInfo('08218965-n', 0), SenseInfo('07985533-n', 0), SenseInfo('07464083-n', 0), SenseInfo('04072960-n', 0) ],
"_can_v_1_rel" : [ SenseInfo('00213794-v', 2), SenseInfo('02402825-v', 1) ],
"_fellow_n_1_rel" : [ SenseInfo('09908025-n', 48), SenseInfo('09945905-n', 20), SenseInfo('09935990-n', 18), SenseInfo('13743100-n', 0), SenseInfo('10083526-n', 0), SenseInfo('10083358-n', 0), SenseInfo('09871364-n', 0) ],
"_egyptian_n_1_rel" : [ SenseInfo('09700492-n', 0), SenseInfo('06990000-n', 0) ],
"_viselike_a_1_rel" : [ SenseInfo('01448362-a', 1) ],
"_darken_v_1_rel" : [ SenseInfo('00312380-v', 4), SenseInfo('01537829-v', 0), SenseInfo('00311559-v', 0) ],
"_underhanded_a_1_rel" : [ SenseInfo('02319346-a', 1), SenseInfo('02470531-a', 0) ],
"_nail_v_up_rel" : [ SenseInfo('01357831-v', 8), SenseInfo('01215137-v', 2), SenseInfo('01401772-v', 1), SenseInfo('02524897-v', 0), SenseInfo('02522581-v', 0), SenseInfo('02287380-v', 0), SenseInfo('01117484-v', 0) ],
"_discernment_n_1_rel" : [ SenseInfo('05805475-n', 0), SenseInfo('05749619-n', 0), SenseInfo('05710210-n', 0), SenseInfo('05614175-n', 0), SenseInfo('04891010-n', 0) ],
"_push_v_back_rel" : [ SenseInfo('01871979-v', 56), SenseInfo('00765977-v', 7), SenseInfo('00976653-v', 6), SenseInfo('02406916-v', 3), SenseInfo('01872645-v', 3), SenseInfo('02054864-v', 1), SenseInfo('02589576-v', 0), SenseInfo('02245555-v', 0), SenseInfo('01872877-v', 0), SenseInfo('01447632-v', 0), SenseInfo('01871979-v', 56), SenseInfo('00765977-v', 7), SenseInfo('00976653-v', 6), SenseInfo('02406916-v', 3), SenseInfo('01872645-v', 3), SenseInfo('02054864-v', 1), SenseInfo('02589576-v', 0), SenseInfo('02245555-v', 0), SenseInfo('01872877-v', 0), SenseInfo('01447632-v', 0) ],
"_method_n_of_rel" : [ SenseInfo('05660268-n', 95), SenseInfo('00549766-n', 0), SenseInfo('05660268-n', 95), SenseInfo('00549766-n', 0) ],
"_crank_v_1_rel" : [ SenseInfo('01991744-v', 0), SenseInfo('01858796-v', 0), SenseInfo('01595149-v', 0), SenseInfo('01341815-v', 0), SenseInfo('01280958-v', 0) ],
"_naught_n_1_rel" : [ SenseInfo('13740168-n', 1), SenseInfo('00067153-n', 0) ],
"_lease_v_from_rel" : [ SenseInfo('02460199-v', 2), SenseInfo('02460619-v', 0), SenseInfo('02208903-v', 0), SenseInfo('02208537-v', 0) ],
"_unbearable_a_1_rel" : [ SenseInfo('02435671-a', 0), SenseInfo('02435671-a', 0), SenseInfo('02435671-a', 0) ],
"_waterlogged_a_1_rel" : [ SenseInfo('02548066-a', 0) ],
"_shut_v_down_rel" : [ SenseInfo('01345109-v', 10), SenseInfo('01346978-v', 2), SenseInfo('02449340-v', 1), SenseInfo('01345109-v', 10), SenseInfo('01346978-v', 2), SenseInfo('02449340-v', 1) ],
"_informational_a_1_rel" : [ SenseInfo('02749150-a', 0) ],
"_addiction_n_to_rel" : [ SenseInfo('14062725-n', 0), SenseInfo('07486145-n', 0), SenseInfo('00087849-n', 0) ],
"_uncomplicated_a_1_rel" : [ SenseInfo('02175980-a', 0), SenseInfo('00750296-a', 0), SenseInfo('02175980-a', 0), SenseInfo('00750296-a', 0) ],
"_luxury_n_1_rel" : [ SenseInfo('05119223-n', 5), SenseInfo('05146471-n', 1), SenseInfo('14492373-n', 0) ],
"_deadline_n_of_rel" : [ SenseInfo('15180082-n', 2) ],
"_mess_v_with_rel" : [ SenseInfo('01176079-v', 0), SenseInfo('00276214-v', 0) ],
"_incompetent_a_1_rel" : [ SenseInfo('00512261-a', 0), SenseInfo('00511214-a', 0), SenseInfo('02229324-a', 0), SenseInfo('01128103-a', 0), SenseInfo('00052246-a', 0), SenseInfo('00512261-a', 0), SenseInfo('00511214-a', 0), SenseInfo('02229324-a', 0), SenseInfo('01128103-a', 0), SenseInfo('00052246-a', 0) ],
"_geometry_n_1_rel" : [ SenseInfo('06004685-n', 3), SenseInfo('06004685-n', 3) ],
"_hulk_n_1_rel" : [ SenseInfo('10129133-n', 1), SenseInfo('03548533-n', 1) ],
"_expedient_n_1_rel" : [ SenseInfo('00177448-n', 0) ],
"_fetter_n_1_rel" : [ SenseInfo('03330947-n', 0) ],
"_portable_n_1_rel" : [ SenseInfo('03985069-n', 0) ],
"_ballyhoo_v_1_rel" : [ SenseInfo('00976365-v', 0) ],
"_decorative_a_1_rel" : [ SenseInfo('01091234-a', 1) ],
"_share_v_1_rel" : [ SenseInfo('02718309-v', 23), SenseInfo('02295550-v', 19), SenseInfo('02295208-v', 15), SenseInfo('02294179-v', 4), SenseInfo('01063930-v', 1) ],
"_ephemeral_a_1_rel" : [ SenseInfo('01756292-a', 1) ],
"_dash_v_2_rel" : [ SenseInfo('02061495-v', 7), SenseInfo('00335923-v', 2), SenseInfo('01507407-v', 1), SenseInfo('02558703-v', 0), SenseInfo('01785748-v', 0), SenseInfo('00184377-v', 0) ],
"_nigger_n_1_rel" : [ SenseInfo('09638009-n', 15) ],
"_meet_v_up_rel" : [ SenseInfo('02023107-v', 49), SenseInfo('02486932-v', 38), SenseInfo('02710402-v', 32), SenseInfo('01183573-v', 23), SenseInfo('02667900-v', 18), SenseInfo('02594674-v', 15), SenseInfo('02428924-v', 14), SenseInfo('02596113-v', 12), SenseInfo('02022804-v', 11), SenseInfo('01079480-v', 8), SenseInfo('02739480-v', 7), SenseInfo('02110082-v', 3), SenseInfo('01205696-v', 1), SenseInfo('02023107-v', 49), SenseInfo('02486932-v', 38), SenseInfo('02710402-v', 32), SenseInfo('01183573-v', 23), SenseInfo('02667900-v', 18), SenseInfo('02594674-v', 15), SenseInfo('02428924-v', 14), SenseInfo('02596113-v', 12), SenseInfo('02022804-v', 11), SenseInfo('01079480-v', 8), SenseInfo('02739480-v', 7), SenseInfo('02110082-v', 3), SenseInfo('01205696-v', 1) ],
"_encircle_v_1_rel" : [ SenseInfo('01522716-v', 0), SenseInfo('01302854-v', 0) ],
"_lymphatic_n_1_rel" : [ SenseInfo('02831031-a', 0) ],
"_obligate_v_1_rel" : [ SenseInfo('02506546-v', 0), SenseInfo('02348182-v', 0), SenseInfo('00885217-v', 0) ],
"_exact_a_1_rel" : [ SenseInfo('00914421-a', 8), SenseInfo('00631798-a', 7), SenseInfo('00914421-a', 8), SenseInfo('00631798-a', 7), SenseInfo('00914421-a', 8), SenseInfo('00631798-a', 7), SenseInfo('00914421-a', 8), SenseInfo('00631798-a', 7) ],
"_leap_v_1_rel" : [ SenseInfo('01963942-v', 22), SenseInfo('00560391-v', 1), SenseInfo('02105082-v', 0), SenseInfo('01965156-v', 0) ],
"_throughput_n_1_rel" : [ SenseInfo('04429756-n', 0) ],
"_lilt_v_1_rel" : [ SenseInfo('00950936-v', 0) ],
"_dye_v_1_rel" : [ SenseInfo('00283090-v', 1), SenseInfo('00283090-v', 1) ],
"_shoulder_v_1_rel" : [ SenseInfo('01239359-v', 2), SenseInfo('01238907-v', 2), SenseInfo('01239054-v', 0) ],
"_male-only_a_1_rel" : [  ],
"_dump_v_1_rel" : [ SenseInfo('02225204-v', 12), SenseInfo('02224945-v', 1), SenseInfo('02350878-v', 0), SenseInfo('01977545-v', 0), SenseInfo('01977080-v', 0), SenseInfo('01412346-v', 0), SenseInfo('02225204-v', 12), SenseInfo('02224945-v', 1), SenseInfo('02350878-v', 0), SenseInfo('01977545-v', 0), SenseInfo('01977080-v', 0), SenseInfo('01412346-v', 0) ],
"_flicker_v_1_rel" : [ SenseInfo('01878719-v', 3), SenseInfo('02763609-v', 0), SenseInfo('02160177-v', 0) ],
"_conservation_n_of_rel" : [ SenseInfo('07419599-n', 2), SenseInfo('00819274-n', 1), SenseInfo('06104073-n', 0) ],
"_my_a_1_rel" : [  ],
"_pka_n_1_rel" : [  ],
"_sentimental_a_1_rel" : [ SenseInfo('02449287-a', 1), SenseInfo('00854413-a', 1) ],
"_bulk_n_1_rel" : [ SenseInfo('05122557-n', 5), SenseInfo('05099389-n', 1), SenseInfo('05025413-n', 0) ],
"_finalize_v_1_rel" : [ SenseInfo('00481941-v', 0) ],
"_folkdance_n_1_rel" : [  ],
"_out_a_1_rel" : [ SenseInfo('02061487-a', 3), SenseInfo('00100213-a', 2), SenseInfo('01823948-a', 1), SenseInfo('02334973-a', 0), SenseInfo('01761375-a', 0), SenseInfo('01295946-a', 0), SenseInfo('00974908-a', 0), SenseInfo('00952653-a', 0), SenseInfo('00949797-a', 0), SenseInfo('00572714-a', 0), SenseInfo('02061487-a', 3), SenseInfo('00100213-a', 2), SenseInfo('01823948-a', 1), SenseInfo('02334973-a', 0), SenseInfo('01761375-a', 0), SenseInfo('01295946-a', 0), SenseInfo('00974908-a', 0), SenseInfo('00952653-a', 0), SenseInfo('00949797-a', 0), SenseInfo('00572714-a', 0) ],
"_degree_n_cel_rel" : [ SenseInfo('05093890-n', 25), SenseInfo('13939892-n', 17), SenseInfo('06697331-n', 13), SenseInfo('13611207-n', 7), SenseInfo('05861317-n', 6), SenseInfo('13714184-n', 1), SenseInfo('05094565-n', 0), SenseInfo('05093890-n', 25), SenseInfo('13939892-n', 17), SenseInfo('06697331-n', 13), SenseInfo('13611207-n', 7), SenseInfo('05861317-n', 6), SenseInfo('13714184-n', 1), SenseInfo('05094565-n', 0), SenseInfo('05093890-n', 25), SenseInfo('13939892-n', 17), SenseInfo('06697331-n', 13), SenseInfo('13611207-n', 7), SenseInfo('05861317-n', 6), SenseInfo('13714184-n', 1), SenseInfo('05094565-n', 0), SenseInfo('05093890-n', 25), SenseInfo('13939892-n', 17), SenseInfo('06697331-n', 13), SenseInfo('13611207-n', 7), SenseInfo('05861317-n', 6), SenseInfo('13714184-n', 1), SenseInfo('05094565-n', 0), SenseInfo('05093890-n', 25), SenseInfo('13939892-n', 17), SenseInfo('06697331-n', 13), SenseInfo('13611207-n', 7), SenseInfo('05861317-n', 6), SenseInfo('13714184-n', 1), SenseInfo('05094565-n', 0), SenseInfo('05093890-n', 25), SenseInfo('13939892-n', 17), SenseInfo('06697331-n', 13), SenseInfo('13611207-n', 7), SenseInfo('05861317-n', 6), SenseInfo('13714184-n', 1), SenseInfo('05094565-n', 0), SenseInfo('05093890-n', 25), SenseInfo('13939892-n', 17), SenseInfo('06697331-n', 13), SenseInfo('13611207-n', 7), SenseInfo('05861317-n', 6), SenseInfo('13714184-n', 1), SenseInfo('05094565-n', 0), SenseInfo('05093890-n', 25), SenseInfo('13939892-n', 17), SenseInfo('06697331-n', 13), SenseInfo('13611207-n', 7), SenseInfo('05861317-n', 6), SenseInfo('13714184-n', 1), SenseInfo('05094565-n', 0) ],
"_hull_v_1_rel" : [ SenseInfo('00180076-v', 0) ],
"_plumb_v_1_rel" : [ SenseInfo('00730647-v', 1), SenseInfo('01487830-v', 0), SenseInfo('00646442-v', 0), SenseInfo('00465634-v', 0) ],
"_arrangement_n_of_rel" : [ SenseInfo('05795044-n', 13), SenseInfo('07938773-n', 4), SenseInfo('05726596-n', 4), SenseInfo('05075602-n', 2), SenseInfo('07038400-n', 1), SenseInfo('00939628-n', 0), SenseInfo('05795044-n', 13), SenseInfo('07938773-n', 4), SenseInfo('05726596-n', 4), SenseInfo('05075602-n', 2), SenseInfo('07038400-n', 1), SenseInfo('00939628-n', 0) ],
"_fiber_n_1_rel" : [ SenseInfo('14866889-n', 14), SenseInfo('07568818-n', 0), SenseInfo('05229622-n', 0), SenseInfo('04620216-n', 0), SenseInfo('03331244-n', 0), SenseInfo('14866889-n', 14), SenseInfo('07568818-n', 0), SenseInfo('05229622-n', 0), SenseInfo('04620216-n', 0), SenseInfo('03331244-n', 0), SenseInfo('14866889-n', 14), SenseInfo('07568818-n', 0), SenseInfo('05229622-n', 0), SenseInfo('04620216-n', 0), SenseInfo('03331244-n', 0), SenseInfo('14866889-n', 14), SenseInfo('07568818-n', 0), SenseInfo('05229622-n', 0), SenseInfo('04620216-n', 0), SenseInfo('03331244-n', 0) ],
"_straddle_v_1_rel" : [ SenseInfo('02705913-v', 4), SenseInfo('02690384-v', 1), SenseInfo('02705832-v', 0) ],
"_of_p_rel" : [  ],
"_complain_v_to-about_rel" : [ SenseInfo('00907147-v', 29), SenseInfo('00844298-v', 0), SenseInfo('00907147-v', 29), SenseInfo('00844298-v', 0) ],
"_fork_v_out_rel" : [ SenseInfo('01579340-v', 0), SenseInfo('01118888-v', 0), SenseInfo('00328802-v', 0), SenseInfo('00141914-v', 0) ],
"_immensity_n_1_rel" : [ SenseInfo('05104548-n', 1) ],
"_advance_v_1_rel" : [ SenseInfo('01992503-v', 7), SenseInfo('00875806-v', 6), SenseInfo('00497061-v', 5), SenseInfo('02554922-v', 4), SenseInfo('01993926-v', 4), SenseInfo('01111028-v', 3), SenseInfo('00248659-v', 2), SenseInfo('00558371-v', 1), SenseInfo('02397637-v', 0), SenseInfo('02283949-v', 0), SenseInfo('01994288-v', 0), SenseInfo('00158222-v', 0), SenseInfo('01992503-v', 7), SenseInfo('00875806-v', 6), SenseInfo('00497061-v', 5), SenseInfo('02554922-v', 4), SenseInfo('01993926-v', 4), SenseInfo('01111028-v', 3), SenseInfo('00248659-v', 2), SenseInfo('00558371-v', 1), SenseInfo('02397637-v', 0), SenseInfo('02283949-v', 0), SenseInfo('01994288-v', 0), SenseInfo('00158222-v', 0), SenseInfo('01992503-v', 7), SenseInfo('00875806-v', 6), SenseInfo('00497061-v', 5), SenseInfo('02554922-v', 4), SenseInfo('01993926-v', 4), SenseInfo('01111028-v', 3), SenseInfo('00248659-v', 2), SenseInfo('00558371-v', 1), SenseInfo('02397637-v', 0), SenseInfo('02283949-v', 0), SenseInfo('01994288-v', 0), SenseInfo('00158222-v', 0) ],
"_spare_v_1_rel" : [ SenseInfo('02464583-v', 7), SenseInfo('02564674-v', 5), SenseInfo('02345647-v', 5), SenseInfo('01158484-v', 0), SenseInfo('02464583-v', 7), SenseInfo('02564674-v', 5), SenseInfo('02345647-v', 5), SenseInfo('01158484-v', 0), SenseInfo('02464583-v', 7), SenseInfo('02564674-v', 5), SenseInfo('02345647-v', 5), SenseInfo('01158484-v', 0) ],
"_bolt_n_1_rel" : [ SenseInfo('11519121-n', 2), SenseInfo('02866106-n', 1), SenseInfo('02865931-n', 1), SenseInfo('00555983-n', 1), SenseInfo('02866286-n', 0), SenseInfo('02865665-n', 0), SenseInfo('00204943-n', 0) ],
"_journalist_n_1_rel" : [ SenseInfo('10224578-n', 4), SenseInfo('10011486-n', 0) ],
"_headway_n_1_rel" : [ SenseInfo('13778261-n', 0), SenseInfo('07372779-n', 0) ],
"_partisan_n_1_rel" : [ SenseInfo('10402086-n', 0), SenseInfo('10059582-n', 0), SenseInfo('03894217-n', 0) ],
"_accord_v_1_rel" : [ SenseInfo('02700104-v', 20), SenseInfo('02255268-v', 5) ],
"_processor_n_of_rel" : [ SenseInfo('08065937-n', 1), SenseInfo('10477955-n', 0), SenseInfo('02995345-n', 0) ],
"_see_v_1_rel" : [ SenseInfo('02129289-v', 613), SenseInfo('00591115-v', 159), SenseInfo('02128873-v', 140), SenseInfo('01635432-v', 58), SenseInfo('00690614-v', 47), SenseInfo('00598954-v', 40), SenseInfo('02150948-v', 29), SenseInfo('02023107-v', 27), SenseInfo('00920336-v', 27), SenseInfo('00662589-v', 22), SenseInfo('02488304-v', 13), SenseInfo('02488488-v', 12), SenseInfo('02493030-v', 10), SenseInfo('02549581-v', 7), SenseInfo('01470670-v', 4), SenseInfo('02486232-v', 1), SenseInfo('02129709-v', 1), SenseInfo('00703708-v', 1), SenseInfo('02156225-v', 0), SenseInfo('02131279-v', 0), SenseInfo('02110220-v', 0), SenseInfo('02026086-v', 0), SenseInfo('01156568-v', 0), SenseInfo('00623151-v', 0), SenseInfo('02129289-v', 613), SenseInfo('00591115-v', 159), SenseInfo('02128873-v', 140), SenseInfo('01635432-v', 58), SenseInfo('00690614-v', 47), SenseInfo('00598954-v', 40), SenseInfo('02150948-v', 29), SenseInfo('02023107-v', 27), SenseInfo('00920336-v', 27), SenseInfo('00662589-v', 22), SenseInfo('02488304-v', 13), SenseInfo('02488488-v', 12), SenseInfo('02493030-v', 10), SenseInfo('02549581-v', 7), SenseInfo('01470670-v', 4), SenseInfo('02486232-v', 1), SenseInfo('02129709-v', 1), SenseInfo('00703708-v', 1), SenseInfo('02156225-v', 0), SenseInfo('02131279-v', 0), SenseInfo('02110220-v', 0), SenseInfo('02026086-v', 0), SenseInfo('01156568-v', 0), SenseInfo('00623151-v', 0), SenseInfo('02129289-v', 613), SenseInfo('00591115-v', 159), SenseInfo('02128873-v', 140), SenseInfo('01635432-v', 58), SenseInfo('00690614-v', 47), SenseInfo('00598954-v', 40), SenseInfo('02150948-v', 29), SenseInfo('02023107-v', 27), SenseInfo('00920336-v', 27), SenseInfo('00662589-v', 22), SenseInfo('02488304-v', 13), SenseInfo('02488488-v', 12), SenseInfo('02493030-v', 10), SenseInfo('02549581-v', 7), SenseInfo('01470670-v', 4), SenseInfo('02486232-v', 1), SenseInfo('02129709-v', 1), SenseInfo('00703708-v', 1), SenseInfo('02156225-v', 0), SenseInfo('02131279-v', 0), SenseInfo('02110220-v', 0), SenseInfo('02026086-v', 0), SenseInfo('01156568-v', 0), SenseInfo('00623151-v', 0), SenseInfo('02129289-v', 613), SenseInfo('00591115-v', 159), SenseInfo('02128873-v', 140), SenseInfo('01635432-v', 58), SenseInfo('00690614-v', 47), SenseInfo('00598954-v', 40), SenseInfo('02150948-v', 29), SenseInfo('02023107-v', 27), SenseInfo('00920336-v', 27), SenseInfo('00662589-v', 22), SenseInfo('02488304-v', 13), SenseInfo('02488488-v', 12), SenseInfo('02493030-v', 10), SenseInfo('02549581-v', 7), SenseInfo('01470670-v', 4), SenseInfo('02486232-v', 1), SenseInfo('02129709-v', 1), SenseInfo('00703708-v', 1), SenseInfo('02156225-v', 0), SenseInfo('02131279-v', 0), SenseInfo('02110220-v', 0), SenseInfo('02026086-v', 0), SenseInfo('01156568-v', 0), SenseInfo('00623151-v', 0), SenseInfo('02129289-v', 613), SenseInfo('00591115-v', 159), SenseInfo('02128873-v', 140), SenseInfo('01635432-v', 58), SenseInfo('00690614-v', 47), SenseInfo('00598954-v', 40), SenseInfo('02150948-v', 29), SenseInfo('02023107-v', 27), SenseInfo('00920336-v', 27), SenseInfo('00662589-v', 22), SenseInfo('02488304-v', 13), SenseInfo('02488488-v', 12), SenseInfo('02493030-v', 10), SenseInfo('02549581-v', 7), SenseInfo('01470670-v', 4), SenseInfo('02486232-v', 1), SenseInfo('02129709-v', 1), SenseInfo('00703708-v', 1), SenseInfo('02156225-v', 0), SenseInfo('02131279-v', 0), SenseInfo('02110220-v', 0), SenseInfo('02026086-v', 0), SenseInfo('01156568-v', 0), SenseInfo('00623151-v', 0), SenseInfo('02129289-v', 613), SenseInfo('00591115-v', 159), SenseInfo('02128873-v', 140), SenseInfo('01635432-v', 58), SenseInfo('00690614-v', 47), SenseInfo('00598954-v', 40), SenseInfo('02150948-v', 29), SenseInfo('02023107-v', 27), SenseInfo('00920336-v', 27), SenseInfo('00662589-v', 22), SenseInfo('02488304-v', 13), SenseInfo('02488488-v', 12), SenseInfo('02493030-v', 10), SenseInfo('02549581-v', 7), SenseInfo('01470670-v', 4), SenseInfo('02486232-v', 1), SenseInfo('02129709-v', 1), SenseInfo('00703708-v', 1), SenseInfo('02156225-v', 0), SenseInfo('02131279-v', 0), SenseInfo('02110220-v', 0), SenseInfo('02026086-v', 0), SenseInfo('01156568-v', 0), SenseInfo('00623151-v', 0), SenseInfo('02129289-v', 613), SenseInfo('00591115-v', 159), SenseInfo('02128873-v', 140), SenseInfo('01635432-v', 58), SenseInfo('00690614-v', 47), SenseInfo('00598954-v', 40), SenseInfo('02150948-v', 29), SenseInfo('02023107-v', 27), SenseInfo('00920336-v', 27), SenseInfo('00662589-v', 22), SenseInfo('02488304-v', 13), SenseInfo('02488488-v', 12), SenseInfo('02493030-v', 10), SenseInfo('02549581-v', 7), SenseInfo('01470670-v', 4), SenseInfo('02486232-v', 1), SenseInfo('02129709-v', 1), SenseInfo('00703708-v', 1), SenseInfo('02156225-v', 0), SenseInfo('02131279-v', 0), SenseInfo('02110220-v', 0), SenseInfo('02026086-v', 0), SenseInfo('01156568-v', 0), SenseInfo('00623151-v', 0), SenseInfo('02129289-v', 613), SenseInfo('00591115-v', 159), SenseInfo('02128873-v', 140), SenseInfo('01635432-v', 58), SenseInfo('00690614-v', 47), SenseInfo('00598954-v', 40), SenseInfo('02150948-v', 29), SenseInfo('02023107-v', 27), SenseInfo('00920336-v', 27), SenseInfo('00662589-v', 22), SenseInfo('02488304-v', 13), SenseInfo('02488488-v', 12), SenseInfo('02493030-v', 10), SenseInfo('02549581-v', 7), SenseInfo('01470670-v', 4), SenseInfo('02486232-v', 1), SenseInfo('02129709-v', 1), SenseInfo('00703708-v', 1), SenseInfo('02156225-v', 0), SenseInfo('02131279-v', 0), SenseInfo('02110220-v', 0), SenseInfo('02026086-v', 0), SenseInfo('01156568-v', 0), SenseInfo('00623151-v', 0) ],
"_tapir_n_1_rel" : [ SenseInfo('02393580-n', 0) ],
"_survival_n_1_rel" : [ SenseInfo('13962166-n', 10), SenseInfo('13563746-n', 0), SenseInfo('01022178-n', 0) ],
"_trio_n_1_rel" : [ SenseInfo('13744044-n', 1), SenseInfo('07041595-n', 1), SenseInfo('08247152-n', 0), SenseInfo('07986198-n', 0), SenseInfo('07986066-n', 0) ],
"_chip_v_1_rel" : [ SenseInfo('01259691-v', 1), SenseInfo('01259005-v', 1), SenseInfo('01598140-v', 0), SenseInfo('01260291-v', 0), SenseInfo('01259458-v', 0) ],
"_corrupt_v_1_rel" : [ SenseInfo('02579447-v', 1), SenseInfo('02284096-v', 0), SenseInfo('01537959-v', 0), SenseInfo('00203081-v', 0), SenseInfo('02579447-v', 1), SenseInfo('02284096-v', 0), SenseInfo('01537959-v', 0), SenseInfo('00203081-v', 0) ],
"_socket_n_1_rel" : [ SenseInfo('05280831-n', 0), SenseInfo('04255163-n', 0), SenseInfo('04255034-n', 0) ],
"_useless_a_1_rel" : [ SenseInfo('02497141-a', 7), SenseInfo('02497141-a', 7) ],
"_squirt_v_1_rel" : [ SenseInfo('01375637-v', 1), SenseInfo('01313411-v', 0) ],
"_get-together_n_1_rel" : [ SenseInfo('08310389-n', 0), SenseInfo('08310389-n', 0) ],
"_phraseology_n_1_rel" : [ SenseInfo('07081739-n', 1) ],
"_postage_n_1_rel" : [ SenseInfo('13324826-n', 0), SenseInfo('06796119-n', 0) ],
"_vicinity_n_of_rel" : [ SenseInfo('08641113-n', 4) ],
"_mahogany_n_1_rel" : [ SenseInfo('12695572-n', 2), SenseInfo('12695144-n', 0), SenseInfo('04973386-n', 0) ],
"_housing_n_1_rel" : [ SenseInfo('03546340-n', 4), SenseInfo('03546766-n', 0), SenseInfo('02955540-n', 0) ],
"_chortle_n_1_rel" : [ SenseInfo('07127563-n', 0) ],
"_because+of_p_rel" : [  ],
"_pipework_n_1_rel" : [ SenseInfo('03854815-n', 0) ],
"_modest_a_1_rel" : [ SenseInfo('01539225-a', 3), SenseInfo('01532912-a', 2), SenseInfo('01851916-a', 1), SenseInfo('01537885-a', 0), SenseInfo('02340458-a', 0), SenseInfo('01893510-a', 0), SenseInfo('01415219-a', 0), SenseInfo('01539225-a', 3), SenseInfo('01532912-a', 2), SenseInfo('01851916-a', 1), SenseInfo('01537885-a', 0), SenseInfo('02340458-a', 0), SenseInfo('01893510-a', 0), SenseInfo('01415219-a', 0) ],
"_central_a_1_rel" : [ SenseInfo('01277097-a', 11), SenseInfo('00329831-a', 7), SenseInfo('01277097-a', 11), SenseInfo('00329831-a', 7) ],
"_subsystem_n_1_rel" : [ SenseInfo('08435937-n', 4) ],
"_propensity_n_for_rel" : [ SenseInfo('07499113-n', 0), SenseInfo('06199561-n', 0), SenseInfo('04943154-n', 0), SenseInfo('07499113-n', 0), SenseInfo('06199561-n', 0), SenseInfo('04943154-n', 0), SenseInfo('07499113-n', 0), SenseInfo('06199561-n', 0), SenseInfo('04943154-n', 0) ],
"_equally_x_deg_rel" : [ SenseInfo('00022131-r', 14), SenseInfo('00332069-r', 2) ],
"_order_n_from_rel" : [ SenseInfo('07168623-n', 26), SenseInfo('05091316-n', 8), SenseInfo('13968547-n', 7), SenseInfo('08456993-n', 6), SenseInfo('14496710-n', 4), SenseInfo('06539770-n', 2), SenseInfo('06529219-n', 2), SenseInfo('08227214-n', 1), SenseInfo('06652878-n', 1), SenseInfo('13950812-n', 0), SenseInfo('08147794-n', 0), SenseInfo('08106934-n', 0), SenseInfo('07279687-n', 0), SenseInfo('04698656-n', 0), SenseInfo('01009871-n', 0) ],
"_slicker_n_1_rel" : [ SenseInfo('03844815-n', 2), SenseInfo('10611869-n', 0), SenseInfo('09998101-n', 0) ],
"_cocky_a_1_rel" : [ SenseInfo('00156440-a', 3), SenseInfo('00156440-a', 3), SenseInfo('00156440-a', 3) ],
"_baffle_n_1_rel" : [ SenseInfo('02772868-n', 0) ],
"_though_x_rel" : [ SenseInfo('00119139-r', 11), SenseInfo('00119139-r', 11), SenseInfo('00119139-r', 11), SenseInfo('00119139-r', 11) ],
"_southern_a_1_rel" : [ SenseInfo('01606648-a', 30), SenseInfo('01603179-a', 7), SenseInfo('01605081-a', 3), SenseInfo('01602966-a', 1), SenseInfo('01606648-a', 30), SenseInfo('01603179-a', 7), SenseInfo('01605081-a', 3), SenseInfo('01602966-a', 1) ],
"_position_v_as_rel" : [ SenseInfo('01987160-v', 2), SenseInfo('01494310-v', 1), SenseInfo('01987160-v', 2), SenseInfo('01494310-v', 1) ],
"_back_x_deg_rel" : [ SenseInfo('00075161-r', 91), SenseInfo('05558717-n', 53), SenseInfo('00074407-r', 36), SenseInfo('00075269-r', 24), SenseInfo('00197576-a', 15), SenseInfo('00074201-r', 15), SenseInfo('00075367-r', 14), SenseInfo('04059701-n', 12), SenseInfo('02453889-v', 7), SenseInfo('01997119-v', 6), SenseInfo('08625846-n', 4), SenseInfo('02556817-v', 4), SenseInfo('01997512-v', 4), SenseInfo('02217695-v', 2), SenseInfo('00074964-r', 1), SenseInfo('00131692-a', 1), SenseInfo('09830194-n', 0), SenseInfo('05588174-n', 0), SenseInfo('02840619-n', 0), SenseInfo('02767665-n', 0), SenseInfo('02767433-n', 0), SenseInfo('00725775-n', 0), SenseInfo('00668816-a', 0), SenseInfo('02693965-v', 0), SenseInfo('01139104-v', 0), SenseInfo('00560628-v', 0), SenseInfo('00223109-v', 0), SenseInfo('00185857-v', 0) ],
"_deaf_a_1_rel" : [ SenseInfo('00681930-a', 7), SenseInfo('01194328-a', 0), SenseInfo('00681930-a', 7), SenseInfo('01194328-a', 0), SenseInfo('00681930-a', 7), SenseInfo('01194328-a', 0) ],
"_desist_v_1_rel" : [ SenseInfo('01196037-v', 0) ],
"_previous_a_1_rel" : [ SenseInfo('00127137-a', 24), SenseInfo('01729819-a', 17), SenseInfo('00815227-a', 0) ],
"_portrait_n_1_rel" : [ SenseInfo('07202391-n', 2), SenseInfo('03987079-n', 2) ],
"_claw_n_1_rel" : [ SenseInfo('02156140-n', 2), SenseInfo('03532672-n', 1), SenseInfo('02156532-n', 1), SenseInfo('02154742-n', 0) ],
"_nest_v_cause_rel" : [ SenseInfo('02654947-v', 4), SenseInfo('01529766-v', 2), SenseInfo('01424948-v', 0), SenseInfo('01383393-v', 0) ],
"_antagonist_n_1_rel" : [ SenseInfo('09773245-n', 10), SenseInfo('05293420-n', 0), SenseInfo('02714883-n', 0) ],
"_denounce_v_as_rel" : [ SenseInfo('00841580-v', 10), SenseInfo('02508245-v', 2), SenseInfo('00842429-v', 1), SenseInfo('00841986-v', 0), SenseInfo('00841580-v', 10), SenseInfo('02508245-v', 2), SenseInfo('00842429-v', 1), SenseInfo('00841986-v', 0) ],
"_need_v_pred_rel" : [ SenseInfo('02627934-v', 110), SenseInfo('01188725-v', 98), SenseInfo('01189113-v', 1) ],
"_accused_n_1_rel" : [ SenseInfo('09762011-n', 0) ],
"_evaluate_v_1_rel" : [ SenseInfo('00681429-v', 18), SenseInfo('00670261-v', 0), SenseInfo('00681429-v', 18), SenseInfo('00670261-v', 0), SenseInfo('00681429-v', 18), SenseInfo('00670261-v', 0), SenseInfo('00681429-v', 18), SenseInfo('00670261-v', 0) ],
"_inexperienced_n_1_rel" : [ SenseInfo('00936740-a', 3) ],
"_underspecification_n_of_rel" : [  ],
"_no_x_deg_rel" : [ SenseInfo('02268485-a', 135), SenseInfo('00050681-r', 38), SenseInfo('07205104-n', 21), SenseInfo('00024587-r', 4), SenseInfo('14647722-n', 0), SenseInfo('00024356-r', 0) ],
"_packed_a_with_rel" : [ SenseInfo('00560100-a', 1), SenseInfo('00502922-a', 0) ],
"_petal_n_1_rel" : [ SenseInfo('11690455-n', 2) ],
"_unlawful_a_1_rel" : [ SenseInfo('01961410-a', 1), SenseInfo('01396047-a', 0), SenseInfo('01551026-a', 0), SenseInfo('01408421-a', 0), SenseInfo('01403760-a', 0), SenseInfo('01961410-a', 1), SenseInfo('01396047-a', 0), SenseInfo('01551026-a', 0), SenseInfo('01408421-a', 0), SenseInfo('01403760-a', 0) ],
"_slide_v_1_rel" : [ SenseInfo('01870275-v', 18), SenseInfo('01886488-v', 14), SenseInfo('02090990-v', 3), SenseInfo('01870275-v', 18), SenseInfo('01886488-v', 14), SenseInfo('02090990-v', 3), SenseInfo('01870275-v', 18), SenseInfo('01886488-v', 14), SenseInfo('02090990-v', 3), SenseInfo('01870275-v', 18), SenseInfo('01886488-v', 14), SenseInfo('02090990-v', 3), SenseInfo('01870275-v', 18), SenseInfo('01886488-v', 14), SenseInfo('02090990-v', 3) ],
"_gratuitous_a_1_rel" : [ SenseInfo('01371553-a', 1), SenseInfo('01710260-a', 0), SenseInfo('01582049-a', 0) ],
"_cement_n_1_rel" : [ SenseInfo('14804487-n', 2), SenseInfo('14804175-n', 2), SenseInfo('14704640-n', 1), SenseInfo('14804641-n', 0), SenseInfo('05308810-n', 0) ],
"_damp_a_1_rel" : [ SenseInfo('02548820-a', 6), SenseInfo('02548820-a', 6), SenseInfo('02548820-a', 6), SenseInfo('02548820-a', 6) ],
"_say_v_to_rel" : [ SenseInfo('01009240-v', 1861), SenseInfo('01016002-v', 254), SenseInfo('00917300-v', 29), SenseInfo('02730813-v', 8), SenseInfo('00746718-v', 8), SenseInfo('00978549-v', 4), SenseInfo('00928959-v', 2), SenseInfo('00979870-v', 1), SenseInfo('01009821-v', 0), SenseInfo('00945499-v', 0), SenseInfo('00923197-v', 0), SenseInfo('01009240-v', 1861), SenseInfo('01016002-v', 254), SenseInfo('00917300-v', 29), SenseInfo('02730813-v', 8), SenseInfo('00746718-v', 8), SenseInfo('00978549-v', 4), SenseInfo('00928959-v', 2), SenseInfo('00979870-v', 1), SenseInfo('01009821-v', 0), SenseInfo('00945499-v', 0), SenseInfo('00923197-v', 0) ],
"_practically_x_deg_rel" : [ SenseInfo('00053744-r', 27), SenseInfo('00053512-r', 0), SenseInfo('00022829-r', 0) ],
"_pakistani_a_1_rel" : [ SenseInfo('03095964-a', 0) ],
"_studio_n_1_rel" : [ SenseInfo('04344246-n', 15), SenseInfo('04344734-n', 0), SenseInfo('04344544-n', 0) ],
"_clutter_n_1_rel" : [ SenseInfo('14500567-n', 0), SenseInfo('07263745-n', 0) ],
"_paperwork_n_1_rel" : [ SenseInfo('00582071-n', 1) ],
"_prodigal_a_1_rel" : [ SenseInfo('02422242-a', 0), SenseInfo('02422242-a', 0) ],
"_subservient_a_1_rel" : [ SenseInfo('02330064-a', 1), SenseInfo('01196775-a', 0), SenseInfo('00790691-a', 0) ],
"_batch_v_1_rel" : [ SenseInfo('01386073-v', 0) ],
"_downcast_a_1_rel" : [ SenseInfo('02492719-a', 1), SenseInfo('00703615-a', 0), SenseInfo('02492719-a', 1), SenseInfo('00703615-a', 0) ],
"_beg_v_for_rel" : [ SenseInfo('00759269-v', 11), SenseInfo('00782057-v', 5), SenseInfo('02270815-v', 2), SenseInfo('00810226-v', 0) ],
"_air-sensitive_a_1_rel" : [  ],
"_end+to+end_a_1_rel" : [ SenseInfo('01445184-a', 0), SenseInfo('01445184-a', 0), SenseInfo('01445184-a', 0), SenseInfo('01445184-a', 0), SenseInfo('01445184-a', 0), SenseInfo('01445184-a', 0), SenseInfo('01445184-a', 0), SenseInfo('01445184-a', 0), SenseInfo('01445184-a', 0) ],
"_day+and+night_a_1_rel" : [ SenseInfo('00595147-a', 0) ],
"_blank_n_1_rel" : [ SenseInfo('06839190-n', 0), SenseInfo('03632189-n', 0), SenseInfo('02849051-n', 0), SenseInfo('02848921-n', 0) ],
"_polish_v_1_rel" : [ SenseInfo('01245637-v', 7), SenseInfo('00474017-v', 3), SenseInfo('00473799-v', 0), SenseInfo('01245637-v', 7), SenseInfo('00474017-v', 3), SenseInfo('00473799-v', 0) ],
"_as_a_also_rel" : [ SenseInfo('14629149-n', 0), SenseInfo('08991878-n', 0) ],
"_times_p_rel" : [ SenseInfo('07309599-n', 219), SenseInfo('15270431-n', 160), SenseInfo('15122231-n', 114), SenseInfo('15245515-n', 43), SenseInfo('00028270-n', 36), SenseInfo('07288215-n', 10), SenseInfo('15129927-n', 7), SenseInfo('15135822-n', 5), SenseInfo('00490968-v', 4), SenseInfo('00678547-v', 3), SenseInfo('04991738-n', 1), SenseInfo('00702226-v', 1), SenseInfo('15224692-n', 0), SenseInfo('00297906-v', 0), SenseInfo('00296973-v', 0), SenseInfo('07309599-n', 219), SenseInfo('15270431-n', 160), SenseInfo('15122231-n', 114), SenseInfo('15245515-n', 43), SenseInfo('00028270-n', 36), SenseInfo('07288215-n', 10), SenseInfo('15129927-n', 7), SenseInfo('15135822-n', 5), SenseInfo('00490968-v', 4), SenseInfo('00678547-v', 3), SenseInfo('04991738-n', 1), SenseInfo('00702226-v', 1), SenseInfo('15224692-n', 0), SenseInfo('00297906-v', 0), SenseInfo('00296973-v', 0), SenseInfo('07309599-n', 219), SenseInfo('15270431-n', 160), SenseInfo('15122231-n', 114), SenseInfo('15245515-n', 43), SenseInfo('00028270-n', 36), SenseInfo('07288215-n', 10), SenseInfo('15129927-n', 7), SenseInfo('15135822-n', 5), SenseInfo('00490968-v', 4), SenseInfo('00678547-v', 3), SenseInfo('04991738-n', 1), SenseInfo('00702226-v', 1), SenseInfo('15224692-n', 0), SenseInfo('00297906-v', 0), SenseInfo('00296973-v', 0) ],
"_rot_v_out_rel" : [ SenseInfo('00209837-v', 3), SenseInfo('00093775-v', 0) ],
"_outstanding_a_1_rel" : [ SenseInfo('02343762-a', 5), SenseInfo('00580805-a', 3), SenseInfo('01710543-a', 0), SenseInfo('01278818-a', 0), SenseInfo('02343762-a', 5), SenseInfo('00580805-a', 3), SenseInfo('01710543-a', 0), SenseInfo('01278818-a', 0) ],
"_knickknack_n_1_rel" : [ SenseInfo('03623448-n', 0), SenseInfo('02897692-n', 0), SenseInfo('03623448-n', 0), SenseInfo('02897692-n', 0) ],
"_deceive_v_1_rel" : [ SenseInfo('02575082-v', 5), SenseInfo('00854420-v', 2), SenseInfo('02575082-v', 5), SenseInfo('00854420-v', 2), SenseInfo('02575082-v', 5), SenseInfo('00854420-v', 2) ],
"_breastbone_n_1_rel" : [ SenseInfo('05281189-n', 0) ],
"_bay_v_1_rel" : [ SenseInfo('01048073-v', 1), SenseInfo('01047951-v', 0) ],
"_reborn_a_1_rel" : [ SenseInfo('01957177-a', 1) ],
"_mustard_a_1_rel" : [ SenseInfo('11878283-n', 0), SenseInfo('07819480-n', 0), SenseInfo('07713763-n', 0) ],
"_durable_n_1_rel" : [ SenseInfo('01439496-a', 1), SenseInfo('02124096-a', 0), SenseInfo('01754049-a', 0) ],
"_conspire_v_1_rel" : [ SenseInfo('00706975-v', 3), SenseInfo('00707624-v', 2), SenseInfo('00706975-v', 3), SenseInfo('00707624-v', 2) ],
"_diagnose_v_as_rel" : [ SenseInfo('00645552-v', 4), SenseInfo('00645771-v', 1), SenseInfo('00645552-v', 4), SenseInfo('00645771-v', 1) ],
"_florentine_a_1_rel" : [ SenseInfo('02904916-a', 1) ],
"_fancy_a_1_rel" : [ SenseInfo('01794340-a', 3), SenseInfo('01794340-a', 3), SenseInfo('01794340-a', 3) ],
"_loath_a_1_rel" : [ SenseInfo('02566453-a', 0), SenseInfo('01293542-a', 0) ],
"_hardly_x_deg_rel" : [ SenseInfo('00002621-r', 37), SenseInfo('00003093-r', 2) ],
"_down_a_1_rel" : [ SenseInfo('02491961-a', 9), SenseInfo('02486248-a', 2), SenseInfo('02487414-a', 1), SenseInfo('02061678-a', 1), SenseInfo('01750617-a', 1), SenseInfo('01212867-a', 0), SenseInfo('01208492-a', 0), SenseInfo('00833737-a', 0), SenseInfo('00703615-a', 0) ],
"_braid_v_1_rel" : [ SenseInfo('01674717-v', 1), SenseInfo('01519727-v', 0), SenseInfo('01519569-v', 0) ],
"_odyssey_n_1_rel" : [ SenseInfo('00308279-n', 1), SenseInfo('06382193-n', 0) ],
"_smallholder_n_1_rel" : [ SenseInfo('10613387-n', 0) ],
"_pin_v_back-i_rel" : [ SenseInfo('01207149-v', 2), SenseInfo('01368264-v', 1), SenseInfo('01444723-v', 0), SenseInfo('01121621-v', 0) ],
"_quietness_n_1_rel" : [ SenseInfo('04982856-n', 2), SenseInfo('07515560-n', 1) ],
"_wintry_a_1_rel" : [ SenseInfo('01255807-a', 1), SenseInfo('01258264-a', 0) ],
"_scotchman_n_1_rel" : [ SenseInfo('09730533-n', 1) ],
"_knife_n_1_rel" : [ SenseInfo('03623556-n', 6), SenseInfo('03624134-n', 5), SenseInfo('13918387-n', 1) ],
"_interaction_n_with_rel" : [ SenseInfo('00039021-n', 15), SenseInfo('11516113-n', 0) ],
"_splatter_n_1_rel" : [ SenseInfo('07394814-n', 1), SenseInfo('13761171-n', 0) ],
"_premise_n_1_rel" : [ SenseInfo('06753800-n', 1), SenseInfo('06753800-n', 1) ],
"_grab_n_1_rel" : [ SenseInfo('03450881-n', 0), SenseInfo('00138956-n', 0) ],
"_alter_v_1_rel" : [ SenseInfo('00126264-v', 26), SenseInfo('00123170-v', 2), SenseInfo('01667132-v', 1), SenseInfo('00201407-v', 0), SenseInfo('00060477-v', 0), SenseInfo('00126264-v', 26), SenseInfo('00123170-v', 2), SenseInfo('01667132-v', 1), SenseInfo('00201407-v', 0), SenseInfo('00060477-v', 0) ],
"_bump_v_off_rel" : [ SenseInfo('01239619-v', 2), SenseInfo('02248465-v', 1), SenseInfo('01895383-v', 1), SenseInfo('02399331-v', 0), SenseInfo('01527508-v', 0) ],
"_wc_n_1_rel" : [  ],
"_log_v_1_rel" : [ SenseInfo('01002481-v', 2), SenseInfo('01258828-v', 1) ],
"_advise_v_of_rel" : [ SenseInfo('00872886-v', 11), SenseInfo('00873682-v', 10), SenseInfo('00875394-v', 4) ],
"_syringe_n_1_rel" : [ SenseInfo('04376876-n', 0) ],
"_nightmare_n_1_rel" : [ SenseInfo('13936676-n', 2), SenseInfo('05769062-n', 2) ],
"_fracture_v_1_rel" : [ SenseInfo('00203739-v', 1), SenseInfo('01621084-v', 0), SenseInfo('00335366-v', 0), SenseInfo('00108303-v', 0), SenseInfo('00107943-v', 0), SenseInfo('00107739-v', 0) ],
"_muddle_v_through_rel" : [ SenseInfo('01419867-v', 0), SenseInfo('00620532-v', 0) ],
"_bag_n_of_rel" : [ SenseInfo('02773037-n', 8), SenseInfo('13754778-n', 2), SenseInfo('02797881-n', 2), SenseInfo('02774152-n', 2), SenseInfo('13764639-n', 1), SenseInfo('02773838-n', 1), SenseInfo('09832321-n', 0), SenseInfo('02370360-n', 0), SenseInfo('00432881-n', 0) ],
"_erection_n_of_rel" : [ SenseInfo('14038185-n', 0), SenseInfo('03295140-n', 0), SenseInfo('00911752-n', 0) ],
"_corona_n_1_rel" : [ SenseInfo('11427067-n', 1), SenseInfo('11691332-n', 0), SenseInfo('11440802-n', 0), SenseInfo('11440691-n', 0), SenseInfo('05607126-n', 0), SenseInfo('03111483-n', 0) ],
"_beret_n_1_rel" : [ SenseInfo('02831237-n', 0) ],
"_stamp_v_1_rel" : [ SenseInfo('01925338-v', 3), SenseInfo('01273016-v', 3), SenseInfo('02144644-v', 1), SenseInfo('01273814-v', 1), SenseInfo('00656292-v', 1), SenseInfo('00478488-v', 1), SenseInfo('01624568-v', 0), SenseInfo('01594362-v', 0), SenseInfo('01531265-v', 0) ],
"_luster_n_1_rel" : [ SenseInfo('04954920-n', 1), SenseInfo('04954683-n', 1), SenseInfo('04701162-n', 0) ],
"_cholesterol_n_1_rel" : [ SenseInfo('15058544-n', 4) ],
"_full-fledged_a_1_rel" : [ SenseInfo('01096308-a', 0), SenseInfo('00935792-a', 0), SenseInfo('01096308-a', 0), SenseInfo('00935792-a', 0) ],
"_impact_n_1_rel" : [ SenseInfo('07338552-n', 11), SenseInfo('11414411-n', 6), SenseInfo('00157957-n', 1), SenseInfo('01172252-n', 0) ],
"_alignment_n_of_rel" : [ SenseInfo('08293982-n', 2), SenseInfo('05077146-n', 2), SenseInfo('07415167-n', 0), SenseInfo('01000068-n', 0) ],
"_only_a_1_rel" : [ SenseInfo('02214736-a', 0), SenseInfo('01862697-a', 0), SenseInfo('02214736-a', 0), SenseInfo('01862697-a', 0), SenseInfo('02214736-a', 0), SenseInfo('01862697-a', 0), SenseInfo('02214736-a', 0), SenseInfo('01862697-a', 0) ],
"_milliampere_n_1_rel" : [ SenseInfo('13637613-n', 2), SenseInfo('13637613-n', 2) ],
"_teaser_n_1_rel" : [ SenseInfo('10695822-n', 0), SenseInfo('10695555-n', 0), SenseInfo('07250868-n', 0), SenseInfo('06784639-n', 0), SenseInfo('06397645-n', 0), SenseInfo('04456276-n', 0), SenseInfo('04398167-n', 0) ],
"_aesthetic_a_1_rel" : [ SenseInfo('02991287-a', 10), SenseInfo('00069531-a', 2), SenseInfo('02393086-a', 0) ],
"_grey_v_1_rel" : [ SenseInfo('00289679-v', 0), SenseInfo('00289392-v', 0) ],
"_overdraft_n_1_rel" : [ SenseInfo('13377654-n', 0) ],
"_throb_n_1_rel" : [ SenseInfo('14333334-n', 0), SenseInfo('07401726-n', 0) ],
"_heavy_n_1_rel" : [ SenseInfo('10167361-n', 0), SenseInfo('05929582-n', 0) ],
"_lead_v_to_rel" : [ SenseInfo('01999798-v', 40), SenseInfo('02635659-v', 35), SenseInfo('02635956-v', 27), SenseInfo('01999423-v', 17), SenseInfo('00771632-v', 17), SenseInfo('02685951-v', 13), SenseInfo('02440244-v', 13), SenseInfo('02687385-v', 10), SenseInfo('02555908-v', 9), SenseInfo('01732921-v', 8), SenseInfo('02686471-v', 5), SenseInfo('01999218-v', 2), SenseInfo('02686625-v', 1), SenseInfo('00813790-v', 0) ],
"_bomb_v_1_rel" : [ SenseInfo('01131902-v', 3), SenseInfo('02523521-v', 0) ],
"_physiological_a_1_rel" : [ SenseInfo('02949082-a', 14), SenseInfo('01779558-a', 0) ],
"_aim_v_1_rel" : [ SenseInfo('01151110-v', 8), SenseInfo('00708980-v', 7), SenseInfo('01026975-v', 5), SenseInfo('00713015-v', 3), SenseInfo('01150559-v', 2), SenseInfo('00955472-v', 2), SenseInfo('00705517-v', 2), SenseInfo('01151110-v', 8), SenseInfo('00708980-v', 7), SenseInfo('01026975-v', 5), SenseInfo('00713015-v', 3), SenseInfo('01150559-v', 2), SenseInfo('00955472-v', 2), SenseInfo('00705517-v', 2) ],
"_expense_n_1_rel" : [ SenseInfo('13275495-n', 25), SenseInfo('07420671-n', 4), SenseInfo('13277886-n', 1), SenseInfo('13275495-n', 25), SenseInfo('07420671-n', 4), SenseInfo('13277886-n', 1) ],
"_tine_n_1_rel" : [ SenseInfo('04439585-n', 2) ],
"_contradictory_a_1_rel" : [ SenseInfo('02382144-a', 1), SenseInfo('02356579-a', 0), SenseInfo('00578234-a', 0), SenseInfo('00508750-a', 0) ],
"_plummet_v_1_rel" : [ SenseInfo('01978199-v', 1) ],
"_colonial_a_1_rel" : [ SenseInfo('02700029-a', 5), SenseInfo('02700199-a', 0), SenseInfo('02177397-a', 0) ],
"_lowland_n_1_rel" : [ SenseInfo('09344198-n', 1) ],
"_retrieval_n_of_rel" : [ SenseInfo('13550940-n', 0), SenseInfo('05761380-n', 0), SenseInfo('00045907-n', 0) ],
"_rate_v_1_rel" : [ SenseInfo('00658052-v', 9), SenseInfo('02646227-v', 2), SenseInfo('00660971-v', 1), SenseInfo('00658052-v', 9), SenseInfo('02646227-v', 2), SenseInfo('00660971-v', 1), SenseInfo('00658052-v', 9), SenseInfo('02646227-v', 2), SenseInfo('00660971-v', 1), SenseInfo('00658052-v', 9), SenseInfo('02646227-v', 2), SenseInfo('00660971-v', 1) ],
"_lecturer_n_1_rel" : [ SenseInfo('10252222-n', 2), SenseInfo('10252547-n', 1) ],
"_epiphany_n_1_rel" : [ SenseInfo('07323605-n', 2), SenseInfo('15194506-n', 0) ],
"_transformation_n_of_rel" : [ SenseInfo('07359599-n', 3), SenseInfo('13785136-n', 0), SenseInfo('07260332-n', 0), SenseInfo('00399030-n', 0), SenseInfo('00398704-n', 0) ],
"_saw_v_1_rel" : [ SenseInfo('01559590-v', 1) ],
"_insulation_n_1_rel" : [ SenseInfo('14415518-n', 1), SenseInfo('14920844-n', 0), SenseInfo('00827010-n', 0) ],
"_corresponding_a_1_rel" : [ SenseInfo('01974451-a', 9), SenseInfo('02072660-a', 7), SenseInfo('02063554-a', 1), SenseInfo('01974451-a', 9), SenseInfo('02072660-a', 7), SenseInfo('02063554-a', 1), SenseInfo('01974451-a', 9), SenseInfo('02072660-a', 7), SenseInfo('02063554-a', 1) ],
"_ultimate_a_1_rel" : [ SenseInfo('01578312-a', 18), SenseInfo('01013961-a', 5), SenseInfo('01578312-a', 18), SenseInfo('01013961-a', 5), SenseInfo('01578312-a', 18), SenseInfo('01013961-a', 5) ],
"_nuts_a_1_rel" : [ SenseInfo('02074929-a', 0) ],
"_leverage_n_1_rel" : [ SenseInfo('11473138-n', 0), SenseInfo('05156481-n', 0), SenseInfo('01099946-n', 0) ],
"_significantly_x_rel" : [ SenseInfo('00509970-r', 6), SenseInfo('00006259-r', 3), SenseInfo('00367868-r', 0) ],
"_colonist_n_1_rel" : [ SenseInfo('10583387-n', 0) ],
"_gray_a_1_rel" : [ SenseInfo('00389310-a', 38), SenseInfo('01645678-a', 6), SenseInfo('01607120-a', 3), SenseInfo('01014685-a', 0), SenseInfo('00389310-a', 38), SenseInfo('01645678-a', 6), SenseInfo('01607120-a', 3), SenseInfo('01014685-a', 0) ],
"_blow_v_down_rel" : [ SenseInfo('00007012-v', 6), SenseInfo('02769241-v', 5), SenseInfo('00034948-v', 3), SenseInfo('01902783-v', 2), SenseInfo('02135877-v', 1), SenseInfo('00477247-v', 1), SenseInfo('02527651-v', 0), SenseInfo('02268351-v', 0), SenseInfo('02266148-v', 0), SenseInfo('02178340-v', 0), SenseInfo('02135727-v', 0), SenseInfo('02117170-v', 0), SenseInfo('02101046-v', 0), SenseInfo('02100632-v', 0), SenseInfo('02068745-v', 0), SenseInfo('01849054-v', 0), SenseInfo('01545208-v', 0), SenseInfo('00934965-v', 0), SenseInfo('00883226-v', 0), SenseInfo('00779804-v', 0), SenseInfo('00435294-v', 0), SenseInfo('00310155-v', 0), SenseInfo('00007012-v', 6), SenseInfo('02769241-v', 5), SenseInfo('00034948-v', 3), SenseInfo('01902783-v', 2), SenseInfo('02135877-v', 1), SenseInfo('00477247-v', 1), SenseInfo('02527651-v', 0), SenseInfo('02268351-v', 0), SenseInfo('02266148-v', 0), SenseInfo('02178340-v', 0), SenseInfo('02135727-v', 0), SenseInfo('02117170-v', 0), SenseInfo('02101046-v', 0), SenseInfo('02100632-v', 0), SenseInfo('02068745-v', 0), SenseInfo('01849054-v', 0), SenseInfo('01545208-v', 0), SenseInfo('00934965-v', 0), SenseInfo('00883226-v', 0), SenseInfo('00779804-v', 0), SenseInfo('00435294-v', 0), SenseInfo('00310155-v', 0) ],
"_accuse_v_of_rel" : [ SenseInfo('00842989-v', 22), SenseInfo('00843468-v', 0), SenseInfo('00842989-v', 22), SenseInfo('00843468-v', 0) ],
"_participate_v_in_rel" : [ SenseInfo('02450256-v', 28), SenseInfo('01082606-v', 1), SenseInfo('02450256-v', 28), SenseInfo('01082606-v', 1) ],
"_hydrophobic_a_1_rel" : [ SenseInfo('00491749-a', 2), SenseInfo('00080098-a', 0) ],
"_oratory_n_1_rel" : [ SenseInfo('07241205-n', 0) ],
"_instead_a_1_rel" : [  ],
"_strum_v_1_rel" : [ SenseInfo('02180362-v', 2) ],
"_dolphin_n_1_rel" : [ SenseInfo('02581957-n', 0), SenseInfo('02068974-n', 0) ],
"_camp_a_1_rel" : [ SenseInfo('02394487-a', 0) ],
"_cycle_v_1_rel" : [ SenseInfo('02052675-v', 1), SenseInfo('02051270-v', 1), SenseInfo('01936048-v', 0), SenseInfo('01935476-v', 0), SenseInfo('00343771-v', 0), SenseInfo('02052675-v', 1), SenseInfo('02051270-v', 1), SenseInfo('01936048-v', 0), SenseInfo('01935476-v', 0), SenseInfo('00343771-v', 0) ],
"_passport_n_1_rel" : [ SenseInfo('06691083-n', 0), SenseInfo('06500937-n', 0), SenseInfo('04673668-n', 0) ],
"_colloquium_n_1_rel" : [ SenseInfo('08327906-n', 0), SenseInfo('07239327-n', 0) ],
"_isotope_n_1_rel" : [ SenseInfo('14619658-n', 0) ],
"_christen_v_1_rel" : [ SenseInfo('01028079-v', 0), SenseInfo('01028079-v', 0) ],
"_matter_v_1_rel" : [ SenseInfo('02645839-v', 21) ],
"_sundew_n_1_rel" : [ SenseInfo('12782530-n', 0) ],
"_drunk_n_1_rel" : [ SenseInfo('10037385-n', 4), SenseInfo('10037080-n', 0) ],
"_drunk_a_1_rel" : [ SenseInfo('00797299-a', 9), SenseInfo('00920260-a', 2), SenseInfo('00797299-a', 9), SenseInfo('00920260-a', 2), SenseInfo('00797299-a', 9), SenseInfo('00920260-a', 2) ],
"_meaningless_a_1_rel" : [ SenseInfo('01497736-a', 4) ],
"_any_x_deg_rel" : [ SenseInfo('02267686-a', 47), SenseInfo('00024509-r', 4) ],
"_bust_v_open_rel" : [ SenseInfo('01369758-v', 1), SenseInfo('02494850-v', 0), SenseInfo('01573515-v', 0), SenseInfo('01369346-v', 0), SenseInfo('00333594-v', 0), SenseInfo('01369758-v', 1), SenseInfo('02494850-v', 0), SenseInfo('01573515-v', 0), SenseInfo('01369346-v', 0), SenseInfo('00333594-v', 0) ],
"_saint_n_1_rel" : [ SenseInfo('10547145-n', 3), SenseInfo('10546850-n', 2), SenseInfo('10325243-n', 1) ],
"_swamp_n_1_rel" : [ SenseInfo('09452395-n', 4), SenseInfo('13938296-n', 0) ],
"_approximately_x_rel" : [ SenseInfo('00007015-r', 26), SenseInfo('00007015-r', 26), SenseInfo('00007015-r', 26), SenseInfo('00007015-r', 26) ],
"_for+the+better_p_rel" : [  ],
"_protract_v_1_rel" : [ SenseInfo('00317888-v', 0) ],
"_retailer_n_1_rel" : [ SenseInfo('10525436-n', 5) ],
"_at_p_sel_rel" : [ SenseInfo('14629561-n', 0), SenseInfo('13681048-n', 0) ],
"_cowberry_n_1_rel" : [ SenseInfo('12249542-n', 0), SenseInfo('07744057-n', 0) ],
"_on+and+off_a_1_rel" : [  ],
"_dawn_v_on_rel" : [ SenseInfo('00591755-v', 1), SenseInfo('02609614-v', 0), SenseInfo('00528836-v', 0) ],
"_grok_v_1_rel" : [ SenseInfo('00588221-v', 0), SenseInfo('00588221-v', 0) ],
"_interconnect_v_1_rel" : [ SenseInfo('02622969-v', 1), SenseInfo('01355646-v', 0) ],
"_alternate_a_1_rel" : [ SenseInfo('00676093-a', 3), SenseInfo('01853934-a', 2), SenseInfo('00675928-a', 1), SenseInfo('01663359-a', 0), SenseInfo('00676093-a', 3), SenseInfo('01853934-a', 2), SenseInfo('00675928-a', 1), SenseInfo('01663359-a', 0) ],
"_commonwealth_n_1_rel" : [ SenseInfo('08542403-n', 2), SenseInfo('08168978-n', 2), SenseInfo('08375154-n', 0), SenseInfo('08361329-n', 0) ],
"_undertone_n_1_rel" : [ SenseInfo('07083136-n', 0), SenseInfo('05922809-n', 0), SenseInfo('04959567-n', 0) ],
"_leery_a_of_rel" : [ SenseInfo('02464277-a', 0) ],
"_forbear_v_1_rel" : [ SenseInfo('02726044-v', 0), SenseInfo('02725714-v', 0) ],
"_downtown_a_2_rel" : [ SenseInfo('02494716-a', 13) ],
"_stink_v_1_rel" : [ SenseInfo('02674173-v', 2), SenseInfo('02124106-v', 0) ],
"_blot_v_1_rel" : [ SenseInfo('01538928-v', 0), SenseInfo('01531998-v', 0) ],
"_tee_n_1_rel" : [ SenseInfo('08661277-n', 1), SenseInfo('04399700-n', 0), SenseInfo('04399537-n', 0) ],
"_terrorist_n_1_rel" : [ SenseInfo('10702781-n', 1) ],
"_confide_v_in_rel" : [ SenseInfo('00936465-v', 6), SenseInfo('02349212-v', 1) ],
"_wander_v_1_rel" : [ SenseInfo('01881180-v', 18), SenseInfo('02576503-v', 1), SenseInfo('02102840-v', 0), SenseInfo('01882814-v', 0), SenseInfo('00780575-v', 0) ],
"_surfeit_v_1_rel" : [ SenseInfo('02333225-v', 1), SenseInfo('01191838-v', 0) ],
"_spectacle_n_of_rel" : [ SenseInfo('06889138-n', 8), SenseInfo('04271891-n', 2), SenseInfo('00075471-n', 0) ],
"_policeman_n_1_rel" : [ SenseInfo('10448983-n', 11) ],
"_beginner_n_1_rel" : [ SenseInfo('10363913-n', 1), SenseInfo('10107303-n', 0) ],
"_dip_v_1_rel" : [ SenseInfo('01577093-v', 2), SenseInfo('01192312-v', 1), SenseInfo('00432061-v', 1), SenseInfo('00286483-v', 1), SenseInfo('02311857-v', 0), SenseInfo('02162310-v', 0), SenseInfo('02041109-v', 0), SenseInfo('02039679-v', 0), SenseInfo('02038145-v', 0), SenseInfo('01976220-v', 0), SenseInfo('01660976-v', 0), SenseInfo('01578124-v', 0), SenseInfo('01577966-v', 0), SenseInfo('01312657-v', 0) ],
"_comb_v_out_rel" : [ SenseInfo('01596645-v', 1), SenseInfo('01319193-v', 1), SenseInfo('00038365-v', 1) ],
"_urge_v_1_rel" : [ SenseInfo('00765649-v', 36), SenseInfo('00875141-v', 11), SenseInfo('00858781-v', 1), SenseInfo('00765649-v', 36), SenseInfo('00875141-v', 11), SenseInfo('00858781-v', 1), SenseInfo('00765649-v', 36), SenseInfo('00875141-v', 11), SenseInfo('00858781-v', 1) ],
"_endless_a_1_rel" : [ SenseInfo('01439784-a', 6), SenseInfo('01008174-a', 3), SenseInfo('01007947-a', 0), SenseInfo('00596211-a', 0), SenseInfo('01439784-a', 6), SenseInfo('01008174-a', 3), SenseInfo('01007947-a', 0), SenseInfo('00596211-a', 0) ],
"_samurai_n_1_rel" : [ SenseInfo('10549763-n', 0), SenseInfo('08388966-n', 0) ],
"_agonizing_a_1_rel" : [ SenseInfo('01711724-a', 0) ],
"_move_n_1_rel" : [ SenseInfo('00165942-n', 8), SenseInfo('00168658-n', 3), SenseInfo('00331950-n', 1), SenseInfo('00279835-n', 0), SenseInfo('00166172-n', 0), SenseInfo('00165942-n', 8), SenseInfo('00168658-n', 3), SenseInfo('00331950-n', 1), SenseInfo('00279835-n', 0), SenseInfo('00166172-n', 0), SenseInfo('00165942-n', 8), SenseInfo('00168658-n', 3), SenseInfo('00331950-n', 1), SenseInfo('00279835-n', 0), SenseInfo('00166172-n', 0) ],
"_region_n_of_rel" : [ SenseInfo('08630039-n', 65), SenseInfo('05221895-n', 5), SenseInfo('08630985-n', 2), SenseInfo('13759146-n', 0), SenseInfo('05997814-n', 0) ],
"_long+ass_a_1_rel" : [  ],
"_arab_a_1_rel" : [ SenseInfo('09729530-n', 0), SenseInfo('02379908-n', 0) ],
"_ambush_v_1_rel" : [ SenseInfo('01138204-v', 2), SenseInfo('01142203-v', 1) ],
"_mistaken_a_1_rel" : [ SenseInfo('02036397-a', 6), SenseInfo('00633235-a', 2), SenseInfo('02036397-a', 6), SenseInfo('00633235-a', 2) ],
"_repeated_a_1_rel" : [ SenseInfo('00592880-a', 6) ],
"_reign_n_1_rel" : [ SenseInfo('15260964-n', 1), SenseInfo('15260814-n', 0), SenseInfo('14443532-n', 0) ],
"_overcast_n_1_rel" : [ SenseInfo('14524198-n', 6), SenseInfo('13984468-n', 0), SenseInfo('03863442-n', 0), SenseInfo('00455076-n', 0) ],
"_increasing_a_1_rel" : [ SenseInfo('02534877-a', 14), SenseInfo('02537743-a', 0) ],
"_cover_v_1_rel" : [ SenseInfo('01332730-v', 35), SenseInfo('01207951-v', 19), SenseInfo('02687916-v', 18), SenseInfo('02675935-v', 16), SenseInfo('01033527-v', 14), SenseInfo('02629793-v', 10), SenseInfo('01912159-v', 4), SenseInfo('00967098-v', 3), SenseInfo('01129201-v', 2), SenseInfo('02395000-v', 1), SenseInfo('02148369-v', 1), SenseInfo('01148296-v', 1), SenseInfo('00967455-v', 1), SenseInfo('00891216-v', 1), SenseInfo('02672859-v', 0), SenseInfo('02474446-v', 0), SenseInfo('02395194-v', 0), SenseInfo('02310674-v', 0), SenseInfo('02147109-v', 0), SenseInfo('01582200-v', 0), SenseInfo('01430447-v', 0), SenseInfo('01336635-v', 0), SenseInfo('01150010-v', 0), SenseInfo('01148580-v', 0), SenseInfo('00060185-v', 0), SenseInfo('00048633-v', 0), SenseInfo('01332730-v', 35), SenseInfo('01207951-v', 19), SenseInfo('02687916-v', 18), SenseInfo('02675935-v', 16), SenseInfo('01033527-v', 14), SenseInfo('02629793-v', 10), SenseInfo('01912159-v', 4), SenseInfo('00967098-v', 3), SenseInfo('01129201-v', 2), SenseInfo('02395000-v', 1), SenseInfo('02148369-v', 1), SenseInfo('01148296-v', 1), SenseInfo('00967455-v', 1), SenseInfo('00891216-v', 1), SenseInfo('02672859-v', 0), SenseInfo('02474446-v', 0), SenseInfo('02395194-v', 0), SenseInfo('02310674-v', 0), SenseInfo('02147109-v', 0), SenseInfo('01582200-v', 0), SenseInfo('01430447-v', 0), SenseInfo('01336635-v', 0), SenseInfo('01150010-v', 0), SenseInfo('01148580-v', 0), SenseInfo('00060185-v', 0), SenseInfo('00048633-v', 0) ],
"_amp_v_1_rel" : [  ],
"_age_n_1_rel" : [ SenseInfo('04924103-n', 75), SenseInfo('15254028-n', 23), SenseInfo('15145171-n', 6), SenseInfo('15242955-n', 0), SenseInfo('15153787-n', 0) ],
"_coordinator_n_1_rel" : [ SenseInfo('09963914-n', 1) ],
"_civilization_n_1_rel" : [ SenseInfo('08111783-n', 17), SenseInfo('13448970-n', 0), SenseInfo('08287844-n', 0), SenseInfo('04811995-n', 0), SenseInfo('08111783-n', 17), SenseInfo('13448970-n', 0), SenseInfo('08287844-n', 0), SenseInfo('04811995-n', 0) ],
"_folk-dance_v_1_rel" : [ SenseInfo('01898769-v', 0), SenseInfo('01898769-v', 0) ],
"_money+back+guarantee_n_1_rel" : [  ],
"_partition_v_1_rel" : [ SenseInfo('01563724-v', 0), SenseInfo('00332835-v', 0) ],
"_eager_a_1_rel" : [ SenseInfo('00810916-a', 20), SenseInfo('00810916-a', 20), SenseInfo('00810916-a', 20) ],
"_Dalmation_n_1_rel" : [  ],
"_draw_v_up_rel" : [ SenseInfo('01448100-v', 13), SenseInfo('02293148-v', 10), SenseInfo('01582645-v', 10), SenseInfo('00730758-v', 10), SenseInfo('01995211-v', 9), SenseInfo('01690294-v', 7), SenseInfo('01854132-v', 6), SenseInfo('00987071-v', 6), SenseInfo('00675901-v', 6), SenseInfo('01760300-v', 5), SenseInfo('01199009-v', 5), SenseInfo('02088107-v', 4), SenseInfo('02311387-v', 3), SenseInfo('01078050-v', 3), SenseInfo('01643297-v', 2), SenseInfo('00556593-v', 2), SenseInfo('02097800-v', 1), SenseInfo('01690816-v', 1), SenseInfo('01643464-v', 1), SenseInfo('01243148-v', 1), SenseInfo('02742107-v', 0), SenseInfo('02628832-v', 0), SenseInfo('02483564-v', 0), SenseInfo('02103162-v', 0), SenseInfo('01539063-v', 0), SenseInfo('01505254-v', 0), SenseInfo('01359432-v', 0), SenseInfo('01243298-v', 0), SenseInfo('01212230-v', 0), SenseInfo('01115190-v', 0), SenseInfo('00476965-v', 0), SenseInfo('00430808-v', 0), SenseInfo('00327982-v', 0), SenseInfo('00197590-v', 0), SenseInfo('00143338-v', 0), SenseInfo('00097029-v', 0) ],
"_petition_v_1_rel" : [ SenseInfo('00754731-v', 2), SenseInfo('00754731-v', 2), SenseInfo('00754731-v', 2) ],
"_disengage_v_from_rel" : [ SenseInfo('01511380-v', 1), SenseInfo('01475953-v', 0), SenseInfo('00220276-v', 0) ],
"_cowardly_a_1_rel" : [ SenseInfo('00264776-a', 2) ],
"_hemispherical_a_1_rel" : [ SenseInfo('02740070-a', 0) ],
"_edify_v_1_rel" : [ SenseInfo('00991385-v', 1) ],
"_during_p_rel" : [  ],
"_out+of+date_a_1_rel" : [ SenseInfo('00669138-a', 0) ],
"_completeness_n_1_rel" : [ SenseInfo('14460974-n', 2), SenseInfo('04785414-n', 0) ],
"_astray_p_rel" : [ SenseInfo('00206386-r', 1), SenseInfo('00495858-r', 0) ],
"_slim_v_1_rel" : [ SenseInfo('00045817-v', 0) ],
"_control_v_for_rel" : [ SenseInfo('02441022-v', 28), SenseInfo('02510337-v', 20), SenseInfo('01224744-v', 7), SenseInfo('01803936-v', 1), SenseInfo('02520997-v', 0), SenseInfo('00663160-v', 0), SenseInfo('00662589-v', 0), SenseInfo('00597385-v', 0) ],
"_flood_v_1_rel" : [ SenseInfo('01524523-v', 6), SenseInfo('00217152-v', 3), SenseInfo('02356704-v', 0), SenseInfo('00452220-v', 0) ],
"_knowledge_n_of_rel" : [ SenseInfo('00023271-n', 45), SenseInfo('00023271-n', 45), SenseInfo('00023271-n', 45), SenseInfo('00023271-n', 45) ],
"_caress_n_1_rel" : [ SenseInfo('00144778-n', 2) ],
"_shah_n_1_rel" : [ SenseInfo('10585496-n', 0) ],
"_travelers+check_n_1_rel" : [  ],
"_volunteer_v_1_rel" : [ SenseInfo('00880102-v', 4), SenseInfo('02425112-v', 2), SenseInfo('02424984-v', 2), SenseInfo('00880102-v', 4), SenseInfo('02425112-v', 2), SenseInfo('02424984-v', 2) ],
"_suspect_v_1_rel" : [ SenseInfo('00921072-v', 6), SenseInfo('00687926-v', 2), SenseInfo('00924873-v', 1), SenseInfo('00921072-v', 6), SenseInfo('00687926-v', 2), SenseInfo('00924873-v', 1) ],
"_look_a_1_rel" : [ SenseInfo('04679738-n', 24), SenseInfo('00877127-n', 16), SenseInfo('04674715-n', 9), SenseInfo('14526182-n', 0) ],
"_wage_n_1_rel" : [ SenseInfo('13279262-n', 70) ],
"_substation_n_1_rel" : [ SenseInfo('04348702-n', 1) ],
"_compound_n_1_rel" : [ SenseInfo('05870180-n', 3), SenseInfo('14818238-n', 1), SenseInfo('03081859-n', 1) ],
"_council_n_of_rel" : [ SenseInfo('08310949-n', 8), SenseInfo('08312559-n', 0), SenseInfo('08309409-n', 0) ],
"_smelt_n_1_rel" : [ SenseInfo('07798554-n', 0), SenseInfo('02540412-n', 0) ],
"_disastrous_a_1_rel" : [ SenseInfo('01050088-a', 6) ],
"_disembark_v_1_rel" : [ SenseInfo('01979241-v', 0) ],
"_pirouette_v_1_rel" : [ SenseInfo('02048384-v', 0) ],
"_mesmerist_n_1_rel" : [ SenseInfo('10195261-n', 0) ],
"_handy_a_for_rel" : [ SenseInfo('00019731-a', 2), SenseInfo('00604897-a', 1), SenseInfo('00062626-a', 0), SenseInfo('00019731-a', 2), SenseInfo('00604897-a', 1), SenseInfo('00062626-a', 0), SenseInfo('00019731-a', 2), SenseInfo('00604897-a', 1), SenseInfo('00062626-a', 0), SenseInfo('00019731-a', 2), SenseInfo('00604897-a', 1), SenseInfo('00062626-a', 0), SenseInfo('00019731-a', 2), SenseInfo('00604897-a', 1), SenseInfo('00062626-a', 0) ],
"_accessible_a_1_rel" : [ SenseInfo('00019131-a', 0), SenseInfo('00533221-a', 0), SenseInfo('00183675-a', 0), SenseInfo('00134251-a', 0) ],
"_grep_v_for_rel" : [  ],
"_flutter_v_1_rel" : [ SenseInfo('01899891-v', 1), SenseInfo('01878719-v', 1), SenseInfo('01900255-v', 0), SenseInfo('01879928-v', 0), SenseInfo('00008195-v', 0) ],
"_tuck_v_1_rel" : [ SenseInfo('01389776-v', 8), SenseInfo('01390327-v', 0), SenseInfo('01330822-v', 0), SenseInfo('01389776-v', 8), SenseInfo('01390327-v', 0), SenseInfo('01330822-v', 0) ],
"_doodle_v_1_rel" : [ SenseInfo('01693324-v', 0) ],
"_corps_n_1_rel" : [ SenseInfo('08212527-n', 4), SenseInfo('08213079-n', 2) ],
"_autonomy_n_1_rel" : [ SenseInfo('13992514-n', 1), SenseInfo('14001031-n', 0), SenseInfo('13992514-n', 1), SenseInfo('14001031-n', 0) ],
"_stand-alone_a_1_rel" : [ SenseInfo('00523867-a', 0), SenseInfo('00523867-a', 0) ],
"_fail_v_1_rel" : [ SenseInfo('02529284-v', 66), SenseInfo('02528380-v', 33), SenseInfo('01799235-v', 5), SenseInfo('00434374-v', 3), SenseInfo('02599528-v', 1), SenseInfo('02523784-v', 0), SenseInfo('02523521-v', 0), SenseInfo('02522319-v', 0), SenseInfo('02318403-v', 0), SenseInfo('00560247-v', 0), SenseInfo('00172909-v', 0), SenseInfo('02529284-v', 66), SenseInfo('02528380-v', 33), SenseInfo('01799235-v', 5), SenseInfo('00434374-v', 3), SenseInfo('02599528-v', 1), SenseInfo('02523784-v', 0), SenseInfo('02523521-v', 0), SenseInfo('02522319-v', 0), SenseInfo('02318403-v', 0), SenseInfo('00560247-v', 0), SenseInfo('00172909-v', 0) ],
"_distort_v_1_rel" : [ SenseInfo('00835903-v', 5), SenseInfo('01223182-v', 1), SenseInfo('01350699-v', 0), SenseInfo('00836926-v', 0), SenseInfo('00476744-v', 0) ],
"_boathouse_n_1_rel" : [ SenseInfo('02859443-n', 0) ],
"_napkin_n_1_rel" : [ SenseInfo('03807537-n', 0), SenseInfo('03188531-n', 0) ],
"_lamp_n_1_rel" : [ SenseInfo('03636248-n', 12), SenseInfo('03636649-n', 2) ],
"_turtle_n_1_rel" : [ SenseInfo('04502197-n', 0), SenseInfo('01662784-n', 0) ],
"_breakfast_n_1_rel" : [ SenseInfo('07574602-n', 12), SenseInfo('07574602-n', 12) ],
"_presuppose_v_1_rel" : [ SenseInfo('00716531-v', 2), SenseInfo('00716345-v', 2), SenseInfo('00716531-v', 2), SenseInfo('00716345-v', 2), SenseInfo('00716531-v', 2), SenseInfo('00716345-v', 2) ],
"_kroner_n_1_rel" : [ SenseInfo('13682971-n', 0), SenseInfo('13682740-n', 0), SenseInfo('13682971-n', 0), SenseInfo('13682740-n', 0), SenseInfo('13682971-n', 0), SenseInfo('13682740-n', 0), SenseInfo('13682971-n', 0), SenseInfo('13682740-n', 0), SenseInfo('13682971-n', 0), SenseInfo('13682740-n', 0), SenseInfo('13682971-n', 0), SenseInfo('13682740-n', 0), SenseInfo('13682971-n', 0), SenseInfo('13682740-n', 0) ],
"_irony_n_1_rel" : [ SenseInfo('06777164-n', 5), SenseInfo('04715075-n', 3), SenseInfo('07106246-n', 0) ],
"_landform_n_1_rel" : [  ],
"_balloon_n_1_rel" : [ SenseInfo('02782093-n', 3), SenseInfo('02782329-n', 1) ],
"_pfennig_n_1_rel" : [ SenseInfo('13688190-n', 1) ],
"free_relative_ever_q_rel" : [  ],
"_room_n_unit_rel" : [ SenseInfo('04105893-n', 116), SenseInfo('13777764-n', 10), SenseInfo('14485436-n', 3), SenseInfo('07985948-n', 0) ],
"_many_n_1_rel" : [ SenseInfo('01551633-a', 347) ],
"_discredit_v_1_rel" : [ SenseInfo('00687738-v', 1), SenseInfo('00847478-v', 0), SenseInfo('00684645-v', 0) ],
"_tragedy_n_1_rel" : [ SenseInfo('07314838-n', 8), SenseInfo('07016948-n', 1) ],
"_accelerate_v_cause_rel" : [ SenseInfo('00438178-v', 11), SenseInfo('00439343-v', 1) ],
"_punic_a_1_rel" : [ SenseInfo('03104740-a', 0), SenseInfo('00960094-a', 0) ],
"_collect+call_n_1_rel" : [ SenseInfo('06273294-n', 0) ],
"_look_v_after_rel" : [ SenseInfo('02130524-v', 274), SenseInfo('02133435-v', 126), SenseInfo('00033599-v', 25), SenseInfo('02153709-v', 8), SenseInfo('02693319-v', 1), SenseInfo('02549581-v', 1), SenseInfo('00929362-v', 1), SenseInfo('00720063-v', 1), SenseInfo('02658447-v', 0), SenseInfo('00712708-v', 0) ],
"_nuisance_n_1_rel" : [ SenseInfo('05830527-n', 3), SenseInfo('10391513-n', 0), SenseInfo('05830527-n', 3), SenseInfo('10391513-n', 0), SenseInfo('05830527-n', 3), SenseInfo('10391513-n', 0) ],
"_burst_v_cause_rel" : [ SenseInfo('00309310-v', 11), SenseInfo('01785395-v', 7), SenseInfo('00306017-v', 7), SenseInfo('01964634-v', 4), SenseInfo('02715595-v', 2), SenseInfo('00424224-v', 2), SenseInfo('01989562-v', 0), SenseInfo('00333594-v', 0) ],
"_exposure_n_of-to_rel" : [ SenseInfo('05043973-n', 6), SenseInfo('00157463-n', 3), SenseInfo('07215377-n', 2), SenseInfo('05934123-n', 2), SenseInfo('14543931-n', 0), SenseInfo('13640206-n', 0), SenseInfo('03925226-n', 0), SenseInfo('00907340-n', 0), SenseInfo('00522537-n', 0), SenseInfo('00204659-n', 0), SenseInfo('05043973-n', 6), SenseInfo('00157463-n', 3), SenseInfo('07215377-n', 2), SenseInfo('05934123-n', 2), SenseInfo('14543931-n', 0), SenseInfo('13640206-n', 0), SenseInfo('03925226-n', 0), SenseInfo('00907340-n', 0), SenseInfo('00522537-n', 0), SenseInfo('00204659-n', 0) ],
"_heroine_n_1_rel" : [ SenseInfo('10173305-n', 2), SenseInfo('10173410-n', 0) ],
"_leather_n_1_rel" : [ SenseInfo('14759722-n', 11) ],
"_intellect_n_1_rel" : [ SenseInfo('05618849-n', 5), SenseInfo('05651680-n', 1), SenseInfo('09621545-n', 0) ],
"_ca_x_deg_rel" : [ SenseInfo('14632648-n', 0), SenseInfo('09060768-n', 0), SenseInfo('14632648-n', 0), SenseInfo('09060768-n', 0) ],
"_artery_n_1_rel" : [ SenseInfo('05333777-n', 5), SenseInfo('02744532-n', 0) ],
"_certificated_a_1_rel" : [ SenseInfo('00342626-a', 0) ],
"_route_n_1_rel" : [ SenseInfo('08616311-n', 11), SenseInfo('04096066-n', 2), SenseInfo('08616311-n', 11), SenseInfo('04096066-n', 2), SenseInfo('08616311-n', 11), SenseInfo('04096066-n', 2), SenseInfo('08616311-n', 11), SenseInfo('04096066-n', 2) ],
"_advertise_v_for_rel" : [ SenseInfo('00975902-v', 7), SenseInfo('00976653-v', 0) ],
"_builder_n_of_rel" : [ SenseInfo('15097209-n', 11), SenseInfo('09878559-n', 0), SenseInfo('09878275-n', 0) ],
"_silence_n_1_rel" : [ SenseInfo('13925550-n', 12), SenseInfo('04982207-n', 10), SenseInfo('04651974-n', 8), SenseInfo('04652177-n', 1) ],
"_experienced_n_1_rel" : [ SenseInfo('00935500-a', 10) ],
"_crusade_v_1_rel" : [ SenseInfo('02589576-v', 0), SenseInfo('01093944-v', 0) ],
"_auspiciousness_n_1_rel" : [ SenseInfo('05161150-n', 0) ],
"_taw_n_1_rel" : [ SenseInfo('06839083-n', 0), SenseInfo('04396093-n', 0) ],
"_furrow_v_cause_rel" : [ SenseInfo('01277431-v', 1), SenseInfo('01277784-v', 0), SenseInfo('01277649-v', 0) ],
"_biology_n_1_rel" : [ SenseInfo('06037666-n', 4), SenseInfo('11473488-n', 0), SenseInfo('07993109-n', 0) ],
"_important_a_for_rel" : [ SenseInfo('01275562-a', 146), SenseInfo('02161432-a', 4), SenseInfo('00655779-a', 2), SenseInfo('01830403-a', 1), SenseInfo('01539887-a', 0), SenseInfo('01275562-a', 146), SenseInfo('02161432-a', 4), SenseInfo('00655779-a', 2), SenseInfo('01830403-a', 1), SenseInfo('01539887-a', 0), SenseInfo('01275562-a', 146), SenseInfo('02161432-a', 4), SenseInfo('00655779-a', 2), SenseInfo('01830403-a', 1), SenseInfo('01539887-a', 0), SenseInfo('01275562-a', 146), SenseInfo('02161432-a', 4), SenseInfo('00655779-a', 2), SenseInfo('01830403-a', 1), SenseInfo('01539887-a', 0), SenseInfo('01275562-a', 146), SenseInfo('02161432-a', 4), SenseInfo('00655779-a', 2), SenseInfo('01830403-a', 1), SenseInfo('01539887-a', 0) ],
"_formidable_a_1_rel" : [ SenseInfo('01284836-a', 4), SenseInfo('00195383-a', 4) ],
"_shade_n_1_rel" : [ SenseInfo('13984613-n', 9), SenseInfo('04959230-n', 5), SenseInfo('04181718-n', 3), SenseInfo('06606191-n', 2), SenseInfo('13951794-n', 0), SenseInfo('13763185-n', 0), SenseInfo('05898171-n', 0), SenseInfo('04181983-n', 0) ],
"_sentence_v_to_rel" : [ SenseInfo('00906735-v', 6), SenseInfo('00906735-v', 6) ],
"_unbelievably_x_deg_rel" : [ SenseInfo('00295825-r', 0), SenseInfo('00244787-r', 0) ],
"_suck_v_out_rel" : [ SenseInfo('01169704-v', 4), SenseInfo('01854888-v', 2), SenseInfo('02765692-v', 0), SenseInfo('02674340-v', 0), SenseInfo('02117170-v', 0), SenseInfo('01539063-v', 0), SenseInfo('01186428-v', 0) ],
"_bird+feed_v_1_rel" : [  ],
"_catalytic_a_1_rel" : [ SenseInfo('03054409-a', 0) ],
"_weight_v_1_rel" : [ SenseInfo('01487311-v', 1), SenseInfo('00680485-v', 1) ],
"_swathe_v_in_rel" : [ SenseInfo('01300271-v', 1) ],
"_herein_p_rel" : [ SenseInfo('00108913-r', 1) ],
"_invertebrate_a_1_rel" : [ SenseInfo('02510273-a', 0) ],
"_load_v_cause_rel" : [ SenseInfo('01489989-v', 8), SenseInfo('01490336-v', 3), SenseInfo('02231910-v', 0), SenseInfo('01612084-v', 0), SenseInfo('00487748-v', 0) ],
"_faint_n_1_rel" : [ SenseInfo('07478318-n', 0) ],
"_calamity_n_1_rel" : [ SenseInfo('07314838-n', 3) ],
"_german_n_1_rel" : [ SenseInfo('09747722-n', 7), SenseInfo('06950528-n', 6) ],
"_sloppy_a_about_rel" : [ SenseInfo('02426420-a', 2), SenseInfo('02550170-a', 0), SenseInfo('02548066-a', 0), SenseInfo('01446991-a', 0), SenseInfo('00856511-a', 0), SenseInfo('00312519-a', 0) ],
"_freefall_n_1_rel" : [  ],
"_intriguing_a_1_rel" : [ SenseInfo('01897106-a', 0), SenseInfo('01344684-a', 0) ],
"_hydro-electricity_n_1_rel" : [ SenseInfo('11467202-n', 0), SenseInfo('11467202-n', 0), SenseInfo('11467202-n', 0) ],
"_cloudiness_n_1_rel" : [ SenseInfo('14524198-n', 0), SenseInfo('13984468-n', 0), SenseInfo('04703698-n', 0) ],
"_crusty_a_1_rel" : [ SenseInfo('01695749-a', 0), SenseInfo('01137000-a', 0), SenseInfo('01695749-a', 0), SenseInfo('01137000-a', 0), SenseInfo('01695749-a', 0), SenseInfo('01137000-a', 0) ],
"_in+any+case_a_1_rel" : [  ],
"_erg_n_1_rel" : [ SenseInfo('13725726-n', 0) ],
"_defeat_n_1_rel" : [ SenseInfo('07475364-n', 12), SenseInfo('07540866-n', 3) ],
"_passive_a_1_rel" : [ SenseInfo('00039592-a', 5), SenseInfo('02513101-a', 1), SenseInfo('00042228-a', 0) ],
"_fashion_a_1_rel" : [ SenseInfo('04928903-n', 17), SenseInfo('00415226-n', 6), SenseInfo('05750657-n', 2), SenseInfo('03323593-n', 0) ],
"_rye_n_1_rel" : [ SenseInfo('12157179-n', 0), SenseInfo('12134025-n', 0), SenseInfo('07907429-n', 0) ],
"_piano_n_1_rel" : [ SenseInfo('03928116-n', 10), SenseInfo('04991389-n', 0) ],
"_expertness_n_1_rel" : [ SenseInfo('05640729-n', 0) ],
"_loblolly_n_1_rel" : [ SenseInfo('07875086-n', 1) ],
"_twinkle_n_1_rel" : [ SenseInfo('07411645-n', 0), SenseInfo('04953380-n', 0) ],
"_posit_v_1_rel" : [ SenseInfo('01575675-v', 0), SenseInfo('00878136-v', 0), SenseInfo('00716758-v', 0), SenseInfo('01575675-v', 0), SenseInfo('00878136-v', 0), SenseInfo('00716758-v', 0) ],
"_stamp_v_out_rel" : [ SenseInfo('01925338-v', 3), SenseInfo('01273016-v', 3), SenseInfo('02144644-v', 1), SenseInfo('01273814-v', 1), SenseInfo('00656292-v', 1), SenseInfo('00478488-v', 1), SenseInfo('01624568-v', 0), SenseInfo('01594362-v', 0), SenseInfo('01531265-v', 0) ],
"_paso+doble_n_1_rel" : [ SenseInfo('00536872-n', 1), SenseInfo('07056265-n', 0) ],
"_slap_n_1_rel" : [ SenseInfo('07410745-n', 0), SenseInfo('00133668-n', 0) ],
"_deep_a_1_rel" : [ SenseInfo('00692762-a', 16), SenseInfo('01873163-a', 12), SenseInfo('00690058-a', 11), SenseInfo('00445937-a', 7), SenseInfo('01511292-a', 6), SenseInfo('01215935-a', 5), SenseInfo('00403385-a', 3), SenseInfo('02410983-a', 2), SenseInfo('02561391-a', 0), SenseInfo('01513776-a', 0), SenseInfo('01385046-a', 0), SenseInfo('01206916-a', 0), SenseInfo('00939444-a', 0), SenseInfo('00899226-a', 0), SenseInfo('00149120-a', 0), SenseInfo('00692762-a', 16), SenseInfo('01873163-a', 12), SenseInfo('00690058-a', 11), SenseInfo('00445937-a', 7), SenseInfo('01511292-a', 6), SenseInfo('01215935-a', 5), SenseInfo('00403385-a', 3), SenseInfo('02410983-a', 2), SenseInfo('02561391-a', 0), SenseInfo('01513776-a', 0), SenseInfo('01385046-a', 0), SenseInfo('01206916-a', 0), SenseInfo('00939444-a', 0), SenseInfo('00899226-a', 0), SenseInfo('00149120-a', 0), SenseInfo('00692762-a', 16), SenseInfo('01873163-a', 12), SenseInfo('00690058-a', 11), SenseInfo('00445937-a', 7), SenseInfo('01511292-a', 6), SenseInfo('01215935-a', 5), SenseInfo('00403385-a', 3), SenseInfo('02410983-a', 2), SenseInfo('02561391-a', 0), SenseInfo('01513776-a', 0), SenseInfo('01385046-a', 0), SenseInfo('01206916-a', 0), SenseInfo('00939444-a', 0), SenseInfo('00899226-a', 0), SenseInfo('00149120-a', 0), SenseInfo('00692762-a', 16), SenseInfo('01873163-a', 12), SenseInfo('00690058-a', 11), SenseInfo('00445937-a', 7), SenseInfo('01511292-a', 6), SenseInfo('01215935-a', 5), SenseInfo('00403385-a', 3), SenseInfo('02410983-a', 2), SenseInfo('02561391-a', 0), SenseInfo('01513776-a', 0), SenseInfo('01385046-a', 0), SenseInfo('01206916-a', 0), SenseInfo('00939444-a', 0), SenseInfo('00899226-a', 0), SenseInfo('00149120-a', 0), SenseInfo('00692762-a', 16), SenseInfo('01873163-a', 12), SenseInfo('00690058-a', 11), SenseInfo('00445937-a', 7), SenseInfo('01511292-a', 6), SenseInfo('01215935-a', 5), SenseInfo('00403385-a', 3), SenseInfo('02410983-a', 2), SenseInfo('02561391-a', 0), SenseInfo('01513776-a', 0), SenseInfo('01385046-a', 0), SenseInfo('01206916-a', 0), SenseInfo('00939444-a', 0), SenseInfo('00899226-a', 0), SenseInfo('00149120-a', 0) ],
"_chevron_n_1_rel" : [ SenseInfo('07269552-n', 0), SenseInfo('03015975-n', 0) ],
"_malfunction_n_1_rel" : [ SenseInfo('07318476-n', 0) ],
"_envelope_n_1_rel" : [ SenseInfo('03291819-n', 9), SenseInfo('03291741-n', 2), SenseInfo('13869788-n', 0), SenseInfo('09273776-n', 0), SenseInfo('05204473-n', 0), SenseInfo('03291963-n', 0) ],
"_alas_a_1_rel" : [  ],
"_mandate_n_1_rel" : [ SenseInfo('06556481-n', 1), SenseInfo('08597727-n', 0), SenseInfo('01140658-n', 0), SenseInfo('06556481-n', 1), SenseInfo('08597727-n', 0), SenseInfo('01140658-n', 0), SenseInfo('06556481-n', 1), SenseInfo('08597727-n', 0), SenseInfo('01140658-n', 0), SenseInfo('06556481-n', 1), SenseInfo('08597727-n', 0), SenseInfo('01140658-n', 0) ],
"_plain_n_1_rel" : [ SenseInfo('09393605-n', 1), SenseInfo('03625226-n', 0) ],
"_phoenician_a_1_rel" : [ SenseInfo('02776931-a', 0), SenseInfo('02776931-a', 0) ],
"_enjoyable_a_1_rel" : [ SenseInfo('01801029-a', 1), SenseInfo('01801029-a', 1), SenseInfo('01801029-a', 1) ],
"_qualm_n_1_rel" : [ SenseInfo('07525555-n', 1), SenseInfo('14360320-n', 0) ],
"_ally_n_1_rel" : [ SenseInfo('08305942-n', 3), SenseInfo('09785042-n', 1) ],
"_pty_n_1_rel" : [  ],
"_convex_n_1_rel" : [ SenseInfo('00537339-a', 1) ],
"_goof_n_1_rel" : [ SenseInfo('10157744-n', 0), SenseInfo('09930876-n', 0) ],
"_planner_n_1_rel" : [ SenseInfo('10438172-n', 4), SenseInfo('03956785-n', 0) ],
"_baptist_n_1_rel" : [ SenseInfo('09838701-n', 2) ],
"_in+vain_a_1_rel" : [  ],
"_qualitative_a_1_rel" : [ SenseInfo('01914521-a', 5), SenseInfo('02976870-a', 0), SenseInfo('01914521-a', 5), SenseInfo('02976870-a', 0) ],
"_pool_v_cause_rel" : [ SenseInfo('02295842-v', 4), SenseInfo('01090107-v', 0) ],
"_raze_v_1_rel" : [ SenseInfo('01661804-v', 0) ],
"_tee+shirt_n_1_rel" : [ SenseInfo('03595614-n', 0), SenseInfo('03595614-n', 0), SenseInfo('03595614-n', 0) ],
"_intersect_v_cause_rel" : [ SenseInfo('02023396-v', 7) ],
"_mall_n_1_rel" : [ SenseInfo('04010205-n', 0), SenseInfo('03965456-n', 0), SenseInfo('04010205-n', 0), SenseInfo('03965456-n', 0) ],
"_dinar_n_1_rel" : [ SenseInfo('13696893-n', 0), SenseInfo('13671182-n', 0), SenseInfo('13670668-n', 0), SenseInfo('13670281-n', 0), SenseInfo('13669860-n', 0), SenseInfo('13669590-n', 0), SenseInfo('13669342-n', 0), SenseInfo('13668864-n', 0), SenseInfo('13668491-n', 0) ],
"_glance_v_at_rel" : [ SenseInfo('02165304-v', 34), SenseInfo('01893000-v', 1) ],
"_feather_v_1_rel" : [ SenseInfo('01272915-v', 1), SenseInfo('01272798-v', 0), SenseInfo('01124964-v', 0), SenseInfo('01124828-v', 0), SenseInfo('00094312-v', 0) ],
"_kidnapper_n_1_rel" : [ SenseInfo('10230801-n', 4) ],
"_scum_n_1_rel" : [ SenseInfo('08402147-n', 0), SenseInfo('04157703-n', 0) ],
"_dislodge_v_1_rel" : [ SenseInfo('01528522-v', 2), SenseInfo('01883344-v', 0), SenseInfo('01527508-v', 0) ],
"_score_n_of_rel" : [ SenseInfo('05737153-n', 18), SenseInfo('06815714-n', 8), SenseInfo('13594585-n', 4), SenseInfo('08272652-n', 4), SenseInfo('09179382-n', 1), SenseInfo('05819338-n', 1), SenseInfo('14491034-n', 0), SenseInfo('13905405-n', 0), SenseInfo('07549536-n', 0), SenseInfo('00186634-n', 0), SenseInfo('00160688-n', 0) ],
"_crease_v_1_rel" : [ SenseInfo('01278427-v', 1), SenseInfo('01277784-v', 0), SenseInfo('01240514-v', 0), SenseInfo('00564857-v', 0) ],
"_smell_n_of_rel" : [ SenseInfo('05713737-n', 8), SenseInfo('04980008-n', 5), SenseInfo('14526182-n', 1), SenseInfo('05658603-n', 0), SenseInfo('00882961-n', 0) ],
"_divide_v_up_rel" : [ SenseInfo('02467662-v', 20), SenseInfo('00642098-v', 11), SenseInfo('02621853-v', 4), SenseInfo('01557774-v', 2), SenseInfo('02031158-v', 1), SenseInfo('01556921-v', 1), SenseInfo('02467662-v', 20), SenseInfo('00642098-v', 11), SenseInfo('02621853-v', 4), SenseInfo('01557774-v', 2), SenseInfo('02031158-v', 1), SenseInfo('01556921-v', 1) ],
"_as+such_a_1_rel" : [  ],
"_right_n_1_rel" : [ SenseInfo('05174653-n', 41), SenseInfo('08625073-n', 27), SenseInfo('04091839-n', 5), SenseInfo('08416652-n', 4), SenseInfo('05565337-n', 2), SenseInfo('00351000-n', 2), SenseInfo('04850341-n', 1), SenseInfo('13341756-n', 0), SenseInfo('05174653-n', 41), SenseInfo('08625073-n', 27), SenseInfo('04091839-n', 5), SenseInfo('08416652-n', 4), SenseInfo('05565337-n', 2), SenseInfo('00351000-n', 2), SenseInfo('04850341-n', 1), SenseInfo('13341756-n', 0), SenseInfo('05174653-n', 41), SenseInfo('08625073-n', 27), SenseInfo('04091839-n', 5), SenseInfo('08416652-n', 4), SenseInfo('05565337-n', 2), SenseInfo('00351000-n', 2), SenseInfo('04850341-n', 1), SenseInfo('13341756-n', 0) ],
"_hunt_n_1_rel" : [ SenseInfo('11067047-n', 0), SenseInfo('11066938-n', 0), SenseInfo('11066772-n', 0), SenseInfo('08229779-n', 0), SenseInfo('05770257-n', 0), SenseInfo('00945401-n', 0), SenseInfo('00622584-n', 0), SenseInfo('00452293-n', 0) ],
"_wicca_n_1_rel" : [ SenseInfo('08485977-n', 0), SenseInfo('06245462-n', 0) ],
"_cereal_n_1_rel" : [ SenseInfo('12141495-n', 0), SenseInfo('07802417-n', 0), SenseInfo('07702796-n', 0) ],
"_gaze_v_at_rel" : [ SenseInfo('02132745-v', 25) ],
"_breech_n_1_rel" : [ SenseInfo('02895881-n', 0) ],
"_folkloric_a_1_rel" : [  ],
"_radish_n_1_rel" : [ SenseInfo('07735687-n', 8), SenseInfo('11895092-n', 0), SenseInfo('11894958-n', 0), SenseInfo('11894770-n', 0), SenseInfo('11894327-n', 0) ],
"_intricate_a_1_rel" : [ SenseInfo('02178500-a', 7) ],
"_download_n_of_rel" : [  ],
"_clang_n_1_rel" : [ SenseInfo('07380144-n', 1) ],
"_or+something_a_1_rel" : [  ],
"_arms_n_1_rel" : [ SenseInfo('05563770-n', 104), SenseInfo('02737833-n', 3), SenseInfo('04565375-n', 1), SenseInfo('02737660-n', 1), SenseInfo('08401248-n', 0), SenseInfo('04236377-n', 0), SenseInfo('05563770-n', 104), SenseInfo('02737833-n', 3), SenseInfo('04565375-n', 1), SenseInfo('02737660-n', 1), SenseInfo('08401248-n', 0), SenseInfo('04236377-n', 0), SenseInfo('05563770-n', 104), SenseInfo('02737833-n', 3), SenseInfo('04565375-n', 1), SenseInfo('02737660-n', 1), SenseInfo('08401248-n', 0), SenseInfo('04236377-n', 0), SenseInfo('05563770-n', 104), SenseInfo('02737833-n', 3), SenseInfo('04565375-n', 1), SenseInfo('02737660-n', 1), SenseInfo('08401248-n', 0), SenseInfo('04236377-n', 0) ],
"_tepid_a_1_rel" : [ SenseInfo('02529581-a', 1), SenseInfo('00887472-a', 0), SenseInfo('02529581-a', 1), SenseInfo('00887472-a', 0) ],
"_foursome_n_1_rel" : [ SenseInfo('07987380-n', 1), SenseInfo('13744304-n', 0) ],
"_thatch_n_1_rel" : [ SenseInfo('05261310-n', 1), SenseInfo('15069712-n', 0), SenseInfo('11334003-n', 0), SenseInfo('04417672-n', 0) ],
"_disordered_a_1_rel" : [ SenseInfo('01669246-a', 3), SenseInfo('00465221-a', 1), SenseInfo('01668250-a', 0) ],
"_volunteer_n_1_rel" : [ SenseInfo('10759331-n', 3), SenseInfo('10759151-n', 1), SenseInfo('09745732-n', 0) ],
"_breeder_n_1_rel" : [ SenseInfo('09873899-n', 0) ],
"_handcuff_v_1_rel" : [ SenseInfo('01288201-v', 0) ],
"_huckleberry_n_1_rel" : [ SenseInfo('12246641-n', 0), SenseInfo('12236546-n', 0), SenseInfo('07743384-n', 0) ],
"_indefinite_a_1_rel" : [ SenseInfo('00701479-a', 8), SenseInfo('00336564-a', 0), SenseInfo('00701479-a', 8), SenseInfo('00336564-a', 0) ],
"_cinephile_n_1_rel" : [  ],
"_demo_v_to_rel" : [ SenseInfo('02148788-v', 0), SenseInfo('02148788-v', 0) ],
"_cavern_n_1_rel" : [ SenseInfo('09239451-n', 1), SenseInfo('09239302-n', 1) ],
"_bottomless_a_1_rel" : [ SenseInfo('00690892-a', 1), SenseInfo('02443005-a', 0), SenseInfo('01415917-a', 0), SenseInfo('00458940-a', 0) ],
"_opener_n_1_rel" : [ SenseInfo('07326369-n', 3), SenseInfo('10737431-n', 0), SenseInfo('03848348-n', 0) ],
"_magazine_n_1_rel" : [ SenseInfo('06595351-n', 13), SenseInfo('03704210-n', 2), SenseInfo('08063303-n', 1), SenseInfo('03704376-n', 0), SenseInfo('03704038-n', 0), SenseInfo('02973017-n', 0), SenseInfo('06595351-n', 13), SenseInfo('03704210-n', 2), SenseInfo('08063303-n', 1), SenseInfo('03704376-n', 0), SenseInfo('03704038-n', 0), SenseInfo('02973017-n', 0) ],
"_photography_n_1_rel" : [ SenseInfo('00903559-n', 1), SenseInfo('13536794-n', 0), SenseInfo('00620554-n', 0) ],
"_fumble_v_1_rel" : [ SenseInfo('01314738-v', 4), SenseInfo('02051547-v', 1), SenseInfo('01211019-v', 1), SenseInfo('02527651-v', 0), SenseInfo('01075327-v', 0) ],
"_unsettled_a_1_rel" : [ SenseInfo('02130514-a', 1), SenseInfo('02126889-a', 0), SenseInfo('02504558-a', 0), SenseInfo('01313835-a', 0) ],
"_former_n_1_rel" : [ SenseInfo('13846356-n', 0) ],
"_percussion_n_1_rel" : [ SenseInfo('00545059-n', 1), SenseInfo('00377813-n', 1), SenseInfo('08217557-n', 0), SenseInfo('00876239-n', 0) ],
"_freight_n_1_rel" : [ SenseInfo('02964389-n', 4), SenseInfo('01106272-n', 1), SenseInfo('13326198-n', 0) ],
"_top+of+the+line_a_1_rel" : [  ],
"_crutch_n_1_rel" : [ SenseInfo('03141823-n', 2), SenseInfo('00178700-n', 1) ],
"_echo_v_1_rel" : [ SenseInfo('00957679-v', 5), SenseInfo('02183787-v', 2), SenseInfo('02675458-v', 0) ],
"_posture_v_1_rel" : [ SenseInfo('02519183-v', 0), SenseInfo('02142775-v', 0) ],
"_hare_n_1_rel" : [ SenseInfo('02326432-n', 1), SenseInfo('07666521-n', 0), SenseInfo('02326432-n', 1), SenseInfo('07666521-n', 0) ],
"_defend_v_from_rel" : [ SenseInfo('00895304-v', 19), SenseInfo('01127795-v', 14), SenseInfo('01129876-v', 3), SenseInfo('01091427-v', 2), SenseInfo('01149138-v', 1), SenseInfo('02581675-v', 0), SenseInfo('01017643-v', 0), SenseInfo('00895304-v', 19), SenseInfo('01127795-v', 14), SenseInfo('01129876-v', 3), SenseInfo('01091427-v', 2), SenseInfo('01149138-v', 1), SenseInfo('02581675-v', 0), SenseInfo('01017643-v', 0) ],
"_chin_n_1_rel" : [ SenseInfo('05599617-n', 14), SenseInfo('06933279-n', 0) ],
"_foil_n_1_rel" : [ SenseInfo('03375694-n', 5), SenseInfo('05853924-n', 0), SenseInfo('03553019-n', 0), SenseInfo('03375956-n', 0), SenseInfo('03375575-n', 0) ],
"_heal_v_cause_rel" : [ SenseInfo('00270561-v', 2), SenseInfo('00099184-v', 1), SenseInfo('00081725-v', 0), SenseInfo('00270561-v', 2), SenseInfo('00099184-v', 1), SenseInfo('00081725-v', 0), SenseInfo('00270561-v', 2), SenseInfo('00099184-v', 1), SenseInfo('00081725-v', 0), SenseInfo('00270561-v', 2), SenseInfo('00099184-v', 1), SenseInfo('00081725-v', 0) ],
"_backer_n_1_rel" : [ SenseInfo('09793717-n', 2) ],
"_icefall_n_1_rel" : [ SenseInfo('09308918-n', 0) ],
"_proclamation_n_of_rel" : [ SenseInfo('06726158-n', 6), SenseInfo('01266491-n', 0), SenseInfo('06726158-n', 6), SenseInfo('01266491-n', 0) ],
"_face+to+face_p_rel" : [ SenseInfo('00044754-r', 2), SenseInfo('00044861-r', 0), SenseInfo('01767975-a', 0), SenseInfo('00044754-r', 2), SenseInfo('00044861-r', 0), SenseInfo('01767975-a', 0), SenseInfo('00044754-r', 2), SenseInfo('00044861-r', 0), SenseInfo('01767975-a', 0), SenseInfo('00044754-r', 2), SenseInfo('00044861-r', 0), SenseInfo('01767975-a', 0), SenseInfo('00044754-r', 2), SenseInfo('00044861-r', 0), SenseInfo('01767975-a', 0) ],
"_leeway_n_1_rel" : [ SenseInfo('13507210-n', 0), SenseInfo('04749991-n', 0) ],
"_fuzz_v_cause_rel" : [  ],
"_promote_v_to_rel" : [ SenseInfo('02554922-v', 31), SenseInfo('02397637-v', 5), SenseInfo('00976653-v', 2), SenseInfo('01080523-v', 0), SenseInfo('01080235-v', 0), SenseInfo('02554922-v', 31), SenseInfo('02397637-v', 5), SenseInfo('00976653-v', 2), SenseInfo('01080523-v', 0), SenseInfo('01080235-v', 0), SenseInfo('02554922-v', 31), SenseInfo('02397637-v', 5), SenseInfo('00976653-v', 2), SenseInfo('01080523-v', 0), SenseInfo('01080235-v', 0), SenseInfo('02554922-v', 31), SenseInfo('02397637-v', 5), SenseInfo('00976653-v', 2), SenseInfo('01080523-v', 0), SenseInfo('01080235-v', 0) ],
"_clog_v_up_rel" : [ SenseInfo('01478603-v', 4), SenseInfo('01709931-v', 0), SenseInfo('01301230-v', 0), SenseInfo('00441007-v', 0), SenseInfo('00368367-v', 0), SenseInfo('00182037-v', 0), SenseInfo('01478603-v', 4), SenseInfo('01709931-v', 0), SenseInfo('01301230-v', 0), SenseInfo('00441007-v', 0), SenseInfo('00368367-v', 0), SenseInfo('00182037-v', 0) ],
"_lofty_a_1_rel" : [ SenseInfo('01588619-a', 1), SenseInfo('01205473-a', 1), SenseInfo('01285136-a', 0), SenseInfo('01588619-a', 1), SenseInfo('01205473-a', 1), SenseInfo('01285136-a', 0), SenseInfo('01588619-a', 1), SenseInfo('01205473-a', 1), SenseInfo('01285136-a', 0) ],
"_pail_n_1_rel" : [ SenseInfo('02909870-n', 5), SenseInfo('13768537-n', 0) ],
"_deportment_n_1_rel" : [ SenseInfo('04897762-n', 0) ],
"_borrowings_n_1_rel" : [ SenseInfo('00084371-n', 1), SenseInfo('01111133-n', 0), SenseInfo('00084371-n', 1), SenseInfo('01111133-n', 0) ],
"_advance_n_of_rel" : [ SenseInfo('07445265-n', 7), SenseInfo('07357388-n', 6), SenseInfo('07164349-n', 1), SenseInfo('00282050-n', 1), SenseInfo('13375891-n', 0), SenseInfo('00364260-n', 0) ],
"_adherent_a_1_rel" : [ SenseInfo('00053032-a', 0) ],
"_pay_v_over_rel" : [ SenseInfo('02251743-v', 138), SenseInfo('01060494-v', 26), SenseInfo('02252931-v', 12), SenseInfo('02291708-v', 6), SenseInfo('02253456-v', 6), SenseInfo('00732224-v', 4), SenseInfo('02732292-v', 3), SenseInfo('02488056-v', 1), SenseInfo('00737884-v', 1), SenseInfo('02344243-v', 0), SenseInfo('02253154-v', 0) ],
"_powerplant_n_1_rel" : [  ],
"_atlas_n_1_rel" : [ SenseInfo('09575548-n', 0), SenseInfo('06427086-n', 0), SenseInfo('05588746-n', 0), SenseInfo('02752810-n', 0) ],
"_forging_n_1_rel" : [ SenseInfo('00925622-n', 0), SenseInfo('00925622-n', 0) ],
"_principal_n_1_rel" : [ SenseInfo('13400662-n', 12), SenseInfo('10474645-n', 2), SenseInfo('10648696-n', 1), SenseInfo('13355868-n', 0), SenseInfo('10474950-n', 0), SenseInfo('10474446-n', 0) ],
"_impossible_a_for_rel" : [ SenseInfo('01823092-a', 34), SenseInfo('02418692-a', 12), SenseInfo('02436025-a', 0), SenseInfo('01823092-a', 34), SenseInfo('02418692-a', 12), SenseInfo('02436025-a', 0), SenseInfo('01823092-a', 34), SenseInfo('02418692-a', 12), SenseInfo('02436025-a', 0), SenseInfo('01823092-a', 34), SenseInfo('02418692-a', 12), SenseInfo('02436025-a', 0) ],
"_bisque_a_1_rel" : [ SenseInfo('07584332-n', 0) ],
"_undergraduate_n_1_rel" : [ SenseInfo('10736602-n', 1) ],
"_amiable_a_1_rel" : [ SenseInfo('01134232-a', 1), SenseInfo('01075178-a', 1), SenseInfo('01134232-a', 1), SenseInfo('01075178-a', 1) ],
"_row_n_of_rel" : [ SenseInfo('08431437-n', 23), SenseInfo('07184149-n', 3), SenseInfo('09417365-n', 1), SenseInfo('03120029-n', 1), SenseInfo('08433447-n', 0), SenseInfo('05045680-n', 0), SenseInfo('00445351-n', 0), SenseInfo('08431437-n', 23), SenseInfo('07184149-n', 3), SenseInfo('09417365-n', 1), SenseInfo('03120029-n', 1), SenseInfo('08433447-n', 0), SenseInfo('05045680-n', 0), SenseInfo('00445351-n', 0) ],
"_tourist+lodge_n_1_rel" : [  ],
"_bunt_n_1_rel" : [ SenseInfo('00128477-n', 1), SenseInfo('14284026-n', 0), SenseInfo('13068434-n', 0), SenseInfo('13068255-n', 0) ],
"_fig_n_1_rel" : [ SenseInfo('06999647-n', 45), SenseInfo('12401684-n', 0), SenseInfo('08032594-n', 0), SenseInfo('07753113-n', 0) ],
"_footstep_n_1_rel" : [ SenseInfo('07383823-n', 4), SenseInfo('00288880-n', 4), SenseInfo('13757249-n', 3) ],
"_jap_n_1_rel" : [ SenseInfo('09718652-n', 5) ],
"_darling_a_1_rel" : [ SenseInfo('01462324-a', 1) ],
"_torsional_a_1_rel" : [  ],
"_ringer_n_1_rel" : [ SenseInfo('10714851-n', 0), SenseInfo('10531557-n', 0), SenseInfo('10531445-n', 0), SenseInfo('00106726-n', 0) ],
"_start_v_1_rel" : [ SenseInfo('00345761-v', 159), SenseInfo('00348746-v', 45), SenseInfo('02014165-v', 29), SenseInfo('02608347-v', 17), SenseInfo('01628449-v', 16), SenseInfo('01650610-v', 11), SenseInfo('01910373-v', 7), SenseInfo('01857717-v', 7), SenseInfo('01864230-v', 5), SenseInfo('02379528-v', 2), SenseInfo('01075164-v', 1), SenseInfo('02608823-v', 0), SenseInfo('02600948-v', 0), SenseInfo('02081946-v', 0), SenseInfo('00345761-v', 159), SenseInfo('00348746-v', 45), SenseInfo('02014165-v', 29), SenseInfo('02608347-v', 17), SenseInfo('01628449-v', 16), SenseInfo('01650610-v', 11), SenseInfo('01910373-v', 7), SenseInfo('01857717-v', 7), SenseInfo('01864230-v', 5), SenseInfo('02379528-v', 2), SenseInfo('01075164-v', 1), SenseInfo('02608823-v', 0), SenseInfo('02600948-v', 0), SenseInfo('02081946-v', 0), SenseInfo('00345761-v', 159), SenseInfo('00348746-v', 45), SenseInfo('02014165-v', 29), SenseInfo('02608347-v', 17), SenseInfo('01628449-v', 16), SenseInfo('01650610-v', 11), SenseInfo('01910373-v', 7), SenseInfo('01857717-v', 7), SenseInfo('01864230-v', 5), SenseInfo('02379528-v', 2), SenseInfo('01075164-v', 1), SenseInfo('02608823-v', 0), SenseInfo('02600948-v', 0), SenseInfo('02081946-v', 0), SenseInfo('00345761-v', 159), SenseInfo('00348746-v', 45), SenseInfo('02014165-v', 29), SenseInfo('02608347-v', 17), SenseInfo('01628449-v', 16), SenseInfo('01650610-v', 11), SenseInfo('01910373-v', 7), SenseInfo('01857717-v', 7), SenseInfo('01864230-v', 5), SenseInfo('02379528-v', 2), SenseInfo('01075164-v', 1), SenseInfo('02608823-v', 0), SenseInfo('02600948-v', 0), SenseInfo('02081946-v', 0) ],
"_tantrum_n_1_rel" : [ SenseInfo('14406303-n', 1) ],
"_theorist_n_1_rel" : [ SenseInfo('10706812-n', 1) ],
"_moleskin_n_1_rel" : [ SenseInfo('03780799-n', 0) ],
"_high+power_a_1_rel" : [ SenseInfo('00809343-a', 0) ],
"_tubing_n_1_rel" : [ SenseInfo('04493505-n', 4) ],
"_concussion_n_1_rel" : [ SenseInfo('07411490-n', 1), SenseInfo('07409930-n', 1) ],
"_pump_n_1_rel" : [ SenseInfo('04021798-n', 4), SenseInfo('05388805-n', 0), SenseInfo('04022332-n', 0) ],
"_dashpnct_p_rel" : [  ],
"_millisigma_n_1_rel" : [  ],
"_one_n_1_rel" : [ SenseInfo('13742573-n', 44), SenseInfo('05870055-n', 26) ],
"_intelligent_a_1_rel" : [ SenseInfo('01334398-a', 4), SenseInfo('02271052-a', 4), SenseInfo('01944088-a', 3), SenseInfo('01926089-a', 1), SenseInfo('01334398-a', 4), SenseInfo('02271052-a', 4), SenseInfo('01944088-a', 3), SenseInfo('01926089-a', 1) ],
"_son_n_of_rel" : [ SenseInfo('10624074-n', 48), SenseInfo('09537144-n', 2) ],
"_deception_n_1_rel" : [ SenseInfo('06758225-n', 0), SenseInfo('00752431-n', 0), SenseInfo('00099951-n', 0) ],
"_regime_n_1_rel" : [ SenseInfo('08050678-n', 2), SenseInfo('05909585-n', 1) ],
"_build_v_in_rel" : [ SenseInfo('01654628-v', 123), SenseInfo('00252990-v', 11), SenseInfo('01655505-v', 4), SenseInfo('00447158-v', 1), SenseInfo('02443424-v', 0), SenseInfo('01739099-v', 0), SenseInfo('01685601-v', 0), SenseInfo('00637115-v', 0), SenseInfo('00253277-v', 0), SenseInfo('00226882-v', 0) ],
"_ape_v_1_rel" : [ SenseInfo('02675067-v', 0), SenseInfo('00849592-v', 0) ],
"_stark_a_1_rel" : [ SenseInfo('00556881-a', 1), SenseInfo('01792387-a', 0), SenseInfo('01535583-a', 0), SenseInfo('01520091-a', 0), SenseInfo('01242750-a', 0), SenseInfo('00556881-a', 1), SenseInfo('01792387-a', 0), SenseInfo('01535583-a', 0), SenseInfo('01520091-a', 0), SenseInfo('01242750-a', 0), SenseInfo('00556881-a', 1), SenseInfo('01792387-a', 0), SenseInfo('01535583-a', 0), SenseInfo('01520091-a', 0), SenseInfo('01242750-a', 0), SenseInfo('00556881-a', 1), SenseInfo('01792387-a', 0), SenseInfo('01535583-a', 0), SenseInfo('01520091-a', 0), SenseInfo('01242750-a', 0) ],
"_execute_v_1_rel" : [ SenseInfo('02483267-v', 2), SenseInfo('02484208-v', 1), SenseInfo('01640855-v', 1), SenseInfo('02563860-v', 0), SenseInfo('02563327-v', 0), SenseInfo('01712704-v', 0), SenseInfo('00997659-v', 0) ],
"_denizen_n_1_rel" : [ SenseInfo('09620078-n', 0), SenseInfo('01315062-n', 0) ],
"_material_n_1_rel" : [ SenseInfo('14580897-n', 73), SenseInfo('06635509-n', 34), SenseInfo('03309808-n', 7), SenseInfo('03729951-n', 5), SenseInfo('10300654-n', 0), SenseInfo('14580897-n', 73), SenseInfo('06635509-n', 34), SenseInfo('03309808-n', 7), SenseInfo('03729951-n', 5), SenseInfo('10300654-n', 0), SenseInfo('14580897-n', 73), SenseInfo('06635509-n', 34), SenseInfo('03309808-n', 7), SenseInfo('03729951-n', 5), SenseInfo('10300654-n', 0) ],
"_taiwanese_a_1_rel" : [ SenseInfo('03122400-a', 0) ],
"_benedict_n_1_rel" : [ SenseInfo('10844401-n', 0), SenseInfo('10843858-n', 0), SenseInfo('09849990-n', 0) ],
"_envisage_v_1_rel" : [ SenseInfo('01636397-v', 2), SenseInfo('01636397-v', 2), SenseInfo('01636397-v', 2), SenseInfo('01636397-v', 2) ],
"_mammoth_n_1_rel" : [ SenseInfo('02504770-n', 0) ],
"_cater_v_to_rel" : [ SenseInfo('01182709-v', 4), SenseInfo('01180844-v', 0) ],
"_badminton_n_1_rel" : [ SenseInfo('00480508-n', 0) ],
"_clock_n_1_rel" : [ SenseInfo('03046257-n', 15) ],
"_stream_v_1_rel" : [ SenseInfo('02070679-v', 4), SenseInfo('00069012-v', 3), SenseInfo('02028366-v', 2), SenseInfo('02758033-v', 0), SenseInfo('02070466-v', 0) ],
"_entertain_v_1_rel" : [ SenseInfo('02492198-v', 24), SenseInfo('00711715-v', 1), SenseInfo('01773130-v', 0), SenseInfo('02492198-v', 24), SenseInfo('00711715-v', 1), SenseInfo('01773130-v', 0), SenseInfo('02492198-v', 24), SenseInfo('00711715-v', 1), SenseInfo('01773130-v', 0) ],
"_kneecap_v_1_rel" : [ SenseInfo('01137415-v', 0) ],
"_pulley_n_1_rel" : [ SenseInfo('04020298-n', 3) ],
"_unfrozen_a_1_rel" : [ SenseInfo('01079683-a', 2), SenseInfo('01079683-a', 2) ],
"_slick_a_1_rel" : [ SenseInfo('02235520-a', 0), SenseInfo('01799781-a', 0), SenseInfo('00282675-a', 0), SenseInfo('00148078-a', 0), SenseInfo('02235520-a', 0), SenseInfo('01799781-a', 0), SenseInfo('00282675-a', 0), SenseInfo('00148078-a', 0), SenseInfo('02235520-a', 0), SenseInfo('01799781-a', 0), SenseInfo('00282675-a', 0), SenseInfo('00148078-a', 0) ],
"_attack_n_1_rel" : [ SenseInfo('00972621-n', 17), SenseInfo('00457723-n', 3), SenseInfo('06711159-n', 2), SenseInfo('00941140-n', 1), SenseInfo('00773814-n', 1), SenseInfo('00236953-n', 1), SenseInfo('14081375-n', 0), SenseInfo('13435548-n', 0), SenseInfo('01220619-n', 0) ],
"_back+to+front_p_rel" : [  ],
"_velvet_n_1_rel" : [ SenseInfo('04525038-n', 2) ],
"_perspiration_n_1_rel" : [ SenseInfo('05405751-n', 5), SenseInfo('13535261-n', 0) ],
"_pass_v_1_rel" : [ SenseInfo('02050132-v', 32), SenseInfo('02051694-v', 31), SenseInfo('02466670-v', 29), SenseInfo('02072849-v', 17), SenseInfo('02230772-v', 13), SenseInfo('02685951-v', 8), SenseInfo('02049696-v', 8), SenseInfo('00339934-v', 7), SenseInfo('02523351-v', 4), SenseInfo('02708420-v', 3), SenseInfo('01212230-v', 3), SenseInfo('00742320-v', 3), SenseInfo('00421691-v', 3), SenseInfo('02525044-v', 2), SenseInfo('02669081-v', 1), SenseInfo('02523953-v', 1), SenseInfo('02423513-v', 1), SenseInfo('02221635-v', 1), SenseInfo('01972131-v', 1), SenseInfo('02231473-v', 0), SenseInfo('02229550-v', 0), SenseInfo('02052476-v', 0), SenseInfo('00803325-v', 0), SenseInfo('00358431-v', 0), SenseInfo('00072989-v', 0), SenseInfo('02050132-v', 32), SenseInfo('02051694-v', 31), SenseInfo('02466670-v', 29), SenseInfo('02072849-v', 17), SenseInfo('02230772-v', 13), SenseInfo('02685951-v', 8), SenseInfo('02049696-v', 8), SenseInfo('00339934-v', 7), SenseInfo('02523351-v', 4), SenseInfo('02708420-v', 3), SenseInfo('01212230-v', 3), SenseInfo('00742320-v', 3), SenseInfo('00421691-v', 3), SenseInfo('02525044-v', 2), SenseInfo('02669081-v', 1), SenseInfo('02523953-v', 1), SenseInfo('02423513-v', 1), SenseInfo('02221635-v', 1), SenseInfo('01972131-v', 1), SenseInfo('02231473-v', 0), SenseInfo('02229550-v', 0), SenseInfo('02052476-v', 0), SenseInfo('00803325-v', 0), SenseInfo('00358431-v', 0), SenseInfo('00072989-v', 0), SenseInfo('02050132-v', 32), SenseInfo('02051694-v', 31), SenseInfo('02466670-v', 29), SenseInfo('02072849-v', 17), SenseInfo('02230772-v', 13), SenseInfo('02685951-v', 8), SenseInfo('02049696-v', 8), SenseInfo('00339934-v', 7), SenseInfo('02523351-v', 4), SenseInfo('02708420-v', 3), SenseInfo('01212230-v', 3), SenseInfo('00742320-v', 3), SenseInfo('00421691-v', 3), SenseInfo('02525044-v', 2), SenseInfo('02669081-v', 1), SenseInfo('02523953-v', 1), SenseInfo('02423513-v', 1), SenseInfo('02221635-v', 1), SenseInfo('01972131-v', 1), SenseInfo('02231473-v', 0), SenseInfo('02229550-v', 0), SenseInfo('02052476-v', 0), SenseInfo('00803325-v', 0), SenseInfo('00358431-v', 0), SenseInfo('00072989-v', 0) ],
"_zombie_n_1_rel" : [ SenseInfo('10805638-n', 1), SenseInfo('10805932-n', 0), SenseInfo('10805783-n', 0), SenseInfo('09825519-n', 0), SenseInfo('07919165-n', 0) ],
"_gravitate_v_toward_rel" : [ SenseInfo('02732148-v', 0), SenseInfo('02731996-v', 0), SenseInfo('01835280-v', 0) ],
"_vitally_x_deg_rel" : [ SenseInfo('00090551-r', 5) ],
"_saami_n_1_rel" : [ SenseInfo('09720033-n', 0), SenseInfo('06959427-n', 0) ],
"_Tri-State_a_1_rel" : [  ],
"_repair_v_to_rel" : [ SenseInfo('00260648-v', 11), SenseInfo('02250625-v', 0), SenseInfo('01843497-v', 0), SenseInfo('00199912-v', 0), SenseInfo('00024279-v', 0) ],
"_asunder_a_1_rel" : [ SenseInfo('02110317-a', 0) ],
"_tote_v_1_rel" : [ SenseInfo('01454246-v', 0) ],
"_vestige_n_1_rel" : [ SenseInfo('06646628-n', 1) ],
"_uneducated_n_1_rel" : [ SenseInfo('00830717-a', 0) ],
"_unbroken_a_1_rel" : [ SenseInfo('00290923-a', 3), SenseInfo('02389719-a', 1), SenseInfo('01833226-a', 0), SenseInfo('00289799-a', 0), SenseInfo('00289365-a', 0), SenseInfo('00290923-a', 3), SenseInfo('02389719-a', 1), SenseInfo('01833226-a', 0), SenseInfo('00289799-a', 0), SenseInfo('00289365-a', 0) ],
"_start_v_off_rel" : [ SenseInfo('00345761-v', 159), SenseInfo('00348746-v', 45), SenseInfo('02014165-v', 29), SenseInfo('02608347-v', 17), SenseInfo('01628449-v', 16), SenseInfo('01650610-v', 11), SenseInfo('01910373-v', 7), SenseInfo('01857717-v', 7), SenseInfo('01864230-v', 5), SenseInfo('02379528-v', 2), SenseInfo('01075164-v', 1), SenseInfo('02608823-v', 0), SenseInfo('02600948-v', 0), SenseInfo('02081946-v', 0), SenseInfo('00345761-v', 159), SenseInfo('00348746-v', 45), SenseInfo('02014165-v', 29), SenseInfo('02608347-v', 17), SenseInfo('01628449-v', 16), SenseInfo('01650610-v', 11), SenseInfo('01910373-v', 7), SenseInfo('01857717-v', 7), SenseInfo('01864230-v', 5), SenseInfo('02379528-v', 2), SenseInfo('01075164-v', 1), SenseInfo('02608823-v', 0), SenseInfo('02600948-v', 0), SenseInfo('02081946-v', 0) ],
"_alleviate_v_1_rel" : [ SenseInfo('00064095-v', 2), SenseInfo('00518395-v', 1) ],
"_precedence_n_1_rel" : [ SenseInfo('13949802-n', 2), SenseInfo('05047279-n', 0), SenseInfo('01257145-n', 0) ],
"_midday_n_1_rel" : [ SenseInfo('15165490-n', 1) ],
"_doorknob_n_1_rel" : [ SenseInfo('03222959-n', 1) ],
"_auscultation_n_1_rel" : [ SenseInfo('00876542-n', 0) ],
"_commission_n_of_rel" : [ SenseInfo('08324514-n', 27), SenseInfo('13320860-n', 1), SenseInfo('01140471-n', 1), SenseInfo('14009274-n', 0), SenseInfo('08402442-n', 0), SenseInfo('07169480-n', 0), SenseInfo('06478988-n', 0), SenseInfo('00773235-n', 0), SenseInfo('00731222-n', 0) ],
"_sonorous_a_1_rel" : [ SenseInfo('01457692-a', 1), SenseInfo('01457692-a', 1) ],
"_swedish_a_1_rel" : [ SenseInfo('02959720-a', 6) ],
"_compact_v_cause_rel" : [ SenseInfo('01484027-v', 0), SenseInfo('01483779-v', 0), SenseInfo('01389329-v', 0), SenseInfo('01387786-v', 0) ],
"_chromatograph_n_1_rel" : [  ],
"_communist_a_1_rel" : [ SenseInfo('02874876-a', 18) ],
"_brain_n_1_rel" : [ SenseInfo('05481095-n', 22), SenseInfo('05618056-n', 5), SenseInfo('05611302-n', 5), SenseInfo('10126926-n', 3), SenseInfo('07652585-n', 0) ],
"_soggy_a_1_rel" : [ SenseInfo('02548066-a', 0), SenseInfo('01185417-a', 0), SenseInfo('00034322-a', 0), SenseInfo('02548066-a', 0), SenseInfo('01185417-a', 0), SenseInfo('00034322-a', 0), SenseInfo('02548066-a', 0), SenseInfo('01185417-a', 0), SenseInfo('00034322-a', 0) ],
"_bb_n_1_rel" : [ SenseInfo('02813874-n', 0) ],
"_reverential_a_1_rel" : [ SenseInfo('02012333-a', 0) ],
"_complication_n_1_rel" : [ SenseInfo('01076359-n', 3), SenseInfo('13933221-n', 2), SenseInfo('14074041-n', 0), SenseInfo('07423899-n', 0), SenseInfo('04766620-n', 0) ],
"_evergreen_n_1_rel" : [ SenseInfo('13099833-n', 0) ],
"_manor_n_1_rel" : [ SenseInfo('03718458-n', 1), SenseInfo('13252168-n', 0) ],
"_shove_v_through_rel" : [ SenseInfo('01871680-v', 6), SenseInfo('01584701-v', 5), SenseInfo('02094569-v', 0) ],
"_contingent_a_1_rel" : [ SenseInfo('01822411-a', 0), SenseInfo('00555859-a', 0), SenseInfo('00341933-a', 0) ],
"_bake_v_1_rel" : [ SenseInfo('00319886-v', 6), SenseInfo('01663749-v', 1), SenseInfo('00544136-v', 1), SenseInfo('02755565-v', 0) ],
"_hikers_a_1_rel" : [  ],
"_crosscut_n_1_rel" : [ SenseInfo('08617311-n', 0), SenseInfo('04204953-n', 0) ],
"_beet_n_1_rel" : [ SenseInfo('11832214-n', 0), SenseInfo('07719839-n', 0) ],
"_counter-attack_n_1_rel" : [ SenseInfo('00978173-n', 1), SenseInfo('00458094-n', 0), SenseInfo('00978173-n', 1), SenseInfo('00458094-n', 0), SenseInfo('00978173-n', 1), SenseInfo('00458094-n', 0), SenseInfo('00978173-n', 1), SenseInfo('00458094-n', 0), SenseInfo('00978173-n', 1), SenseInfo('00458094-n', 0), SenseInfo('00978173-n', 1), SenseInfo('00458094-n', 0), SenseInfo('00978173-n', 1), SenseInfo('00458094-n', 0), SenseInfo('00978173-n', 1), SenseInfo('00458094-n', 0), SenseInfo('00978173-n', 1), SenseInfo('00458094-n', 0), SenseInfo('00978173-n', 1), SenseInfo('00458094-n', 0) ],
"_famous_a_for_rel" : [ SenseInfo('01375831-a', 21), SenseInfo('01375831-a', 21) ],
"_track+meet_n_1_rel" : [ SenseInfo('07468692-n', 1) ],
"_all+afternoon+long_a_1_rel" : [  ],
"_virus_n_1_rel" : [ SenseInfo('01328702-n', 4), SenseInfo('14007864-n', 0), SenseInfo('06585816-n', 0) ],
"_penny_n_1_rel" : [ SenseInfo('13694367-n', 2), SenseInfo('13390626-n', 1) ],
"_ear_n_1_rel" : [ SenseInfo('05320899-n', 36), SenseInfo('05657999-n', 7), SenseInfo('05323889-n', 6), SenseInfo('05703205-n', 1), SenseInfo('13133613-n', 0) ],
"_spout_v_1_rel" : [ SenseInfo('02068413-v', 1), SenseInfo('01051956-v', 1) ],
"_push_v_in_rel" : [ SenseInfo('01871979-v', 56), SenseInfo('00765977-v', 7), SenseInfo('00976653-v', 6), SenseInfo('02406916-v', 3), SenseInfo('01872645-v', 3), SenseInfo('02054864-v', 1), SenseInfo('02589576-v', 0), SenseInfo('02245555-v', 0), SenseInfo('01872877-v', 0), SenseInfo('01447632-v', 0) ],
"_manly_a_1_rel" : [ SenseInfo('01475831-a', 0), SenseInfo('01483677-a', 0), SenseInfo('01475831-a', 0), SenseInfo('01483677-a', 0), SenseInfo('01475831-a', 0), SenseInfo('01483677-a', 0) ],
"_discern_v_1_rel" : [ SenseInfo('02193194-v', 7), SenseInfo('02193194-v', 7), SenseInfo('02193194-v', 7), SenseInfo('02193194-v', 7), SenseInfo('02193194-v', 7) ],
"_patch_n_1_rel" : [ SenseInfo('04682462-n', 7), SenseInfo('08674739-n', 3), SenseInfo('03897943-n', 2), SenseInfo('15246353-n', 0), SenseInfo('06573223-n', 0), SenseInfo('04408871-n', 0), SenseInfo('03745285-n', 0), SenseInfo('03309356-n', 0), SenseInfo('02785648-n', 0) ],
"_roll-out_n_1_rel" : [  ],
"_tooth_n_1_rel" : [ SenseInfo('05282746-n', 38), SenseInfo('04452848-n', 2), SenseInfo('02155872-n', 1), SenseInfo('00179576-n', 1), SenseInfo('04453037-n', 0) ],
"_bustle_n_1_rel" : [ SenseInfo('00555138-n', 1), SenseInfo('02926591-n', 0) ],
"_towline_n_1_rel" : [ SenseInfo('04461294-n', 0) ],
"_bead_n_1_rel" : [ SenseInfo('02815071-n', 1), SenseInfo('13901585-n', 0), SenseInfo('02815237-n', 0) ],
"_opposite_n_of_rel" : [ SenseInfo('06288024-n', 2), SenseInfo('13858604-n', 1), SenseInfo('10379620-n', 1), SenseInfo('13858833-n', 0), SenseInfo('06288024-n', 2), SenseInfo('13858604-n', 1), SenseInfo('10379620-n', 1), SenseInfo('13858833-n', 0) ],
"_hooray_v_1_rel" : [  ],
"_se_n_of_rel" : [ SenseInfo('14654175-n', 0), SenseInfo('13832841-n', 0) ],
"_swivel_v_cause_rel" : [ SenseInfo('02046572-v', 2) ],
"_village_n_of_rel" : [ SenseInfo('08226699-n', 29), SenseInfo('08672738-n', 6), SenseInfo('09122968-n', 1), SenseInfo('08226699-n', 29), SenseInfo('08672738-n', 6), SenseInfo('09122968-n', 1) ],
"_porridge_n_1_rel" : [ SenseInfo('07874780-n', 0) ],
"_escutcheon_n_1_rel" : [ SenseInfo('03342262-n', 0), SenseInfo('03296597-n', 0), SenseInfo('03296478-n', 0) ],
"_transverse_n_1_rel" : [ SenseInfo('01445917-a', 4) ],
"_current_n_1_rel" : [ SenseInfo('11443532-n', 11), SenseInfo('07406765-n', 6), SenseInfo('08461595-n', 1) ],
"_of_p_sel_rel" : [  ],
"_dribble_v_1_rel" : [ SenseInfo('02070874-v', 2), SenseInfo('01611516-v', 0), SenseInfo('01408760-v', 0), SenseInfo('00102974-v', 0) ],
"_uncritical_a_1_rel" : [ SenseInfo('00650351-a', 1), SenseInfo('00648816-a', 0), SenseInfo('00650351-a', 1), SenseInfo('00648816-a', 0) ],
"_sophomore_n_1_rel" : [ SenseInfo('10625438-n', 4) ],
"_flask_n_1_rel" : [ SenseInfo('03359566-n', 4), SenseInfo('13767146-n', 0) ],
"_fulfil_v_1_rel" : [ SenseInfo('01640855-v', 3), SenseInfo('01183573-v', 1), SenseInfo('02671880-v', 0) ],
"_standard-bearer_n_1_rel" : [ SenseInfo('10647475-n', 0), SenseInfo('09938272-n', 0), SenseInfo('10647475-n', 0), SenseInfo('09938272-n', 0) ],
"_cave_v_in_rel" : [ SenseInfo('01283033-v', 0), SenseInfo('00649887-v', 0), SenseInfo('01283033-v', 0), SenseInfo('00649887-v', 0) ],
"_shock_v_1_rel" : [ SenseInfo('01809064-v', 4), SenseInfo('01810447-v', 3), SenseInfo('01783022-v', 0), SenseInfo('01561713-v', 0), SenseInfo('01386308-v', 0), SenseInfo('00090386-v', 0), SenseInfo('00090186-v', 0), SenseInfo('01809064-v', 4), SenseInfo('01810447-v', 3), SenseInfo('01783022-v', 0), SenseInfo('01561713-v', 0), SenseInfo('01386308-v', 0), SenseInfo('00090386-v', 0), SenseInfo('00090186-v', 0), SenseInfo('01809064-v', 4), SenseInfo('01810447-v', 3), SenseInfo('01783022-v', 0), SenseInfo('01561713-v', 0), SenseInfo('01386308-v', 0), SenseInfo('00090386-v', 0), SenseInfo('00090186-v', 0), SenseInfo('01809064-v', 4), SenseInfo('01810447-v', 3), SenseInfo('01783022-v', 0), SenseInfo('01561713-v', 0), SenseInfo('01386308-v', 0), SenseInfo('00090386-v', 0), SenseInfo('00090186-v', 0), SenseInfo('01809064-v', 4), SenseInfo('01810447-v', 3), SenseInfo('01783022-v', 0), SenseInfo('01561713-v', 0), SenseInfo('01386308-v', 0), SenseInfo('00090386-v', 0), SenseInfo('00090186-v', 0) ],
"_pic_n_1_rel" : [ SenseInfo('06613686-n', 0), SenseInfo('03925226-n', 0) ],
"_contingency_n_1_rel" : [ SenseInfo('07290761-n', 1), SenseInfo('14001973-n', 0) ],
"_matriarchal_a_1_rel" : [ SenseInfo('01738335-a', 0) ],
"_avail_n_1_rel" : [ SenseInfo('05149832-n', 2) ],
"_dramatist_n_1_rel" : [ SenseInfo('10030277-n', 2) ],
"_recount_n_1_rel" : [ SenseInfo('00653958-n', 0) ],
"_boring_a_1_rel" : [ SenseInfo('01345307-a', 2) ],
"_kosher_a_1_rel" : [ SenseInfo('00427644-a', 1), SenseInfo('01880071-a', 0) ],
"_baker_n_1_rel" : [ SenseInfo('09833651-n', 0), SenseInfo('09833536-n', 0) ],
"_acme_n_1_rel" : [ SenseInfo('13940456-n', 0), SenseInfo('08677801-n', 0) ],
"_crossing_n_1_rel" : [ SenseInfo('00297532-n', 1), SenseInfo('09283623-n', 0), SenseInfo('08547938-n', 0), SenseInfo('03581125-n', 0), SenseInfo('03137228-n', 0), SenseInfo('00850425-n', 0), SenseInfo('00313245-n', 0) ],
"_on+time_a_1_rel" : [  ],
"_restorative_a_1_rel" : [ SenseInfo('01357742-a', 0), SenseInfo('01167540-a', 0) ],
"_gun_v_cause_rel" : [ SenseInfo('01136614-v', 0) ],
"_stinky_a_1_rel" : [ SenseInfo('01053144-a', 0), SenseInfo('01127782-a', 0) ],
"_only_x_deg_rel" : [ SenseInfo('00004722-r', 258), SenseInfo('00008600-r', 226), SenseInfo('00010759-r', 13), SenseInfo('00010914-r', 6), SenseInfo('00028319-r', 4), SenseInfo('00505114-r', 2), SenseInfo('00011011-r', 0), SenseInfo('02214736-a', 0), SenseInfo('01862697-a', 0) ],
"_unaffected_a_1_rel" : [ SenseInfo('00071992-a', 1), SenseInfo('02107827-a', 1), SenseInfo('01560320-a', 0), SenseInfo('00074346-a', 0), SenseInfo('00071992-a', 1), SenseInfo('02107827-a', 1), SenseInfo('01560320-a', 0), SenseInfo('00074346-a', 0) ],
"_recall_n_of_rel" : [ SenseInfo('07280072-n', 0), SenseInfo('07190840-n', 0), SenseInfo('06804388-n', 0), SenseInfo('05761559-n', 0), SenseInfo('01258719-n', 0) ],
"_pouch_n_1_rel" : [ SenseInfo('03993180-n', 1), SenseInfo('13914473-n', 0), SenseInfo('05516848-n', 0) ],
"_disgust_v_1_rel" : [ SenseInfo('02194913-v', 1), SenseInfo('01808374-v', 0), SenseInfo('02194913-v', 1), SenseInfo('01808374-v', 0), SenseInfo('02194913-v', 1), SenseInfo('01808374-v', 0), SenseInfo('02194913-v', 1), SenseInfo('01808374-v', 0), SenseInfo('02194913-v', 1), SenseInfo('01808374-v', 0) ],
"_incapacitate_v_1_rel" : [ SenseInfo('00512186-v', 1), SenseInfo('00091968-v', 0) ],
"_swede_n_1_rel" : [ SenseInfo('09732441-n', 1), SenseInfo('11877860-n', 0), SenseInfo('07736087-n', 0) ],
"_bail_n_1_rel" : [ SenseInfo('13350976-n', 0), SenseInfo('05903445-n', 0) ],
"_crease_v_cause_rel" : [ SenseInfo('01278427-v', 1), SenseInfo('01277784-v', 0), SenseInfo('01240514-v', 0), SenseInfo('00564857-v', 0) ],
"_astounding_a_1_rel" : [ SenseInfo('00645856-a', 1), SenseInfo('01283155-a', 0) ],
"_break_v_through_rel" : [ SenseInfo('00364064-v', 15), SenseInfo('00334186-v', 13), SenseInfo('00258665-v', 9), SenseInfo('01369758-v', 8), SenseInfo('00334996-v', 8), SenseInfo('02566528-v', 5), SenseInfo('02073233-v', 4), SenseInfo('02029369-v', 4), SenseInfo('01785395-v', 4), SenseInfo('00362348-v', 4), SenseInfo('02570684-v', 3), SenseInfo('00202569-v', 3), SenseInfo('02668523-v', 2), SenseInfo('01106864-v', 2), SenseInfo('00933821-v', 2), SenseInfo('00558536-v', 2), SenseInfo('00434374-v', 2), SenseInfo('02535716-v', 1), SenseInfo('02030764-v', 1), SenseInfo('01972976-v', 1), SenseInfo('00390215-v', 1), SenseInfo('00202784-v', 1), SenseInfo('02746617-v', 0), SenseInfo('02746449-v', 0), SenseInfo('02681639-v', 0), SenseInfo('02681524-v', 0), SenseInfo('02625187-v', 0), SenseInfo('02600082-v', 0), SenseInfo('02559395-v', 0), SenseInfo('02478469-v', 0), SenseInfo('02431320-v', 0), SenseInfo('02399331-v', 0), SenseInfo('02318165-v', 0), SenseInfo('02101373-v', 0), SenseInfo('01991347-v', 0), SenseInfo('01989053-v', 0), SenseInfo('01896484-v', 0), SenseInfo('01610666-v', 0), SenseInfo('01610463-v', 0), SenseInfo('01597995-v', 0), SenseInfo('01557646-v', 0), SenseInfo('01369346-v', 0), SenseInfo('01298931-v', 0), SenseInfo('01228524-v', 0), SenseInfo('01228396-v', 0), SenseInfo('00935987-v', 0), SenseInfo('00779061-v', 0), SenseInfo('00778745-v', 0), SenseInfo('00744439-v', 0), SenseInfo('00738440-v', 0), SenseInfo('00738314-v', 0), SenseInfo('00551412-v', 0), SenseInfo('00339464-v', 0), SenseInfo('00336260-v', 0), SenseInfo('00258366-v', 0), SenseInfo('00155046-v', 0), SenseInfo('00107739-v', 0), SenseInfo('00107604-v', 0), SenseInfo('00030463-v', 0) ],
"_feedforward_a_1_rel" : [  ],
"_open_a_to_rel" : [ SenseInfo('01652380-a', 34), SenseInfo('01652902-a', 17), SenseInfo('01886620-a', 13), SenseInfo('01861910-a', 7), SenseInfo('01654377-a', 4), SenseInfo('00185509-a', 4), SenseInfo('02003357-a', 3), SenseInfo('02523664-a', 2), SenseInfo('02232112-a', 2), SenseInfo('01659117-a', 2), SenseInfo('01659999-a', 1), SenseInfo('02130821-a', 1), SenseInfo('02087178-a', 1), SenseInfo('01449354-a', 1), SenseInfo('01985247-a', 0), SenseInfo('01704761-a', 0), SenseInfo('02474876-a', 0), SenseInfo('02361540-a', 0), SenseInfo('01622505-a', 0), SenseInfo('01310273-a', 0), SenseInfo('00036254-a', 0), SenseInfo('01652380-a', 34), SenseInfo('01652902-a', 17), SenseInfo('01886620-a', 13), SenseInfo('01861910-a', 7), SenseInfo('01654377-a', 4), SenseInfo('00185509-a', 4), SenseInfo('02003357-a', 3), SenseInfo('02523664-a', 2), SenseInfo('02232112-a', 2), SenseInfo('01659117-a', 2), SenseInfo('01659999-a', 1), SenseInfo('02130821-a', 1), SenseInfo('02087178-a', 1), SenseInfo('01449354-a', 1), SenseInfo('01985247-a', 0), SenseInfo('01704761-a', 0), SenseInfo('02474876-a', 0), SenseInfo('02361540-a', 0), SenseInfo('01622505-a', 0), SenseInfo('01310273-a', 0), SenseInfo('00036254-a', 0) ],
"_tier_n_1_rel" : [ SenseInfo('14428160-n', 0), SenseInfo('10710509-n', 0), SenseInfo('10710403-n', 0), SenseInfo('04434059-n', 0), SenseInfo('04433905-n', 0) ],
"_jerk_v_1_rel" : [ SenseInfo('01592072-v', 15), SenseInfo('01891817-v', 4), SenseInfo('00009631-v', 2), SenseInfo('01884383-v', 0), SenseInfo('01591158-v', 0) ],
"_eel_n_1_rel" : [ SenseInfo('07783967-n', 0), SenseInfo('02526121-n', 0) ],
"_wooly_a_1_rel" : [ SenseInfo('01154351-a', 0), SenseInfo('00436115-a', 0), SenseInfo('00216668-a', 0) ],
"_calm_a_1_rel" : [ SenseInfo('00529657-a', 11), SenseInfo('00302761-a', 0), SenseInfo('00529657-a', 11), SenseInfo('00302761-a', 0), SenseInfo('00529657-a', 11), SenseInfo('00302761-a', 0), SenseInfo('00529657-a', 11), SenseInfo('00302761-a', 0) ],
"_alone_p_rel" : [ SenseInfo('00008600-r', 32), SenseInfo('00157967-r', 28), SenseInfo('02249766-a', 26), SenseInfo('02251212-a', 4), SenseInfo('01862697-a', 1), SenseInfo('00505853-a', 0), SenseInfo('00008600-r', 32), SenseInfo('00157967-r', 28), SenseInfo('02249766-a', 26), SenseInfo('02251212-a', 4), SenseInfo('01862697-a', 1), SenseInfo('00505853-a', 0) ],
"_invaluable_a_1_rel" : [ SenseInfo('02501367-a', 1) ],
"_type_v_out_rel" : [ SenseInfo('01004692-v', 2), SenseInfo('00618682-v', 1) ],
"_verge_v_on_rel" : [ SenseInfo('02703790-v', 0), SenseInfo('02703790-v', 0) ],
"_proper_a_1_rel" : [ SenseInfo('01878466-a', 34), SenseInfo('01938322-a', 4), SenseInfo('01104889-a', 2), SenseInfo('00135455-a', 2), SenseInfo('01878466-a', 34), SenseInfo('01938322-a', 4), SenseInfo('01104889-a', 2), SenseInfo('00135455-a', 2), SenseInfo('01878466-a', 34), SenseInfo('01938322-a', 4), SenseInfo('01104889-a', 2), SenseInfo('00135455-a', 2), SenseInfo('01878466-a', 34), SenseInfo('01938322-a', 4), SenseInfo('01104889-a', 2), SenseInfo('00135455-a', 2), SenseInfo('01878466-a', 34), SenseInfo('01938322-a', 4), SenseInfo('01104889-a', 2), SenseInfo('00135455-a', 2) ],
"_halfway_a_1_rel" : [ SenseInfo('00330506-a', 4), SenseInfo('01014838-a', 1), SenseInfo('00517710-a', 0) ],
"_in+person_a_1_rel" : [ SenseInfo('01768466-a', 1) ],
"_folly_n_1_rel" : [ SenseInfo('04891333-n', 2), SenseInfo('01248075-n', 1), SenseInfo('05647156-n', 0), SenseInfo('00512843-n', 0) ],
"_firearm_n_1_rel" : [ SenseInfo('03343853-n', 6) ],
"_obvious_a_to_rel" : [ SenseInfo('01618053-a', 26), SenseInfo('01618053-a', 26), SenseInfo('01618053-a', 26), SenseInfo('01618053-a', 26), SenseInfo('01618053-a', 26) ],
"_epoch_n_1_rel" : [ SenseInfo('15248564-n', 5), SenseInfo('15296687-n', 0), SenseInfo('15248269-n', 0) ],
"_illegality_n_1_rel" : [ SenseInfo('04810327-n', 0) ],
"_carpool_v_1_rel" : [  ],
"_safeguard_v_1_rel" : [ SenseInfo('01138102-v', 2), SenseInfo('02026327-v', 0) ],
"_graph_v_1_rel" : [ SenseInfo('01755137-v', 1), SenseInfo('01755291-v', 0) ],
"_humanistic_a_1_rel" : [ SenseInfo('02743932-a', 1), SenseInfo('02743750-a', 0), SenseInfo('02743547-a', 0), SenseInfo('01262284-a', 0) ],
"_prowess_n_1_rel" : [ SenseInfo('05638987-n', 3) ],
"_nod_v_1_rel" : [ SenseInfo('00898434-v', 35), SenseInfo('00898210-v', 16), SenseInfo('00016702-v', 1), SenseInfo('01877785-v', 0), SenseInfo('00016573-v', 0), SenseInfo('00898434-v', 35), SenseInfo('00898210-v', 16), SenseInfo('00016702-v', 1), SenseInfo('01877785-v', 0), SenseInfo('00016573-v', 0) ],
"_trifling_a_1_rel" : [ SenseInfo('02502994-a', 0) ],
"_swarm_n_of_rel" : [ SenseInfo('08184217-n', 1), SenseInfo('07996149-n', 1) ],
"_hay_n_1_rel" : [ SenseInfo('07802026-n', 11) ],
"_cross+country_a_1_rel" : [  ],
"_ripple_n_1_rel" : [ SenseInfo('07344663-n', 4), SenseInfo('07345441-n', 1) ],
"_pooch_n_1_rel" : [ SenseInfo('02084732-n', 0) ],
"_scepticism_n_about_rel" : [ SenseInfo('05980051-n', 1) ],
"_tusk_n_1_rel" : [ SenseInfo('14757547-n', 0), SenseInfo('01465713-n', 0) ],
"_saddle_n_1_rel" : [ SenseInfo('04123740-n', 14), SenseInfo('09418810-n', 0), SenseInfo('07667636-n', 0), SenseInfo('04123980-n', 0), SenseInfo('02835915-n', 0), SenseInfo('01895219-n', 0) ],
"_bolt_v_1_rel" : [ SenseInfo('01966039-v', 2), SenseInfo('01348838-v', 2), SenseInfo('01202651-v', 1), SenseInfo('02073714-v', 0), SenseInfo('02011040-v', 0), SenseInfo('01173933-v', 0), SenseInfo('00436304-v', 0), SenseInfo('01966039-v', 2), SenseInfo('01348838-v', 2), SenseInfo('01202651-v', 1), SenseInfo('02073714-v', 0), SenseInfo('02011040-v', 0), SenseInfo('01173933-v', 0), SenseInfo('00436304-v', 0) ],
"_do_v_away-with_rel" : [ SenseInfo('02560585-v', 526), SenseInfo('01712704-v', 173), SenseInfo('02561995-v', 134), SenseInfo('02617567-v', 58), SenseInfo('01645601-v', 35), SenseInfo('02568672-v', 20), SenseInfo('02669789-v', 11), SenseInfo('01619014-v', 9), SenseInfo('00010435-v', 3), SenseInfo('02709107-v', 2), SenseInfo('02523221-v', 2), SenseInfo('00038849-v', 2), SenseInfo('01841772-v', 1) ],
"_krone_n_1_rel" : [ SenseInfo('13682971-n', 0), SenseInfo('13682740-n', 0), SenseInfo('13682971-n', 0), SenseInfo('13682740-n', 0), SenseInfo('13682971-n', 0), SenseInfo('13682740-n', 0), SenseInfo('13682971-n', 0), SenseInfo('13682740-n', 0), SenseInfo('13682971-n', 0), SenseInfo('13682740-n', 0), SenseInfo('13682971-n', 0), SenseInfo('13682740-n', 0), SenseInfo('13682971-n', 0), SenseInfo('13682740-n', 0), SenseInfo('13682971-n', 0), SenseInfo('13682740-n', 0), SenseInfo('13682971-n', 0), SenseInfo('13682740-n', 0), SenseInfo('13682971-n', 0), SenseInfo('13682740-n', 0) ],
"_assent_v_to_rel" : [ SenseInfo('00804139-v', 3) ],
"_harangue_n_1_rel" : [ SenseInfo('07242912-n', 1) ],
"_lcd_n_1_rel" : [ SenseInfo('03676759-n', 0) ],
"_swing_v_down_rel" : [ SenseInfo('02087745-v', 35), SenseInfo('01877355-v', 15), SenseInfo('01877620-v', 6), SenseInfo('02537238-v', 4), SenseInfo('01593763-v', 4), SenseInfo('02717472-v', 2), SenseInfo('01152040-v', 2), SenseInfo('00557216-v', 2), SenseInfo('02615140-v', 1), SenseInfo('02752277-v', 0), SenseInfo('02389815-v', 0), SenseInfo('01725375-v', 0), SenseInfo('01427483-v', 0) ],
"_narrow_v_1_rel" : [ SenseInfo('00305109-v', 2), SenseInfo('00715541-v', 1), SenseInfo('00437449-v', 1), SenseInfo('00304422-v', 1) ],
"_menu_n_1_rel" : [ SenseInfo('06492939-n', 1), SenseInfo('07565083-n', 0), SenseInfo('06493392-n', 0), SenseInfo('05911124-n', 0) ],
"_apropos_a_1_rel" : [ SenseInfo('00138169-a', 0) ],
"_sack_n_1_rel" : [ SenseInfo('04122825-n', 1), SenseInfo('13914473-n', 0), SenseInfo('13769206-n', 0), SenseInfo('07897975-n', 0), SenseInfo('04123026-n', 0), SenseInfo('03482252-n', 0), SenseInfo('03013438-n', 0), SenseInfo('00967446-n', 0), SenseInfo('00216174-n', 0) ],
"_complacent_a_1_rel" : [ SenseInfo('00589067-a', 0), SenseInfo('00589067-a', 0) ],
"_belittlement_n_1_rel" : [  ],
"_essence_n_1_rel" : [ SenseInfo('05921123-n', 2), SenseInfo('15110096-n', 0), SenseInfo('06604066-n', 0), SenseInfo('03916031-n', 0) ],
"_eastbound_a_1_rel" : [ SenseInfo('00823556-a', 0) ],
"_cloister_v_1_rel" : [ SenseInfo('02724126-v', 0), SenseInfo('01471434-v', 0), SenseInfo('00495636-v', 0) ],
"_embarrass_v_1_rel" : [ SenseInfo('01792097-v', 1), SenseInfo('02557199-v', 0), SenseInfo('01792097-v', 1), SenseInfo('02557199-v', 0), SenseInfo('01792097-v', 1), SenseInfo('02557199-v', 0), SenseInfo('01792097-v', 1), SenseInfo('02557199-v', 0) ],
"_participation_n_in_rel" : [ SenseInfo('01239064-n', 13), SenseInfo('13924659-n', 0) ],
"_mail_v_out_rel" : [ SenseInfo('01437888-v', 12), SenseInfo('01031256-v', 0) ],
"_immobilize_v_1_rel" : [ SenseInfo('02214864-v', 0), SenseInfo('01207149-v', 0), SenseInfo('01121508-v', 0), SenseInfo('00269889-v', 0), SenseInfo('00269423-v', 0), SenseInfo('00269140-v', 0), SenseInfo('02214864-v', 0), SenseInfo('01207149-v', 0), SenseInfo('01121508-v', 0), SenseInfo('00269889-v', 0), SenseInfo('00269423-v', 0), SenseInfo('00269140-v', 0) ],
"_endearing_a_for_rel" : [ SenseInfo('01459755-a', 1), SenseInfo('01459755-a', 1), SenseInfo('01459755-a', 1) ],
"_crumble_v_1_rel" : [ SenseInfo('02041877-v', 2), SenseInfo('00397405-v', 0), SenseInfo('00208836-v', 0) ],
"_communicate_v_to_rel" : [ SenseInfo('00742320-v', 9), SenseInfo('00740577-v', 8), SenseInfo('02231661-v', 0), SenseInfo('01355518-v', 0), SenseInfo('01070102-v', 0), SenseInfo('01030678-v', 0), SenseInfo('00760402-v', 0), SenseInfo('00742320-v', 9), SenseInfo('00740577-v', 8), SenseInfo('02231661-v', 0), SenseInfo('01355518-v', 0), SenseInfo('01070102-v', 0), SenseInfo('01030678-v', 0), SenseInfo('00760402-v', 0) ],
"_game_n_1_rel" : [ SenseInfo('00455599-n', 38), SenseInfo('00456199-n', 26), SenseInfo('00430606-n', 14), SenseInfo('02152991-n', 7), SenseInfo('15256567-n', 0), SenseInfo('13596235-n', 0), SenseInfo('07650449-n', 0), SenseInfo('05907682-n', 0), SenseInfo('03413828-n', 0), SenseInfo('00583089-n', 0), SenseInfo('00513089-n', 0), SenseInfo('00455599-n', 38), SenseInfo('00456199-n', 26), SenseInfo('00430606-n', 14), SenseInfo('02152991-n', 7), SenseInfo('15256567-n', 0), SenseInfo('13596235-n', 0), SenseInfo('07650449-n', 0), SenseInfo('05907682-n', 0), SenseInfo('03413828-n', 0), SenseInfo('00583089-n', 0), SenseInfo('00513089-n', 0) ],
"_mineral_n_1_rel" : [ SenseInfo('14662574-n', 9), SenseInfo('14662574-n', 9), SenseInfo('14662574-n', 9) ],
"_pale_a_1_rel" : [ SenseInfo('00408992-a', 12), SenseInfo('02325984-a', 9), SenseInfo('00408445-a', 6), SenseInfo('00405879-a', 3), SenseInfo('01458200-a', 0), SenseInfo('00408992-a', 12), SenseInfo('02325984-a', 9), SenseInfo('00408445-a', 6), SenseInfo('00405879-a', 3), SenseInfo('01458200-a', 0), SenseInfo('00408992-a', 12), SenseInfo('02325984-a', 9), SenseInfo('00408445-a', 6), SenseInfo('00405879-a', 3), SenseInfo('01458200-a', 0) ],
"_ad_x_rel" : [ SenseInfo('07248801-n', 6), SenseInfo('00001837-r', 0), SenseInfo('07248801-n', 6), SenseInfo('00001837-r', 0), SenseInfo('07248801-n', 6), SenseInfo('00001837-r', 0), SenseInfo('07248801-n', 6), SenseInfo('00001837-r', 0), SenseInfo('07248801-n', 6), SenseInfo('00001837-r', 0), SenseInfo('07248801-n', 6), SenseInfo('00001837-r', 0), SenseInfo('07248801-n', 6), SenseInfo('00001837-r', 0), SenseInfo('07248801-n', 6), SenseInfo('00001837-r', 0), SenseInfo('07248801-n', 6), SenseInfo('00001837-r', 0), SenseInfo('07248801-n', 6), SenseInfo('00001837-r', 0) ],
"_inept_a_1_rel" : [ SenseInfo('01001180-a', 1), SenseInfo('00511526-a', 1), SenseInfo('00063953-a', 0) ],
"_northcentral_a_1_rel" : [  ],
"_usual_a_1_rel" : [ SenseInfo('00489108-a', 29), SenseInfo('00970610-a', 2), SenseInfo('00489108-a', 29), SenseInfo('00970610-a', 2), SenseInfo('00489108-a', 29), SenseInfo('00970610-a', 2), SenseInfo('00489108-a', 29), SenseInfo('00970610-a', 2) ],
"_saucepan_n_1_rel" : [ SenseInfo('04138977-n', 0) ],
"_oregonian_a_1_rel" : [ SenseInfo('09745229-n', 0) ],
"_subsidize_v_1_rel" : [ SenseInfo('02216710-v', 6), SenseInfo('02217011-v', 0) ],
"_womankind_n_1_rel" : [ SenseInfo('08477912-n', 0) ],
"_overcurrent_n_1_rel" : [  ],
"_contamination_n_of_rel" : [ SenseInfo('14487731-n', 2), SenseInfo('14821984-n', 0), SenseInfo('00276987-n', 0) ],
"_extend_v_1_rel" : [ SenseInfo('00540235-v', 20), SenseInfo('02685951-v', 16), SenseInfo('02687916-v', 11), SenseInfo('02297948-v', 6), SenseInfo('00027705-v', 5), SenseInfo('02690093-v', 4), SenseInfo('02297742-v', 3), SenseInfo('00027268-v', 2), SenseInfo('00540946-v', 1), SenseInfo('00317888-v', 1), SenseInfo('02054989-v', 0), SenseInfo('01960296-v', 0), SenseInfo('01368863-v', 0), SenseInfo('01165579-v', 0), SenseInfo('00318326-v', 0), SenseInfo('00235110-v', 0), SenseInfo('00154141-v', 0), SenseInfo('00540235-v', 20), SenseInfo('02685951-v', 16), SenseInfo('02687916-v', 11), SenseInfo('02297948-v', 6), SenseInfo('00027705-v', 5), SenseInfo('02690093-v', 4), SenseInfo('02297742-v', 3), SenseInfo('00027268-v', 2), SenseInfo('00540946-v', 1), SenseInfo('00317888-v', 1), SenseInfo('02054989-v', 0), SenseInfo('01960296-v', 0), SenseInfo('01368863-v', 0), SenseInfo('01165579-v', 0), SenseInfo('00318326-v', 0), SenseInfo('00235110-v', 0), SenseInfo('00154141-v', 0), SenseInfo('00540235-v', 20), SenseInfo('02685951-v', 16), SenseInfo('02687916-v', 11), SenseInfo('02297948-v', 6), SenseInfo('00027705-v', 5), SenseInfo('02690093-v', 4), SenseInfo('02297742-v', 3), SenseInfo('00027268-v', 2), SenseInfo('00540946-v', 1), SenseInfo('00317888-v', 1), SenseInfo('02054989-v', 0), SenseInfo('01960296-v', 0), SenseInfo('01368863-v', 0), SenseInfo('01165579-v', 0), SenseInfo('00318326-v', 0), SenseInfo('00235110-v', 0), SenseInfo('00154141-v', 0) ],
"_vibe_n_1_rel" : [ SenseInfo('04727883-n', 0) ],
"_chant_v_to_rel" : [ SenseInfo('01049737-v', 6), SenseInfo('01066775-v', 2), SenseInfo('01049737-v', 6), SenseInfo('01066775-v', 2) ],
"_indifference_n_1_rel" : [ SenseInfo('07505676-n', 4), SenseInfo('07483782-n', 1), SenseInfo('04636610-n', 1), SenseInfo('04673470-n', 0) ],
"_indulge_v_in_rel" : [ SenseInfo('02511276-v', 2), SenseInfo('01182293-v', 2), SenseInfo('01191645-v', 1), SenseInfo('02570267-v', 0) ],
"_cartoon_n_1_rel" : [ SenseInfo('06780678-n', 2), SenseInfo('06616464-n', 0) ],
"_ventilation_n_of_rel" : [ SenseInfo('00266645-n', 3), SenseInfo('04526520-n', 1), SenseInfo('07144190-n', 0), SenseInfo('00831191-n', 0) ],
"_kilovolt_n_1_rel" : [ SenseInfo('13643770-n', 0) ],
"_call_v_off_rel" : [ SenseInfo('01028748-v', 91), SenseInfo('00971015-v', 51), SenseInfo('00789448-v', 38), SenseInfo('00913065-v', 25), SenseInfo('00792471-v', 25), SenseInfo('02487573-v', 9), SenseInfo('02429810-v', 9), SenseInfo('01067995-v', 1), SenseInfo('01062739-v', 1), SenseInfo('00975036-v', 1), SenseInfo('02643421-v', 0), SenseInfo('02601456-v', 0), SenseInfo('02487901-v', 0), SenseInfo('02359061-v', 0), SenseInfo('02300060-v', 0), SenseInfo('01899017-v', 0), SenseInfo('01068793-v', 0), SenseInfo('00917772-v', 0), SenseInfo('00874002-v', 0), SenseInfo('00869393-v', 0), SenseInfo('00822746-v', 0), SenseInfo('00783523-v', 0), SenseInfo('00754156-v', 0), SenseInfo('00753881-v', 0), SenseInfo('00738747-v', 0), SenseInfo('00738583-v', 0), SenseInfo('00691516-v', 0), SenseInfo('00107231-v', 0) ],
"_raindrop_n_1_rel" : [ SenseInfo('11501649-n', 0) ],
"_mica_n_1_rel" : [ SenseInfo('14681555-n', 0) ],
"_gloomy_a_1_rel" : [ SenseInfo('00275764-a', 1), SenseInfo('00703615-a', 0), SenseInfo('00364881-a', 0), SenseInfo('00275764-a', 1), SenseInfo('00703615-a', 0), SenseInfo('00364881-a', 0), SenseInfo('00275764-a', 1), SenseInfo('00703615-a', 0), SenseInfo('00364881-a', 0) ],
"_chat_v_1_rel" : [ SenseInfo('01038666-v', 2) ],
"_breach_n_of_rel" : [ SenseInfo('00068901-n', 1), SenseInfo('09228801-n', 0), SenseInfo('07313814-n', 0) ],
"_boa+constrictor_n_1_rel" : [ SenseInfo('01742172-n', 6) ],
"_neither_a_1_rel" : [ SenseInfo('00524607-a', 0), SenseInfo('00524607-a', 0), SenseInfo('00524607-a', 0), SenseInfo('00524607-a', 0) ],
"_rehabilitation_n_of_rel" : [ SenseInfo('00400645-n', 7), SenseInfo('00269018-n', 2), SenseInfo('01241997-n', 0), SenseInfo('00700260-n', 0) ],
"_tie_v_to_rel" : [ SenseInfo('01285440-v', 13), SenseInfo('01115190-v', 5), SenseInfo('00234217-v', 4), SenseInfo('01354673-v', 2), SenseInfo('00141632-v', 1), SenseInfo('02538086-v', 0), SenseInfo('02489456-v', 0), SenseInfo('01658444-v', 0), SenseInfo('01355411-v', 0) ],
"_assessment_n_1_rel" : [ SenseInfo('05733583-n', 4), SenseInfo('13403146-n', 0), SenseInfo('05146055-n', 0), SenseInfo('00874067-n', 0), SenseInfo('05733583-n', 4), SenseInfo('13403146-n', 0), SenseInfo('05146055-n', 0), SenseInfo('00874067-n', 0) ],
"_chance_n_of_rel" : [ SenseInfo('14483917-n', 40), SenseInfo('11418138-n', 8), SenseInfo('00802629-n', 4), SenseInfo('05091770-n', 2), SenseInfo('14482968-n', 0), SenseInfo('14483917-n', 40), SenseInfo('11418138-n', 8), SenseInfo('00802629-n', 4), SenseInfo('05091770-n', 2), SenseInfo('14482968-n', 0), SenseInfo('14483917-n', 40), SenseInfo('11418138-n', 8), SenseInfo('00802629-n', 4), SenseInfo('05091770-n', 2), SenseInfo('14482968-n', 0), SenseInfo('14483917-n', 40), SenseInfo('11418138-n', 8), SenseInfo('00802629-n', 4), SenseInfo('05091770-n', 2), SenseInfo('14482968-n', 0) ],
"_head_v_for_rel" : [ SenseInfo('01935233-v', 29), SenseInfo('02440244-v', 19), SenseInfo('01999423-v', 3), SenseInfo('02729023-v', 2), SenseInfo('01931768-v', 2), SenseInfo('02754463-v', 0), SenseInfo('02694287-v', 0), SenseInfo('02624128-v', 0), SenseInfo('01590915-v', 0) ],
"_as_p_sel_rel" : [ SenseInfo('13658027-n', 6), SenseInfo('15089803-n', 0), SenseInfo('14829565-n', 0), SenseInfo('14706889-n', 0), SenseInfo('13637376-n', 0), SenseInfo('06831177-n', 0), SenseInfo('05400860-n', 0), SenseInfo('13658027-n', 6), SenseInfo('15089803-n', 0), SenseInfo('14829565-n', 0), SenseInfo('14706889-n', 0), SenseInfo('13637376-n', 0), SenseInfo('06831177-n', 0), SenseInfo('05400860-n', 0) ],
"_instruction_n_of_rel" : [ SenseInfo('06786629-n', 11), SenseInfo('00883297-n', 5), SenseInfo('00887081-n', 2), SenseInfo('06584891-n', 0), SenseInfo('06786629-n', 11), SenseInfo('00883297-n', 5), SenseInfo('00887081-n', 2), SenseInfo('06584891-n', 0), SenseInfo('06786629-n', 11), SenseInfo('00883297-n', 5), SenseInfo('00887081-n', 2), SenseInfo('06584891-n', 0) ],
"_provider_n_of_rel" : [ SenseInfo('10677271-n', 0), SenseInfo('10486349-n', 0) ],
"_fore_p_rel" : [ SenseInfo('01033081-a', 0), SenseInfo('02880008-n', 0), SenseInfo('00275694-r', 0) ],
"_bivalve_n_1_rel" : [ SenseInfo('01955933-n', 0) ],
"_dole_v_to_rel" : [  ],
"_master_n_1_rel" : [ SenseInfo('10280130-n', 8), SenseInfo('10388440-n', 5), SenseInfo('10752930-n', 1), SenseInfo('10298647-n', 1), SenseInfo('10164233-n', 1), SenseInfo('03727274-n', 1), SenseInfo('10298912-n', 0), SenseInfo('10298798-n', 0), SenseInfo('10298482-n', 0), SenseInfo('03896984-n', 0) ],
"_taper_v_1_rel" : [ SenseInfo('00152762-v', 1), SenseInfo('00392960-v', 0), SenseInfo('00152762-v', 1), SenseInfo('00392960-v', 0) ],
"_chlorine_n_1_rel" : [ SenseInfo('14634591-n', 32) ],
"_lemon_a_1_rel" : [ SenseInfo('07749582-n', 4), SenseInfo('04966543-n', 2), SenseInfo('12711596-n', 0), SenseInfo('05716342-n', 0), SenseInfo('03655838-n', 0) ],
"_western_a_1_rel" : [ SenseInfo('00825089-a', 21), SenseInfo('00825970-a', 3), SenseInfo('00824631-a', 1), SenseInfo('00824753-a', 0), SenseInfo('00825089-a', 21), SenseInfo('00825970-a', 3), SenseInfo('00824631-a', 1), SenseInfo('00824753-a', 0) ],
"_soon+after_a_1_rel" : [  ],
"_wife_n_of_rel" : [ SenseInfo('10780632-n', 120) ],
"_overmantel_n_1_rel" : [ SenseInfo('03865288-n', 0) ],
"_capacious_a_1_rel" : [ SenseInfo('01384572-a', 0) ],
"_deliberation_n_1_rel" : [ SenseInfo('07142365-n', 1), SenseInfo('05785067-n', 1), SenseInfo('05796423-n', 0), SenseInfo('05061977-n', 0), SenseInfo('04661151-n', 0) ],
"_anachronism_n_1_rel" : [ SenseInfo('15180304-n', 1), SenseInfo('02707036-n', 1), SenseInfo('09606873-n', 0) ],
"_tame_a_1_rel" : [ SenseInfo('00923232-a', 1), SenseInfo('02389946-a', 0), SenseInfo('02388145-a', 0), SenseInfo('02328916-a', 0), SenseInfo('00923232-a', 1), SenseInfo('02389946-a', 0), SenseInfo('02388145-a', 0), SenseInfo('02328916-a', 0), SenseInfo('00923232-a', 1), SenseInfo('02389946-a', 0), SenseInfo('02388145-a', 0), SenseInfo('02328916-a', 0) ],
"_tunnel_n_1_rel" : [ SenseInfo('04497962-n', 1), SenseInfo('09230041-n', 0) ],
"_nightcap_n_1_rel" : [ SenseInfo('07912619-n', 0), SenseInfo('03824284-n', 0), SenseInfo('00460844-n', 0) ],
"_regard_v_as_rel" : [ SenseInfo('00690614-v', 33), SenseInfo('02133185-v', 19), SenseInfo('02677097-v', 12), SenseInfo('00690614-v', 33), SenseInfo('02133185-v', 19), SenseInfo('02677097-v', 12), SenseInfo('00690614-v', 33), SenseInfo('02133185-v', 19), SenseInfo('02677097-v', 12) ],
"_load_v_1_rel" : [ SenseInfo('01489989-v', 8), SenseInfo('01490336-v', 3), SenseInfo('02231910-v', 0), SenseInfo('01612084-v', 0), SenseInfo('00487748-v', 0), SenseInfo('01489989-v', 8), SenseInfo('01490336-v', 3), SenseInfo('02231910-v', 0), SenseInfo('01612084-v', 0), SenseInfo('00487748-v', 0) ],
"_laziness_n_1_rel" : [ SenseInfo('04637108-n', 0), SenseInfo('01064613-n', 0), SenseInfo('00758795-n', 0) ],
"_testimonial_n_1_rel" : [ SenseInfo('06648207-n', 2), SenseInfo('06697195-n', 1), SenseInfo('06694540-n', 0) ],
"_rest_n_of_rel" : [ SenseInfo('13810818-n', 44), SenseInfo('01064148-n', 6), SenseInfo('15274074-n', 3), SenseInfo('14012501-n', 1), SenseInfo('13962765-n', 1), SenseInfo('04081044-n', 1), SenseInfo('06865177-n', 0), SenseInfo('13810818-n', 44), SenseInfo('01064148-n', 6), SenseInfo('15274074-n', 3), SenseInfo('14012501-n', 1), SenseInfo('13962765-n', 1), SenseInfo('04081044-n', 1), SenseInfo('06865177-n', 0) ],
"_shrine_n_1_rel" : [ SenseInfo('04210390-n', 1) ],
"_dribs_n_1_rel" : [ SenseInfo('13771404-n', 0), SenseInfo('13771404-n', 0) ],
"_spinach_n_1_rel" : [ SenseInfo('11835568-n', 0), SenseInfo('07736692-n', 0) ],
"_beach_v_1_rel" : [ SenseInfo('01978947-v', 0) ],
"_count_v_for_rel" : [ SenseInfo('00948071-v', 23), SenseInfo('02645839-v', 7), SenseInfo('00950431-v', 4), SenseInfo('00947857-v', 3), SenseInfo('02731632-v', 2), SenseInfo('00685081-v', 2), SenseInfo('02747140-v', 0), SenseInfo('00712708-v', 0), SenseInfo('00712556-v', 0) ],
"_splurge_n_1_rel" : [ SenseInfo('06890000-n', 0), SenseInfo('01073824-n', 0) ],
"_gush_n_1_rel" : [ SenseInfo('07439570-n', 0), SenseInfo('07014320-n', 0) ],
"_unreleased_a_1_rel" : [ SenseInfo('00470719-a', 1), SenseInfo('00470719-a', 1) ],
"_greater+than_x_deg_rel" : [  ],
"_american_a_1_rel" : [ SenseInfo('02927512-a', 117), SenseInfo('02927303-a', 4) ],
"_writhe_v_1_rel" : [ SenseInfo('01868370-v', 7) ],
"_cc_n_1_rel" : [ SenseInfo('13623636-n', 2) ],
"_workflow_n_1_rel" : [ SenseInfo('00250143-n', 0) ],
"_goodly_a_1_rel" : [ SenseInfo('00624576-a', 0) ],
"_confirm_v_as_rel" : [ SenseInfo('00665886-v', 18), SenseInfo('01012073-v', 5), SenseInfo('00221840-v', 2), SenseInfo('02476518-v', 1), SenseInfo('02474603-v', 0), SenseInfo('00665886-v', 18), SenseInfo('01012073-v', 5), SenseInfo('00221840-v', 2), SenseInfo('02476518-v', 1), SenseInfo('02474603-v', 0), SenseInfo('00665886-v', 18), SenseInfo('01012073-v', 5), SenseInfo('00221840-v', 2), SenseInfo('02476518-v', 1), SenseInfo('02474603-v', 0), SenseInfo('00665886-v', 18), SenseInfo('01012073-v', 5), SenseInfo('00221840-v', 2), SenseInfo('02476518-v', 1), SenseInfo('02474603-v', 0), SenseInfo('00665886-v', 18), SenseInfo('01012073-v', 5), SenseInfo('00221840-v', 2), SenseInfo('02476518-v', 1), SenseInfo('02474603-v', 0) ],
"_swing_v_1_rel" : [ SenseInfo('02087745-v', 35), SenseInfo('01877355-v', 15), SenseInfo('01877620-v', 6), SenseInfo('02537238-v', 4), SenseInfo('01593763-v', 4), SenseInfo('02717472-v', 2), SenseInfo('01152040-v', 2), SenseInfo('00557216-v', 2), SenseInfo('02615140-v', 1), SenseInfo('02752277-v', 0), SenseInfo('02389815-v', 0), SenseInfo('01725375-v', 0), SenseInfo('01427483-v', 0) ],
"_correspond_v_with_rel" : [ SenseInfo('02657219-v', 9), SenseInfo('02633534-v', 6), SenseInfo('01006810-v', 3), SenseInfo('02699497-v', 0) ],
"_gouge_v_away_rel" : [ SenseInfo('01281611-v', 3), SenseInfo('02241107-v', 2), SenseInfo('01281782-v', 2) ],
"_as+for_p_rel" : [  ],
"_site_v_1_rel" : [ SenseInfo('02333689-v', 0), SenseInfo('02333689-v', 0) ],
"_and_c_mod_rel" : [  ],
"_stopover_n_1_rel" : [ SenseInfo('08657100-n', 0), SenseInfo('01056411-n', 0) ],
"_poncho_n_1_rel" : [ SenseInfo('03980874-n', 3) ],
"_late_a_for_rel" : [ SenseInfo('00816481-a', 33), SenseInfo('01901186-a', 4), SenseInfo('01730444-a', 3), SenseInfo('00097674-a', 3), SenseInfo('00820721-a', 2), SenseInfo('00819235-a', 1), SenseInfo('01729819-a', 0), SenseInfo('00816481-a', 33), SenseInfo('01901186-a', 4), SenseInfo('01730444-a', 3), SenseInfo('00097674-a', 3), SenseInfo('00820721-a', 2), SenseInfo('00819235-a', 1), SenseInfo('01729819-a', 0), SenseInfo('00816481-a', 33), SenseInfo('01901186-a', 4), SenseInfo('01730444-a', 3), SenseInfo('00097674-a', 3), SenseInfo('00820721-a', 2), SenseInfo('00819235-a', 1), SenseInfo('01729819-a', 0), SenseInfo('00816481-a', 33), SenseInfo('01901186-a', 4), SenseInfo('01730444-a', 3), SenseInfo('00097674-a', 3), SenseInfo('00820721-a', 2), SenseInfo('00819235-a', 1), SenseInfo('01729819-a', 0), SenseInfo('00816481-a', 33), SenseInfo('01901186-a', 4), SenseInfo('01730444-a', 3), SenseInfo('00097674-a', 3), SenseInfo('00820721-a', 2), SenseInfo('00819235-a', 1), SenseInfo('01729819-a', 0) ],
"_scratch_n_1_rel" : [ SenseInfo('14286549-n', 1), SenseInfo('13904843-n', 0), SenseInfo('13385216-n', 0), SenseInfo('10563610-n', 0), SenseInfo('08653873-n', 0), SenseInfo('07805389-n', 0), SenseInfo('07392982-n', 0), SenseInfo('06404147-n', 0), SenseInfo('05163401-n', 0), SenseInfo('04693900-n', 0) ],
"_puncture_v_1_rel" : [ SenseInfo('01274971-v', 1), SenseInfo('01275182-v', 0), SenseInfo('00856234-v', 0), SenseInfo('00403798-v', 0), SenseInfo('00309990-v', 0) ],
"_desolate_a_1_rel" : [ SenseInfo('01242750-a', 4), SenseInfo('01232507-a', 0) ],
"_uranium_n_1_rel" : [ SenseInfo('14660443-n', 0) ],
"_bit_n_of_rel" : [ SenseInfo('13761407-n', 18), SenseInfo('09222051-n', 4), SenseInfo('15246853-n', 1), SenseInfo('07309457-n', 1), SenseInfo('02844714-n', 1), SenseInfo('13625237-n', 0), SenseInfo('07579076-n', 0), SenseInfo('07009042-n', 0), SenseInfo('06892016-n', 0), SenseInfo('02845002-n', 0), SenseInfo('02844307-n', 0), SenseInfo('13761407-n', 18), SenseInfo('09222051-n', 4), SenseInfo('15246853-n', 1), SenseInfo('07309457-n', 1), SenseInfo('02844714-n', 1), SenseInfo('13625237-n', 0), SenseInfo('07579076-n', 0), SenseInfo('07009042-n', 0), SenseInfo('06892016-n', 0), SenseInfo('02845002-n', 0), SenseInfo('02844307-n', 0) ],
"_stir_v_1_rel" : [ SenseInfo('01894320-v', 7), SenseInfo('01893988-v', 5), SenseInfo('02116118-v', 4), SenseInfo('01761706-v', 4), SenseInfo('01770802-v', 1), SenseInfo('01629958-v', 1), SenseInfo('01894164-v', 0), SenseInfo('01541467-v', 0) ],
"_tan_n_1_rel" : [ SenseInfo('14290534-n', 1), SenseInfo('04973020-n', 1), SenseInfo('13788035-n', 0) ],
"_is-a_a_1_rel" : [  ],
"_rococo_a_1_rel" : [ SenseInfo('01796844-a', 0) ],
"_cover_n_1_rel" : [ SenseInfo('04151940-n', 9), SenseInfo('02849154-n', 8), SenseInfo('01049685-n', 4), SenseInfo('02840619-n', 2), SenseInfo('09257949-n', 1), SenseInfo('04453910-n', 1), SenseInfo('00988893-n', 1), SenseInfo('13318411-n', 0), SenseInfo('03121698-n', 0), SenseInfo('01049992-n', 0) ],
"_pleasant_a_1_rel" : [ SenseInfo('01800349-a', 9), SenseInfo('01586866-a', 1), SenseInfo('01800349-a', 9), SenseInfo('01586866-a', 1) ],
"_rough_x_deg_rel" : [ SenseInfo('02238462-a', 13), SenseInfo('01951197-a', 2), SenseInfo('00915976-a', 2), SenseInfo('00354033-r', 1), SenseInfo('00747910-a', 1), SenseInfo('00304949-a', 1), SenseInfo('00299476-a', 1), SenseInfo('00084353-a', 1), SenseInfo('01754452-v', 1), SenseInfo('02245403-a', 0), SenseInfo('02243567-a', 0), SenseInfo('00664167-a', 0), SenseInfo('08640962-n', 0), SenseInfo('00353916-r', 0), SenseInfo('02229584-a', 0), SenseInfo('01813183-a', 0), SenseInfo('01803583-a', 0), SenseInfo('01374183-a', 0) ],
"_cycleway_n_1_rel" : [  ],
"_cheese_n_1_rel" : [ SenseInfo('07850329-n', 2), SenseInfo('12171503-n', 0) ],
"_holster_v_1_rel" : [  ],
"_veterans_a_1_rel" : [ SenseInfo('00936523-a', 11), SenseInfo('00936523-a', 11), SenseInfo('00936523-a', 11), SenseInfo('00936523-a', 11) ],
"_productivity_n_1_rel" : [ SenseInfo('05147940-n', 13), SenseInfo('13824500-n', 0) ],
"_climb_n_1_rel" : [ SenseInfo('09206985-n', 0), SenseInfo('07370410-n', 0), SenseInfo('00325110-n', 0) ],
"_dream_v_up_rel" : [ SenseInfo('01637633-v', 15), SenseInfo('02118242-v', 11) ],
"_immortality_n_1_rel" : [ SenseInfo('05056102-n', 14), SenseInfo('15144094-n', 0) ],
"_checkup_n_1_rel" : [ SenseInfo('00142361-n', 1), SenseInfo('00142361-n', 1), SenseInfo('00142361-n', 1) ],
"_starve_v_cause_rel" : [ SenseInfo('01188144-v', 4), SenseInfo('01187537-v', 3), SenseInfo('01187740-v', 1), SenseInfo('01188485-v', 0), SenseInfo('01187948-v', 0) ],
"_travel_n_1_rel" : [ SenseInfo('00295701-n', 7), SenseInfo('07311115-n', 1), SenseInfo('00283127-n', 0) ],
"_which_q_rel" : [  ],
"_root_n_i_rel" : [ SenseInfo('13125117-n', 11), SenseInfo('08507558-n', 2), SenseInfo('06300193-n', 2), SenseInfo('13731669-n', 1), SenseInfo('08005954-n', 1), SenseInfo('09792555-n', 0), SenseInfo('06300445-n', 0), SenseInfo('05308310-n', 0) ],
"_fleet_a_1_rel" : [ SenseInfo('00978199-a', 2), SenseInfo('00978199-a', 2) ],
"_dislike_n_of_rel" : [ SenseInfo('06200741-n', 4), SenseInfo('07501545-n', 2) ],
"_propulsion_n_1_rel" : [ SenseInfo('11497777-n', 0), SenseInfo('00045250-n', 0) ],
"_murder_n_of_rel" : [ SenseInfo('00220522-n', 45) ],
"_idea_n_of_rel" : [ SenseInfo('05833840-n', 151), SenseInfo('05982915-n', 4), SenseInfo('05837850-n', 1), SenseInfo('05803379-n', 1), SenseInfo('07029247-n', 0), SenseInfo('05833840-n', 151), SenseInfo('05982915-n', 4), SenseInfo('05837850-n', 1), SenseInfo('05803379-n', 1), SenseInfo('07029247-n', 0), SenseInfo('05833840-n', 151), SenseInfo('05982915-n', 4), SenseInfo('05837850-n', 1), SenseInfo('05803379-n', 1), SenseInfo('07029247-n', 0), SenseInfo('05833840-n', 151), SenseInfo('05982915-n', 4), SenseInfo('05837850-n', 1), SenseInfo('05803379-n', 1), SenseInfo('07029247-n', 0) ],
"_license_n_1_rel" : [ SenseInfo('06549661-n', 4), SenseInfo('13994806-n', 3), SenseInfo('13995378-n', 0), SenseInfo('01139194-n', 0), SenseInfo('06549661-n', 4), SenseInfo('13994806-n', 3), SenseInfo('13995378-n', 0), SenseInfo('01139194-n', 0), SenseInfo('06549661-n', 4), SenseInfo('13994806-n', 3), SenseInfo('13995378-n', 0), SenseInfo('01139194-n', 0) ],
"_take_v_with-i_rel" : [ SenseInfo('02599636-v', 92), SenseInfo('02267989-v', 74), SenseInfo('01999798-v', 73), SenseInfo('01214265-v', 50), SenseInfo('00524682-v', 38), SenseInfo('00624476-v', 36), SenseInfo('02077656-v', 32), SenseInfo('02205272-v', 28), SenseInfo('01842690-v', 26), SenseInfo('00674607-v', 26), SenseInfo('02236124-v', 25), SenseInfo('02394183-v', 22), SenseInfo('00734054-v', 22), SenseInfo('02627934-v', 21), SenseInfo('02109045-v', 21), SenseInfo('01002740-v', 16), SenseInfo('00173338-v', 16), SenseInfo('01156834-v', 15), SenseInfo('00669762-v', 15), SenseInfo('02209936-v', 14), SenseInfo('02206619-v', 13), SenseInfo('01982395-v', 10), SenseInfo('02236624-v', 8), SenseInfo('00523095-v', 7), SenseInfo('00599992-v', 6), SenseInfo('00756076-v', 5), SenseInfo('02075857-v', 4), SenseInfo('01151110-v', 4), SenseInfo('00557404-v', 4), SenseInfo('02717102-v', 2), SenseInfo('02208537-v', 2), SenseInfo('02209745-v', 1), SenseInfo('02208118-v', 1), SenseInfo('02201138-v', 1), SenseInfo('01427127-v', 1), SenseInfo('00758333-v', 1), SenseInfo('02741546-v', 0), SenseInfo('02701210-v', 0), SenseInfo('02590253-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01100830-v', 0), SenseInfo('00087736-v', 0) ],
"_misfortune_n_1_rel" : [ SenseInfo('07304852-n', 4), SenseInfo('14475405-n', 3) ],
"_kill_v_1_rel" : [ SenseInfo('01323958-v', 103), SenseInfo('02473688-v', 1), SenseInfo('00355038-v', 1), SenseInfo('02748495-v', 0), SenseInfo('02198819-v', 0), SenseInfo('01809617-v', 0), SenseInfo('01407376-v', 0), SenseInfo('01407235-v', 0), SenseInfo('01325774-v', 0), SenseInfo('01325536-v', 0), SenseInfo('01202374-v', 0), SenseInfo('00478830-v', 0), SenseInfo('00355524-v', 0), SenseInfo('00355365-v', 0), SenseInfo('00355177-v', 0) ],
"_appertain_v_to_rel" : [ SenseInfo('02653706-v', 0) ],
"_erotic_a_1_rel" : [ SenseInfo('02132080-a', 3) ],
"_couplet_n_1_rel" : [ SenseInfo('13743605-n', 0), SenseInfo('06378917-n', 0) ],
"_to+date_p_rel" : [ SenseInfo('00172151-r', 0) ],
"_audit_n_of_rel" : [ SenseInfo('13411157-n', 2), SenseInfo('00141176-n', 0) ],
"_pipe_v_in_rel" : [ SenseInfo('00914420-v', 1), SenseInfo('01950295-v', 0), SenseInfo('01727684-v', 0), SenseInfo('01670645-v', 0) ],
"_haul_v_1_rel" : [ SenseInfo('01454810-v', 7), SenseInfo('01452255-v', 5) ],
"_straw_n_1_rel" : [ SenseInfo('14959939-n', 10), SenseInfo('14805899-n', 2), SenseInfo('04966941-n', 0), SenseInfo('04334232-n', 0) ],
"_juggle_v_around_rel" : [ SenseInfo('02578235-v', 0), SenseInfo('02577391-v', 0), SenseInfo('02438383-v', 0), SenseInfo('01604814-v', 0), SenseInfo('01602527-v', 0) ],
"_clamor_v_for_rel" : [ SenseInfo('00774641-v', 5), SenseInfo('00915041-v', 3), SenseInfo('02506924-v', 0), SenseInfo('00774641-v', 5), SenseInfo('00915041-v', 3), SenseInfo('02506924-v', 0) ],
"_thirst_n_for_rel" : [ SenseInfo('14040660-n', 2), SenseInfo('04945254-n', 1) ],
"_partition_v_cause_rel" : [ SenseInfo('01563724-v', 0), SenseInfo('00332835-v', 0) ],
"_doorway_n_1_rel" : [ SenseInfo('03224032-n', 11), SenseInfo('03224032-n', 11) ],
"_nosedive_v_1_rel" : [ SenseInfo('01967634-v', 0), SenseInfo('01967634-v', 0), SenseInfo('01967634-v', 0) ],
"_epinaler_n_1_rel" : [  ],
"_sand_v_down_rel" : [ SenseInfo('01386433-v', 2) ],
"_uninitiated_a_1_rel" : [ SenseInfo('00937341-a', 1), SenseInfo('00937341-a', 1) ],
"_ardent_a_1_rel" : [ SenseInfo('01726235-a', 1), SenseInfo('00886117-a', 0), SenseInfo('00281342-a', 0) ],
"_tease_v_open_rel" : [ SenseInfo('01803380-v', 2), SenseInfo('00850501-v', 1), SenseInfo('01803641-v', 0), SenseInfo('01572386-v', 0), SenseInfo('01531635-v', 0), SenseInfo('01463792-v', 0), SenseInfo('01356256-v', 0), SenseInfo('00852506-v', 0), SenseInfo('00040188-v', 0) ],
"_creditor_n_1_rel" : [ SenseInfo('09976728-n', 0), SenseInfo('09976728-n', 0), SenseInfo('09976728-n', 0) ],
"_chalk_n_1_rel" : [ SenseInfo('14806598-n', 0), SenseInfo('04961472-n', 0), SenseInfo('03754295-n', 0), SenseInfo('03003091-n', 0) ],
"_mute_v_1_rel" : [ SenseInfo('02191311-v', 0) ],
"_flex_v_1_rel" : [ SenseInfo('02036977-v', 1), SenseInfo('02142280-v', 0), SenseInfo('02035919-v', 0), SenseInfo('01280488-v', 0), SenseInfo('01280014-v', 0) ],
"_depot_n_1_rel" : [ SenseInfo('04412901-n', 1), SenseInfo('04329190-n', 0) ],
"_christian_a_1_rel" : [ SenseInfo('02952275-a', 36), SenseInfo('00411009-a', 1) ],
"_utmost_a_1_rel" : [ SenseInfo('01511520-a', 3), SenseInfo('01212095-a', 1), SenseInfo('00443618-a', 0) ],
"_archeological_a_1_rel" : [ SenseInfo('02638392-a', 1) ],
"_docility_n_1_rel" : [ SenseInfo('04905697-n', 0) ],
"_poetry_n_1_rel" : [ SenseInfo('07092592-n', 11), SenseInfo('07093273-n', 1), SenseInfo('07092592-n', 11), SenseInfo('07093273-n', 1) ],
"_exhaust_v_1_rel" : [ SenseInfo('00075421-v', 4), SenseInfo('01157517-v', 3), SenseInfo('02280869-v', 1), SenseInfo('00450997-v', 0), SenseInfo('00104868-v', 0), SenseInfo('00075421-v', 4), SenseInfo('01157517-v', 3), SenseInfo('02280869-v', 1), SenseInfo('00450997-v', 0), SenseInfo('00104868-v', 0), SenseInfo('00075421-v', 4), SenseInfo('01157517-v', 3), SenseInfo('02280869-v', 1), SenseInfo('00450997-v', 0), SenseInfo('00104868-v', 0), SenseInfo('00075421-v', 4), SenseInfo('01157517-v', 3), SenseInfo('02280869-v', 1), SenseInfo('00450997-v', 0), SenseInfo('00104868-v', 0), SenseInfo('00075421-v', 4), SenseInfo('01157517-v', 3), SenseInfo('02280869-v', 1), SenseInfo('00450997-v', 0), SenseInfo('00104868-v', 0) ],
"_clock_v_1_rel" : [ SenseInfo('00490968-v', 1) ],
"_hardly_a_1_rel" : [  ],
"_footprint_v_1_rel" : [  ],
"_moist_a_1_rel" : [ SenseInfo('02548820-a', 6), SenseInfo('02548820-a', 6), SenseInfo('02548820-a', 6) ],
"_take_v_out_rel" : [ SenseInfo('02599636-v', 92), SenseInfo('02267989-v', 74), SenseInfo('01999798-v', 73), SenseInfo('01214265-v', 50), SenseInfo('00524682-v', 38), SenseInfo('00624476-v', 36), SenseInfo('02077656-v', 32), SenseInfo('02205272-v', 28), SenseInfo('01842690-v', 26), SenseInfo('00674607-v', 26), SenseInfo('02236124-v', 25), SenseInfo('02394183-v', 22), SenseInfo('00734054-v', 22), SenseInfo('02627934-v', 21), SenseInfo('02109045-v', 21), SenseInfo('01002740-v', 16), SenseInfo('00173338-v', 16), SenseInfo('01156834-v', 15), SenseInfo('00669762-v', 15), SenseInfo('02209936-v', 14), SenseInfo('02206619-v', 13), SenseInfo('01982395-v', 10), SenseInfo('02236624-v', 8), SenseInfo('00523095-v', 7), SenseInfo('00599992-v', 6), SenseInfo('00756076-v', 5), SenseInfo('02075857-v', 4), SenseInfo('01151110-v', 4), SenseInfo('00557404-v', 4), SenseInfo('02717102-v', 2), SenseInfo('02208537-v', 2), SenseInfo('02209745-v', 1), SenseInfo('02208118-v', 1), SenseInfo('02201138-v', 1), SenseInfo('01427127-v', 1), SenseInfo('00758333-v', 1), SenseInfo('02741546-v', 0), SenseInfo('02701210-v', 0), SenseInfo('02590253-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01100830-v', 0), SenseInfo('00087736-v', 0), SenseInfo('02599636-v', 92), SenseInfo('02267989-v', 74), SenseInfo('01999798-v', 73), SenseInfo('01214265-v', 50), SenseInfo('00524682-v', 38), SenseInfo('00624476-v', 36), SenseInfo('02077656-v', 32), SenseInfo('02205272-v', 28), SenseInfo('01842690-v', 26), SenseInfo('00674607-v', 26), SenseInfo('02236124-v', 25), SenseInfo('02394183-v', 22), SenseInfo('00734054-v', 22), SenseInfo('02627934-v', 21), SenseInfo('02109045-v', 21), SenseInfo('01002740-v', 16), SenseInfo('00173338-v', 16), SenseInfo('01156834-v', 15), SenseInfo('00669762-v', 15), SenseInfo('02209936-v', 14), SenseInfo('02206619-v', 13), SenseInfo('01982395-v', 10), SenseInfo('02236624-v', 8), SenseInfo('00523095-v', 7), SenseInfo('00599992-v', 6), SenseInfo('00756076-v', 5), SenseInfo('02075857-v', 4), SenseInfo('01151110-v', 4), SenseInfo('00557404-v', 4), SenseInfo('02717102-v', 2), SenseInfo('02208537-v', 2), SenseInfo('02209745-v', 1), SenseInfo('02208118-v', 1), SenseInfo('02201138-v', 1), SenseInfo('01427127-v', 1), SenseInfo('00758333-v', 1), SenseInfo('02741546-v', 0), SenseInfo('02701210-v', 0), SenseInfo('02590253-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01100830-v', 0), SenseInfo('00087736-v', 0) ],
"_pontificate_v_1_rel" : [ SenseInfo('02432395-v', 0), SenseInfo('00828754-v', 0), SenseInfo('02432395-v', 0), SenseInfo('00828754-v', 0) ],
"_improvement_n_1_rel" : [ SenseInfo('07357388-n', 7), SenseInfo('00248977-n', 7), SenseInfo('14422179-n', 4) ],
"_abacinate_v_1_rel" : [ SenseInfo('02168378-v', 0) ],
"_leukemia_n_1_rel" : [ SenseInfo('14242922-n', 0) ],
"_works_n_1_rel" : [ SenseInfo('00575741-n', 90), SenseInfo('04599396-n', 76), SenseInfo('00584367-n', 27), SenseInfo('05755883-n', 11), SenseInfo('11453420-n', 5), SenseInfo('04602044-n', 3), SenseInfo('03841417-n', 0), SenseInfo('00575741-n', 90), SenseInfo('04599396-n', 76), SenseInfo('00584367-n', 27), SenseInfo('05755883-n', 11), SenseInfo('11453420-n', 5), SenseInfo('04602044-n', 3), SenseInfo('03841417-n', 0) ],
"_empty_a_of_rel" : [ SenseInfo('01086545-a', 30), SenseInfo('01498084-a', 6), SenseInfo('01269319-a', 0), SenseInfo('01088749-a', 0) ],
"_surroundings_n_1_rel" : [ SenseInfo('14513944-n', 5), SenseInfo('08567235-n', 1), SenseInfo('14513944-n', 5), SenseInfo('08567235-n', 1) ],
"_drill_n_1_rel" : [ SenseInfo('03239726-n', 0), SenseInfo('02487079-n', 0), SenseInfo('00894552-n', 0), SenseInfo('00894359-n', 0) ],
"_labyrinth_n_1_rel" : [ SenseInfo('03733281-n', 1), SenseInfo('05321307-n', 0) ],
"_mug_n_1_rel" : [ SenseInfo('13768440-n', 0), SenseInfo('09921409-n', 0), SenseInfo('05601357-n', 0), SenseInfo('03797390-n', 0) ],
"_succeed_v_1_rel" : [ SenseInfo('02524171-v', 28), SenseInfo('02406585-v', 12) ],
"_spiral_n_1_rel" : [ SenseInfo('13876371-n', 7), SenseInfo('13876561-n', 0), SenseInfo('13560191-n', 0), SenseInfo('04279666-n', 0), SenseInfo('03065424-n', 0), SenseInfo('00343606-n', 0) ],
"_prophetic_a_1_rel" : [ SenseInfo('01881696-a', 3) ],
"_hand-off_n_1_rel" : [ SenseInfo('00561078-n', 0), SenseInfo('00561078-n', 0), SenseInfo('00561078-n', 0) ],
"_two-bagger_n_1_rel" : [ SenseInfo('00132756-n', 0), SenseInfo('00132756-n', 0) ],
"_shriek_v_out_rel" : [ SenseInfo('00914420-v', 4), SenseInfo('00914420-v', 4) ],
"_discretionary_a_1_rel" : [ SenseInfo('00719819-a', 1), SenseInfo('02003186-a', 0) ],
"_short+circuit_n_1_rel" : [ SenseInfo('04204755-n', 0) ],
"_any+longer_a_1_rel" : [  ],
"_carp_v_1_rel" : [ SenseInfo('00808671-v', 0), SenseInfo('00808671-v', 0) ],
"_stealth_n_1_rel" : [ SenseInfo('01051082-n', 1) ],
"_star_v_1_rel" : [ SenseInfo('02631349-v', 3), SenseInfo('01720980-v', 0), SenseInfo('00510869-v', 0), SenseInfo('02631349-v', 3), SenseInfo('01720980-v', 0), SenseInfo('00510869-v', 0) ],
"_connect_v_to-with_rel" : [ SenseInfo('01354673-v', 8), SenseInfo('00713167-v', 4), SenseInfo('02622234-v', 3), SenseInfo('01069391-v', 3), SenseInfo('01237761-v', 1), SenseInfo('01069190-v', 1), SenseInfo('02747403-v', 0), SenseInfo('02389592-v', 0), SenseInfo('02389346-v', 0), SenseInfo('01421122-v', 0), SenseInfo('01407568-v', 0), SenseInfo('01354673-v', 8), SenseInfo('00713167-v', 4), SenseInfo('02622234-v', 3), SenseInfo('01069391-v', 3), SenseInfo('01237761-v', 1), SenseInfo('01069190-v', 1), SenseInfo('02747403-v', 0), SenseInfo('02389592-v', 0), SenseInfo('02389346-v', 0), SenseInfo('01421122-v', 0), SenseInfo('01407568-v', 0) ],
"_flyer_n_1_rel" : [ SenseInfo('07250339-n', 1), SenseInfo('10096217-n', 0), SenseInfo('09826204-n', 0) ],
"_ham_v_up_rel" : [ SenseInfo('01751173-v', 0) ],
"_toughbook_n_1_rel" : [  ],
"_summon_v_to_rel" : [ SenseInfo('00791134-v', 8), SenseInfo('01041762-v', 2), SenseInfo('01381549-v', 0), SenseInfo('00270215-v', 0) ],
"_inland_a_1_rel" : [ SenseInfo('00463784-a', 0) ],
"_profane_a_1_rel" : [ SenseInfo('00425002-a', 1), SenseInfo('02056880-a', 0), SenseInfo('02054926-a', 0), SenseInfo('02012748-a', 0) ],
"_spline_n_1_rel" : [ SenseInfo('04282379-n', 0), SenseInfo('04234455-n', 0) ],
"_live_v_1_rel" : [ SenseInfo('02649830-v', 129), SenseInfo('02614387-v', 51), SenseInfo('02618149-v', 29), SenseInfo('02616713-v', 16), SenseInfo('02614181-v', 14), SenseInfo('00596644-v', 1), SenseInfo('02614970-v', 0), SenseInfo('02649830-v', 129), SenseInfo('02614387-v', 51), SenseInfo('02618149-v', 29), SenseInfo('02616713-v', 16), SenseInfo('02614181-v', 14), SenseInfo('00596644-v', 1), SenseInfo('02614970-v', 0), SenseInfo('02649830-v', 129), SenseInfo('02614387-v', 51), SenseInfo('02618149-v', 29), SenseInfo('02616713-v', 16), SenseInfo('02614181-v', 14), SenseInfo('00596644-v', 1), SenseInfo('02614970-v', 0) ],
"_grandfather_n_of_rel" : [ SenseInfo('10142391-n', 4) ],
"_fifth+place_n_1_rel" : [  ],
"_addition_n_of_rel" : [ SenseInfo('02679415-n', 5), SenseInfo('00363788-n', 5), SenseInfo('13754293-n', 1), SenseInfo('13253423-n', 0), SenseInfo('08554872-n', 0), SenseInfo('00872107-n', 0), SenseInfo('02679415-n', 5), SenseInfo('00363788-n', 5), SenseInfo('13754293-n', 1), SenseInfo('13253423-n', 0), SenseInfo('08554872-n', 0), SenseInfo('00872107-n', 0) ],
"_acquire_v_1_rel" : [ SenseInfo('02210855-v', 34), SenseInfo('00524682-v', 5), SenseInfo('00094460-v', 1), SenseInfo('02695378-v', 0), SenseInfo('02288295-v', 0), SenseInfo('00597915-v', 0), SenseInfo('00545557-v', 0) ],
"_intervention_n_1_rel" : [ SenseInfo('01240210-n', 3), SenseInfo('06661562-n', 0), SenseInfo('01052215-n', 0), SenseInfo('01023242-n', 0), SenseInfo('00658082-n', 0) ],
"_imposition_n_of_rel" : [ SenseInfo('01127623-n', 2), SenseInfo('05833371-n', 0) ],
"_kilobit_n_1_rel" : [ SenseInfo('13627810-n', 0) ],
"_landowner_n_1_rel" : [ SenseInfo('10245639-n', 1) ],
"_loanword_n_1_rel" : [ SenseInfo('06293460-n', 0) ],
"_info_n_on_rel" : [ SenseInfo('06634376-n', 0), SenseInfo('06634376-n', 0) ],
"_reductive_a_1_rel" : [ SenseInfo('00050446-a', 0) ],
"_radioactive_a_1_rel" : [ SenseInfo('00426907-a', 3) ],
"_av_a_1_rel" : [ SenseInfo('15216563-n', 0) ],
"_push_v_aside_rel" : [ SenseInfo('01871979-v', 56), SenseInfo('00765977-v', 7), SenseInfo('00976653-v', 6), SenseInfo('02406916-v', 3), SenseInfo('01872645-v', 3), SenseInfo('02054864-v', 1), SenseInfo('02589576-v', 0), SenseInfo('02245555-v', 0), SenseInfo('01872877-v', 0), SenseInfo('01447632-v', 0) ],
"_forenoon_n_1_rel" : [ SenseInfo('15165289-n', 0) ],
"_off_p_rel" : [ SenseInfo('00232936-r', 13), SenseInfo('00235254-r', 12), SenseInfo('00193194-r', 5), SenseInfo('01651469-a', 3), SenseInfo('02082924-a', 1), SenseInfo('01651896-a', 0), SenseInfo('02369869-a', 0), SenseInfo('00035254-a', 0), SenseInfo('02482425-v', 0), SenseInfo('00232936-r', 13), SenseInfo('00235254-r', 12), SenseInfo('00193194-r', 5), SenseInfo('01651469-a', 3), SenseInfo('02082924-a', 1), SenseInfo('01651896-a', 0), SenseInfo('02369869-a', 0), SenseInfo('00035254-a', 0), SenseInfo('02482425-v', 0), SenseInfo('00232936-r', 13), SenseInfo('00235254-r', 12), SenseInfo('00193194-r', 5), SenseInfo('01651469-a', 3), SenseInfo('02082924-a', 1), SenseInfo('01651896-a', 0), SenseInfo('02369869-a', 0), SenseInfo('00035254-a', 0), SenseInfo('02482425-v', 0), SenseInfo('00232936-r', 13), SenseInfo('00235254-r', 12), SenseInfo('00193194-r', 5), SenseInfo('01651469-a', 3), SenseInfo('02082924-a', 1), SenseInfo('01651896-a', 0), SenseInfo('02369869-a', 0), SenseInfo('00035254-a', 0), SenseInfo('02482425-v', 0) ],
"_possibility_n_of_rel" : [ SenseInfo('05951180-n', 21), SenseInfo('14481929-n', 18), SenseInfo('05888929-n', 12), SenseInfo('05792010-n', 6), SenseInfo('05951180-n', 21), SenseInfo('14481929-n', 18), SenseInfo('05888929-n', 12), SenseInfo('05792010-n', 6) ],
"_predator_n_1_rel" : [ SenseInfo('10293172-n', 0), SenseInfo('02152740-n', 0) ],
"_pious_a_1_rel" : [ SenseInfo('01781478-a', 0) ],
"_aforementioned_a_1_rel" : [ SenseInfo('02068730-a', 0), SenseInfo('02068730-a', 0), SenseInfo('02068730-a', 0), SenseInfo('02068730-a', 0), SenseInfo('02068730-a', 0), SenseInfo('02068730-a', 0) ],
"_feeler_n_1_rel" : [ SenseInfo('02584915-n', 1), SenseInfo('07164349-n', 0), SenseInfo('04843270-n', 0), SenseInfo('02585285-n', 0) ],
"_vow_v_1_rel" : [ SenseInfo('00886759-v', 4), SenseInfo('00886978-v', 0) ],
"_joke_v_around_rel" : [ SenseInfo('00853633-v', 2), SenseInfo('00105554-v', 1) ],
"_earthwork_n_1_rel" : [ SenseInfo('03262717-n', 0) ],
"_analyzer_n_1_rel" : [ SenseInfo('02708711-n', 1) ],
"_currency_n_1_rel" : [ SenseInfo('13385913-n', 1), SenseInfo('04765586-n', 1), SenseInfo('05050379-n', 0) ],
"_admiration_n_of_rel" : [ SenseInfo('07500741-n', 8), SenseInfo('07509996-n', 1), SenseInfo('01218593-n', 0) ],
"_all-important_a_1_rel" : [ SenseInfo('01276150-a', 0) ],
"_emanate_v_from_rel" : [ SenseInfo('00546192-v', 1), SenseInfo('00004605-v', 0) ],
"_ballroom_n_1_rel" : [ SenseInfo('02783324-n', 3) ],
"_nationality_n_1_rel" : [ SenseInfo('07949463-n', 1), SenseInfo('13953787-n', 0) ],
"_farm_v_1_rel" : [ SenseInfo('02420232-v', 4), SenseInfo('02218443-v', 0), SenseInfo('01739814-v', 0) ],
"_passivity_n_1_rel" : [ SenseInfo('04636397-n', 1), SenseInfo('04907020-n', 0) ],
"_personal_a_1_rel" : [ SenseInfo('01767329-a', 31), SenseInfo('01616157-a', 12), SenseInfo('02858816-a', 2), SenseInfo('01779428-a', 1), SenseInfo('02858707-a', 0), SenseInfo('01767329-a', 31), SenseInfo('01616157-a', 12), SenseInfo('02858816-a', 2), SenseInfo('01779428-a', 1), SenseInfo('02858707-a', 0) ],
"_supplant_v_1_rel" : [ SenseInfo('02405390-v', 3) ],
"_chesstree_n_1_rel" : [  ],
"_screwball_n_1_rel" : [ SenseInfo('09974496-n', 0), SenseInfo('00108818-n', 0) ],
"_nectar_n_1_rel" : [ SenseInfo('14846779-n', 3), SenseInfo('07924276-n', 0), SenseInfo('07610295-n', 0) ],
"_change_n_of_rel" : [ SenseInfo('07296428-n', 46), SenseInfo('13859043-n', 45), SenseInfo('00191142-n', 17), SenseInfo('11412727-n', 13), SenseInfo('13387689-n', 2), SenseInfo('03005920-n', 1), SenseInfo('03005769-n', 1), SenseInfo('13388111-n', 0), SenseInfo('13387479-n', 0), SenseInfo('04752034-n', 0), SenseInfo('07296428-n', 46), SenseInfo('13859043-n', 45), SenseInfo('00191142-n', 17), SenseInfo('11412727-n', 13), SenseInfo('13387689-n', 2), SenseInfo('03005920-n', 1), SenseInfo('03005769-n', 1), SenseInfo('13388111-n', 0), SenseInfo('13387479-n', 0), SenseInfo('04752034-n', 0) ],
"_incline_v_cause_rel" : [ SenseInfo('02719399-v', 6), SenseInfo('02171322-v', 0), SenseInfo('02063018-v', 0), SenseInfo('02037090-v', 0), SenseInfo('01772172-v', 0), SenseInfo('00680841-v', 0) ],
"_unchanging_a_1_rel" : [ SenseInfo('00577782-a', 0), SenseInfo('00348018-a', 0), SenseInfo('00577782-a', 0), SenseInfo('00348018-a', 0) ],
"_spoil_v_1_rel" : [ SenseInfo('02527651-v', 2), SenseInfo('00210259-v', 1), SenseInfo('00203081-v', 1), SenseInfo('02570267-v', 0), SenseInfo('02558172-v', 0), SenseInfo('01825761-v', 0), SenseInfo('01565472-v', 0), SenseInfo('00477941-v', 0), SenseInfo('02527651-v', 2), SenseInfo('00210259-v', 1), SenseInfo('00203081-v', 1), SenseInfo('02570267-v', 0), SenseInfo('02558172-v', 0), SenseInfo('01825761-v', 0), SenseInfo('01565472-v', 0), SenseInfo('00477941-v', 0), SenseInfo('02527651-v', 2), SenseInfo('00210259-v', 1), SenseInfo('00203081-v', 1), SenseInfo('02570267-v', 0), SenseInfo('02558172-v', 0), SenseInfo('01825761-v', 0), SenseInfo('01565472-v', 0), SenseInfo('00477941-v', 0), SenseInfo('02527651-v', 2), SenseInfo('00210259-v', 1), SenseInfo('00203081-v', 1), SenseInfo('02570267-v', 0), SenseInfo('02558172-v', 0), SenseInfo('01825761-v', 0), SenseInfo('01565472-v', 0), SenseInfo('00477941-v', 0), SenseInfo('02527651-v', 2), SenseInfo('00210259-v', 1), SenseInfo('00203081-v', 1), SenseInfo('02570267-v', 0), SenseInfo('02558172-v', 0), SenseInfo('01825761-v', 0), SenseInfo('01565472-v', 0), SenseInfo('00477941-v', 0) ],
"_conflict_v_1_rel" : [ SenseInfo('02667228-v', 2), SenseInfo('02567147-v', 1), SenseInfo('02667228-v', 2), SenseInfo('02567147-v', 1) ],
"_extension_n_of_rel" : [ SenseInfo('15272382-n', 13), SenseInfo('00367768-n', 10), SenseInfo('06253518-n', 2), SenseInfo('00886039-n', 1), SenseInfo('00369532-n', 1), SenseInfo('06335162-n', 0), SenseInfo('05922949-n', 0), SenseInfo('05214599-n', 0), SenseInfo('05133535-n', 0), SenseInfo('03306869-n', 0), SenseInfo('03281935-n', 0), SenseInfo('02713594-n', 0) ],
"_ignorant_a_of_rel" : [ SenseInfo('00831225-a', 3), SenseInfo('00830981-a', 2), SenseInfo('01308894-a', 0) ],
"_goldeneye_n_1_rel" : [ SenseInfo('02265076-n', 0), SenseInfo('01850373-n', 0) ],
"_logbook_n_1_rel" : [ SenseInfo('06504049-n', 0) ],
"_whack_v_1_rel" : [ SenseInfo('01415807-v', 2), SenseInfo('01415807-v', 2) ],
"_wow_v_1_rel" : [ SenseInfo('01770252-v', 0) ],
"_handiwork_n_1_rel" : [ SenseInfo('03485655-n', 1) ],
"_probable_a_1_rel" : [ SenseInfo('01413247-a', 11), SenseInfo('01412134-a', 2), SenseInfo('01413247-a', 11), SenseInfo('01412134-a', 2), SenseInfo('01413247-a', 11), SenseInfo('01412134-a', 2), SenseInfo('01413247-a', 11), SenseInfo('01412134-a', 2), SenseInfo('01413247-a', 11), SenseInfo('01412134-a', 2) ],
"_dowel_n_1_rel" : [ SenseInfo('03229244-n', 0) ],
"_icelandic_a_1_rel" : [ SenseInfo('03074173-a', 0) ],
"_worldly_a_1_rel" : [ SenseInfo('02577061-a', 1), SenseInfo('02270782-a', 0), SenseInfo('02577061-a', 1), SenseInfo('02270782-a', 0), SenseInfo('02577061-a', 1), SenseInfo('02270782-a', 0) ],
"_AG_n_1_rel" : [ SenseInfo('14654954-n', 0), SenseInfo('14654954-n', 0), SenseInfo('14654954-n', 0), SenseInfo('14654954-n', 0), SenseInfo('14654954-n', 0), SenseInfo('14654954-n', 0) ],
"_quarrel_v_with_rel" : [ SenseInfo('00775156-v', 11) ],
"_communicate_v_1_rel" : [ SenseInfo('00742320-v', 9), SenseInfo('00740577-v', 8), SenseInfo('02231661-v', 0), SenseInfo('01355518-v', 0), SenseInfo('01070102-v', 0), SenseInfo('01030678-v', 0), SenseInfo('00760402-v', 0) ],
"_quaver_v_1_rel" : [ SenseInfo('01051118-v', 0), SenseInfo('01050896-v', 0) ],
"_manual_n_of_rel" : [ SenseInfo('06421685-n', 2), SenseInfo('00895135-n', 0) ],
"_invitation_n_of_rel" : [ SenseInfo('07186148-n', 5), SenseInfo('04689048-n', 0), SenseInfo('07186148-n', 5), SenseInfo('04689048-n', 0) ],
"_mutate_v_cause_rel" : [ SenseInfo('00119873-v', 0) ],
"_line_v_1_rel" : [ SenseInfo('02703539-v', 7), SenseInfo('01270784-v', 5), SenseInfo('01582645-v', 0), SenseInfo('01276361-v', 0), SenseInfo('00454135-v', 0), SenseInfo('00222993-v', 0) ],
"_mickey_n_1_rel" : [ SenseInfo('09715521-n', 0) ],
"_diligent_a_1_rel" : [ SenseInfo('01736122-a', 1), SenseInfo('00754107-a', 0), SenseInfo('01736122-a', 1), SenseInfo('00754107-a', 0) ],
"_receptor_n_1_rel" : [ SenseInfo('05608868-n', 0), SenseInfo('05299178-n', 0) ],
"_headline_v_1_rel" : [ SenseInfo('00976224-v', 1), SenseInfo('02332445-v', 0), SenseInfo('00976224-v', 1), SenseInfo('02332445-v', 0) ],
"_flumenophobe_n_1_rel" : [  ],
"_coverage_n_of_rel" : [ SenseInfo('13344664-n', 1), SenseInfo('05123760-n', 1), SenseInfo('06683784-n', 0) ],
"_after_p_sel_rel" : [ SenseInfo('00061203-r', 5), SenseInfo('00508070-r', 0), SenseInfo('01033542-a', 0) ],
"_bound_v_1_rel" : [ SenseInfo('01963942-v', 4), SenseInfo('02710673-v', 2), SenseInfo('00233335-v', 2), SenseInfo('01892104-v', 1), SenseInfo('01963942-v', 4), SenseInfo('02710673-v', 2), SenseInfo('00233335-v', 2), SenseInfo('01892104-v', 1) ],
"_demand_v_from_rel" : [ SenseInfo('00754942-v', 47), SenseInfo('02627934-v', 22), SenseInfo('01017826-v', 7), SenseInfo('01069090-v', 0), SenseInfo('01068985-v', 0), SenseInfo('01018065-v', 0) ],
"_color-code_v_1_rel" : [  ],
"_plan_v_for_rel" : [ SenseInfo('00705227-v', 44), SenseInfo('00704690-v', 27), SenseInfo('01638368-v', 17), SenseInfo('01639714-v', 2) ],
"_aeronautical_a_1_rel" : [ SenseInfo('02607298-a', 0) ],
"_bankrupt_v_1_rel" : [ SenseInfo('02318165-v', 1) ],
"_enrage_v_1_rel" : [ SenseInfo('01795888-v', 1) ],
"_plaintive_a_1_rel" : [ SenseInfo('01366157-a', 0) ],
"_mask_n_1_rel" : [ SenseInfo('03724870-n', 1), SenseInfo('01049475-n', 1), SenseInfo('08253450-n', 0), SenseInfo('03725035-n', 0) ],
"_unsatisfactory_a_for_rel" : [ SenseInfo('02082218-a', 6), SenseInfo('02082218-a', 6), SenseInfo('02082218-a', 6), SenseInfo('02082218-a', 6), SenseInfo('02082218-a', 6), SenseInfo('02082218-a', 6), SenseInfo('02082218-a', 6) ],
"_wheeze_v_1_rel" : [ SenseInfo('00006697-v', 2), SenseInfo('00006697-v', 2) ],
"_hit-or-miss_a_1_rel" : [ SenseInfo('01924803-a', 0), SenseInfo('01924803-a', 0), SenseInfo('01924803-a', 0) ],
"_implicate_v_in_rel" : [ SenseInfo('02677332-v', 0), SenseInfo('02634808-v', 0), SenseInfo('02677332-v', 0), SenseInfo('02634808-v', 0) ],
"_flume_n_1_rel" : [ SenseInfo('09295946-n', 0), SenseInfo('03369866-n', 0) ],
"_traditional_a_1_rel" : [ SenseInfo('00611047-a', 23), SenseInfo('01690767-a', 3), SenseInfo('00611047-a', 23), SenseInfo('01690767-a', 3) ],
"_ultraviolet_a_1_rel" : [ SenseInfo('02518601-a', 2), SenseInfo('02518601-a', 2) ],
"_quieten_v_down_rel" : [ SenseInfo('02190188-v', 0), SenseInfo('01764800-v', 0), SenseInfo('00461493-v', 0), SenseInfo('02190188-v', 0), SenseInfo('01764800-v', 0), SenseInfo('00461493-v', 0) ],
"_sanitation_n_1_rel" : [ SenseInfo('14495466-n', 1), SenseInfo('00254415-n', 1) ],
"_gallus_n_1_rel" : [ SenseInfo('02887489-n', 1), SenseInfo('01790943-n', 0) ],
"_gaze_n_1_rel" : [ SenseInfo('00878648-n', 8) ],
"_swoon_v_1_rel" : [ SenseInfo('00023646-v', 1), SenseInfo('00023646-v', 1) ],
"_provisional_a_1_rel" : [ SenseInfo('00556318-a', 3) ],
"_monkish_a_1_rel" : [ SenseInfo('01300961-a', 1) ],
"_variant_n_1_rel" : [ SenseInfo('07366627-n', 1), SenseInfo('08111157-n', 0), SenseInfo('05864177-n', 0), SenseInfo('05840650-n', 0) ],
"_overthrow_v_1_rel" : [ SenseInfo('02402409-v', 4), SenseInfo('00716130-v', 0), SenseInfo('02402409-v', 4), SenseInfo('00716130-v', 0) ],
"_uneconomical_a_for_rel" : [ SenseInfo('00841159-a', 2), SenseInfo('02422592-a', 0), SenseInfo('00841159-a', 2), SenseInfo('02422592-a', 0), SenseInfo('00841159-a', 2), SenseInfo('02422592-a', 0), SenseInfo('00841159-a', 2), SenseInfo('02422592-a', 0) ],
"_jungle_n_1_rel" : [ SenseInfo('08509111-n', 0), SenseInfo('08478171-n', 0), SenseInfo('08439022-n', 0) ],
"_enfant+terrible_n_1_rel" : [ SenseInfo('10057595-n', 1) ],
"_slacken_v_off_rel" : [ SenseInfo('00440580-v', 4), SenseInfo('00441212-v', 1), SenseInfo('00421408-v', 0), SenseInfo('00421125-v', 0) ],
"_abdominal_a_1_rel" : [ SenseInfo('02934594-a', 3) ],
"_all+year+round_a_1_rel" : [  ],
"_brand+new_a_1_rel" : [ SenseInfo('01641460-a', 0), SenseInfo('01641460-a', 0) ],
"_depress_v_1_rel" : [ SenseInfo('01814396-v', 3), SenseInfo('01973932-v', 1), SenseInfo('01574923-v', 0), SenseInfo('01574766-v', 0), SenseInfo('00225438-v', 0), SenseInfo('01814396-v', 3), SenseInfo('01973932-v', 1), SenseInfo('01574923-v', 0), SenseInfo('01574766-v', 0), SenseInfo('00225438-v', 0), SenseInfo('01814396-v', 3), SenseInfo('01973932-v', 1), SenseInfo('01574923-v', 0), SenseInfo('01574766-v', 0), SenseInfo('00225438-v', 0), SenseInfo('01814396-v', 3), SenseInfo('01973932-v', 1), SenseInfo('01574923-v', 0), SenseInfo('01574766-v', 0), SenseInfo('00225438-v', 0), SenseInfo('01814396-v', 3), SenseInfo('01973932-v', 1), SenseInfo('01574923-v', 0), SenseInfo('01574766-v', 0), SenseInfo('00225438-v', 0) ],
"_for+the+most+part_a_1_rel" : [  ],
"_sensor_n_of_rel" : [ SenseInfo('03180969-n', 7) ],
"_tiger_n_1_rel" : [ SenseInfo('10710632-n', 1), SenseInfo('02129604-n', 1) ],
"_pearl_n_1_rel" : [ SenseInfo('13372403-n', 1), SenseInfo('04961331-n', 1), SenseInfo('13901585-n', 0) ],
"_undecomposed_a_1_rel" : [ SenseInfo('01068306-a', 0), SenseInfo('01068306-a', 0) ],
"_grouse_v_1_rel" : [ SenseInfo('01143028-v', 0), SenseInfo('00910973-v', 0), SenseInfo('01143028-v', 0), SenseInfo('00910973-v', 0) ],
"_bring_v_together_rel" : [ SenseInfo('02077656-v', 122), SenseInfo('01438902-v', 55), SenseInfo('01629589-v', 31), SenseInfo('01433294-v', 19), SenseInfo('00135857-v', 9), SenseInfo('01434140-v', 4), SenseInfo('01618547-v', 3), SenseInfo('02324478-v', 2), SenseInfo('02247390-v', 1), SenseInfo('01808218-v', 0), SenseInfo('00767334-v', 0) ],
"_aspiration_n_1_rel" : [ SenseInfo('04836491-n', 2), SenseInfo('07484547-n', 0), SenseInfo('07116869-n', 0), SenseInfo('00836788-n', 0), SenseInfo('04836491-n', 2), SenseInfo('07484547-n', 0), SenseInfo('07116869-n', 0), SenseInfo('00836788-n', 0), SenseInfo('04836491-n', 2), SenseInfo('07484547-n', 0), SenseInfo('07116869-n', 0), SenseInfo('00836788-n', 0) ],
"_belt_n_1_rel" : [ SenseInfo('02827883-n', 4), SenseInfo('02827606-n', 4), SenseInfo('08509786-n', 2), SenseInfo('07410207-n', 1), SenseInfo('09452653-n', 0), SenseInfo('02828115-n', 0), SenseInfo('00133338-n', 0) ],
"_diversification_n_1_rel" : [ SenseInfo('00195569-n', 1), SenseInfo('14575180-n', 0) ],
"_phoenician_n_1_rel" : [ SenseInfo('09640859-n', 0), SenseInfo('06989473-n', 0), SenseInfo('09640859-n', 0), SenseInfo('06989473-n', 0) ],
"_cuttings_n_1_rel" : [ SenseInfo('00945205-n', 2), SenseInfo('13127473-n', 1), SenseInfo('00386915-n', 1), SenseInfo('09262371-n', 0), SenseInfo('06612649-n', 0), SenseInfo('00942234-n', 0), SenseInfo('00489475-n', 0), SenseInfo('00387657-n', 0), SenseInfo('00363052-n', 0), SenseInfo('00359238-n', 0), SenseInfo('00945205-n', 2), SenseInfo('13127473-n', 1), SenseInfo('00386915-n', 1), SenseInfo('09262371-n', 0), SenseInfo('06612649-n', 0), SenseInfo('00942234-n', 0), SenseInfo('00489475-n', 0), SenseInfo('00387657-n', 0), SenseInfo('00363052-n', 0), SenseInfo('00359238-n', 0) ],
"_walk-off_a_1_rel" : [  ],
"_mop_v_1_rel" : [ SenseInfo('01393339-v', 2), SenseInfo('00034758-v', 0), SenseInfo('01393339-v', 2), SenseInfo('00034758-v', 0) ],
"_sabbath_n_1_rel" : [ SenseInfo('15164750-n', 1) ],
"_triumph_n_1_rel" : [ SenseInfo('07473441-n', 6), SenseInfo('07528097-n', 5) ],
"_sharpness_n_1_rel" : [ SenseInfo('05620468-n', 1), SenseInfo('05171978-n', 0), SenseInfo('04992834-n', 0), SenseInfo('04720226-n', 0), SenseInfo('04705324-n', 0), SenseInfo('04702688-n', 0), SenseInfo('04643099-n', 0) ],
"_tourist_n_1_rel" : [ SenseInfo('10718131-n', 3) ],
"_headquarter_v_1_rel" : [ SenseInfo('02366884-v', 0), SenseInfo('02366884-v', 0), SenseInfo('02366884-v', 0) ],
"_by_p_sel_rel" : [ SenseInfo('00417787-r', 2), SenseInfo('00233687-r', 0) ],
"_sop_n_1_rel" : [ SenseInfo('07861421-n', 0), SenseInfo('07216615-n', 0), SenseInfo('01024968-n', 0) ],
"_unsympathetic_a_1_rel" : [ SenseInfo('02375828-a', 2), SenseInfo('02376562-a', 0), SenseInfo('01986349-a', 0), SenseInfo('01374461-a', 0), SenseInfo('00561359-a', 0), SenseInfo('02375828-a', 2), SenseInfo('02376562-a', 0), SenseInfo('01986349-a', 0), SenseInfo('01374461-a', 0), SenseInfo('00561359-a', 0) ],
"_helium_n_1_rel" : [ SenseInfo('14639921-n', 15) ],
"_final_n_1_rel" : [ SenseInfo('07466832-n', 0), SenseInfo('07198276-n', 0) ],
"_sheltered_a_1_rel" : [ SenseInfo('02526611-a', 0) ],
"_executable_a_1_rel" : [ SenseInfo('01822563-a', 0) ],
"_giro_n_1_rel" : [ SenseInfo('13382766-n', 0), SenseInfo('08055321-n', 0) ],
"_chair_v_1_rel" : [ SenseInfo('02440020-v', 0), SenseInfo('00813790-v', 0) ],
"_heat_v_up-cause_rel" : [ SenseInfo('00371264-v', 11), SenseInfo('02333358-v', 0), SenseInfo('01761120-v', 0), SenseInfo('00372665-v', 0) ],
"_very_a_1_rel" : [ SenseInfo('01839317-a', 19), SenseInfo('02068946-a', 14) ],
"_admire_v_1_rel" : [ SenseInfo('01827858-v', 13), SenseInfo('02164694-v', 8), SenseInfo('01827858-v', 13), SenseInfo('02164694-v', 8), SenseInfo('01827858-v', 13), SenseInfo('02164694-v', 8) ],
"_ahead_p_rel" : [ SenseInfo('00066781-r', 21), SenseInfo('00075442-r', 5), SenseInfo('00067265-r', 5), SenseInfo('00067045-r', 1), SenseInfo('02490631-a', 1), SenseInfo('00068070-r', 0), SenseInfo('00067823-r', 0), SenseInfo('00067513-r', 0) ],
"_tune_v_up_rel" : [ SenseInfo('00295966-v', 1), SenseInfo('00295346-v', 0), SenseInfo('00295966-v', 1), SenseInfo('00295346-v', 0) ],
"_fusion_n_1_rel" : [ SenseInfo('07373602-n', 4), SenseInfo('14418662-n', 0), SenseInfo('13485767-n', 0), SenseInfo('13485525-n', 0), SenseInfo('05936561-n', 0), SenseInfo('00699517-n', 0), SenseInfo('00380568-n', 0) ],
"_impossibly_x_rel" : [ SenseInfo('00300682-r', 0) ],
"_gapt_n_1_rel" : [  ],
"_bluff_n_1_rel" : [ SenseInfo('09224725-n', 5), SenseInfo('06759602-n', 2), SenseInfo('00756598-n', 0) ],
"_inside_p_rel" : [ SenseInfo('00110533-r', 19), SenseInfo('00110815-r', 14), SenseInfo('08588294-n', 4), SenseInfo('08588152-n', 4), SenseInfo('01693799-a', 2), SenseInfo('00953213-a', 1), SenseInfo('00230189-r', 0), SenseInfo('00104099-r', 0), SenseInfo('01863066-a', 0), SenseInfo('00950592-a', 0), SenseInfo('00110533-r', 19), SenseInfo('00110815-r', 14), SenseInfo('08588294-n', 4), SenseInfo('08588152-n', 4), SenseInfo('01693799-a', 2), SenseInfo('00953213-a', 1), SenseInfo('00230189-r', 0), SenseInfo('00104099-r', 0), SenseInfo('01863066-a', 0), SenseInfo('00950592-a', 0) ],
"_releaser_n_1_rel" : [  ],
"_signification_n_1_rel" : [ SenseInfo('06601327-n', 0) ],
"_hyper_a_1_rel" : [  ],
"_hawk_n_1_rel" : [ SenseInfo('01605630-n', 2), SenseInfo('10162644-n', 0), SenseInfo('03787164-n', 0) ],
"_research_n_1_rel" : [ SenseInfo('00636921-n', 46), SenseInfo('05797597-n', 6), SenseInfo('00636921-n', 46), SenseInfo('05797597-n', 6), SenseInfo('00636921-n', 46), SenseInfo('05797597-n', 6), SenseInfo('00636921-n', 46), SenseInfo('05797597-n', 6) ],
"_spy_n_1_rel" : [ SenseInfo('10641755-n', 3), SenseInfo('10642151-n', 0) ],
"_vine_n_1_rel" : [ SenseInfo('13100677-n', 7) ],
"_governance_n_1_rel" : [ SenseInfo('08164585-n', 0), SenseInfo('01124794-n', 0) ],
"_soak_v_off_rel" : [ SenseInfo('01578513-v', 4), SenseInfo('02319050-v', 1), SenseInfo('00216216-v', 1), SenseInfo('02347220-v', 0), SenseInfo('01397870-v', 0), SenseInfo('01190494-v', 0), SenseInfo('01190277-v', 0), SenseInfo('00456151-v', 0), SenseInfo('00372157-v', 0) ],
"_thirsty_a_1_rel" : [ SenseInfo('02554140-a', 1), SenseInfo('01270004-a', 0), SenseInfo('00888200-a', 0), SenseInfo('00007697-a', 0), SenseInfo('02554140-a', 1), SenseInfo('01270004-a', 0), SenseInfo('00888200-a', 0), SenseInfo('00007697-a', 0), SenseInfo('02554140-a', 1), SenseInfo('01270004-a', 0), SenseInfo('00888200-a', 0), SenseInfo('00007697-a', 0) ],
"_exaggerate_v_1_rel" : [ SenseInfo('00839834-v', 14), SenseInfo('02568999-v', 2) ],
"_24-hour-a-day_a_1_rel" : [  ],
"_subserve_v_1_rel" : [ SenseInfo('02548588-v', 0) ],
"_brake_n_1_rel" : [ SenseInfo('02889425-n', 2), SenseInfo('13214031-n', 0), SenseInfo('13189844-n', 0), SenseInfo('08437721-n', 0), SenseInfo('02889646-n', 0) ],
"_plump_a_1_rel" : [ SenseInfo('00986766-a', 2), SenseInfo('00986766-a', 2), SenseInfo('00986766-a', 2) ],
"_rust_v_1_rel" : [ SenseInfo('00273963-v', 2), SenseInfo('00274283-v', 0), SenseInfo('00239614-v', 0) ],
"_organism_n_1_rel" : [ SenseInfo('00004475-n', 9), SenseInfo('08436036-n', 0) ],
"_axiom_n_of_rel" : [ SenseInfo('07152948-n', 1), SenseInfo('06753550-n', 0), SenseInfo('07152948-n', 1), SenseInfo('06753550-n', 0) ],
"_infant_n_1_rel" : [ SenseInfo('09827683-n', 3) ],
"_lengthen_v_cause_rel" : [ SenseInfo('00317700-v', 1), SenseInfo('00316631-v', 0) ],
"_whitewash_n_1_rel" : [ SenseInfo('07476952-n', 0), SenseInfo('04581102-n', 0), SenseInfo('01241594-n', 0) ],
"_clique_n_1_rel" : [ SenseInfo('08240633-n', 1) ],
"_take-out_n_1_rel" : [ SenseInfo('07594511-n', 0), SenseInfo('06737628-n', 0), SenseInfo('07594511-n', 0), SenseInfo('06737628-n', 0), SenseInfo('07594511-n', 0), SenseInfo('06737628-n', 0) ],
"_renmimbi_n_1_rel" : [  ],
"_bored_a_1_rel" : [ SenseInfo('02432682-a', 1), SenseInfo('01343200-a', 1) ],
"_feminist_n_1_rel" : [ SenseInfo('10084635-n', 0) ],
"_maroon_a_1_rel" : [ SenseInfo('00377702-a', 1) ],
"_follow+on_n_1_rel" : [ SenseInfo('00457038-n', 0), SenseInfo('00457038-n', 0) ],
"_x_q_rel" : [  ],
"_some+more_a_1_rel" : [  ],
"_thrice_a_1_rel" : [  ],
"_smarty-pants_n_1_rel" : [  ],
"_consciousness_n_1_rel" : [ SenseInfo('05675130-n', 20), SenseInfo('05675905-n', 1) ],
"_toss_v_down_rel" : [ SenseInfo('01512625-v', 13), SenseInfo('01893079-v', 10), SenseInfo('01514525-v', 5), SenseInfo('01890792-v', 4), SenseInfo('02222318-v', 1), SenseInfo('01418536-v', 1) ],
"_pantry_n_1_rel" : [ SenseInfo('03885535-n', 1) ],
"_diesel_n_1_rel" : [ SenseInfo('10935128-n', 0), SenseInfo('03193107-n', 0) ],
"_social_a_1_rel" : [ SenseInfo('02798370-a', 81), SenseInfo('02248349-a', 7), SenseInfo('02798597-a', 2), SenseInfo('02258360-a', 2), SenseInfo('02252877-a', 0), SenseInfo('01076634-a', 0), SenseInfo('02798370-a', 81), SenseInfo('02248349-a', 7), SenseInfo('02798597-a', 2), SenseInfo('02258360-a', 2), SenseInfo('02252877-a', 0), SenseInfo('01076634-a', 0) ],
"_jurisprudence_n_1_rel" : [ SenseInfo('06161718-n', 2), SenseInfo('08441203-n', 0) ],
"_speak_v_of_rel" : [ SenseInfo('00941990-v', 86), SenseInfo('00962447-v', 53), SenseInfo('00963570-v', 23), SenseInfo('00989201-v', 11), SenseInfo('02135607-v', 3) ],
"_payable_a_to_rel" : [ SenseInfo('00136884-a', 2) ],
"_squid_n_1_rel" : [ SenseInfo('07781801-n', 0), SenseInfo('01971280-n', 0) ],
"_easier_a_for_rel" : [  ],
"_dependence_n_on_rel" : [ SenseInfo('14001348-n', 6), SenseInfo('14062725-n', 0) ],
"_bomber_n_1_rel" : [ SenseInfo('02867715-n', 9), SenseInfo('09864536-n', 0), SenseInfo('07697825-n', 0) ],
"_buzz_v_1_rel" : [ SenseInfo('02182109-v', 4), SenseInfo('01924267-v', 3), SenseInfo('02706605-v', 2), SenseInfo('00792304-v', 0) ],
"_constable_n_1_rel" : [ SenseInfo('09959142-n', 1), SenseInfo('10907851-n', 0), SenseInfo('09959258-n', 0) ],
"_at_p_rel" : [ SenseInfo('14629561-n', 0), SenseInfo('13681048-n', 0) ],
"_augment_v_1_rel" : [ SenseInfo('00154388-v', 8), SenseInfo('00157950-v', 1), SenseInfo('00154388-v', 8), SenseInfo('00157950-v', 1) ],
"_ordinary_a_1_rel" : [ SenseInfo('01672607-a', 28), SenseInfo('00486290-a', 4), SenseInfo('01672607-a', 28), SenseInfo('00486290-a', 4) ],
"_checklist_n_1_rel" : [ SenseInfo('06489070-n', 5) ],
"_cracker_n_of_rel" : [ SenseInfo('07681926-n', 1), SenseInfo('10513938-n', 0), SenseInfo('09974278-n', 0), SenseInfo('03345115-n', 0), SenseInfo('03125352-n', 0) ],
"_paraffin_n_1_rel" : [ SenseInfo('15095237-n', 0), SenseInfo('14951377-n', 0), SenseInfo('14926086-n', 0) ],
"_well-to-do_a_1_rel" : [ SenseInfo('02022556-a', 0), SenseInfo('02022556-a', 0), SenseInfo('02022556-a', 0), SenseInfo('02022556-a', 0) ],
"_root_v_for_rel" : [ SenseInfo('00358135-v', 2), SenseInfo('02623731-v', 0), SenseInfo('01529194-v', 0), SenseInfo('01282413-v', 0), SenseInfo('00415398-v', 0), SenseInfo('00358314-v', 0) ],
"_directional_a_1_rel" : [ SenseInfo('02713974-a', 1), SenseInfo('02714263-a', 0), SenseInfo('00199114-a', 0) ],
"_obedient_a_1_rel" : [ SenseInfo('01612053-a', 3) ],
"_circa_p_rel" : [  ],
"_done_a_1_rel" : [ SenseInfo('01003536-a', 7), SenseInfo('00617344-a', 0) ],
"_foliage_n_1_rel" : [ SenseInfo('13152742-n', 6), SenseInfo('03377077-n', 1) ],
"_obsession_n_1_rel" : [ SenseInfo('09183255-n', 0), SenseInfo('05700401-n', 0) ],
"_site_n_1_rel" : [ SenseInfo('08651247-n', 51), SenseInfo('08622950-n', 1), SenseInfo('06359193-n', 0) ],
"_conservative_a_1_rel" : [ SenseInfo('00574422-a', 11), SenseInfo('02030312-a', 1), SenseInfo('01532149-a', 1), SenseInfo('00607656-a', 0), SenseInfo('00260780-a', 0) ],
"_collaborator_n_1_rel" : [ SenseInfo('09953483-n', 1), SenseInfo('09935793-n', 0), SenseInfo('09935434-n', 0) ],
"_chilean_n_1_rel" : [ SenseInfo('09697986-n', 0) ],
"_grit_v_1_rel" : [ SenseInfo('01394938-v', 0), SenseInfo('01394715-v', 0) ],
"_fish_v_1_rel" : [ SenseInfo('01319346-v', 2), SenseInfo('01140794-v', 1) ],
"_french_a_1_rel" : [ SenseInfo('02958392-a', 9) ],
"_combine_v_1_rel" : [ SenseInfo('02631163-v', 14), SenseInfo('00193486-v', 12), SenseInfo('01461328-v', 5), SenseInfo('02309008-v', 4), SenseInfo('02377938-v', 2), SenseInfo('01385170-v', 1), SenseInfo('00394813-v', 1) ],
"_bill_n_of_rel" : [ SenseInfo('06536853-n', 22), SenseInfo('06516955-n', 6), SenseInfo('13393762-n', 4), SenseInfo('00551407-n', 1), SenseInfo('07250339-n', 0), SenseInfo('06793426-n', 0), SenseInfo('06486874-n', 0), SenseInfo('02838958-n', 0), SenseInfo('02838728-n', 0), SenseInfo('01758308-n', 0), SenseInfo('06536853-n', 22), SenseInfo('06516955-n', 6), SenseInfo('13393762-n', 4), SenseInfo('00551407-n', 1), SenseInfo('07250339-n', 0), SenseInfo('06793426-n', 0), SenseInfo('06486874-n', 0), SenseInfo('02838958-n', 0), SenseInfo('02838728-n', 0), SenseInfo('01758308-n', 0), SenseInfo('06536853-n', 22), SenseInfo('06516955-n', 6), SenseInfo('13393762-n', 4), SenseInfo('00551407-n', 1), SenseInfo('07250339-n', 0), SenseInfo('06793426-n', 0), SenseInfo('06486874-n', 0), SenseInfo('02838958-n', 0), SenseInfo('02838728-n', 0), SenseInfo('01758308-n', 0) ],
"_doll_n_1_rel" : [ SenseInfo('03219135-n', 1), SenseInfo('09989045-n', 0) ],
"_infection_n_1_rel" : [ SenseInfo('14174549-n', 9), SenseInfo('13498666-n', 0), SenseInfo('13498404-n', 0), SenseInfo('07360647-n', 0), SenseInfo('06282383-n', 0), SenseInfo('04851421-n', 0), SenseInfo('04811296-n', 0) ],
"_figure_v_in_rel" : [ SenseInfo('00712135-v', 20), SenseInfo('02722207-v', 8), SenseInfo('01635432-v', 3), SenseInfo('00637259-v', 2), SenseInfo('00590241-v', 1), SenseInfo('00712135-v', 20), SenseInfo('02722207-v', 8), SenseInfo('01635432-v', 3), SenseInfo('00637259-v', 2), SenseInfo('00590241-v', 1) ],
"_optimistic_a_1_rel" : [ SenseInfo('01663571-a', 2), SenseInfo('01817908-a', 0), SenseInfo('01663571-a', 2), SenseInfo('01817908-a', 0), SenseInfo('01663571-a', 2), SenseInfo('01817908-a', 0) ],
"_tinge_v_with_rel" : [ SenseInfo('00836926-v', 0), SenseInfo('00286928-v', 0), SenseInfo('00836926-v', 0), SenseInfo('00286928-v', 0) ],
"_hazy_a_1_rel" : [ SenseInfo('00461609-a', 1), SenseInfo('00781644-a', 0), SenseInfo('00461609-a', 1), SenseInfo('00781644-a', 0), SenseInfo('00461609-a', 1), SenseInfo('00781644-a', 0) ],
"_ski_n_1_rel" : [ SenseInfo('04228054-n', 0) ],
"_dollar_n_1_rel" : [ SenseInfo('13661273-n', 23), SenseInfo('13395897-n', 11), SenseInfo('13391967-n', 0), SenseInfo('06821581-n', 0), SenseInfo('13661273-n', 23), SenseInfo('13395897-n', 11), SenseInfo('13391967-n', 0), SenseInfo('06821581-n', 0), SenseInfo('13661273-n', 23), SenseInfo('13395897-n', 11), SenseInfo('13391967-n', 0), SenseInfo('06821581-n', 0) ],
"_soundproof_v_1_rel" : [ SenseInfo('00495505-v', 0) ],
"_beaded_a_1_rel" : [ SenseInfo('01695160-a', 1) ],
"_imagery_n_1_rel" : [ SenseInfo('05767733-n', 4) ],
"_gather_v_up_rel" : [ SenseInfo('01380638-v', 23), SenseInfo('02428924-v', 7), SenseInfo('00158804-v', 3), SenseInfo('00945125-v', 2), SenseInfo('01330822-v', 1), SenseInfo('02598143-v', 0), SenseInfo('01349893-v', 0), SenseInfo('01316619-v', 0), SenseInfo('00157462-v', 0) ],
"_gifted_a_1_rel" : [ SenseInfo('01119192-a', 0) ],
"_vent_v_cause_rel" : [ SenseInfo('00944548-v', 3), SenseInfo('00488770-v', 0) ],
"_sprain_n_1_rel" : [ SenseInfo('14299336-n', 0) ],
"_recognition_n_of_rel" : [ SenseInfo('14411981-n', 10), SenseInfo('05762998-n', 8), SenseInfo('06688274-n', 1), SenseInfo('05807540-n', 1), SenseInfo('11502695-n', 0), SenseInfo('07149107-n', 0), SenseInfo('06194216-n', 0), SenseInfo('00165563-n', 0), SenseInfo('14411981-n', 10), SenseInfo('05762998-n', 8), SenseInfo('06688274-n', 1), SenseInfo('05807540-n', 1), SenseInfo('11502695-n', 0), SenseInfo('07149107-n', 0), SenseInfo('06194216-n', 0), SenseInfo('00165563-n', 0) ],
"_coach_n_1_rel" : [ SenseInfo('09931640-n', 20), SenseInfo('09931418-n', 0), SenseInfo('03895866-n', 0), SenseInfo('03055670-n', 0), SenseInfo('02924116-n', 0) ],
"_now_a_1_rel" : [ SenseInfo('15119919-n', 10), SenseInfo('15119919-n', 10) ],
"_stove_n_1_rel" : [ SenseInfo('04330340-n', 5), SenseInfo('04330267-n', 1) ],
"_cultivation_n_of_rel" : [ SenseInfo('01129363-n', 1), SenseInfo('00915722-n', 1), SenseInfo('14459824-n', 0), SenseInfo('13454318-n', 0), SenseInfo('00916023-n', 0) ],
"_like+manner_n_1_rel" : [  ],
"_reschedulable_a_1_rel" : [  ],
"_irish_n_1_rel" : [ SenseInfo('09732778-n', 2), SenseInfo('07907161-n', 0), SenseInfo('06960778-n', 0), SenseInfo('09732778-n', 2), SenseInfo('07907161-n', 0), SenseInfo('06960778-n', 0), SenseInfo('09732778-n', 2), SenseInfo('07907161-n', 0), SenseInfo('06960778-n', 0) ],
"_numerousness_n_1_rel" : [ SenseInfo('05121908-n', 0) ],
"_meow_n_1_rel" : [ SenseInfo('07386614-n', 0) ],
"_tiredness_n_1_rel" : [ SenseInfo('14016361-n', 0) ],
"_test+drive_v_1_rel" : [ SenseInfo('01931375-v', 0), SenseInfo('01931375-v', 0) ],
"_first+person_n_1_rel" : [ SenseInfo('06327718-n', 0), SenseInfo('06327718-n', 0) ],
"_model_n_of_rel" : [ SenseInfo('05890249-n', 19), SenseInfo('05845652-n', 11), SenseInfo('10324560-n', 6), SenseInfo('03777283-n', 4), SenseInfo('05925366-n', 3), SenseInfo('10324851-n', 1), SenseInfo('05937112-n', 1), SenseInfo('10291240-n', 0), SenseInfo('00898804-n', 0), SenseInfo('05890249-n', 19), SenseInfo('05845652-n', 11), SenseInfo('10324560-n', 6), SenseInfo('03777283-n', 4), SenseInfo('05925366-n', 3), SenseInfo('10324851-n', 1), SenseInfo('05937112-n', 1), SenseInfo('10291240-n', 0), SenseInfo('00898804-n', 0) ],
"_want_v_1_rel" : [ SenseInfo('01825237-v', 389), SenseInfo('01188725-v', 15), SenseInfo('01317064-v', 3), SenseInfo('00709205-v', 2), SenseInfo('02632567-v', 0), SenseInfo('01825237-v', 389), SenseInfo('01188725-v', 15), SenseInfo('01317064-v', 3), SenseInfo('00709205-v', 2), SenseInfo('02632567-v', 0), SenseInfo('01825237-v', 389), SenseInfo('01188725-v', 15), SenseInfo('01317064-v', 3), SenseInfo('00709205-v', 2), SenseInfo('02632567-v', 0), SenseInfo('01825237-v', 389), SenseInfo('01188725-v', 15), SenseInfo('01317064-v', 3), SenseInfo('00709205-v', 2), SenseInfo('02632567-v', 0), SenseInfo('01825237-v', 389), SenseInfo('01188725-v', 15), SenseInfo('01317064-v', 3), SenseInfo('00709205-v', 2), SenseInfo('02632567-v', 0), SenseInfo('01825237-v', 389), SenseInfo('01188725-v', 15), SenseInfo('01317064-v', 3), SenseInfo('00709205-v', 2), SenseInfo('02632567-v', 0), SenseInfo('01825237-v', 389), SenseInfo('01188725-v', 15), SenseInfo('01317064-v', 3), SenseInfo('00709205-v', 2), SenseInfo('02632567-v', 0) ],
"_get_v_out_rel" : [ SenseInfo('02210855-v', 235), SenseInfo('00149583-v', 157), SenseInfo('00120796-v', 82), SenseInfo('00522751-v', 64), SenseInfo('02005948-v', 58), SenseInfo('01433294-v', 45), SenseInfo('02108026-v', 36), SenseInfo('01153947-v', 14), SenseInfo('02355596-v', 9), SenseInfo('00770437-v', 7), SenseInfo('01215421-v', 4), SenseInfo('00094460-v', 4), SenseInfo('00087736-v', 4), SenseInfo('01066036-v', 3), SenseInfo('00120316-v', 3), SenseInfo('01026975-v', 2), SenseInfo('00589904-v', 2), SenseInfo('01505958-v', 1), SenseInfo('01401115-v', 1), SenseInfo('00639849-v', 1), SenseInfo('02359340-v', 0), SenseInfo('02208265-v', 0), SenseInfo('02189398-v', 0), SenseInfo('02109645-v', 0), SenseInfo('02108654-v', 0), SenseInfo('02010864-v', 0), SenseInfo('02006573-v', 0), SenseInfo('01771194-v', 0), SenseInfo('01771039-v', 0), SenseInfo('01738107-v', 0), SenseInfo('01643297-v', 0), SenseInfo('01565211-v', 0), SenseInfo('00622384-v', 0), SenseInfo('00345761-v', 0), SenseInfo('00065639-v', 0), SenseInfo('00054628-v', 0) ],
"_sidereal_a_1_rel" : [ SenseInfo('02797408-a', 0), SenseInfo('00643116-a', 0) ],
"_homology_n_1_rel" : [ SenseInfo('04744319-n', 0) ],
"_pop_v_down_rel" : [ SenseInfo('02081946-v', 3), SenseInfo('01404913-v', 3), SenseInfo('02185988-v', 1), SenseInfo('01134071-v', 1), SenseInfo('02186192-v', 0), SenseInfo('02157519-v', 0), SenseInfo('01499510-v', 0), SenseInfo('01474980-v', 0), SenseInfo('01401005-v', 0), SenseInfo('01202374-v', 0), SenseInfo('01199487-v', 0), SenseInfo('00309792-v', 0), SenseInfo('00309582-v', 0) ],
"_end_v_1_rel" : [ SenseInfo('02609764-v', 53), SenseInfo('00352826-v', 29), SenseInfo('02735418-v', 10), SenseInfo('01620854-v', 0) ],
"_ethics_n_1_rel" : [ SenseInfo('05956019-n', 2), SenseInfo('06663617-n', 0) ],
"_read_v_of_rel" : [ SenseInfo('00625119-v', 115), SenseInfo('02730813-v', 17), SenseInfo('00626428-v', 15), SenseInfo('00627520-v', 5), SenseInfo('00627091-v', 5), SenseInfo('00624476-v', 5), SenseInfo('00599992-v', 4), SenseInfo('00922867-v', 3), SenseInfo('01718755-v', 0), SenseInfo('00620239-v', 0), SenseInfo('00593852-v', 0) ],
"_ride_v_in_rel" : [ SenseInfo('01957529-v', 53), SenseInfo('01955984-v', 30), SenseInfo('02684644-v', 2), SenseInfo('01839538-v', 2), SenseInfo('00850501-v', 1), SenseInfo('02750154-v', 0), SenseInfo('02742232-v', 0), SenseInfo('02711987-v', 0), SenseInfo('02692089-v', 0), SenseInfo('02102398-v', 0), SenseInfo('02095545-v', 0), SenseInfo('01847676-v', 0), SenseInfo('01511134-v', 0), SenseInfo('01429322-v', 0) ],
"_rake_n_1_rel" : [ SenseInfo('10505942-n', 0), SenseInfo('05069199-n', 0), SenseInfo('04050066-n', 0) ],
"_runic_a_1_rel" : [ SenseInfo('02938236-a', 0) ],
"_definite_a_1_rel" : [ SenseInfo('00700451-a', 13), SenseInfo('00335768-a', 1), SenseInfo('00700451-a', 13), SenseInfo('00335768-a', 1), SenseInfo('00700451-a', 13), SenseInfo('00335768-a', 1), SenseInfo('00700451-a', 13), SenseInfo('00335768-a', 1) ],
"_graver_n_1_rel" : [ SenseInfo('03455355-n', 0) ],
"_disquieting_a_1_rel" : [ SenseInfo('00480753-a', 0) ],
"_whenever_x_subord_rel" : [  ],
"_resistant_a_1_rel" : [ SenseInfo('02363614-a', 1), SenseInfo('02435383-a', 0), SenseInfo('01774869-a', 0), SenseInfo('00695938-a', 0), SenseInfo('00007990-a', 0) ],
"_enlarge_v_1_rel" : [ SenseInfo('00154778-v', 7), SenseInfo('00240293-v', 2), SenseInfo('00157844-v', 2), SenseInfo('00955601-v', 1) ],
"_ban_n_1_rel" : [ SenseInfo('06542047-n', 1), SenseInfo('13702315-n', 0), SenseInfo('13685578-n', 0), SenseInfo('07255401-n', 0), SenseInfo('06698902-n', 0) ],
"_crimson_a_1_rel" : [ SenseInfo('00381097-a', 7), SenseInfo('00248560-a', 5), SenseInfo('00395626-a', 0) ],
"_fling_v_open_rel" : [ SenseInfo('01512465-v', 13), SenseInfo('02094428-v', 1), SenseInfo('02269003-v', 0), SenseInfo('02222318-v', 0) ],
"_gagwriter_n_1_rel" : [ SenseInfo('10117267-n', 1) ],
"_wheeze_n_1_rel" : [ SenseInfo('00836407-n', 1), SenseInfo('05909384-n', 0) ],
"_carp_n_1_rel" : [ SenseInfo('07779123-n', 0), SenseInfo('01439514-n', 0) ],
"_warm_v_up_rel" : [ SenseInfo('00373250-v', 2), SenseInfo('00372958-v', 1), SenseInfo('00373250-v', 2), SenseInfo('00372958-v', 1) ],
"_boycott_v_1_rel" : [ SenseInfo('02465494-v', 2) ],
"_coast_v_1_rel" : [ SenseInfo('01886728-v', 1) ],
"_easy+going_a_1_rel" : [ SenseInfo('01272176-a', 0), SenseInfo('00750054-a', 0), SenseInfo('00712004-a', 0), SenseInfo('01272176-a', 0), SenseInfo('00750054-a', 0), SenseInfo('00712004-a', 0), SenseInfo('01272176-a', 0), SenseInfo('00750054-a', 0), SenseInfo('00712004-a', 0) ],
"_wrest_v_1_rel" : [ SenseInfo('01213998-v', 0) ],
"_fallacious_a_1_rel" : [ SenseInfo('02500179-a', 0), SenseInfo('01223941-a', 0), SenseInfo('00633084-a', 0) ],
"_topmost_a_1_rel" : [ SenseInfo('02440461-a', 0), SenseInfo('02440461-a', 0), SenseInfo('02440461-a', 0) ],
"_insure_v_1_rel" : [ SenseInfo('00662589-v', 12), SenseInfo('00890590-v', 10), SenseInfo('00891216-v', 2), SenseInfo('02251065-v', 1) ],
"_from_p_time-on_rel" : [  ],
"_culture_n_1_rel" : [ SenseInfo('08287844-n', 17), SenseInfo('05751794-n', 12), SenseInfo('05984936-n', 6), SenseInfo('00920510-n', 1), SenseInfo('14459824-n', 0), SenseInfo('06194409-n', 0), SenseInfo('00917759-n', 0) ],
"_devise_v_1_rel" : [ SenseInfo('01632411-v', 14), SenseInfo('01651444-v', 1), SenseInfo('02229412-v', 0) ],
"_differentiate_v_from_rel" : [ SenseInfo('00650353-v', 4), SenseInfo('00651991-v', 1), SenseInfo('00642803-v', 0), SenseInfo('00119524-v', 0), SenseInfo('00119266-v', 0), SenseInfo('00119074-v', 0) ],
"_outdistance_v_1_rel" : [ SenseInfo('02081795-v', 4) ],
"_microchip_n_1_rel" : [ SenseInfo('03020034-n', 0) ],
"_just+in+time_a_1_rel" : [  ],
"_allude_v_to_rel" : [ SenseInfo('01026728-v', 0) ],
"_mustard_n_1_rel" : [ SenseInfo('11878283-n', 0), SenseInfo('07819480-n', 0), SenseInfo('07713763-n', 0) ],
"_portray_v_as_rel" : [ SenseInfo('00988890-v', 9), SenseInfo('01688256-v', 3), SenseInfo('01723690-v', 2), SenseInfo('01688771-v', 0), SenseInfo('00988890-v', 9), SenseInfo('01688256-v', 3), SenseInfo('01723690-v', 2), SenseInfo('01688771-v', 0) ],
"_spouse_n_of_rel" : [ SenseInfo('10640620-n', 3) ],
"_violence_n_1_rel" : [ SenseInfo('00965404-n', 13), SenseInfo('05037813-n', 3), SenseInfo('13979977-n', 2) ],
"_allright_a_for_rel" : [  ],
"_face-down_a_1_rel" : [  ],
"_thin_a_sel_rel" : [ SenseInfo('02412164-a', 16), SenseInfo('00988232-a', 15), SenseInfo('02562566-a', 7), SenseInfo('00542359-a', 2), SenseInfo('02417301-a', 1), SenseInfo('01458054-a', 0), SenseInfo('02282277-a', 0), SenseInfo('02164913-a', 0) ],
"_elicit_v_1_rel" : [ SenseInfo('01759326-v', 6), SenseInfo('01630532-v', 2), SenseInfo('00728826-v', 0) ],
"_unavailing_a_1_rel" : [ SenseInfo('02497471-a', 1) ],
"_down+under_p_rel" : [  ],
"_salacious_a_1_rel" : [ SenseInfo('02133779-a', 1), SenseInfo('00425740-a', 1) ],
"_lower_x_deg_rel" : [ SenseInfo('01973125-v', 15), SenseInfo('00531489-v', 6), SenseInfo('00267855-v', 1), SenseInfo('03693973-n', 0), SenseInfo('01574923-v', 0), SenseInfo('00032981-v', 0) ],
"_stall_v_off_rel" : [ SenseInfo('02642238-v', 2), SenseInfo('01862340-v', 1), SenseInfo('00460555-v', 1), SenseInfo('02460070-v', 0), SenseInfo('01862776-v', 0), SenseInfo('01862640-v', 0), SenseInfo('01862496-v', 0) ],
"_inhalation_n_1_rel" : [ SenseInfo('00836788-n', 1), SenseInfo('03571155-n', 0) ],
"_mercy_n_1_rel" : [ SenseInfo('01071411-n', 4), SenseInfo('04829282-n', 2), SenseInfo('07554500-n', 1), SenseInfo('14474435-n', 0), SenseInfo('01227495-n', 0) ],
"_dependable_a_1_rel" : [ SenseInfo('00724081-a', 4), SenseInfo('02465519-a', 1), SenseInfo('02301969-a', 0), SenseInfo('02273643-a', 0) ],
"_heart_n_1_rel" : [ SenseInfo('05919263-n', 42), SenseInfo('05388805-n', 25), SenseInfo('04857490-n', 9), SenseInfo('08523483-n', 5), SenseInfo('05921123-n', 2), SenseInfo('04624826-n', 1), SenseInfo('13865904-n', 0), SenseInfo('07651905-n', 0), SenseInfo('07544647-n', 0), SenseInfo('03507048-n', 0), SenseInfo('05919263-n', 42), SenseInfo('05388805-n', 25), SenseInfo('04857490-n', 9), SenseInfo('08523483-n', 5), SenseInfo('05921123-n', 2), SenseInfo('04624826-n', 1), SenseInfo('13865904-n', 0), SenseInfo('07651905-n', 0), SenseInfo('07544647-n', 0), SenseInfo('03507048-n', 0), SenseInfo('05919263-n', 42), SenseInfo('05388805-n', 25), SenseInfo('04857490-n', 9), SenseInfo('08523483-n', 5), SenseInfo('05921123-n', 2), SenseInfo('04624826-n', 1), SenseInfo('13865904-n', 0), SenseInfo('07651905-n', 0), SenseInfo('07544647-n', 0), SenseInfo('03507048-n', 0), SenseInfo('05919263-n', 42), SenseInfo('05388805-n', 25), SenseInfo('04857490-n', 9), SenseInfo('08523483-n', 5), SenseInfo('05921123-n', 2), SenseInfo('04624826-n', 1), SenseInfo('13865904-n', 0), SenseInfo('07651905-n', 0), SenseInfo('07544647-n', 0), SenseInfo('03507048-n', 0) ],
"_disturbing_a_for_rel" : [ SenseInfo('01189386-a', 5), SenseInfo('01189386-a', 5), SenseInfo('01189386-a', 5) ],
"_lilac_a_1_rel" : [ SenseInfo('00376917-a', 1) ],
"_invest_v_with_rel" : [ SenseInfo('02271137-v', 7), SenseInfo('02474239-v', 2), SenseInfo('02386675-v', 0), SenseInfo('02386388-v', 0), SenseInfo('02384275-v', 0) ],
"_void_n_1_rel" : [ SenseInfo('14455700-n', 0), SenseInfo('13910116-n', 0) ],
"_corporal_n_1_rel" : [ SenseInfo('09966139-n', 9), SenseInfo('09966139-n', 9) ],
"_trashy_a_1_rel" : [ SenseInfo('02503656-a', 0), SenseInfo('02393791-a', 0) ],
"_tidy_v_1_rel" : [ SenseInfo('00275843-v', 0) ],
"_pick_v_1_rel" : [ SenseInfo('00676450-v', 13), SenseInfo('01382083-v', 4), SenseInfo('00842772-v', 2), SenseInfo('01647131-v', 1), SenseInfo('00178102-v', 1), SenseInfo('00177714-v', 1), SenseInfo('02321648-v', 0), SenseInfo('02287209-v', 0), SenseInfo('01452546-v', 0), SenseInfo('01442578-v', 0), SenseInfo('01243474-v', 0), SenseInfo('01174294-v', 0) ],
"_withdrawal_n_of_rel" : [ SenseInfo('07206302-n', 1), SenseInfo('01262713-n', 1), SenseInfo('00053913-n', 1), SenseInfo('07506031-n', 0), SenseInfo('01262868-n', 0), SenseInfo('01202799-n', 0), SenseInfo('00849059-n', 0), SenseInfo('00384933-n', 0), SenseInfo('00228911-n', 0) ],
"_chamberlain_n_1_rel" : [ SenseInfo('10889689-n', 0), SenseInfo('09906195-n', 0), SenseInfo('09906079-n', 0) ],
"_invite_v_in_rel" : [ SenseInfo('01760143-v', 7), SenseInfo('02384686-v', 6), SenseInfo('01807529-v', 6), SenseInfo('00793580-v', 6), SenseInfo('02384940-v', 3), SenseInfo('01469770-v', 2), SenseInfo('01063695-v', 2), SenseInfo('01470225-v', 0) ],
"_back_v_down_rel" : [ SenseInfo('02453889-v', 7), SenseInfo('01997119-v', 6), SenseInfo('02556817-v', 4), SenseInfo('01997512-v', 4), SenseInfo('02217695-v', 2), SenseInfo('02693965-v', 0), SenseInfo('01139104-v', 0), SenseInfo('00560628-v', 0), SenseInfo('00223109-v', 0), SenseInfo('00185857-v', 0) ],
"_mankind_n_1_rel" : [ SenseInfo('02472987-n', 0) ],
"_titration_n_1_rel" : [ SenseInfo('00648237-n', 1) ],
"_repute_v_1_rel" : [ SenseInfo('00689950-v', 2), SenseInfo('00689950-v', 2) ],
"_congress_n_1_rel" : [ SenseInfo('08161757-n', 24), SenseInfo('08308800-n', 1), SenseInfo('08318691-n', 0), SenseInfo('00845523-n', 0), SenseInfo('08161757-n', 24), SenseInfo('08308800-n', 1), SenseInfo('08318691-n', 0), SenseInfo('00845523-n', 0) ],
"_splendor_n_1_rel" : [ SenseInfo('04954920-n', 2), SenseInfo('04814238-n', 2) ],
"_shortsighted_a_1_rel" : [ SenseInfo('01896046-a', 4), SenseInfo('02157226-a', 0), SenseInfo('01899742-a', 0) ],
"_arrange_v_for_rel" : [ SenseInfo('01463963-v', 13), SenseInfo('01021629-v', 7), SenseInfo('01648126-v', 3), SenseInfo('01745141-v', 2), SenseInfo('00038849-v', 2), SenseInfo('01706129-v', 0), SenseInfo('00735571-v', 0), SenseInfo('01463963-v', 13), SenseInfo('01021629-v', 7), SenseInfo('01648126-v', 3), SenseInfo('01745141-v', 2), SenseInfo('00038849-v', 2), SenseInfo('01706129-v', 0), SenseInfo('00735571-v', 0) ],
"_onshore_p_rel" : [ SenseInfo('00464195-a', 1), SenseInfo('00140168-r', 1), SenseInfo('00125068-a', 0) ],
"_dim_a_1_rel" : [ SenseInfo('00275290-a', 4), SenseInfo('00782216-a', 3), SenseInfo('00284575-a', 0), SenseInfo('01229561-a', 0), SenseInfo('00440579-a', 0), SenseInfo('00275290-a', 4), SenseInfo('00782216-a', 3), SenseInfo('00284575-a', 0), SenseInfo('01229561-a', 0), SenseInfo('00440579-a', 0), SenseInfo('00275290-a', 4), SenseInfo('00782216-a', 3), SenseInfo('00284575-a', 0), SenseInfo('01229561-a', 0), SenseInfo('00440579-a', 0), SenseInfo('00275290-a', 4), SenseInfo('00782216-a', 3), SenseInfo('00284575-a', 0), SenseInfo('01229561-a', 0), SenseInfo('00440579-a', 0) ],
"_all+month+long_a_1_rel" : [  ],
"_sub_n_1_rel" : [ SenseInfo('07697825-n', 0), SenseInfo('04347754-n', 0) ],
"_wash_v_down_rel" : [ SenseInfo('01270199-v', 13), SenseInfo('00036362-v', 9), SenseInfo('01535246-v', 7), SenseInfo('02098179-v', 2), SenseInfo('02742842-v', 0), SenseInfo('02703153-v', 0), SenseInfo('01536344-v', 0), SenseInfo('01269844-v', 0), SenseInfo('00557686-v', 0), SenseInfo('00274942-v', 0), SenseInfo('00217956-v', 0), SenseInfo('00217576-v', 0), SenseInfo('00036178-v', 0), SenseInfo('01270199-v', 13), SenseInfo('00036362-v', 9), SenseInfo('01535246-v', 7), SenseInfo('02098179-v', 2), SenseInfo('02742842-v', 0), SenseInfo('02703153-v', 0), SenseInfo('01536344-v', 0), SenseInfo('01269844-v', 0), SenseInfo('00557686-v', 0), SenseInfo('00274942-v', 0), SenseInfo('00217956-v', 0), SenseInfo('00217576-v', 0), SenseInfo('00036178-v', 0) ],
"_pricetag_n_1_rel" : [  ],
"_delude_v_1_rel" : [ SenseInfo('02575082-v', 1) ],
"_continent_n_1_rel" : [ SenseInfo('09254614-n', 5), SenseInfo('08696737-n', 2) ],
"_block_n_of_rel" : [ SenseInfo('02852523-n', 29), SenseInfo('08642145-n', 6), SenseInfo('13914608-n', 1), SenseInfo('07954014-n', 1), SenseInfo('02853016-n', 1), SenseInfo('13626464-n', 0), SenseInfo('05645199-n', 0), SenseInfo('04020298-n', 0), SenseInfo('03288225-n', 0), SenseInfo('02853449-n', 0), SenseInfo('02756601-n', 0), SenseInfo('00562398-n', 0), SenseInfo('02852523-n', 29), SenseInfo('08642145-n', 6), SenseInfo('13914608-n', 1), SenseInfo('07954014-n', 1), SenseInfo('02853016-n', 1), SenseInfo('13626464-n', 0), SenseInfo('05645199-n', 0), SenseInfo('04020298-n', 0), SenseInfo('03288225-n', 0), SenseInfo('02853449-n', 0), SenseInfo('02756601-n', 0), SenseInfo('00562398-n', 0) ],
"_in+regard+to_p_rel" : [  ],
"_turn_v_prd_rel" : [ SenseInfo('01907258-v', 187), SenseInfo('00146138-v', 21), SenseInfo('02626604-v', 12), SenseInfo('02089984-v', 8), SenseInfo('00138508-v', 7), SenseInfo('01909812-v', 5), SenseInfo('00125841-v', 5), SenseInfo('01436518-v', 2), SenseInfo('02096167-v', 1), SenseInfo('02089420-v', 1), SenseInfo('01952208-v', 1), SenseInfo('01741864-v', 1), SenseInfo('01584450-v', 1), SenseInfo('00282523-v', 1), SenseInfo('00091124-v', 1), SenseInfo('02626934-v', 0), SenseInfo('02562425-v', 0), SenseInfo('02211948-v', 0), SenseInfo('02090435-v', 0), SenseInfo('01951937-v', 0), SenseInfo('01280014-v', 0), SenseInfo('01225215-v', 0), SenseInfo('01151889-v', 0), SenseInfo('00794640-v', 0), SenseInfo('00458471-v', 0), SenseInfo('00248387-v', 0), SenseInfo('01907258-v', 187), SenseInfo('00146138-v', 21), SenseInfo('02626604-v', 12), SenseInfo('02089984-v', 8), SenseInfo('00138508-v', 7), SenseInfo('01909812-v', 5), SenseInfo('00125841-v', 5), SenseInfo('01436518-v', 2), SenseInfo('02096167-v', 1), SenseInfo('02089420-v', 1), SenseInfo('01952208-v', 1), SenseInfo('01741864-v', 1), SenseInfo('01584450-v', 1), SenseInfo('00282523-v', 1), SenseInfo('00091124-v', 1), SenseInfo('02626934-v', 0), SenseInfo('02562425-v', 0), SenseInfo('02211948-v', 0), SenseInfo('02090435-v', 0), SenseInfo('01951937-v', 0), SenseInfo('01280014-v', 0), SenseInfo('01225215-v', 0), SenseInfo('01151889-v', 0), SenseInfo('00794640-v', 0), SenseInfo('00458471-v', 0), SenseInfo('00248387-v', 0) ],
"_english_n_1_rel" : [ SenseInfo('06947032-n', 18), SenseInfo('09732668-n', 3), SenseInfo('06155432-n', 3), SenseInfo('07442569-n', 0), SenseInfo('06947032-n', 18), SenseInfo('09732668-n', 3), SenseInfo('06155432-n', 3), SenseInfo('07442569-n', 0), SenseInfo('06947032-n', 18), SenseInfo('09732668-n', 3), SenseInfo('06155432-n', 3), SenseInfo('07442569-n', 0) ],
"_fishermens_a_1_rel" : [  ],
"_pickings_n_1_rel" : [ SenseInfo('00714477-n', 0), SenseInfo('00714477-n', 0) ],
"_enforcement_n_of_rel" : [ SenseInfo('01127019-n', 3) ],
"_repeat_n_1_rel" : [ SenseInfo('07342049-n', 2) ],
"_over-optimistic_a_1_rel" : [  ],
"_carpet_v_1_rel" : [ SenseInfo('02749520-v', 0), SenseInfo('01235073-v', 0), SenseInfo('01234920-v', 0) ],
"_interpretation_n_of_rel" : [ SenseInfo('05928513-n', 11), SenseInfo('00100543-n', 3), SenseInfo('07170753-n', 1), SenseInfo('05766247-n', 1) ],
"_compelling_a_1_rel" : [ SenseInfo('01826477-a', 0), SenseInfo('01770591-a', 0) ],
"_roll_v_out_rel" : [ SenseInfo('01866192-v', 22), SenseInfo('01887020-v', 10), SenseInfo('02687251-v', 7), SenseInfo('01391280-v', 6), SenseInfo('02198014-v', 2), SenseInfo('01522276-v', 2), SenseInfo('01526139-v', 1), SenseInfo('00143204-v', 1), SenseInfo('00100410-v', 1), SenseInfo('02322596-v', 0), SenseInfo('01901783-v', 0), SenseInfo('01881180-v', 0), SenseInfo('01875684-v', 0), SenseInfo('01866610-v', 0), SenseInfo('01055978-v', 0), SenseInfo('00324427-v', 0), SenseInfo('00125289-v', 0), SenseInfo('00125078-v', 0) ],
"_club_n_1_rel" : [ SenseInfo('08079613-n', 14), SenseInfo('08227214-n', 9), SenseInfo('03053474-n', 3), SenseInfo('03054311-n', 2), SenseInfo('03446070-n', 1), SenseInfo('03053788-n', 0), SenseInfo('02931417-n', 0), SenseInfo('08079613-n', 14), SenseInfo('08227214-n', 9), SenseInfo('03053474-n', 3), SenseInfo('03054311-n', 2), SenseInfo('03446070-n', 1), SenseInfo('03053788-n', 0), SenseInfo('02931417-n', 0) ],
"_goodwill_n_1_rel" : [ SenseInfo('13332820-n', 0), SenseInfo('07499930-n', 0), SenseInfo('04640356-n', 0), SenseInfo('13332820-n', 0), SenseInfo('07499930-n', 0), SenseInfo('04640356-n', 0) ],
"_get_v_on_rel" : [ SenseInfo('02210855-v', 235), SenseInfo('00149583-v', 157), SenseInfo('00120796-v', 82), SenseInfo('00522751-v', 64), SenseInfo('02005948-v', 58), SenseInfo('01433294-v', 45), SenseInfo('02108026-v', 36), SenseInfo('01153947-v', 14), SenseInfo('02355596-v', 9), SenseInfo('00770437-v', 7), SenseInfo('01215421-v', 4), SenseInfo('00094460-v', 4), SenseInfo('00087736-v', 4), SenseInfo('01066036-v', 3), SenseInfo('00120316-v', 3), SenseInfo('01026975-v', 2), SenseInfo('00589904-v', 2), SenseInfo('01505958-v', 1), SenseInfo('01401115-v', 1), SenseInfo('00639849-v', 1), SenseInfo('02359340-v', 0), SenseInfo('02208265-v', 0), SenseInfo('02189398-v', 0), SenseInfo('02109645-v', 0), SenseInfo('02108654-v', 0), SenseInfo('02010864-v', 0), SenseInfo('02006573-v', 0), SenseInfo('01771194-v', 0), SenseInfo('01771039-v', 0), SenseInfo('01738107-v', 0), SenseInfo('01643297-v', 0), SenseInfo('01565211-v', 0), SenseInfo('00622384-v', 0), SenseInfo('00345761-v', 0), SenseInfo('00065639-v', 0), SenseInfo('00054628-v', 0), SenseInfo('02210855-v', 235), SenseInfo('00149583-v', 157), SenseInfo('00120796-v', 82), SenseInfo('00522751-v', 64), SenseInfo('02005948-v', 58), SenseInfo('01433294-v', 45), SenseInfo('02108026-v', 36), SenseInfo('01153947-v', 14), SenseInfo('02355596-v', 9), SenseInfo('00770437-v', 7), SenseInfo('01215421-v', 4), SenseInfo('00094460-v', 4), SenseInfo('00087736-v', 4), SenseInfo('01066036-v', 3), SenseInfo('00120316-v', 3), SenseInfo('01026975-v', 2), SenseInfo('00589904-v', 2), SenseInfo('01505958-v', 1), SenseInfo('01401115-v', 1), SenseInfo('00639849-v', 1), SenseInfo('02359340-v', 0), SenseInfo('02208265-v', 0), SenseInfo('02189398-v', 0), SenseInfo('02109645-v', 0), SenseInfo('02108654-v', 0), SenseInfo('02010864-v', 0), SenseInfo('02006573-v', 0), SenseInfo('01771194-v', 0), SenseInfo('01771039-v', 0), SenseInfo('01738107-v', 0), SenseInfo('01643297-v', 0), SenseInfo('01565211-v', 0), SenseInfo('00622384-v', 0), SenseInfo('00345761-v', 0), SenseInfo('00065639-v', 0), SenseInfo('00054628-v', 0) ],
"_achieve_v_1_rel" : [ SenseInfo('02526085-v', 100) ],
"_bunk_n_1_rel" : [ SenseInfo('02920164-n', 9), SenseInfo('02831724-n', 4), SenseInfo('02920083-n', 3), SenseInfo('06611681-n', 0), SenseInfo('06607339-n', 0), SenseInfo('02920259-n', 0) ],
"_send_v_off_rel" : [ SenseInfo('01951480-v', 79), SenseInfo('01437254-v', 20), SenseInfo('01031256-v', 20), SenseInfo('01950798-v', 14), SenseInfo('01088923-v', 5), SenseInfo('01062555-v', 5), SenseInfo('02348568-v', 3), SenseInfo('00973056-v', 2) ],
"_plush_n_1_rel" : [ SenseInfo('03970546-n', 0) ],
"_broom_n_1_rel" : [ SenseInfo('02906734-n', 3), SenseInfo('12520864-n', 0), SenseInfo('12233529-n', 0) ],
"_roller+coaster_n_1_rel" : [ SenseInfo('13979786-n', 0), SenseInfo('04102406-n', 0), SenseInfo('13979786-n', 0), SenseInfo('04102406-n', 0) ],
"_gelatine_n_1_rel" : [ SenseInfo('14730553-n', 0) ],
"_dissent_v_1_rel" : [ SenseInfo('00804653-v', 1), SenseInfo('02521410-v', 0), SenseInfo('00804802-v', 0) ],
"_squirm_v_1_rel" : [ SenseInfo('01868370-v', 3) ],
"_anteroom_n_1_rel" : [ SenseInfo('02715513-n', 0) ],
"_quits_n_i_rel" : [ SenseInfo('00892104-a', 0) ],
"_rationalization_n_1_rel" : [ SenseInfo('05794403-n', 1), SenseInfo('13546169-n', 0), SenseInfo('01212225-n', 0), SenseInfo('01137760-n', 0), SenseInfo('01009190-n', 0), SenseInfo('05794403-n', 1), SenseInfo('13546169-n', 0), SenseInfo('01212225-n', 0), SenseInfo('01137760-n', 0), SenseInfo('01009190-n', 0), SenseInfo('05794403-n', 1), SenseInfo('13546169-n', 0), SenseInfo('01212225-n', 0), SenseInfo('01137760-n', 0), SenseInfo('01009190-n', 0), SenseInfo('05794403-n', 1), SenseInfo('13546169-n', 0), SenseInfo('01212225-n', 0), SenseInfo('01137760-n', 0), SenseInfo('01009190-n', 0) ],
"_loathe_v_1_rel" : [ SenseInfo('01774426-v', 3) ],
"_some_q_rel" : [  ],
"_trump_n_1_rel" : [ SenseInfo('04491135-n', 0), SenseInfo('04490859-n', 0), SenseInfo('03110669-n', 0) ],
"_hammock_n_1_rel" : [ SenseInfo('09326662-n', 0), SenseInfo('03482252-n', 0) ],
"_inclosure_n_1_rel" : [ SenseInfo('06473381-n', 0), SenseInfo('00321956-n', 0) ],
"_merciful_a_1_rel" : [ SenseInfo('01507134-a', 1), SenseInfo('01142196-a', 0) ],
"_strand_n_of_rel" : [ SenseInfo('05932062-n', 1), SenseInfo('04332783-n', 1), SenseInfo('02999757-n', 1), SenseInfo('14867858-n', 0), SenseInfo('09447666-n', 0), SenseInfo('08657748-n', 0) ],
"_verdigris_a_1_rel" : [ SenseInfo('15096524-n', 0), SenseInfo('04528079-n', 0) ],
"_uncanny_a_1_rel" : [ SenseInfo('01575424-a', 1), SenseInfo('01677733-a', 0) ],
"_scrubber_n_1_rel" : [ SenseInfo('10565048-n', 0), SenseInfo('04156140-n', 0), SenseInfo('04156040-n', 0) ],
"_whale_v_1_rel" : [ SenseInfo('01141938-v', 0) ],
"_flightiness_n_1_rel" : [ SenseInfo('04671841-n', 0) ],
"_onward_p_sel_rel" : [ SenseInfo('00103859-r', 0), SenseInfo('00067265-r', 0) ],
"_performance+artist_n_1_rel" : [  ],
"_shuttle_n_1_rel" : [ SenseInfo('04212282-n', 0), SenseInfo('04211970-n', 0), SenseInfo('04211857-n', 0) ],
"_humdrum_a_1_rel" : [ SenseInfo('00922840-a', 0), SenseInfo('00807817-a', 0) ],
"_structured_a_1_rel" : [ SenseInfo('01671732-a', 12), SenseInfo('01679744-a', 0) ],
"_race_n_of-for_rel" : [ SenseInfo('07472657-n', 6), SenseInfo('07458453-n', 6), SenseInfo('07967982-n', 4), SenseInfo('08110648-n', 2), SenseInfo('11423197-n', 0), SenseInfo('04037873-n', 0), SenseInfo('07472657-n', 6), SenseInfo('07458453-n', 6), SenseInfo('07967982-n', 4), SenseInfo('08110648-n', 2), SenseInfo('11423197-n', 0), SenseInfo('04037873-n', 0) ],
"_issue_n_1_rel" : [ SenseInfo('05814650-n', 23), SenseInfo('06596978-n', 3), SenseInfo('05814291-n', 2), SenseInfo('01060234-n', 1), SenseInfo('13367593-n', 0), SenseInfo('13260190-n', 0), SenseInfo('11410625-n', 0), SenseInfo('10373998-n', 0), SenseInfo('07319909-n', 0), SenseInfo('03303965-n', 0), SenseInfo('01103614-n', 0), SenseInfo('05814650-n', 23), SenseInfo('06596978-n', 3), SenseInfo('05814291-n', 2), SenseInfo('01060234-n', 1), SenseInfo('13367593-n', 0), SenseInfo('13260190-n', 0), SenseInfo('11410625-n', 0), SenseInfo('10373998-n', 0), SenseInfo('07319909-n', 0), SenseInfo('03303965-n', 0), SenseInfo('01103614-n', 0), SenseInfo('05814650-n', 23), SenseInfo('06596978-n', 3), SenseInfo('05814291-n', 2), SenseInfo('01060234-n', 1), SenseInfo('13367593-n', 0), SenseInfo('13260190-n', 0), SenseInfo('11410625-n', 0), SenseInfo('10373998-n', 0), SenseInfo('07319909-n', 0), SenseInfo('03303965-n', 0), SenseInfo('01103614-n', 0) ],
"_surprising_a_1_rel" : [ SenseInfo('02359464-a', 11), SenseInfo('02359464-a', 11), SenseInfo('02359464-a', 11), SenseInfo('02359464-a', 11), SenseInfo('02359464-a', 11), SenseInfo('02359464-a', 11), SenseInfo('02359464-a', 11) ],
"_side+by+side_p_1_rel" : [ SenseInfo('00447472-a', 2), SenseInfo('01974584-a', 0), SenseInfo('00447472-a', 2), SenseInfo('01974584-a', 0) ],
"_hate_v_1_rel" : [ SenseInfo('01774136-v', 50), SenseInfo('01774136-v', 50), SenseInfo('01774136-v', 50), SenseInfo('01774136-v', 50) ],
"_intermediary_n_1_rel" : [ SenseInfo('09624559-n', 1) ],
"_underweight_n_1_rel" : [ SenseInfo('00990192-a', 0) ],
"_gunboat_n_1_rel" : [ SenseInfo('03468570-n', 0) ],
"_personal_n_1_rel" : [ SenseInfo('06271288-n', 0) ],
"_crank_n_1_rel" : [ SenseInfo('10148305-n', 0), SenseInfo('09974496-n', 0), SenseInfo('03754295-n', 0), SenseInfo('03127024-n', 0) ],
"_nothing_n_1_rel" : [ SenseInfo('13740168-n', 141) ],
"_yuck_a_1_rel" : [  ],
"_draw_v_upon_rel" : [ SenseInfo('01448100-v', 13), SenseInfo('02293148-v', 10), SenseInfo('01582645-v', 10), SenseInfo('00730758-v', 10), SenseInfo('01995211-v', 9), SenseInfo('01690294-v', 7), SenseInfo('01854132-v', 6), SenseInfo('00987071-v', 6), SenseInfo('00675901-v', 6), SenseInfo('01760300-v', 5), SenseInfo('01199009-v', 5), SenseInfo('02088107-v', 4), SenseInfo('02311387-v', 3), SenseInfo('01078050-v', 3), SenseInfo('01643297-v', 2), SenseInfo('00556593-v', 2), SenseInfo('02097800-v', 1), SenseInfo('01690816-v', 1), SenseInfo('01643464-v', 1), SenseInfo('01243148-v', 1), SenseInfo('02742107-v', 0), SenseInfo('02628832-v', 0), SenseInfo('02483564-v', 0), SenseInfo('02103162-v', 0), SenseInfo('01539063-v', 0), SenseInfo('01505254-v', 0), SenseInfo('01359432-v', 0), SenseInfo('01243298-v', 0), SenseInfo('01212230-v', 0), SenseInfo('01115190-v', 0), SenseInfo('00476965-v', 0), SenseInfo('00430808-v', 0), SenseInfo('00327982-v', 0), SenseInfo('00197590-v', 0), SenseInfo('00143338-v', 0), SenseInfo('00097029-v', 0) ],
"_measure_n_1_rel" : [ SenseInfo('00174412-n', 5), SenseInfo('00033615-n', 5), SenseInfo('06536853-n', 2), SenseInfo('00996969-n', 2), SenseInfo('07260623-n', 1), SenseInfo('07094093-n', 1), SenseInfo('06864725-n', 0), SenseInfo('03735637-n', 0), SenseInfo('03733644-n', 0), SenseInfo('00174412-n', 5), SenseInfo('00033615-n', 5), SenseInfo('06536853-n', 2), SenseInfo('00996969-n', 2), SenseInfo('07260623-n', 1), SenseInfo('07094093-n', 1), SenseInfo('06864725-n', 0), SenseInfo('03735637-n', 0), SenseInfo('03733644-n', 0) ],
"_start_n_1_rel" : [ SenseInfo('07325190-n', 11), SenseInfo('15265518-n', 5), SenseInfo('00241699-n', 2), SenseInfo('00867357-n', 1), SenseInfo('00235435-n', 1), SenseInfo('08653873-n', 0), SenseInfo('06792188-n', 0), SenseInfo('05157406-n', 0) ],
"_harness_v_1_rel" : [ SenseInfo('01491697-v', 2), SenseInfo('01163495-v', 1), SenseInfo('02442737-v', 0), SenseInfo('00234857-v', 0) ],
"_archiepiscopal_a_1_rel" : [ SenseInfo('02639895-a', 0) ],
"_hazard_n_1_rel" : [ SenseInfo('14541852-n', 3), SenseInfo('11418138-n', 1), SenseInfo('03501152-n', 0) ],
"_baobab_n_1_rel" : [ SenseInfo('12189987-n', 0) ],
"_center_v_around_rel" : [ SenseInfo('02676496-v', 11), SenseInfo('00722232-v', 5), SenseInfo('01852701-v', 0), SenseInfo('02676496-v', 11), SenseInfo('00722232-v', 5), SenseInfo('01852701-v', 0) ],
"_beatable_a_1_rel" : [ SenseInfo('00569304-a', 0) ],
"_pore_v_over_rel" : [ SenseInfo('00722232-v', 1) ],
"_associate_v_1_rel" : [ SenseInfo('00713167-v', 25), SenseInfo('02589245-v', 3), SenseInfo('02470175-v', 1) ],
"_before+school_a_1_rel" : [  ],
"_cave_n_1_rel" : [ SenseInfo('09238926-n', 4), SenseInfo('09238926-n', 4) ],
"_repair_n_of_rel" : [ SenseInfo('00266806-n', 5), SenseInfo('14546701-n', 1), SenseInfo('08581503-n', 0) ],
"_candy_n_1_rel" : [ SenseInfo('07597365-n', 1) ],
"_sensory_a_1_rel" : [ SenseInfo('00333611-a', 4), SenseInfo('02108665-a', 3), SenseInfo('02796425-a', 0) ],
"_record_a_1_rel" : [ SenseInfo('06647206-n', 26), SenseInfo('03924069-n', 23), SenseInfo('13596986-n', 7), SenseInfo('00047745-n', 6), SenseInfo('06636524-n', 3), SenseInfo('00063014-n', 3), SenseInfo('13403643-n', 1), SenseInfo('06490173-n', 0) ],
"_allow_v_for_rel" : [ SenseInfo('02423183-v', 65), SenseInfo('00802318-v', 49), SenseInfo('02255462-v', 17), SenseInfo('00724150-v', 8), SenseInfo('02721438-v', 3), SenseInfo('00723545-v', 3), SenseInfo('02745486-v', 0), SenseInfo('02423650-v', 0), SenseInfo('02319669-v', 0), SenseInfo('00802946-v', 0) ],
"_fourth+prize_n_1_rel" : [  ],
"_fly_v_to_rel" : [ SenseInfo('01940403-v', 33), SenseInfo('01842068-v', 9), SenseInfo('01941093-v', 5), SenseInfo('01451842-v', 3), SenseInfo('01848058-v', 2), SenseInfo('01839404-v', 2), SenseInfo('00545292-v', 2), SenseInfo('02073065-v', 1), SenseInfo('01840238-v', 1), SenseInfo('02140965-v', 0), SenseInfo('02075462-v', 0), SenseInfo('01847845-v', 0), SenseInfo('01402765-v', 0), SenseInfo('00153061-v', 0), SenseInfo('01940403-v', 33), SenseInfo('01842068-v', 9), SenseInfo('01941093-v', 5), SenseInfo('01451842-v', 3), SenseInfo('01848058-v', 2), SenseInfo('01839404-v', 2), SenseInfo('00545292-v', 2), SenseInfo('02073065-v', 1), SenseInfo('01840238-v', 1), SenseInfo('02140965-v', 0), SenseInfo('02075462-v', 0), SenseInfo('01847845-v', 0), SenseInfo('01402765-v', 0), SenseInfo('00153061-v', 0) ],
"_token_n_1_rel" : [ SenseInfo('06795746-n', 2), SenseInfo('06646531-n', 0), SenseInfo('04448361-n', 0), SenseInfo('03610270-n', 0) ],
"_entwist_v_cause_rel" : [  ],
"_colonel_n_1_rel" : [ SenseInfo('09937250-n', 33), SenseInfo('09937250-n', 33) ],
"_position_n_of_rel" : [ SenseInfo('08621598-n', 34), SenseInfo('08622586-n', 18), SenseInfo('06208751-n', 18), SenseInfo('05079866-n', 14), SenseInfo('13945919-n', 12), SenseInfo('00586262-n', 12), SenseInfo('05074774-n', 7), SenseInfo('08622201-n', 3), SenseInfo('00722479-n', 3), SenseInfo('01051331-n', 2), SenseInfo('13925752-n', 1), SenseInfo('06196284-n', 1), SenseInfo('06783265-n', 0), SenseInfo('06483454-n', 0), SenseInfo('00721431-n', 0), SenseInfo('00083448-n', 0), SenseInfo('08621598-n', 34), SenseInfo('08622586-n', 18), SenseInfo('06208751-n', 18), SenseInfo('05079866-n', 14), SenseInfo('13945919-n', 12), SenseInfo('00586262-n', 12), SenseInfo('05074774-n', 7), SenseInfo('08622201-n', 3), SenseInfo('00722479-n', 3), SenseInfo('01051331-n', 2), SenseInfo('13925752-n', 1), SenseInfo('06196284-n', 1), SenseInfo('06783265-n', 0), SenseInfo('06483454-n', 0), SenseInfo('00721431-n', 0), SenseInfo('00083448-n', 0) ],
"_outlive_v_1_rel" : [ SenseInfo('02619739-v', 2) ],
"_thrust_v_1_rel" : [ SenseInfo('01899262-v', 11), SenseInfo('02094569-v', 7), SenseInfo('02062212-v', 4), SenseInfo('00747418-v', 3), SenseInfo('01441510-v', 1), SenseInfo('02714057-v', 0), SenseInfo('02713852-v', 0), SenseInfo('01499265-v', 0), SenseInfo('01899262-v', 11), SenseInfo('02094569-v', 7), SenseInfo('02062212-v', 4), SenseInfo('00747418-v', 3), SenseInfo('01441510-v', 1), SenseInfo('02714057-v', 0), SenseInfo('02713852-v', 0), SenseInfo('01499265-v', 0), SenseInfo('01899262-v', 11), SenseInfo('02094569-v', 7), SenseInfo('02062212-v', 4), SenseInfo('00747418-v', 3), SenseInfo('01441510-v', 1), SenseInfo('02714057-v', 0), SenseInfo('02713852-v', 0), SenseInfo('01499265-v', 0) ],
"_butterfly_n_1_rel" : [ SenseInfo('02274259-n', 0), SenseInfo('00570854-n', 0) ],
"_bail_v_out+of_rel" : [ SenseInfo('02421749-v', 0), SenseInfo('02293732-v', 0), SenseInfo('00890403-v', 0), SenseInfo('00177136-v', 0), SenseInfo('00177011-v', 0) ],
"_slice_n_1_rel" : [ SenseInfo('13286524-n', 3), SenseInfo('07654667-n', 2), SenseInfo('14287113-n', 1), SenseInfo('00572043-n', 1), SenseInfo('09437241-n', 0), SenseInfo('04237086-n', 0) ],
"_dogsledge_n_1_rel" : [  ],
"_icy_a_1_rel" : [ SenseInfo('01258264-a', 2), SenseInfo('01252151-a', 1), SenseInfo('01079240-a', 1), SenseInfo('01120242-a', 0), SenseInfo('01258264-a', 2), SenseInfo('01252151-a', 1), SenseInfo('01079240-a', 1), SenseInfo('01120242-a', 0), SenseInfo('01258264-a', 2), SenseInfo('01252151-a', 1), SenseInfo('01079240-a', 1), SenseInfo('01120242-a', 0) ],
"_fantasy_n_1_rel" : [ SenseInfo('05632446-n', 3), SenseInfo('06368425-n', 1), SenseInfo('05896059-n', 1) ],
"_overly_x_rel" : [ SenseInfo('00047392-r', 0) ],
"_consent_n_1_rel" : [ SenseInfo('06689667-n', 7) ],
"_exam_n_1_rel" : [ SenseInfo('07197021-n', 0) ],
"_wear_v_1_rel" : [ SenseInfo('00052374-v', 83), SenseInfo('00047745-v', 22), SenseInfo('02740034-v', 6), SenseInfo('00469382-v', 2), SenseInfo('00047610-v', 2), SenseInfo('02705132-v', 1), SenseInfo('01369346-v', 0), SenseInfo('00075021-v', 0), SenseInfo('00050652-v', 0), SenseInfo('00052374-v', 83), SenseInfo('00047745-v', 22), SenseInfo('02740034-v', 6), SenseInfo('00469382-v', 2), SenseInfo('00047610-v', 2), SenseInfo('02705132-v', 1), SenseInfo('01369346-v', 0), SenseInfo('00075021-v', 0), SenseInfo('00050652-v', 0), SenseInfo('00052374-v', 83), SenseInfo('00047745-v', 22), SenseInfo('02740034-v', 6), SenseInfo('00469382-v', 2), SenseInfo('00047610-v', 2), SenseInfo('02705132-v', 1), SenseInfo('01369346-v', 0), SenseInfo('00075021-v', 0), SenseInfo('00050652-v', 0), SenseInfo('00052374-v', 83), SenseInfo('00047745-v', 22), SenseInfo('02740034-v', 6), SenseInfo('00469382-v', 2), SenseInfo('00047610-v', 2), SenseInfo('02705132-v', 1), SenseInfo('01369346-v', 0), SenseInfo('00075021-v', 0), SenseInfo('00050652-v', 0) ],
"_compact_a_1_rel" : [ SenseInfo('00502180-a', 2), SenseInfo('02387413-a', 0), SenseInfo('00547317-a', 0) ],
"_ornamented_a_1_rel" : [  ],
"_deacon_n_1_rel" : [ SenseInfo('09994673-n', 4), SenseInfo('09994520-n', 0) ],
"_goulash_n_1_rel" : [ SenseInfo('07590320-n', 0) ],
"_i+e_a_1_rel" : [  ],
"_gigahertz_n_1_rel" : [ SenseInfo('15278691-n', 0), SenseInfo('15278691-n', 0), SenseInfo('15278691-n', 0) ],
"_directly_x_deg_rel" : [ SenseInfo('00051848-r', 26), SenseInfo('00504281-r', 14), SenseInfo('00048739-r', 9), SenseInfo('00058128-r', 5) ],
"_florentine_n_1_rel" : [ SenseInfo('10097590-n', 0) ],
"_turbulent_a_1_rel" : [ SenseInfo('01923720-a', 1), SenseInfo('00087597-a', 1) ],
"_record_n_of_rel" : [ SenseInfo('06647206-n', 26), SenseInfo('03924069-n', 23), SenseInfo('13596986-n', 7), SenseInfo('00047745-n', 6), SenseInfo('06636524-n', 3), SenseInfo('00063014-n', 3), SenseInfo('13403643-n', 1), SenseInfo('06490173-n', 0), SenseInfo('06647206-n', 26), SenseInfo('03924069-n', 23), SenseInfo('13596986-n', 7), SenseInfo('00047745-n', 6), SenseInfo('06636524-n', 3), SenseInfo('00063014-n', 3), SenseInfo('13403643-n', 1), SenseInfo('06490173-n', 0), SenseInfo('06647206-n', 26), SenseInfo('03924069-n', 23), SenseInfo('13596986-n', 7), SenseInfo('00047745-n', 6), SenseInfo('06636524-n', 3), SenseInfo('00063014-n', 3), SenseInfo('13403643-n', 1), SenseInfo('06490173-n', 0), SenseInfo('06647206-n', 26), SenseInfo('03924069-n', 23), SenseInfo('13596986-n', 7), SenseInfo('00047745-n', 6), SenseInfo('06636524-n', 3), SenseInfo('00063014-n', 3), SenseInfo('13403643-n', 1), SenseInfo('06490173-n', 0), SenseInfo('06647206-n', 26), SenseInfo('03924069-n', 23), SenseInfo('13596986-n', 7), SenseInfo('00047745-n', 6), SenseInfo('06636524-n', 3), SenseInfo('00063014-n', 3), SenseInfo('13403643-n', 1), SenseInfo('06490173-n', 0), SenseInfo('06647206-n', 26), SenseInfo('03924069-n', 23), SenseInfo('13596986-n', 7), SenseInfo('00047745-n', 6), SenseInfo('06636524-n', 3), SenseInfo('00063014-n', 3), SenseInfo('13403643-n', 1), SenseInfo('06490173-n', 0) ],
"_circulate_v_cause_rel" : [ SenseInfo('00969873-v', 2), SenseInfo('00968211-v', 2), SenseInfo('02043190-v', 1), SenseInfo('02042404-v', 1), SenseInfo('02044278-v', 0), SenseInfo('02042843-v', 0), SenseInfo('02042237-v', 0), SenseInfo('00270005-v', 0) ],
"_odious_a_1_rel" : [ SenseInfo('01460679-a', 1) ],
"_literally_x_deg_rel" : [ SenseInfo('00340133-r', 5), SenseInfo('00111269-r', 5), SenseInfo('00340133-r', 5), SenseInfo('00111269-r', 5) ],
"_extrinsic_a_1_rel" : [ SenseInfo('01349041-a', 0) ],
"_biopsy_n_1_rel" : [ SenseInfo('05740929-n', 3) ],
"_fortnight_a_1_rel" : [ SenseInfo('15170331-n', 0) ],
"_break_v_out_rel" : [ SenseInfo('00364064-v', 15), SenseInfo('00334186-v', 13), SenseInfo('00258665-v', 9), SenseInfo('01369758-v', 8), SenseInfo('00334996-v', 8), SenseInfo('02566528-v', 5), SenseInfo('02073233-v', 4), SenseInfo('02029369-v', 4), SenseInfo('01785395-v', 4), SenseInfo('00362348-v', 4), SenseInfo('02570684-v', 3), SenseInfo('00202569-v', 3), SenseInfo('02668523-v', 2), SenseInfo('01106864-v', 2), SenseInfo('00933821-v', 2), SenseInfo('00558536-v', 2), SenseInfo('00434374-v', 2), SenseInfo('02535716-v', 1), SenseInfo('02030764-v', 1), SenseInfo('01972976-v', 1), SenseInfo('00390215-v', 1), SenseInfo('00202784-v', 1), SenseInfo('02746617-v', 0), SenseInfo('02746449-v', 0), SenseInfo('02681639-v', 0), SenseInfo('02681524-v', 0), SenseInfo('02625187-v', 0), SenseInfo('02600082-v', 0), SenseInfo('02559395-v', 0), SenseInfo('02478469-v', 0), SenseInfo('02431320-v', 0), SenseInfo('02399331-v', 0), SenseInfo('02318165-v', 0), SenseInfo('02101373-v', 0), SenseInfo('01991347-v', 0), SenseInfo('01989053-v', 0), SenseInfo('01896484-v', 0), SenseInfo('01610666-v', 0), SenseInfo('01610463-v', 0), SenseInfo('01597995-v', 0), SenseInfo('01557646-v', 0), SenseInfo('01369346-v', 0), SenseInfo('01298931-v', 0), SenseInfo('01228524-v', 0), SenseInfo('01228396-v', 0), SenseInfo('00935987-v', 0), SenseInfo('00779061-v', 0), SenseInfo('00778745-v', 0), SenseInfo('00744439-v', 0), SenseInfo('00738440-v', 0), SenseInfo('00738314-v', 0), SenseInfo('00551412-v', 0), SenseInfo('00339464-v', 0), SenseInfo('00336260-v', 0), SenseInfo('00258366-v', 0), SenseInfo('00155046-v', 0), SenseInfo('00107739-v', 0), SenseInfo('00107604-v', 0), SenseInfo('00030463-v', 0), SenseInfo('00364064-v', 15), SenseInfo('00334186-v', 13), SenseInfo('00258665-v', 9), SenseInfo('01369758-v', 8), SenseInfo('00334996-v', 8), SenseInfo('02566528-v', 5), SenseInfo('02073233-v', 4), SenseInfo('02029369-v', 4), SenseInfo('01785395-v', 4), SenseInfo('00362348-v', 4), SenseInfo('02570684-v', 3), SenseInfo('00202569-v', 3), SenseInfo('02668523-v', 2), SenseInfo('01106864-v', 2), SenseInfo('00933821-v', 2), SenseInfo('00558536-v', 2), SenseInfo('00434374-v', 2), SenseInfo('02535716-v', 1), SenseInfo('02030764-v', 1), SenseInfo('01972976-v', 1), SenseInfo('00390215-v', 1), SenseInfo('00202784-v', 1), SenseInfo('02746617-v', 0), SenseInfo('02746449-v', 0), SenseInfo('02681639-v', 0), SenseInfo('02681524-v', 0), SenseInfo('02625187-v', 0), SenseInfo('02600082-v', 0), SenseInfo('02559395-v', 0), SenseInfo('02478469-v', 0), SenseInfo('02431320-v', 0), SenseInfo('02399331-v', 0), SenseInfo('02318165-v', 0), SenseInfo('02101373-v', 0), SenseInfo('01991347-v', 0), SenseInfo('01989053-v', 0), SenseInfo('01896484-v', 0), SenseInfo('01610666-v', 0), SenseInfo('01610463-v', 0), SenseInfo('01597995-v', 0), SenseInfo('01557646-v', 0), SenseInfo('01369346-v', 0), SenseInfo('01298931-v', 0), SenseInfo('01228524-v', 0), SenseInfo('01228396-v', 0), SenseInfo('00935987-v', 0), SenseInfo('00779061-v', 0), SenseInfo('00778745-v', 0), SenseInfo('00744439-v', 0), SenseInfo('00738440-v', 0), SenseInfo('00738314-v', 0), SenseInfo('00551412-v', 0), SenseInfo('00339464-v', 0), SenseInfo('00336260-v', 0), SenseInfo('00258366-v', 0), SenseInfo('00155046-v', 0), SenseInfo('00107739-v', 0), SenseInfo('00107604-v', 0), SenseInfo('00030463-v', 0) ],
"_correspondingly_a_1_rel" : [  ],
"_foundry_n_1_rel" : [ SenseInfo('03387653-n', 1) ],
"_prefer_v_1_rel" : [ SenseInfo('01826498-v', 22), SenseInfo('00679389-v', 16), SenseInfo('02400037-v', 1), SenseInfo('02400251-v', 0), SenseInfo('01826498-v', 22), SenseInfo('00679389-v', 16), SenseInfo('02400037-v', 1), SenseInfo('02400251-v', 0) ],
"_militant_n_1_rel" : [ SenseInfo('10315837-n', 0) ],
"_put_v_off_rel" : [ SenseInfo('01494310-v', 138), SenseInfo('01493741-v', 98), SenseInfo('00981276-v', 28), SenseInfo('01160370-v', 6), SenseInfo('02271137-v', 3), SenseInfo('00673448-v', 2), SenseInfo('02111499-v', 0), SenseInfo('01706375-v', 0), SenseInfo('00735571-v', 0), SenseInfo('01494310-v', 138), SenseInfo('01493741-v', 98), SenseInfo('00981276-v', 28), SenseInfo('01160370-v', 6), SenseInfo('02271137-v', 3), SenseInfo('00673448-v', 2), SenseInfo('02111499-v', 0), SenseInfo('01706375-v', 0), SenseInfo('00735571-v', 0) ],
"_numb_v_cause_rel" : [ SenseInfo('02115273-v', 0) ],
"_strait_n_1_rel" : [ SenseInfo('09446115-n', 3), SenseInfo('13936939-n', 0), SenseInfo('09446115-n', 3), SenseInfo('13936939-n', 0) ],
"_sip_v_1_rel" : [ SenseInfo('01170687-v', 7) ],
"_sami_n_1_rel" : [ SenseInfo('09720033-n', 0), SenseInfo('06959427-n', 0) ],
"_moisture_n_1_rel" : [ SenseInfo('14535431-n', 7) ],
"_superficial_a_1_rel" : [ SenseInfo('01873406-a', 4), SenseInfo('02805490-a', 0), SenseInfo('02165432-a', 0), SenseInfo('01873406-a', 4), SenseInfo('02805490-a', 0), SenseInfo('02165432-a', 0) ],
"_army_n_of_rel" : [ SenseInfo('08191230-n', 61), SenseInfo('08183290-n', 2), SenseInfo('08394922-n', 0) ],
"_purge_n_1_rel" : [ SenseInfo('00252662-n', 0), SenseInfo('00252430-n', 0), SenseInfo('00216834-n', 0) ],
"_program_n_of_rel" : [ SenseInfo('05898568-n', 106), SenseInfo('05899087-n', 36), SenseInfo('06619428-n', 5), SenseInfo('06501311-n', 3), SenseInfo('06748466-n', 0), SenseInfo('06676416-n', 0), SenseInfo('06568978-n', 0), SenseInfo('00551215-n', 0), SenseInfo('05898568-n', 106), SenseInfo('05899087-n', 36), SenseInfo('06619428-n', 5), SenseInfo('06501311-n', 3), SenseInfo('06748466-n', 0), SenseInfo('06676416-n', 0), SenseInfo('06568978-n', 0), SenseInfo('00551215-n', 0) ],
"_commerce_n_1_rel" : [ SenseInfo('01090446-n', 10), SenseInfo('08129268-n', 0), SenseInfo('07137622-n', 0) ],
"_advisory_a_1_rel" : [ SenseInfo('01304802-a', 0) ],
"_mow_v_1_rel" : [ SenseInfo('01319562-v', 1), SenseInfo('00034758-v', 0) ],
"_interact_v_with_rel" : [ SenseInfo('02376958-v', 2) ],
"_startac_n_1_rel" : [  ],
"_veil_v_1_rel" : [ SenseInfo('01483247-v', 5), SenseInfo('00313987-v', 0) ],
"_possible_n_1_rel" : [ SenseInfo('05792192-n', 1), SenseInfo('10456514-n', 0) ],
"_year-before_a_1_rel" : [  ],
"_for_p_sel_rel" : [  ],
"_magenta_a_1_rel" : [ SenseInfo('00377524-a', 0) ],
"_overthrow_n_1_rel" : [ SenseInfo('00215683-n', 1), SenseInfo('00554850-n', 0) ],
"_chunk_n_of_rel" : [ SenseInfo('07961016-n', 3), SenseInfo('13758197-n', 0) ],
"_foul_n_1_rel" : [ SenseInfo('00770997-n', 0) ],
"_connective_a_1_rel" : [ SenseInfo('00563980-a', 2) ],
"_kame_n_1_rel" : [  ],
"_topographic_a_1_rel" : [ SenseInfo('03018112-a', 0) ],
"_aftereffect_n_1_rel" : [ SenseInfo('11411501-n', 1), SenseInfo('14311574-n', 0), SenseInfo('11411501-n', 1), SenseInfo('14311574-n', 0) ],
"_tarmac_n_1_rel" : [ SenseInfo('14977188-n', 0), SenseInfo('04394630-n', 0) ],
"_sunblock_n_1_rel" : [ SenseInfo('04357314-n', 0) ],
"_shears_n_1_rel" : [ SenseInfo('11506738-n', 21), SenseInfo('04186709-n', 0), SenseInfo('11506738-n', 21), SenseInfo('04186709-n', 0), SenseInfo('11506738-n', 21), SenseInfo('04186709-n', 0) ],
"_gusty_a_1_rel" : [ SenseInfo('00305700-a', 0), SenseInfo('00305700-a', 0), SenseInfo('00305700-a', 0), SenseInfo('00305700-a', 0) ],
"_jam_x_deg_rel" : [ SenseInfo('07642933-n', 3), SenseInfo('02064131-v', 1), SenseInfo('01993668-v', 1), SenseInfo('01492944-v', 1), SenseInfo('01057034-v', 1), SenseInfo('14409489-n', 0), SenseInfo('08183398-n', 0), SenseInfo('01253379-n', 0), SenseInfo('01525177-v', 0), SenseInfo('01524298-v', 0), SenseInfo('01476483-v', 0) ],
"_gauge_v_1_rel" : [ SenseInfo('00672433-v', 2), SenseInfo('01250374-v', 0), SenseInfo('00919424-v', 0), SenseInfo('00490285-v', 0), SenseInfo('00468116-v', 0), SenseInfo('00395583-v', 0), SenseInfo('00672433-v', 2), SenseInfo('01250374-v', 0), SenseInfo('00919424-v', 0), SenseInfo('00490285-v', 0), SenseInfo('00468116-v', 0), SenseInfo('00395583-v', 0) ],
"_isthmus_n_1_rel" : [ SenseInfo('09319604-n', 0), SenseInfo('05267211-n', 0) ],
"_encompassment_n_1_rel" : [ SenseInfo('14427537-n', 0) ],
"_caravan_v_1_rel" : [ SenseInfo('01949333-v', 0) ],
"_gracefulness_n_1_rel" : [ SenseInfo('05003423-n', 0) ],
"_industrial_a_1_rel" : [ SenseInfo('02748635-a', 20), SenseInfo('01301624-a', 3), SenseInfo('02556901-a', 2), SenseInfo('01188648-a', 0) ],
"_insider_n_1_rel" : [ SenseInfo('10208583-n', 0) ],
"_waiter_n_1_rel" : [ SenseInfo('10763383-n', 4), SenseInfo('10763725-n', 0) ],
"_culinary_a_1_rel" : [ SenseInfo('02707659-a', 0) ],
"_email_n_1_rel" : [ SenseInfo('06279326-n', 0), SenseInfo('06279326-n', 0), SenseInfo('06279326-n', 0), SenseInfo('06279326-n', 0), SenseInfo('06279326-n', 0), SenseInfo('06279326-n', 0), SenseInfo('06279326-n', 0), SenseInfo('06279326-n', 0) ],
"_shout_n_of_rel" : [ SenseInfo('07120524-n', 3) ],
"_sustainable_a_1_rel" : [ SenseInfo('02806261-a', 0) ],
"_unchaste_a_1_rel" : [ SenseInfo('00361509-a', 0), SenseInfo('00361509-a', 0) ],
"_considerably_x_deg_rel" : [ SenseInfo('00014285-r', 19) ],
"_stowaway_n_1_rel" : [ SenseInfo('10660471-n', 0) ],
"_key_a_1_rel" : [ SenseInfo('01277097-a', 8) ],
"_certificate_n_of_rel" : [ SenseInfo('06471345-n', 3), SenseInfo('13416345-n', 0) ],
"_dwindle_v_1_rel" : [ SenseInfo('00267681-v', 9) ],
"_serve_v_as_rel" : [ SenseInfo('02670890-v', 55), SenseInfo('01095218-v', 36), SenseInfo('02670398-v', 24), SenseInfo('02541251-v', 23), SenseInfo('01181295-v', 21), SenseInfo('01180351-v', 20), SenseInfo('02593107-v', 19), SenseInfo('02670578-v', 7), SenseInfo('02709107-v', 3), SenseInfo('02540670-v', 3), SenseInfo('01438681-v', 3), SenseInfo('02669789-v', 0), SenseInfo('02411621-v', 0), SenseInfo('01428011-v', 0), SenseInfo('01077568-v', 0), SenseInfo('02670890-v', 55), SenseInfo('01095218-v', 36), SenseInfo('02670398-v', 24), SenseInfo('02541251-v', 23), SenseInfo('01181295-v', 21), SenseInfo('01180351-v', 20), SenseInfo('02593107-v', 19), SenseInfo('02670578-v', 7), SenseInfo('02709107-v', 3), SenseInfo('02540670-v', 3), SenseInfo('01438681-v', 3), SenseInfo('02669789-v', 0), SenseInfo('02411621-v', 0), SenseInfo('01428011-v', 0), SenseInfo('01077568-v', 0), SenseInfo('02670890-v', 55), SenseInfo('01095218-v', 36), SenseInfo('02670398-v', 24), SenseInfo('02541251-v', 23), SenseInfo('01181295-v', 21), SenseInfo('01180351-v', 20), SenseInfo('02593107-v', 19), SenseInfo('02670578-v', 7), SenseInfo('02709107-v', 3), SenseInfo('02540670-v', 3), SenseInfo('01438681-v', 3), SenseInfo('02669789-v', 0), SenseInfo('02411621-v', 0), SenseInfo('01428011-v', 0), SenseInfo('01077568-v', 0), SenseInfo('02670890-v', 55), SenseInfo('01095218-v', 36), SenseInfo('02670398-v', 24), SenseInfo('02541251-v', 23), SenseInfo('01181295-v', 21), SenseInfo('01180351-v', 20), SenseInfo('02593107-v', 19), SenseInfo('02670578-v', 7), SenseInfo('02709107-v', 3), SenseInfo('02540670-v', 3), SenseInfo('01438681-v', 3), SenseInfo('02669789-v', 0), SenseInfo('02411621-v', 0), SenseInfo('01428011-v', 0), SenseInfo('01077568-v', 0), SenseInfo('02670890-v', 55), SenseInfo('01095218-v', 36), SenseInfo('02670398-v', 24), SenseInfo('02541251-v', 23), SenseInfo('01181295-v', 21), SenseInfo('01180351-v', 20), SenseInfo('02593107-v', 19), SenseInfo('02670578-v', 7), SenseInfo('02709107-v', 3), SenseInfo('02540670-v', 3), SenseInfo('01438681-v', 3), SenseInfo('02669789-v', 0), SenseInfo('02411621-v', 0), SenseInfo('01428011-v', 0), SenseInfo('01077568-v', 0), SenseInfo('02670890-v', 55), SenseInfo('01095218-v', 36), SenseInfo('02670398-v', 24), SenseInfo('02541251-v', 23), SenseInfo('01181295-v', 21), SenseInfo('01180351-v', 20), SenseInfo('02593107-v', 19), SenseInfo('02670578-v', 7), SenseInfo('02709107-v', 3), SenseInfo('02540670-v', 3), SenseInfo('01438681-v', 3), SenseInfo('02669789-v', 0), SenseInfo('02411621-v', 0), SenseInfo('01428011-v', 0), SenseInfo('01077568-v', 0) ],
"_deflate_v_cause_rel" : [ SenseInfo('01436865-v', 0), SenseInfo('01436721-v', 0), SenseInfo('00856234-v', 0), SenseInfo('00562720-v', 0), SenseInfo('00562303-v', 0), SenseInfo('00264705-v', 0) ],
"_archer_n_1_rel" : [ SenseInfo('09805324-n', 0), SenseInfo('09753348-n', 0), SenseInfo('08687525-n', 0), SenseInfo('09805324-n', 0), SenseInfo('09753348-n', 0), SenseInfo('08687525-n', 0) ],
"_smooth_v_1_rel" : [ SenseInfo('01252971-v', 7), SenseInfo('01245637-v', 1), SenseInfo('02313098-v', 0) ],
"_incubus_n_1_rel" : [ SenseInfo('09542868-n', 1), SenseInfo('13936676-n', 0), SenseInfo('10202531-n', 0) ],
"_bet_v_on_rel" : [ SenseInfo('00918580-v', 19), SenseInfo('01155687-v', 0), SenseInfo('00712708-v', 0), SenseInfo('00918580-v', 19), SenseInfo('01155687-v', 0), SenseInfo('00712708-v', 0) ],
"_think_v_1_rel" : [ SenseInfo('00689344-v', 274), SenseInfo('00631737-v', 188), SenseInfo('00628491-v', 111), SenseInfo('00607780-v', 8), SenseInfo('01637166-v', 4), SenseInfo('00723056-v', 3), SenseInfo('00708538-v', 2), SenseInfo('00739340-v', 0), SenseInfo('00739082-v', 0), SenseInfo('00689809-v', 0), SenseInfo('00629738-v', 0), SenseInfo('00608808-v', 0), SenseInfo('00561887-v', 0), SenseInfo('00689344-v', 274), SenseInfo('00631737-v', 188), SenseInfo('00628491-v', 111), SenseInfo('00607780-v', 8), SenseInfo('01637166-v', 4), SenseInfo('00723056-v', 3), SenseInfo('00708538-v', 2), SenseInfo('00739340-v', 0), SenseInfo('00739082-v', 0), SenseInfo('00689809-v', 0), SenseInfo('00629738-v', 0), SenseInfo('00608808-v', 0), SenseInfo('00561887-v', 0), SenseInfo('00689344-v', 274), SenseInfo('00631737-v', 188), SenseInfo('00628491-v', 111), SenseInfo('00607780-v', 8), SenseInfo('01637166-v', 4), SenseInfo('00723056-v', 3), SenseInfo('00708538-v', 2), SenseInfo('00739340-v', 0), SenseInfo('00739082-v', 0), SenseInfo('00689809-v', 0), SenseInfo('00629738-v', 0), SenseInfo('00608808-v', 0), SenseInfo('00561887-v', 0), SenseInfo('00689344-v', 274), SenseInfo('00631737-v', 188), SenseInfo('00628491-v', 111), SenseInfo('00607780-v', 8), SenseInfo('01637166-v', 4), SenseInfo('00723056-v', 3), SenseInfo('00708538-v', 2), SenseInfo('00739340-v', 0), SenseInfo('00739082-v', 0), SenseInfo('00689809-v', 0), SenseInfo('00629738-v', 0), SenseInfo('00608808-v', 0), SenseInfo('00561887-v', 0), SenseInfo('00689344-v', 274), SenseInfo('00631737-v', 188), SenseInfo('00628491-v', 111), SenseInfo('00607780-v', 8), SenseInfo('01637166-v', 4), SenseInfo('00723056-v', 3), SenseInfo('00708538-v', 2), SenseInfo('00739340-v', 0), SenseInfo('00739082-v', 0), SenseInfo('00689809-v', 0), SenseInfo('00629738-v', 0), SenseInfo('00608808-v', 0), SenseInfo('00561887-v', 0), SenseInfo('00689344-v', 274), SenseInfo('00631737-v', 188), SenseInfo('00628491-v', 111), SenseInfo('00607780-v', 8), SenseInfo('01637166-v', 4), SenseInfo('00723056-v', 3), SenseInfo('00708538-v', 2), SenseInfo('00739340-v', 0), SenseInfo('00739082-v', 0), SenseInfo('00689809-v', 0), SenseInfo('00629738-v', 0), SenseInfo('00608808-v', 0), SenseInfo('00561887-v', 0) ],
"_crowd_v_out_rel" : [ SenseInfo('02028722-v', 6), SenseInfo('02649305-v', 3), SenseInfo('02027612-v', 2), SenseInfo('02054864-v', 1) ],
"_when_x_subord_rel" : [  ],
"_forward+of_p_rel" : [  ],
"_eerie_a_1_rel" : [ SenseInfo('01575299-a', 0), SenseInfo('00968522-a', 0) ],
"_boarder_n_1_rel" : [ SenseInfo('10269458-n', 0), SenseInfo('09862479-n', 0), SenseInfo('09862345-n', 0) ],
"_assay_n_1_rel" : [ SenseInfo('05738625-n', 1), SenseInfo('14584390-n', 0), SenseInfo('07219162-n', 0), SenseInfo('00791527-n', 0) ],
"_lengthy_a_1_rel" : [ SenseInfo('01439155-a', 6), SenseInfo('01439155-a', 6), SenseInfo('01439155-a', 6) ],
"_councillor_n_1_rel" : [ SenseInfo('09944763-n', 0) ],
"_of_p_nbar_rel" : [  ],
"_lollipop_n_1_rel" : [ SenseInfo('07615774-n', 0), SenseInfo('07607605-n', 0) ],
"_another_x_deg_rel" : [ SenseInfo('02070188-a', 51) ],
"_whisper_v_to_rel" : [ SenseInfo('00915830-v', 22), SenseInfo('00915830-v', 22) ],
"_counter+narcotic_a_1_rel" : [  ],
"_idiopathic_a_1_rel" : [ SenseInfo('02745739-a', 0) ],
"_second+place_n_1_rel" : [  ],
"_torrent_n_1_rel" : [ SenseInfo('11502102-n', 1), SenseInfo('07407593-n', 1), SenseInfo('13775706-n', 0) ],
"_fen_n_1_rel" : [ SenseInfo('13710219-n', 0), SenseInfo('09347779-n', 0) ],
"_azure_a_1_rel" : [ SenseInfo('00370267-a', 0) ],
"_file_v_1_rel" : [ SenseInfo('01001857-v', 50), SenseInfo('01387022-v', 10), SenseInfo('01920048-v', 3), SenseInfo('00869931-v', 2), SenseInfo('01001643-v', 1) ],
"_line+up_n_1_rel" : [ SenseInfo('06486161-n', 1), SenseInfo('08431205-n', 0), SenseInfo('06486161-n', 1), SenseInfo('08431205-n', 0), SenseInfo('06486161-n', 1), SenseInfo('08431205-n', 0) ],
"_borrow_v_from_rel" : [ SenseInfo('02324026-v', 16), SenseInfo('02346724-v', 5), SenseInfo('02324026-v', 16), SenseInfo('02346724-v', 5) ],
"_collateral_a_1_rel" : [ SenseInfo('01417228-a', 0), SenseInfo('02355521-a', 0), SenseInfo('01854420-a', 0), SenseInfo('01718609-a', 0) ],
"_conservatism_n_1_rel" : [ SenseInfo('06216160-n', 6) ],
"_second_a_1_rel" : [ SenseInfo('02202146-a', 108), SenseInfo('01016436-a', 0), SenseInfo('02202146-a', 108), SenseInfo('01016436-a', 0), SenseInfo('02202146-a', 108), SenseInfo('01016436-a', 0) ],
"_point_n_of_rel" : [ SenseInfo('05865998-n', 51), SenseInfo('08620061-n', 21), SenseInfo('06606808-n', 20), SenseInfo('05817845-n', 17), SenseInfo('13939892-n', 16), SenseInfo('15180528-n', 9), SenseInfo('05984066-n', 6), SenseInfo('13902482-n', 3), SenseInfo('13911872-n', 2), SenseInfo('13610162-n', 2), SenseInfo('09396465-n', 2), SenseInfo('06482401-n', 2), SenseInfo('13794885-n', 1), SenseInfo('04731925-n', 1), SenseInfo('03974215-n', 1), SenseInfo('13830305-n', 0), SenseInfo('13712286-n', 0), SenseInfo('13400150-n', 0), SenseInfo('06843520-n', 0), SenseInfo('06822034-n', 0), SenseInfo('06812289-n', 0), SenseInfo('05071556-n', 0), SenseInfo('04732067-n', 0), SenseInfo('03974769-n', 0), SenseInfo('03974671-n', 0), SenseInfo('03213826-n', 0), SenseInfo('05865998-n', 51), SenseInfo('08620061-n', 21), SenseInfo('06606808-n', 20), SenseInfo('05817845-n', 17), SenseInfo('13939892-n', 16), SenseInfo('15180528-n', 9), SenseInfo('05984066-n', 6), SenseInfo('13902482-n', 3), SenseInfo('13911872-n', 2), SenseInfo('13610162-n', 2), SenseInfo('09396465-n', 2), SenseInfo('06482401-n', 2), SenseInfo('13794885-n', 1), SenseInfo('04731925-n', 1), SenseInfo('03974215-n', 1), SenseInfo('13830305-n', 0), SenseInfo('13712286-n', 0), SenseInfo('13400150-n', 0), SenseInfo('06843520-n', 0), SenseInfo('06822034-n', 0), SenseInfo('06812289-n', 0), SenseInfo('05071556-n', 0), SenseInfo('04732067-n', 0), SenseInfo('03974769-n', 0), SenseInfo('03974671-n', 0), SenseInfo('03213826-n', 0), SenseInfo('05865998-n', 51), SenseInfo('08620061-n', 21), SenseInfo('06606808-n', 20), SenseInfo('05817845-n', 17), SenseInfo('13939892-n', 16), SenseInfo('15180528-n', 9), SenseInfo('05984066-n', 6), SenseInfo('13902482-n', 3), SenseInfo('13911872-n', 2), SenseInfo('13610162-n', 2), SenseInfo('09396465-n', 2), SenseInfo('06482401-n', 2), SenseInfo('13794885-n', 1), SenseInfo('04731925-n', 1), SenseInfo('03974215-n', 1), SenseInfo('13830305-n', 0), SenseInfo('13712286-n', 0), SenseInfo('13400150-n', 0), SenseInfo('06843520-n', 0), SenseInfo('06822034-n', 0), SenseInfo('06812289-n', 0), SenseInfo('05071556-n', 0), SenseInfo('04732067-n', 0), SenseInfo('03974769-n', 0), SenseInfo('03974671-n', 0), SenseInfo('03213826-n', 0), SenseInfo('05865998-n', 51), SenseInfo('08620061-n', 21), SenseInfo('06606808-n', 20), SenseInfo('05817845-n', 17), SenseInfo('13939892-n', 16), SenseInfo('15180528-n', 9), SenseInfo('05984066-n', 6), SenseInfo('13902482-n', 3), SenseInfo('13911872-n', 2), SenseInfo('13610162-n', 2), SenseInfo('09396465-n', 2), SenseInfo('06482401-n', 2), SenseInfo('13794885-n', 1), SenseInfo('04731925-n', 1), SenseInfo('03974215-n', 1), SenseInfo('13830305-n', 0), SenseInfo('13712286-n', 0), SenseInfo('13400150-n', 0), SenseInfo('06843520-n', 0), SenseInfo('06822034-n', 0), SenseInfo('06812289-n', 0), SenseInfo('05071556-n', 0), SenseInfo('04732067-n', 0), SenseInfo('03974769-n', 0), SenseInfo('03974671-n', 0), SenseInfo('03213826-n', 0) ],
"_e+ticket_n_1_rel" : [  ],
"_all+right_a_1_rel" : [ SenseInfo('02081114-a', 10), SenseInfo('02081114-a', 10), SenseInfo('02081114-a', 10), SenseInfo('02081114-a', 10) ],
"_mason_n_1_rel" : [ SenseInfo('11163160-n', 0), SenseInfo('11163041-n', 0), SenseInfo('11162915-n', 0), SenseInfo('10297531-n', 0), SenseInfo('10111144-n', 0) ],
"_pamphlet_n_of_rel" : [ SenseInfo('06413889-n', 1), SenseInfo('06409290-n', 1) ],
"_osteoarthritis_n_1_rel" : [ SenseInfo('14188238-n', 0) ],
"_waterproof_v_1_rel" : [ SenseInfo('01354405-v', 0) ],
"_fence_n_1_rel" : [ SenseInfo('03327234-n', 32), SenseInfo('10085101-n', 0) ],
"_forgive_v_for_rel" : [ SenseInfo('00903385-v', 24), SenseInfo('02564426-v', 1), SenseInfo('00903385-v', 24), SenseInfo('02564426-v', 1), SenseInfo('00903385-v', 24), SenseInfo('02564426-v', 1), SenseInfo('00903385-v', 24), SenseInfo('02564426-v', 1), SenseInfo('00903385-v', 24), SenseInfo('02564426-v', 1) ],
"_murder_v_1_rel" : [ SenseInfo('02482425-v', 5), SenseInfo('00548750-v', 1) ],
"_upgrade_v_1_rel" : [ SenseInfo('00660851-v', 2), SenseInfo('00207184-v', 1), SenseInfo('02397637-v', 0), SenseInfo('00584220-v', 0), SenseInfo('00583991-v', 0) ],
"_marathon_n_1_rel" : [ SenseInfo('00797361-n', 1), SenseInfo('07460546-n', 0), SenseInfo('01286569-n', 0) ],
"_nutrition_n_1_rel" : [ SenseInfo('13523661-n', 0), SenseInfo('07570720-n', 0), SenseInfo('06135915-n', 0) ],
"_call_v_i_rel" : [ SenseInfo('01028748-v', 91), SenseInfo('00971015-v', 51), SenseInfo('00789448-v', 38), SenseInfo('00913065-v', 25), SenseInfo('00792471-v', 25), SenseInfo('02487573-v', 9), SenseInfo('02429810-v', 9), SenseInfo('01067995-v', 1), SenseInfo('01062739-v', 1), SenseInfo('00975036-v', 1), SenseInfo('02643421-v', 0), SenseInfo('02601456-v', 0), SenseInfo('02487901-v', 0), SenseInfo('02359061-v', 0), SenseInfo('02300060-v', 0), SenseInfo('01899017-v', 0), SenseInfo('01068793-v', 0), SenseInfo('00917772-v', 0), SenseInfo('00874002-v', 0), SenseInfo('00869393-v', 0), SenseInfo('00822746-v', 0), SenseInfo('00783523-v', 0), SenseInfo('00754156-v', 0), SenseInfo('00753881-v', 0), SenseInfo('00738747-v', 0), SenseInfo('00738583-v', 0), SenseInfo('00691516-v', 0), SenseInfo('00107231-v', 0) ],
"_do_v_without_rel" : [ SenseInfo('02560585-v', 526), SenseInfo('01712704-v', 173), SenseInfo('02561995-v', 134), SenseInfo('02617567-v', 58), SenseInfo('01645601-v', 35), SenseInfo('02568672-v', 20), SenseInfo('02669789-v', 11), SenseInfo('01619014-v', 9), SenseInfo('00010435-v', 3), SenseInfo('02709107-v', 2), SenseInfo('02523221-v', 2), SenseInfo('00038849-v', 2), SenseInfo('01841772-v', 1) ],
"_misuse_v_1_rel" : [ SenseInfo('01161290-v', 2), SenseInfo('00203213-v', 0), SenseInfo('01161290-v', 2), SenseInfo('00203213-v', 0) ],
"_catalyze_v_1_rel" : [ SenseInfo('00267519-v', 0) ],
"_compiler_n_1_rel" : [ SenseInfo('09946957-n', 0), SenseInfo('06573600-n', 0) ],
"_blissful_a_1_rel" : [ SenseInfo('01148897-a', 1), SenseInfo('01148897-a', 1) ],
"_subdivide_v_cause_rel" : [ SenseInfo('00333277-v', 0), SenseInfo('00333066-v', 0) ],
"_sphere_n_1_rel" : [ SenseInfo('14514039-n', 5), SenseInfo('04274530-n', 5), SenseInfo('08653570-n', 2), SenseInfo('05853100-n', 2), SenseInfo('13899200-n', 0), SenseInfo('13898899-n', 0), SenseInfo('08521267-n', 0) ],
"_extinguish_v_1_rel" : [ SenseInfo('00478217-v', 1), SenseInfo('02761897-v', 0), SenseInfo('00478682-v', 0), SenseInfo('00471711-v', 0), SenseInfo('00470701-v', 0) ],
"_impeachable_a_1_rel" : [  ],
"_flattish_a_1_rel" : [  ],
"_card_v_1_rel" : [ SenseInfo('01356256-v', 0), SenseInfo('00663894-v', 0) ],
"_submit_v_1_rel" : [ SenseInfo('00878636-v', 12), SenseInfo('00878136-v', 8), SenseInfo('01118081-v', 6), SenseInfo('02262752-v', 4), SenseInfo('02589013-v', 2), SenseInfo('00878348-v', 2), SenseInfo('00669762-v', 2), SenseInfo('01072641-v', 1), SenseInfo('02310328-v', 0), SenseInfo('00732394-v', 0) ],
"_plenitude_n_1_rel" : [ SenseInfo('05115568-n', 1) ],
"_years+end_n_1_rel" : [  ],
"_dyed-in-the-wool_a_1_rel" : [  ],
"_bastard_a_1_rel" : [ SenseInfo('01117477-a', 0) ],
"_mount_v_up_rel" : [ SenseInfo('01343204-v', 10), SenseInfo('00433232-v', 8), SenseInfo('00407633-v', 6), SenseInfo('01649124-v', 4), SenseInfo('01923414-v', 3), SenseInfo('01921964-v', 3), SenseInfo('01649251-v', 0), SenseInfo('01429322-v', 0), SenseInfo('01343204-v', 10), SenseInfo('00433232-v', 8), SenseInfo('00407633-v', 6), SenseInfo('01649124-v', 4), SenseInfo('01923414-v', 3), SenseInfo('01921964-v', 3), SenseInfo('01649251-v', 0), SenseInfo('01429322-v', 0) ],
"_offensive_n_1_rel" : [ SenseInfo('00980038-n', 1) ],
"_confidence_n_1_rel" : [ SenseInfo('05697363-n', 13), SenseInfo('07526505-n', 6), SenseInfo('14483744-n', 3), SenseInfo('13929852-n', 0), SenseInfo('06673435-n', 0), SenseInfo('05697363-n', 13), SenseInfo('07526505-n', 6), SenseInfo('14483744-n', 3), SenseInfo('13929852-n', 0), SenseInfo('06673435-n', 0) ],
"_baggage_n_1_rel" : [ SenseInfo('02774630-n', 1), SenseInfo('09832456-n', 0), SenseInfo('02774921-n', 0) ],
"_clasp_n_1_rel" : [ SenseInfo('03038281-n', 0), SenseInfo('00812526-n', 0) ],
"_computer_n_1_rel" : [ SenseInfo('03082979-n', 6), SenseInfo('09887034-n', 0) ],
"_tidings_n_1_rel" : [ SenseInfo('06642138-n', 3), SenseInfo('06642138-n', 3) ],
"_timing_n_1_rel" : [ SenseInfo('05046009-n', 6), SenseInfo('00807078-n', 0) ],
"_hue_n_1_rel" : [ SenseInfo('04975122-n', 6) ],
"_grass_v_1_rel" : [ SenseInfo('01137055-v', 1), SenseInfo('01603032-v', 0), SenseInfo('01580348-v', 0), SenseInfo('01209025-v', 0), SenseInfo('01204581-v', 0), SenseInfo('00841986-v', 0) ],
"_smolder_v_1_rel" : [ SenseInfo('00377569-v', 3), SenseInfo('01772699-v', 0) ],
"_relate_v_to_rel" : [ SenseInfo('00713167-v', 15), SenseInfo('02676054-v', 9), SenseInfo('00953058-v', 7), SenseInfo('02724417-v', 4), SenseInfo('02458103-v', 2), SenseInfo('00713167-v', 15), SenseInfo('02676054-v', 9), SenseInfo('00953058-v', 7), SenseInfo('02724417-v', 4), SenseInfo('02458103-v', 2), SenseInfo('00713167-v', 15), SenseInfo('02676054-v', 9), SenseInfo('00953058-v', 7), SenseInfo('02724417-v', 4), SenseInfo('02458103-v', 2), SenseInfo('00713167-v', 15), SenseInfo('02676054-v', 9), SenseInfo('00953058-v', 7), SenseInfo('02724417-v', 4), SenseInfo('02458103-v', 2) ],
"_believable_n_1_rel" : [ SenseInfo('00644839-a', 1) ],
"_summons_n_1_rel" : [ SenseInfo('07186528-n', 0), SenseInfo('07169098-n', 0), SenseInfo('06556692-n', 0) ],
"_weightless_a_1_rel" : [ SenseInfo('01187777-a', 0) ],
"_worker_n_1_rel" : [ SenseInfo('09632518-n', 29), SenseInfo('10481711-n', 4), SenseInfo('02207449-n', 4), SenseInfo('09767197-n', 0), SenseInfo('09632518-n', 29), SenseInfo('10481711-n', 4), SenseInfo('02207449-n', 4), SenseInfo('09767197-n', 0), SenseInfo('09632518-n', 29), SenseInfo('10481711-n', 4), SenseInfo('02207449-n', 4), SenseInfo('09767197-n', 0) ],
"_all_a_1_rel" : [ SenseInfo('02269286-a', 247), SenseInfo('00521584-a', 3), SenseInfo('02269286-a', 247), SenseInfo('00521584-a', 3) ],
"_calamitous_a_1_rel" : [ SenseInfo('01050088-a', 0) ],
"_poll_n_1_rel" : [ SenseInfo('05800998-n', 4), SenseInfo('05539595-n', 0), SenseInfo('05539012-n', 0), SenseInfo('01817346-n', 0), SenseInfo('00653811-n', 0) ],
"_autograph_n_1_rel" : [ SenseInfo('06407094-n', 0), SenseInfo('06404907-n', 0) ],
"_smell_v_1_rel" : [ SenseInfo('02124748-v', 14), SenseInfo('02123672-v', 12), SenseInfo('02124332-v', 3), SenseInfo('02194723-v', 0), SenseInfo('00589469-v', 0), SenseInfo('02124748-v', 14), SenseInfo('02123672-v', 12), SenseInfo('02124332-v', 3), SenseInfo('02194723-v', 0), SenseInfo('00589469-v', 0) ],
"_powerbook_n_1_rel" : [  ],
"_chase_v_after_rel" : [ SenseInfo('02001858-v', 10), SenseInfo('02535093-v', 0), SenseInfo('01583881-v', 0), SenseInfo('01277649-v', 0) ],
"_puzzle_v_out_rel" : [ SenseInfo('00622384-v', 6), SenseInfo('01831308-v', 0), SenseInfo('00622384-v', 6), SenseInfo('01831308-v', 0) ],
"_snowmobile_v_dir_rel" : [ SenseInfo('01957273-v', 0) ],
"_bolster_n_1_rel" : [ SenseInfo('02865509-n', 1) ],
"_radio_n_1_rel" : [ SenseInfo('06277135-n', 9), SenseInfo('04043733-n', 8), SenseInfo('04041544-n', 6), SenseInfo('06277135-n', 9), SenseInfo('04043733-n', 8), SenseInfo('04041544-n', 6) ],
"_self-insure_v_1_rel" : [  ],
"_look_v_at_rel" : [ SenseInfo('02130524-v', 274), SenseInfo('02133435-v', 126), SenseInfo('00033599-v', 25), SenseInfo('02153709-v', 8), SenseInfo('02693319-v', 1), SenseInfo('02549581-v', 1), SenseInfo('00929362-v', 1), SenseInfo('00720063-v', 1), SenseInfo('02658447-v', 0), SenseInfo('00712708-v', 0) ],
"_meteor_n_1_rel" : [ SenseInfo('09353109-n', 6), SenseInfo('11483990-n', 0) ],
"_get_v_to_rel" : [ SenseInfo('02210855-v', 235), SenseInfo('00149583-v', 157), SenseInfo('00120796-v', 82), SenseInfo('00522751-v', 64), SenseInfo('02005948-v', 58), SenseInfo('01433294-v', 45), SenseInfo('02108026-v', 36), SenseInfo('01153947-v', 14), SenseInfo('02355596-v', 9), SenseInfo('00770437-v', 7), SenseInfo('01215421-v', 4), SenseInfo('00094460-v', 4), SenseInfo('00087736-v', 4), SenseInfo('01066036-v', 3), SenseInfo('00120316-v', 3), SenseInfo('01026975-v', 2), SenseInfo('00589904-v', 2), SenseInfo('01505958-v', 1), SenseInfo('01401115-v', 1), SenseInfo('00639849-v', 1), SenseInfo('02359340-v', 0), SenseInfo('02208265-v', 0), SenseInfo('02189398-v', 0), SenseInfo('02109645-v', 0), SenseInfo('02108654-v', 0), SenseInfo('02010864-v', 0), SenseInfo('02006573-v', 0), SenseInfo('01771194-v', 0), SenseInfo('01771039-v', 0), SenseInfo('01738107-v', 0), SenseInfo('01643297-v', 0), SenseInfo('01565211-v', 0), SenseInfo('00622384-v', 0), SenseInfo('00345761-v', 0), SenseInfo('00065639-v', 0), SenseInfo('00054628-v', 0) ],
"_too_a_also-2_rel" : [  ],
"_faultless_a_1_rel" : [ SenseInfo('01750847-a', 0), SenseInfo('01750847-a', 0) ],
"_recommend_v_1_rel" : [ SenseInfo('00875141-v', 50), SenseInfo('00882948-v', 6), SenseInfo('00578733-v', 0), SenseInfo('00875141-v', 50), SenseInfo('00882948-v', 6), SenseInfo('00578733-v', 0) ],
"_customer_n_of_rel" : [ SenseInfo('09984659-n', 25), SenseInfo('09984659-n', 25), SenseInfo('09984659-n', 25) ],
"_reunion_n_1_rel" : [ SenseInfo('08478371-n', 1), SenseInfo('00382474-n', 1) ],
"_custody_n_1_rel" : [ SenseInfo('13999663-n', 1), SenseInfo('01147347-n', 0), SenseInfo('00818678-n', 0) ],
"_as+in_x_rel" : [ SenseInfo('15220625-n', 0) ],
"_pecan_n_1_rel" : [ SenseInfo('12321304-n', 0), SenseInfo('12321077-n', 0), SenseInfo('07774719-n', 0) ],
"_masterwort_n_1_rel" : [ SenseInfo('12934036-n', 0) ],
"_relaxed_a_1_rel" : [ SenseInfo('02407603-a', 2) ],
"_phantom_n_1_rel" : [ SenseInfo('09547111-n', 2), SenseInfo('05897553-n', 1) ],
"_slash_n_1_rel" : [ SenseInfo('14287113-n', 0), SenseInfo('09437098-n', 0), SenseInfo('06844903-n', 0), SenseInfo('00388065-n', 0) ],
"_fine-tune_v_1_rel" : [ SenseInfo('00474017-v', 0), SenseInfo('00302763-v', 0), SenseInfo('00295697-v', 0), SenseInfo('00474017-v', 0), SenseInfo('00302763-v', 0), SenseInfo('00295697-v', 0) ],
"_skateboard_n_1_rel" : [ SenseInfo('04225987-n', 0) ],
"_picket_n_1_rel" : [ SenseInfo('10271216-n', 2), SenseInfo('08216295-n', 2), SenseInfo('10431770-n', 0), SenseInfo('03930087-n', 0), SenseInfo('03929952-n', 0), SenseInfo('00423563-n', 0) ],
"_description_n_of_rel" : [ SenseInfo('06724763-n', 27), SenseInfo('07201365-n', 0), SenseInfo('05840076-n', 0) ],
"_loan_n_1_rel" : [ SenseInfo('13398953-n', 19), SenseInfo('06293460-n', 0) ],
"_eastern_a_1_rel" : [ SenseInfo('00823971-a', 8), SenseInfo('00826959-a', 1), SenseInfo('00823832-a', 1), SenseInfo('00825604-a', 0), SenseInfo('00823665-a', 0), SenseInfo('00823971-a', 8), SenseInfo('00826959-a', 1), SenseInfo('00823832-a', 1), SenseInfo('00825604-a', 0), SenseInfo('00823665-a', 0) ],
"_default_v_on_rel" : [ SenseInfo('02253766-v', 1) ],
"_hash_n_1_rel" : [ SenseInfo('07869391-n', 0), SenseInfo('03497182-n', 0) ],
"_aftermath_n_1_rel" : [ SenseInfo('11411610-n', 0), SenseInfo('07294019-n', 0) ],
"_serve_v_up_rel" : [ SenseInfo('02670890-v', 55), SenseInfo('01095218-v', 36), SenseInfo('02670398-v', 24), SenseInfo('02541251-v', 23), SenseInfo('01181295-v', 21), SenseInfo('01180351-v', 20), SenseInfo('02593107-v', 19), SenseInfo('02670578-v', 7), SenseInfo('02709107-v', 3), SenseInfo('02540670-v', 3), SenseInfo('01438681-v', 3), SenseInfo('02669789-v', 0), SenseInfo('02411621-v', 0), SenseInfo('01428011-v', 0), SenseInfo('01077568-v', 0) ],
"_coloration_n_1_rel" : [ SenseInfo('04988478-n', 0), SenseInfo('04975988-n', 0), SenseInfo('00161739-n', 0), SenseInfo('04988478-n', 0), SenseInfo('04975988-n', 0), SenseInfo('00161739-n', 0) ],
"_unlace_v_1_rel" : [ SenseInfo('01284461-v', 1), SenseInfo('01284461-v', 1) ],
"_laudanum_n_1_rel" : [ SenseInfo('03647108-n', 1) ],
"_settle_v_1_rel" : [ SenseInfo('01988458-v', 16), SenseInfo('00698855-v', 10), SenseInfo('00763399-v', 8), SenseInfo('00413876-v', 7), SenseInfo('00764902-v', 5), SenseInfo('01989873-v', 4), SenseInfo('00415398-v', 3), SenseInfo('00558673-v', 2), SenseInfo('00539338-v', 2), SenseInfo('01987058-v', 1), SenseInfo('01465921-v', 1), SenseInfo('00798091-v', 1), SenseInfo('00764032-v', 1), SenseInfo('02254258-v', 0), SenseInfo('01986715-v', 0), SenseInfo('01986551-v', 0), SenseInfo('01986185-v', 0), SenseInfo('01493619-v', 0), SenseInfo('01092128-v', 0), SenseInfo('00481941-v', 0), SenseInfo('00415044-v', 0), SenseInfo('00342164-v', 0) ],
"_partly_x_deg_rel" : [ SenseInfo('00007703-r', 19) ],
"_transcend_v_1_rel" : [ SenseInfo('02669477-v', 3), SenseInfo('02669081-v', 1) ],
"_pretty+well_x_deg_rel" : [  ],
"_avail_v_of_rel" : [ SenseInfo('01161561-v', 3), SenseInfo('02549048-v', 2), SenseInfo('01193569-v', 0), SenseInfo('01161561-v', 3), SenseInfo('02549048-v', 2), SenseInfo('01193569-v', 0) ],
"_notebook_n_of_rel" : [ SenseInfo('06415419-n', 2), SenseInfo('03832673-n', 0) ],
"_helpfulness_n_1_rel" : [ SenseInfo('05149695-n', 0), SenseInfo('04841664-n', 0) ],
"_rma_n_1_rel" : [  ],
"_beg_v_1_rel" : [ SenseInfo('00759269-v', 11), SenseInfo('00782057-v', 5), SenseInfo('02270815-v', 2), SenseInfo('00810226-v', 0), SenseInfo('00759269-v', 11), SenseInfo('00782057-v', 5), SenseInfo('02270815-v', 2), SenseInfo('00810226-v', 0), SenseInfo('00759269-v', 11), SenseInfo('00782057-v', 5), SenseInfo('02270815-v', 2), SenseInfo('00810226-v', 0), SenseInfo('00759269-v', 11), SenseInfo('00782057-v', 5), SenseInfo('02270815-v', 2), SenseInfo('00810226-v', 0), SenseInfo('00759269-v', 11), SenseInfo('00782057-v', 5), SenseInfo('02270815-v', 2), SenseInfo('00810226-v', 0), SenseInfo('00759269-v', 11), SenseInfo('00782057-v', 5), SenseInfo('02270815-v', 2), SenseInfo('00810226-v', 0) ],
"_preventive_a_1_rel" : [ SenseInfo('01167269-a', 1), SenseInfo('01763813-a', 0) ],
"_thermophilic_a_1_rel" : [  ],
"_buoyant_a_1_rel" : [ SenseInfo('01187072-a', 1), SenseInfo('00363621-a', 1) ],
"_dam_v_up_rel" : [ SenseInfo('01477224-v', 1) ],
"_anthracite_n_1_rel" : [ SenseInfo('14814921-n', 0) ],
"_park_n_1_rel" : [ SenseInfo('08615149-n', 13), SenseInfo('08615374-n', 5), SenseInfo('02782778-n', 2), SenseInfo('11222655-n', 0), SenseInfo('08615638-n', 0), SenseInfo('03890881-n', 0), SenseInfo('08615149-n', 13), SenseInfo('08615374-n', 5), SenseInfo('02782778-n', 2), SenseInfo('11222655-n', 0), SenseInfo('08615638-n', 0), SenseInfo('03890881-n', 0) ],
"_verse_n_1_rel" : [ SenseInfo('07092592-n', 2), SenseInfo('06381869-n', 2), SenseInfo('06384708-n', 1) ],
"_edifice_n_1_rel" : [ SenseInfo('02913152-n', 2) ],
"_recollection_n_of_rel" : [ SenseInfo('05761918-n', 4), SenseInfo('05761559-n', 3), SenseInfo('05935292-n', 0) ],
"_promotion_n_of_rel" : [ SenseInfo('07247071-n', 4), SenseInfo('00198451-n', 1), SenseInfo('07251984-n', 0), SenseInfo('00249780-n', 0) ],
"_unevaluated_a_1_rel" : [  ],
"_adversary_n_1_rel" : [ SenseInfo('09773245-n', 1) ],
"_singular_a_1_rel" : [ SenseInfo('01678417-a', 3), SenseInfo('00968010-a', 1), SenseInfo('00494622-a', 1), SenseInfo('02183421-a', 0), SenseInfo('02182862-a', 0), SenseInfo('02215087-a', 0) ],
"_comparative_a_1_rel" : [ SenseInfo('02990954-a', 4), SenseInfo('00006032-a', 0), SenseInfo('02990954-a', 4), SenseInfo('00006032-a', 0) ],
"_color_n_1_rel" : [ SenseInfo('04956594-n', 48), SenseInfo('05193338-n', 4), SenseInfo('04988478-n', 3), SenseInfo('07968354-n', 2), SenseInfo('04677952-n', 1), SenseInfo('14984973-n', 0), SenseInfo('05844663-n', 0), SenseInfo('04674968-n', 0), SenseInfo('04956594-n', 48), SenseInfo('05193338-n', 4), SenseInfo('04988478-n', 3), SenseInfo('07968354-n', 2), SenseInfo('04677952-n', 1), SenseInfo('14984973-n', 0), SenseInfo('05844663-n', 0), SenseInfo('04674968-n', 0) ],
"_screen+name_n_1_rel" : [  ],
"_turntable_n_1_rel" : [ SenseInfo('04501550-n', 1), SenseInfo('04501837-n', 0), SenseInfo('04501713-n', 0) ],
"_regarding_p_rel" : [  ],
"_compensate_v_for_rel" : [ SenseInfo('02672540-v', 5), SenseInfo('02250625-v', 1), SenseInfo('02672859-v', 0), SenseInfo('02519991-v', 0), SenseInfo('02253456-v', 0), SenseInfo('02249741-v', 0) ],
"_lieutenant+general_n_1_rel" : [ SenseInfo('10260166-n', 0), SenseInfo('10260166-n', 0), SenseInfo('10260166-n', 0) ],
"_talk_v_of_rel" : [ SenseInfo('00962447-v', 108), SenseInfo('00941990-v', 26), SenseInfo('00963570-v', 8), SenseInfo('00952841-v', 4), SenseInfo('00937208-v', 2), SenseInfo('00830761-v', 0) ],
"_ultimately_x_deg_rel" : [ SenseInfo('00047903-r', 5) ],
"_unnerving_a_for_rel" : [ SenseInfo('00195383-a', 0), SenseInfo('00195383-a', 0), SenseInfo('00195383-a', 0) ],
"_sensitive_a_to_rel" : [ SenseInfo('02103481-a', 13), SenseInfo('02105990-a', 7), SenseInfo('02102484-a', 0), SenseInfo('01712753-a', 0), SenseInfo('00416164-a', 0), SenseInfo('02103481-a', 13), SenseInfo('02105990-a', 7), SenseInfo('02102484-a', 0), SenseInfo('01712753-a', 0), SenseInfo('00416164-a', 0) ],
"_jockey_v_1_rel" : [ SenseInfo('01104624-v', 1), SenseInfo('01110143-v', 0), SenseInfo('01087074-v', 0) ],
"_loom_v_1_rel" : [ SenseInfo('02696961-v', 7), SenseInfo('02696503-v', 4), SenseInfo('02744061-v', 3), SenseInfo('01672384-v', 0) ],
"_hopscotch_n_1_rel" : [ SenseInfo('00485081-n', 1) ],
"_import_v_1_rel" : [ SenseInfo('02346136-v', 4), SenseInfo('02232722-v', 0), SenseInfo('00932636-v', 0) ],
"_example_n_of_rel" : [ SenseInfo('05820620-n', 45), SenseInfo('05937112-n', 13), SenseInfo('05925366-n', 5), SenseInfo('06672752-n', 2), SenseInfo('07308889-n', 0), SenseInfo('00729919-n', 0) ],
"_doings_n_1_rel" : [ SenseInfo('01220984-n', 0), SenseInfo('01220984-n', 0) ],
"_whiten_v_cause_rel" : [ SenseInfo('00280301-v', 1) ],
"_self-improvement_n_1_rel" : [ SenseInfo('00261258-n', 0) ],
"_footgear_n_1_rel" : [ SenseInfo('03380867-n', 0) ],
"_archaeology_n_1_rel" : [ SenseInfo('06144081-n', 0) ],
"_in+the+meanwhile_p_rel" : [  ],
"_disabled_n_1_rel" : [ SenseInfo('07946288-n', 2) ],
"_terrace_n_1_rel" : [ SenseInfo('03899768-n', 2), SenseInfo('09456207-n', 0), SenseInfo('08431721-n', 0) ],
"_federation_n_1_rel" : [ SenseInfo('08303504-n', 0), SenseInfo('08303275-n', 0), SenseInfo('01153305-n', 0), SenseInfo('08303504-n', 0), SenseInfo('08303275-n', 0), SenseInfo('01153305-n', 0) ],
"_kinetics_n_1_rel" : [ SenseInfo('06113597-n', 0) ],
"_fort_n_1_rel" : [ SenseInfo('03420559-n', 2), SenseInfo('03386011-n', 1), SenseInfo('03420559-n', 2), SenseInfo('03386011-n', 1) ],
"_gaff_n_1_rel" : [ SenseInfo('03410303-n', 0), SenseInfo('03410147-n', 0), SenseInfo('03410022-n', 0) ],
"_jail_n_1_rel" : [ SenseInfo('03592245-n', 3) ],
"_eject_v_cause_rel" : [ SenseInfo('01468576-v', 2), SenseInfo('00104868-v', 1), SenseInfo('02076999-v', 0), SenseInfo('01375637-v', 0), SenseInfo('01468576-v', 2), SenseInfo('00104868-v', 1), SenseInfo('02076999-v', 0), SenseInfo('01375637-v', 0) ],
"_irrational_n_1_rel" : [ SenseInfo('13730584-n', 0) ],
"_gloominess_n_1_rel" : [ SenseInfo('14525365-n', 0), SenseInfo('07533257-n', 0), SenseInfo('04631470-n', 0) ],
"_jumble_n_1_rel" : [ SenseInfo('14500567-n', 3), SenseInfo('07633861-n', 0), SenseInfo('05953416-n', 0) ],
"_curry_v_1_rel" : [ SenseInfo('02192225-v', 0), SenseInfo('00516294-v', 0), SenseInfo('00045639-v', 0) ],
"_leach_v_cause_rel" : [ SenseInfo('02071837-v', 0), SenseInfo('02071627-v', 0), SenseInfo('00488617-v', 0) ],
"_aim_v_at_rel" : [ SenseInfo('01151110-v', 8), SenseInfo('00708980-v', 7), SenseInfo('01026975-v', 5), SenseInfo('00713015-v', 3), SenseInfo('01150559-v', 2), SenseInfo('00955472-v', 2), SenseInfo('00705517-v', 2), SenseInfo('01151110-v', 8), SenseInfo('00708980-v', 7), SenseInfo('01026975-v', 5), SenseInfo('00713015-v', 3), SenseInfo('01150559-v', 2), SenseInfo('00955472-v', 2), SenseInfo('00705517-v', 2) ],
"_rebellious_a_1_rel" : [ SenseInfo('02331088-a', 1), SenseInfo('00589960-a', 1), SenseInfo('00963671-a', 0) ],
"_acclimatize_v_1_rel" : [ SenseInfo('00393677-v', 1) ],
"_spellbound_a_1_rel" : [ SenseInfo('00865848-a', 3) ],
"_counter+attack_v_1_rel" : [ SenseInfo('01125084-v', 1), SenseInfo('01125084-v', 1), SenseInfo('01125084-v', 1), SenseInfo('01125084-v', 1), SenseInfo('01125084-v', 1), SenseInfo('01125084-v', 1), SenseInfo('01125084-v', 1), SenseInfo('01125084-v', 1) ],
"_pastoral_a_1_rel" : [ SenseInfo('02860564-a', 1), SenseInfo('02895044-a', 0), SenseInfo('02051179-a', 0) ],
"_dinner_n_1_rel" : [ SenseInfo('07575726-n', 25), SenseInfo('08253815-n', 5), SenseInfo('07575726-n', 25), SenseInfo('08253815-n', 5) ],
"_jacket_n_1_rel" : [ SenseInfo('03589791-n', 12), SenseInfo('03590306-n', 3), SenseInfo('03139089-n', 1), SenseInfo('07711471-n', 0), SenseInfo('03590475-n', 0) ],
"_pyramidal_a_1_rel" : [ SenseInfo('01810998-a', 0) ],
"_induction_n_of_rel" : [ SenseInfo('07453195-n', 2), SenseInfo('11468172-n', 1), SenseInfo('05774415-n', 1), SenseInfo('05827253-n', 0), SenseInfo('00238527-n', 0), SenseInfo('00156390-n', 0) ],
"_erosive_a_1_rel" : [ SenseInfo('00588062-a', 0), SenseInfo('00587376-a', 0) ],
"_cableway_n_1_rel" : [  ],
"_specimen_n_1_rel" : [ SenseInfo('05822239-n', 5), SenseInfo('05266879-n', 3) ],
"_voltage_n_of_rel" : [ SenseInfo('11523538-n', 8), SenseInfo('11493827-n', 2) ],
"_kind_n_of_rel" : [ SenseInfo('05839024-n', 126) ],
"_notorious_a_1_rel" : [ SenseInfo('01984411-a', 5), SenseInfo('01984411-a', 5) ],
"_after+tax_a_1_rel" : [  ],
"_potency_n_1_rel" : [ SenseInfo('05196582-n', 2), SenseInfo('05034225-n', 1), SenseInfo('14482620-n', 0), SenseInfo('14051728-n', 0) ],
"_sneak_v_1_rel" : [ SenseInfo('01911888-v', 2), SenseInfo('02597449-v', 1), SenseInfo('02276866-v', 0), SenseInfo('02231328-v', 0), SenseInfo('01911888-v', 2), SenseInfo('02597449-v', 1), SenseInfo('02276866-v', 0), SenseInfo('02231328-v', 0) ],
"_harmonic_a_1_rel" : [ SenseInfo('02737772-a', 1), SenseInfo('02738346-a', 0), SenseInfo('02738091-a', 0), SenseInfo('01163589-a', 0), SenseInfo('01163320-a', 0) ],
"_clout_v_1_rel" : [ SenseInfo('01412759-v', 0) ],
"_honorable_a_1_rel" : [ SenseInfo('01222360-a', 1), SenseInfo('01226240-a', 0), SenseInfo('02035086-a', 0), SenseInfo('01983162-a', 0), SenseInfo('01222360-a', 1), SenseInfo('01226240-a', 0), SenseInfo('02035086-a', 0), SenseInfo('01983162-a', 0), SenseInfo('01222360-a', 1), SenseInfo('01226240-a', 0), SenseInfo('02035086-a', 0), SenseInfo('01983162-a', 0), SenseInfo('01222360-a', 1), SenseInfo('01226240-a', 0), SenseInfo('02035086-a', 0), SenseInfo('01983162-a', 0), SenseInfo('01222360-a', 1), SenseInfo('01226240-a', 0), SenseInfo('02035086-a', 0), SenseInfo('01983162-a', 0) ],
"_shabby_a_1_rel" : [ SenseInfo('02583043-a', 4), SenseInfo('01228159-a', 0), SenseInfo('02583043-a', 4), SenseInfo('01228159-a', 0), SenseInfo('02583043-a', 4), SenseInfo('01228159-a', 0) ],
"_rostrum_n_1_rel" : [ SenseInfo('03159640-n', 1), SenseInfo('02452813-n', 0) ],
"_loon_n_1_rel" : [ SenseInfo('10271451-n', 1), SenseInfo('02049088-n', 1), SenseInfo('10598904-n', 0) ],
"_eligible_a_1_rel" : [ SenseInfo('00851744-a', 5), SenseInfo('00851744-a', 5) ],
"_limb_n_1_rel" : [ SenseInfo('05560244-n', 6), SenseInfo('13163803-n', 0), SenseInfo('08592494-n', 0), SenseInfo('03669094-n', 0), SenseInfo('03668906-n', 0), SenseInfo('02737833-n', 0) ],
"_superhuman_a_1_rel" : [ SenseInfo('01260873-a', 0) ],
"_precleaner_n_1_rel" : [  ],
"_referee_v_1_rel" : [ SenseInfo('01085237-v', 0), SenseInfo('00855794-v', 0) ],
"_customary_a_1_rel" : [ SenseInfo('00606079-a', 4), SenseInfo('00489491-a', 4), SenseInfo('00606079-a', 4), SenseInfo('00489491-a', 4) ],
"_pivot_v_1_rel" : [ SenseInfo('02046572-v', 1) ],
"_one-by-one_a_2_rel" : [  ],
"_loophole_n_1_rel" : [ SenseInfo('06604548-n', 2), SenseInfo('03689443-n', 1) ],
"_spillover_n_1_rel" : [ SenseInfo('11513880-n', 0) ],
"_robot_n_1_rel" : [ SenseInfo('02761392-n', 0) ],
"_redoubt_n_1_rel" : [ SenseInfo('04066476-n', 0), SenseInfo('04066388-n', 0) ],
"_unattached_a_1_rel" : [ SenseInfo('00568881-a', 1), SenseInfo('00158407-a', 0), SenseInfo('00160288-a', 0), SenseInfo('00568881-a', 1), SenseInfo('00158407-a', 0), SenseInfo('00160288-a', 0) ],
"_maximum_a_1_rel" : [ SenseInfo('01495725-a', 36) ],
"_ramification_n_1_rel" : [ SenseInfo('00388392-n', 1), SenseInfo('13913849-n', 0), SenseInfo('07423899-n', 0), SenseInfo('05083200-n', 0) ],
"_shoo_v_out_rel" : [ SenseInfo('02003480-v', 0) ],
"_stem_n_1_rel" : [ SenseInfo('06300193-n', 23), SenseInfo('13129165-n', 10), SenseInfo('04184095-n', 1), SenseInfo('04313771-n', 0), SenseInfo('02880008-n', 0), SenseInfo('00441501-n', 0) ],
"_funny_a_1_rel" : [ SenseInfo('01265308-a', 14), SenseInfo('00968010-a', 9), SenseInfo('01917594-a', 4), SenseInfo('02545023-a', 0), SenseInfo('01265308-a', 14), SenseInfo('00968010-a', 9), SenseInfo('01917594-a', 4), SenseInfo('02545023-a', 0), SenseInfo('01265308-a', 14), SenseInfo('00968010-a', 9), SenseInfo('01917594-a', 4), SenseInfo('02545023-a', 0), SenseInfo('01265308-a', 14), SenseInfo('00968010-a', 9), SenseInfo('01917594-a', 4), SenseInfo('02545023-a', 0) ],
"_heel_v_1_rel" : [ SenseInfo('02038791-v', 0), SenseInfo('01992114-v', 0), SenseInfo('01751545-v', 0), SenseInfo('01403987-v', 0), SenseInfo('00533671-v', 0) ],
"_enterprise_n_1_rel" : [ SenseInfo('00796886-n', 8), SenseInfo('08056231-n', 5), SenseInfo('04836074-n', 0) ],
"_clinch_n_1_rel" : [ SenseInfo('00059728-n', 1), SenseInfo('03042984-n', 0), SenseInfo('03042829-n', 0), SenseInfo('03036866-n', 0), SenseInfo('00417859-n', 0) ],
"_bedeck_v_1_rel" : [ SenseInfo('01679980-v', 0) ],
"_whisper_n_1_rel" : [ SenseInfo('07130341-n', 6), SenseInfo('07392783-n', 0), SenseInfo('07130341-n', 6), SenseInfo('07392783-n', 0) ],
"_dye_n_1_rel" : [ SenseInfo('14985383-n', 0) ],
"_coalition_n_1_rel" : [ SenseInfo('08293982-n', 1), SenseInfo('14418662-n', 0), SenseInfo('00382109-n', 0) ],
"_mystery_n_1_rel" : [ SenseInfo('05685538-n', 18), SenseInfo('06370792-n', 0) ],
"_quarterly_a_1_rel" : [ SenseInfo('02998046-a', 1), SenseInfo('02998046-a', 1) ],
"_sophisticate_n_1_rel" : [ SenseInfo('10625285-n', 1) ],
"_long_a_1_rel" : [ SenseInfo('01437963-a', 118), SenseInfo('01433493-a', 105), SenseInfo('02386125-a', 2), SenseInfo('02005756-a', 0), SenseInfo('01444434-a', 0), SenseInfo('01444022-a', 0), SenseInfo('02274869-a', 0), SenseInfo('01895296-a', 0), SenseInfo('00015589-a', 0), SenseInfo('01437963-a', 118), SenseInfo('01433493-a', 105), SenseInfo('02386125-a', 2), SenseInfo('02005756-a', 0), SenseInfo('01444434-a', 0), SenseInfo('01444022-a', 0), SenseInfo('02274869-a', 0), SenseInfo('01895296-a', 0), SenseInfo('00015589-a', 0), SenseInfo('01437963-a', 118), SenseInfo('01433493-a', 105), SenseInfo('02386125-a', 2), SenseInfo('02005756-a', 0), SenseInfo('01444434-a', 0), SenseInfo('01444022-a', 0), SenseInfo('02274869-a', 0), SenseInfo('01895296-a', 0), SenseInfo('00015589-a', 0), SenseInfo('01437963-a', 118), SenseInfo('01433493-a', 105), SenseInfo('02386125-a', 2), SenseInfo('02005756-a', 0), SenseInfo('01444434-a', 0), SenseInfo('01444022-a', 0), SenseInfo('02274869-a', 0), SenseInfo('01895296-a', 0), SenseInfo('00015589-a', 0), SenseInfo('01437963-a', 118), SenseInfo('01433493-a', 105), SenseInfo('02386125-a', 2), SenseInfo('02005756-a', 0), SenseInfo('01444434-a', 0), SenseInfo('01444022-a', 0), SenseInfo('02274869-a', 0), SenseInfo('01895296-a', 0), SenseInfo('00015589-a', 0), SenseInfo('01437963-a', 118), SenseInfo('01433493-a', 105), SenseInfo('02386125-a', 2), SenseInfo('02005756-a', 0), SenseInfo('01444434-a', 0), SenseInfo('01444022-a', 0), SenseInfo('02274869-a', 0), SenseInfo('01895296-a', 0), SenseInfo('00015589-a', 0) ],
"_signal_v_to_rel" : [ SenseInfo('01039330-v', 4), SenseInfo('00921300-v', 3) ],
"_inboard_a_1_rel" : [ SenseInfo('01291234-a', 1) ],
"_plate_n_of_rel" : [ SenseInfo('03528901-n', 6), SenseInfo('03959936-n', 4), SenseInfo('03960664-n', 3), SenseInfo('03959485-n', 3), SenseInfo('13768850-n', 1), SenseInfo('09395457-n', 0), SenseInfo('07657664-n', 0), SenseInfo('07579787-n', 0), SenseInfo('05581349-n', 0), SenseInfo('03960950-n', 0), SenseInfo('03960783-n', 0), SenseInfo('03960490-n', 0), SenseInfo('03960374-n', 0), SenseInfo('03959701-n', 0), SenseInfo('03176386-n', 0) ],
"_meaning_n_1_rel" : [ SenseInfo('06601327-n', 48), SenseInfo('05919866-n', 31) ],
"_churn_n_1_rel" : [ SenseInfo('03029445-n', 0) ],
"_invert_v_1_rel" : [ SenseInfo('00387153-v', 1), SenseInfo('00386965-v', 0), SenseInfo('00386715-v', 0) ],
"_move_v_on_rel" : [ SenseInfo('01835496-v', 110), SenseInfo('01850315-v', 57), SenseInfo('01831531-v', 52), SenseInfo('01855606-v', 20), SenseInfo('02372605-v', 15), SenseInfo('00014549-v', 7), SenseInfo('00124442-v', 6), SenseInfo('02367363-v', 3), SenseInfo('01767949-v', 3), SenseInfo('01649999-v', 3), SenseInfo('01771390-v', 2), SenseInfo('02355959-v', 1), SenseInfo('00539110-v', 1), SenseInfo('02598863-v', 0), SenseInfo('01076615-v', 0), SenseInfo('00879356-v', 0) ],
"_athletes_a_1_rel" : [  ],
"_messenger_n_1_rel" : [ SenseInfo('10311021-n', 7) ],
"_memento_n_1_rel" : [ SenseInfo('05813822-n', 0) ],
"_watershed_n_1_rel" : [ SenseInfo('08679369-n', 1), SenseInfo('08518940-n', 0), SenseInfo('07417851-n', 0) ],
"_ditch_v_1_rel" : [ SenseInfo('02228268-v', 0), SenseInfo('02227362-v', 0), SenseInfo('02224945-v', 0), SenseInfo('01980920-v', 0), SenseInfo('01562891-v', 0), SenseInfo('01311896-v', 0) ],
"_mast_n_1_rel" : [ SenseInfo('03726760-n', 3), SenseInfo('12280364-n', 0), SenseInfo('07805872-n', 0), SenseInfo('03726993-n', 0) ],
"_bale_v_1_rel" : [ SenseInfo('01386200-v', 0) ],
"_scoop_v_up_rel" : [ SenseInfo('01312371-v', 0), SenseInfo('01109259-v', 0) ],
"_wizard_n_1_rel" : [ SenseInfo('09762509-n', 2), SenseInfo('10625860-n', 0) ],
"_square_a_1_rel" : [ SenseInfo('02043217-a', 7), SenseInfo('02318464-a', 0), SenseInfo('02558528-a', 0), SenseInfo('01709681-a', 0), SenseInfo('00766102-a', 0), SenseInfo('00607857-a', 0), SenseInfo('02043217-a', 7), SenseInfo('02318464-a', 0), SenseInfo('02558528-a', 0), SenseInfo('01709681-a', 0), SenseInfo('00766102-a', 0), SenseInfo('00607857-a', 0), SenseInfo('02043217-a', 7), SenseInfo('02318464-a', 0), SenseInfo('02558528-a', 0), SenseInfo('01709681-a', 0), SenseInfo('00766102-a', 0), SenseInfo('00607857-a', 0) ],
"_happening+artist_n_1_rel" : [  ],
"_ethiopic_a_1_rel" : [  ],
"_yell_v_1_rel" : [ SenseInfo('00913065-v', 18), SenseInfo('00912833-v', 6), SenseInfo('00913065-v', 18), SenseInfo('00912833-v', 6) ],
"_promise_n_of_rel" : [ SenseInfo('07226545-n', 8), SenseInfo('05950733-n', 8), SenseInfo('07226545-n', 8), SenseInfo('05950733-n', 8), SenseInfo('07226545-n', 8), SenseInfo('05950733-n', 8), SenseInfo('07226545-n', 8), SenseInfo('05950733-n', 8) ],
"_decline_n_1_rel" : [ SenseInfo('13457378-n', 4), SenseInfo('14422488-n', 2), SenseInfo('13456567-n', 1), SenseInfo('09265620-n', 0) ],
"_find_v_mental_rel" : [ SenseInfo('02248465-v', 159), SenseInfo('02154508-v', 141), SenseInfo('02285629-v', 86), SenseInfo('00918872-v', 57), SenseInfo('00715239-v', 57), SenseInfo('02128873-v', 45), SenseInfo('02213336-v', 41), SenseInfo('01637982-v', 34), SenseInfo('00721437-v', 29), SenseInfo('02212275-v', 16), SenseInfo('00971999-v', 16), SenseInfo('00522751-v', 13), SenseInfo('02197781-v', 11), SenseInfo('02247977-v', 0), SenseInfo('02021653-v', 0), SenseInfo('00250691-v', 0), SenseInfo('02248465-v', 159), SenseInfo('02154508-v', 141), SenseInfo('02285629-v', 86), SenseInfo('00918872-v', 57), SenseInfo('00715239-v', 57), SenseInfo('02128873-v', 45), SenseInfo('02213336-v', 41), SenseInfo('01637982-v', 34), SenseInfo('00721437-v', 29), SenseInfo('02212275-v', 16), SenseInfo('00971999-v', 16), SenseInfo('00522751-v', 13), SenseInfo('02197781-v', 11), SenseInfo('02247977-v', 0), SenseInfo('02021653-v', 0), SenseInfo('00250691-v', 0) ],
"_abuse_v_1_rel" : [ SenseInfo('02516594-v', 3), SenseInfo('00203213-v', 2), SenseInfo('00845299-v', 0), SenseInfo('00203556-v', 0) ],
"_debate_n_1_rel" : [ SenseInfo('07140978-n', 17), SenseInfo('07242104-n', 5) ],
"_glorious_a_1_rel" : [ SenseInfo('01120925-a', 5), SenseInfo('01285376-a', 0), SenseInfo('00219389-a', 0) ],
"_watchful_a_1_rel" : [ SenseInfo('00091311-a', 0), SenseInfo('00187176-a', 0) ],
"_reel_v_off_rel" : [ SenseInfo('01924882-v', 2), SenseInfo('02046755-v', 1), SenseInfo('01523105-v', 0) ],
"_occasion_n_of_rel" : [ SenseInfo('07416714-n', 14), SenseInfo('07447261-n', 6), SenseInfo('09179264-n', 3), SenseInfo('15245829-n', 0), SenseInfo('14485064-n', 0) ],
"_pretty+much_x_deg_rel" : [ SenseInfo('00022717-r', 3), SenseInfo('00022717-r', 3) ],
"_fog_v_1_rel" : [ SenseInfo('02157731-v', 0) ],
"_trot_v_out_rel" : [ SenseInfo('01901447-v', 10), SenseInfo('01960779-v', 2), SenseInfo('01901660-v', 0) ],
"_stallion_n_1_rel" : [ SenseInfo('02377181-n', 0) ],
"_shut_v_out_rel" : [ SenseInfo('01345109-v', 10), SenseInfo('01346978-v', 2), SenseInfo('02449340-v', 1) ],
"_creeps_n_1_rel" : [ SenseInfo('14263089-n', 0), SenseInfo('07519983-n', 0), SenseInfo('14263089-n', 0), SenseInfo('07519983-n', 0) ],
"_while_n_1_rel" : [ SenseInfo('15246353-n', 23) ],
"_faithful_a_to_rel" : [ SenseInfo('00958880-a', 5), SenseInfo('00022219-a', 1), SenseInfo('00960629-a', 0), SenseInfo('00958880-a', 5), SenseInfo('00022219-a', 1), SenseInfo('00960629-a', 0), SenseInfo('00958880-a', 5), SenseInfo('00022219-a', 1), SenseInfo('00960629-a', 0) ],
"_headmaster_n_1_rel" : [ SenseInfo('10164233-n', 2) ],
"_reflect_v_1_rel" : [ SenseInfo('02136892-v', 41), SenseInfo('00630380-v', 18), SenseInfo('02136271-v', 17), SenseInfo('02765924-v', 5), SenseInfo('02136754-v', 0), SenseInfo('00821765-v', 0), SenseInfo('00821580-v', 0), SenseInfo('02136892-v', 41), SenseInfo('00630380-v', 18), SenseInfo('02136271-v', 17), SenseInfo('02765924-v', 5), SenseInfo('02136754-v', 0), SenseInfo('00821765-v', 0), SenseInfo('00821580-v', 0) ],
"_documentary_a_1_rel" : [ SenseInfo('02896789-a', 0), SenseInfo('01934026-a', 0) ],
"_publicize_v_1_rel" : [ SenseInfo('00954608-v', 3), SenseInfo('00975902-v', 2) ],
"_wriggle_v_1_rel" : [ SenseInfo('01868370-v', 2) ],
"_prima+donna_n_1_rel" : [ SenseInfo('10471859-n', 0), SenseInfo('10471732-n', 0), SenseInfo('10471859-n', 0), SenseInfo('10471732-n', 0) ],
"_benevolence_n_1_rel" : [ SenseInfo('07545717-n', 0), SenseInfo('04840285-n', 0), SenseInfo('01226679-n', 0) ],
"_anneal_v_1_rel" : [ SenseInfo('00303056-v', 0) ],
"_grieve_v_over_rel" : [ SenseInfo('01797347-v', 1), SenseInfo('01797582-v', 0) ],
"_pencil_v_1_rel" : [ SenseInfo('01688604-v', 0) ],
"_truculence_n_1_rel" : [ SenseInfo('04644161-n', 1) ],
"_turbulence_n_1_rel" : [ SenseInfo('11520989-n', 1), SenseInfo('14524383-n', 0), SenseInfo('13979173-n', 0) ],
"_zeppelin_n_1_rel" : [ SenseInfo('11406141-n', 0), SenseInfo('04614372-n', 0) ],
"_southbound_a_1_rel" : [ SenseInfo('01602683-a', 1) ],
"_steady_a_1_rel" : [ SenseInfo('02301560-a', 11), SenseInfo('02291336-a', 0), SenseInfo('02095542-a', 0), SenseInfo('01990653-a', 0), SenseInfo('01067003-a', 0), SenseInfo('00919445-a', 0), SenseInfo('02301560-a', 11), SenseInfo('02291336-a', 0), SenseInfo('02095542-a', 0), SenseInfo('01990653-a', 0), SenseInfo('01067003-a', 0), SenseInfo('00919445-a', 0), SenseInfo('02301560-a', 11), SenseInfo('02291336-a', 0), SenseInfo('02095542-a', 0), SenseInfo('01990653-a', 0), SenseInfo('01067003-a', 0), SenseInfo('00919445-a', 0), SenseInfo('02301560-a', 11), SenseInfo('02291336-a', 0), SenseInfo('02095542-a', 0), SenseInfo('01990653-a', 0), SenseInfo('01067003-a', 0), SenseInfo('00919445-a', 0) ],
"_first+time_a_1_rel" : [  ],
"_same_n_1_rel" : [ SenseInfo('09720033-n', 0), SenseInfo('06959427-n', 0) ],
"_gentleness_n_1_rel" : [ SenseInfo('05069853-n', 0), SenseInfo('04910973-n', 0) ],
"_specialize_v_1_rel" : [ SenseInfo('00437449-v', 3), SenseInfo('01021973-v', 2), SenseInfo('00437732-v', 2), SenseInfo('02446164-v', 0), SenseInfo('00119266-v', 0), SenseInfo('00437449-v', 3), SenseInfo('01021973-v', 2), SenseInfo('00437732-v', 2), SenseInfo('02446164-v', 0), SenseInfo('00119266-v', 0) ],
"_isle_n_1_rel" : [ SenseInfo('09319456-n', 1) ],
"_bleary_a_1_rel" : [ SenseInfo('02432562-a', 1), SenseInfo('00781644-a', 0), SenseInfo('02432562-a', 1), SenseInfo('00781644-a', 0), SenseInfo('02432562-a', 1), SenseInfo('00781644-a', 0) ],
"_trifler_n_1_rel" : [ SenseInfo('10729330-n', 0) ],
"_clip_v_1_rel" : [ SenseInfo('01456463-v', 2), SenseInfo('01901447-v', 0), SenseInfo('01367616-v', 0), SenseInfo('01321002-v', 0), SenseInfo('00292877-v', 0), SenseInfo('01456463-v', 2), SenseInfo('01901447-v', 0), SenseInfo('01367616-v', 0), SenseInfo('01321002-v', 0), SenseInfo('00292877-v', 0) ],
"_front_n_1_rel" : [ SenseInfo('08573472-n', 20), SenseInfo('08573674-n', 15), SenseInfo('05940302-n', 2), SenseInfo('03398467-n', 2), SenseInfo('10113583-n', 1), SenseInfo('14514491-n', 0), SenseInfo('11460488-n', 0), SenseInfo('08642632-n', 0), SenseInfo('08626080-n', 0), SenseInfo('08464601-n', 0), SenseInfo('08573472-n', 20), SenseInfo('08573674-n', 15), SenseInfo('05940302-n', 2), SenseInfo('03398467-n', 2), SenseInfo('10113583-n', 1), SenseInfo('14514491-n', 0), SenseInfo('11460488-n', 0), SenseInfo('08642632-n', 0), SenseInfo('08626080-n', 0), SenseInfo('08464601-n', 0) ],
"_canadian_a_1_rel" : [ SenseInfo('02982473-a', 1) ],
"_look+out_n_for_rel" : [ SenseInfo('10271216-n', 0), SenseInfo('08597176-n', 0), SenseInfo('03688943-n', 0), SenseInfo('00881545-n', 0), SenseInfo('10271216-n', 0), SenseInfo('08597176-n', 0), SenseInfo('03688943-n', 0), SenseInfo('00881545-n', 0) ],
"_copyleft_n_1_rel" : [  ],
"_doll_v_up_rel" : [  ],
"_cash_v_1_rel" : [ SenseInfo('02256354-v', 2) ],
"_quip_n_1_rel" : [ SenseInfo('07153727-n', 0), SenseInfo('06767777-n', 0), SenseInfo('07153727-n', 0), SenseInfo('06767777-n', 0) ],
"_escapement_n_1_rel" : [ SenseInfo('03296081-n', 0) ],
"_beady_a_1_rel" : [ SenseInfo('00280245-a', 1), SenseInfo('00056660-a', 0) ],
"_strike_v_up_rel" : [ SenseInfo('01410223-v', 18), SenseInfo('01767949-v', 16), SenseInfo('01236164-v', 14), SenseInfo('01123887-v', 7), SenseInfo('00923622-v', 5), SenseInfo('01209135-v', 4), SenseInfo('02412647-v', 3), SenseInfo('02611976-v', 2), SenseInfo('02526811-v', 2), SenseInfo('01209426-v', 2), SenseInfo('00143540-v', 2), SenseInfo('02286687-v', 1), SenseInfo('01675073-v', 1), SenseInfo('01549420-v', 1), SenseInfo('02108791-v', 0), SenseInfo('02104161-v', 0), SenseInfo('01982395-v', 0), SenseInfo('01639105-v', 0), SenseInfo('01308008-v', 0), SenseInfo('01228235-v', 0), SenseInfo('00635904-v', 0) ],
"_objection_n_to_rel" : [ SenseInfo('07246742-n', 10), SenseInfo('07208338-n', 3), SenseInfo('01177033-n', 2), SenseInfo('01025678-n', 0), SenseInfo('07246742-n', 10), SenseInfo('07208338-n', 3), SenseInfo('01177033-n', 2), SenseInfo('01025678-n', 0) ],
"_dairy_n_1_rel" : [ SenseInfo('03159535-n', 1) ],
"_amble_n_1_rel" : [ SenseInfo('00284101-n', 0) ],
"_fall_v_1_rel" : [ SenseInfo('01972298-v', 43), SenseInfo('01970826-v', 21), SenseInfo('00147815-v', 16), SenseInfo('02729963-v', 6), SenseInfo('02756821-v', 4), SenseInfo('02528985-v', 4), SenseInfo('02620213-v', 3), SenseInfo('02611976-v', 3), SenseInfo('02304507-v', 3), SenseInfo('00342443-v', 3), SenseInfo('00151689-v', 3), SenseInfo('02565911-v', 2), SenseInfo('02385153-v', 2), SenseInfo('02358655-v', 2), SenseInfo('02099413-v', 1), SenseInfo('02661015-v', 0), SenseInfo('02566092-v', 0), SenseInfo('02358922-v', 0), SenseInfo('02230056-v', 0), SenseInfo('02229828-v', 0), SenseInfo('02229550-v', 0), SenseInfo('02037839-v', 0), SenseInfo('01984317-v', 0), SenseInfo('01984119-v', 0), SenseInfo('01542668-v', 0), SenseInfo('00561375-v', 0), SenseInfo('00561266-v', 0), SenseInfo('00530177-v', 0), SenseInfo('00360678-v', 0), SenseInfo('00346839-v', 0), SenseInfo('00342314-v', 0), SenseInfo('00342164-v', 0), SenseInfo('01972298-v', 43), SenseInfo('01970826-v', 21), SenseInfo('00147815-v', 16), SenseInfo('02729963-v', 6), SenseInfo('02756821-v', 4), SenseInfo('02528985-v', 4), SenseInfo('02620213-v', 3), SenseInfo('02611976-v', 3), SenseInfo('02304507-v', 3), SenseInfo('00342443-v', 3), SenseInfo('00151689-v', 3), SenseInfo('02565911-v', 2), SenseInfo('02385153-v', 2), SenseInfo('02358655-v', 2), SenseInfo('02099413-v', 1), SenseInfo('02661015-v', 0), SenseInfo('02566092-v', 0), SenseInfo('02358922-v', 0), SenseInfo('02230056-v', 0), SenseInfo('02229828-v', 0), SenseInfo('02229550-v', 0), SenseInfo('02037839-v', 0), SenseInfo('01984317-v', 0), SenseInfo('01984119-v', 0), SenseInfo('01542668-v', 0), SenseInfo('00561375-v', 0), SenseInfo('00561266-v', 0), SenseInfo('00530177-v', 0), SenseInfo('00360678-v', 0), SenseInfo('00346839-v', 0), SenseInfo('00342314-v', 0), SenseInfo('00342164-v', 0), SenseInfo('01972298-v', 43), SenseInfo('01970826-v', 21), SenseInfo('00147815-v', 16), SenseInfo('02729963-v', 6), SenseInfo('02756821-v', 4), SenseInfo('02528985-v', 4), SenseInfo('02620213-v', 3), SenseInfo('02611976-v', 3), SenseInfo('02304507-v', 3), SenseInfo('00342443-v', 3), SenseInfo('00151689-v', 3), SenseInfo('02565911-v', 2), SenseInfo('02385153-v', 2), SenseInfo('02358655-v', 2), SenseInfo('02099413-v', 1), SenseInfo('02661015-v', 0), SenseInfo('02566092-v', 0), SenseInfo('02358922-v', 0), SenseInfo('02230056-v', 0), SenseInfo('02229828-v', 0), SenseInfo('02229550-v', 0), SenseInfo('02037839-v', 0), SenseInfo('01984317-v', 0), SenseInfo('01984119-v', 0), SenseInfo('01542668-v', 0), SenseInfo('00561375-v', 0), SenseInfo('00561266-v', 0), SenseInfo('00530177-v', 0), SenseInfo('00360678-v', 0), SenseInfo('00346839-v', 0), SenseInfo('00342314-v', 0), SenseInfo('00342164-v', 0) ],
"_demonstrate_v_to_rel" : [ SenseInfo('02148788-v', 24), SenseInfo('00664788-v', 22), SenseInfo('00820976-v', 2), SenseInfo('02521816-v', 1), SenseInfo('02148788-v', 24), SenseInfo('00664788-v', 22), SenseInfo('00820976-v', 2), SenseInfo('02521816-v', 1) ],
"_resort_n_1_rel" : [ SenseInfo('08640531-n', 1), SenseInfo('08581503-n', 0), SenseInfo('05155123-n', 0), SenseInfo('01208597-n', 0), SenseInfo('08640531-n', 1), SenseInfo('08581503-n', 0), SenseInfo('05155123-n', 0), SenseInfo('01208597-n', 0), SenseInfo('08640531-n', 1), SenseInfo('08581503-n', 0), SenseInfo('05155123-n', 0), SenseInfo('01208597-n', 0) ],
"_ring_v_up_rel" : [ SenseInfo('02180898-v', 15), SenseInfo('02183787-v', 7), SenseInfo('02181538-v', 5), SenseInfo('00789448-v', 1), SenseInfo('01467370-v', 0), SenseInfo('01297401-v', 0) ],
"_acceptive_a_1_rel" : [ SenseInfo('00075952-a', 0), SenseInfo('01985557-a', 0) ],
"_forget_v_1_rel" : [ SenseInfo('00610167-v', 61), SenseInfo('00609100-v', 21), SenseInfo('00614829-v', 9), SenseInfo('00613018-v', 0), SenseInfo('00610167-v', 61), SenseInfo('00609100-v', 21), SenseInfo('00614829-v', 9), SenseInfo('00613018-v', 0), SenseInfo('00610167-v', 61), SenseInfo('00609100-v', 21), SenseInfo('00614829-v', 9), SenseInfo('00613018-v', 0), SenseInfo('00610167-v', 61), SenseInfo('00609100-v', 21), SenseInfo('00614829-v', 9), SenseInfo('00613018-v', 0) ],
"_unusual_a_for_rel" : [ SenseInfo('00490035-a', 24), SenseInfo('00967129-a', 1), SenseInfo('00488857-a', 1), SenseInfo('00490035-a', 24), SenseInfo('00967129-a', 1), SenseInfo('00488857-a', 1), SenseInfo('00490035-a', 24), SenseInfo('00967129-a', 1), SenseInfo('00488857-a', 1), SenseInfo('00490035-a', 24), SenseInfo('00967129-a', 1), SenseInfo('00488857-a', 1), SenseInfo('00490035-a', 24), SenseInfo('00967129-a', 1), SenseInfo('00488857-a', 1), SenseInfo('00490035-a', 24), SenseInfo('00967129-a', 1), SenseInfo('00488857-a', 1) ],
"_brace_n_1_rel" : [ SenseInfo('02887209-n', 1), SenseInfo('13743605-n', 0), SenseInfo('07985223-n', 0), SenseInfo('06842165-n', 0), SenseInfo('02887683-n', 0), SenseInfo('02887489-n', 0), SenseInfo('02887079-n', 0), SenseInfo('02886907-n', 0), SenseInfo('02886599-n', 0) ],
"_sub_a_1_rel" : [ SenseInfo('07697825-n', 0), SenseInfo('04347754-n', 0) ],
"_ginkgo_n_1_rel" : [ SenseInfo('11664418-n', 1) ],
"_adhesive_n_1_rel" : [ SenseInfo('14702416-n', 3), SenseInfo('14702416-n', 3), SenseInfo('14702416-n', 3), SenseInfo('14702416-n', 3), SenseInfo('14702416-n', 3) ],
"_hunch_n_1_rel" : [ SenseInfo('05919034-n', 6), SenseInfo('00406114-n', 0) ],
"_sage_n_1_rel" : [ SenseInfo('10546202-n', 1), SenseInfo('07820497-n', 1), SenseInfo('12864545-n', 0) ],
"_goldfinch_n_1_rel" : [ SenseInfo('01532325-n', 0), SenseInfo('01531178-n', 0) ],
"_consistence_n_1_rel" : [ SenseInfo('04745932-n', 1), SenseInfo('04934546-n', 0) ],
"_in+which+case_x_rel" : [  ],
"_swivel_v_1_rel" : [ SenseInfo('02046572-v', 2) ],
"_platoon_n_1_rel" : [ SenseInfo('08214470-n', 6), SenseInfo('08214698-n', 2), SenseInfo('08215044-n', 0) ],
"_duplex_n_1_rel" : [ SenseInfo('03257210-n', 0), SenseInfo('03257065-n', 0) ],
"_nonetheless_a_1_rel" : [  ],
"_hide_v_out_rel" : [ SenseInfo('02144835-v', 28), SenseInfo('02145814-v', 6), SenseInfo('01582200-v', 0), SenseInfo('00313987-v', 0) ],
"_repression_n_of_rel" : [ SenseInfo('13996571-n', 1), SenseInfo('13550089-n', 0), SenseInfo('00420712-n', 0) ],
"_manouver_v_1_rel" : [  ],
"_muscle_v_out_rel" : [ SenseInfo('02019431-v', 0) ],
"_mold_n_1_rel" : [ SenseInfo('13913566-n', 1), SenseInfo('03779370-n', 1), SenseInfo('14953564-n', 0), SenseInfo('13516176-n', 0), SenseInfo('13077033-n', 0), SenseInfo('07938594-n', 0), SenseInfo('04732709-n', 0), SenseInfo('03779621-n', 0), SenseInfo('13913566-n', 1), SenseInfo('03779370-n', 1), SenseInfo('14953564-n', 0), SenseInfo('13516176-n', 0), SenseInfo('13077033-n', 0), SenseInfo('07938594-n', 0), SenseInfo('04732709-n', 0), SenseInfo('03779621-n', 0) ],
"_disruptive_a_1_rel" : [ SenseInfo('01923720-a', 2) ],
"_surreptitious_a_1_rel" : [ SenseInfo('02088974-a', 0), SenseInfo('01706465-a', 0) ],
"_windshield_n_1_rel" : [ SenseInfo('04590553-n', 3) ],
"_bluish_a_1_rel" : [ SenseInfo('00370869-a', 1) ],
"_stepmother_n_1_rel" : [ SenseInfo('10654827-n', 4) ],
"_wreath_v_1_rel" : [  ],
"_bedside_n_1_rel" : [ SenseInfo('08649711-n', 1) ],
"_lad_n_1_rel" : [ SenseInfo('09908025-n', 4), SenseInfo('09871229-n', 1) ],
"_away_p_rel" : [ SenseInfo('00232936-r', 70), SenseInfo('00233295-r', 21), SenseInfo('00234052-r', 13), SenseInfo('00234553-r', 3), SenseInfo('00235254-r', 2), SenseInfo('00234747-r', 2), SenseInfo('00235438-r', 1), SenseInfo('01847864-a', 1), SenseInfo('01219938-a', 0), SenseInfo('00235570-r', 0), SenseInfo('00235070-r', 0), SenseInfo('00234951-r', 0), SenseInfo('00233687-r', 0), SenseInfo('00023655-a', 0) ],
"_wood_n_1_rel" : [ SenseInfo('15098161-n', 14), SenseInfo('08438533-n', 10), SenseInfo('11395895-n', 0), SenseInfo('11395773-n', 0), SenseInfo('11395609-n', 0), SenseInfo('11395466-n', 0), SenseInfo('04598582-n', 0), SenseInfo('04597066-n', 0) ],
"_otherwise_a_1_rel" : [ SenseInfo('02071301-a', 0), SenseInfo('02071301-a', 0), SenseInfo('02071301-a', 0), SenseInfo('02071301-a', 0) ],
"_enable_v_1_rel" : [ SenseInfo('00512877-v', 44), SenseInfo('00512877-v', 44), SenseInfo('00512877-v', 44) ],
"_cuff_v_1_rel" : [ SenseInfo('01417162-v', 0), SenseInfo('01288201-v', 0) ],
"_pin_v_down_rel" : [ SenseInfo('01207149-v', 2), SenseInfo('01368264-v', 1), SenseInfo('01444723-v', 0), SenseInfo('01121621-v', 0), SenseInfo('01207149-v', 2), SenseInfo('01368264-v', 1), SenseInfo('01444723-v', 0), SenseInfo('01121621-v', 0), SenseInfo('01207149-v', 2), SenseInfo('01368264-v', 1), SenseInfo('01444723-v', 0), SenseInfo('01121621-v', 0) ],
"_groom_v_1_rel" : [ SenseInfo('02387034-v', 1), SenseInfo('00045639-v', 1), SenseInfo('00040353-v', 0) ],
"_lag_n_of_rel" : [ SenseInfo('01067577-n', 1), SenseInfo('15272887-n', 0), SenseInfo('04307269-n', 0) ],
"_monastic_a_1_rel" : [ SenseInfo('02578894-a', 5) ],
"_unfold_v_1_rel" : [ SenseInfo('00293760-v', 5), SenseInfo('02144101-v', 1), SenseInfo('02054989-v', 1), SenseInfo('01579813-v', 0) ],
"_likely_a_1_rel" : [ SenseInfo('01411451-a', 58), SenseInfo('01413247-a', 4), SenseInfo('01884176-a', 0), SenseInfo('00645169-a', 0), SenseInfo('01411451-a', 58), SenseInfo('01413247-a', 4), SenseInfo('01884176-a', 0), SenseInfo('00645169-a', 0), SenseInfo('01411451-a', 58), SenseInfo('01413247-a', 4), SenseInfo('01884176-a', 0), SenseInfo('00645169-a', 0), SenseInfo('01411451-a', 58), SenseInfo('01413247-a', 4), SenseInfo('01884176-a', 0), SenseInfo('00645169-a', 0), SenseInfo('01411451-a', 58), SenseInfo('01413247-a', 4), SenseInfo('01884176-a', 0), SenseInfo('00645169-a', 0), SenseInfo('01411451-a', 58), SenseInfo('01413247-a', 4), SenseInfo('01884176-a', 0), SenseInfo('00645169-a', 0), SenseInfo('01411451-a', 58), SenseInfo('01413247-a', 4), SenseInfo('01884176-a', 0), SenseInfo('00645169-a', 0) ],
"_struggle_n_1_rel" : [ SenseInfo('00788973-n', 16), SenseInfo('00958896-n', 11), SenseInfo('00622068-n', 1), SenseInfo('00788973-n', 16), SenseInfo('00958896-n', 11), SenseInfo('00622068-n', 1) ],
"_embrace_v_1_rel" : [ SenseInfo('02629793-v', 5), SenseInfo('01424456-v', 3), SenseInfo('00601822-v', 1) ],
"_frustrate_v_1_rel" : [ SenseInfo('02558172-v', 5), SenseInfo('01803003-v', 0), SenseInfo('02558172-v', 5), SenseInfo('01803003-v', 0), SenseInfo('02558172-v', 5), SenseInfo('01803003-v', 0), SenseInfo('02558172-v', 5), SenseInfo('01803003-v', 0) ],
"_being_n_1_rel" : [ SenseInfo('13954253-n', 12), SenseInfo('00004475-n', 6), SenseInfo('13954253-n', 12), SenseInfo('00004475-n', 6), SenseInfo('13954253-n', 12), SenseInfo('00004475-n', 6) ],
"_toothbrush_n_1_rel" : [ SenseInfo('04453156-n', 1), SenseInfo('05262422-n', 0) ],
"_lash_v_1_rel" : [ SenseInfo('01411085-v', 4), SenseInfo('01877946-v', 0), SenseInfo('01398032-v', 0), SenseInfo('01303707-v', 0) ],
"_inhabit_v_1_rel" : [ SenseInfo('02649830-v', 3), SenseInfo('02654416-v', 1), SenseInfo('02755773-v', 0) ],
"_level_v_1_rel" : [ SenseInfo('01152896-v', 4), SenseInfo('01661804-v', 1), SenseInfo('01307142-v', 1), SenseInfo('01152214-v', 0), SenseInfo('00964237-v', 0), SenseInfo('00356649-v', 0) ],
"_bowl_v_over_rel" : [ SenseInfo('01887324-v', 0), SenseInfo('01616738-v', 0), SenseInfo('01146507-v', 0) ],
"_long-lasting_a_1_rel" : [ SenseInfo('01439496-a', 0), SenseInfo('01439496-a', 0) ],
"_worry_v_about_rel" : [ SenseInfo('01767163-v', 32), SenseInfo('01766748-v', 9), SenseInfo('01765908-v', 9), SenseInfo('02678438-v', 0), SenseInfo('01559473-v', 0), SenseInfo('01251109-v', 0), SenseInfo('01767163-v', 32), SenseInfo('01766748-v', 9), SenseInfo('01765908-v', 9), SenseInfo('02678438-v', 0), SenseInfo('01559473-v', 0), SenseInfo('01251109-v', 0), SenseInfo('01767163-v', 32), SenseInfo('01766748-v', 9), SenseInfo('01765908-v', 9), SenseInfo('02678438-v', 0), SenseInfo('01559473-v', 0), SenseInfo('01251109-v', 0) ],
"_flurry_v_1_rel" : [ SenseInfo('02084252-v', 2), SenseInfo('01790739-v', 0) ],
"_belgian_a_1_rel" : [ SenseInfo('02960507-a', 2) ],
"_senora_n_1_rel" : [ SenseInfo('06342015-n', 0), SenseInfo('06342015-n', 0), SenseInfo('06342015-n', 0) ],
"_collide_v_1_rel" : [ SenseInfo('02667698-v', 0), SenseInfo('01562733-v', 0), SenseInfo('01561143-v', 0), SenseInfo('02667698-v', 0), SenseInfo('01562733-v', 0), SenseInfo('01561143-v', 0) ],
"_course_n_i_rel" : [ SenseInfo('00884466-n', 61), SenseInfo('08377085-n', 14), SenseInfo('08681222-n', 11), SenseInfo('00038262-n', 9), SenseInfo('09387222-n', 5), SenseInfo('08238463-n', 0), SenseInfo('07556970-n', 0), SenseInfo('03120029-n', 0), SenseInfo('03119790-n', 0) ],
"_frog_n_1_rel" : [ SenseInfo('01639765-n', 2), SenseInfo('09708648-n', 0), SenseInfo('03398382-n', 0) ],
"_preoccupation_n_1_rel" : [ SenseInfo('05836921-n', 1), SenseInfo('05700087-n', 1), SenseInfo('00087073-n', 0) ],
"_endorse_v_1_rel" : [ SenseInfo('02453889-v', 7), SenseInfo('02556817-v', 1), SenseInfo('02447793-v', 1), SenseInfo('00997794-v', 0) ],
"_tuck_v_in_rel" : [ SenseInfo('01389776-v', 8), SenseInfo('01390327-v', 0), SenseInfo('01330822-v', 0), SenseInfo('01389776-v', 8), SenseInfo('01390327-v', 0), SenseInfo('01330822-v', 0) ],
"_worm_n_1_rel" : [ SenseInfo('01922303-n', 3), SenseInfo('10792028-n', 2), SenseInfo('06586098-n', 0), SenseInfo('04604513-n', 0) ],
"_brewery_n_1_rel" : [ SenseInfo('02897237-n', 0) ],
"_adjustable_a_1_rel" : [ SenseInfo('01027686-a', 0), SenseInfo('00344686-a', 0) ],
"_occasion_n_1_rel" : [ SenseInfo('07416714-n', 14), SenseInfo('07447261-n', 6), SenseInfo('09179264-n', 3), SenseInfo('15245829-n', 0), SenseInfo('14485064-n', 0) ],
"_dish_n_of_rel" : [ SenseInfo('03206908-n', 9), SenseInfo('07557434-n', 3), SenseInfo('13766896-n', 0), SenseInfo('10613996-n', 0), SenseInfo('03207305-n', 0), SenseInfo('00432881-n', 0) ],
"_tournament_n_of_rel" : [ SenseInfo('07464725-n', 6), SenseInfo('07472327-n', 0) ],
"_unyielding_a_1_rel" : [ SenseInfo('02327569-a', 0), SenseInfo('01152620-a', 0), SenseInfo('02327569-a', 0), SenseInfo('01152620-a', 0) ],
"_unnoticed_a_1_rel" : [ SenseInfo('01608264-a', 1), SenseInfo('01608264-a', 1) ],
"_causeway_n_1_rel" : [ SenseInfo('02986920-n', 0) ],
"_of_x_subord_rel" : [  ],
"_maxim_n_1_rel" : [ SenseInfo('07152948-n', 1), SenseInfo('11166060-n', 0), SenseInfo('07152948-n', 1), SenseInfo('11166060-n', 0) ],
"_gigantic_a_1_rel" : [ SenseInfo('01386538-a', 9) ],
"_decry_v_as_rel" : [ SenseInfo('00864159-v', 4), SenseInfo('00864159-v', 4) ],
"_meow_v_1_rel" : [ SenseInfo('01052782-v', 0) ],
"_advocate_n_1_rel" : [ SenseInfo('09774783-n', 2), SenseInfo('09775663-n', 0) ],
"_alluvium_n_1_rel" : [ SenseInfo('09193282-n', 0) ],
"_landscaped_a_1_rel" : [ SenseInfo('01289083-a', 1) ],
"_incidental_n_1_rel" : [ SenseInfo('13306436-n', 0), SenseInfo('06482978-n', 0) ],
"_tarpaulin_n_1_rel" : [ SenseInfo('04395024-n', 2) ],
"_damp_v_out_rel" : [ SenseInfo('02191311-v', 0), SenseInfo('00573085-v', 0), SenseInfo('00390560-v', 0), SenseInfo('00390215-v', 0) ],
"_overlook_n_1_rel" : [ SenseInfo('08614104-n', 0) ],
"_cut_v_off_rel" : [ SenseInfo('01552519-v', 58), SenseInfo('00429060-v', 18), SenseInfo('02033295-v', 3), SenseInfo('01610834-v', 2), SenseInfo('02422283-v', 1), SenseInfo('01754915-v', 1), SenseInfo('01666717-v', 1), SenseInfo('01413917-v', 1), SenseInfo('01064799-v', 1), SenseInfo('00201722-v', 1), SenseInfo('02613860-v', 0), SenseInfo('02588280-v', 0), SenseInfo('02134232-v', 0), SenseInfo('02101649-v', 0), SenseInfo('01915865-v', 0), SenseInfo('01915730-v', 0), SenseInfo('01860107-v', 0), SenseInfo('01859995-v', 0), SenseInfo('01756563-v', 0), SenseInfo('01756416-v', 0), SenseInfo('01756277-v', 0), SenseInfo('01754737-v', 0), SenseInfo('01713491-v', 0), SenseInfo('01611123-v', 0), SenseInfo('01610990-v', 0), SenseInfo('01555437-v', 0), SenseInfo('01510576-v', 0), SenseInfo('01320424-v', 0), SenseInfo('01319738-v', 0), SenseInfo('01227088-v', 0), SenseInfo('01059564-v', 0), SenseInfo('00561090-v', 0), SenseInfo('00473322-v', 0), SenseInfo('00447654-v', 0), SenseInfo('00429968-v', 0), SenseInfo('00292507-v', 0), SenseInfo('00243900-v', 0), SenseInfo('00226071-v', 0), SenseInfo('00108475-v', 0), SenseInfo('00096136-v', 0), SenseInfo('00061219-v', 0), SenseInfo('01552519-v', 58), SenseInfo('00429060-v', 18), SenseInfo('02033295-v', 3), SenseInfo('01610834-v', 2), SenseInfo('02422283-v', 1), SenseInfo('01754915-v', 1), SenseInfo('01666717-v', 1), SenseInfo('01413917-v', 1), SenseInfo('01064799-v', 1), SenseInfo('00201722-v', 1), SenseInfo('02613860-v', 0), SenseInfo('02588280-v', 0), SenseInfo('02134232-v', 0), SenseInfo('02101649-v', 0), SenseInfo('01915865-v', 0), SenseInfo('01915730-v', 0), SenseInfo('01860107-v', 0), SenseInfo('01859995-v', 0), SenseInfo('01756563-v', 0), SenseInfo('01756416-v', 0), SenseInfo('01756277-v', 0), SenseInfo('01754737-v', 0), SenseInfo('01713491-v', 0), SenseInfo('01611123-v', 0), SenseInfo('01610990-v', 0), SenseInfo('01555437-v', 0), SenseInfo('01510576-v', 0), SenseInfo('01320424-v', 0), SenseInfo('01319738-v', 0), SenseInfo('01227088-v', 0), SenseInfo('01059564-v', 0), SenseInfo('00561090-v', 0), SenseInfo('00473322-v', 0), SenseInfo('00447654-v', 0), SenseInfo('00429968-v', 0), SenseInfo('00292507-v', 0), SenseInfo('00243900-v', 0), SenseInfo('00226071-v', 0), SenseInfo('00108475-v', 0), SenseInfo('00096136-v', 0), SenseInfo('00061219-v', 0) ],
"_maitre+d_n_1_rel" : [  ],
"_in+order+that_x_rel" : [  ],
"_breast_n_1_rel" : [ SenseInfo('05553288-n', 6), SenseInfo('05554405-n', 2), SenseInfo('07648408-n', 0), SenseInfo('01514431-n', 0) ],
"_nation_n_of_rel" : [ SenseInfo('08168978-n', 33), SenseInfo('08166552-n', 10), SenseInfo('11201061-n', 0), SenseInfo('08303692-n', 0) ],
"_shake_n_1_rel" : [ SenseInfo('15039445-n', 0), SenseInfo('07923297-n', 0), SenseInfo('06860177-n', 0), SenseInfo('06632097-n', 0), SenseInfo('00867983-n', 0), SenseInfo('00347652-n', 0) ],
"_hose_n_1_rel" : [ SenseInfo('03540267-n', 0), SenseInfo('03540090-n', 0), SenseInfo('03539875-n', 0) ],
"_inhospitable_a_1_rel" : [ SenseInfo('01242489-a', 1), SenseInfo('01244195-a', 0) ],
"_armor_v_1_rel" : [ SenseInfo('02341684-v', 0), SenseInfo('02341684-v', 0) ],
"_overcoat_n_1_rel" : [ SenseInfo('03456665-n', 3), SenseInfo('03863657-n', 0) ],
"_guatemalan_a_1_rel" : [ SenseInfo('03071022-a', 1) ],
"_bargain_v_over_rel" : [ SenseInfo('02259829-v', 1), SenseInfo('00764782-v', 0) ],
"_dust_n_1_rel" : [ SenseInfo('14839846-n', 38), SenseInfo('14857897-n', 15), SenseInfo('14840092-n', 0) ],
"_nearby_p_rel" : [ SenseInfo('00445169-a', 8), SenseInfo('00071321-r', 7), SenseInfo('00445169-a', 8), SenseInfo('00071321-r', 7), SenseInfo('00445169-a', 8), SenseInfo('00071321-r', 7) ],
"_silkworm_n_1_rel" : [ SenseInfo('02300797-n', 1), SenseInfo('02302620-n', 0) ],
"_bye_a_1_rel" : [ SenseInfo('07176499-n', 0), SenseInfo('06629610-n', 0) ],
"_furious_a_1_rel" : [ SenseInfo('02511528-a', 7), SenseInfo('00114454-a', 4), SenseInfo('00304144-a', 2), SenseInfo('02511528-a', 7), SenseInfo('00114454-a', 4), SenseInfo('00304144-a', 2), SenseInfo('02511528-a', 7), SenseInfo('00114454-a', 4), SenseInfo('00304144-a', 2) ],
"_hypocrisy_n_1_rel" : [ SenseInfo('06760076-n', 1), SenseInfo('04868148-n', 1) ],
"_insouciance_n_1_rel" : [ SenseInfo('07530866-n', 1) ],
"_chimpanzee_n_1_rel" : [ SenseInfo('02481823-n', 0) ],
"_flow_n_of_rel" : [ SenseInfo('07405893-n', 18), SenseInfo('15277730-n', 7), SenseInfo('00329227-n', 5), SenseInfo('13482330-n', 3), SenseInfo('14005892-n', 1), SenseInfo('08461595-n', 1), SenseInfo('13513747-n', 0) ],
"_shrubby_a_1_rel" : [ SenseInfo('03021866-a', 0), SenseInfo('03021866-a', 0), SenseInfo('03021866-a', 0) ],
"_authorize_v_1_rel" : [ SenseInfo('00803325-v', 32), SenseInfo('02473981-v', 0), SenseInfo('00803325-v', 32), SenseInfo('02473981-v', 0), SenseInfo('00803325-v', 32), SenseInfo('02473981-v', 0), SenseInfo('00803325-v', 32), SenseInfo('02473981-v', 0) ],
"_medic_n_1_rel" : [ SenseInfo('12548280-n', 0), SenseInfo('10305635-n', 0) ],
"_impenetrable_a_1_rel" : [ SenseInfo('01771632-a', 0), SenseInfo('02416390-a', 0), SenseInfo('00534918-a', 0) ],
"_mighty_x_deg_rel" : [ SenseInfo('01826575-a', 10), SenseInfo('00032299-r', 4) ],
"_take_v_x-off_rel" : [ SenseInfo('02599636-v', 92), SenseInfo('02267989-v', 74), SenseInfo('01999798-v', 73), SenseInfo('01214265-v', 50), SenseInfo('00524682-v', 38), SenseInfo('00624476-v', 36), SenseInfo('02077656-v', 32), SenseInfo('02205272-v', 28), SenseInfo('01842690-v', 26), SenseInfo('00674607-v', 26), SenseInfo('02236124-v', 25), SenseInfo('02394183-v', 22), SenseInfo('00734054-v', 22), SenseInfo('02627934-v', 21), SenseInfo('02109045-v', 21), SenseInfo('01002740-v', 16), SenseInfo('00173338-v', 16), SenseInfo('01156834-v', 15), SenseInfo('00669762-v', 15), SenseInfo('02209936-v', 14), SenseInfo('02206619-v', 13), SenseInfo('01982395-v', 10), SenseInfo('02236624-v', 8), SenseInfo('00523095-v', 7), SenseInfo('00599992-v', 6), SenseInfo('00756076-v', 5), SenseInfo('02075857-v', 4), SenseInfo('01151110-v', 4), SenseInfo('00557404-v', 4), SenseInfo('02717102-v', 2), SenseInfo('02208537-v', 2), SenseInfo('02209745-v', 1), SenseInfo('02208118-v', 1), SenseInfo('02201138-v', 1), SenseInfo('01427127-v', 1), SenseInfo('00758333-v', 1), SenseInfo('02741546-v', 0), SenseInfo('02701210-v', 0), SenseInfo('02590253-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01100830-v', 0), SenseInfo('00087736-v', 0) ],
"_urge_v_to_rel" : [ SenseInfo('00765649-v', 36), SenseInfo('00875141-v', 11), SenseInfo('00858781-v', 1) ],
"_subjunctive_a_1_rel" : [ SenseInfo('03094107-a', 0) ],
"_fewer+than_x_rel" : [  ],
"_disquiet_n_1_rel" : [ SenseInfo('07524760-n', 0), SenseInfo('04904851-n', 0) ],
"_megabyte_n_1_rel" : [ SenseInfo('13628246-n', 0), SenseInfo('13628056-n', 0), SenseInfo('13628246-n', 0), SenseInfo('13628056-n', 0), SenseInfo('13628246-n', 0), SenseInfo('13628056-n', 0), SenseInfo('13628246-n', 0), SenseInfo('13628056-n', 0) ],
"_as+for_x_subord_rel" : [  ],
"_biochemistry_n_1_rel" : [ SenseInfo('06079620-n', 0) ],
"_colorless_a_1_rel" : [ SenseInfo('00408031-a', 0), SenseInfo('00404202-a', 0), SenseInfo('00408031-a', 0), SenseInfo('00404202-a', 0) ],
"_de+rigueur_a_1_rel" : [ SenseInfo('00848679-a', 0) ],
"_tack_v_down_rel" : [ SenseInfo('01357429-v', 3), SenseInfo('01946408-v', 1), SenseInfo('01656788-v', 0), SenseInfo('01331348-v', 0), SenseInfo('01328513-v', 0), SenseInfo('00121678-v', 0) ],
"_accumulate_v_cause_rel" : [ SenseInfo('02304982-v', 4), SenseInfo('00158804-v', 4) ],
"_bottle_v_in_rel" : [ SenseInfo('02283080-v', 0), SenseInfo('01502279-v', 0) ],
"_melt_v_down_rel" : [ SenseInfo('00444629-v', 3), SenseInfo('00376106-v', 2), SenseInfo('00254486-v', 2), SenseInfo('00395841-v', 1), SenseInfo('00224651-v', 0), SenseInfo('00223928-v', 0), SenseInfo('00444629-v', 3), SenseInfo('00376106-v', 2), SenseInfo('00254486-v', 2), SenseInfo('00395841-v', 1), SenseInfo('00224651-v', 0), SenseInfo('00223928-v', 0) ],
"_footer_n_1_rel" : [ SenseInfo('13650225-n', 0), SenseInfo('10412055-n', 0), SenseInfo('06764244-n', 0) ],
"_kid_n_1_rel" : [ SenseInfo('09917593-n', 53), SenseInfo('14762846-n', 0), SenseInfo('11113489-n', 0), SenseInfo('09918248-n', 0), SenseInfo('02416820-n', 0) ],
"_api_n_1_rel" : [  ],
"_apply_v_1_rel" : [ SenseInfo('01158872-v', 45), SenseInfo('02676789-v', 29), SenseInfo('00765396-v', 13), SenseInfo('01363648-v', 11), SenseInfo('02707429-v', 4), SenseInfo('02309165-v', 2), SenseInfo('02561332-v', 1), SenseInfo('02560164-v', 1), SenseInfo('01026558-v', 1), SenseInfo('02595523-v', 0), SenseInfo('01158872-v', 45), SenseInfo('02676789-v', 29), SenseInfo('00765396-v', 13), SenseInfo('01363648-v', 11), SenseInfo('02707429-v', 4), SenseInfo('02309165-v', 2), SenseInfo('02561332-v', 1), SenseInfo('02560164-v', 1), SenseInfo('01026558-v', 1), SenseInfo('02595523-v', 0) ],
"_crawl_n_1_rel" : [ SenseInfo('00330035-n', 1), SenseInfo('00570366-n', 0), SenseInfo('00294868-n', 0) ],
"_station_n_1_rel" : [ SenseInfo('04306080-n', 23), SenseInfo('13947645-n', 0), SenseInfo('08656590-n', 0), SenseInfo('08624385-n', 0), SenseInfo('05057061-n', 0), SenseInfo('04306080-n', 23), SenseInfo('13947645-n', 0), SenseInfo('08656590-n', 0), SenseInfo('08624385-n', 0), SenseInfo('05057061-n', 0) ],
"_former_a_1_rel" : [ SenseInfo('01047301-a', 21), SenseInfo('01729566-a', 20), SenseInfo('01729819-a', 4), SenseInfo('01729384-a', 0), SenseInfo('01047301-a', 21), SenseInfo('01729566-a', 20), SenseInfo('01729819-a', 4), SenseInfo('01729384-a', 0), SenseInfo('01047301-a', 21), SenseInfo('01729566-a', 20), SenseInfo('01729819-a', 4), SenseInfo('01729384-a', 0), SenseInfo('01047301-a', 21), SenseInfo('01729566-a', 20), SenseInfo('01729819-a', 4), SenseInfo('01729384-a', 0) ],
"_overprotective_a_1_rel" : [ SenseInfo('01888450-a', 1) ],
"_standby_n_1_rel" : [ SenseInfo('04301919-n', 1), SenseInfo('10737103-n', 0), SenseInfo('04301919-n', 1), SenseInfo('10737103-n', 0) ],
"_quarter-of-a-century_n_1_rel" : [  ],
"_sap_n_1_rel" : [ SenseInfo('15038127-n', 0), SenseInfo('10100761-n', 0), SenseInfo('02847461-n', 0) ],
"_gain_v_1_rel" : [ SenseInfo('02292125-v', 27), SenseInfo('02288295-v', 13), SenseInfo('02290461-v', 7), SenseInfo('02020590-v', 5), SenseInfo('01111028-v', 2), SenseInfo('00158222-v', 2), SenseInfo('00157462-v', 2), SenseInfo('02289295-v', 1), SenseInfo('00046151-v', 0) ],
"_rampart_n_1_rel" : [ SenseInfo('04051825-n', 2) ],
"_picker_n_1_rel" : [ SenseInfo('10431625-n', 0), SenseInfo('10431514-n', 0) ],
"_tectonic_a_1_rel" : [ SenseInfo('02939099-a', 0), SenseInfo('02898121-a', 0) ],
"_big+ass_a_1_rel" : [  ],
"_electricity_n_1_rel" : [ SenseInfo('11449907-n', 8), SenseInfo('11450566-n', 5), SenseInfo('07514600-n', 1) ],
"_plague_v_1_rel" : [ SenseInfo('02771320-v', 6), SenseInfo('01789514-v', 2) ],
"_poise_v_1_rel" : [ SenseInfo('01943571-v', 3), SenseInfo('01806109-v', 1), SenseInfo('01602665-v', 1), SenseInfo('01602318-v', 0), SenseInfo('01943571-v', 3), SenseInfo('01806109-v', 1), SenseInfo('01602665-v', 1), SenseInfo('01602318-v', 0) ],
"_blur_v_1_rel" : [ SenseInfo('02158034-v', 2), SenseInfo('02161758-v', 1), SenseInfo('00620673-v', 1), SenseInfo('01251928-v', 0), SenseInfo('00312990-v', 0), SenseInfo('00311113-v', 0) ],
"_usability_n_1_rel" : [ SenseInfo('05150129-n', 0) ],
"_counsel_v_1_rel" : [ SenseInfo('00872886-v', 3) ],
"_refuse_v_1_rel" : [ SenseInfo('00797430-v', 47), SenseInfo('02237338-v', 13), SenseInfo('02707800-v', 5), SenseInfo('02212825-v', 2), SenseInfo('02755017-v', 0), SenseInfo('02502916-v', 0), SenseInfo('00797430-v', 47), SenseInfo('02237338-v', 13), SenseInfo('02707800-v', 5), SenseInfo('02212825-v', 2), SenseInfo('02755017-v', 0), SenseInfo('02502916-v', 0), SenseInfo('00797430-v', 47), SenseInfo('02237338-v', 13), SenseInfo('02707800-v', 5), SenseInfo('02212825-v', 2), SenseInfo('02755017-v', 0), SenseInfo('02502916-v', 0) ],
"_thunder_n_1_rel" : [ SenseInfo('07377682-n', 8), SenseInfo('07397355-n', 5), SenseInfo('02837416-n', 0) ],
"_bubble_v_up_rel" : [ SenseInfo('00519056-v', 3), SenseInfo('02187922-v', 0), SenseInfo('01969084-v', 0), SenseInfo('00519229-v', 0), SenseInfo('00003431-v', 0) ],
"_huddle_v_1_rel" : [ SenseInfo('02027226-v', 6), SenseInfo('02063988-v', 3), SenseInfo('02027226-v', 6), SenseInfo('02063988-v', 3) ],
"_retinal_a_1_rel" : [ SenseInfo('02979139-a', 3) ],
"_dignity_n_1_rel" : [ SenseInfo('04886881-n', 14), SenseInfo('04910684-n', 4), SenseInfo('14431902-n', 0) ],
"_improbability_n_1_rel" : [ SenseInfo('04758452-n', 0) ],
"_shout_v_at_rel" : [ SenseInfo('00912473-v', 39), SenseInfo('00913065-v', 18), SenseInfo('00912048-v', 2), SenseInfo('00845299-v', 0) ],
"_context_n_1_rel" : [ SenseInfo('06284898-n', 14), SenseInfo('14512817-n', 4) ],
"_confusing_a_1_rel" : [ SenseInfo('01685706-a', 1), SenseInfo('00430756-a', 1) ],
"_down_p_rel" : [ SenseInfo('00095320-r', 98), SenseInfo('00095612-r', 22), SenseInfo('02491961-a', 9), SenseInfo('01202374-v', 3), SenseInfo('00095841-r', 2), SenseInfo('02486248-a', 2), SenseInfo('01896561-n', 1), SenseInfo('00458286-n', 1), SenseInfo('02487414-a', 1), SenseInfo('02061678-a', 1), SenseInfo('01750617-a', 1), SenseInfo('01197014-v', 1), SenseInfo('01103336-v', 1), SenseInfo('10942144-n', 0), SenseInfo('09269341-n', 0), SenseInfo('05255692-n', 0), SenseInfo('00096232-r', 0), SenseInfo('00096089-r', 0), SenseInfo('00095946-r', 0), SenseInfo('01212867-a', 0), SenseInfo('01208492-a', 0), SenseInfo('00833737-a', 0), SenseInfo('00703615-a', 0), SenseInfo('01981279-v', 0), SenseInfo('01239862-v', 0), SenseInfo('00474017-v', 0), SenseInfo('00095320-r', 98), SenseInfo('00095612-r', 22), SenseInfo('02491961-a', 9), SenseInfo('01202374-v', 3), SenseInfo('00095841-r', 2), SenseInfo('02486248-a', 2), SenseInfo('01896561-n', 1), SenseInfo('00458286-n', 1), SenseInfo('02487414-a', 1), SenseInfo('02061678-a', 1), SenseInfo('01750617-a', 1), SenseInfo('01197014-v', 1), SenseInfo('01103336-v', 1), SenseInfo('10942144-n', 0), SenseInfo('09269341-n', 0), SenseInfo('05255692-n', 0), SenseInfo('00096232-r', 0), SenseInfo('00096089-r', 0), SenseInfo('00095946-r', 0), SenseInfo('01212867-a', 0), SenseInfo('01208492-a', 0), SenseInfo('00833737-a', 0), SenseInfo('00703615-a', 0), SenseInfo('01981279-v', 0), SenseInfo('01239862-v', 0), SenseInfo('00474017-v', 0), SenseInfo('00095320-r', 98), SenseInfo('00095612-r', 22), SenseInfo('02491961-a', 9), SenseInfo('01202374-v', 3), SenseInfo('00095841-r', 2), SenseInfo('02486248-a', 2), SenseInfo('01896561-n', 1), SenseInfo('00458286-n', 1), SenseInfo('02487414-a', 1), SenseInfo('02061678-a', 1), SenseInfo('01750617-a', 1), SenseInfo('01197014-v', 1), SenseInfo('01103336-v', 1), SenseInfo('10942144-n', 0), SenseInfo('09269341-n', 0), SenseInfo('05255692-n', 0), SenseInfo('00096232-r', 0), SenseInfo('00096089-r', 0), SenseInfo('00095946-r', 0), SenseInfo('01212867-a', 0), SenseInfo('01208492-a', 0), SenseInfo('00833737-a', 0), SenseInfo('00703615-a', 0), SenseInfo('01981279-v', 0), SenseInfo('01239862-v', 0), SenseInfo('00474017-v', 0) ],
"_purification_n_of_rel" : [ SenseInfo('00253270-n', 2), SenseInfo('13548105-n', 0), SenseInfo('00253070-n', 0), SenseInfo('00252894-n', 0) ],
"_mandate_v_1_rel" : [ SenseInfo('02395603-v', 1), SenseInfo('00751389-v', 0), SenseInfo('00751279-v', 0), SenseInfo('02395603-v', 1), SenseInfo('00751389-v', 0), SenseInfo('00751279-v', 0), SenseInfo('02395603-v', 1), SenseInfo('00751389-v', 0), SenseInfo('00751279-v', 0) ],
"_career_v_1_rel" : [ SenseInfo('02082181-v', 3) ],
"_interval_n_of_rel" : [ SenseInfo('15269513-n', 10), SenseInfo('06016276-n', 8), SenseInfo('05089947-n', 1), SenseInfo('06858779-n', 0) ],
"_soothsayer_n_1_rel" : [ SenseInfo('10102506-n', 1) ],
"_gun_n_1_rel" : [ SenseInfo('03467984-n', 72), SenseInfo('02746365-n', 25), SenseInfo('10593392-n', 0), SenseInfo('10152083-n', 0), SenseInfo('03456299-n', 0), SenseInfo('02670683-n', 0), SenseInfo('00123430-n', 0) ],
"_adjustment_n_1_rel" : [ SenseInfo('07369604-n', 5), SenseInfo('00199707-n', 3), SenseInfo('00999787-n', 1), SenseInfo('13427078-n', 0), SenseInfo('13274092-n', 0) ],
"_allotted_a_1_rel" : [ SenseInfo('00847103-a', 0) ],
"_not+yet_a_1_rel" : [  ],
"_penetration_n_of_rel" : [ SenseInfo('00975452-n', 2), SenseInfo('05710356-n', 1), SenseInfo('00051525-n', 1), SenseInfo('05201452-n', 0), SenseInfo('05135288-n', 0), SenseInfo('00846817-n', 0) ],
"_cash-and-carry_n_1_rel" : [ SenseInfo('02682543-a', 0), SenseInfo('02682543-a', 0) ],
"_sandwich_n_1_rel" : [ SenseInfo('07695965-n', 6) ],
"_PLC_n_1_rel" : [  ],
"_hurry_v_1_rel" : [ SenseInfo('02055649-v', 30), SenseInfo('00459498-v', 8), SenseInfo('00459296-v', 1), SenseInfo('02055649-v', 30), SenseInfo('00459498-v', 8), SenseInfo('00459296-v', 1), SenseInfo('02055649-v', 30), SenseInfo('00459498-v', 8), SenseInfo('00459296-v', 1) ],
"_multitask_v_1_rel" : [  ],
"_maltese_n_1_rel" : [ SenseInfo('09747618-n', 0), SenseInfo('06988913-n', 0), SenseInfo('02124157-n', 0), SenseInfo('02085936-n', 0) ],
"_intrinsic_a_1_rel" : [ SenseInfo('01348258-a', 2), SenseInfo('00949374-a', 0), SenseInfo('01348258-a', 2), SenseInfo('00949374-a', 0) ],
"_storage_n_of_rel" : [ SenseInfo('00811355-n', 7), SenseInfo('04329190-n', 1), SenseInfo('00811661-n', 1), SenseInfo('13562133-n', 0), SenseInfo('03744276-n', 0), SenseInfo('00372607-n', 0) ],
"_bamboo_n_1_rel" : [ SenseInfo('12147539-n', 0), SenseInfo('12147226-n', 0) ],
"_extreme_n_1_rel" : [ SenseInfo('05098099-n', 6), SenseInfo('08569165-n', 3) ],
"_fowl_n_1_rel" : [ SenseInfo('01789740-n', 1), SenseInfo('07644382-n', 0) ],
"_lubricate_v_1_rel" : [ SenseInfo('02751597-v', 0), SenseInfo('01484982-v', 0), SenseInfo('00219012-v', 0) ],
"_shrink_v_1_rel" : [ SenseInfo('00241689-v', 3), SenseInfo('02061069-v', 2), SenseInfo('00241038-v', 2), SenseInfo('00240571-v', 1), SenseInfo('00152558-v', 0) ],
"_unattractive_a_1_rel" : [ SenseInfo('00169164-a', 1), SenseInfo('00171447-a', 1), SenseInfo('01359159-a', 0), SenseInfo('00169164-a', 1), SenseInfo('00171447-a', 1), SenseInfo('01359159-a', 0) ],
"_pound_n_cur_rel" : [ SenseInfo('13720096-n', 42), SenseInfo('13686660-n', 2), SenseInfo('13720302-n', 0), SenseInfo('13695674-n', 0), SenseInfo('13695420-n', 0), SenseInfo('13694936-n', 0), SenseInfo('13694657-n', 0), SenseInfo('13694017-n', 0), SenseInfo('13693641-n', 0), SenseInfo('13648184-n', 0), SenseInfo('11244550-n', 0), SenseInfo('06809756-n', 0), SenseInfo('03993703-n', 0), SenseInfo('01175316-n', 0), SenseInfo('13720096-n', 42), SenseInfo('13686660-n', 2), SenseInfo('13720302-n', 0), SenseInfo('13695674-n', 0), SenseInfo('13695420-n', 0), SenseInfo('13694936-n', 0), SenseInfo('13694657-n', 0), SenseInfo('13694017-n', 0), SenseInfo('13693641-n', 0), SenseInfo('13648184-n', 0), SenseInfo('11244550-n', 0), SenseInfo('06809756-n', 0), SenseInfo('03993703-n', 0), SenseInfo('01175316-n', 0) ],
"_hip_a_1_rel" : [ SenseInfo('01307571-a', 0), SenseInfo('01307571-a', 0), SenseInfo('01307571-a', 0) ],
"_light_v_1_rel" : [ SenseInfo('00291873-v', 12), SenseInfo('01199881-v', 10), SenseInfo('01978700-v', 3), SenseInfo('02759614-v', 2), SenseInfo('02229828-v', 0), SenseInfo('01958452-v', 0) ],
"_devilish_a_1_rel" : [ SenseInfo('01133374-a', 1), SenseInfo('02122379-a', 0) ],
"_all+the+same_a_1_rel" : [  ],
"_toss-up_n_1_rel" : [ SenseInfo('11519799-n', 0), SenseInfo('11519799-n', 0) ],
"_accrue_v_1_rel" : [ SenseInfo('00155869-v', 2), SenseInfo('02230056-v', 0) ],
"_stability_n_1_rel" : [ SenseInfo('04778401-n', 6), SenseInfo('13970124-n', 0), SenseInfo('04738641-n', 0) ],
"_equation_n_of_rel" : [ SenseInfo('06669864-n', 8), SenseInfo('13946760-n', 0), SenseInfo('00185307-n', 0), SenseInfo('06669864-n', 8), SenseInfo('13946760-n', 0), SenseInfo('00185307-n', 0), SenseInfo('06669864-n', 8), SenseInfo('13946760-n', 0), SenseInfo('00185307-n', 0), SenseInfo('06669864-n', 8), SenseInfo('13946760-n', 0), SenseInfo('00185307-n', 0), SenseInfo('06669864-n', 8), SenseInfo('13946760-n', 0), SenseInfo('00185307-n', 0), SenseInfo('06669864-n', 8), SenseInfo('13946760-n', 0), SenseInfo('00185307-n', 0), SenseInfo('06669864-n', 8), SenseInfo('13946760-n', 0), SenseInfo('00185307-n', 0), SenseInfo('06669864-n', 8), SenseInfo('13946760-n', 0), SenseInfo('00185307-n', 0), SenseInfo('06669864-n', 8), SenseInfo('13946760-n', 0), SenseInfo('00185307-n', 0), SenseInfo('06669864-n', 8), SenseInfo('13946760-n', 0), SenseInfo('00185307-n', 0), SenseInfo('06669864-n', 8), SenseInfo('13946760-n', 0), SenseInfo('00185307-n', 0), SenseInfo('06669864-n', 8), SenseInfo('13946760-n', 0), SenseInfo('00185307-n', 0) ],
"_misfeed_v_1_rel" : [  ],
"_approx-equal_a_1_rel" : [  ],
"_friday-the-13th_a_1_rel" : [  ],
"_jut_v_1_rel" : [ SenseInfo('02713372-v', 0) ],
"_over+and+done+with_a_1_rel" : [  ],
"_react_v_to_rel" : [ SenseInfo('00717358-v', 22), SenseInfo('02378623-v', 2), SenseInfo('00446885-v', 2) ],
"_pressurize_v_1_rel" : [ SenseInfo('00403609-v', 0), SenseInfo('00403401-v', 0), SenseInfo('00403149-v', 0) ],
"_stoop_v_1_rel" : [ SenseInfo('02062632-v', 7), SenseInfo('02517827-v', 0), SenseInfo('02064612-v', 0), SenseInfo('02037683-v', 0), SenseInfo('01601685-v', 0) ],
"_take_v_over_rel" : [ SenseInfo('02599636-v', 92), SenseInfo('02267989-v', 74), SenseInfo('01999798-v', 73), SenseInfo('01214265-v', 50), SenseInfo('00524682-v', 38), SenseInfo('00624476-v', 36), SenseInfo('02077656-v', 32), SenseInfo('02205272-v', 28), SenseInfo('01842690-v', 26), SenseInfo('00674607-v', 26), SenseInfo('02236124-v', 25), SenseInfo('02394183-v', 22), SenseInfo('00734054-v', 22), SenseInfo('02627934-v', 21), SenseInfo('02109045-v', 21), SenseInfo('01002740-v', 16), SenseInfo('00173338-v', 16), SenseInfo('01156834-v', 15), SenseInfo('00669762-v', 15), SenseInfo('02209936-v', 14), SenseInfo('02206619-v', 13), SenseInfo('01982395-v', 10), SenseInfo('02236624-v', 8), SenseInfo('00523095-v', 7), SenseInfo('00599992-v', 6), SenseInfo('00756076-v', 5), SenseInfo('02075857-v', 4), SenseInfo('01151110-v', 4), SenseInfo('00557404-v', 4), SenseInfo('02717102-v', 2), SenseInfo('02208537-v', 2), SenseInfo('02209745-v', 1), SenseInfo('02208118-v', 1), SenseInfo('02201138-v', 1), SenseInfo('01427127-v', 1), SenseInfo('00758333-v', 1), SenseInfo('02741546-v', 0), SenseInfo('02701210-v', 0), SenseInfo('02590253-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01100830-v', 0), SenseInfo('00087736-v', 0), SenseInfo('02599636-v', 92), SenseInfo('02267989-v', 74), SenseInfo('01999798-v', 73), SenseInfo('01214265-v', 50), SenseInfo('00524682-v', 38), SenseInfo('00624476-v', 36), SenseInfo('02077656-v', 32), SenseInfo('02205272-v', 28), SenseInfo('01842690-v', 26), SenseInfo('00674607-v', 26), SenseInfo('02236124-v', 25), SenseInfo('02394183-v', 22), SenseInfo('00734054-v', 22), SenseInfo('02627934-v', 21), SenseInfo('02109045-v', 21), SenseInfo('01002740-v', 16), SenseInfo('00173338-v', 16), SenseInfo('01156834-v', 15), SenseInfo('00669762-v', 15), SenseInfo('02209936-v', 14), SenseInfo('02206619-v', 13), SenseInfo('01982395-v', 10), SenseInfo('02236624-v', 8), SenseInfo('00523095-v', 7), SenseInfo('00599992-v', 6), SenseInfo('00756076-v', 5), SenseInfo('02075857-v', 4), SenseInfo('01151110-v', 4), SenseInfo('00557404-v', 4), SenseInfo('02717102-v', 2), SenseInfo('02208537-v', 2), SenseInfo('02209745-v', 1), SenseInfo('02208118-v', 1), SenseInfo('02201138-v', 1), SenseInfo('01427127-v', 1), SenseInfo('00758333-v', 1), SenseInfo('02741546-v', 0), SenseInfo('02701210-v', 0), SenseInfo('02590253-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01100830-v', 0), SenseInfo('00087736-v', 0) ],
"_due_n_1_rel" : [ SenseInfo('05176082-n', 4), SenseInfo('13396861-n', 0) ],
"_wink_n_1_rel" : [ SenseInfo('15247110-n', 1), SenseInfo('06878934-n', 0), SenseInfo('00117959-n', 0) ],
"_A+s_n_1_rel" : [  ],
"_reply_v_to_rel" : [ SenseInfo('00815686-v', 53), SenseInfo('00815686-v', 53) ],
"_monkey+bar_n_1_rel" : [  ],
"_insubstantial_a_1_rel" : [ SenseInfo('00625774-a', 1), SenseInfo('02559694-a', 0) ],
"_commence_v_1_rel" : [ SenseInfo('00345761-v', 8), SenseInfo('00348746-v', 6), SenseInfo('01650610-v', 3), SenseInfo('00345761-v', 8), SenseInfo('00348746-v', 6), SenseInfo('01650610-v', 3) ],
"_natural+language_n_1_rel" : [ SenseInfo('06904171-n', 0), SenseInfo('06904171-n', 0), SenseInfo('06904171-n', 0) ],
"_gunstock_n_1_rel" : [ SenseInfo('04322026-n', 0) ],
"_substantive_n_1_rel" : [ SenseInfo('06303540-n', 0) ],
"_weariness_n_1_rel" : [ SenseInfo('14016361-n', 2) ],
"_wide_a_1_rel" : [ SenseInfo('02560548-a', 45), SenseInfo('00526062-a', 12), SenseInfo('01654900-a', 4), SenseInfo('01384212-a', 1), SenseInfo('02563068-a', 0), SenseInfo('00106277-a', 0), SenseInfo('00024241-a', 0), SenseInfo('02560548-a', 45), SenseInfo('00526062-a', 12), SenseInfo('01654900-a', 4), SenseInfo('01384212-a', 1), SenseInfo('02563068-a', 0), SenseInfo('00106277-a', 0), SenseInfo('00024241-a', 0), SenseInfo('02560548-a', 45), SenseInfo('00526062-a', 12), SenseInfo('01654900-a', 4), SenseInfo('01384212-a', 1), SenseInfo('02563068-a', 0), SenseInfo('00106277-a', 0), SenseInfo('00024241-a', 0), SenseInfo('02560548-a', 45), SenseInfo('00526062-a', 12), SenseInfo('01654900-a', 4), SenseInfo('01384212-a', 1), SenseInfo('02563068-a', 0), SenseInfo('00106277-a', 0), SenseInfo('00024241-a', 0) ],
"_division_n_of_rel" : [ SenseInfo('08213205-n', 10), SenseInfo('05867413-n', 6), SenseInfo('00385791-n', 4), SenseInfo('08220714-n', 3), SenseInfo('07181842-n', 1), SenseInfo('08239808-n', 0), SenseInfo('08221348-n', 0), SenseInfo('08220891-n', 0), SenseInfo('08219330-n', 0), SenseInfo('08219226-n', 0), SenseInfo('00870912-n', 0), SenseInfo('00397953-n', 0), SenseInfo('08213205-n', 10), SenseInfo('05867413-n', 6), SenseInfo('00385791-n', 4), SenseInfo('08220714-n', 3), SenseInfo('07181842-n', 1), SenseInfo('08239808-n', 0), SenseInfo('08221348-n', 0), SenseInfo('08220891-n', 0), SenseInfo('08219330-n', 0), SenseInfo('08219226-n', 0), SenseInfo('00870912-n', 0), SenseInfo('00397953-n', 0) ],
"_pigment_n_1_rel" : [ SenseInfo('14989820-n', 2), SenseInfo('14990723-n', 0), SenseInfo('03875218-n', 0) ],
"_assyrian_n_1_rel" : [ SenseInfo('09640490-n', 1), SenseInfo('06988684-n', 1), SenseInfo('06987659-n', 0) ],
"_tardiness_n_1_rel" : [ SenseInfo('05047956-n', 0) ],
"_teaspoon_n_1_rel" : [ SenseInfo('13770729-n', 0), SenseInfo('04398688-n', 0) ],
"_eviscerate_v_1_rel" : [ SenseInfo('01255057-v', 0), SenseInfo('00450168-v', 0), SenseInfo('00197590-v', 0), SenseInfo('00167191-v', 0) ],
"_trap_n_1_rel" : [ SenseInfo('04474466-n', 4), SenseInfo('04475032-n', 2), SenseInfo('05837370-n', 1), SenseInfo('04474922-n', 1), SenseInfo('01246926-n', 1), SenseInfo('05302307-n', 0), SenseInfo('04474843-n', 0), SenseInfo('02920369-n', 0) ],
"_operable_a_1_rel" : [ SenseInfo('01169817-a', 0), SenseInfo('02124253-a', 0), SenseInfo('01835663-a', 0) ],
"_ropelength_n_1_rel" : [  ],
"_progressive_a_1_rel" : [ SenseInfo('01876006-a', 3), SenseInfo('00576189-a', 3), SenseInfo('01877617-a', 0), SenseInfo('02536518-a', 0), SenseInfo('01668011-a', 0), SenseInfo('00037653-a', 0), SenseInfo('01876006-a', 3), SenseInfo('00576189-a', 3), SenseInfo('01877617-a', 0), SenseInfo('02536518-a', 0), SenseInfo('01668011-a', 0), SenseInfo('00037653-a', 0) ],
"_habit_n_of_rel" : [ SenseInfo('05669034-n', 7), SenseInfo('00414179-n', 6), SenseInfo('03473966-n', 1), SenseInfo('13490909-n', 0), SenseInfo('03474167-n', 0), SenseInfo('00947923-n', 0) ],
"_egyptian_a_1_rel" : [ SenseInfo('02971469-a', 0) ],
"_rustle_n_1_rel" : [ SenseInfo('07392783-n', 1) ],
"_bustle_v_1_rel" : [ SenseInfo('02058191-v', 2) ],
"_martini_n_1_rel" : [ SenseInfo('07916041-n', 2) ],
"_booked_a_1_rel" : [ SenseInfo('01988468-a', 1) ],
"_restraint_n_1_rel" : [ SenseInfo('01145359-n', 5), SenseInfo('04882968-n', 2), SenseInfo('13998781-n', 0), SenseInfo('06247701-n', 0), SenseInfo('04697442-n', 0), SenseInfo('04081844-n', 0) ],
"_straighten_v_out_rel" : [ SenseInfo('02035781-v', 7), SenseInfo('01368597-v', 6), SenseInfo('01982044-v', 3), SenseInfo('00275843-v', 1), SenseInfo('01487185-v', 0), SenseInfo('00277935-v', 0), SenseInfo('02035781-v', 7), SenseInfo('01368597-v', 6), SenseInfo('01982044-v', 3), SenseInfo('00275843-v', 1), SenseInfo('01487185-v', 0), SenseInfo('00277935-v', 0) ],
"_trainee_n_1_rel" : [ SenseInfo('10722385-n', 0) ],
"_bit_n_2_rel" : [ SenseInfo('13761407-n', 18), SenseInfo('09222051-n', 4), SenseInfo('15246853-n', 1), SenseInfo('07309457-n', 1), SenseInfo('02844714-n', 1), SenseInfo('13625237-n', 0), SenseInfo('07579076-n', 0), SenseInfo('07009042-n', 0), SenseInfo('06892016-n', 0), SenseInfo('02845002-n', 0), SenseInfo('02844307-n', 0) ],
"_reproduce_v_1_rel" : [ SenseInfo('01736822-v', 13), SenseInfo('00055142-v', 1), SenseInfo('01737141-v', 0), SenseInfo('00959178-v', 0) ],
"_airplane_n_1_rel" : [ SenseInfo('02691156-n', 5) ],
"_suppleness_n_1_rel" : [ SenseInfo('05004091-n', 1), SenseInfo('05023022-n', 0), SenseInfo('04659730-n', 0) ],
"_chatter_n_1_rel" : [ SenseInfo('07136940-n', 2), SenseInfo('07378952-n', 0), SenseInfo('07378781-n', 0) ],
"_comely_a_1_rel" : [ SenseInfo('01878870-a', 0), SenseInfo('00218440-a', 0), SenseInfo('01878870-a', 0), SenseInfo('00218440-a', 0), SenseInfo('01878870-a', 0), SenseInfo('00218440-a', 0) ],
"_trumpet_v_cause_rel" : [ SenseInfo('00977871-v', 1), SenseInfo('01733829-v', 0), SenseInfo('00857784-v', 0) ],
"_lay_v_for_rel" : [ SenseInfo('01494310-v', 24), SenseInfo('01544692-v', 11), SenseInfo('01651972-v', 5), SenseInfo('01545079-v', 4), SenseInfo('02307261-v', 1) ],
"_injustice_n_1_rel" : [ SenseInfo('00744616-n', 2), SenseInfo('04854389-n', 0) ],
"_trimmings_n_1_rel" : [ SenseInfo('03354350-n', 0), SenseInfo('03354350-n', 0) ],
"_deviate_n_1_rel" : [ SenseInfo('10419047-n', 0) ],
"_therefore_a_1_rel" : [  ],
"_av_n_1_rel" : [ SenseInfo('15216563-n', 0) ],
"_porch_n_1_rel" : [ SenseInfo('03984381-n', 21), SenseInfo('03984381-n', 21) ],
"_dry_a_1_rel" : [ SenseInfo('02551380-a', 18), SenseInfo('01266092-a', 1), SenseInfo('02555267-a', 0), SenseInfo('02554940-a', 0), SenseInfo('02554546-a', 0), SenseInfo('02367785-a', 0), SenseInfo('01178669-a', 0), SenseInfo('02474076-a', 0), SenseInfo('02307729-a', 0), SenseInfo('02260730-a', 0), SenseInfo('01867052-a', 0), SenseInfo('01793106-a', 0), SenseInfo('01792973-a', 0), SenseInfo('01158837-a', 0), SenseInfo('00857387-a', 0), SenseInfo('00799953-a', 0), SenseInfo('02551380-a', 18), SenseInfo('01266092-a', 1), SenseInfo('02555267-a', 0), SenseInfo('02554940-a', 0), SenseInfo('02554546-a', 0), SenseInfo('02367785-a', 0), SenseInfo('01178669-a', 0), SenseInfo('02474076-a', 0), SenseInfo('02307729-a', 0), SenseInfo('02260730-a', 0), SenseInfo('01867052-a', 0), SenseInfo('01793106-a', 0), SenseInfo('01792973-a', 0), SenseInfo('01158837-a', 0), SenseInfo('00857387-a', 0), SenseInfo('00799953-a', 0), SenseInfo('02551380-a', 18), SenseInfo('01266092-a', 1), SenseInfo('02555267-a', 0), SenseInfo('02554940-a', 0), SenseInfo('02554546-a', 0), SenseInfo('02367785-a', 0), SenseInfo('01178669-a', 0), SenseInfo('02474076-a', 0), SenseInfo('02307729-a', 0), SenseInfo('02260730-a', 0), SenseInfo('01867052-a', 0), SenseInfo('01793106-a', 0), SenseInfo('01792973-a', 0), SenseInfo('01158837-a', 0), SenseInfo('00857387-a', 0), SenseInfo('00799953-a', 0), SenseInfo('02551380-a', 18), SenseInfo('01266092-a', 1), SenseInfo('02555267-a', 0), SenseInfo('02554940-a', 0), SenseInfo('02554546-a', 0), SenseInfo('02367785-a', 0), SenseInfo('01178669-a', 0), SenseInfo('02474076-a', 0), SenseInfo('02307729-a', 0), SenseInfo('02260730-a', 0), SenseInfo('01867052-a', 0), SenseInfo('01793106-a', 0), SenseInfo('01792973-a', 0), SenseInfo('01158837-a', 0), SenseInfo('00857387-a', 0), SenseInfo('00799953-a', 0), SenseInfo('02551380-a', 18), SenseInfo('01266092-a', 1), SenseInfo('02555267-a', 0), SenseInfo('02554940-a', 0), SenseInfo('02554546-a', 0), SenseInfo('02367785-a', 0), SenseInfo('01178669-a', 0), SenseInfo('02474076-a', 0), SenseInfo('02307729-a', 0), SenseInfo('02260730-a', 0), SenseInfo('01867052-a', 0), SenseInfo('01793106-a', 0), SenseInfo('01792973-a', 0), SenseInfo('01158837-a', 0), SenseInfo('00857387-a', 0), SenseInfo('00799953-a', 0), SenseInfo('02551380-a', 18), SenseInfo('01266092-a', 1), SenseInfo('02555267-a', 0), SenseInfo('02554940-a', 0), SenseInfo('02554546-a', 0), SenseInfo('02367785-a', 0), SenseInfo('01178669-a', 0), SenseInfo('02474076-a', 0), SenseInfo('02307729-a', 0), SenseInfo('02260730-a', 0), SenseInfo('01867052-a', 0), SenseInfo('01793106-a', 0), SenseInfo('01792973-a', 0), SenseInfo('01158837-a', 0), SenseInfo('00857387-a', 0), SenseInfo('00799953-a', 0), SenseInfo('02551380-a', 18), SenseInfo('01266092-a', 1), SenseInfo('02555267-a', 0), SenseInfo('02554940-a', 0), SenseInfo('02554546-a', 0), SenseInfo('02367785-a', 0), SenseInfo('01178669-a', 0), SenseInfo('02474076-a', 0), SenseInfo('02307729-a', 0), SenseInfo('02260730-a', 0), SenseInfo('01867052-a', 0), SenseInfo('01793106-a', 0), SenseInfo('01792973-a', 0), SenseInfo('01158837-a', 0), SenseInfo('00857387-a', 0), SenseInfo('00799953-a', 0) ],
"_fearful_a_1_rel" : [ SenseInfo('00079485-a', 2), SenseInfo('00193799-a', 1), SenseInfo('00264776-a', 0), SenseInfo('01127147-a', 0), SenseInfo('00252498-a', 0) ],
"_firestarter_n_1_rel" : [  ],
"_at+best_p_rel" : [ SenseInfo('00105775-r', 4) ],
"_mustang_n_1_rel" : [ SenseInfo('02380583-n', 0) ],
"_economics_n_1_rel" : [ SenseInfo('06149484-n', 3) ],
"_slight_a_1_rel" : [ SenseInfo('01554510-a', 0), SenseInfo('02164913-a', 0), SenseInfo('00990855-a', 0), SenseInfo('01554510-a', 0), SenseInfo('02164913-a', 0), SenseInfo('00990855-a', 0), SenseInfo('01554510-a', 0), SenseInfo('02164913-a', 0), SenseInfo('00990855-a', 0), SenseInfo('01554510-a', 0), SenseInfo('02164913-a', 0), SenseInfo('00990855-a', 0) ],
"_modish_a_1_rel" : [ SenseInfo('00971506-a', 0) ],
"_dewlap_n_1_rel" : [ SenseInfo('05239680-n', 0) ],
"_ticket_n_1_rel" : [ SenseInfo('06518719-n', 3), SenseInfo('07273136-n', 0), SenseInfo('06558678-n', 0), SenseInfo('06495948-n', 0), SenseInfo('04716703-n', 0) ],
"_neural_a_1_rel" : [ SenseInfo('02904518-a', 0), SenseInfo('02894119-a', 0) ],
"_tough_a_for_rel" : [ SenseInfo('02448437-a', 9), SenseInfo('00748058-a', 5), SenseInfo('02447344-a', 2), SenseInfo('00707795-a', 2), SenseInfo('02512641-a', 1), SenseInfo('00478311-a', 1), SenseInfo('02445636-a', 0), SenseInfo('01127302-a', 0), SenseInfo('00746451-a', 0), SenseInfo('02448437-a', 9), SenseInfo('00748058-a', 5), SenseInfo('02447344-a', 2), SenseInfo('00707795-a', 2), SenseInfo('02512641-a', 1), SenseInfo('00478311-a', 1), SenseInfo('02445636-a', 0), SenseInfo('01127302-a', 0), SenseInfo('00746451-a', 0), SenseInfo('02448437-a', 9), SenseInfo('00748058-a', 5), SenseInfo('02447344-a', 2), SenseInfo('00707795-a', 2), SenseInfo('02512641-a', 1), SenseInfo('00478311-a', 1), SenseInfo('02445636-a', 0), SenseInfo('01127302-a', 0), SenseInfo('00746451-a', 0), SenseInfo('02448437-a', 9), SenseInfo('00748058-a', 5), SenseInfo('02447344-a', 2), SenseInfo('00707795-a', 2), SenseInfo('02512641-a', 1), SenseInfo('00478311-a', 1), SenseInfo('02445636-a', 0), SenseInfo('01127302-a', 0), SenseInfo('00746451-a', 0) ],
"_tangible_a_1_rel" : [ SenseInfo('02391455-a', 1), SenseInfo('00013662-a', 1), SenseInfo('02392134-a', 0), SenseInfo('01717117-a', 0) ],
"_subvert_v_from_rel" : [ SenseInfo('02402409-v', 1), SenseInfo('02579447-v', 0), SenseInfo('02543607-v', 0), SenseInfo('01565028-v', 0), SenseInfo('02402409-v', 1), SenseInfo('02579447-v', 0), SenseInfo('02543607-v', 0), SenseInfo('01565028-v', 0) ],
"_deal_v_1_rel" : [ SenseInfo('01033527-v', 34), SenseInfo('00734054-v', 15), SenseInfo('02370987-v', 14), SenseInfo('02587532-v', 9), SenseInfo('02294436-v', 5), SenseInfo('02244956-v', 4), SenseInfo('02436349-v', 3), SenseInfo('02377764-v', 3), SenseInfo('02246456-v', 2), SenseInfo('02445509-v', 0), SenseInfo('02294179-v', 0), SenseInfo('02246686-v', 0), SenseInfo('02245993-v', 0), SenseInfo('01033527-v', 34), SenseInfo('00734054-v', 15), SenseInfo('02370987-v', 14), SenseInfo('02587532-v', 9), SenseInfo('02294436-v', 5), SenseInfo('02244956-v', 4), SenseInfo('02436349-v', 3), SenseInfo('02377764-v', 3), SenseInfo('02246456-v', 2), SenseInfo('02445509-v', 0), SenseInfo('02294179-v', 0), SenseInfo('02246686-v', 0), SenseInfo('02245993-v', 0) ],
"_page_v_1_rel" : [ SenseInfo('00754560-v', 1), SenseInfo('02412513-v', 0), SenseInfo('00949093-v', 0) ],
"_alibi_n_1_rel" : [ SenseInfo('06741099-n', 2), SenseInfo('06741305-n', 0) ],
"_gear_v_up_rel" : [ SenseInfo('00298244-v', 3), SenseInfo('00298244-v', 3), SenseInfo('00298244-v', 3) ],
"_taxi_n_1_rel" : [ SenseInfo('02930766-n', 5) ],
"_particularly_x_deg_rel" : [ SenseInfo('00084223-r', 61), SenseInfo('00248765-r', 0), SenseInfo('00248488-r', 0) ],
"_regards_n_1_rel" : [ SenseInfo('05820170-n', 4), SenseInfo('05702726-n', 2), SenseInfo('06630627-n', 1), SenseInfo('00878648-n', 1), SenseInfo('14437552-n', 0), SenseInfo('07545415-n', 0), SenseInfo('06206800-n', 0), SenseInfo('05820170-n', 4), SenseInfo('05702726-n', 2), SenseInfo('06630627-n', 1), SenseInfo('00878648-n', 1), SenseInfo('14437552-n', 0), SenseInfo('07545415-n', 0), SenseInfo('06206800-n', 0) ],
"_riser_n_1_rel" : [ SenseInfo('10532576-n', 0), SenseInfo('04094859-n', 0), SenseInfo('04094720-n', 0) ],
"_wick_v_1_rel" : [  ],
"_steel_v_1_rel" : [ SenseInfo('01806271-v', 1), SenseInfo('01614907-v', 0) ],
"_unself+conscious_a_1_rel" : [ SenseInfo('00074867-a', 1), SenseInfo('00074867-a', 1), SenseInfo('00074867-a', 1) ],
"_stop_v_from_rel" : [ SenseInfo('01860795-v', 57), SenseInfo('02680814-v', 56), SenseInfo('02559752-v', 25), SenseInfo('01862918-v', 7), SenseInfo('01859221-v', 7), SenseInfo('00362348-v', 4), SenseInfo('01131473-v', 3), SenseInfo('01440378-v', 2), SenseInfo('02609764-v', 1), SenseInfo('01478002-v', 0), SenseInfo('00362610-v', 0) ],
"_saline_a_1_rel" : [ SenseInfo('01074458-a', 0) ],
"_scepticism_n_1_rel" : [ SenseInfo('05980051-n', 1) ],
"_take_v_aback_rel" : [ SenseInfo('02599636-v', 92), SenseInfo('02267989-v', 74), SenseInfo('01999798-v', 73), SenseInfo('01214265-v', 50), SenseInfo('00524682-v', 38), SenseInfo('00624476-v', 36), SenseInfo('02077656-v', 32), SenseInfo('02205272-v', 28), SenseInfo('01842690-v', 26), SenseInfo('00674607-v', 26), SenseInfo('02236124-v', 25), SenseInfo('02394183-v', 22), SenseInfo('00734054-v', 22), SenseInfo('02627934-v', 21), SenseInfo('02109045-v', 21), SenseInfo('01002740-v', 16), SenseInfo('00173338-v', 16), SenseInfo('01156834-v', 15), SenseInfo('00669762-v', 15), SenseInfo('02209936-v', 14), SenseInfo('02206619-v', 13), SenseInfo('01982395-v', 10), SenseInfo('02236624-v', 8), SenseInfo('00523095-v', 7), SenseInfo('00599992-v', 6), SenseInfo('00756076-v', 5), SenseInfo('02075857-v', 4), SenseInfo('01151110-v', 4), SenseInfo('00557404-v', 4), SenseInfo('02717102-v', 2), SenseInfo('02208537-v', 2), SenseInfo('02209745-v', 1), SenseInfo('02208118-v', 1), SenseInfo('02201138-v', 1), SenseInfo('01427127-v', 1), SenseInfo('00758333-v', 1), SenseInfo('02741546-v', 0), SenseInfo('02701210-v', 0), SenseInfo('02590253-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01100830-v', 0), SenseInfo('00087736-v', 0) ],
"_flood_v_cause_rel" : [ SenseInfo('01524523-v', 6), SenseInfo('00217152-v', 3), SenseInfo('02356704-v', 0), SenseInfo('00452220-v', 0) ],
"_smoke_v_1_rel" : [ SenseInfo('01198101-v', 12), SenseInfo('02767922-v', 0) ],
"_stop_n_1_rel" : [ SenseInfo('07365849-n', 3), SenseInfo('01076046-n', 3), SenseInfo('01056411-n', 3), SenseInfo('14010927-n', 1), SenseInfo('08656893-n', 1), SenseInfo('07115914-n', 0), SenseInfo('06843520-n', 0), SenseInfo('04327324-n', 0), SenseInfo('03189083-n', 0), SenseInfo('02982790-n', 0), SenseInfo('02853449-n', 0) ],
"_purify_v_1_rel" : [ SenseInfo('00475183-v', 2), SenseInfo('00475819-v', 1), SenseInfo('00476133-v', 0) ],
"_epispastic_n_1_rel" : [  ],
"_sniff_v_1_rel" : [ SenseInfo('02125032-v', 5), SenseInfo('00007549-v', 1), SenseInfo('02125032-v', 5), SenseInfo('00007549-v', 1) ],
"_spanish_n_1_rel" : [ SenseInfo('06966825-n', 6), SenseInfo('09733243-n', 1), SenseInfo('06966825-n', 6), SenseInfo('09733243-n', 1), SenseInfo('06966825-n', 6), SenseInfo('09733243-n', 1) ],
"_blurt_v_out_rel" : [ SenseInfo('00981944-v', 1) ],
"_inanimate_a_1_rel" : [ SenseInfo('00120411-a', 1), SenseInfo('00118238-a', 0), SenseInfo('00096595-a', 0) ],
"_scramble_v_1_rel" : [ SenseInfo('01886334-v', 9), SenseInfo('01921772-v', 4), SenseInfo('01472807-v', 0), SenseInfo('01418179-v', 0), SenseInfo('00537316-v', 0), SenseInfo('01886334-v', 9), SenseInfo('01921772-v', 4), SenseInfo('01472807-v', 0), SenseInfo('01418179-v', 0), SenseInfo('00537316-v', 0) ],
"_rapids_n_1_rel" : [ SenseInfo('09405396-n', 0), SenseInfo('09405396-n', 0) ],
"_murmur_v_to_rel" : [ SenseInfo('01044114-v', 15), SenseInfo('00909219-v', 0), SenseInfo('01044114-v', 15), SenseInfo('00909219-v', 0) ],
"_memoir_n_1_rel" : [ SenseInfo('06516495-n', 1), SenseInfo('06410187-n', 0) ],
"_instead+of_p_rel" : [  ],
"_request_n_for_rel" : [ SenseInfo('06513366-n', 10), SenseInfo('07185325-n', 4), SenseInfo('06513366-n', 10), SenseInfo('07185325-n', 4), SenseInfo('06513366-n', 10), SenseInfo('07185325-n', 4), SenseInfo('06513366-n', 10), SenseInfo('07185325-n', 4), SenseInfo('06513366-n', 10), SenseInfo('07185325-n', 4) ],
"_herbivore_n_1_rel" : [ SenseInfo('01324610-n', 0) ],
"_likelihood_n_of_rel" : [ SenseInfo('04756635-n', 2), SenseInfo('04756635-n', 2) ],
"_anchor_v_1_rel" : [ SenseInfo('01304944-v', 3), SenseInfo('01304716-v', 3) ],
"_mechanize_v_1_rel" : [ SenseInfo('00480751-v', 0), SenseInfo('00480569-v', 0), SenseInfo('00479598-v', 0) ],
"_upper_a_1_rel" : [ SenseInfo('02440617-a', 18), SenseInfo('01206318-a', 14), SenseInfo('02340096-a', 0), SenseInfo('02440617-a', 18), SenseInfo('01206318-a', 14), SenseInfo('02340096-a', 0) ],
"_selenium_n_1_rel" : [ SenseInfo('14654175-n', 0) ],
"_baffle_v_1_rel" : [ SenseInfo('00622384-v', 1), SenseInfo('02558172-v', 0), SenseInfo('00234988-v', 0), SenseInfo('00622384-v', 1), SenseInfo('02558172-v', 0), SenseInfo('00234988-v', 0), SenseInfo('00622384-v', 1), SenseInfo('02558172-v', 0), SenseInfo('00234988-v', 0) ],
"_resize_v_1_rel" : [ SenseInfo('00319629-v', 0) ],
"_microprocessor_n_1_rel" : [ SenseInfo('03760310-n', 0) ],
"_sniff_v_at_rel" : [ SenseInfo('02125032-v', 5), SenseInfo('00007549-v', 1) ],
"_oats_n_1_rel" : [ SenseInfo('12109827-n', 1), SenseInfo('07804152-n', 0), SenseInfo('12109827-n', 1), SenseInfo('07804152-n', 0) ],
"_landscape_v_1_rel" : [ SenseInfo('01751836-v', 0), SenseInfo('01741221-v', 0) ],
"_aside+from_p_rel" : [  ],
"_pinion_n_1_rel" : [ SenseInfo('03943115-n', 0), SenseInfo('02468864-n', 0), SenseInfo('02152446-n', 0) ],
"_sforzando_n_1_rel" : [ SenseInfo('06869742-n', 1), SenseInfo('06869428-n', 0) ],
"_really_a_1_rel" : [  ],
"_meteorite_n_1_rel" : [ SenseInfo('09352849-n', 8) ],
"_northeast_n_of_rel" : [ SenseInfo('13831843-n', 1), SenseInfo('08563990-n', 1), SenseInfo('13835546-n', 0), SenseInfo('08561230-n', 0), SenseInfo('13831843-n', 1), SenseInfo('08563990-n', 1), SenseInfo('13835546-n', 0), SenseInfo('08561230-n', 0), SenseInfo('13831843-n', 1), SenseInfo('08563990-n', 1), SenseInfo('13835546-n', 0), SenseInfo('08561230-n', 0), SenseInfo('13831843-n', 1), SenseInfo('08563990-n', 1), SenseInfo('13835546-n', 0), SenseInfo('08561230-n', 0), SenseInfo('13831843-n', 1), SenseInfo('08563990-n', 1), SenseInfo('13835546-n', 0), SenseInfo('08561230-n', 0), SenseInfo('13831843-n', 1), SenseInfo('08563990-n', 1), SenseInfo('13835546-n', 0), SenseInfo('08561230-n', 0), SenseInfo('13831843-n', 1), SenseInfo('08563990-n', 1), SenseInfo('13835546-n', 0), SenseInfo('08561230-n', 0) ],
"_urielite_a_1_rel" : [  ],
"_chances+are_a_1_rel" : [  ],
"_merger_n_1_rel" : [ SenseInfo('01238424-n', 6), SenseInfo('07373602-n', 0), SenseInfo('01238424-n', 6), SenseInfo('07373602-n', 0), SenseInfo('01238424-n', 6), SenseInfo('07373602-n', 0) ],
"_picnic_n_1_rel" : [ SenseInfo('15138691-n', 2), SenseInfo('00575365-n', 1), SenseInfo('07576438-n', 0) ],
"_whiteface_n_1_rel" : [ SenseInfo('02407625-n', 2), SenseInfo('10778044-n', 0) ],
"_ice+skate_v_1_rel" : [ SenseInfo('01937222-v', 0), SenseInfo('01937222-v', 0) ],
"_drop_n_of_rel" : [ SenseInfo('13901585-n', 9), SenseInfo('13771404-n', 9), SenseInfo('05111835-n', 1), SenseInfo('09246464-n', 0), SenseInfo('08583793-n', 0), SenseInfo('07362386-n', 0), SenseInfo('03246454-n', 0), SenseInfo('03246052-n', 0), SenseInfo('00327366-n', 0) ],
"_family_n_of_rel" : [ SenseInfo('08078020-n', 66), SenseInfo('07970406-n', 52), SenseInfo('07997703-n', 8), SenseInfo('07970721-n', 5), SenseInfo('10236304-n', 2), SenseInfo('08107499-n', 2), SenseInfo('08246302-n', 0), SenseInfo('08227916-n', 0), SenseInfo('08078020-n', 66), SenseInfo('07970406-n', 52), SenseInfo('07997703-n', 8), SenseInfo('07970721-n', 5), SenseInfo('10236304-n', 2), SenseInfo('08107499-n', 2), SenseInfo('08246302-n', 0), SenseInfo('08227916-n', 0), SenseInfo('08078020-n', 66), SenseInfo('07970406-n', 52), SenseInfo('07997703-n', 8), SenseInfo('07970721-n', 5), SenseInfo('10236304-n', 2), SenseInfo('08107499-n', 2), SenseInfo('08246302-n', 0), SenseInfo('08227916-n', 0) ],
"_versatility_n_1_rel" : [ SenseInfo('05641834-n', 1) ],
"_meet_n_1_rel" : [ SenseInfo('07467846-n', 4) ],
"_type_v_in_rel" : [ SenseInfo('01004692-v', 2), SenseInfo('00618682-v', 1) ],
"_extremis_n_1_rel" : [  ],
"_pinch_v_1_rel" : [ SenseInfo('01456771-v', 3), SenseInfo('01457206-v', 2), SenseInfo('02276866-v', 0), SenseInfo('01321509-v', 0), SenseInfo('00504019-v', 0) ],
"_bleed_v_cause_rel" : [ SenseInfo('00074834-v', 10), SenseInfo('00086077-v', 2), SenseInfo('02360003-v', 0), SenseInfo('02060792-v', 0), SenseInfo('00449153-v', 0) ],
"_or_p_rel" : [ SenseInfo('09133010-n', 0), SenseInfo('03850245-n', 0) ],
"_urgency_n_1_rel" : [ SenseInfo('14451020-n', 2), SenseInfo('05171800-n', 1), SenseInfo('13944516-n', 0), SenseInfo('07188385-n', 0) ],
"_way_n_of_rel" : [ SenseInfo('04928903-n', 183), SenseInfo('00172710-n', 61), SenseInfo('08679972-n', 40), SenseInfo('13939604-n', 28), SenseInfo('00415676-n', 19), SenseInfo('04564698-n', 16), SenseInfo('00312691-n', 12), SenseInfo('13777764-n', 10), SenseInfo('05084733-n', 7), SenseInfo('05791764-n', 3), SenseInfo('05839910-n', 1), SenseInfo('13285973-n', 0), SenseInfo('04928903-n', 183), SenseInfo('00172710-n', 61), SenseInfo('08679972-n', 40), SenseInfo('13939604-n', 28), SenseInfo('00415676-n', 19), SenseInfo('04564698-n', 16), SenseInfo('00312691-n', 12), SenseInfo('13777764-n', 10), SenseInfo('05084733-n', 7), SenseInfo('05791764-n', 3), SenseInfo('05839910-n', 1), SenseInfo('13285973-n', 0), SenseInfo('04928903-n', 183), SenseInfo('00172710-n', 61), SenseInfo('08679972-n', 40), SenseInfo('13939604-n', 28), SenseInfo('00415676-n', 19), SenseInfo('04564698-n', 16), SenseInfo('00312691-n', 12), SenseInfo('13777764-n', 10), SenseInfo('05084733-n', 7), SenseInfo('05791764-n', 3), SenseInfo('05839910-n', 1), SenseInfo('13285973-n', 0), SenseInfo('04928903-n', 183), SenseInfo('00172710-n', 61), SenseInfo('08679972-n', 40), SenseInfo('13939604-n', 28), SenseInfo('00415676-n', 19), SenseInfo('04564698-n', 16), SenseInfo('00312691-n', 12), SenseInfo('13777764-n', 10), SenseInfo('05084733-n', 7), SenseInfo('05791764-n', 3), SenseInfo('05839910-n', 1), SenseInfo('13285973-n', 0) ],
"_reverent_a_1_rel" : [ SenseInfo('02011810-a', 0), SenseInfo('01781882-a', 0) ],
"_thumb_v_through_rel" : [ SenseInfo('01956955-v', 2), SenseInfo('02153023-v', 0), SenseInfo('01209953-v', 0) ],
"_at+present_p_rel" : [ SenseInfo('00049220-r', 8) ],
"_hplc_n_1_rel" : [  ],
"_theory_n_of_rel" : [ SenseInfo('05989479-n', 49), SenseInfo('05888929-n', 18), SenseInfo('05952979-n', 5), SenseInfo('05989479-n', 49), SenseInfo('05888929-n', 18), SenseInfo('05952979-n', 5) ],
"_shelter_n_1_rel" : [ SenseInfo('04191595-n', 56), SenseInfo('04191943-n', 3), SenseInfo('14539960-n', 0), SenseInfo('13313733-n', 0), SenseInfo('04192238-n', 0) ],
"_molar_n_1_rel" : [ SenseInfo('05307773-n', 0) ],
"_economical_a_1_rel" : [ SenseInfo('00840212-a', 6), SenseInfo('02716739-a', 2), SenseInfo('02421364-a', 1), SenseInfo('00840212-a', 6), SenseInfo('02716739-a', 2), SenseInfo('02421364-a', 1) ],
"_read+write_a_1_rel" : [  ],
"_gymnastic_a_1_rel" : [ SenseInfo('00032497-a', 4), SenseInfo('02849732-a', 0) ],
"_watery_a_1_rel" : [ SenseInfo('02551259-a', 1), SenseInfo('02549857-a', 1), SenseInfo('02262365-a', 0), SenseInfo('00756459-a', 0), SenseInfo('02551259-a', 1), SenseInfo('02549857-a', 1), SenseInfo('02262365-a', 0), SenseInfo('00756459-a', 0), SenseInfo('02551259-a', 1), SenseInfo('02549857-a', 1), SenseInfo('02262365-a', 0), SenseInfo('00756459-a', 0) ],
"_gnarl_n_1_rel" : [ SenseInfo('13885836-n', 0) ],
"_play_v_1_rel" : [ SenseInfo('01072949-v', 70), SenseInfo('02370650-v', 37), SenseInfo('01725051-v', 29), SenseInfo('01719302-v', 27), SenseInfo('02418686-v', 23), SenseInfo('01724459-v', 14), SenseInfo('01726172-v', 8), SenseInfo('00013615-v', 6), SenseInfo('01903385-v', 5), SenseInfo('01138911-v', 5), SenseInfo('02418421-v', 4), SenseInfo('01722077-v', 4), SenseInfo('01717436-v', 3), SenseInfo('01716619-v', 2), SenseInfo('01149470-v', 2), SenseInfo('00013328-v', 2), SenseInfo('02597601-v', 1), SenseInfo('01717169-v', 1), SenseInfo('01586278-v', 1), SenseInfo('01163355-v', 1), SenseInfo('00711932-v', 1), SenseInfo('02722449-v', 0), SenseInfo('02437465-v', 0), SenseInfo('01903562-v', 0), SenseInfo('01719921-v', 0), SenseInfo('01716882-v', 0), SenseInfo('01629589-v', 0), SenseInfo('01377239-v', 0), SenseInfo('01156115-v', 0), SenseInfo('01155687-v', 0), SenseInfo('01080691-v', 0), SenseInfo('01080064-v', 0), SenseInfo('01079873-v', 0), SenseInfo('01079480-v', 0), SenseInfo('00075875-v', 0), SenseInfo('01072949-v', 70), SenseInfo('02370650-v', 37), SenseInfo('01725051-v', 29), SenseInfo('01719302-v', 27), SenseInfo('02418686-v', 23), SenseInfo('01724459-v', 14), SenseInfo('01726172-v', 8), SenseInfo('00013615-v', 6), SenseInfo('01903385-v', 5), SenseInfo('01138911-v', 5), SenseInfo('02418421-v', 4), SenseInfo('01722077-v', 4), SenseInfo('01717436-v', 3), SenseInfo('01716619-v', 2), SenseInfo('01149470-v', 2), SenseInfo('00013328-v', 2), SenseInfo('02597601-v', 1), SenseInfo('01717169-v', 1), SenseInfo('01586278-v', 1), SenseInfo('01163355-v', 1), SenseInfo('00711932-v', 1), SenseInfo('02722449-v', 0), SenseInfo('02437465-v', 0), SenseInfo('01903562-v', 0), SenseInfo('01719921-v', 0), SenseInfo('01716882-v', 0), SenseInfo('01629589-v', 0), SenseInfo('01377239-v', 0), SenseInfo('01156115-v', 0), SenseInfo('01155687-v', 0), SenseInfo('01080691-v', 0), SenseInfo('01080064-v', 0), SenseInfo('01079873-v', 0), SenseInfo('01079480-v', 0), SenseInfo('00075875-v', 0) ],
"_provide_v_1_rel" : [ SenseInfo('02327200-v', 270), SenseInfo('01182709-v', 25), SenseInfo('01063188-v', 14), SenseInfo('02376289-v', 2), SenseInfo('02721438-v', 0), SenseInfo('02219442-v', 0), SenseInfo('00406963-v', 0), SenseInfo('02327200-v', 270), SenseInfo('01182709-v', 25), SenseInfo('01063188-v', 14), SenseInfo('02376289-v', 2), SenseInfo('02721438-v', 0), SenseInfo('02219442-v', 0), SenseInfo('00406963-v', 0), SenseInfo('02327200-v', 270), SenseInfo('01182709-v', 25), SenseInfo('01063188-v', 14), SenseInfo('02376289-v', 2), SenseInfo('02721438-v', 0), SenseInfo('02219442-v', 0), SenseInfo('00406963-v', 0), SenseInfo('02327200-v', 270), SenseInfo('01182709-v', 25), SenseInfo('01063188-v', 14), SenseInfo('02376289-v', 2), SenseInfo('02721438-v', 0), SenseInfo('02219442-v', 0), SenseInfo('00406963-v', 0), SenseInfo('02327200-v', 270), SenseInfo('01182709-v', 25), SenseInfo('01063188-v', 14), SenseInfo('02376289-v', 2), SenseInfo('02721438-v', 0), SenseInfo('02219442-v', 0), SenseInfo('00406963-v', 0) ],
"_plump_v_for_rel" : [ SenseInfo('01978199-v', 0), SenseInfo('01500572-v', 0), SenseInfo('01194938-v', 0), SenseInfo('00676267-v', 0) ],
"_tenant_n_1_rel" : [ SenseInfo('10700201-n', 4), SenseInfo('10700640-n', 0), SenseInfo('10700517-n', 0) ],
"_gash_v_1_rel" : [ SenseInfo('01322509-v', 1) ],
"_dolomite-spread_a_1_rel" : [  ],
"_lump_v_1_rel" : [ SenseInfo('01385920-v', 2), SenseInfo('00657016-v', 0), SenseInfo('01385920-v', 2), SenseInfo('00657016-v', 0) ],
"_okay_a_accept_rel" : [ SenseInfo('02081114-a', 2) ],
"_saturate_v_1_rel" : [ SenseInfo('00456357-v', 1), SenseInfo('00497705-v', 0), SenseInfo('00456357-v', 1), SenseInfo('00497705-v', 0), SenseInfo('00456357-v', 1), SenseInfo('00497705-v', 0) ],
"_obelisk_n_1_rel" : [ SenseInfo('03837869-n', 1), SenseInfo('06828529-n', 0) ],
"_center+of+mass_n_1_rel" : [ SenseInfo('08522872-n', 0), SenseInfo('08522872-n', 0), SenseInfo('08522872-n', 0), SenseInfo('08522872-n', 0) ],
"_tanker_n_1_rel" : [ SenseInfo('03845190-n', 1), SenseInfo('10690648-n', 0) ],
"_fragment_n_1_rel" : [ SenseInfo('09285254-n', 7), SenseInfo('04184701-n', 1), SenseInfo('07008680-n', 0) ],
"_tollbooth_n_1_rel" : [ SenseInfo('04449290-n', 0) ],
"_rush_v_out_rel" : [ SenseInfo('02058994-v', 20), SenseInfo('01119950-v', 6), SenseInfo('00459296-v', 2), SenseInfo('00459498-v', 1), SenseInfo('02059770-v', 0), SenseInfo('02059462-v', 0), SenseInfo('01644522-v', 0) ],
"_drawback_n_1_rel" : [ SenseInfo('05164521-n', 0) ],
"_inaccurate_a_1_rel" : [ SenseInfo('00023383-a', 2), SenseInfo('00023383-a', 2) ],
"_page_n_1_rel" : [ SenseInfo('06256697-n', 34), SenseInfo('11220149-n', 0), SenseInfo('11219992-n', 0), SenseInfo('10391416-n', 0), SenseInfo('10391248-n', 0), SenseInfo('10391086-n', 0), SenseInfo('06256697-n', 34), SenseInfo('11220149-n', 0), SenseInfo('11219992-n', 0), SenseInfo('10391416-n', 0), SenseInfo('10391248-n', 0), SenseInfo('10391086-n', 0) ],
"_sorry_a_for_rel" : [ SenseInfo('01150475-a', 1), SenseInfo('01126841-a', 1), SenseInfo('02502578-a', 0), SenseInfo('00364881-a', 0), SenseInfo('01150475-a', 1), SenseInfo('01126841-a', 1), SenseInfo('02502578-a', 0), SenseInfo('00364881-a', 0), SenseInfo('01150475-a', 1), SenseInfo('01126841-a', 1), SenseInfo('02502578-a', 0), SenseInfo('00364881-a', 0) ],
"_wise_a_for_rel" : [ SenseInfo('02569130-a', 13), SenseInfo('01898722-a', 2), SenseInfo('01307690-a', 0), SenseInfo('00205295-a', 0), SenseInfo('02569130-a', 13), SenseInfo('01898722-a', 2), SenseInfo('01307690-a', 0), SenseInfo('00205295-a', 0), SenseInfo('02569130-a', 13), SenseInfo('01898722-a', 2), SenseInfo('01307690-a', 0), SenseInfo('00205295-a', 0), SenseInfo('02569130-a', 13), SenseInfo('01898722-a', 2), SenseInfo('01307690-a', 0), SenseInfo('00205295-a', 0), SenseInfo('02569130-a', 13), SenseInfo('01898722-a', 2), SenseInfo('01307690-a', 0), SenseInfo('00205295-a', 0) ],
"_click_v_cause_rel" : [ SenseInfo('01893771-v', 5), SenseInfo('02185664-v', 1), SenseInfo('02185861-v', 0), SenseInfo('01242208-v', 0), SenseInfo('01055146-v', 0), SenseInfo('01054849-v', 0), SenseInfo('00591755-v', 0) ],
"_unbecoming_a_1_rel" : [ SenseInfo('01880918-a', 0) ],
"_boil_n_1_rel" : [ SenseInfo('14183210-n', 0), SenseInfo('05014099-n', 0) ],
"_trick_n_1_rel" : [ SenseInfo('00171618-n', 2), SenseInfo('15292260-n', 1), SenseInfo('00750730-n', 1), SenseInfo('00427580-n', 1), SenseInfo('00099951-n', 1), SenseInfo('10779995-n', 0), SenseInfo('01259594-n', 0) ],
"_brim_n_of_rel" : [ SenseInfo('02902250-n', 1), SenseInfo('02902079-n', 0), SenseInfo('02902250-n', 1), SenseInfo('02902079-n', 0) ],
"_for+real_a_1_rel" : [  ],
"_kindness_n_1_rel" : [ SenseInfo('04840011-n', 0), SenseInfo('04829764-n', 0), SenseInfo('00034574-n', 0), SenseInfo('04840011-n', 0), SenseInfo('04829764-n', 0), SenseInfo('00034574-n', 0) ],
"_rust_v_out_rel" : [ SenseInfo('00273963-v', 2), SenseInfo('00274283-v', 0), SenseInfo('00239614-v', 0) ],
"_portability_n_1_rel" : [ SenseInfo('04776176-n', 0) ],
"_illustrator_n_of_rel" : [ SenseInfo('09812068-n', 2) ],
"_torch_n_1_rel" : [ SenseInfo('04456115-n', 2), SenseInfo('12889713-n', 0), SenseInfo('03359137-n', 0), SenseInfo('02855390-n', 0) ],
"_scratch_v_up_rel" : [ SenseInfo('01250908-v', 9), SenseInfo('01309143-v', 8), SenseInfo('02119874-v', 1), SenseInfo('02477755-v', 0), SenseInfo('01549420-v', 0), SenseInfo('01384752-v', 0), SenseInfo('01321895-v', 0) ],
"_bottle_n_of_rel" : [ SenseInfo('02876657-n', 28), SenseInfo('13765396-n', 2), SenseInfo('02877266-n', 0) ],
"_full+blown_a_1_rel" : [ SenseInfo('01489085-a', 0), SenseInfo('00523068-a', 0), SenseInfo('01489085-a', 0), SenseInfo('00523068-a', 0) ],
"_valid_a_1_rel" : [ SenseInfo('02498708-a', 5), SenseInfo('00938659-a', 0) ],
"_administration_n_of_rel" : [ SenseInfo('01135952-n', 8), SenseInfo('08164585-n', 3), SenseInfo('00694990-n', 2), SenseInfo('15266265-n', 1), SenseInfo('01124794-n', 0), SenseInfo('00694866-n', 0) ],
"_intent_n_1_rel" : [ SenseInfo('05982152-n', 3), SenseInfo('06605897-n', 2), SenseInfo('05982152-n', 3), SenseInfo('06605897-n', 2) ],
"_cowshed_n_1_rel" : [ SenseInfo('03123809-n', 0) ],
"_bundle_v_1_rel" : [ SenseInfo('01487008-v', 2), SenseInfo('01484392-v', 0), SenseInfo('01483779-v', 0), SenseInfo('00015163-v', 0), SenseInfo('01487008-v', 2), SenseInfo('01484392-v', 0), SenseInfo('01483779-v', 0), SenseInfo('00015163-v', 0) ],
"_troubled_a_1_rel" : [ SenseInfo('02455297-a', 1), SenseInfo('01923720-a', 1), SenseInfo('02455297-a', 1), SenseInfo('01923720-a', 1) ],
"_jump+rope_v_1_rel" : [  ],
"_lamechian_n_1_rel" : [  ],
"_buffalo_n_1_rel" : [ SenseInfo('02410702-n', 3), SenseInfo('09118505-n', 0), SenseInfo('07663492-n', 0), SenseInfo('02407959-n', 0) ],
"_touristic_a_1_rel" : [  ],
"_faster_a_1_rel" : [  ],
"_strength_n_1_rel" : [ SenseInfo('05029706-n', 42), SenseInfo('05203649-n', 10), SenseInfo('05035353-n', 4), SenseInfo('05159225-n', 2), SenseInfo('05191832-n', 1), SenseInfo('05099796-n', 1), SenseInfo('05034225-n', 1), SenseInfo('14474556-n', 0), SenseInfo('05053688-n', 0) ],
"_retaliate_v_1_rel" : [ SenseInfo('01153486-v', 1), SenseInfo('01153165-v', 1) ],
"_sweat_v_1_rel" : [ SenseInfo('00067545-v', 5) ],
"_read_n_1_rel" : [ SenseInfo('06590065-n', 0) ],
"_stun+gun_n_1_rel" : [ SenseInfo('04346157-n', 0) ],
"_sprinkle_v_1_rel" : [ SenseInfo('01376245-v', 5), SenseInfo('01374767-v', 1), SenseInfo('02757828-v', 0), SenseInfo('00228655-v', 0) ],
"_awe_n_1_rel" : [ SenseInfo('07510184-n', 4), SenseInfo('07521039-n', 0) ],
"_rosemary_n_1_rel" : [ SenseInfo('12864160-n', 0), SenseInfo('07820145-n', 0) ],
"_pet_v_1_rel" : [ SenseInfo('01425892-v', 1), SenseInfo('01226600-v', 0) ],
"_smack_n_1_rel" : [ SenseInfo('07410745-n', 0), SenseInfo('05715864-n', 0), SenseInfo('04244847-n', 0), SenseInfo('02837416-n', 0), SenseInfo('00138599-n', 0), SenseInfo('00133668-n', 0) ],
"_soda_n_1_rel" : [ SenseInfo('15044844-n', 0), SenseInfo('07927512-n', 0) ],
"_profusion_n_of_rel" : [ SenseInfo('05115804-n', 1), SenseInfo('05115804-n', 1) ],
"_angular_a_1_rel" : [ SenseInfo('02930616-a', 1), SenseInfo('02047807-a', 1) ],
"_hide-and-seek_n_1_rel" : [ SenseInfo('00484910-n', 0), SenseInfo('00484910-n', 0) ],
"_deserving_a_1_rel" : [ SenseInfo('02586206-a', 2) ],
"_dormancy_n_1_rel" : [ SenseInfo('14011811-n', 0), SenseInfo('01064863-n', 0) ],
"_overflow_v_cause_rel" : [ SenseInfo('02072159-v', 2), SenseInfo('01763101-v', 0) ],
"_flourish_v_1_rel" : [ SenseInfo('00310386-v', 11), SenseInfo('02342800-v', 1), SenseInfo('01446901-v', 0) ],
"_bear_v_out_rel" : [ SenseInfo('02630871-v', 23), SenseInfo('00056930-v', 17), SenseInfo('00668099-v', 13), SenseInfo('01432601-v', 10), SenseInfo('01652139-v', 6), SenseInfo('02301825-v', 5), SenseInfo('02700867-v', 4), SenseInfo('02291708-v', 4), SenseInfo('00047745-v', 1), SenseInfo('02518161-v', 0), SenseInfo('02302220-v', 0), SenseInfo('01601234-v', 0), SenseInfo('00059019-v', 0) ],
"_clockwise_p_rel" : [ SenseInfo('00441781-a', 1), SenseInfo('00254369-r', 0) ],
"_massage_v_1_rel" : [ SenseInfo('01232738-v', 1), SenseInfo('00064487-v', 1) ],
"_limp_n_1_rel" : [ SenseInfo('00286756-n', 0) ],
"_mushroom_n_1_rel" : [ SenseInfo('13001041-n', 0), SenseInfo('13000891-n', 0), SenseInfo('12997919-n', 0), SenseInfo('11442073-n', 0), SenseInfo('07734744-n', 0) ],
"_flail_v_1_rel" : [ SenseInfo('01416193-v', 1), SenseInfo('02093920-v', 0) ],
"_jest_v_1_rel" : [ SenseInfo('00853633-v', 1), SenseInfo('00105554-v', 0), SenseInfo('00853633-v', 1), SenseInfo('00105554-v', 0) ],
"_pretext_n_1_rel" : [ SenseInfo('06759776-n', 1), SenseInfo('04678908-n', 0), SenseInfo('06759776-n', 1), SenseInfo('04678908-n', 0), SenseInfo('06759776-n', 1), SenseInfo('04678908-n', 0), SenseInfo('06759776-n', 1), SenseInfo('04678908-n', 0) ],
"_evidence_n_of_rel" : [ SenseInfo('05823932-n', 54), SenseInfo('06643408-n', 23), SenseInfo('06733939-n', 7), SenseInfo('05823932-n', 54), SenseInfo('06643408-n', 23), SenseInfo('06733939-n', 7) ],
"_copy_v_down_rel" : [ SenseInfo('01747374-v', 3), SenseInfo('01742886-v', 3), SenseInfo('01734929-v', 0), SenseInfo('01693881-v', 0) ],
"_resemblance_n_1_rel" : [ SenseInfo('04747445-n', 7) ],
"_flyfisher_n_1_rel" : [  ],
"_eradicate_v_1_rel" : [ SenseInfo('00470701-v', 2), SenseInfo('01662118-v', 0) ],
"_ferry_v_1_rel" : [ SenseInfo('01949674-v', 1), SenseInfo('01949435-v', 0), SenseInfo('01949218-v', 0), SenseInfo('01949674-v', 1), SenseInfo('01949435-v', 0), SenseInfo('01949218-v', 0) ],
"_corrode_v_cause_rel" : [ SenseInfo('00274283-v', 1), SenseInfo('00273963-v', 0) ],
"_jimmy_v_1_rel" : [ SenseInfo('01593254-v', 1) ],
"_smoke_n_1_rel" : [ SenseInfo('11508092-n', 65), SenseInfo('13556893-n', 4), SenseInfo('06802880-n', 0), SenseInfo('04761960-n', 0), SenseInfo('04103491-n', 0), SenseInfo('03990834-n', 0), SenseInfo('00834636-n', 0), SenseInfo('00108181-n', 0) ],
"_compulsory_a_1_rel" : [ SenseInfo('00848466-a', 0) ],
"_ideal_a_1_rel" : [ SenseInfo('01751201-a', 8), SenseInfo('00012689-a', 2), SenseInfo('02745284-a', 0), SenseInfo('01751201-a', 8), SenseInfo('00012689-a', 2), SenseInfo('02745284-a', 0) ],
"_tradition_n_1_rel" : [ SenseInfo('05809745-n', 28), SenseInfo('05667404-n', 15) ],
"_learn_v_of_rel" : [ SenseInfo('00597915-v', 90), SenseInfo('00598954-v', 53), SenseInfo('00604576-v', 6), SenseInfo('00599992-v', 3), SenseInfo('00829107-v', 2), SenseInfo('00920336-v', 0), SenseInfo('00597915-v', 90), SenseInfo('00598954-v', 53), SenseInfo('00604576-v', 6), SenseInfo('00599992-v', 3), SenseInfo('00829107-v', 2), SenseInfo('00920336-v', 0), SenseInfo('00597915-v', 90), SenseInfo('00598954-v', 53), SenseInfo('00604576-v', 6), SenseInfo('00599992-v', 3), SenseInfo('00829107-v', 2), SenseInfo('00920336-v', 0) ],
"_possessor_n_1_rel" : [ SenseInfo('10389398-n', 0) ],
"_oatmeal_n_1_rel" : [ SenseInfo('07874995-n', 1), SenseInfo('07568502-n', 0) ],
"_on-chip_a_1_rel" : [  ],
"_ripple_v_1_rel" : [ SenseInfo('02040054-v', 2), SenseInfo('02187922-v', 1) ],
"_clutch_n_of_rel" : [ SenseInfo('00812526-n', 2), SenseInfo('14032737-n', 1), SenseInfo('08400870-n', 0), SenseInfo('08400452-n', 0), SenseInfo('03055418-n', 0), SenseInfo('03055159-n', 0), SenseInfo('03054901-n', 0) ],
"_dancehall_n_1_rel" : [  ],
"_sneaky_a_1_rel" : [ SenseInfo('02319346-a', 0), SenseInfo('02088974-a', 0), SenseInfo('02319346-a', 0), SenseInfo('02088974-a', 0) ],
"_toxic_a_1_rel" : [ SenseInfo('02449430-a', 3) ],
"_green_a_2_rel" : [ SenseInfo('00375969-a', 26), SenseInfo('03069937-a', 0), SenseInfo('01493897-a', 0), SenseInfo('02545257-a', 0), SenseInfo('02272485-a', 0) ],
"_envy_n_of_rel" : [ SenseInfo('07549716-n', 2), SenseInfo('00758335-n', 0) ],
"_fluffy_a_1_rel" : [ SenseInfo('01154030-a', 1) ],
"_ltd_n_1_rel" : [  ],
"_expect_v_of_rel" : [ SenseInfo('00719734-v', 204), SenseInfo('00755745-v', 30), SenseInfo('00720063-v', 12), SenseInfo('00592702-v', 0), SenseInfo('00059376-v', 0), SenseInfo('00059019-v', 0) ],
"_endocarp_n_1_rel" : [ SenseInfo('11684739-n', 0) ],
"_jewel_n_1_rel" : [ SenseInfo('03596787-n', 2), SenseInfo('10221656-n', 0) ],
"_lobe_n_1_rel" : [ SenseInfo('05493303-n', 6), SenseInfo('13161506-n', 0), SenseInfo('07005523-n', 0), SenseInfo('03680734-n', 0) ],
"_much-abused_a_1_rel" : [  ],
"_wake_v_up_rel" : [ SenseInfo('00020133-v', 7), SenseInfo('00018526-v', 3), SenseInfo('01761120-v', 0), SenseInfo('00872747-v', 0), SenseInfo('00018813-v', 0), SenseInfo('00020133-v', 7), SenseInfo('00018526-v', 3), SenseInfo('01761120-v', 0), SenseInfo('00872747-v', 0), SenseInfo('00018813-v', 0) ],
"_lost_a_1_rel" : [ SenseInfo('01449564-a', 5), SenseInfo('01684133-a', 5), SenseInfo('01450969-a', 3), SenseInfo('01452266-a', 2), SenseInfo('01956855-a', 2), SenseInfo('00535170-a', 1), SenseInfo('02419159-a', 0), SenseInfo('01766133-a', 0), SenseInfo('01230616-a', 0) ],
"_revel_n_1_rel" : [ SenseInfo('00510189-n', 1) ],
"_on+the+basis+of_p_rel" : [  ],
"_hack_v_up_rel" : [ SenseInfo('01257173-v', 1), SenseInfo('02588280-v', 0), SenseInfo('01257817-v', 0), SenseInfo('01148199-v', 0), SenseInfo('01148101-v', 0), SenseInfo('00526441-v', 0), SenseInfo('00201618-v', 0), SenseInfo('00006100-v', 0) ],
"_MT_n_1_rel" : [ SenseInfo('14644963-n', 0), SenseInfo('13725588-n', 0), SenseInfo('09108164-n', 0), SenseInfo('06133503-n', 0) ],
"_scheme_v_1_rel" : [ SenseInfo('00707956-v', 1), SenseInfo('00708376-v', 0) ],
"_die_v_off_rel" : [ SenseInfo('00358431-v', 141), SenseInfo('02109818-v', 1), SenseInfo('01784953-v', 1), SenseInfo('00434374-v', 1), SenseInfo('01829475-v', 0), SenseInfo('01785242-v', 0), SenseInfo('01555034-v', 0), SenseInfo('01074914-v', 0), SenseInfo('00538323-v', 0), SenseInfo('00354845-v', 0), SenseInfo('00224295-v', 0) ],
"_afghani_n_1_rel" : [ SenseInfo('13663229-n', 0), SenseInfo('06975132-n', 0) ],
"_captivating_a_1_rel" : [ SenseInfo('00166753-a', 1) ],
"_dent_v_cause_rel" : [ SenseInfo('01279631-v', 3), SenseInfo('01279631-v', 3) ],
"_blast_v_out_rel" : [ SenseInfo('02182479-v', 3), SenseInfo('01401772-v', 2), SenseInfo('01135922-v', 1), SenseInfo('02101216-v', 0), SenseInfo('01759021-v', 0), SenseInfo('01758276-v', 0), SenseInfo('01134781-v', 0), SenseInfo('00823827-v', 0), SenseInfo('00336158-v', 0), SenseInfo('00241924-v', 0) ],
"_bush_n_1_rel" : [ SenseInfo('13112664-n', 5), SenseInfo('08505018-n', 2), SenseInfo('08438223-n', 2), SenseInfo('10875910-n', 0), SenseInfo('10875681-n', 0), SenseInfo('10875468-n', 0), SenseInfo('05263587-n', 0) ],
"_chorister_n_1_rel" : [ SenseInfo('09920771-n', 0) ],
"_divine_a_1_rel" : [ SenseInfo('01179547-a', 4), SenseInfo('01180363-a', 1), SenseInfo('01179767-a', 1), SenseInfo('02055460-a', 0), SenseInfo('01261127-a', 0), SenseInfo('01121507-a', 0) ],
"_flavorful_a_1_rel" : [ SenseInfo('02396911-a', 0) ],
"_anatomical_a_1_rel" : [ SenseInfo('02897524-a', 7), SenseInfo('02897730-a', 0) ],
"_study_n_of_rel" : [ SenseInfo('00644503-n', 90), SenseInfo('05755883-n', 17), SenseInfo('07218470-n', 6), SenseInfo('05705355-n', 6), SenseInfo('04345028-n', 6), SenseInfo('05996646-n', 3), SenseInfo('04227144-n', 2), SenseInfo('05784242-n', 1), SenseInfo('10666464-n', 0), SenseInfo('07048627-n', 0) ],
"_reproof_n_1_rel" : [ SenseInfo('06711855-n', 1) ],
"_skin_v_1_rel" : [ SenseInfo('01921772-v', 0), SenseInfo('01309478-v', 0), SenseInfo('01263784-v', 0), SenseInfo('01262936-v', 0) ],
"_derelict_n_1_rel" : [ SenseInfo('10006081-n', 0), SenseInfo('02666501-n', 0) ],
"_what+s+more_a_1_rel" : [  ],
"_forever_a_2_rel" : [  ],
"_pig_v_out_rel" : [ SenseInfo('02615739-v', 0), SenseInfo('01196653-v', 0), SenseInfo('00058645-v', 0) ],
"_expertise_n_1_rel" : [ SenseInfo('05640729-n', 2) ],
"_GPL-d_a_1_rel" : [  ],
"_alligator_n_1_rel" : [ SenseInfo('14760447-n', 1), SenseInfo('01698434-n', 1) ],
"_head_n_of_rel" : [ SenseInfo('05538625-n', 208), SenseInfo('01318381-n', 21), SenseInfo('05611302-n', 7), SenseInfo('10162991-n', 6), SenseInfo('08482271-n', 6), SenseInfo('11495607-n', 3), SenseInfo('08664184-n', 1), SenseInfo('08508449-n', 1), SenseInfo('06291809-n', 1), SenseInfo('14312481-n', 0), SenseInfo('13654380-n', 0), SenseInfo('13133786-n', 0), SenseInfo('10474645-n', 0), SenseInfo('10163354-n', 0), SenseInfo('10162780-n', 0), SenseInfo('09399592-n', 0), SenseInfo('09302031-n', 0), SenseInfo('09301844-n', 0), SenseInfo('08572467-n', 0), SenseInfo('07418822-n', 0), SenseInfo('07372779-n', 0), SenseInfo('06822034-n', 0), SenseInfo('06783768-n', 0), SenseInfo('06343971-n', 0), SenseInfo('05595837-n', 0), SenseInfo('05290756-n', 0), SenseInfo('04058721-n', 0), SenseInfo('03501811-n', 0), SenseInfo('03501614-n', 0), SenseInfo('03501520-n', 0), SenseInfo('03501288-n', 0), SenseInfo('03250279-n', 0), SenseInfo('00854876-n', 0), SenseInfo('05538625-n', 208), SenseInfo('01318381-n', 21), SenseInfo('05611302-n', 7), SenseInfo('10162991-n', 6), SenseInfo('08482271-n', 6), SenseInfo('11495607-n', 3), SenseInfo('08664184-n', 1), SenseInfo('08508449-n', 1), SenseInfo('06291809-n', 1), SenseInfo('14312481-n', 0), SenseInfo('13654380-n', 0), SenseInfo('13133786-n', 0), SenseInfo('10474645-n', 0), SenseInfo('10163354-n', 0), SenseInfo('10162780-n', 0), SenseInfo('09399592-n', 0), SenseInfo('09302031-n', 0), SenseInfo('09301844-n', 0), SenseInfo('08572467-n', 0), SenseInfo('07418822-n', 0), SenseInfo('07372779-n', 0), SenseInfo('06822034-n', 0), SenseInfo('06783768-n', 0), SenseInfo('06343971-n', 0), SenseInfo('05595837-n', 0), SenseInfo('05290756-n', 0), SenseInfo('04058721-n', 0), SenseInfo('03501811-n', 0), SenseInfo('03501614-n', 0), SenseInfo('03501520-n', 0), SenseInfo('03501288-n', 0), SenseInfo('03250279-n', 0), SenseInfo('00854876-n', 0), SenseInfo('05538625-n', 208), SenseInfo('01318381-n', 21), SenseInfo('05611302-n', 7), SenseInfo('10162991-n', 6), SenseInfo('08482271-n', 6), SenseInfo('11495607-n', 3), SenseInfo('08664184-n', 1), SenseInfo('08508449-n', 1), SenseInfo('06291809-n', 1), SenseInfo('14312481-n', 0), SenseInfo('13654380-n', 0), SenseInfo('13133786-n', 0), SenseInfo('10474645-n', 0), SenseInfo('10163354-n', 0), SenseInfo('10162780-n', 0), SenseInfo('09399592-n', 0), SenseInfo('09302031-n', 0), SenseInfo('09301844-n', 0), SenseInfo('08572467-n', 0), SenseInfo('07418822-n', 0), SenseInfo('07372779-n', 0), SenseInfo('06822034-n', 0), SenseInfo('06783768-n', 0), SenseInfo('06343971-n', 0), SenseInfo('05595837-n', 0), SenseInfo('05290756-n', 0), SenseInfo('04058721-n', 0), SenseInfo('03501811-n', 0), SenseInfo('03501614-n', 0), SenseInfo('03501520-n', 0), SenseInfo('03501288-n', 0), SenseInfo('03250279-n', 0), SenseInfo('00854876-n', 0) ],
"_quadrat_n_1_rel" : [  ],
"_sentient_a_1_rel" : [ SenseInfo('00117385-a', 1), SenseInfo('00571424-a', 0) ],
"_yelp_n_1_rel" : [ SenseInfo('07400552-n', 1) ],
"_pregnancy_n_1_rel" : [ SenseInfo('14046202-n', 0) ],
"_violation_n_of_rel" : [ SenseInfo('00770270-n', 6), SenseInfo('00770543-n', 2), SenseInfo('00733483-n', 2), SenseInfo('00746232-n', 1), SenseInfo('00773402-n', 0) ],
"_gall_v_1_rel" : [ SenseInfo('02119659-v', 0), SenseInfo('01786760-v', 0), SenseInfo('02119659-v', 0), SenseInfo('01786760-v', 0), SenseInfo('02119659-v', 0), SenseInfo('01786760-v', 0), SenseInfo('02119659-v', 0), SenseInfo('01786760-v', 0), SenseInfo('02119659-v', 0), SenseInfo('01786760-v', 0), SenseInfo('02119659-v', 0), SenseInfo('01786760-v', 0) ],
"_dilution_n_of_rel" : [ SenseInfo('14835478-n', 4), SenseInfo('00362659-n', 2) ],
"_mutter_v_1_rel" : [ SenseInfo('01044533-v', 19), SenseInfo('00909219-v', 6), SenseInfo('01044533-v', 19), SenseInfo('00909219-v', 6) ],
"_cream_n_1_rel" : [ SenseInfo('08387035-n', 2), SenseInfo('07847198-n', 0), SenseInfo('03128519-n', 0) ],
"_lite_a_1_rel" : [ SenseInfo('00993117-a', 0) ],
"_intimidate_v_1_rel" : [ SenseInfo('01781180-v', 2), SenseInfo('01819554-v', 1), SenseInfo('01781180-v', 2), SenseInfo('01819554-v', 1), SenseInfo('01781180-v', 2), SenseInfo('01819554-v', 1), SenseInfo('01781180-v', 2), SenseInfo('01819554-v', 1), SenseInfo('01781180-v', 2), SenseInfo('01819554-v', 1), SenseInfo('01781180-v', 2), SenseInfo('01819554-v', 1) ],
"_figure_n_1_rel" : [ SenseInfo('06999647-n', 65), SenseInfo('05217168-n', 48), SenseInfo('13741022-n', 18), SenseInfo('03335600-n', 14), SenseInfo('10344443-n', 13), SenseInfo('13862780-n', 8), SenseInfo('13331634-n', 8), SenseInfo('04675646-n', 8), SenseInfo('05121418-n', 1), SenseInfo('07105475-n', 0), SenseInfo('05930386-n', 0), SenseInfo('03178782-n', 0), SenseInfo('00556992-n', 0), SenseInfo('06999647-n', 65), SenseInfo('05217168-n', 48), SenseInfo('13741022-n', 18), SenseInfo('03335600-n', 14), SenseInfo('10344443-n', 13), SenseInfo('13862780-n', 8), SenseInfo('13331634-n', 8), SenseInfo('04675646-n', 8), SenseInfo('05121418-n', 1), SenseInfo('07105475-n', 0), SenseInfo('05930386-n', 0), SenseInfo('03178782-n', 0), SenseInfo('00556992-n', 0) ],
"_solidify_v_1_rel" : [ SenseInfo('00445467-v', 0), SenseInfo('00445169-v', 0) ],
"_aunt_n_of_rel" : [ SenseInfo('09823502-n', 4) ],
"_discredit_n_1_rel" : [ SenseInfo('14439745-n', 1) ],
"_unfashionable_a_1_rel" : [ SenseInfo('00973844-a', 0), SenseInfo('00973844-a', 0) ],
"_rape_v_1_rel" : [ SenseInfo('02567519-v', 4), SenseInfo('01565472-v', 0) ],
"_froth_v_1_rel" : [ SenseInfo('00519363-v', 0), SenseInfo('00511855-v', 0), SenseInfo('00109389-v', 0) ],
"_easy-to-read_a_1_rel" : [  ],
"_antagonistic_a_1_rel" : [ SenseInfo('01818680-a', 1), SenseInfo('01245138-a', 1), SenseInfo('00760577-a', 0), SenseInfo('00623565-a', 0), SenseInfo('00508480-a', 0), SenseInfo('01818680-a', 1), SenseInfo('01245138-a', 1), SenseInfo('00760577-a', 0), SenseInfo('00623565-a', 0), SenseInfo('00508480-a', 0) ],
"_tenderness_n_1_rel" : [ SenseInfo('04627241-n', 3), SenseInfo('14332617-n', 0), SenseInfo('07554342-n', 0), SenseInfo('07544647-n', 0), SenseInfo('07505347-n', 0) ],
"_cent_n_1_rel" : [ SenseInfo('13664521-n', 15), SenseInfo('13390626-n', 2), SenseInfo('13664521-n', 15), SenseInfo('13390626-n', 2), SenseInfo('13664521-n', 15), SenseInfo('13390626-n', 2), SenseInfo('13664521-n', 15), SenseInfo('13390626-n', 2), SenseInfo('13664521-n', 15), SenseInfo('13390626-n', 2) ],
"_freckle_v_1_rel" : [ SenseInfo('00510116-v', 0), SenseInfo('00509857-v', 0) ],
"_under_p_sel_rel" : [ SenseInfo('00486509-r', 2), SenseInfo('01207546-a', 2), SenseInfo('00793682-a', 1), SenseInfo('00486694-r', 0), SenseInfo('00486605-r', 0), SenseInfo('00486384-r', 0), SenseInfo('00486296-r', 0), SenseInfo('00486223-r', 0), SenseInfo('00486157-r', 0), SenseInfo('00486067-r', 0) ],
"_emphasis_n_on_rel" : [ SenseInfo('14434866-n', 18), SenseInfo('05037394-n', 7), SenseInfo('07102945-n', 1), SenseInfo('07085375-n', 0), SenseInfo('14434866-n', 18), SenseInfo('05037394-n', 7), SenseInfo('07102945-n', 1), SenseInfo('07085375-n', 0) ],
"_sermon_n_1_rel" : [ SenseInfo('07243837-n', 4), SenseInfo('06712325-n', 0) ],
"_enormous_a_1_rel" : [ SenseInfo('01385255-a', 17), SenseInfo('01385255-a', 17) ],
"_care_n_i_rel" : [ SenseInfo('00654885-n', 9), SenseInfo('05615869-n', 4), SenseInfo('07524529-n', 1), SenseInfo('07505047-n', 1), SenseInfo('00829378-n', 1), SenseInfo('00267522-n', 1) ],
"_dream_v_1_rel" : [ SenseInfo('01637633-v', 15), SenseInfo('02118242-v', 11), SenseInfo('01637633-v', 15), SenseInfo('02118242-v', 11) ],
"_challenge_v_1_rel" : [ SenseInfo('00869126-v', 12), SenseInfo('00868591-v', 7), SenseInfo('00808343-v', 1), SenseInfo('00808162-v', 1), SenseInfo('00869126-v', 12), SenseInfo('00868591-v', 7), SenseInfo('00808343-v', 1), SenseInfo('00808162-v', 1), SenseInfo('00869126-v', 12), SenseInfo('00868591-v', 7), SenseInfo('00808343-v', 1), SenseInfo('00808162-v', 1) ],
"_extraction_n_of_rel" : [ SenseInfo('13478525-n', 0), SenseInfo('04923743-n', 0), SenseInfo('00392950-n', 0) ],
"_maneuver_v_1_rel" : [ SenseInfo('01931768-v', 5), SenseInfo('02369390-v', 0), SenseInfo('01109863-v', 0), SenseInfo('01931768-v', 5), SenseInfo('02369390-v', 0), SenseInfo('01109863-v', 0), SenseInfo('01931768-v', 5), SenseInfo('02369390-v', 0), SenseInfo('01109863-v', 0) ],
"_awareness_n_1_rel" : [ SenseInfo('05675905-n', 10), SenseInfo('05677952-n', 2) ],
"_submit_v_to_rel" : [ SenseInfo('00878636-v', 12), SenseInfo('00878136-v', 8), SenseInfo('01118081-v', 6), SenseInfo('02262752-v', 4), SenseInfo('02589013-v', 2), SenseInfo('00878348-v', 2), SenseInfo('00669762-v', 2), SenseInfo('01072641-v', 1), SenseInfo('02310328-v', 0), SenseInfo('00732394-v', 0), SenseInfo('00878636-v', 12), SenseInfo('00878136-v', 8), SenseInfo('01118081-v', 6), SenseInfo('02262752-v', 4), SenseInfo('02589013-v', 2), SenseInfo('00878348-v', 2), SenseInfo('00669762-v', 2), SenseInfo('01072641-v', 1), SenseInfo('02310328-v', 0), SenseInfo('00732394-v', 0) ],
"_unfailing_a_1_rel" : [ SenseInfo('00965176-a', 0), SenseInfo('00925985-a', 0), SenseInfo('00583842-a', 0), SenseInfo('00965176-a', 0), SenseInfo('00925985-a', 0), SenseInfo('00583842-a', 0) ],
"_offer_n_1_rel" : [ SenseInfo('07185076-n', 2), SenseInfo('07164546-n', 2), SenseInfo('00787061-n', 0), SenseInfo('07185076-n', 2), SenseInfo('07164546-n', 2), SenseInfo('00787061-n', 0), SenseInfo('07185076-n', 2), SenseInfo('07164546-n', 2), SenseInfo('00787061-n', 0), SenseInfo('07185076-n', 2), SenseInfo('07164546-n', 2), SenseInfo('00787061-n', 0), SenseInfo('07185076-n', 2), SenseInfo('07164546-n', 2), SenseInfo('00787061-n', 0) ],
"_stout_a_1_rel" : [ SenseInfo('01991586-a', 3), SenseInfo('00988077-a', 2), SenseInfo('02038994-a', 1), SenseInfo('01991586-a', 3), SenseInfo('00988077-a', 2), SenseInfo('02038994-a', 1), SenseInfo('01991586-a', 3), SenseInfo('00988077-a', 2), SenseInfo('02038994-a', 1), SenseInfo('01991586-a', 3), SenseInfo('00988077-a', 2), SenseInfo('02038994-a', 1) ],
"_wonder_v_at_rel" : [ SenseInfo('00729378-v', 58), SenseInfo('00925110-v', 41), SenseInfo('00925490-v', 2) ],
"_rockbound_a_1_rel" : [ SenseInfo('02241834-a', 0) ],
"_goldenrod_n_1_rel" : [ SenseInfo('12015959-n', 0) ],
"_gsm_n_1_rel" : [  ],
"_twinflower_n_1_rel" : [ SenseInfo('12673328-n', 0) ],
"_winch_v_in_rel" : [ SenseInfo('01592306-v', 0) ],
"_tremendous_a_1_rel" : [ SenseInfo('01385255-a', 19), SenseInfo('01676517-a', 10), SenseInfo('01677200-a', 0), SenseInfo('01385255-a', 19), SenseInfo('01676517-a', 10), SenseInfo('01677200-a', 0) ],
"_impervious_a_1_rel" : [ SenseInfo('01773665-a', 1) ],
"_seabird_n_1_rel" : [ SenseInfo('02021795-n', 0) ],
"_sherry_n_1_rel" : [ SenseInfo('07900958-n', 3) ],
"_noteworthy_a_1_rel" : [ SenseInfo('02586957-a', 3), SenseInfo('02163602-a', 0) ],
"_host_v_1_rel" : [ SenseInfo('01194418-v', 0) ],
"_dropoff_n_1_rel" : [  ],
"_clothesline_n_1_rel" : [ SenseInfo('03051152-n', 1) ],
"_target_v_1_rel" : [ SenseInfo('01150559-v', 0) ],
"_scold_v_1_rel" : [ SenseInfo('00824767-v', 3), SenseInfo('00909573-v', 1) ],
"_tech_a_1_rel" : [ SenseInfo('08285246-n', 0) ],
"_handcuff_n_1_rel" : [ SenseInfo('03484576-n', 0) ],
"_uncertainty_n_1_rel" : [ SenseInfo('04756887-n', 6), SenseInfo('05698247-n', 4), SenseInfo('04756887-n', 6), SenseInfo('05698247-n', 4) ],
"_visit_n_to_rel" : [ SenseInfo('01233156-n', 11), SenseInfo('08385280-n', 7), SenseInfo('01232842-n', 4), SenseInfo('01232684-n', 0), SenseInfo('01055360-n', 0) ],
"_dismount_v_1_rel" : [ SenseInfo('01958452-v', 6) ],
"_sergeant_n_1_rel" : [ SenseInfo('10580772-n', 6), SenseInfo('10449521-n', 3), SenseInfo('10581890-n', 0), SenseInfo('10580772-n', 6), SenseInfo('10449521-n', 3), SenseInfo('10581890-n', 0) ],
"_fanny_n_1_rel" : [ SenseInfo('05559256-n', 0), SenseInfo('05514410-n', 0) ],
"_abolish_v_1_rel" : [ SenseInfo('02427334-v', 9) ],
"_adorn_v_1_rel" : [ SenseInfo('01675963-v', 3), SenseInfo('02748927-v', 0), SenseInfo('02386675-v', 0) ],
"_dehydration_n_1_rel" : [ SenseInfo('14536831-n', 0), SenseInfo('14040846-n', 0), SenseInfo('13460568-n', 0) ],
"_macroeconomics_n_1_rel" : [ SenseInfo('06150933-n', 0) ],
"_insoluble_a_1_rel" : [ SenseInfo('02265891-a', 9), SenseInfo('02266600-a', 0), SenseInfo('01230728-a', 0) ],
"_informed_a_1_rel" : [ SenseInfo('01306273-a', 2) ],
"_skeleton_n_1_rel" : [ SenseInfo('13763626-n', 0), SenseInfo('07306481-n', 0), SenseInfo('05585383-n', 0), SenseInfo('04226537-n', 0) ],
"_drip_v_1_rel" : [ SenseInfo('02071142-v', 11), SenseInfo('01611516-v', 0) ],
"_midst_n_of_rel" : [ SenseInfo('08588699-n', 3) ],
"_auxiliary_n_1_rel" : [ SenseInfo('09780249-n', 2) ],
"_hem_v_1_rel" : [ SenseInfo('01329732-v', 0), SenseInfo('01061799-v', 0) ],
"_huge_a_1_rel" : [ SenseInfo('01387319-a', 23) ],
"_burrow_v_1_rel" : [ SenseInfo('02042067-v', 3) ],
"_sand_v_off_rel" : [ SenseInfo('01386433-v', 2) ],
"_taste_v_to_rel" : [ SenseInfo('02194286-v', 10), SenseInfo('02191546-v', 3), SenseInfo('01195299-v', 3), SenseInfo('02194495-v', 0), SenseInfo('02192992-v', 0), SenseInfo('00597061-v', 0) ],
"_liberal_n_1_rel" : [ SenseInfo('10256756-n', 27), SenseInfo('10257084-n', 1) ],
"_libel_v_1_rel" : [ SenseInfo('00847683-v', 0) ],
"_counterfeit_a_1_rel" : [ SenseInfo('01116380-a', 0) ],
"_turkish_a_1_rel" : [ SenseInfo('03023852-a', 1) ],
"_spiritual_n_1_rel" : [ SenseInfo('07035598-n', 2) ],
"_transitive_n_1_rel" : [ SenseInfo('06331281-n', 0) ],
"_headland_n_1_rel" : [ SenseInfo('09399592-n', 2) ],
"_pheromone_n_1_rel" : [ SenseInfo('14846890-n', 0) ],
"_problem_n_of_rel" : [ SenseInfo('14410605-n', 151), SenseInfo('06784003-n', 38), SenseInfo('05687338-n', 17) ],
"_impossibility_n_1_rel" : [ SenseInfo('14483126-n', 0), SenseInfo('05792312-n', 0) ],
"_revoke_v_1_rel" : [ SenseInfo('01074357-v', 0), SenseInfo('00799798-v', 0) ],
"_signal+to+noise_a_1_rel" : [  ],
"_speak_v_to_rel" : [ SenseInfo('00941990-v', 86), SenseInfo('00962447-v', 53), SenseInfo('00963570-v', 23), SenseInfo('00989201-v', 11), SenseInfo('02135607-v', 3), SenseInfo('00941990-v', 86), SenseInfo('00962447-v', 53), SenseInfo('00963570-v', 23), SenseInfo('00989201-v', 11), SenseInfo('02135607-v', 3), SenseInfo('00941990-v', 86), SenseInfo('00962447-v', 53), SenseInfo('00963570-v', 23), SenseInfo('00989201-v', 11), SenseInfo('02135607-v', 3) ],
"_rotten_a_1_rel" : [ SenseInfo('01127782-a', 1), SenseInfo('02275892-a', 0), SenseInfo('01070538-a', 0) ],
"_hip+hop_n_1_rel" : [ SenseInfo('08289282-n', 0), SenseInfo('07064055-n', 0), SenseInfo('08289282-n', 0), SenseInfo('07064055-n', 0) ],
"_above_n_1_rel" : [ SenseInfo('06392660-n', 0) ],
"_regardless+of_p_rel" : [  ],
"_vow_v_to_rel" : [ SenseInfo('00886759-v', 4), SenseInfo('00886978-v', 0), SenseInfo('00886759-v', 4), SenseInfo('00886978-v', 0) ],
"_monitor_v_1_rel" : [ SenseInfo('02163301-v', 9), SenseInfo('02163626-v', 0) ],
"_midwestern_a_1_rel" : [ SenseInfo('00826403-a', 4) ],
"_rounding+off_n_1_rel" : [  ],
"_supplier_n_of_rel" : [ SenseInfo('10677271-n', 2) ],
"_galaxy_n_1_rel" : [ SenseInfo('08270938-n', 2), SenseInfo('12251278-n', 0), SenseInfo('08271042-n', 0) ],
"_confused_a_about_rel" : [ SenseInfo('01766133-a', 5), SenseInfo('00465221-a', 3), SenseInfo('01684133-a', 2), SenseInfo('01669246-a', 2), SenseInfo('00435492-a', 1), SenseInfo('01766133-a', 5), SenseInfo('00465221-a', 3), SenseInfo('01684133-a', 2), SenseInfo('01669246-a', 2), SenseInfo('00435492-a', 1) ],
"_gunpowder_n_1_rel" : [ SenseInfo('15016314-n', 2) ],
"_shade_v_1_rel" : [ SenseInfo('02768702-v', 2), SenseInfo('01695567-v', 1), SenseInfo('01477704-v', 1), SenseInfo('00113605-v', 0), SenseInfo('00113420-v', 0) ],
"_effeminate_a_1_rel" : [ SenseInfo('01476325-a', 0) ],
"_interlock_n_1_rel" : [ SenseInfo('03579791-n', 0), SenseInfo('00140393-n', 0) ],
"_competitor_n_1_rel" : [ SenseInfo('10533013-n', 7) ],
"_well-loved_a_1_rel" : [  ],
"_champion_n_of_rel" : [ SenseInfo('09906704-n', 14), SenseInfo('09906538-n', 1), SenseInfo('10677713-n', 0), SenseInfo('09762509-n', 0) ],
"_marshmallow_n_1_rel" : [ SenseInfo('07608098-n', 0) ],
"_step-by-step_a_1_rel" : [ SenseInfo('01143006-a', 1), SenseInfo('01143006-a', 1) ],
"_standing_n_1_rel" : [ SenseInfo('13948136-n', 3), SenseInfo('06496116-n', 0), SenseInfo('00349080-n', 0) ],
"_snatch_v_1_rel" : [ SenseInfo('01439745-v', 13), SenseInfo('01213146-v', 1), SenseInfo('01471043-v', 0) ],
"_skier_n_1_rel" : [ SenseInfo('10605253-n', 0) ],
"_accumulation_n_of_rel" : [ SenseInfo('13424865-n', 2), SenseInfo('07951464-n', 1), SenseInfo('00372013-n', 1), SenseInfo('13366693-n', 0) ],
"_dedicate_v_to_rel" : [ SenseInfo('00887463-v', 4), SenseInfo('02395996-v', 0), SenseInfo('00887142-v', 0), SenseInfo('00677966-v', 0) ],
"_minimum_a_1_rel" : [ SenseInfo('01496021-a', 23) ],
"_lifecycle_n_1_rel" : [  ],
"_close_v_off_rel" : [ SenseInfo('01345109-v', 32), SenseInfo('01346978-v', 20), SenseInfo('02426395-v', 18), SenseInfo('02425913-v', 13), SenseInfo('02610628-v', 2), SenseInfo('00763831-v', 1), SenseInfo('02754276-v', 0), SenseInfo('02375619-v', 0), SenseInfo('02140781-v', 0), SenseInfo('02104503-v', 0), SenseInfo('02054541-v', 0), SenseInfo('02054382-v', 0), SenseInfo('01607288-v', 0), SenseInfo('01478423-v', 0), SenseInfo('01423285-v', 0), SenseInfo('01291941-v', 0), SenseInfo('00352137-v', 0), SenseInfo('01345109-v', 32), SenseInfo('01346978-v', 20), SenseInfo('02426395-v', 18), SenseInfo('02425913-v', 13), SenseInfo('02610628-v', 2), SenseInfo('00763831-v', 1), SenseInfo('02754276-v', 0), SenseInfo('02375619-v', 0), SenseInfo('02140781-v', 0), SenseInfo('02104503-v', 0), SenseInfo('02054541-v', 0), SenseInfo('02054382-v', 0), SenseInfo('01607288-v', 0), SenseInfo('01478423-v', 0), SenseInfo('01423285-v', 0), SenseInfo('01291941-v', 0), SenseInfo('00352137-v', 0) ],
"_indication_n_of_rel" : [ SenseInfo('06797169-n', 13), SenseInfo('07231048-n', 0), SenseInfo('06797671-n', 0), SenseInfo('06671818-n', 0), SenseInfo('05816790-n', 0), SenseInfo('06797169-n', 13), SenseInfo('07231048-n', 0), SenseInfo('06797671-n', 0), SenseInfo('06671818-n', 0), SenseInfo('05816790-n', 0) ],
"_south+korean_n_1_rel" : [ SenseInfo('09719207-n', 0) ],
"_pull_v_off_rel" : [ SenseInfo('01448100-v', 44), SenseInfo('01505254-v', 8), SenseInfo('02057499-v', 6), SenseInfo('01609287-v', 3), SenseInfo('02582615-v', 2), SenseInfo('01995211-v', 2), SenseInfo('02057337-v', 1), SenseInfo('00071803-v', 1), SenseInfo('02103162-v', 0), SenseInfo('01947247-v', 0), SenseInfo('01858573-v', 0), SenseInfo('01573276-v', 0), SenseInfo('01407059-v', 0), SenseInfo('01384275-v', 0), SenseInfo('01351170-v', 0), SenseInfo('01148710-v', 0), SenseInfo('00571596-v', 0) ],
"_per_p_rel" : [  ],
"_visualize_v_understand_rel" : [ SenseInfo('01635432-v', 4), SenseInfo('02151394-v', 0), SenseInfo('01636008-v', 0), SenseInfo('00581205-v', 0), SenseInfo('01635432-v', 4), SenseInfo('02151394-v', 0), SenseInfo('01636008-v', 0), SenseInfo('00581205-v', 0), SenseInfo('01635432-v', 4), SenseInfo('02151394-v', 0), SenseInfo('01636008-v', 0), SenseInfo('00581205-v', 0), SenseInfo('01635432-v', 4), SenseInfo('02151394-v', 0), SenseInfo('01636008-v', 0), SenseInfo('00581205-v', 0) ],
"_interview_n_1_rel" : [ SenseInfo('07196075-n', 7), SenseInfo('07143624-n', 3) ],
"_gone+by_p_rel" : [  ],
"_disruption_n_of_rel" : [ SenseInfo('00383952-n', 1), SenseInfo('13977366-n', 0), SenseInfo('07367385-n', 0), SenseInfo('00553173-n', 0) ],
"_splendid_a_1_rel" : [ SenseInfo('00219389-a', 7), SenseInfo('02343110-a', 0), SenseInfo('01285376-a', 0), SenseInfo('00219389-a', 7), SenseInfo('02343110-a', 0), SenseInfo('01285376-a', 0), SenseInfo('00219389-a', 7), SenseInfo('02343110-a', 0), SenseInfo('01285376-a', 0) ],
"_kidnap_v_1_rel" : [ SenseInfo('01471043-v', 3) ],
"_bald_a_1_rel" : [ SenseInfo('01705088-a', 1), SenseInfo('00210848-a', 1), SenseInfo('01698610-a', 0) ],
"_manifold_a_1_rel" : [ SenseInfo('02218314-a', 1) ],
"_spaghetti_n_1_rel" : [ SenseInfo('07700003-n', 0), SenseInfo('07699914-n', 0) ],
"_womb_n_1_rel" : [ SenseInfo('05519085-n', 1) ],
"_powder_n_1_rel" : [ SenseInfo('14997012-n', 15), SenseInfo('15016314-n', 6), SenseInfo('03994008-n', 1) ],
"_repetitive_a_1_rel" : [ SenseInfo('00592539-a', 1), SenseInfo('01964367-a', 0) ],
"_tailor_v_1_rel" : [ SenseInfo('00301662-v', 5), SenseInfo('01666717-v', 1), SenseInfo('01666327-v', 0), SenseInfo('00301662-v', 5), SenseInfo('01666717-v', 1), SenseInfo('01666327-v', 0) ],
"_salute_v_1_rel" : [ SenseInfo('01175467-v', 1), SenseInfo('00899597-v', 1), SenseInfo('00857270-v', 1), SenseInfo('02124501-v', 0), SenseInfo('00900214-v', 0), SenseInfo('00899956-v', 0) ],
"_slice_v_1_rel" : [ SenseInfo('01559055-v', 2), SenseInfo('01408958-v', 1), SenseInfo('01254477-v', 1), SenseInfo('01124389-v', 1) ],
"_runable_a_1_rel" : [  ],
"_contraction_n_1_rel" : [ SenseInfo('00369802-n', 1), SenseInfo('07313241-n', 0), SenseInfo('06289472-n', 0), SenseInfo('00365471-n', 0) ],
"_draw_v_aside_rel" : [ SenseInfo('01448100-v', 13), SenseInfo('02293148-v', 10), SenseInfo('01582645-v', 10), SenseInfo('00730758-v', 10), SenseInfo('01995211-v', 9), SenseInfo('01690294-v', 7), SenseInfo('01854132-v', 6), SenseInfo('00987071-v', 6), SenseInfo('00675901-v', 6), SenseInfo('01760300-v', 5), SenseInfo('01199009-v', 5), SenseInfo('02088107-v', 4), SenseInfo('02311387-v', 3), SenseInfo('01078050-v', 3), SenseInfo('01643297-v', 2), SenseInfo('00556593-v', 2), SenseInfo('02097800-v', 1), SenseInfo('01690816-v', 1), SenseInfo('01643464-v', 1), SenseInfo('01243148-v', 1), SenseInfo('02742107-v', 0), SenseInfo('02628832-v', 0), SenseInfo('02483564-v', 0), SenseInfo('02103162-v', 0), SenseInfo('01539063-v', 0), SenseInfo('01505254-v', 0), SenseInfo('01359432-v', 0), SenseInfo('01243298-v', 0), SenseInfo('01212230-v', 0), SenseInfo('01115190-v', 0), SenseInfo('00476965-v', 0), SenseInfo('00430808-v', 0), SenseInfo('00327982-v', 0), SenseInfo('00197590-v', 0), SenseInfo('00143338-v', 0), SenseInfo('00097029-v', 0), SenseInfo('01448100-v', 13), SenseInfo('02293148-v', 10), SenseInfo('01582645-v', 10), SenseInfo('00730758-v', 10), SenseInfo('01995211-v', 9), SenseInfo('01690294-v', 7), SenseInfo('01854132-v', 6), SenseInfo('00987071-v', 6), SenseInfo('00675901-v', 6), SenseInfo('01760300-v', 5), SenseInfo('01199009-v', 5), SenseInfo('02088107-v', 4), SenseInfo('02311387-v', 3), SenseInfo('01078050-v', 3), SenseInfo('01643297-v', 2), SenseInfo('00556593-v', 2), SenseInfo('02097800-v', 1), SenseInfo('01690816-v', 1), SenseInfo('01643464-v', 1), SenseInfo('01243148-v', 1), SenseInfo('02742107-v', 0), SenseInfo('02628832-v', 0), SenseInfo('02483564-v', 0), SenseInfo('02103162-v', 0), SenseInfo('01539063-v', 0), SenseInfo('01505254-v', 0), SenseInfo('01359432-v', 0), SenseInfo('01243298-v', 0), SenseInfo('01212230-v', 0), SenseInfo('01115190-v', 0), SenseInfo('00476965-v', 0), SenseInfo('00430808-v', 0), SenseInfo('00327982-v', 0), SenseInfo('00197590-v', 0), SenseInfo('00143338-v', 0), SenseInfo('00097029-v', 0) ],
"_artist_n_1_rel" : [ SenseInfo('09812338-n', 44) ],
"_skyscraper_n_1_rel" : [ SenseInfo('04233124-n', 1) ],
"_rubric_n_1_rel" : [ SenseInfo('06652614-n', 1), SenseInfo('06744000-n', 0), SenseInfo('06652712-n', 0), SenseInfo('06345993-n', 0), SenseInfo('06344998-n', 0), SenseInfo('05839776-n', 0) ],
"_somato_a_1_rel" : [  ],
"_minority_n_1_rel" : [ SenseInfo('07966570-n', 3), SenseInfo('05122850-n', 2), SenseInfo('15152261-n', 0) ],
"_inaugurate_v_1_rel" : [ SenseInfo('02395782-v', 3), SenseInfo('02425337-v', 0), SenseInfo('00349592-v', 0) ],
"_drool_n_1_rel" : [ SenseInfo('06611147-n', 0), SenseInfo('05416678-n', 0) ],
"_rockscape_n_1_rel" : [  ],
"_figurative_a_1_rel" : [ SenseInfo('01419149-a', 3), SenseInfo('01979604-a', 0), SenseInfo('01419149-a', 3), SenseInfo('01979604-a', 0), SenseInfo('01419149-a', 3), SenseInfo('01979604-a', 0) ],
"_remotely_x_deg_rel" : [ SenseInfo('00440845-r', 0), SenseInfo('00440745-r', 0) ],
"_part+and+parcel_n_1_rel" : [  ],
"_censure_v_1_rel" : [ SenseInfo('00823669-v', 0) ],
"_give_v_in_rel" : [ SenseInfo('02316868-v', 179), SenseInfo('02339171-v', 160), SenseInfo('02199590-v', 96), SenseInfo('02235842-v', 78), SenseInfo('01060494-v', 32), SenseInfo('01733477-v', 29), SenseInfo('01060317-v', 24), SenseInfo('02200686-v', 20), SenseInfo('01629403-v', 18), SenseInfo('00732224-v', 18), SenseInfo('01629000-v', 16), SenseInfo('02296153-v', 14), SenseInfo('01647672-v', 14), SenseInfo('02200498-v', 12), SenseInfo('02562901-v', 10), SenseInfo('02343595-v', 10), SenseInfo('02230772-v', 10), SenseInfo('00887463-v', 8), SenseInfo('02309374-v', 5), SenseInfo('02309165-v', 5), SenseInfo('01060746-v', 5), SenseInfo('02317094-v', 4), SenseInfo('01848465-v', 4), SenseInfo('01178565-v', 4), SenseInfo('02308741-v', 3), SenseInfo('01989053-v', 1), SenseInfo('00673571-v', 1), SenseInfo('02564052-v', 0), SenseInfo('02359553-v', 0), SenseInfo('02358034-v', 0), SenseInfo('01716283-v', 0), SenseInfo('01716112-v', 0), SenseInfo('01449796-v', 0), SenseInfo('01175810-v', 0), SenseInfo('01069638-v', 0), SenseInfo('00944247-v', 0), SenseInfo('00888009-v', 0), SenseInfo('00878876-v', 0), SenseInfo('00771806-v', 0), SenseInfo('00748972-v', 0), SenseInfo('00748616-v', 0), SenseInfo('00341184-v', 0), SenseInfo('00108747-v', 0), SenseInfo('00108604-v', 0), SenseInfo('02316868-v', 179), SenseInfo('02339171-v', 160), SenseInfo('02199590-v', 96), SenseInfo('02235842-v', 78), SenseInfo('01060494-v', 32), SenseInfo('01733477-v', 29), SenseInfo('01060317-v', 24), SenseInfo('02200686-v', 20), SenseInfo('01629403-v', 18), SenseInfo('00732224-v', 18), SenseInfo('01629000-v', 16), SenseInfo('02296153-v', 14), SenseInfo('01647672-v', 14), SenseInfo('02200498-v', 12), SenseInfo('02562901-v', 10), SenseInfo('02343595-v', 10), SenseInfo('02230772-v', 10), SenseInfo('00887463-v', 8), SenseInfo('02309374-v', 5), SenseInfo('02309165-v', 5), SenseInfo('01060746-v', 5), SenseInfo('02317094-v', 4), SenseInfo('01848465-v', 4), SenseInfo('01178565-v', 4), SenseInfo('02308741-v', 3), SenseInfo('01989053-v', 1), SenseInfo('00673571-v', 1), SenseInfo('02564052-v', 0), SenseInfo('02359553-v', 0), SenseInfo('02358034-v', 0), SenseInfo('01716283-v', 0), SenseInfo('01716112-v', 0), SenseInfo('01449796-v', 0), SenseInfo('01175810-v', 0), SenseInfo('01069638-v', 0), SenseInfo('00944247-v', 0), SenseInfo('00888009-v', 0), SenseInfo('00878876-v', 0), SenseInfo('00771806-v', 0), SenseInfo('00748972-v', 0), SenseInfo('00748616-v', 0), SenseInfo('00341184-v', 0), SenseInfo('00108747-v', 0), SenseInfo('00108604-v', 0), SenseInfo('02316868-v', 179), SenseInfo('02339171-v', 160), SenseInfo('02199590-v', 96), SenseInfo('02235842-v', 78), SenseInfo('01060494-v', 32), SenseInfo('01733477-v', 29), SenseInfo('01060317-v', 24), SenseInfo('02200686-v', 20), SenseInfo('01629403-v', 18), SenseInfo('00732224-v', 18), SenseInfo('01629000-v', 16), SenseInfo('02296153-v', 14), SenseInfo('01647672-v', 14), SenseInfo('02200498-v', 12), SenseInfo('02562901-v', 10), SenseInfo('02343595-v', 10), SenseInfo('02230772-v', 10), SenseInfo('00887463-v', 8), SenseInfo('02309374-v', 5), SenseInfo('02309165-v', 5), SenseInfo('01060746-v', 5), SenseInfo('02317094-v', 4), SenseInfo('01848465-v', 4), SenseInfo('01178565-v', 4), SenseInfo('02308741-v', 3), SenseInfo('01989053-v', 1), SenseInfo('00673571-v', 1), SenseInfo('02564052-v', 0), SenseInfo('02359553-v', 0), SenseInfo('02358034-v', 0), SenseInfo('01716283-v', 0), SenseInfo('01716112-v', 0), SenseInfo('01449796-v', 0), SenseInfo('01175810-v', 0), SenseInfo('01069638-v', 0), SenseInfo('00944247-v', 0), SenseInfo('00888009-v', 0), SenseInfo('00878876-v', 0), SenseInfo('00771806-v', 0), SenseInfo('00748972-v', 0), SenseInfo('00748616-v', 0), SenseInfo('00341184-v', 0), SenseInfo('00108747-v', 0), SenseInfo('00108604-v', 0) ],
"_corpus+callosum_n_1_rel" : [ SenseInfo('05491461-n', 0) ],
"_insolence_n_1_rel" : [ SenseInfo('04915866-n', 3), SenseInfo('01224914-n', 0) ],
"_note_v_to_rel" : [ SenseInfo('01020005-v', 41), SenseInfo('02118476-v', 36), SenseInfo('02118933-v', 29), SenseInfo('01020934-v', 3), SenseInfo('01020005-v', 41), SenseInfo('02118476-v', 36), SenseInfo('02118933-v', 29), SenseInfo('01020934-v', 3) ],
"_off-course_p_rel" : [  ],
"_ce_x_rel" : [ SenseInfo('14633957-n', 0), SenseInfo('00001981-r', 0), SenseInfo('14633957-n', 0), SenseInfo('00001981-r', 0), SenseInfo('14633957-n', 0), SenseInfo('00001981-r', 0), SenseInfo('14633957-n', 0), SenseInfo('00001981-r', 0), SenseInfo('14633957-n', 0), SenseInfo('00001981-r', 0), SenseInfo('14633957-n', 0), SenseInfo('00001981-r', 0), SenseInfo('14633957-n', 0), SenseInfo('00001981-r', 0) ],
"_artless_a_1_rel" : [ SenseInfo('01309991-a', 0), SenseInfo('00149861-a', 0), SenseInfo('02228901-a', 0), SenseInfo('01949740-a', 0) ],
"_humanitarian_n_1_rel" : [ SenseInfo('10191613-n', 0), SenseInfo('10191388-n', 0) ],
"_disaster_n_1_rel" : [ SenseInfo('14476290-n', 7), SenseInfo('07314838-n', 7), SenseInfo('00217499-n', 1) ],
"_rip_v_up_rel" : [ SenseInfo('01573276-v', 8), SenseInfo('02098041-v', 2), SenseInfo('01601147-v', 2), SenseInfo('00863277-v', 0) ],
"_weld_n_1_rel" : [ SenseInfo('12385830-n', 0), SenseInfo('11380655-n', 0), SenseInfo('04571958-n', 0) ],
"_set_v_1_rel" : [ SenseInfo('01494310-v', 30), SenseInfo('00699815-v', 29), SenseInfo('00947077-v', 12), SenseInfo('01062395-v', 10), SenseInfo('00298896-v', 9), SenseInfo('01607445-v', 6), SenseInfo('00406243-v', 5), SenseInfo('00298556-v', 5), SenseInfo('01711749-v', 3), SenseInfo('01970646-v', 2), SenseInfo('01706129-v', 2), SenseInfo('01567275-v', 2), SenseInfo('01628899-v', 1), SenseInfo('00442669-v', 1), SenseInfo('01744888-v', 0), SenseInfo('01613239-v', 0), SenseInfo('01530273-v', 0), SenseInfo('01247322-v', 0), SenseInfo('01115006-v', 0), SenseInfo('00673448-v', 0), SenseInfo('00408085-v', 0), SenseInfo('00407848-v', 0), SenseInfo('00296178-v', 0), SenseInfo('00056188-v', 0), SenseInfo('00038849-v', 0), SenseInfo('01494310-v', 30), SenseInfo('00699815-v', 29), SenseInfo('00947077-v', 12), SenseInfo('01062395-v', 10), SenseInfo('00298896-v', 9), SenseInfo('01607445-v', 6), SenseInfo('00406243-v', 5), SenseInfo('00298556-v', 5), SenseInfo('01711749-v', 3), SenseInfo('01970646-v', 2), SenseInfo('01706129-v', 2), SenseInfo('01567275-v', 2), SenseInfo('01628899-v', 1), SenseInfo('00442669-v', 1), SenseInfo('01744888-v', 0), SenseInfo('01613239-v', 0), SenseInfo('01530273-v', 0), SenseInfo('01247322-v', 0), SenseInfo('01115006-v', 0), SenseInfo('00673448-v', 0), SenseInfo('00408085-v', 0), SenseInfo('00407848-v', 0), SenseInfo('00296178-v', 0), SenseInfo('00056188-v', 0), SenseInfo('00038849-v', 0) ],
"_spoon_v_1_rel" : [ SenseInfo('01579622-v', 0), SenseInfo('01425709-v', 0), SenseInfo('01579622-v', 0), SenseInfo('01425709-v', 0) ],
"_blunder_v_1_rel" : [ SenseInfo('02566227-v', 1), SenseInfo('02051547-v', 0), SenseInfo('00981944-v', 0) ],
"_appreciation_n_for_rel" : [ SenseInfo('05806623-n', 7), SenseInfo('05749619-n', 2), SenseInfo('07229111-n', 1), SenseInfo('01218593-n', 1), SenseInfo('00364440-n', 1), SenseInfo('05806623-n', 7), SenseInfo('05749619-n', 2), SenseInfo('07229111-n', 1), SenseInfo('01218593-n', 1), SenseInfo('00364440-n', 1), SenseInfo('05806623-n', 7), SenseInfo('05749619-n', 2), SenseInfo('07229111-n', 1), SenseInfo('01218593-n', 1), SenseInfo('00364440-n', 1) ],
"_cornsilk_n_1_rel" : [ SenseInfo('12145638-n', 0) ],
"_jellyfish_n_1_rel" : [ SenseInfo('01913166-n', 0), SenseInfo('01910747-n', 0) ],
"_shambles_n_1_rel" : [ SenseInfo('00292712-n', 0) ],
"_gunfire_n_1_rel" : [ SenseInfo('00123783-n', 5) ],
"_allurement_n_1_rel" : [ SenseInfo('05695446-n', 0), SenseInfo('04688842-n', 0), SenseInfo('00161044-n', 0) ],
"_reminder_n_1_rel" : [ SenseInfo('06506757-n', 3), SenseInfo('05813626-n', 3), SenseInfo('09771855-n', 0), SenseInfo('06506757-n', 3), SenseInfo('05813626-n', 3), SenseInfo('09771855-n', 0) ],
"_hopeful_a_of-about_rel" : [ SenseInfo('01228530-a', 2), SenseInfo('00176387-a', 1), SenseInfo('01228530-a', 2), SenseInfo('00176387-a', 1), SenseInfo('01228530-a', 2), SenseInfo('00176387-a', 1), SenseInfo('01228530-a', 2), SenseInfo('00176387-a', 1) ],
"_nutritional_a_1_rel" : [ SenseInfo('03002351-a', 1) ],
"_borough_n_1_rel" : [ SenseInfo('08540532-n', 3), SenseInfo('08540016-n', 0) ],
"_bridge_v_1_rel" : [ SenseInfo('02623194-v', 3), SenseInfo('01296324-v', 1), SenseInfo('01915131-v', 0) ],
"_fast_a_1_rel" : [ SenseInfo('00976508-a', 18), SenseInfo('00983573-a', 0), SenseInfo('00981818-a', 0), SenseInfo('02237502-a', 0), SenseInfo('01774091-a', 0), SenseInfo('01549568-a', 0), SenseInfo('01270486-a', 0), SenseInfo('01059711-a', 0), SenseInfo('00959244-a', 0), SenseInfo('00323873-a', 0), SenseInfo('00976508-a', 18), SenseInfo('00983573-a', 0), SenseInfo('00981818-a', 0), SenseInfo('02237502-a', 0), SenseInfo('01774091-a', 0), SenseInfo('01549568-a', 0), SenseInfo('01270486-a', 0), SenseInfo('01059711-a', 0), SenseInfo('00959244-a', 0), SenseInfo('00323873-a', 0), SenseInfo('00976508-a', 18), SenseInfo('00983573-a', 0), SenseInfo('00981818-a', 0), SenseInfo('02237502-a', 0), SenseInfo('01774091-a', 0), SenseInfo('01549568-a', 0), SenseInfo('01270486-a', 0), SenseInfo('01059711-a', 0), SenseInfo('00959244-a', 0), SenseInfo('00323873-a', 0), SenseInfo('00976508-a', 18), SenseInfo('00983573-a', 0), SenseInfo('00981818-a', 0), SenseInfo('02237502-a', 0), SenseInfo('01774091-a', 0), SenseInfo('01549568-a', 0), SenseInfo('01270486-a', 0), SenseInfo('01059711-a', 0), SenseInfo('00959244-a', 0), SenseInfo('00323873-a', 0) ],
"_relic_n_1_rel" : [ SenseInfo('04073547-n', 2), SenseInfo('03610270-n', 0) ],
"_clustering_n_1_rel" : [ SenseInfo('07959943-n', 0), SenseInfo('07959943-n', 0) ],
"_dotterel_a_1_rel" : [ SenseInfo('02024185-n', 0) ],
"_mingle_v_1_rel" : [ SenseInfo('01462005-v', 9), SenseInfo('02597095-v', 2), SenseInfo('02739861-v', 0) ],
"_pristine_a_1_rel" : [ SenseInfo('01907293-a', 0), SenseInfo('00418679-a', 0) ],
"_monster_n_1_rel" : [ SenseInfo('09491966-n', 5), SenseInfo('10128909-n', 1), SenseInfo('10109443-n', 1), SenseInfo('10329945-n', 0), SenseInfo('01460108-n', 0) ],
"_welcome_n_1_rel" : [ SenseInfo('14413265-n', 1), SenseInfo('06631322-n', 0) ],
"_merit_n_of_rel" : [ SenseInfo('05138958-n', 5), SenseInfo('04807050-n', 3) ],
"_stable_v_1_rel" : [ SenseInfo('02459915-v', 1) ],
"_vis-a-vis_p_rel" : [ SenseInfo('00045092-r', 1), SenseInfo('05695806-n', 0), SenseInfo('03693474-n', 0), SenseInfo('00045092-r', 1), SenseInfo('05695806-n', 0), SenseInfo('03693474-n', 0), SenseInfo('00045092-r', 1), SenseInfo('05695806-n', 0), SenseInfo('03693474-n', 0) ],
"_degradation_n_of_rel" : [ SenseInfo('00271263-n', 1), SenseInfo('14440623-n', 0) ],
"_foregoing_a_1_rel" : [ SenseInfo('00126235-a', 4) ],
"_periodicity_n_1_rel" : [ SenseInfo('04767805-n', 1) ],
"_client_n_1_rel" : [ SenseInfo('09985075-n', 9), SenseInfo('09984659-n', 1), SenseInfo('03827107-n', 0) ],
"_northeasterly_a_1_rel" : [ SenseInfo('01601763-a', 0), SenseInfo('01601592-a', 0), SenseInfo('01601763-a', 0), SenseInfo('01601592-a', 0) ],
"_realization_n_of_rel" : [ SenseInfo('05807540-n', 3), SenseInfo('00931847-n', 3), SenseInfo('07039056-n', 0), SenseInfo('01119620-n', 0), SenseInfo('00940043-n', 0), SenseInfo('00061917-n', 0), SenseInfo('05807540-n', 3), SenseInfo('00931847-n', 3), SenseInfo('07039056-n', 0), SenseInfo('01119620-n', 0), SenseInfo('00940043-n', 0), SenseInfo('00061917-n', 0) ],
"_harshness_n_1_rel" : [ SenseInfo('04949066-n', 1), SenseInfo('04988666-n', 0), SenseInfo('04845475-n', 0), SenseInfo('04639732-n', 0) ],
"_retainer_n_1_rel" : [ SenseInfo('13323313-n', 0), SenseInfo('10582154-n', 0), SenseInfo('04082562-n', 0) ],
"_writer_n_of_rel" : [ SenseInfo('10794014-n', 36), SenseInfo('10801291-n', 5) ],
"_ischial_a_1_rel" : [  ],
"_league_n_of_rel" : [ SenseInfo('08231184-n', 9), SenseInfo('08305114-n', 2), SenseInfo('13652066-n', 0), SenseInfo('08231184-n', 9), SenseInfo('08305114-n', 2), SenseInfo('13652066-n', 0) ],
"_alarm_v_x_rel" : [ SenseInfo('01782650-v', 2), SenseInfo('00872414-v', 1) ],
"_subordinate_v_1_rel" : [ SenseInfo('00659535-v', 1), SenseInfo('00579712-v', 0) ],
"_econometric_a_1_rel" : [ SenseInfo('02919733-a', 0) ],
"_cage_v_1_rel" : [ SenseInfo('02496036-v', 0) ],
"_rent_n_1_rel" : [ SenseInfo('13295657-n', 6), SenseInfo('09410928-n', 2), SenseInfo('13296270-n', 0), SenseInfo('00391407-n', 0) ],
"_creditworthy_a_1_rel" : [ SenseInfo('02465350-a', 0) ],
"_listener_n_1_rel" : [ SenseInfo('10165448-n', 9) ],
"_size_n_1_rel" : [ SenseInfo('05098942-n', 70), SenseInfo('05095691-n', 3), SenseInfo('14706372-n', 0), SenseInfo('13937727-n', 0), SenseInfo('05099231-n', 0) ],
"_manned_a_1_rel" : [ SenseInfo('01479805-a', 3) ],
"_pizza_n_1_rel" : [ SenseInfo('07873807-n', 1) ],
"_trill_n_1_rel" : [ SenseInfo('06860177-n', 3), SenseInfo('07133477-n', 0) ],
"_yard_n_2_rel" : [ SenseInfo('13650447-n', 34), SenseInfo('04610879-n', 12), SenseInfo('08684294-n', 1), SenseInfo('13750844-n', 0), SenseInfo('13618076-n', 0), SenseInfo('08684676-n', 0), SenseInfo('04611154-n', 0), SenseInfo('04610676-n', 0), SenseInfo('04610503-n', 0) ],
"_explicit_a_1_rel" : [ SenseInfo('00940437-a', 7), SenseInfo('01418989-a', 0), SenseInfo('00940437-a', 7), SenseInfo('01418989-a', 0) ],
"_rip_v_1_rel" : [ SenseInfo('01573276-v', 8), SenseInfo('02098041-v', 2), SenseInfo('01601147-v', 2), SenseInfo('00863277-v', 0) ],
"_good-looking_a_1_rel" : [ SenseInfo('00218950-a', 1), SenseInfo('00218950-a', 1) ],
"_greedy_n_1_rel" : [ SenseInfo('00029933-a', 1), SenseInfo('00888477-a', 0), SenseInfo('00011160-a', 0) ],
"_curious_n_1_rel" : [ SenseInfo('00968010-a', 14), SenseInfo('00664449-a', 13), SenseInfo('01342572-a', 0) ],
"_geologic_a_1_rel" : [ SenseInfo('02905591-a', 0) ],
"_leavening_n_1_rel" : [ SenseInfo('05869407-n', 1), SenseInfo('14934031-n', 0) ],
"_spectrum_n_1_rel" : [ SenseInfo('11420831-n', 18), SenseInfo('05128219-n', 2) ],
"_drag_v_cause_rel" : [ SenseInfo('01453433-v', 16), SenseInfo('01454810-v', 13), SenseInfo('02677797-v', 1), SenseInfo('02099544-v', 1), SenseInfo('02058756-v', 1), SenseInfo('01199009-v', 1), SenseInfo('02101789-v', 0), SenseInfo('01917845-v', 0), SenseInfo('01244692-v', 0), SenseInfo('00783689-v', 0), SenseInfo('00341757-v', 0), SenseInfo('01453433-v', 16), SenseInfo('01454810-v', 13), SenseInfo('02677797-v', 1), SenseInfo('02099544-v', 1), SenseInfo('02058756-v', 1), SenseInfo('01199009-v', 1), SenseInfo('02101789-v', 0), SenseInfo('01917845-v', 0), SenseInfo('01244692-v', 0), SenseInfo('00783689-v', 0), SenseInfo('00341757-v', 0) ],
"_limy_a_1_rel" : [  ],
"_tuckered_a_1_rel" : [  ],
"_pastry_n_1_rel" : [ SenseInfo('07623136-n', 0), SenseInfo('07622708-n', 0) ],
"_bench_n_1_rel" : [ SenseInfo('02828884-n', 9), SenseInfo('09456207-n', 1), SenseInfo('08166187-n', 1), SenseInfo('04600486-n', 1), SenseInfo('08328700-n', 0), SenseInfo('08209519-n', 0), SenseInfo('02829116-n', 0) ],
"_representation_n_of_rel" : [ SenseInfo('05926676-n', 10), SenseInfo('04076846-n', 10), SenseInfo('01217499-n', 1), SenseInfo('14000403-n', 0), SenseInfo('08337108-n', 0), SenseInfo('07203388-n', 0), SenseInfo('06893885-n', 0), SenseInfo('06739782-n', 0), SenseInfo('05187711-n', 0), SenseInfo('00898518-n', 0) ],
"_cask_n_1_rel" : [ SenseInfo('13766547-n', 0), SenseInfo('02795169-n', 0) ],
"_independently+of_p_rel" : [  ],
"_tendency_n_to_rel" : [ SenseInfo('06196584-n', 11), SenseInfo('07499113-n', 6), SenseInfo('04944048-n', 5), SenseInfo('08681777-n', 0), SenseInfo('06196584-n', 11), SenseInfo('07499113-n', 6), SenseInfo('04944048-n', 5), SenseInfo('08681777-n', 0) ],
"_promising_a_1_rel" : [ SenseInfo('01412286-a', 9), SenseInfo('00176387-a', 2), SenseInfo('01412286-a', 9), SenseInfo('00176387-a', 2), SenseInfo('01412286-a', 9), SenseInfo('00176387-a', 2) ],
"_fringed_a_1_rel" : [ SenseInfo('00258587-a', 3), SenseInfo('00058822-a', 1), SenseInfo('02247166-a', 0), SenseInfo('00258587-a', 3), SenseInfo('00058822-a', 1), SenseInfo('02247166-a', 0) ],
"_grievance_n_1_rel" : [ SenseInfo('07549536-n', 1), SenseInfo('07236466-n', 1), SenseInfo('07210801-n', 1) ],
"_broadcast_n_1_rel" : [ SenseInfo('06254007-n', 3), SenseInfo('06619428-n', 0) ],
"_distant_a_1_rel" : [ SenseInfo('00445548-a', 33), SenseInfo('00450606-a', 2), SenseInfo('01987646-a', 0), SenseInfo('00443075-a', 0), SenseInfo('00442917-a', 0) ],
"_deal_v_out_rel" : [ SenseInfo('01033527-v', 34), SenseInfo('00734054-v', 15), SenseInfo('02370987-v', 14), SenseInfo('02587532-v', 9), SenseInfo('02294436-v', 5), SenseInfo('02244956-v', 4), SenseInfo('02436349-v', 3), SenseInfo('02377764-v', 3), SenseInfo('02246456-v', 2), SenseInfo('02445509-v', 0), SenseInfo('02294179-v', 0), SenseInfo('02246686-v', 0), SenseInfo('02245993-v', 0) ],
"_feminine_a_1_rel" : [ SenseInfo('01484083-a', 4), SenseInfo('01486197-a', 1), SenseInfo('01484987-a', 0), SenseInfo('02320289-a', 0) ],
"_urban_a_1_rel" : [ SenseInfo('02821071-a', 5), SenseInfo('02052333-a', 2) ],
"_natural-sounding_a_1_rel" : [  ],
"_artillery_n_1_rel" : [ SenseInfo('02746365-n', 8), SenseInfo('08389297-n', 3), SenseInfo('07246932-n', 1) ],
"_All-State_a_1_rel" : [  ],
"_zipper_n_1_rel" : [ SenseInfo('04238321-n', 0) ],
"_cut+off_n_1_rel" : [ SenseInfo('13759014-n', 0), SenseInfo('04204953-n', 0), SenseInfo('03153585-n', 0), SenseInfo('13759014-n', 0), SenseInfo('04204953-n', 0), SenseInfo('03153585-n', 0) ],
"_puppy_n_1_rel" : [ SenseInfo('01322604-n', 2), SenseInfo('10493835-n', 0) ],
"_clause_n_1_rel" : [ SenseInfo('06314144-n', 2), SenseInfo('06392935-n', 1) ],
"_per+se_p_rel" : [ SenseInfo('00036762-r', 5) ],
"_retail_n_1_rel" : [ SenseInfo('01114458-n', 1) ],
"_handfast_n_1_rel" : [  ],
"_drive_v_in_rel" : [ SenseInfo('01930874-v', 56), SenseInfo('01930117-v', 24), SenseInfo('02056971-v', 13), SenseInfo('01516534-v', 13), SenseInfo('02505358-v', 6), SenseInfo('01506157-v', 5), SenseInfo('01646300-v', 4), SenseInfo('01512259-v', 2), SenseInfo('01509584-v', 2), SenseInfo('02406916-v', 1), SenseInfo('01026975-v', 1), SenseInfo('02742232-v', 0), SenseInfo('02408281-v', 0), SenseInfo('02057656-v', 0), SenseInfo('01939553-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01407904-v', 0), SenseInfo('01407722-v', 0), SenseInfo('01310964-v', 0), SenseInfo('01181741-v', 0), SenseInfo('01142636-v', 0), SenseInfo('01142490-v', 0) ],
"_better+than+chance_a_1_rel" : [  ],
"_strain_n_1_rel" : [ SenseInfo('11515325-n', 5), SenseInfo('14410089-n', 3), SenseInfo('07028373-n', 3), SenseInfo('14375890-n', 2), SenseInfo('08101410-n', 2), SenseInfo('08111157-n', 1), SenseInfo('14298102-n', 0), SenseInfo('05922450-n', 0), SenseInfo('00788766-n', 0), SenseInfo('00624553-n', 0), SenseInfo('00546389-n', 0) ],
"_comprise_v_1_rel" : [ SenseInfo('02633356-v', 8), SenseInfo('02629535-v', 6), SenseInfo('02620587-v', 1) ],
"_char_v_cause_rel" : [ SenseInfo('02771997-v', 0), SenseInfo('00379440-v', 0) ],
"_conceivable_a_1_rel" : [ SenseInfo('02418249-a', 2), SenseInfo('02418249-a', 2) ],
"_amp_n_1_rel" : [ SenseInfo('13637376-n', 4), SenseInfo('14707710-n', 0) ],
"_con_v_1_rel" : [ SenseInfo('02572119-v', 1), SenseInfo('00604576-v', 0) ],
"_blog_v_1_rel" : [ SenseInfo('00865280-v', 0) ],
"_adolescent_n_1_rel" : [ SenseInfo('09772029-n', 1) ],
"_drum_n_1_rel" : [ SenseInfo('03249569-n', 5), SenseInfo('07383475-n', 1), SenseInfo('13901211-n', 0), SenseInfo('03249956-n', 0), SenseInfo('02890351-n', 0), SenseInfo('02594552-n', 0) ],
"_amateur_a_1_rel" : [ SenseInfo('01869634-a', 3), SenseInfo('01870636-a', 0) ],
"_constrain_v_from_rel" : [ SenseInfo('01301051-v', 0), SenseInfo('00418765-v', 0), SenseInfo('01301051-v', 0), SenseInfo('00418765-v', 0) ],
"_even_a_1_rel" : [ SenseInfo('00913387-a', 4), SenseInfo('00891170-a', 3), SenseInfo('00909545-a', 2), SenseInfo('02372520-a', 0), SenseInfo('02302187-a', 0), SenseInfo('00892243-a', 0), SenseInfo('00913387-a', 4), SenseInfo('00891170-a', 3), SenseInfo('00909545-a', 2), SenseInfo('02372520-a', 0), SenseInfo('02302187-a', 0), SenseInfo('00892243-a', 0), SenseInfo('00913387-a', 4), SenseInfo('00891170-a', 3), SenseInfo('00909545-a', 2), SenseInfo('02372520-a', 0), SenseInfo('02302187-a', 0), SenseInfo('00892243-a', 0), SenseInfo('00913387-a', 4), SenseInfo('00891170-a', 3), SenseInfo('00909545-a', 2), SenseInfo('02372520-a', 0), SenseInfo('02302187-a', 0), SenseInfo('00892243-a', 0) ],
"_fend_v_off_rel" : [ SenseInfo('02588122-v', 0), SenseInfo('01115916-v', 0) ],
"_counter-_a_anti_rel" : [ SenseInfo('01818680-a', 2), SenseInfo('01818680-a', 2) ],
"_croft_n_1_rel" : [ SenseInfo('03134015-n', 0) ],
"_spooky_a_1_rel" : [ SenseInfo('00919155-a', 0) ],
"_like+as+not_a_1_rel" : [  ],
"_tacky_a_1_rel" : [ SenseInfo('02550891-a', 0), SenseInfo('02393791-a', 0), SenseInfo('02550891-a', 0), SenseInfo('02393791-a', 0), SenseInfo('02550891-a', 0), SenseInfo('02393791-a', 0) ],
"_invest_v_1_rel" : [ SenseInfo('02271137-v', 7), SenseInfo('02474239-v', 2), SenseInfo('02386675-v', 0), SenseInfo('02386388-v', 0), SenseInfo('02384275-v', 0) ],
"_cactus_n_1_rel" : [ SenseInfo('11842204-n', 0) ],
"_portage_v_1_rel" : [  ],
"_exposed_a_1_rel" : [ SenseInfo('01886620-a', 5), SenseInfo('00459330-a', 1) ],
"_luminosity_n_1_rel" : [ SenseInfo('05018103-n', 1) ],
"_snarl_v_at_rel" : [ SenseInfo('00916274-v', 6), SenseInfo('00916520-v', 1), SenseInfo('01462928-v', 0), SenseInfo('00402831-v', 0) ],
"_paraglider_n_1_rel" : [  ],
"_triumph_v_1_rel" : [ SenseInfo('01101734-v', 1), SenseInfo('01823370-v', 0), SenseInfo('00883635-v', 0), SenseInfo('00857923-v', 0) ],
"_only_child_n_1_rel" : [  ],
"_sensational_a_for_rel" : [ SenseInfo('02101580-a', 3), SenseInfo('01282921-a', 3), SenseInfo('02796425-a', 0), SenseInfo('02101580-a', 3), SenseInfo('01282921-a', 3), SenseInfo('02796425-a', 0), SenseInfo('02101580-a', 3), SenseInfo('01282921-a', 3), SenseInfo('02796425-a', 0) ],
"_ex_p_rel" : [ SenseInfo('10194231-n', 0), SenseInfo('10020533-n', 0), SenseInfo('06833663-n', 0), SenseInfo('00974159-a', 0), SenseInfo('10194231-n', 0), SenseInfo('10020533-n', 0), SenseInfo('06833663-n', 0), SenseInfo('00974159-a', 0), SenseInfo('10194231-n', 0), SenseInfo('10020533-n', 0), SenseInfo('06833663-n', 0), SenseInfo('00974159-a', 0) ],
"_anterior_n_1_rel" : [ SenseInfo('05306190-n', 1) ],
"_step_v_1_rel" : [ SenseInfo('01928838-v', 23), SenseInfo('02091410-v', 7), SenseInfo('02563616-v', 0), SenseInfo('02516594-v', 0), SenseInfo('02330247-v', 0), SenseInfo('02091885-v', 0), SenseInfo('02091689-v', 0), SenseInfo('01256487-v', 0), SenseInfo('00490722-v', 0), SenseInfo('00124659-v', 0) ],
"_irritation_n_at_rel" : [ SenseInfo('14406573-n', 6), SenseInfo('07518468-n', 1), SenseInfo('14531392-n', 0), SenseInfo('14036356-n', 0), SenseInfo('07495973-n', 0), SenseInfo('01221790-n', 0), SenseInfo('00418394-n', 0) ],
"_skew_n_1_rel" : [ SenseInfo('01235706-a', 0) ],
"_mix+up_n_1_rel" : [ SenseInfo('00072473-n', 0), SenseInfo('00072473-n', 0), SenseInfo('00072473-n', 0) ],
"_cyan_a_1_rel" : [ SenseInfo('00371163-a', 0) ],
"_tangential_a_1_rel" : [ SenseInfo('01976360-a', 1), SenseInfo('02808830-a', 0) ],
"_rascal_n_1_rel" : [ SenseInfo('10536728-n', 1), SenseInfo('10200047-n', 0) ],
"_catharsis_n_1_rel" : [ SenseInfo('00253395-n', 4), SenseInfo('00253577-n', 0) ],
"_sugary_a_1_rel" : [ SenseInfo('02337667-a', 0) ],
"_lawe_v_1_rel" : [  ],
"_attractive_a_1_rel" : [ SenseInfo('00166146-a', 4), SenseInfo('00170847-a', 3), SenseInfo('00169955-a', 0), SenseInfo('00166146-a', 4), SenseInfo('00170847-a', 3), SenseInfo('00169955-a', 0) ],
"_mouth+to+mouth_a_1_rel" : [  ],
"_affinity_n_for_rel" : [ SenseInfo('11426778-n', 1), SenseInfo('13813283-n', 0), SenseInfo('13812296-n', 0), SenseInfo('13811410-n', 0), SenseInfo('11422822-n', 0), SenseInfo('04747798-n', 0), SenseInfo('04688648-n', 0) ],
"_throne_n_1_rel" : [ SenseInfo('04429376-n', 1), SenseInfo('04446521-n', 0), SenseInfo('00605023-n', 0) ],
"_cleanse_v_of_rel" : [ SenseInfo('00035758-v', 1), SenseInfo('00501896-v', 0), SenseInfo('00035758-v', 1), SenseInfo('00501896-v', 0) ],
"_plop_v_1_rel" : [ SenseInfo('01977421-v', 0), SenseInfo('01977266-v', 0), SenseInfo('01500572-v', 0), SenseInfo('01977421-v', 0), SenseInfo('01977266-v', 0), SenseInfo('01500572-v', 0) ],
"_observable_a_1_rel" : [ SenseInfo('01287486-a', 1) ],
"_interjection_n_1_rel" : [ SenseInfo('07125958-n', 0), SenseInfo('01068184-n', 0) ],
"_risk_n_of_rel" : [ SenseInfo('14541852-n', 4), SenseInfo('00802238-n', 2), SenseInfo('05093418-n', 0), SenseInfo('05093293-n', 0), SenseInfo('14541852-n', 4), SenseInfo('00802238-n', 2), SenseInfo('05093418-n', 0), SenseInfo('05093293-n', 0), SenseInfo('14541852-n', 4), SenseInfo('00802238-n', 2), SenseInfo('05093418-n', 0), SenseInfo('05093293-n', 0), SenseInfo('14541852-n', 4), SenseInfo('00802238-n', 2), SenseInfo('05093418-n', 0), SenseInfo('05093293-n', 0), SenseInfo('14541852-n', 4), SenseInfo('00802238-n', 2), SenseInfo('05093418-n', 0), SenseInfo('05093293-n', 0) ],
"_cruise_v_1_rel" : [ SenseInfo('01931566-v', 3), SenseInfo('01844859-v', 2), SenseInfo('02154031-v', 0), SenseInfo('01844653-v', 0), SenseInfo('01931566-v', 3), SenseInfo('01844859-v', 2), SenseInfo('02154031-v', 0), SenseInfo('01844653-v', 0) ],
"_resort_v_to_rel" : [ SenseInfo('02590072-v', 7), SenseInfo('01843497-v', 0) ],
"_humor_n_1_rel" : [ SenseInfo('06776138-n', 8), SenseInfo('04650201-n', 8), SenseInfo('07551052-n', 7), SenseInfo('05211044-n', 1), SenseInfo('05604535-n', 0), SenseInfo('05397468-n', 0), SenseInfo('06776138-n', 8), SenseInfo('04650201-n', 8), SenseInfo('07551052-n', 7), SenseInfo('05211044-n', 1), SenseInfo('05604535-n', 0), SenseInfo('05397468-n', 0), SenseInfo('06776138-n', 8), SenseInfo('04650201-n', 8), SenseInfo('07551052-n', 7), SenseInfo('05211044-n', 1), SenseInfo('05604535-n', 0), SenseInfo('05397468-n', 0), SenseInfo('06776138-n', 8), SenseInfo('04650201-n', 8), SenseInfo('07551052-n', 7), SenseInfo('05211044-n', 1), SenseInfo('05604535-n', 0), SenseInfo('05397468-n', 0) ],
"_mitt_n_1_rel" : [ SenseInfo('05564590-n', 0), SenseInfo('02800213-n', 0) ],
"_involve_v_in_rel" : [ SenseInfo('02677097-v', 56), SenseInfo('02677567-v', 23), SenseInfo('02636132-v', 17), SenseInfo('02627934-v', 12), SenseInfo('02633218-v', 6), SenseInfo('00600724-v', 0), SenseInfo('00401538-v', 0) ],
"_online_a_2_rel" : [ SenseInfo('01650883-a', 0), SenseInfo('01650401-a', 0), SenseInfo('00667936-a', 0), SenseInfo('01650883-a', 0), SenseInfo('01650401-a', 0), SenseInfo('00667936-a', 0), SenseInfo('01650883-a', 0), SenseInfo('01650401-a', 0), SenseInfo('00667936-a', 0) ],
"_rabies_n_1_rel" : [ SenseInfo('14271667-n', 0) ],
"_tutor_n_of_rel" : [ SenseInfo('09931418-n', 1) ],
"_according+to_p_rel" : [  ],
"comp_equal_rel" : [  ],
"_arrowhead_n_1_rel" : [ SenseInfo('02743050-n', 0) ],
"_priest_n_1_rel" : [ SenseInfo('10470779-n', 10), SenseInfo('10471250-n', 5) ],
"_superb_a_1_rel" : [ SenseInfo('02342608-a', 6), SenseInfo('01125154-a', 0), SenseInfo('02342608-a', 6), SenseInfo('01125154-a', 0) ],
"_anti-_a_1_rel" : [ SenseInfo('01817405-a', 7) ],
"_bloat_v_1_rel" : [ SenseInfo('00361797-v', 1), SenseInfo('00361952-v', 0) ],
"_corral_n_1_rel" : [ SenseInfo('03124590-n', 2) ],
"_flaxen_a_1_rel" : [ SenseInfo('00244199-a', 0) ],
"_daytripper_n_1_rel" : [  ],
"_fixed_a_1_rel" : [ SenseInfo('00740217-a', 12), SenseInfo('01564603-a', 6), SenseInfo('01059400-a', 2), SenseInfo('00347707-a', 2) ],
"_undeniable_a_1_rel" : [ SenseInfo('00721505-a', 2), SenseInfo('00721505-a', 2), SenseInfo('00721505-a', 2), SenseInfo('00721505-a', 2) ],
"_carve_v_up_rel" : [ SenseInfo('01256157-v', 9), SenseInfo('01256600-v', 3), SenseInfo('01255967-v', 0) ],
"_symphony_n_of_rel" : [ SenseInfo('07044760-n', 4), SenseInfo('08248856-n', 1) ],
"_alternative_n_to_rel" : [ SenseInfo('05790944-n', 16) ],
"_warm_v_cause_rel" : [ SenseInfo('00373250-v', 2), SenseInfo('00372958-v', 1), SenseInfo('00373250-v', 2), SenseInfo('00372958-v', 1) ],
"_script_v_1_rel" : [ SenseInfo('01756719-v', 0) ],
"_foliar_a_1_rel" : [  ],
"_superfluous_a_1_rel" : [ SenseInfo('02503305-a', 0), SenseInfo('01581305-a', 0), SenseInfo('02503305-a', 0), SenseInfo('01581305-a', 0) ],
"_reproductive_a_1_rel" : [ SenseInfo('01081592-a', 0) ],
"_bog_v_down_rel" : [ SenseInfo('00363916-v', 1), SenseInfo('00363742-v', 0), SenseInfo('00363916-v', 1), SenseInfo('00363742-v', 0) ],
"_by_p_temp_rel" : [ SenseInfo('00417787-r', 2), SenseInfo('00233687-r', 0) ],
"_stand_v_for_rel" : [ SenseInfo('01546111-v', 169), SenseInfo('02611373-v', 53), SenseInfo('02734488-v', 38), SenseInfo('02702120-v', 18), SenseInfo('00668099-v', 9), SenseInfo('00670991-v', 8), SenseInfo('02707125-v', 5), SenseInfo('02703018-v', 3), SenseInfo('02702368-v', 2), SenseInfo('01546768-v', 1), SenseInfo('01115916-v', 1), SenseInfo('01428203-v', 0) ],
"_hemorrhage_v_1_rel" : [ SenseInfo('00074834-v', 0) ],
"_unheeded_a_1_rel" : [ SenseInfo('01608656-a', 1), SenseInfo('01608656-a', 1) ],
"_normalize_v_1_rel" : [ SenseInfo('00468583-v', 0), SenseInfo('00468236-v', 0), SenseInfo('00303056-v', 0), SenseInfo('00468583-v', 0), SenseInfo('00468236-v', 0), SenseInfo('00303056-v', 0) ],
"_salmon_a_1_rel" : [ SenseInfo('00379804-a', 0) ],
"_single_n_1_rel" : [ SenseInfo('00132601-n', 7), SenseInfo('13742573-n', 0), SenseInfo('00132601-n', 7), SenseInfo('13742573-n', 0) ],
"_trickier_a_for_rel" : [  ],
"_natural_a_to-for_rel" : [ SenseInfo('01569965-a', 22), SenseInfo('01570892-a', 15), SenseInfo('01574036-a', 4), SenseInfo('01595050-a', 2), SenseInfo('01577771-a', 0), SenseInfo('02282985-a', 0), SenseInfo('01952643-a', 0), SenseInfo('01406180-a', 0), SenseInfo('01335708-a', 0), SenseInfo('00074594-a', 0), SenseInfo('01569965-a', 22), SenseInfo('01570892-a', 15), SenseInfo('01574036-a', 4), SenseInfo('01595050-a', 2), SenseInfo('01577771-a', 0), SenseInfo('02282985-a', 0), SenseInfo('01952643-a', 0), SenseInfo('01406180-a', 0), SenseInfo('01335708-a', 0), SenseInfo('00074594-a', 0), SenseInfo('01569965-a', 22), SenseInfo('01570892-a', 15), SenseInfo('01574036-a', 4), SenseInfo('01595050-a', 2), SenseInfo('01577771-a', 0), SenseInfo('02282985-a', 0), SenseInfo('01952643-a', 0), SenseInfo('01406180-a', 0), SenseInfo('01335708-a', 0), SenseInfo('00074594-a', 0), SenseInfo('01569965-a', 22), SenseInfo('01570892-a', 15), SenseInfo('01574036-a', 4), SenseInfo('01595050-a', 2), SenseInfo('01577771-a', 0), SenseInfo('02282985-a', 0), SenseInfo('01952643-a', 0), SenseInfo('01406180-a', 0), SenseInfo('01335708-a', 0), SenseInfo('00074594-a', 0), SenseInfo('01569965-a', 22), SenseInfo('01570892-a', 15), SenseInfo('01574036-a', 4), SenseInfo('01595050-a', 2), SenseInfo('01577771-a', 0), SenseInfo('02282985-a', 0), SenseInfo('01952643-a', 0), SenseInfo('01406180-a', 0), SenseInfo('01335708-a', 0), SenseInfo('00074594-a', 0) ],
"_suffice_v_1_rel" : [ SenseInfo('02669789-v', 3), SenseInfo('02669789-v', 3) ],
"_grunt_n_of_rel" : [ SenseInfo('07384614-n', 2), SenseInfo('10149241-n', 0), SenseInfo('02588286-n', 0) ],
"_describe_v_to_rel" : [ SenseInfo('00987071-v', 77), SenseInfo('00965035-v', 52), SenseInfo('01582645-v', 1), SenseInfo('00652346-v', 1) ],
"_desertion_n_1_rel" : [ SenseInfo('00055315-n', 2), SenseInfo('00204439-n', 0) ],
"_sandy_a_1_rel" : [ SenseInfo('00244199-a', 1), SenseInfo('00142040-a', 0), SenseInfo('00244199-a', 1), SenseInfo('00142040-a', 0), SenseInfo('00244199-a', 1), SenseInfo('00142040-a', 0) ],
"_mid-trail_a_1_rel" : [  ],
"_sunburn_n_1_rel" : [ SenseInfo('14290534-n', 0), SenseInfo('14290365-n', 0) ],
"_hassle_n_1_rel" : [ SenseInfo('07372565-n', 0), SenseInfo('01172441-n', 0) ],
"_pope_n_1_rel" : [ SenseInfo('10453533-n', 6), SenseInfo('11242743-n', 0) ],
"_bias_v_1_rel" : [ SenseInfo('01085677-v', 0), SenseInfo('00680346-v', 0) ],
"_misty_a_1_rel" : [ SenseInfo('00461609-a', 1), SenseInfo('02549569-a', 0), SenseInfo('00461609-a', 1), SenseInfo('02549569-a', 0), SenseInfo('00461609-a', 1), SenseInfo('02549569-a', 0) ],
"_streamline_v_1_rel" : [ SenseInfo('01689899-v', 0) ],
"_hesitation_n_1_rel" : [ SenseInfo('05699434-n', 4), SenseInfo('04645943-n', 2), SenseInfo('01063350-n', 1) ],
"_unregenerate_a_1_rel" : [ SenseInfo('02326695-a', 0), SenseInfo('01957454-a', 0), SenseInfo('00635607-a', 0), SenseInfo('02326695-a', 0), SenseInfo('01957454-a', 0), SenseInfo('00635607-a', 0) ],
"_widget_n_1_rel" : [ SenseInfo('03218545-n', 0), SenseInfo('02729965-n', 0) ],
"_hamburger_n_1_rel" : [ SenseInfo('07697100-n', 0), SenseInfo('07664007-n', 0) ],
"_vapor_n_1_rel" : [ SenseInfo('15055633-n', 5), SenseInfo('13572436-n', 1), SenseInfo('15055633-n', 5), SenseInfo('13572436-n', 1) ],
"_carbon_n_1_rel" : [ SenseInfo('14633206-n', 6), SenseInfo('14797813-n', 0), SenseInfo('02961851-n', 0) ],
"_copulate_v_1_rel" : [ SenseInfo('01428853-v', 0) ],
"_unlink_v_1_rel" : [  ],
"_seashore_n_1_rel" : [ SenseInfo('09428293-n', 0) ],
"_divisional_a_1_rel" : [ SenseInfo('03061626-a', 0), SenseInfo('00565115-a', 0), SenseInfo('00517010-a', 0) ],
"_will_n_1_rel" : [ SenseInfo('05652593-n', 11), SenseInfo('05983654-n', 9), SenseInfo('06544142-n', 6) ],
"_thoughtful_a_of_rel" : [ SenseInfo('01873295-a', 2), SenseInfo('02418872-a', 1), SenseInfo('02119971-a', 1), SenseInfo('01194483-a', 0), SenseInfo('00639230-a', 0), SenseInfo('01873295-a', 2), SenseInfo('02418872-a', 1), SenseInfo('02119971-a', 1), SenseInfo('01194483-a', 0), SenseInfo('00639230-a', 0) ],
"_strange_a_to_rel" : [ SenseInfo('00967129-a', 41), SenseInfo('00966753-a', 15), SenseInfo('01034457-a', 0), SenseInfo('00967129-a', 41), SenseInfo('00966753-a', 15), SenseInfo('01034457-a', 0) ],
"_superstitious_a_1_rel" : [ SenseInfo('01927061-a', 1), SenseInfo('01927061-a', 1) ],
"_conflict-of-interest_a_1_rel" : [  ],
"_equity_n_1_rel" : [ SenseInfo('13333696-n', 1), SenseInfo('13333420-n', 0), SenseInfo('04839154-n', 0), SenseInfo('13333696-n', 1), SenseInfo('13333420-n', 0), SenseInfo('04839154-n', 0), SenseInfo('13333696-n', 1), SenseInfo('13333420-n', 0), SenseInfo('04839154-n', 0) ],
"_roundabout_a_1_rel" : [ SenseInfo('00767349-a', 1), SenseInfo('00763013-a', 1) ],
"_impoliteness_n_1_rel" : [ SenseInfo('04914694-n', 0), SenseInfo('04914694-n', 0) ],
"_bite_v_1_rel" : [ SenseInfo('01445932-v', 12), SenseInfo('02120451-v', 2), SenseInfo('01441382-v', 1), SenseInfo('01445407-v', 0), SenseInfo('01445932-v', 12), SenseInfo('02120451-v', 2), SenseInfo('01441382-v', 1), SenseInfo('01445407-v', 0) ],
"_hard_a_for_rel" : [ SenseInfo('00744916-a', 37), SenseInfo('01155354-a', 20), SenseInfo('01150915-a', 15), SenseInfo('02322512-a', 5), SenseInfo('00836544-a', 3), SenseInfo('02286294-a', 0), SenseInfo('01157762-a', 0), SenseInfo('01156505-a', 0), SenseInfo('01299173-a', 0), SenseInfo('01158974-a', 0), SenseInfo('01127302-a', 0), SenseInfo('01069715-a', 0), SenseInfo('00744916-a', 37), SenseInfo('01155354-a', 20), SenseInfo('01150915-a', 15), SenseInfo('02322512-a', 5), SenseInfo('00836544-a', 3), SenseInfo('02286294-a', 0), SenseInfo('01157762-a', 0), SenseInfo('01156505-a', 0), SenseInfo('01299173-a', 0), SenseInfo('01158974-a', 0), SenseInfo('01127302-a', 0), SenseInfo('01069715-a', 0), SenseInfo('00744916-a', 37), SenseInfo('01155354-a', 20), SenseInfo('01150915-a', 15), SenseInfo('02322512-a', 5), SenseInfo('00836544-a', 3), SenseInfo('02286294-a', 0), SenseInfo('01157762-a', 0), SenseInfo('01156505-a', 0), SenseInfo('01299173-a', 0), SenseInfo('01158974-a', 0), SenseInfo('01127302-a', 0), SenseInfo('01069715-a', 0), SenseInfo('00744916-a', 37), SenseInfo('01155354-a', 20), SenseInfo('01150915-a', 15), SenseInfo('02322512-a', 5), SenseInfo('00836544-a', 3), SenseInfo('02286294-a', 0), SenseInfo('01157762-a', 0), SenseInfo('01156505-a', 0), SenseInfo('01299173-a', 0), SenseInfo('01158974-a', 0), SenseInfo('01127302-a', 0), SenseInfo('01069715-a', 0), SenseInfo('00744916-a', 37), SenseInfo('01155354-a', 20), SenseInfo('01150915-a', 15), SenseInfo('02322512-a', 5), SenseInfo('00836544-a', 3), SenseInfo('02286294-a', 0), SenseInfo('01157762-a', 0), SenseInfo('01156505-a', 0), SenseInfo('01299173-a', 0), SenseInfo('01158974-a', 0), SenseInfo('01127302-a', 0), SenseInfo('01069715-a', 0) ],
"_mislead_v_1_rel" : [ SenseInfo('02000288-v', 2), SenseInfo('00834009-v', 2), SenseInfo('02000288-v', 2), SenseInfo('00834009-v', 2), SenseInfo('02000288-v', 2), SenseInfo('00834009-v', 2), SenseInfo('02000288-v', 2), SenseInfo('00834009-v', 2) ],
"_delineate_v_1_rel" : [ SenseInfo('02736778-v', 0), SenseInfo('02611630-v', 0), SenseInfo('01689379-v', 0), SenseInfo('01582645-v', 0), SenseInfo('00989084-v', 0) ],
"_attempt_n_1_rel" : [ SenseInfo('00786195-n', 49), SenseInfo('00773814-n', 2), SenseInfo('00786195-n', 49), SenseInfo('00773814-n', 2) ],
"_aim_v_for_rel" : [ SenseInfo('01151110-v', 8), SenseInfo('00708980-v', 7), SenseInfo('01026975-v', 5), SenseInfo('00713015-v', 3), SenseInfo('01150559-v', 2), SenseInfo('00955472-v', 2), SenseInfo('00705517-v', 2) ],
"_self-respect_n_1_rel" : [ SenseInfo('04886881-n', 2), SenseInfo('04886881-n', 2), SenseInfo('04886881-n', 2), SenseInfo('04886881-n', 2), SenseInfo('04886881-n', 2) ],
"_thrombosis_n_1_rel" : [ SenseInfo('14102075-n', 1) ],
"_self-reliance_n_1_rel" : [ SenseInfo('14001031-n', 1) ],
"_discipline_v_1_rel" : [ SenseInfo('02553697-v', 4), SenseInfo('02553428-v', 0) ],
"_maize_n_1_rel" : [ SenseInfo('12143676-n', 0), SenseInfo('04966543-n', 0) ],
"_yearn_v_for_rel" : [ SenseInfo('01828405-v', 4), SenseInfo('01805684-v', 0), SenseInfo('01777605-v', 0) ],
"_fatigue_v_1_rel" : [ SenseInfo('00076114-v', 0), SenseInfo('00075021-v', 0), SenseInfo('00076114-v', 0), SenseInfo('00075021-v', 0) ],
"_burdock_n_1_rel" : [ SenseInfo('11924445-n', 0) ],
"_shrub_n_1_rel" : [ SenseInfo('13112664-n', 3) ],
"_convergence_n_1_rel" : [ SenseInfo('07414740-n', 0), SenseInfo('05863106-n', 0), SenseInfo('05764365-n', 0), SenseInfo('00146572-n', 0) ],
"_clog_v_1_rel" : [ SenseInfo('01478603-v', 4), SenseInfo('01709931-v', 0), SenseInfo('01301230-v', 0), SenseInfo('00441007-v', 0), SenseInfo('00368367-v', 0), SenseInfo('00182037-v', 0) ],
"_centerpiece_n_1_rel" : [ SenseInfo('05851330-n', 0), SenseInfo('02994419-n', 0), SenseInfo('05851330-n', 0), SenseInfo('02994419-n', 0) ],
"_know_v_of_rel" : [ SenseInfo('00594621-v', 585), SenseInfo('00595935-v', 142), SenseInfo('00595630-v', 123), SenseInfo('00594337-v', 76), SenseInfo('00596644-v', 17), SenseInfo('00592883-v', 10), SenseInfo('00596132-v', 1), SenseInfo('01426397-v', 0), SenseInfo('00608670-v', 0), SenseInfo('00608502-v', 0), SenseInfo('00608372-v', 0), SenseInfo('00594621-v', 585), SenseInfo('00595935-v', 142), SenseInfo('00595630-v', 123), SenseInfo('00594337-v', 76), SenseInfo('00596644-v', 17), SenseInfo('00592883-v', 10), SenseInfo('00596132-v', 1), SenseInfo('01426397-v', 0), SenseInfo('00608670-v', 0), SenseInfo('00608502-v', 0), SenseInfo('00608372-v', 0) ],
"_tong_n_1_rel" : [  ],
"_yakuza_n_1_rel" : [ SenseInfo('10801802-n', 0), SenseInfo('08230906-n', 0) ],
"_saltwater_n_1_rel" : [ SenseInfo('15008847-n', 1) ],
"_lithe_a_1_rel" : [ SenseInfo('01140290-a', 1) ],
"_how-to_a_1_rel" : [  ],
"_quiet_v_down_rel" : [ SenseInfo('02190188-v', 1), SenseInfo('01764800-v', 1), SenseInfo('02190188-v', 1), SenseInfo('01764800-v', 1) ],
"_overhang_n_1_rel" : [ SenseInfo('03864356-n', 1) ],
"_customary_a_for_rel" : [ SenseInfo('00606079-a', 4), SenseInfo('00489491-a', 4), SenseInfo('00606079-a', 4), SenseInfo('00489491-a', 4), SenseInfo('00606079-a', 4), SenseInfo('00489491-a', 4), SenseInfo('00606079-a', 4), SenseInfo('00489491-a', 4) ],
"_history_n_of_rel" : [ SenseInfo('15121406-n', 49), SenseInfo('06514093-n', 23), SenseInfo('06155567-n', 16), SenseInfo('15123996-n', 14), SenseInfo('06156752-n', 5) ],
"_yak_v_1_rel" : [ SenseInfo('00741573-v', 0) ],
"_stationary_a_1_rel" : [ SenseInfo('01565252-a', 0), SenseInfo('01060445-a', 0) ],
"_punishment_n_1_rel" : [ SenseInfo('01160342-n', 12) ],
"_capitalize_v_on_rel" : [ SenseInfo('02279772-v', 3), SenseInfo('02330742-v', 0), SenseInfo('01692266-v', 0), SenseInfo('00731159-v', 0), SenseInfo('00731000-v', 0), SenseInfo('00162167-v', 0), SenseInfo('02279772-v', 3), SenseInfo('02330742-v', 0), SenseInfo('01692266-v', 0), SenseInfo('00731159-v', 0), SenseInfo('00731000-v', 0), SenseInfo('00162167-v', 0) ],
"_dilemma_n_1_rel" : [ SenseInfo('05686086-n', 8) ],
"_dehumanize_v_1_rel" : [ SenseInfo('01801297-v', 0), SenseInfo('00479817-v', 0) ],
"_prevail_v_1_rel" : [ SenseInfo('02644234-v', 6), SenseInfo('02648502-v', 5), SenseInfo('02647497-v', 5), SenseInfo('01101734-v', 2), SenseInfo('00777793-v', 0) ],
"_vacuum_n_1_rel" : [ SenseInfo('14456054-n', 12), SenseInfo('13910116-n', 0), SenseInfo('08653474-n', 0), SenseInfo('04517823-n', 0) ],
"_poke_v_out_rel" : [ SenseInfo('01229976-v', 7), SenseInfo('02169119-v', 5), SenseInfo('01424220-v', 0), SenseInfo('01414626-v', 0), SenseInfo('01230241-v', 0) ],
"_handmade_a_1_rel" : [ SenseInfo('00673456-a', 2) ],
"_bank_v_1_rel" : [ SenseInfo('02039413-v', 2), SenseInfo('01587705-v', 1), SenseInfo('02343374-v', 0), SenseInfo('02343252-v', 0), SenseInfo('02343056-v', 0), SenseInfo('02310855-v', 0), SenseInfo('01234793-v', 0), SenseInfo('00688377-v', 0) ],
"_throw_v_1_rel" : [ SenseInfo('01508368-v', 53), SenseInfo('02097204-v', 9), SenseInfo('01513430-v', 7), SenseInfo('01499265-v', 7), SenseInfo('01060317-v', 6), SenseInfo('01510173-v', 5), SenseInfo('01632897-v', 4), SenseInfo('02097341-v', 2), SenseInfo('01791232-v', 2), SenseInfo('01067664-v', 2), SenseInfo('01733477-v', 1), SenseInfo('01663443-v', 0), SenseInfo('01527754-v', 0), SenseInfo('01437011-v', 0), SenseInfo('00621734-v', 0), SenseInfo('01508368-v', 53), SenseInfo('02097204-v', 9), SenseInfo('01513430-v', 7), SenseInfo('01499265-v', 7), SenseInfo('01060317-v', 6), SenseInfo('01510173-v', 5), SenseInfo('01632897-v', 4), SenseInfo('02097341-v', 2), SenseInfo('01791232-v', 2), SenseInfo('01067664-v', 2), SenseInfo('01733477-v', 1), SenseInfo('01663443-v', 0), SenseInfo('01527754-v', 0), SenseInfo('01437011-v', 0), SenseInfo('00621734-v', 0), SenseInfo('01508368-v', 53), SenseInfo('02097204-v', 9), SenseInfo('01513430-v', 7), SenseInfo('01499265-v', 7), SenseInfo('01060317-v', 6), SenseInfo('01510173-v', 5), SenseInfo('01632897-v', 4), SenseInfo('02097341-v', 2), SenseInfo('01791232-v', 2), SenseInfo('01067664-v', 2), SenseInfo('01733477-v', 1), SenseInfo('01663443-v', 0), SenseInfo('01527754-v', 0), SenseInfo('01437011-v', 0), SenseInfo('00621734-v', 0) ],
"_take_v_in_rel" : [ SenseInfo('02599636-v', 92), SenseInfo('02267989-v', 74), SenseInfo('01999798-v', 73), SenseInfo('01214265-v', 50), SenseInfo('00524682-v', 38), SenseInfo('00624476-v', 36), SenseInfo('02077656-v', 32), SenseInfo('02205272-v', 28), SenseInfo('01842690-v', 26), SenseInfo('00674607-v', 26), SenseInfo('02236124-v', 25), SenseInfo('02394183-v', 22), SenseInfo('00734054-v', 22), SenseInfo('02627934-v', 21), SenseInfo('02109045-v', 21), SenseInfo('01002740-v', 16), SenseInfo('00173338-v', 16), SenseInfo('01156834-v', 15), SenseInfo('00669762-v', 15), SenseInfo('02209936-v', 14), SenseInfo('02206619-v', 13), SenseInfo('01982395-v', 10), SenseInfo('02236624-v', 8), SenseInfo('00523095-v', 7), SenseInfo('00599992-v', 6), SenseInfo('00756076-v', 5), SenseInfo('02075857-v', 4), SenseInfo('01151110-v', 4), SenseInfo('00557404-v', 4), SenseInfo('02717102-v', 2), SenseInfo('02208537-v', 2), SenseInfo('02209745-v', 1), SenseInfo('02208118-v', 1), SenseInfo('02201138-v', 1), SenseInfo('01427127-v', 1), SenseInfo('00758333-v', 1), SenseInfo('02741546-v', 0), SenseInfo('02701210-v', 0), SenseInfo('02590253-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01100830-v', 0), SenseInfo('00087736-v', 0) ],
"_venezuelan_n_1_rel" : [ SenseInfo('09747062-n', 0) ],
"_dim_v_cause_rel" : [ SenseInfo('02162310-v', 0), SenseInfo('00313585-v', 0), SenseInfo('00313464-v', 0), SenseInfo('00312278-v', 0), SenseInfo('00311113-v', 0) ],
"_baptize_v_1_rel" : [ SenseInfo('01028079-v', 8) ],
"_seahorse_n_1_rel" : [ SenseInfo('02081571-n', 1), SenseInfo('01456756-n', 0), SenseInfo('02081571-n', 1), SenseInfo('01456756-n', 0) ],
"_leaflet_v_1_rel" : [  ],
"_howl_v_at_rel" : [ SenseInfo('01046932-v', 3), SenseInfo('01047381-v', 0), SenseInfo('01046059-v', 0), SenseInfo('00029836-v', 0) ],
"_uneven_a_1_rel" : [ SenseInfo('00911327-a', 4), SenseInfo('00892773-a', 1), SenseInfo('00913454-a', 0), SenseInfo('02305651-a', 0), SenseInfo('00578662-a', 0), SenseInfo('00911327-a', 4), SenseInfo('00892773-a', 1), SenseInfo('00913454-a', 0), SenseInfo('02305651-a', 0), SenseInfo('00578662-a', 0) ],
"_work_n_1_rel" : [ SenseInfo('00575741-n', 90), SenseInfo('04599396-n', 76), SenseInfo('00584367-n', 27), SenseInfo('05755883-n', 11), SenseInfo('11453420-n', 5), SenseInfo('04602044-n', 3), SenseInfo('03841417-n', 0), SenseInfo('00575741-n', 90), SenseInfo('04599396-n', 76), SenseInfo('00584367-n', 27), SenseInfo('05755883-n', 11), SenseInfo('11453420-n', 5), SenseInfo('04602044-n', 3), SenseInfo('03841417-n', 0) ],
"_essay_v_1_rel" : [ SenseInfo('02530167-v', 1), SenseInfo('02531625-v', 0), SenseInfo('02530167-v', 1), SenseInfo('02531625-v', 0) ],
"_firewood_n_1_rel" : [ SenseInfo('15100644-n', 1) ],
"_shelve_v_1_rel" : [ SenseInfo('02642814-v', 1), SenseInfo('01497750-v', 0) ],
"_milkmaid_n_1_rel" : [ SenseInfo('09988216-n', 0) ],
"_glue_n_1_rel" : [ SenseInfo('14702875-n', 1) ],
"_revelry_n_1_rel" : [ SenseInfo('00510189-n', 1) ],
"_counter+proposal_n_1_rel" : [ SenseInfo('07162424-n', 1), SenseInfo('07162424-n', 1), SenseInfo('07162424-n', 1), SenseInfo('07162424-n', 1), SenseInfo('07162424-n', 1), SenseInfo('07162424-n', 1) ],
"_rotate_v_cause_rel" : [ SenseInfo('02045043-v', 8), SenseInfo('02393894-v', 1), SenseInfo('01096305-v', 1), SenseInfo('02045790-v', 0), SenseInfo('02045415-v', 0), SenseInfo('00245913-v', 0) ],
"_bask_v_1_rel" : [ SenseInfo('01820302-v', 3), SenseInfo('01548181-v', 2) ],
"_stiffness_n_1_rel" : [ SenseInfo('05023591-n', 1), SenseInfo('05004895-n', 1), SenseInfo('04862888-n', 0), SenseInfo('04815624-n', 0), SenseInfo('04639732-n', 0) ],
"_varied_a_1_rel" : [ SenseInfo('02506555-a', 11), SenseInfo('00783469-a', 0), SenseInfo('00355083-a', 0) ],
"_insectivorous_a_1_rel" : [ SenseInfo('00315383-a', 0) ],
"_apprehension_n_1_rel" : [ SenseInfo('07521674-n', 5), SenseInfo('05805475-n', 3), SenseInfo('05951566-n', 0), SenseInfo('00088725-n', 0) ],
"_finish_v_up_rel" : [ SenseInfo('00484166-v', 44), SenseInfo('00352558-v', 12), SenseInfo('02609764-v', 8), SenseInfo('01265989-v', 3), SenseInfo('01196802-v', 2), SenseInfo('00351963-v', 0), SenseInfo('00484166-v', 44), SenseInfo('00352558-v', 12), SenseInfo('02609764-v', 8), SenseInfo('01265989-v', 3), SenseInfo('01196802-v', 2), SenseInfo('00351963-v', 0) ],
"_to_p_rel" : [  ],
"_epitome_n_1_rel" : [ SenseInfo('05937524-n', 1), SenseInfo('06468818-n', 0) ],
"_road+north_n_1_rel" : [  ],
"_outing_n_1_rel" : [ SenseInfo('00311809-n', 1), SenseInfo('15138691-n', 0) ],
"_a+whole+lot_x_deg_rel" : [  ],
"_talus_n_1_rel" : [ SenseInfo('09454153-n', 0), SenseInfo('05271383-n', 0) ],
"_stop_v_off_rel" : [ SenseInfo('01860795-v', 57), SenseInfo('02680814-v', 56), SenseInfo('02559752-v', 25), SenseInfo('01862918-v', 7), SenseInfo('01859221-v', 7), SenseInfo('00362348-v', 4), SenseInfo('01131473-v', 3), SenseInfo('01440378-v', 2), SenseInfo('02609764-v', 1), SenseInfo('01478002-v', 0), SenseInfo('00362610-v', 0) ],
"_sake_n_of_rel" : [ SenseInfo('05143077-n', 10), SenseInfo('07891433-n', 0), SenseInfo('05983347-n', 0) ],
"_overland_p_rel" : [ SenseInfo('00125170-a', 0) ],
"_indian_n_1_rel" : [ SenseInfo('09645091-n', 10), SenseInfo('09673495-n', 0), SenseInfo('06906439-n', 0) ],
"_blast_v_open_rel" : [ SenseInfo('02182479-v', 3), SenseInfo('01401772-v', 2), SenseInfo('01135922-v', 1), SenseInfo('02101216-v', 0), SenseInfo('01759021-v', 0), SenseInfo('01758276-v', 0), SenseInfo('01134781-v', 0), SenseInfo('00823827-v', 0), SenseInfo('00336158-v', 0), SenseInfo('00241924-v', 0) ],
"_masseur_n_1_rel" : [ SenseInfo('10298202-n', 3) ],
"_stick_v_1_rel" : [ SenseInfo('01528069-v', 5), SenseInfo('01857392-v', 2), SenseInfo('01356750-v', 2), SenseInfo('02754032-v', 0), SenseInfo('02647798-v', 0), SenseInfo('02638845-v', 0), SenseInfo('02638630-v', 0), SenseInfo('01667969-v', 0), SenseInfo('01614581-v', 0), SenseInfo('01614426-v', 0), SenseInfo('01614235-v', 0), SenseInfo('01441993-v', 0), SenseInfo('01441793-v', 0), SenseInfo('01220885-v', 0), SenseInfo('00748084-v', 0), SenseInfo('00622384-v', 0), SenseInfo('01528069-v', 5), SenseInfo('01857392-v', 2), SenseInfo('01356750-v', 2), SenseInfo('02754032-v', 0), SenseInfo('02647798-v', 0), SenseInfo('02638845-v', 0), SenseInfo('02638630-v', 0), SenseInfo('01667969-v', 0), SenseInfo('01614581-v', 0), SenseInfo('01614426-v', 0), SenseInfo('01614235-v', 0), SenseInfo('01441993-v', 0), SenseInfo('01441793-v', 0), SenseInfo('01220885-v', 0), SenseInfo('00748084-v', 0), SenseInfo('00622384-v', 0) ],
"_versus_p_rel" : [  ],
"_relinquishment_n_1_rel" : [ SenseInfo('07254836-n', 0), SenseInfo('00212808-n', 0) ],
"_hoop_n_1_rel" : [ SenseInfo('03534429-n', 1), SenseInfo('03533972-n', 1), SenseInfo('04582771-n', 0), SenseInfo('02802215-n', 0) ],
"_scale_v_down_rel" : [ SenseInfo('02728388-v', 1), SenseInfo('01744082-v', 1), SenseInfo('02207036-v', 0), SenseInfo('01999082-v', 0), SenseInfo('01922466-v', 0), SenseInfo('01264148-v', 0), SenseInfo('00490428-v', 0), SenseInfo('00319406-v', 0) ],
"_a+little_a_1_rel" : [  ],
"_gather_v_1_rel" : [ SenseInfo('01380638-v', 23), SenseInfo('02428924-v', 7), SenseInfo('00158804-v', 3), SenseInfo('00945125-v', 2), SenseInfo('01330822-v', 1), SenseInfo('02598143-v', 0), SenseInfo('01349893-v', 0), SenseInfo('01316619-v', 0), SenseInfo('00157462-v', 0) ],
"_infinitive_n_1_rel" : [ SenseInfo('06318904-n', 1) ],
"_back+and+forth_a_1_rel" : [  ],
"_raise_n_1_rel" : [ SenseInfo('05110185-n', 3), SenseInfo('09206985-n', 0), SenseInfo('00803208-n', 0), SenseInfo('00116376-n', 0) ],
"_pay_v_off_rel" : [ SenseInfo('02251743-v', 138), SenseInfo('01060494-v', 26), SenseInfo('02252931-v', 12), SenseInfo('02291708-v', 6), SenseInfo('02253456-v', 6), SenseInfo('00732224-v', 4), SenseInfo('02732292-v', 3), SenseInfo('02488056-v', 1), SenseInfo('00737884-v', 1), SenseInfo('02344243-v', 0), SenseInfo('02253154-v', 0), SenseInfo('02251743-v', 138), SenseInfo('01060494-v', 26), SenseInfo('02252931-v', 12), SenseInfo('02291708-v', 6), SenseInfo('02253456-v', 6), SenseInfo('00732224-v', 4), SenseInfo('02732292-v', 3), SenseInfo('02488056-v', 1), SenseInfo('00737884-v', 1), SenseInfo('02344243-v', 0), SenseInfo('02253154-v', 0) ],
"_neglect_n_of_rel" : [ SenseInfo('05706629-n', 2), SenseInfo('14423428-n', 1), SenseInfo('00418615-n', 1), SenseInfo('04665813-n', 0), SenseInfo('00739270-n', 0) ],
"_inquire_v_1_rel" : [ SenseInfo('00784342-v', 13), SenseInfo('00729378-v', 4), SenseInfo('00785962-v', 0), SenseInfo('00784342-v', 13), SenseInfo('00729378-v', 4), SenseInfo('00785962-v', 0), SenseInfo('00784342-v', 13), SenseInfo('00729378-v', 4), SenseInfo('00785962-v', 0) ],
"_melange_n_1_rel" : [ SenseInfo('08399977-n', 0), SenseInfo('08399977-n', 0) ],
"_stomach_n_1_rel" : [ SenseInfo('05395690-n', 23), SenseInfo('05556943-n', 5), SenseInfo('07499276-n', 0), SenseInfo('07485916-n', 0) ],
"_squeeze_v_by_rel" : [ SenseInfo('01593937-v', 9), SenseInfo('01447868-v', 6), SenseInfo('01527271-v', 4), SenseInfo('02504562-v', 0), SenseInfo('02241107-v', 0), SenseInfo('02094569-v', 0), SenseInfo('01456771-v', 0), SenseInfo('01424456-v', 0), SenseInfo('01387786-v', 0) ],
"_descent_n_1_rel" : [ SenseInfo('07363346-n', 2), SenseInfo('04923743-n', 2), SenseInfo('00326440-n', 1), SenseInfo('13813042-n', 0), SenseInfo('09265620-n', 0), SenseInfo('08101937-n', 0) ],
"_permit_n_1_rel" : [ SenseInfo('06549661-n', 6), SenseInfo('01139194-n', 1), SenseInfo('02579928-n', 0) ],
"_sicilian_n_1_rel" : [ SenseInfo('09717566-n', 2) ],
"_restrain_v_from_rel" : [ SenseInfo('02422663-v', 11), SenseInfo('00233335-v', 3), SenseInfo('01301410-v', 1), SenseInfo('01301051-v', 1), SenseInfo('01819554-v', 0), SenseInfo('02422663-v', 11), SenseInfo('00233335-v', 3), SenseInfo('01301410-v', 1), SenseInfo('01301051-v', 1), SenseInfo('01819554-v', 0) ],
"_mould_n_1_rel" : [ SenseInfo('14953564-n', 0), SenseInfo('13913566-n', 0), SenseInfo('13516176-n', 0), SenseInfo('13077033-n', 0), SenseInfo('07938594-n', 0), SenseInfo('04732709-n', 0), SenseInfo('03779621-n', 0), SenseInfo('03779370-n', 0) ],
"_balloonist_n_1_rel" : [ SenseInfo('09835348-n', 0) ],
"_flank_n_of_rel" : [ SenseInfo('08482113-n', 3), SenseInfo('13897377-n', 0), SenseInfo('07657757-n', 0), SenseInfo('02464223-n', 0) ],
"_skilled_a_1_rel" : [ SenseInfo('02225510-a', 11) ],
"_pack_v_in_rel" : [ SenseInfo('01482449-v', 11), SenseInfo('02086963-v', 2), SenseInfo('01483779-v', 2), SenseInfo('01451176-v', 2), SenseInfo('02396536-v', 1), SenseInfo('02717102-v', 0), SenseInfo('02064131-v', 0), SenseInfo('01926031-v', 0), SenseInfo('01574571-v', 0), SenseInfo('01484884-v', 0), SenseInfo('01484027-v', 0), SenseInfo('01483131-v', 0), SenseInfo('00108909-v', 0) ],
"_sixfold_a_1_rel" : [ SenseInfo('02219770-a', 0), SenseInfo('02219770-a', 0) ],
"_pathway_n_1_rel" : [ SenseInfo('05475878-n', 2), SenseInfo('03899533-n', 1) ],
"_equality_n_1_rel" : [ SenseInfo('04747899-n', 2), SenseInfo('13946760-n', 1) ],
"_argot_n_1_rel" : [ SenseInfo('07157273-n', 1) ],
"_micromanage_v_1_rel" : [  ],
"_leash_n_1_rel" : [ SenseInfo('03652932-n', 2), SenseInfo('13744044-n', 0), SenseInfo('01145688-n', 0) ],
"_complete_v_2_rel" : [ SenseInfo('00484166-v', 52), SenseInfo('00455750-v', 5), SenseInfo('02563724-v', 3), SenseInfo('01117484-v', 1), SenseInfo('01020731-v', 1) ],
"_ng_n_1_rel" : [ SenseInfo('13723189-n', 0) ],
"_exquisiteness_n_1_rel" : [ SenseInfo('04684654-n', 0) ],
"_insignificant_a_1_rel" : [ SenseInfo('01288298-a', 2), SenseInfo('01498298-a', 1), SenseInfo('01473353-a', 1), SenseInfo('02164402-a', 0), SenseInfo('01288298-a', 2), SenseInfo('01498298-a', 1), SenseInfo('01473353-a', 1), SenseInfo('02164402-a', 0) ],
"_congelifract_n_1_rel" : [  ],
"_geek_n_1_rel" : [ SenseInfo('10123615-n', 0), SenseInfo('10042845-n', 0) ],
"_wide_x_deg_rel" : [ SenseInfo('02560548-a', 45), SenseInfo('00526062-a', 12), SenseInfo('00495743-r', 4), SenseInfo('01654900-a', 4), SenseInfo('00496010-r', 1), SenseInfo('01384212-a', 1), SenseInfo('02563068-a', 0), SenseInfo('00495858-r', 0), SenseInfo('00495524-r', 0), SenseInfo('00106277-a', 0), SenseInfo('00024241-a', 0) ],
"_lover_n_1_rel" : [ SenseInfo('09622302-n', 7), SenseInfo('10077593-n', 2), SenseInfo('09622745-n', 0) ],
"_hiss_n_1_rel" : [ SenseInfo('07384898-n', 0), SenseInfo('07123870-n', 0) ],
"_prizewinner_n_1_rel" : [  ],
"_abandonment_n_1_rel" : [ SenseInfo('00204439-n', 3), SenseInfo('00055315-n', 1), SenseInfo('00091013-n', 0) ],
"_diet_v_1_rel" : [ SenseInfo('01190012-v', 0), SenseInfo('01189224-v', 0) ],
"_touch_v_off_rel" : [ SenseInfo('01206218-v', 33), SenseInfo('02127358-v', 5), SenseInfo('01770802-v', 4), SenseInfo('02676054-v', 3), SenseInfo('01205696-v', 3), SenseInfo('00137313-v', 3), SenseInfo('02599325-v', 2), SenseInfo('01206849-v', 2), SenseInfo('02685665-v', 1), SenseInfo('02672187-v', 1), SenseInfo('01207527-v', 1), SenseInfo('01026728-v', 1), SenseInfo('00590642-v', 1), SenseInfo('01172701-v', 0), SenseInfo('00286928-v', 0) ],
"_swarthy_a_1_rel" : [ SenseInfo('00245458-a', 1), SenseInfo('00245458-a', 1), SenseInfo('00245458-a', 1) ],
"_partly_a_1_rel" : [  ],
"_elastic_n_1_rel" : [ SenseInfo('04116098-n', 0), SenseInfo('03267696-n', 0) ],
"_reactor_n_1_rel" : [ SenseInfo('04057846-n', 0), SenseInfo('03834040-n', 0) ],
"_fruit_v_1_rel" : [ SenseInfo('01652895-v', 0), SenseInfo('01652731-v', 0) ],
"_manouver_n_1_rel" : [  ],
"_kick_v_out_rel" : [ SenseInfo('01371756-v', 11), SenseInfo('01936233-v', 9), SenseInfo('01370561-v', 7), SenseInfo('02048511-v', 0), SenseInfo('01371454-v', 0), SenseInfo('01196524-v', 0), SenseInfo('01112979-v', 0), SenseInfo('00907147-v', 0) ],
"_bowl_v_2_rel" : [ SenseInfo('01887324-v', 0), SenseInfo('01616738-v', 0), SenseInfo('01146507-v', 0) ],
"_huh_a_1_rel" : [  ],
"_wound_v_1_rel" : [ SenseInfo('00069879-v', 5), SenseInfo('01793177-v', 0) ],
"_monarch_n_1_rel" : [ SenseInfo('10628644-n', 2), SenseInfo('02279972-n', 0) ],
"_stretch_v_over_rel" : [ SenseInfo('02607830-v', 16), SenseInfo('00027268-v', 11), SenseInfo('02054989-v', 4), SenseInfo('00240810-v', 4), SenseInfo('00318816-v', 3), SenseInfo('01985271-v', 1), SenseInfo('01449591-v', 1), SenseInfo('00541746-v', 1), SenseInfo('00487748-v', 0), SenseInfo('00154141-v', 0), SenseInfo('00101434-v', 0) ],
"_haul_n_1_rel" : [ SenseInfo('00115036-n', 1), SenseInfo('13755822-n', 0) ],
"_plucky_a_1_rel" : [ SenseInfo('00266634-a', 0), SenseInfo('02279900-a', 0), SenseInfo('00266634-a', 0), SenseInfo('02279900-a', 0), SenseInfo('00266634-a', 0), SenseInfo('02279900-a', 0) ],
"_advertising_n_1_rel" : [ SenseInfo('07248801-n', 7), SenseInfo('01101329-n', 6) ],
"_cdrom_n_1_rel" : [  ],
"_steam_v_1_rel" : [ SenseInfo('01944976-v', 2), SenseInfo('02768579-v', 1), SenseInfo('01970272-v', 0), SenseInfo('01787319-v', 0), SenseInfo('01245325-v', 0), SenseInfo('00327145-v', 0), SenseInfo('01944976-v', 2), SenseInfo('02768579-v', 1), SenseInfo('01970272-v', 0), SenseInfo('01787319-v', 0), SenseInfo('01245325-v', 0), SenseInfo('00327145-v', 0) ],
"_tie_n_1_rel" : [ SenseInfo('03815615-n', 5), SenseInfo('13930385-n', 4), SenseInfo('13947174-n', 3), SenseInfo('04433377-n', 1), SenseInfo('03673971-n', 1), SenseInfo('07353716-n', 0), SenseInfo('06866124-n', 0), SenseInfo('04433585-n', 0), SenseInfo('04433185-n', 0) ],
"_sole_a_1_rel" : [ SenseInfo('02152985-a', 2), SenseInfo('02214736-a', 0), SenseInfo('02152985-a', 2), SenseInfo('02214736-a', 0) ],
"_adhere_v_to_rel" : [ SenseInfo('02718178-v', 5), SenseInfo('00486557-v', 3), SenseInfo('01220885-v', 1), SenseInfo('02638845-v', 0), SenseInfo('02638630-v', 0), SenseInfo('01356750-v', 0) ],
"_frenchman_n_1_rel" : [ SenseInfo('09708405-n', 5) ],
"_alarm_n_1_rel" : [ SenseInfo('07519773-n', 5), SenseInfo('02694426-n', 3), SenseInfo('06803157-n', 0), SenseInfo('02694662-n', 0) ],
"_girlish_a_1_rel" : [ SenseInfo('01648698-a', 5) ],
"_disown_v_1_rel" : [ SenseInfo('02316097-v', 1), SenseInfo('00757544-v', 0) ],
"_the_q_rel" : [  ],
"_copy_n_of_rel" : [ SenseInfo('06505517-n', 7), SenseInfo('03104594-n', 6), SenseInfo('06390512-n', 2), SenseInfo('06676109-n', 0) ],
"_except_x_to_rel" : [ SenseInfo('00807941-v', 1), SenseInfo('00615774-v', 1) ],
"_fault_v_1_rel" : [ SenseInfo('00842538-v', 1) ],
"_ice_v_1_rel" : [ SenseInfo('01517175-v', 0), SenseInfo('00375579-v', 0), SenseInfo('00370921-v', 0) ],
"_itch_v_1_rel" : [ SenseInfo('02119874-v', 3), SenseInfo('02121188-v', 1), SenseInfo('02121423-v', 0), SenseInfo('01825761-v', 0), SenseInfo('02119874-v', 3), SenseInfo('02121188-v', 1), SenseInfo('02121423-v', 0), SenseInfo('01825761-v', 0) ],
"_machete_n_1_rel" : [ SenseInfo('03699591-n', 0) ],
"_on-demand_a_2_rel" : [  ],
"_assumption_n_1_rel" : [ SenseInfo('06753800-n', 15), SenseInfo('05892096-n', 13), SenseInfo('00082870-n', 1), SenseInfo('15193908-n', 0), SenseInfo('07357866-n', 0), SenseInfo('04838727-n', 0), SenseInfo('00083260-n', 0), SenseInfo('06753800-n', 15), SenseInfo('05892096-n', 13), SenseInfo('00082870-n', 1), SenseInfo('15193908-n', 0), SenseInfo('07357866-n', 0), SenseInfo('04838727-n', 0), SenseInfo('00083260-n', 0) ],
"_volume_n_of_rel" : [ SenseInfo('13779032-n', 25), SenseInfo('05099389-n', 11), SenseInfo('02870092-n', 8), SenseInfo('06413666-n', 4), SenseInfo('13779244-n', 2), SenseInfo('04990220-n', 1) ],
"_adept_a_1_rel" : [ SenseInfo('02226162-a', 1) ],
"_SR_n_1_rel" : [ SenseInfo('14655731-n', 0), SenseInfo('13612791-n', 0) ],
"_buggy_n_1_rel" : [ SenseInfo('02912557-n', 2) ],
"_distribute_v_to_rel" : [ SenseInfo('02294436-v', 10), SenseInfo('01378556-v', 5), SenseInfo('02479990-v', 4), SenseInfo('02201644-v', 3), SenseInfo('02043190-v', 1), SenseInfo('00968211-v', 1), SenseInfo('02754855-v', 0), SenseInfo('02754696-v', 0), SenseInfo('02754598-v', 0), SenseInfo('01504130-v', 0), SenseInfo('02294436-v', 10), SenseInfo('01378556-v', 5), SenseInfo('02479990-v', 4), SenseInfo('02201644-v', 3), SenseInfo('02043190-v', 1), SenseInfo('00968211-v', 1), SenseInfo('02754855-v', 0), SenseInfo('02754696-v', 0), SenseInfo('02754598-v', 0), SenseInfo('01504130-v', 0) ],
"_hop_v_1_rel" : [ SenseInfo('01966861-v', 7), SenseInfo('02095211-v', 1), SenseInfo('01840736-v', 1), SenseInfo('02095060-v', 0), SenseInfo('02094922-v', 0), SenseInfo('02094788-v', 0), SenseInfo('01966861-v', 7), SenseInfo('02095211-v', 1), SenseInfo('01840736-v', 1), SenseInfo('02095060-v', 0), SenseInfo('02094922-v', 0), SenseInfo('02094788-v', 0) ],
"_unused_a_1_rel" : [ SenseInfo('00418198-a', 1), SenseInfo('01643260-a', 0), SenseInfo('00037188-a', 0), SenseInfo('00025138-a', 0), SenseInfo('00418198-a', 1), SenseInfo('01643260-a', 0), SenseInfo('00037188-a', 0), SenseInfo('00025138-a', 0) ],
"_dizzying_a_1_rel" : [  ],
"_b_a_parens_rel" : [ SenseInfo('01349948-n', 1), SenseInfo('15090742-n', 0), SenseInfo('14631871-n', 0), SenseInfo('13713521-n', 0), SenseInfo('13614256-n', 0), SenseInfo('06831284-n', 0), SenseInfo('05400978-n', 0), SenseInfo('01349948-n', 1), SenseInfo('15090742-n', 0), SenseInfo('14631871-n', 0), SenseInfo('13713521-n', 0), SenseInfo('13614256-n', 0), SenseInfo('06831284-n', 0), SenseInfo('05400978-n', 0) ],
"_out+of+doors_p_rel" : [ SenseInfo('08613733-n', 1) ],
"_benevolent_a_1_rel" : [ SenseInfo('02661446-a', 0), SenseInfo('01372948-a', 0), SenseInfo('01111312-a', 0), SenseInfo('00359645-a', 0) ],
"_diplomatic_a_1_rel" : [ SenseInfo('02713715-a', 2), SenseInfo('00758459-a', 1) ],
"_furnishings_n_1_rel" : [ SenseInfo('03405595-n', 0), SenseInfo('03405265-n', 0), SenseInfo('00608551-n', 0) ],
"_expulsion_n_of_rel" : [ SenseInfo('00206927-n', 1), SenseInfo('00358702-n', 0), SenseInfo('00116687-n', 0) ],
"_cope_v_with_rel" : [ SenseInfo('02587532-v', 5), SenseInfo('02587532-v', 5) ],
"_advertisement_n_1_rel" : [ SenseInfo('07248801-n', 2) ],
"_incomprehensible_a_to_rel" : [ SenseInfo('00939105-a', 1), SenseInfo('00533851-a', 1) ],
"_linear_a_1_rel" : [ SenseInfo('01417451-a', 4), SenseInfo('00658259-a', 3), SenseInfo('00110497-a', 0), SenseInfo('02168699-a', 0), SenseInfo('01445438-a', 0), SenseInfo('01417451-a', 4), SenseInfo('00658259-a', 3), SenseInfo('00110497-a', 0), SenseInfo('02168699-a', 0), SenseInfo('01445438-a', 0) ],
"_hairtonic_n_1_rel" : [  ],
"_violet_a_1_rel" : [ SenseInfo('00380312-a', 0) ],
"_shop_v_buy_rel" : [ SenseInfo('02325968-v', 7), SenseInfo('02466134-v', 1), SenseInfo('02326355-v', 0), SenseInfo('00841986-v', 0) ],
"_formulate_v_1_rel" : [ SenseInfo('00925873-v', 8), SenseInfo('01632411-v', 4), SenseInfo('00980453-v', 4), SenseInfo('01633173-v', 1) ],
"_smelter_n_1_rel" : [ SenseInfo('04246156-n', 0) ],
"_greater+than_a_1_rel" : [  ],
"_monkey_v_with_rel" : [ SenseInfo('01586018-v', 0), SenseInfo('01473346-v', 0) ],
"_next+to_p_rel" : [  ],
"_adventurer_n_1_rel" : [ SenseInfo('09606009-n', 1), SenseInfo('10072708-n', 0) ],
"_pinnacle_n_1_rel" : [ SenseInfo('03943266-n', 1), SenseInfo('13940456-n', 0), SenseInfo('08619457-n', 0) ],
"_black_v_out_rel" : [ SenseInfo('00280532-v', 0), SenseInfo('00280532-v', 0) ],
"_all+the+more_x_rel" : [  ],
"_cut_v_apart_rel" : [ SenseInfo('01552519-v', 58), SenseInfo('00429060-v', 18), SenseInfo('02033295-v', 3), SenseInfo('01610834-v', 2), SenseInfo('02422283-v', 1), SenseInfo('01754915-v', 1), SenseInfo('01666717-v', 1), SenseInfo('01413917-v', 1), SenseInfo('01064799-v', 1), SenseInfo('00201722-v', 1), SenseInfo('02613860-v', 0), SenseInfo('02588280-v', 0), SenseInfo('02134232-v', 0), SenseInfo('02101649-v', 0), SenseInfo('01915865-v', 0), SenseInfo('01915730-v', 0), SenseInfo('01860107-v', 0), SenseInfo('01859995-v', 0), SenseInfo('01756563-v', 0), SenseInfo('01756416-v', 0), SenseInfo('01756277-v', 0), SenseInfo('01754737-v', 0), SenseInfo('01713491-v', 0), SenseInfo('01611123-v', 0), SenseInfo('01610990-v', 0), SenseInfo('01555437-v', 0), SenseInfo('01510576-v', 0), SenseInfo('01320424-v', 0), SenseInfo('01319738-v', 0), SenseInfo('01227088-v', 0), SenseInfo('01059564-v', 0), SenseInfo('00561090-v', 0), SenseInfo('00473322-v', 0), SenseInfo('00447654-v', 0), SenseInfo('00429968-v', 0), SenseInfo('00292507-v', 0), SenseInfo('00243900-v', 0), SenseInfo('00226071-v', 0), SenseInfo('00108475-v', 0), SenseInfo('00096136-v', 0), SenseInfo('00061219-v', 0) ],
"_thirst_v_for-after_rel" : [ SenseInfo('02122060-v', 0), SenseInfo('01188485-v', 0), SenseInfo('02122060-v', 0), SenseInfo('01188485-v', 0), SenseInfo('02122060-v', 0), SenseInfo('01188485-v', 0) ],
"_mooring_n_1_rel" : [ SenseInfo('08640111-n', 0), SenseInfo('03784475-n', 0) ],
"_fiery_a_1_rel" : [ SenseInfo('01726235-a', 2), SenseInfo('01248958-a', 2), SenseInfo('01256735-a', 0) ],
"_like_v_1_rel" : [ SenseInfo('01824736-v', 76), SenseInfo('01777210-v', 73), SenseInfo('01776952-v', 19), SenseInfo('00691665-v', 2), SenseInfo('01825962-v', 1), SenseInfo('01824736-v', 76), SenseInfo('01777210-v', 73), SenseInfo('01776952-v', 19), SenseInfo('00691665-v', 2), SenseInfo('01825962-v', 1), SenseInfo('01824736-v', 76), SenseInfo('01777210-v', 73), SenseInfo('01776952-v', 19), SenseInfo('00691665-v', 2), SenseInfo('01825962-v', 1), SenseInfo('01824736-v', 76), SenseInfo('01777210-v', 73), SenseInfo('01776952-v', 19), SenseInfo('00691665-v', 2), SenseInfo('01825962-v', 1), SenseInfo('01824736-v', 76), SenseInfo('01777210-v', 73), SenseInfo('01776952-v', 19), SenseInfo('00691665-v', 2), SenseInfo('01825962-v', 1), SenseInfo('01824736-v', 76), SenseInfo('01777210-v', 73), SenseInfo('01776952-v', 19), SenseInfo('00691665-v', 2), SenseInfo('01825962-v', 1) ],
"_short_a_of_rel" : [ SenseInfo('01442186-a', 43), SenseInfo('01436003-a', 21), SenseInfo('02386612-a', 7), SenseInfo('02336904-a', 3), SenseInfo('02006031-a', 0), SenseInfo('01444620-a', 0), SenseInfo('01444230-a', 0), SenseInfo('02337329-a', 0), SenseInfo('01896046-a', 0), SenseInfo('00709021-a', 0), SenseInfo('00640660-a', 0) ],
"_circle_v_1_rel" : [ SenseInfo('01911339-v', 6), SenseInfo('02044278-v', 4), SenseInfo('01522716-v', 0), SenseInfo('01911339-v', 6), SenseInfo('02044278-v', 4), SenseInfo('01522716-v', 0) ],
"_tear_n_1_rel" : [ SenseInfo('05405324-n', 6), SenseInfo('09410928-n', 1), SenseInfo('00510723-n', 0), SenseInfo('00391086-n', 0) ],
"_gesture_n_1_rel" : [ SenseInfo('00334509-n', 20), SenseInfo('06876309-n', 4), SenseInfo('01228380-n', 3) ],
"_withstand_v_1_rel" : [ SenseInfo('02706816-v', 6), SenseInfo('01116585-v', 0) ],
"_stavechurch_n_1_rel" : [  ],
"_sure-fire_a_1_rel" : [ SenseInfo('02332845-a', 0), SenseInfo('02332845-a', 0) ],
"_anthropologist_n_1_rel" : [ SenseInfo('09796323-n', 3) ],
"_trigger_v_1_rel" : [ SenseInfo('01643657-v', 4), SenseInfo('01135371-v', 1) ],
"_regimented_a_1_rel" : [ SenseInfo('00599745-a', 0) ],
"_gesture_v_1_rel" : [ SenseInfo('00992041-v', 3) ],
"_check_v_out_rel" : [ SenseInfo('00661824-v', 27), SenseInfo('02533282-v', 7), SenseInfo('00662589-v', 6), SenseInfo('02510337-v', 5), SenseInfo('01861403-v', 1), SenseInfo('00662182-v', 1), SenseInfo('00440286-v', 1), SenseInfo('02658283-v', 0), SenseInfo('02657219-v', 0), SenseInfo('02557638-v', 0), SenseInfo('02553697-v', 0), SenseInfo('02347905-v', 0), SenseInfo('02347447-v', 0), SenseInfo('01861767-v', 0), SenseInfo('01861622-v', 0), SenseInfo('01692978-v', 0), SenseInfo('01139756-v', 0), SenseInfo('01131473-v', 0), SenseInfo('01114764-v', 0), SenseInfo('01064999-v', 0), SenseInfo('00920336-v', 0), SenseInfo('00663353-v', 0), SenseInfo('00354634-v', 0), SenseInfo('00336539-v', 0), SenseInfo('00336260-v', 0), SenseInfo('00661824-v', 27), SenseInfo('02533282-v', 7), SenseInfo('00662589-v', 6), SenseInfo('02510337-v', 5), SenseInfo('01861403-v', 1), SenseInfo('00662182-v', 1), SenseInfo('00440286-v', 1), SenseInfo('02658283-v', 0), SenseInfo('02657219-v', 0), SenseInfo('02557638-v', 0), SenseInfo('02553697-v', 0), SenseInfo('02347905-v', 0), SenseInfo('02347447-v', 0), SenseInfo('01861767-v', 0), SenseInfo('01861622-v', 0), SenseInfo('01692978-v', 0), SenseInfo('01139756-v', 0), SenseInfo('01131473-v', 0), SenseInfo('01114764-v', 0), SenseInfo('01064999-v', 0), SenseInfo('00920336-v', 0), SenseInfo('00663353-v', 0), SenseInfo('00354634-v', 0), SenseInfo('00336539-v', 0), SenseInfo('00336260-v', 0) ],
"_contextual_a_1_rel" : [ SenseInfo('03002190-a', 0) ],
"_sacrificial_a_1_rel" : [ SenseInfo('03113271-a', 0) ],
"_knight_v_1_rel" : [ SenseInfo('02399185-v', 0) ],
"_limestone_n_1_rel" : [ SenseInfo('14936226-n', 0) ],
"_splice_n_1_rel" : [ SenseInfo('04281998-n', 0), SenseInfo('03642573-n', 0) ],
"_half-dozen_n_1_rel" : [ SenseInfo('02186833-a', 0), SenseInfo('02186833-a', 0) ],
"_semi_x_deg_rel" : [ SenseInfo('07467393-n', 0), SenseInfo('04467665-n', 0), SenseInfo('04172342-n', 0) ],
"_in+spite+of_p_rel" : [  ],
"_temperate_a_1_rel" : [ SenseInfo('02402559-a', 0), SenseInfo('02401590-a', 0), SenseInfo('01509367-a', 0) ],
"_placement_n_of_rel" : [ SenseInfo('05075602-n', 6), SenseInfo('00039990-n', 2), SenseInfo('01051331-n', 1) ],
"_naked_a_1_rel" : [ SenseInfo('00457998-a', 6), SenseInfo('01886783-a', 3), SenseInfo('02354234-a', 1), SenseInfo('01705195-a', 1), SenseInfo('01698760-a', 0), SenseInfo('00457998-a', 6), SenseInfo('01886783-a', 3), SenseInfo('02354234-a', 1), SenseInfo('01705195-a', 1), SenseInfo('01698760-a', 0) ],
"_shape_v_up_rel" : [ SenseInfo('00701040-v', 11), SenseInfo('01659248-v', 6), SenseInfo('00142191-v', 3), SenseInfo('00701040-v', 11), SenseInfo('01659248-v', 6), SenseInfo('00142191-v', 3) ],
"_swoop_n_1_rel" : [ SenseInfo('06857264-n', 1), SenseInfo('00977214-n', 0), SenseInfo('00327033-n', 0) ],
"_pasta_n_1_rel" : [ SenseInfo('07863374-n', 0), SenseInfo('07698915-n', 0) ],
"_sharply_x_deg_rel" : [ SenseInfo('00049947-r', 14), SenseInfo('00211651-r', 3), SenseInfo('00503102-r', 2), SenseInfo('00429534-r', 0) ],
"_reel_n_1_rel" : [ SenseInfo('04067658-n', 3), SenseInfo('07056680-n', 0), SenseInfo('04067472-n', 0), SenseInfo('02860415-n', 0), SenseInfo('00540211-n', 0), SenseInfo('00539674-n', 0) ],
"_chute_n_1_rel" : [ SenseInfo('03888257-n', 1), SenseInfo('03029603-n', 1) ],
"_ecological_a_1_rel" : [ SenseInfo('02906778-a', 0), SenseInfo('02906478-a', 0), SenseInfo('02906778-a', 0), SenseInfo('02906478-a', 0) ],
"_corolla_n_1_rel" : [ SenseInfo('11691046-n', 0) ],
"_peal_v_1_rel" : [ SenseInfo('02181402-v', 0), SenseInfo('02180898-v', 0) ],
"_thou+shalt+not_n_1_rel" : [  ],
"_amongst_p_rel" : [  ],
"_talented_a_1_rel" : [ SenseInfo('01119192-a', 0) ],
"_metro_a_1_rel" : [ SenseInfo('03757138-n', 1) ],
"_degenerate_v_into_rel" : [ SenseInfo('00092293-v', 0) ],
"_for_x_cond_rel" : [  ],
"_brazilian_a_1_rel" : [ SenseInfo('02966829-a', 2) ],
"_livery_n_1_rel" : [ SenseInfo('03679174-n', 0), SenseInfo('01108753-n', 0), SenseInfo('00658946-n', 0) ],
"_malign_a_1_rel" : [ SenseInfo('00227003-a', 1), SenseInfo('00224515-a', 0) ],
"_hyperbola_n_1_rel" : [ SenseInfo('13886575-n', 0) ],
"_upswing_n_1_rel" : [  ],
"_off-putting_a_1_rel" : [ SenseInfo('01809541-a', 0), SenseInfo('00171292-a', 0), SenseInfo('01809541-a', 0), SenseInfo('00171292-a', 0) ],
"_aplenty_a_1_rel" : [  ],
"_swear+word_n_1_rel" : [ SenseInfo('07125096-n', 0), SenseInfo('07125096-n', 0) ],
"_visibility_n_1_rel" : [ SenseInfo('05017458-n', 1), SenseInfo('14434329-n', 0), SenseInfo('04702545-n', 0) ],
"_tropical_a_1_rel" : [ SenseInfo('02443907-a', 3), SenseInfo('02929500-a', 1), SenseInfo('01420899-a', 0), SenseInfo('01250835-a', 0) ],
"_waveband_n_1_rel" : [ SenseInfo('06260628-n', 0) ],
"_robust_a_1_rel" : [ SenseInfo('02037708-a', 1), SenseInfo('02397234-a', 0), SenseInfo('02323521-a', 0), SenseInfo('01951112-a', 0) ],
"_poet_n_1_rel" : [ SenseInfo('10444194-n', 14) ],
"_bead_v_1_rel" : [ SenseInfo('02625521-v', 0), SenseInfo('01670511-v', 0), SenseInfo('01360091-v', 0) ],
"_diagnose_v_1_rel" : [ SenseInfo('00645552-v', 4), SenseInfo('00645771-v', 1) ],
"_revere_v_1_rel" : [ SenseInfo('01778017-v', 2), SenseInfo('01778568-v', 1) ],
"_bout_n_1_rel" : [ SenseInfo('15256714-n', 1), SenseInfo('15119072-n', 0), SenseInfo('07456906-n', 0), SenseInfo('00510723-n', 0) ],
"_kindergarten_n_1_rel" : [ SenseInfo('08412136-n', 1) ],
"_dilute_a_1_rel" : [ SenseInfo('00756091-a', 1) ],
"_dot_n_1_rel" : [ SenseInfo('13911872-n', 13), SenseInfo('08143653-n', 0), SenseInfo('06805826-n', 0), SenseInfo('02675657-n', 0) ],
"_auger_n_1_rel" : [ SenseInfo('03968886-n', 0), SenseInfo('02758490-n', 0) ],
"_indictment_n_1_rel" : [ SenseInfo('07235335-n', 4), SenseInfo('07237409-n', 1) ],
"_micron-scale_a_1_rel" : [  ],
"_disc_n_1_rel" : [ SenseInfo('03924069-n', 10), SenseInfo('13875185-n', 1), SenseInfo('03706653-n', 0), SenseInfo('03208556-n', 0) ],
"_confined_a_1_rel" : [ SenseInfo('01356283-a', 0), SenseInfo('00558373-a', 0), SenseInfo('01065126-a', 0) ],
"_maturate_v_cause_rel" : [ SenseInfo('00250181-v', 0), SenseInfo('00248026-v', 0), SenseInfo('00096766-v', 0) ],
"_act_n_of_rel" : [ SenseInfo('06532095-n', 35), SenseInfo('00030358-n', 24), SenseInfo('07009640-n', 9), SenseInfo('06892016-n', 3), SenseInfo('07014029-n', 0) ],
"_conviction_n_of_rel" : [ SenseInfo('05942888-n', 19), SenseInfo('01189282-n', 3), SenseInfo('05942888-n', 19), SenseInfo('01189282-n', 3) ],
"_tell_v_by_rel" : [ SenseInfo('01009240-v', 196), SenseInfo('00952524-v', 189), SenseInfo('00953216-v', 75), SenseInfo('00746718-v', 60), SenseInfo('00720961-v', 27), SenseInfo('01019643-v', 6), SenseInfo('00954422-v', 4), SenseInfo('00650353-v', 3) ],
"_propel_v_1_rel" : [ SenseInfo('01511706-v', 4), SenseInfo('01649999-v', 0) ],
"_recover_v_from_rel" : [ SenseInfo('02247977-v', 9), SenseInfo('00092690-v', 4), SenseInfo('00528339-v', 3), SenseInfo('02249438-v', 0), SenseInfo('02226833-v', 0), SenseInfo('01336541-v', 0) ],
"_dummy_n_1_rel" : [ SenseInfo('10039569-n', 0), SenseInfo('10039391-n', 0), SenseInfo('03255648-n', 0), SenseInfo('02848921-n', 0) ],
"_bourgeois_a_1_rel" : [ SenseInfo('00297598-a', 0), SenseInfo('00260780-a', 0), SenseInfo('00260695-a', 0) ],
"_transmit_v_1_rel" : [ SenseInfo('02231661-v', 4), SenseInfo('02079933-v', 2), SenseInfo('00973056-v', 2), SenseInfo('01435380-v', 1), SenseInfo('02231661-v', 4), SenseInfo('02079933-v', 2), SenseInfo('00973056-v', 2), SenseInfo('01435380-v', 1) ],
"_so_a_thus_rel" : [ SenseInfo('06868844-n', 0) ],
"_affix_v_1_rel" : [ SenseInfo('01356370-v', 7), SenseInfo('01328705-v', 2), SenseInfo('01298283-v', 0), SenseInfo('01356370-v', 7), SenseInfo('01328705-v', 2), SenseInfo('01298283-v', 0) ],
"_stain_v_1_rel" : [ SenseInfo('00286008-v', 19), SenseInfo('00286605-v', 2), SenseInfo('01537409-v', 0), SenseInfo('00283415-v', 0) ],
"_wealthy_a_1_rel" : [ SenseInfo('02022167-a', 3), SenseInfo('02022167-a', 3), SenseInfo('02022167-a', 3) ],
"_sunbeam_n_1_rel" : [ SenseInfo('11485582-n', 0) ],
"_per+centimeter_p_rel" : [  ],
"_under-report_v_1_rel" : [  ],
"_care_v_1_rel" : [ SenseInfo('01822936-v', 64), SenseInfo('02550296-v', 9), SenseInfo('01824736-v', 7), SenseInfo('02436349-v', 4), SenseInfo('01766748-v', 1), SenseInfo('01822936-v', 64), SenseInfo('02550296-v', 9), SenseInfo('01824736-v', 7), SenseInfo('02436349-v', 4), SenseInfo('01766748-v', 1), SenseInfo('01822936-v', 64), SenseInfo('02550296-v', 9), SenseInfo('01824736-v', 7), SenseInfo('02436349-v', 4), SenseInfo('01766748-v', 1), SenseInfo('01822936-v', 64), SenseInfo('02550296-v', 9), SenseInfo('01824736-v', 7), SenseInfo('02436349-v', 4), SenseInfo('01766748-v', 1) ],
"_foul_v_up_rel" : [ SenseInfo('01147855-v', 1), SenseInfo('00492706-v', 1), SenseInfo('01478603-v', 0), SenseInfo('01147709-v', 0), SenseInfo('00492410-v', 0), SenseInfo('00492310-v', 0), SenseInfo('00492225-v', 0) ],
"_corrupt_a_1_rel" : [ SenseInfo('00620731-a', 3), SenseInfo('02319129-a', 0), SenseInfo('01752792-a', 0), SenseInfo('01070716-a', 0) ],
"_slam-dunk_v_1_rel" : [ SenseInfo('02602685-v', 0), SenseInfo('01597832-v', 0), SenseInfo('02602685-v', 0), SenseInfo('01597832-v', 0) ],
"_disappearance_n_of_rel" : [ SenseInfo('00053609-n', 4), SenseInfo('07335716-n', 1), SenseInfo('00230172-n', 1), SenseInfo('07336346-n', 0) ],
"_skeptical_a_of_rel" : [ SenseInfo('00647247-a', 3), SenseInfo('02463847-a', 2), SenseInfo('00647247-a', 3), SenseInfo('02463847-a', 2) ],
"_stigma_n_1_rel" : [ SenseInfo('11677603-n', 0), SenseInfo('06794666-n', 0), SenseInfo('05250550-n', 0), SenseInfo('04696085-n', 0) ],
"_gnome_n_1_rel" : [ SenseInfo('09541125-n', 1), SenseInfo('07153385-n', 0) ],
"_triplet_n_1_rel" : [ SenseInfo('13744044-n', 0), SenseInfo('10729801-n', 0), SenseInfo('07986198-n', 0) ],
"_surgery_n_1_rel" : [ SenseInfo('06063588-n', 0), SenseInfo('04363991-n', 0), SenseInfo('03850245-n', 0), SenseInfo('00671351-n', 0) ],
"_creature_n_1_rel" : [ SenseInfo('00015388-n', 16), SenseInfo('09976429-n', 2), SenseInfo('09976551-n', 1) ],
"_stately_a_1_rel" : [ SenseInfo('01283508-a', 1), SenseInfo('02386418-a', 0), SenseInfo('00751838-a', 0), SenseInfo('01283508-a', 1), SenseInfo('02386418-a', 0), SenseInfo('00751838-a', 0), SenseInfo('01283508-a', 1), SenseInfo('02386418-a', 0), SenseInfo('00751838-a', 0) ],
"_archery_n_1_rel" : [ SenseInfo('00446980-n', 0) ],
"_stripe_v_1_rel" : [ SenseInfo('01273263-v', 0) ],
"_exasperate_v_1_rel" : [ SenseInfo('01820901-v', 1), SenseInfo('01786906-v', 0), SenseInfo('00208210-v', 0), SenseInfo('01820901-v', 1), SenseInfo('01786906-v', 0), SenseInfo('00208210-v', 0) ],
"_bloom_n_1_rel" : [ SenseInfo('13439390-n', 3), SenseInfo('11669335-n', 2), SenseInfo('15151641-n', 1), SenseInfo('14050871-n', 1), SenseInfo('15295045-n', 0), SenseInfo('11410527-n', 0), SenseInfo('13439390-n', 3), SenseInfo('11669335-n', 2), SenseInfo('15151641-n', 1), SenseInfo('14050871-n', 1), SenseInfo('15295045-n', 0), SenseInfo('11410527-n', 0) ],
"_leave_v_in_rel" : [ SenseInfo('02009433-v', 146), SenseInfo('00613683-v', 63), SenseInfo('02729414-v', 56), SenseInfo('00136991-v', 27), SenseInfo('02015598-v', 20), SenseInfo('02721438-v', 19), SenseInfo('02635659-v', 16), SenseInfo('02383440-v', 14), SenseInfo('02356230-v', 8), SenseInfo('02229055-v', 7), SenseInfo('02730135-v', 5), SenseInfo('00360092-v', 5), SenseInfo('02296153-v', 3), SenseInfo('00613018-v', 3) ],
"_case_v_1_rel" : [ SenseInfo('02165982-v', 1), SenseInfo('01486312-v', 0) ],
"_sanctuary_n_1_rel" : [ SenseInfo('04133648-n', 0), SenseInfo('04071102-n', 0), SenseInfo('03004824-n', 0) ],
"_brand_n_of_rel" : [ SenseInfo('06845599-n', 7), SenseInfo('05845140-n', 3), SenseInfo('06795543-n', 2), SenseInfo('15101157-n', 0), SenseInfo('06794666-n', 0), SenseInfo('04373894-n', 0), SenseInfo('06845599-n', 7), SenseInfo('05845140-n', 3), SenseInfo('06795543-n', 2), SenseInfo('15101157-n', 0), SenseInfo('06794666-n', 0), SenseInfo('04373894-n', 0), SenseInfo('06845599-n', 7), SenseInfo('05845140-n', 3), SenseInfo('06795543-n', 2), SenseInfo('15101157-n', 0), SenseInfo('06794666-n', 0), SenseInfo('04373894-n', 0), SenseInfo('06845599-n', 7), SenseInfo('05845140-n', 3), SenseInfo('06795543-n', 2), SenseInfo('15101157-n', 0), SenseInfo('06794666-n', 0), SenseInfo('04373894-n', 0) ],
"_moral_n_1_rel" : [ SenseInfo('06606044-n', 2) ],
"_casting_n_1_rel" : [ SenseInfo('02979662-n', 0), SenseInfo('00909899-n', 0), SenseInfo('00454624-n', 0), SenseInfo('00161603-n', 0) ],
"_excreta_n_1_rel" : [ SenseInfo('14853947-n', 0) ],
"_briefcase_n_1_rel" : [ SenseInfo('02900705-n', 3) ],
"_still_a_1_rel" : [ SenseInfo('01564315-a', 16), SenseInfo('01919428-a', 9), SenseInfo('00302951-a', 3), SenseInfo('01565751-a', 2), SenseInfo('02277485-a', 0), SenseInfo('01241600-a', 0), SenseInfo('01564315-a', 16), SenseInfo('01919428-a', 9), SenseInfo('00302951-a', 3), SenseInfo('01565751-a', 2), SenseInfo('02277485-a', 0), SenseInfo('01241600-a', 0), SenseInfo('01564315-a', 16), SenseInfo('01919428-a', 9), SenseInfo('00302951-a', 3), SenseInfo('01565751-a', 2), SenseInfo('02277485-a', 0), SenseInfo('01241600-a', 0), SenseInfo('01564315-a', 16), SenseInfo('01919428-a', 9), SenseInfo('00302951-a', 3), SenseInfo('01565751-a', 2), SenseInfo('02277485-a', 0), SenseInfo('01241600-a', 0), SenseInfo('01564315-a', 16), SenseInfo('01919428-a', 9), SenseInfo('00302951-a', 3), SenseInfo('01565751-a', 2), SenseInfo('02277485-a', 0), SenseInfo('01241600-a', 0) ],
"_ragged_a_1_rel" : [ SenseInfo('02582697-a', 5), SenseInfo('02434210-a', 2), SenseInfo('00913131-a', 2) ],
"_paprika_n_1_rel" : [ SenseInfo('12901264-n', 0), SenseInfo('07824702-n', 0) ],
"_cross_v_out_rel" : [ SenseInfo('01912159-v', 47), SenseInfo('02023396-v', 7), SenseInfo('02558172-v', 1), SenseInfo('01914657-v', 1), SenseInfo('02685390-v', 0), SenseInfo('01913997-v', 0), SenseInfo('01691798-v', 0), SenseInfo('01429953-v', 0) ],
"_fragmentation_n_of_rel" : [ SenseInfo('00388210-n', 1), SenseInfo('13993517-n', 0), SenseInfo('13484303-n', 0), SenseInfo('07409121-n', 0) ],
"_shin_v_1_rel" : [ SenseInfo('01921772-v', 0) ],
"_glaciation_n_1_rel" : [ SenseInfo('14519673-n', 0), SenseInfo('13487409-n', 0) ],
"_resin_n_1_rel" : [ SenseInfo('14894140-n', 0) ],
"_souvenir_n_1_rel" : [ SenseInfo('03610270-n', 1), SenseInfo('05813822-n', 0) ],
"_standby_a_1_rel" : [ SenseInfo('01855086-a', 0), SenseInfo('01855086-a', 0) ],
"_perk_n_1_rel" : [ SenseInfo('13298011-n', 0) ],
"_deform_v_cause_rel" : [ SenseInfo('01584875-v', 0), SenseInfo('01350699-v', 0), SenseInfo('01280014-v', 0), SenseInfo('00477665-v', 0), SenseInfo('00476744-v', 0), SenseInfo('00140967-v', 0) ],
"_engagement_n_of_rel" : [ SenseInfo('00953559-n', 6), SenseInfo('08385009-n', 2), SenseInfo('07228211-n', 2), SenseInfo('01217859-n', 1), SenseInfo('00270919-n', 1), SenseInfo('07338114-n', 0), SenseInfo('01239064-n', 0) ],
"_touching_a_for_rel" : [ SenseInfo('01560821-a', 3), SenseInfo('01560821-a', 3), SenseInfo('01560821-a', 3) ],
"_instrument_n_of_rel" : [ SenseInfo('03574816-n', 23), SenseInfo('00173761-n', 4), SenseInfo('10209616-n', 1), SenseInfo('06479665-n', 0), SenseInfo('06332731-n', 0), SenseInfo('03800933-n', 0) ],
"_churn_v_cause_rel" : [ SenseInfo('01418389-v', 1), SenseInfo('01885430-v', 0) ],
"_sip_n_1_rel" : [ SenseInfo('00843494-n', 2) ],
"_so+so_a_1_rel" : [ SenseInfo('01674604-a', 3), SenseInfo('01674604-a', 3) ],
"_art_n_1_rel" : [ SenseInfo('02743547-n', 49), SenseInfo('00933420-n', 15), SenseInfo('05638987-n', 7), SenseInfo('06998748-n', 3), SenseInfo('02743547-n', 49), SenseInfo('00933420-n', 15), SenseInfo('05638987-n', 7), SenseInfo('06998748-n', 3), SenseInfo('02743547-n', 49), SenseInfo('00933420-n', 15), SenseInfo('05638987-n', 7), SenseInfo('06998748-n', 3) ],
"_hear_v_from_rel" : [ SenseInfo('02169702-v', 275), SenseInfo('00598954-v', 60), SenseInfo('02500902-v', 12), SenseInfo('02107442-v', 8), SenseInfo('02171039-v', 0) ],
"_tailings_n_1_rel" : [ SenseInfo('00320486-n', 0), SenseInfo('00320486-n', 0) ],
"_helmet_n_1_rel" : [ SenseInfo('03513376-n', 0), SenseInfo('03513137-n', 0) ],
"_abloom_a_with_rel" : [ SenseInfo('01488856-a', 0), SenseInfo('01488856-a', 0), SenseInfo('01488856-a', 0) ],
"_auspices_n_1_rel" : [ SenseInfo('01214863-n', 0), SenseInfo('01214863-n', 0) ],
"_paternal_a_1_rel" : [ SenseInfo('02759604-a', 0), SenseInfo('01734436-a', 0), SenseInfo('01722529-a', 0), SenseInfo('01971671-a', 0), SenseInfo('02759604-a', 0), SenseInfo('01734436-a', 0), SenseInfo('01722529-a', 0), SenseInfo('01971671-a', 0) ],
"_like_x_preph_rel" : [ SenseInfo('01824736-v', 76), SenseInfo('01777210-v', 73), SenseInfo('01409581-a', 30), SenseInfo('01776952-v', 19), SenseInfo('00691665-v', 2), SenseInfo('01411065-a', 1), SenseInfo('01410606-a', 1), SenseInfo('01825962-v', 1), SenseInfo('05845888-n', 0), SenseInfo('05845419-n', 0), SenseInfo('02063554-a', 0) ],
"_not+more+than_x_rel" : [  ],
"_cook_n_1_rel" : [ SenseInfo('09963320-n', 7), SenseInfo('10908313-n', 0) ],
"_configuration_n_of_rel" : [ SenseInfo('05731779-n', 1), SenseInfo('05064037-n', 1) ],
"_sled_n_1_rel" : [ SenseInfo('04235291-n', 0) ],
"_peony_n_1_rel" : [ SenseInfo('11719286-n', 2) ],
"_registry_n_1_rel" : [ SenseInfo('06507041-n', 1) ],
"_raft_v_1_rel" : [ SenseInfo('01949966-v', 0), SenseInfo('01842508-v', 0), SenseInfo('01654156-v', 0) ],
"_swallow_v_down_rel" : [ SenseInfo('01201856-v', 12), SenseInfo('01083769-v', 4), SenseInfo('01582409-v', 2), SenseInfo('00941037-v', 0), SenseInfo('00799076-v', 0), SenseInfo('00737352-v', 0), SenseInfo('00668805-v', 0), SenseInfo('00601659-v', 0) ],
"_preview_n_1_rel" : [ SenseInfo('06888674-n', 0), SenseInfo('06888506-n', 0) ],
"_amass_v_1_rel" : [ SenseInfo('00158804-v', 1), SenseInfo('02304982-v', 0) ],
"_bulk_v_up_rel" : [ SenseInfo('00263564-v', 2), SenseInfo('00256369-v', 0) ],
"_squeeze_v_out_rel" : [ SenseInfo('01593937-v', 9), SenseInfo('01447868-v', 6), SenseInfo('01527271-v', 4), SenseInfo('02504562-v', 0), SenseInfo('02241107-v', 0), SenseInfo('02094569-v', 0), SenseInfo('01456771-v', 0), SenseInfo('01424456-v', 0), SenseInfo('01387786-v', 0), SenseInfo('01593937-v', 9), SenseInfo('01447868-v', 6), SenseInfo('01527271-v', 4), SenseInfo('02504562-v', 0), SenseInfo('02241107-v', 0), SenseInfo('02094569-v', 0), SenseInfo('01456771-v', 0), SenseInfo('01424456-v', 0), SenseInfo('01387786-v', 0) ],
"_whack_n_1_rel" : [ SenseInfo('07399829-n', 0), SenseInfo('00133338-n', 0) ],
"_nix_v_1_rel" : [ SenseInfo('00795863-v', 0) ],
"_somewhat_x_deg_rel" : [ SenseInfo('00036291-r', 50), SenseInfo('00035718-r', 5), SenseInfo('00036291-r', 50), SenseInfo('00035718-r', 5) ],
"_smart_v_1_rel" : [ SenseInfo('02122164-v', 1) ],
"_touch_n_1_rel" : [ SenseInfo('07409592-n', 8), SenseInfo('05655119-n', 3), SenseInfo('07164163-n', 2), SenseInfo('04931428-n', 2), SenseInfo('00046522-n', 2), SenseInfo('13774115-n', 1), SenseInfo('07279285-n', 1), SenseInfo('14082186-n', 0), SenseInfo('07188238-n', 0), SenseInfo('05722427-n', 0), SenseInfo('05642553-n', 0), SenseInfo('04946760-n', 0) ],
"_invoice_n_for_rel" : [ SenseInfo('06516955-n', 0) ],
"_confirmation_n_of_rel" : [ SenseInfo('05825245-n', 4), SenseInfo('06650070-n', 1), SenseInfo('07179943-n', 0), SenseInfo('01038895-n', 0), SenseInfo('01038761-n', 0), SenseInfo('05825245-n', 4), SenseInfo('06650070-n', 1), SenseInfo('07179943-n', 0), SenseInfo('01038895-n', 0), SenseInfo('01038761-n', 0) ],
"_swing_v_out_rel" : [ SenseInfo('02087745-v', 35), SenseInfo('01877355-v', 15), SenseInfo('01877620-v', 6), SenseInfo('02537238-v', 4), SenseInfo('01593763-v', 4), SenseInfo('02717472-v', 2), SenseInfo('01152040-v', 2), SenseInfo('00557216-v', 2), SenseInfo('02615140-v', 1), SenseInfo('02752277-v', 0), SenseInfo('02389815-v', 0), SenseInfo('01725375-v', 0), SenseInfo('01427483-v', 0) ],
"_awfully_x_rel" : [ SenseInfo('00054950-r', 5), SenseInfo('00056340-r', 0), SenseInfo('00055101-r', 0) ],
"_sick+and+tired_a_of_rel" : [  ],
"_overturn_v_1_rel" : [ SenseInfo('01909397-v', 2), SenseInfo('01909978-v', 1), SenseInfo('00716130-v', 1), SenseInfo('02402409-v', 0), SenseInfo('00799798-v', 0), SenseInfo('00125633-v', 0) ],
"_seafaring_a_1_rel" : [ SenseInfo('01381074-a', 0) ],
"_reel_v_1_rel" : [ SenseInfo('01924882-v', 2), SenseInfo('02046755-v', 1), SenseInfo('01523105-v', 0) ],
"_fathom_v_1_rel" : [ SenseInfo('00728954-v', 4), SenseInfo('00491689-v', 0), SenseInfo('00728954-v', 4), SenseInfo('00491689-v', 0) ],
"_not+only_a_1_rel" : [ SenseInfo('02214736-a', 0), SenseInfo('01862697-a', 0) ],
"_corruption_n_of_rel" : [ SenseInfo('04853948-n', 1), SenseInfo('14561102-n', 0), SenseInfo('13453640-n', 0), SenseInfo('04850996-n', 0), SenseInfo('00272448-n', 0), SenseInfo('00159396-n', 0) ],
"_tidy_v_up_rel" : [ SenseInfo('00275843-v', 0), SenseInfo('00275843-v', 0) ],
"_addictive_a_1_rel" : [ SenseInfo('00047786-a', 0) ],
"_sleepover_n_1_rel" : [ SenseInfo('07455984-n', 0), SenseInfo('07455984-n', 0), SenseInfo('07455984-n', 0) ],
"_kilogram_n_1_rel" : [ SenseInfo('13724582-n', 0), SenseInfo('13724582-n', 0), SenseInfo('13724582-n', 0), SenseInfo('13724582-n', 0) ],
"_spiral_v_1_rel" : [ SenseInfo('02049190-v', 2), SenseInfo('02738544-v', 0), SenseInfo('02049561-v', 0) ],
"_nanny_n_1_rel" : [ SenseInfo('10345100-n', 0), SenseInfo('02416964-n', 0) ],
"_liner_n_1_rel" : [ SenseInfo('00131608-n', 1), SenseInfo('03673767-n', 0), SenseInfo('03673270-n', 0), SenseInfo('03673027-n', 0) ],
"_dendrite_n_1_rel" : [ SenseInfo('05469861-n', 0) ],
"_attend_v_1_rel" : [ SenseInfo('02612762-v', 84), SenseInfo('02549581-v', 2), SenseInfo('02716567-v', 1), SenseInfo('02540670-v', 1), SenseInfo('02170427-v', 1), SenseInfo('02612762-v', 84), SenseInfo('02549581-v', 2), SenseInfo('02716567-v', 1), SenseInfo('02540670-v', 1), SenseInfo('02170427-v', 1), SenseInfo('02612762-v', 84), SenseInfo('02549581-v', 2), SenseInfo('02716567-v', 1), SenseInfo('02540670-v', 1), SenseInfo('02170427-v', 1) ],
"_reinstatement_n_of_rel" : [ SenseInfo('13944914-n', 0), SenseInfo('00401459-n', 0) ],
"_cling_v_on_rel" : [ SenseInfo('01220885-v', 9), SenseInfo('01776065-v', 5), SenseInfo('01216331-v', 2) ],
"_kid_v_1_rel" : [ SenseInfo('00851100-v', 5), SenseInfo('00855295-v', 2) ],
"_arabic_a_1_rel" : [ SenseInfo('03044740-a', 0) ],
"_fewer+than_x_deg_rel" : [  ],
"_gasoline_n_1_rel" : [ SenseInfo('14686913-n', 1) ],
"_in+brief_a_1_rel" : [  ],
"_dormouse_n_1_rel" : [ SenseInfo('02352591-n', 0) ],
"_exist_v_1_rel" : [ SenseInfo('02603699-v', 100), SenseInfo('02616713-v', 5) ],
"_beckon_v_to_rel" : [ SenseInfo('01041415-v', 9), SenseInfo('01807051-v', 1), SenseInfo('01041644-v', 0), SenseInfo('01041415-v', 9), SenseInfo('01807051-v', 1), SenseInfo('01041644-v', 0), SenseInfo('01041415-v', 9), SenseInfo('01807051-v', 1), SenseInfo('01041644-v', 0), SenseInfo('01041415-v', 9), SenseInfo('01807051-v', 1), SenseInfo('01041644-v', 0) ],
"_suitability_n_1_rel" : [ SenseInfo('04715487-n', 1) ],
"_mimic_n_1_rel" : [ SenseInfo('10319163-n', 0) ],
"_eater_n_1_rel" : [ SenseInfo('10042300-n', 0), SenseInfo('07708260-n', 0) ],
"_snag_v_cause_rel" : [ SenseInfo('01328212-v', 2), SenseInfo('02353088-v', 0), SenseInfo('01260593-v', 0) ],
"_couch_n_1_rel" : [ SenseInfo('04256520-n', 5), SenseInfo('03115897-n', 0), SenseInfo('03115762-n', 0) ],
"_delineation_n_of_rel" : [ SenseInfo('07201804-n', 1), SenseInfo('03173524-n', 0), SenseInfo('00900726-n', 0) ],
"_tympanum_n_1_rel" : [ SenseInfo('05324888-n', 0), SenseInfo('05318831-n', 0), SenseInfo('03612965-n', 0) ],
"_clamp_v_down_rel" : [ SenseInfo('01343610-v', 7), SenseInfo('00747932-v', 1), SenseInfo('01343610-v', 7), SenseInfo('00747932-v', 1), SenseInfo('01343610-v', 7), SenseInfo('00747932-v', 1) ],
"_episode_n_1_rel" : [ SenseInfo('07289956-n', 4), SenseInfo('06396330-n', 3), SenseInfo('06621771-n', 0), SenseInfo('04173172-n', 0) ],
"_ill_n_1_rel" : [ SenseInfo('14055408-n', 0) ],
"_grape_n_1_rel" : [ SenseInfo('07758680-n', 2), SenseInfo('13144794-n', 0), SenseInfo('03453547-n', 0) ],
"_accommodation_n_1_rel" : [ SenseInfo('07369604-n', 0), SenseInfo('07177437-n', 0), SenseInfo('05755486-n', 0), SenseInfo('02672371-n', 0), SenseInfo('01210816-n', 0), SenseInfo('00193225-n', 0) ],
"_trudge_n_1_rel" : [ SenseInfo('00289175-n', 0) ],
"_abbreviation_n_1_rel" : [ SenseInfo('07091587-n', 0), SenseInfo('00359135-n', 0) ],
"_concession_n_1_rel" : [ SenseInfo('06526619-n', 2), SenseInfo('07176243-n', 1), SenseInfo('07216412-n', 0), SenseInfo('06526619-n', 2), SenseInfo('07176243-n', 1), SenseInfo('07216412-n', 0), SenseInfo('06526619-n', 2), SenseInfo('07176243-n', 1), SenseInfo('07216412-n', 0) ],
"_blacktop_n_1_rel" : [ SenseInfo('14976871-n', 0) ],
"_suction_n_1_rel" : [ SenseInfo('11517494-n', 1), SenseInfo('00842692-n', 0) ],
"_still_n_1_rel" : [ SenseInfo('04319248-n', 2), SenseInfo('04982478-n', 0), SenseInfo('04318982-n', 0), SenseInfo('03212811-n', 0) ],
"_severity_n_1_rel" : [ SenseInfo('05036715-n', 2), SenseInfo('04710127-n', 0), SenseInfo('04697666-n', 0), SenseInfo('04639732-n', 0) ],
"_though_p_1_rel" : [ SenseInfo('00119139-r', 11), SenseInfo('00119139-r', 11) ],
"_westward_a_1_rel" : [ SenseInfo('00824509-a', 0) ],
"_local_a_1_rel" : [ SenseInfo('01106405-a', 47), SenseInfo('02756346-a', 3), SenseInfo('01425529-a', 0), SenseInfo('01106405-a', 47), SenseInfo('02756346-a', 3), SenseInfo('01425529-a', 0) ],
"_divert_v_1_rel" : [ SenseInfo('02064887-v', 2), SenseInfo('01952363-v', 2), SenseInfo('02492362-v', 1), SenseInfo('02312014-v', 0), SenseInfo('02064887-v', 2), SenseInfo('01952363-v', 2), SenseInfo('02492362-v', 1), SenseInfo('02312014-v', 0) ],
"_rip_v_off_rel" : [ SenseInfo('01573276-v', 8), SenseInfo('02098041-v', 2), SenseInfo('01601147-v', 2), SenseInfo('00863277-v', 0) ],
"_noodle_n_1_rel" : [ SenseInfo('07699584-n', 0), SenseInfo('05539454-n', 0) ],
"_pastime_n_1_rel" : [ SenseInfo('00431552-n', 1) ],
"_no+more_q_rel" : [  ],
"_choir_n_1_rel" : [ SenseInfo('08188638-n', 2), SenseInfo('08188814-n', 0), SenseInfo('03024064-n', 0) ],
"_impaired_n_1_rel" : [ SenseInfo('01274261-a', 1), SenseInfo('01018264-a', 0) ],
"_wonderland_n_1_rel" : [ SenseInfo('09480699-n', 0), SenseInfo('05632175-n', 0) ],
"_haymaking_n_1_rel" : [ SenseInfo('00623052-n', 0), SenseInfo('00622957-n', 0) ],
"_footwear_n_1_rel" : [ SenseInfo('03381126-n', 0), SenseInfo('03380867-n', 0), SenseInfo('03381126-n', 0), SenseInfo('03380867-n', 0) ],
"_balinese_a_1_rel" : [ SenseInfo('06939656-n', 1) ],
"_scouring_n_1_rel" : [ SenseInfo('00993488-n', 1), SenseInfo('00251780-n', 1) ],
"_tedious_a_for_rel" : [ SenseInfo('01345307-a', 2), SenseInfo('00549236-a', 0), SenseInfo('01345307-a', 2), SenseInfo('00549236-a', 0) ],
"_at+least_a_1_rel" : [  ],
"_legation_n_1_rel" : [ SenseInfo('00594260-n', 2), SenseInfo('08403082-n', 0) ],
"_find_v_out_rel" : [ SenseInfo('02248465-v', 159), SenseInfo('02154508-v', 141), SenseInfo('02285629-v', 86), SenseInfo('00918872-v', 57), SenseInfo('00715239-v', 57), SenseInfo('02128873-v', 45), SenseInfo('02213336-v', 41), SenseInfo('01637982-v', 34), SenseInfo('00721437-v', 29), SenseInfo('02212275-v', 16), SenseInfo('00971999-v', 16), SenseInfo('00522751-v', 13), SenseInfo('02197781-v', 11), SenseInfo('02247977-v', 0), SenseInfo('02021653-v', 0), SenseInfo('00250691-v', 0), SenseInfo('02248465-v', 159), SenseInfo('02154508-v', 141), SenseInfo('02285629-v', 86), SenseInfo('00918872-v', 57), SenseInfo('00715239-v', 57), SenseInfo('02128873-v', 45), SenseInfo('02213336-v', 41), SenseInfo('01637982-v', 34), SenseInfo('00721437-v', 29), SenseInfo('02212275-v', 16), SenseInfo('00971999-v', 16), SenseInfo('00522751-v', 13), SenseInfo('02197781-v', 11), SenseInfo('02247977-v', 0), SenseInfo('02021653-v', 0), SenseInfo('00250691-v', 0), SenseInfo('02248465-v', 159), SenseInfo('02154508-v', 141), SenseInfo('02285629-v', 86), SenseInfo('00918872-v', 57), SenseInfo('00715239-v', 57), SenseInfo('02128873-v', 45), SenseInfo('02213336-v', 41), SenseInfo('01637982-v', 34), SenseInfo('00721437-v', 29), SenseInfo('02212275-v', 16), SenseInfo('00971999-v', 16), SenseInfo('00522751-v', 13), SenseInfo('02197781-v', 11), SenseInfo('02247977-v', 0), SenseInfo('02021653-v', 0), SenseInfo('00250691-v', 0) ],
"_ridiculously_x_rel" : [ SenseInfo('00387017-r', 1) ],
"_towards_p_rel" : [  ],
"_vinegar_n_1_rel" : [ SenseInfo('07828987-n', 1), SenseInfo('15088111-n', 0) ],
"_minister_v_to_rel" : [ SenseInfo('02549392-v', 3), SenseInfo('02446660-v', 0), SenseInfo('02549392-v', 3), SenseInfo('02446660-v', 0) ],
"_millionaire_n_1_rel" : [ SenseInfo('10529555-n', 0) ],
"_boil_v_down_rel" : [ SenseInfo('00375021-v', 4), SenseInfo('00328128-v', 4), SenseInfo('00374668-v', 3), SenseInfo('01885430-v', 0), SenseInfo('01767612-v', 0), SenseInfo('00375021-v', 4), SenseInfo('00328128-v', 4), SenseInfo('00374668-v', 3), SenseInfo('01885430-v', 0), SenseInfo('01767612-v', 0), SenseInfo('00375021-v', 4), SenseInfo('00328128-v', 4), SenseInfo('00374668-v', 3), SenseInfo('01885430-v', 0), SenseInfo('01767612-v', 0), SenseInfo('00375021-v', 4), SenseInfo('00328128-v', 4), SenseInfo('00374668-v', 3), SenseInfo('01885430-v', 0), SenseInfo('01767612-v', 0) ],
"_preferable_a_1_rel" : [ SenseInfo('00733743-a', 1), SenseInfo('00733743-a', 1) ],
"_light_v_cause_rel" : [ SenseInfo('00291873-v', 12), SenseInfo('01199881-v', 10), SenseInfo('01978700-v', 3), SenseInfo('02759614-v', 2), SenseInfo('02229828-v', 0), SenseInfo('01958452-v', 0) ],
"_dammit_a_1_rel" : [  ],
"_die-hard_a_1_rel" : [ SenseInfo('01025212-a', 0), SenseInfo('01025212-a', 0), SenseInfo('01025212-a', 0) ],
"_pediatrician_n_1_rel" : [ SenseInfo('09828760-n', 0) ],
"_bounce_v_cause_rel" : [ SenseInfo('01892104-v', 13), SenseInfo('01404389-v', 5), SenseInfo('01892608-v', 4), SenseInfo('02254923-v', 1), SenseInfo('01964788-v', 1), SenseInfo('02254767-v', 0), SenseInfo('01469080-v', 0) ],
"_doorstep_n_1_rel" : [ SenseInfo('03223686-n', 0) ],
"_crusade_n_1_rel" : [ SenseInfo('00798245-n', 2), SenseInfo('00968715-n', 1) ],
"_throttle_v_1_rel" : [ SenseInfo('00233335-v', 2), SenseInfo('01570935-v', 1), SenseInfo('00173159-v', 0) ],
"_packhorse_n_1_rel" : [ SenseInfo('02386746-n', 0) ],
"_predicate_v_on_rel" : [ SenseInfo('01017222-v', 0), SenseInfo('01017001-v', 0), SenseInfo('00931232-v', 0) ],
"_electric_n_1_rel" : [ SenseInfo('03268790-n', 0) ],
"_festive_a_1_rel" : [ SenseInfo('01367431-a', 2), SenseInfo('01367431-a', 2) ],
"_objective_a_1_rel" : [ SenseInfo('01615180-a', 9), SenseInfo('02861997-a', 0), SenseInfo('01934026-a', 0), SenseInfo('00013442-a', 0), SenseInfo('01615180-a', 9), SenseInfo('02861997-a', 0), SenseInfo('01934026-a', 0), SenseInfo('00013442-a', 0) ],
"_agriculture_n_1_rel" : [ SenseInfo('01104406-n', 4), SenseInfo('00916464-n', 1), SenseInfo('08128964-n', 0), SenseInfo('08075287-n', 0) ],
"_initial_a_1_rel" : [ SenseInfo('01011973-a', 21), SenseInfo('01011973-a', 21) ],
"_familiarity_n_1_rel" : [ SenseInfo('05817145-n', 2), SenseInfo('04796291-n', 1), SenseInfo('04655442-n', 1), SenseInfo('04912240-n', 0), SenseInfo('00737070-n', 0) ],
"_pill_n_1_rel" : [ SenseInfo('03936764-n', 6), SenseInfo('03936568-n', 1), SenseInfo('10432875-n', 0), SenseInfo('05833511-n', 0), SenseInfo('03936895-n', 0) ],
"_miscellaneous_a_1_rel" : [ SenseInfo('01199083-a', 2), SenseInfo('02506922-a', 0), SenseInfo('01199083-a', 2), SenseInfo('02506922-a', 0) ],
"_give_v_off_rel" : [ SenseInfo('02316868-v', 179), SenseInfo('02339171-v', 160), SenseInfo('02199590-v', 96), SenseInfo('02235842-v', 78), SenseInfo('01060494-v', 32), SenseInfo('01733477-v', 29), SenseInfo('01060317-v', 24), SenseInfo('02200686-v', 20), SenseInfo('01629403-v', 18), SenseInfo('00732224-v', 18), SenseInfo('01629000-v', 16), SenseInfo('02296153-v', 14), SenseInfo('01647672-v', 14), SenseInfo('02200498-v', 12), SenseInfo('02562901-v', 10), SenseInfo('02343595-v', 10), SenseInfo('02230772-v', 10), SenseInfo('00887463-v', 8), SenseInfo('02309374-v', 5), SenseInfo('02309165-v', 5), SenseInfo('01060746-v', 5), SenseInfo('02317094-v', 4), SenseInfo('01848465-v', 4), SenseInfo('01178565-v', 4), SenseInfo('02308741-v', 3), SenseInfo('01989053-v', 1), SenseInfo('00673571-v', 1), SenseInfo('02564052-v', 0), SenseInfo('02359553-v', 0), SenseInfo('02358034-v', 0), SenseInfo('01716283-v', 0), SenseInfo('01716112-v', 0), SenseInfo('01449796-v', 0), SenseInfo('01175810-v', 0), SenseInfo('01069638-v', 0), SenseInfo('00944247-v', 0), SenseInfo('00888009-v', 0), SenseInfo('00878876-v', 0), SenseInfo('00771806-v', 0), SenseInfo('00748972-v', 0), SenseInfo('00748616-v', 0), SenseInfo('00341184-v', 0), SenseInfo('00108747-v', 0), SenseInfo('00108604-v', 0) ],
"_tell_v_of_rel" : [ SenseInfo('01009240-v', 196), SenseInfo('00952524-v', 189), SenseInfo('00953216-v', 75), SenseInfo('00746718-v', 60), SenseInfo('00720961-v', 27), SenseInfo('01019643-v', 6), SenseInfo('00954422-v', 4), SenseInfo('00650353-v', 3) ],
"_contrariety_n_1_rel" : [ SenseInfo('13858392-n', 0) ],
"_boost_v_to_rel" : [ SenseInfo('01975912-v', 3), SenseInfo('00310937-v', 2), SenseInfo('02554922-v', 1), SenseInfo('00497061-v', 1), SenseInfo('01516071-v', 0) ],
"_solution_n_of_rel" : [ SenseInfo('14589223-n', 12), SenseInfo('06743506-n', 8), SenseInfo('05661668-n', 8), SenseInfo('08005954-n', 6), SenseInfo('00190783-n', 0), SenseInfo('14589223-n', 12), SenseInfo('06743506-n', 8), SenseInfo('05661668-n', 8), SenseInfo('08005954-n', 6), SenseInfo('00190783-n', 0) ],
"_onyx_n_1_rel" : [ SenseInfo('14969523-n', 0) ],
"_hunters_a_1_rel" : [  ],
"_roomy_a_1_rel" : [ SenseInfo('00476249-a', 0), SenseInfo('00476249-a', 0), SenseInfo('00476249-a', 0) ],
"_twinkle_v_1_rel" : [ SenseInfo('02159890-v', 1), SenseInfo('02764765-v', 0) ],
"_seize_v_upon_rel" : [ SenseInfo('01212572-v', 13), SenseInfo('01213614-v', 5), SenseInfo('02272549-v', 4), SenseInfo('02273293-v', 3), SenseInfo('02274482-v', 0), SenseInfo('01365839-v', 0), SenseInfo('00737656-v', 0), SenseInfo('00737476-v', 0) ],
"_pillow_n_1_rel" : [ SenseInfo('03938244-n', 8) ],
"_pump_v_in_rel" : [ SenseInfo('01225684-v', 4), SenseInfo('01155307-v', 3), SenseInfo('01853310-v', 1), SenseInfo('02356113-v', 0), SenseInfo('02068324-v', 0), SenseInfo('01853192-v', 0), SenseInfo('01853069-v', 0), SenseInfo('00788057-v', 0), SenseInfo('01225684-v', 4), SenseInfo('01155307-v', 3), SenseInfo('01853310-v', 1), SenseInfo('02356113-v', 0), SenseInfo('02068324-v', 0), SenseInfo('01853192-v', 0), SenseInfo('01853069-v', 0), SenseInfo('00788057-v', 0) ],
"_hole_v_up_rel" : [ SenseInfo('01408153-v', 0), SenseInfo('01282023-v', 0), SenseInfo('01408153-v', 0), SenseInfo('01282023-v', 0) ],
"_sharpen_v_cause_rel" : [ SenseInfo('01246601-v', 1), SenseInfo('00392426-v', 1), SenseInfo('00392314-v', 1), SenseInfo('00314272-v', 1), SenseInfo('02190786-v', 0), SenseInfo('00393398-v', 0), SenseInfo('00392960-v', 0), SenseInfo('00392588-v', 0) ],
"_coupon_n_1_rel" : [ SenseInfo('06518068-n', 1), SenseInfo('05822001-n', 1) ],
"_quaint_a_1_rel" : [ SenseInfo('00969556-a', 3), SenseInfo('00969763-a', 1), SenseInfo('00973192-a', 0), SenseInfo('00969556-a', 3), SenseInfo('00969763-a', 1), SenseInfo('00973192-a', 0), SenseInfo('00969556-a', 3), SenseInfo('00969763-a', 1), SenseInfo('00973192-a', 0) ],
"_aqueous_a_1_rel" : [ SenseInfo('02636461-a', 14), SenseInfo('01355089-a', 0) ],
"_correlate_n_1_rel" : [ SenseInfo('05858407-n', 0) ],
"_dimensionality_n_1_rel" : [ SenseInfo('05062993-n', 0) ],
"_populate_v_1_rel" : [ SenseInfo('02649830-v', 7), SenseInfo('00451279-v', 0) ],
"_take_v_apart_rel" : [ SenseInfo('02599636-v', 92), SenseInfo('02267989-v', 74), SenseInfo('01999798-v', 73), SenseInfo('01214265-v', 50), SenseInfo('00524682-v', 38), SenseInfo('00624476-v', 36), SenseInfo('02077656-v', 32), SenseInfo('02205272-v', 28), SenseInfo('01842690-v', 26), SenseInfo('00674607-v', 26), SenseInfo('02236124-v', 25), SenseInfo('02394183-v', 22), SenseInfo('00734054-v', 22), SenseInfo('02627934-v', 21), SenseInfo('02109045-v', 21), SenseInfo('01002740-v', 16), SenseInfo('00173338-v', 16), SenseInfo('01156834-v', 15), SenseInfo('00669762-v', 15), SenseInfo('02209936-v', 14), SenseInfo('02206619-v', 13), SenseInfo('01982395-v', 10), SenseInfo('02236624-v', 8), SenseInfo('00523095-v', 7), SenseInfo('00599992-v', 6), SenseInfo('00756076-v', 5), SenseInfo('02075857-v', 4), SenseInfo('01151110-v', 4), SenseInfo('00557404-v', 4), SenseInfo('02717102-v', 2), SenseInfo('02208537-v', 2), SenseInfo('02209745-v', 1), SenseInfo('02208118-v', 1), SenseInfo('02201138-v', 1), SenseInfo('01427127-v', 1), SenseInfo('00758333-v', 1), SenseInfo('02741546-v', 0), SenseInfo('02701210-v', 0), SenseInfo('02590253-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01100830-v', 0), SenseInfo('00087736-v', 0) ],
"_conventional_a_1_rel" : [ SenseInfo('00605516-a', 12), SenseInfo('01690606-a', 2), SenseInfo('00610861-a', 1), SenseInfo('00607421-a', 1), SenseInfo('01980796-a', 1), SenseInfo('00611281-a', 1), SenseInfo('01042703-a', 0), SenseInfo('00605516-a', 12), SenseInfo('01690606-a', 2), SenseInfo('00610861-a', 1), SenseInfo('00607421-a', 1), SenseInfo('01980796-a', 1), SenseInfo('00611281-a', 1), SenseInfo('01042703-a', 0) ],
"_seaside_n_1_rel" : [ SenseInfo('09428628-n', 0), SenseInfo('09428628-n', 0) ],
"_guarantee_v_1_rel" : [ SenseInfo('00890100-v', 8), SenseInfo('00890590-v', 2), SenseInfo('00889555-v', 2), SenseInfo('00891936-v', 1), SenseInfo('00890100-v', 8), SenseInfo('00890590-v', 2), SenseInfo('00889555-v', 2), SenseInfo('00891936-v', 1), SenseInfo('00890100-v', 8), SenseInfo('00890590-v', 2), SenseInfo('00889555-v', 2), SenseInfo('00891936-v', 1), SenseInfo('00890100-v', 8), SenseInfo('00890590-v', 2), SenseInfo('00889555-v', 2), SenseInfo('00891936-v', 1), SenseInfo('00890100-v', 8), SenseInfo('00890590-v', 2), SenseInfo('00889555-v', 2), SenseInfo('00891936-v', 1), SenseInfo('00890100-v', 8), SenseInfo('00890590-v', 2), SenseInfo('00889555-v', 2), SenseInfo('00891936-v', 1) ],
"_bring_v_to_rel" : [ SenseInfo('02077656-v', 122), SenseInfo('01438902-v', 55), SenseInfo('01629589-v', 31), SenseInfo('01433294-v', 19), SenseInfo('00135857-v', 9), SenseInfo('01434140-v', 4), SenseInfo('01618547-v', 3), SenseInfo('02324478-v', 2), SenseInfo('02247390-v', 1), SenseInfo('01808218-v', 0), SenseInfo('00767334-v', 0) ],
"_float_v_1_rel" : [ SenseInfo('01902783-v', 14), SenseInfo('01904293-v', 4), SenseInfo('01874568-v', 3), SenseInfo('02532079-v', 0), SenseInfo('01838651-v', 0), SenseInfo('01514887-v', 0), SenseInfo('01361998-v', 0), SenseInfo('00696042-v', 0), SenseInfo('00566181-v', 0), SenseInfo('01902783-v', 14), SenseInfo('01904293-v', 4), SenseInfo('01874568-v', 3), SenseInfo('02532079-v', 0), SenseInfo('01838651-v', 0), SenseInfo('01514887-v', 0), SenseInfo('01361998-v', 0), SenseInfo('00696042-v', 0), SenseInfo('00566181-v', 0) ],
"minus_c_rel" : [  ],
"_plus_p_rel" : [ SenseInfo('01819390-a', 0), SenseInfo('05154517-n', 0), SenseInfo('00872107-n', 0), SenseInfo('00065064-a', 0) ],
"_nibble_v_on_rel" : [ SenseInfo('01446729-v', 0), SenseInfo('01446420-v', 0), SenseInfo('01174294-v', 0) ],
"_norm_n_1_rel" : [ SenseInfo('13854488-n', 9), SenseInfo('06021761-n', 3) ],
"_arranger_n_of_rel" : [ SenseInfo('10383237-n', 0), SenseInfo('09809925-n', 0) ],
"_chill_n_1_rel" : [ SenseInfo('05015463-n', 3), SenseInfo('07520112-n', 2), SenseInfo('14340287-n', 1), SenseInfo('07537259-n', 0) ],
"_indonesian_n_1_rel" : [ SenseInfo('09714264-n', 0), SenseInfo('06939198-n', 0) ],
"_flooring_n_1_rel" : [ SenseInfo('03365592-n', 1), SenseInfo('14871370-n', 0) ],
"_snakebite_n_1_rel" : [ SenseInfo('14287647-n', 0) ],
"_bud_v_1_rel" : [ SenseInfo('00357998-v', 2), SenseInfo('00345652-v', 1) ],
"_treat_n_1_rel" : [ SenseInfo('07557165-n', 0), SenseInfo('07289358-n', 0) ],
"_scrape_v_out_rel" : [ SenseInfo('01308160-v', 4), SenseInfo('01750156-v', 1), SenseInfo('01309143-v', 1), SenseInfo('02040709-v', 0), SenseInfo('01384752-v', 0), SenseInfo('01309478-v', 0) ],
"_flat_n_1_rel" : [ SenseInfo('09281411-n', 2), SenseInfo('03360038-n', 1), SenseInfo('06866919-n', 0), SenseInfo('03360731-n', 0), SenseInfo('03359950-n', 0), SenseInfo('03359755-n', 0), SenseInfo('02726305-n', 0) ],
"_harvest_n_1_rel" : [ SenseInfo('13085864-n', 2), SenseInfo('11414257-n', 0), SenseInfo('01015310-n', 0), SenseInfo('00921790-n', 0) ],
"_matchbook_n_1_rel" : [ SenseInfo('03729308-n', 0) ],
"_individual_a_1_rel" : [ SenseInfo('00493460-a', 38), SenseInfo('00729246-a', 8), SenseInfo('02153174-a', 4), SenseInfo('01768086-a', 2), SenseInfo('00493460-a', 38), SenseInfo('00729246-a', 8), SenseInfo('02153174-a', 4), SenseInfo('01768086-a', 2) ],
"_timewise_a_1_rel" : [  ],
"_machine_n_1_rel" : [ SenseInfo('03699975-n', 33), SenseInfo('10278666-n', 2), SenseInfo('08264759-n', 2), SenseInfo('03700963-n', 1), SenseInfo('08264583-n', 0), SenseInfo('02958343-n', 0) ],
"_paren+stranded+left_a_1_rel" : [  ],
"_sidewinder_n_1_rel" : [ SenseInfo('01756291-n', 1), SenseInfo('04215910-n', 0) ],
"_wink_v_1_rel" : [ SenseInfo('00008299-v', 10), SenseInfo('02159890-v', 3), SenseInfo('00007739-v', 1), SenseInfo('00008435-v', 0) ],
"_purge_v_of_rel" : [ SenseInfo('02565090-v', 1), SenseInfo('00905283-v', 0), SenseInfo('00475819-v', 0), SenseInfo('00475647-v', 0), SenseInfo('00455529-v', 0), SenseInfo('00076400-v', 0), SenseInfo('00073813-v', 0) ],
"_inquiry_n_1_rel" : [ SenseInfo('05797597-n', 4), SenseInfo('07193596-n', 3), SenseInfo('00636728-n', 2) ],
"_mutual_a_1_rel" : [ SenseInfo('02152473-a', 3), SenseInfo('01945550-a', 0), SenseInfo('02152473-a', 3), SenseInfo('01945550-a', 0) ],
"_delay_v_1_rel" : [ SenseInfo('00459776-v', 8), SenseInfo('02641957-v', 6), SenseInfo('00460900-v', 3), SenseInfo('00440286-v', 0) ],
"_embellishment_n_1_rel" : [ SenseInfo('07172979-n', 0), SenseInfo('03282401-n', 0), SenseInfo('00262743-n', 0) ],
"_merry_a_1_rel" : [ SenseInfo('01367651-a', 4), SenseInfo('01367431-a', 1), SenseInfo('00874226-a', 0), SenseInfo('01367651-a', 4), SenseInfo('01367431-a', 1), SenseInfo('00874226-a', 0), SenseInfo('01367651-a', 4), SenseInfo('01367431-a', 1), SenseInfo('00874226-a', 0) ],
"_foreign_a_1_rel" : [ SenseInfo('01037540-a', 20), SenseInfo('01034457-a', 10), SenseInfo('01349927-a', 4), SenseInfo('02117464-a', 1) ],
"_displacement_n_1_rel" : [ SenseInfo('00197610-n', 2), SenseInfo('07444668-n', 1), SenseInfo('00330984-n', 1), SenseInfo('13467224-n', 0), SenseInfo('13467009-n', 0), SenseInfo('00315830-n', 0), SenseInfo('00209446-n', 0) ],
"_electrochemical_a_1_rel" : [ SenseInfo('02717784-a', 0) ],
"_eternal_a_1_rel" : [ SenseInfo('01755024-a', 9), SenseInfo('01439784-a', 1) ],
"_feel_v_1_rel" : [ SenseInfo('01771535-v', 181), SenseInfo('00715239-v', 150), SenseInfo('02106006-v', 66), SenseInfo('00105958-v', 39), SenseInfo('00690305-v', 37), SenseInfo('02110552-v', 34), SenseInfo('02730471-v', 14), SenseInfo('02127613-v', 5), SenseInfo('01209678-v', 4), SenseInfo('01210352-v', 3), SenseInfo('02286027-v', 1), SenseInfo('02134350-v', 0), SenseInfo('01210152-v', 0), SenseInfo('01771535-v', 181), SenseInfo('00715239-v', 150), SenseInfo('02106006-v', 66), SenseInfo('00105958-v', 39), SenseInfo('00690305-v', 37), SenseInfo('02110552-v', 34), SenseInfo('02730471-v', 14), SenseInfo('02127613-v', 5), SenseInfo('01209678-v', 4), SenseInfo('01210352-v', 3), SenseInfo('02286027-v', 1), SenseInfo('02134350-v', 0), SenseInfo('01210152-v', 0), SenseInfo('01771535-v', 181), SenseInfo('00715239-v', 150), SenseInfo('02106006-v', 66), SenseInfo('00105958-v', 39), SenseInfo('00690305-v', 37), SenseInfo('02110552-v', 34), SenseInfo('02730471-v', 14), SenseInfo('02127613-v', 5), SenseInfo('01209678-v', 4), SenseInfo('01210352-v', 3), SenseInfo('02286027-v', 1), SenseInfo('02134350-v', 0), SenseInfo('01210152-v', 0), SenseInfo('01771535-v', 181), SenseInfo('00715239-v', 150), SenseInfo('02106006-v', 66), SenseInfo('00105958-v', 39), SenseInfo('00690305-v', 37), SenseInfo('02110552-v', 34), SenseInfo('02730471-v', 14), SenseInfo('02127613-v', 5), SenseInfo('01209678-v', 4), SenseInfo('01210352-v', 3), SenseInfo('02286027-v', 1), SenseInfo('02134350-v', 0), SenseInfo('01210152-v', 0), SenseInfo('01771535-v', 181), SenseInfo('00715239-v', 150), SenseInfo('02106006-v', 66), SenseInfo('00105958-v', 39), SenseInfo('00690305-v', 37), SenseInfo('02110552-v', 34), SenseInfo('02730471-v', 14), SenseInfo('02127613-v', 5), SenseInfo('01209678-v', 4), SenseInfo('01210352-v', 3), SenseInfo('02286027-v', 1), SenseInfo('02134350-v', 0), SenseInfo('01210152-v', 0), SenseInfo('01771535-v', 181), SenseInfo('00715239-v', 150), SenseInfo('02106006-v', 66), SenseInfo('00105958-v', 39), SenseInfo('00690305-v', 37), SenseInfo('02110552-v', 34), SenseInfo('02730471-v', 14), SenseInfo('02127613-v', 5), SenseInfo('01209678-v', 4), SenseInfo('01210352-v', 3), SenseInfo('02286027-v', 1), SenseInfo('02134350-v', 0), SenseInfo('01210152-v', 0) ],
"_copper_v_i_rel" : [ SenseInfo('01265880-v', 0) ],
"_boast_v_about_rel" : [ SenseInfo('00883226-v', 7), SenseInfo('02631659-v', 6) ],
"_unoccupied_a_1_rel" : [ SenseInfo('01623836-a', 2), SenseInfo('01624403-a', 0), SenseInfo('01313346-a', 0), SenseInfo('01623836-a', 2), SenseInfo('01624403-a', 0), SenseInfo('01313346-a', 0) ],
"_blow_v_on_rel" : [ SenseInfo('00007012-v', 6), SenseInfo('02769241-v', 5), SenseInfo('00034948-v', 3), SenseInfo('01902783-v', 2), SenseInfo('02135877-v', 1), SenseInfo('00477247-v', 1), SenseInfo('02527651-v', 0), SenseInfo('02268351-v', 0), SenseInfo('02266148-v', 0), SenseInfo('02178340-v', 0), SenseInfo('02135727-v', 0), SenseInfo('02117170-v', 0), SenseInfo('02101046-v', 0), SenseInfo('02100632-v', 0), SenseInfo('02068745-v', 0), SenseInfo('01849054-v', 0), SenseInfo('01545208-v', 0), SenseInfo('00934965-v', 0), SenseInfo('00883226-v', 0), SenseInfo('00779804-v', 0), SenseInfo('00435294-v', 0), SenseInfo('00310155-v', 0) ],
"_chilean_a_1_rel" : [ SenseInfo('02965985-a', 0) ],
"_highlight_n_1_rel" : [ SenseInfo('13810141-n', 0), SenseInfo('04952120-n', 0) ],
"_semicolumn_n_1_rel" : [  ],
"_third+person_n_1_rel" : [ SenseInfo('06328022-n', 1), SenseInfo('06328022-n', 1) ],
"_damages_n_1_rel" : [ SenseInfo('07420770-n', 11), SenseInfo('07339653-n', 1), SenseInfo('00403092-n', 1), SenseInfo('13303315-n', 0), SenseInfo('00744131-n', 0), SenseInfo('07420770-n', 11), SenseInfo('07339653-n', 1), SenseInfo('00403092-n', 1), SenseInfo('13303315-n', 0), SenseInfo('00744131-n', 0), SenseInfo('07420770-n', 11), SenseInfo('07339653-n', 1), SenseInfo('00403092-n', 1), SenseInfo('13303315-n', 0), SenseInfo('00744131-n', 0), SenseInfo('07420770-n', 11), SenseInfo('07339653-n', 1), SenseInfo('00403092-n', 1), SenseInfo('13303315-n', 0), SenseInfo('00744131-n', 0) ],
"_spunky_a_1_rel" : [ SenseInfo('02279900-a', 0), SenseInfo('00263994-a', 0) ],
"_brainstorm_n_1_rel" : [ SenseInfo('05807306-n', 0) ],
"_agonize_v_1_rel" : [ SenseInfo('01794523-v', 0), SenseInfo('01794363-v', 0) ],
"_wear_v_off_rel" : [ SenseInfo('00052374-v', 83), SenseInfo('00047745-v', 22), SenseInfo('02740034-v', 6), SenseInfo('00469382-v', 2), SenseInfo('00047610-v', 2), SenseInfo('02705132-v', 1), SenseInfo('01369346-v', 0), SenseInfo('00075021-v', 0), SenseInfo('00050652-v', 0) ],
"_flatten_v_1_rel" : [ SenseInfo('00463778-v', 6), SenseInfo('00463469-v', 1), SenseInfo('00393534-v', 0) ],
"_wash_v_1_rel" : [ SenseInfo('01270199-v', 13), SenseInfo('00036362-v', 9), SenseInfo('01535246-v', 7), SenseInfo('02098179-v', 2), SenseInfo('02742842-v', 0), SenseInfo('02703153-v', 0), SenseInfo('01536344-v', 0), SenseInfo('01269844-v', 0), SenseInfo('00557686-v', 0), SenseInfo('00274942-v', 0), SenseInfo('00217956-v', 0), SenseInfo('00217576-v', 0), SenseInfo('00036178-v', 0), SenseInfo('01270199-v', 13), SenseInfo('00036362-v', 9), SenseInfo('01535246-v', 7), SenseInfo('02098179-v', 2), SenseInfo('02742842-v', 0), SenseInfo('02703153-v', 0), SenseInfo('01536344-v', 0), SenseInfo('01269844-v', 0), SenseInfo('00557686-v', 0), SenseInfo('00274942-v', 0), SenseInfo('00217956-v', 0), SenseInfo('00217576-v', 0), SenseInfo('00036178-v', 0) ],
"_veil_n_1_rel" : [ SenseInfo('03502331-n', 2), SenseInfo('13094556-n', 0), SenseInfo('05310596-n', 0), SenseInfo('03548930-n', 0) ],
"_welcome_a_1_rel" : [ SenseInfo('02539968-a', 4) ],
"_speed_v_1_rel" : [ SenseInfo('02058994-v', 7), SenseInfo('00438178-v', 5), SenseInfo('02055649-v', 3), SenseInfo('02055975-v', 2), SenseInfo('00439343-v', 1), SenseInfo('02058994-v', 7), SenseInfo('00438178-v', 5), SenseInfo('02055649-v', 3), SenseInfo('02055975-v', 2), SenseInfo('00439343-v', 1) ],
"_pantomime_v_1_rel" : [ SenseInfo('01724185-v', 1) ],
"_humpback_n_1_rel" : [ SenseInfo('14505069-n', 0), SenseInfo('10192412-n', 0), SenseInfo('02065726-n', 0) ],
"_tour+de+force_n_1_rel" : [ SenseInfo('00047018-n', 1) ],
"_selectivity_n_1_rel" : [ SenseInfo('05208988-n', 0) ],
"_less+than_x_deg_rel" : [  ],
"_crevice_n_1_rel" : [ SenseInfo('13907272-n', 1), SenseInfo('09258715-n', 0) ],
"_costa+rican_a_1_rel" : [ SenseInfo('03056693-a', 0) ],
"_currently_x_deg_rel" : [ SenseInfo('00048268-r', 4) ],
"_as+long+as_x_rel" : [  ],
"_fivefold_a_1_rel" : [ SenseInfo('02219660-a', 0), SenseInfo('02219660-a', 0) ],
"_armrest_n_1_rel" : [ SenseInfo('02741475-n', 0) ],
"_snorkel_n_1_rel" : [ SenseInfo('04251144-n', 0), SenseInfo('04250850-n', 0) ],
"_bismuth_n_1_rel" : [ SenseInfo('14631502-n', 0) ],
"_snout_n_1_rel" : [ SenseInfo('02452637-n', 1), SenseInfo('05598707-n', 0), SenseInfo('02452813-n', 0) ],
"_armor_n_1_rel" : [ SenseInfo('02739668-n', 2), SenseInfo('08197742-n', 0), SenseInfo('01902750-n', 0), SenseInfo('02739668-n', 2), SenseInfo('08197742-n', 0), SenseInfo('01902750-n', 0) ],
"_split_n_1_rel" : [ SenseInfo('00437929-n', 5), SenseInfo('13770076-n', 0), SenseInfo('13286640-n', 0), SenseInfo('09443136-n', 0), SenseInfo('09410928-n', 0), SenseInfo('08819016-n', 0), SenseInfo('07616590-n', 0), SenseInfo('04282664-n', 0), SenseInfo('00439043-n', 0), SenseInfo('00391407-n', 0), SenseInfo('00386676-n', 0) ],
"_and_p_rel" : [  ],
"_nutty_a_1_rel" : [ SenseInfo('02398255-a', 0), SenseInfo('02074929-a', 0), SenseInfo('02398255-a', 0), SenseInfo('02074929-a', 0), SenseInfo('02398255-a', 0), SenseInfo('02074929-a', 0) ],
"_paw_v_1_rel" : [ SenseInfo('01211455-v', 1), SenseInfo('01211098-v', 1), SenseInfo('01211455-v', 1), SenseInfo('01211098-v', 1) ],
"_let_v_in_rel" : [ SenseInfo('02423183-v', 219), SenseInfo('00771490-v', 15), SenseInfo('00802318-v', 2), SenseInfo('00120796-v', 2), SenseInfo('00496673-v', 1), SenseInfo('02208903-v', 0) ],
"_flowery_a_1_rel" : [ SenseInfo('02729665-a', 0), SenseInfo('02017141-a', 0), SenseInfo('02729665-a', 0), SenseInfo('02017141-a', 0), SenseInfo('02729665-a', 0), SenseInfo('02017141-a', 0) ],
"_proxy_n_1_rel" : [ SenseInfo('10486909-n', 0), SenseInfo('06531141-n', 0) ],
"_oily_a_1_rel" : [ SenseInfo('00992432-a', 4), SenseInfo('02181432-a', 1), SenseInfo('01699838-a', 1), SenseInfo('00422168-a', 0), SenseInfo('00992432-a', 4), SenseInfo('02181432-a', 1), SenseInfo('01699838-a', 1), SenseInfo('00422168-a', 0), SenseInfo('00992432-a', 4), SenseInfo('02181432-a', 1), SenseInfo('01699838-a', 1), SenseInfo('00422168-a', 0) ],
"_civilian_a_1_rel" : [ SenseInfo('01517921-a', 8) ],
"_poise_n_1_rel" : [ SenseInfo('13715240-n', 2), SenseInfo('14003880-n', 0), SenseInfo('04904162-n', 0) ],
"_right+to+left_p_rel" : [  ],
"_circular_a_1_rel" : [ SenseInfo('02040652-a', 6), SenseInfo('00676271-a', 0), SenseInfo('02040652-a', 6), SenseInfo('00676271-a', 0) ],
"_raft_n_1_rel" : [ SenseInfo('04045397-n', 2), SenseInfo('13774404-n', 0) ],
"_get_v_down_rel" : [ SenseInfo('02210855-v', 235), SenseInfo('00149583-v', 157), SenseInfo('00120796-v', 82), SenseInfo('00522751-v', 64), SenseInfo('02005948-v', 58), SenseInfo('01433294-v', 45), SenseInfo('02108026-v', 36), SenseInfo('01153947-v', 14), SenseInfo('02355596-v', 9), SenseInfo('00770437-v', 7), SenseInfo('01215421-v', 4), SenseInfo('00094460-v', 4), SenseInfo('00087736-v', 4), SenseInfo('01066036-v', 3), SenseInfo('00120316-v', 3), SenseInfo('01026975-v', 2), SenseInfo('00589904-v', 2), SenseInfo('01505958-v', 1), SenseInfo('01401115-v', 1), SenseInfo('00639849-v', 1), SenseInfo('02359340-v', 0), SenseInfo('02208265-v', 0), SenseInfo('02189398-v', 0), SenseInfo('02109645-v', 0), SenseInfo('02108654-v', 0), SenseInfo('02010864-v', 0), SenseInfo('02006573-v', 0), SenseInfo('01771194-v', 0), SenseInfo('01771039-v', 0), SenseInfo('01738107-v', 0), SenseInfo('01643297-v', 0), SenseInfo('01565211-v', 0), SenseInfo('00622384-v', 0), SenseInfo('00345761-v', 0), SenseInfo('00065639-v', 0), SenseInfo('00054628-v', 0) ],
"_herringbone_n_1_rel" : [ SenseInfo('03516266-n', 1), SenseInfo('03516367-n', 0) ],
"_pace_n_1_rel" : [ SenseInfo('15280497-n', 10), SenseInfo('13757249-n', 6), SenseInfo('05058580-n', 4), SenseInfo('00285889-n', 1), SenseInfo('15283097-n', 0), SenseInfo('13650447-n', 0), SenseInfo('15280497-n', 10), SenseInfo('13757249-n', 6), SenseInfo('05058580-n', 4), SenseInfo('00285889-n', 1), SenseInfo('15283097-n', 0), SenseInfo('13650447-n', 0) ],
"_screw_n_1_rel" : [ SenseInfo('10149867-n', 0), SenseInfo('04154340-n', 0), SenseInfo('04154152-n', 0), SenseInfo('04153751-n', 0), SenseInfo('00846021-n', 0) ],
"_invite_v_to_rel" : [ SenseInfo('01760143-v', 7), SenseInfo('02384686-v', 6), SenseInfo('01807529-v', 6), SenseInfo('00793580-v', 6), SenseInfo('02384940-v', 3), SenseInfo('01469770-v', 2), SenseInfo('01063695-v', 2), SenseInfo('01470225-v', 0), SenseInfo('01760143-v', 7), SenseInfo('02384686-v', 6), SenseInfo('01807529-v', 6), SenseInfo('00793580-v', 6), SenseInfo('02384940-v', 3), SenseInfo('01469770-v', 2), SenseInfo('01063695-v', 2), SenseInfo('01470225-v', 0), SenseInfo('01760143-v', 7), SenseInfo('02384686-v', 6), SenseInfo('01807529-v', 6), SenseInfo('00793580-v', 6), SenseInfo('02384940-v', 3), SenseInfo('01469770-v', 2), SenseInfo('01063695-v', 2), SenseInfo('01470225-v', 0) ],
"_make-believe_n_1_rel" : [ SenseInfo('05769930-n', 0), SenseInfo('00755500-n', 0), SenseInfo('05769930-n', 0), SenseInfo('00755500-n', 0), SenseInfo('05769930-n', 0), SenseInfo('00755500-n', 0), SenseInfo('05769930-n', 0), SenseInfo('00755500-n', 0) ],
"_elbow_n_1_rel" : [ SenseInfo('05579944-n', 9), SenseInfo('03268470-n', 1), SenseInfo('03268553-n', 0), SenseInfo('03268311-n', 0), SenseInfo('02468368-n', 0) ],
"_flavour_v_1_rel" : [ SenseInfo('02191766-v', 0) ],
"_spear_v_1_rel" : [ SenseInfo('01444887-v', 3), SenseInfo('02714200-v', 0) ],
"_follow+up_n_1_rel" : [ SenseInfo('03377582-n', 0), SenseInfo('00455348-n', 0), SenseInfo('00143251-n', 0), SenseInfo('03377582-n', 0), SenseInfo('00455348-n', 0), SenseInfo('00143251-n', 0) ],
"_impossible_n_1_rel" : [ SenseInfo('05792446-n', 1) ],
"_annals_n_1_rel" : [ SenseInfo('06597617-n', 0), SenseInfo('06515662-n', 0), SenseInfo('06597617-n', 0), SenseInfo('06515662-n', 0) ],
"_bluster_n_1_rel" : [ SenseInfo('13976182-n', 2), SenseInfo('06889591-n', 1), SenseInfo('11465297-n', 0), SenseInfo('07230089-n', 0) ],
"_list_v_2_rel" : [ SenseInfo('00945853-v', 23), SenseInfo('02472223-v', 19), SenseInfo('02039013-v', 0), SenseInfo('02038791-v', 0), SenseInfo('00946755-v', 0) ],
"_transcriber_n_1_rel" : [ SenseInfo('10725280-n', 0), SenseInfo('10724272-n', 0), SenseInfo('10724132-n', 0), SenseInfo('10723984-n', 0), SenseInfo('09809925-n', 0) ],
"_slaver_v_1_rel" : [ SenseInfo('00102974-v', 1) ],
"_siren_n_1_rel" : [ SenseInfo('10601840-n', 0), SenseInfo('10055410-n', 0), SenseInfo('07265789-n', 0), SenseInfo('04224395-n', 0), SenseInfo('01639187-n', 0) ],
"_polytechnic_a_1_rel" : [ SenseInfo('08285407-n', 0) ],
"_routine_n_1_rel" : [ SenseInfo('01026482-n', 10), SenseInfo('06892016-n', 2), SenseInfo('06582403-n', 1) ],
"_high_n_1_rel" : [ SenseInfo('05097536-n', 5), SenseInfo('14520670-n', 0), SenseInfo('14405621-n', 0), SenseInfo('14405452-n', 0), SenseInfo('08584618-n', 0), SenseInfo('08409617-n', 0), SenseInfo('03518631-n', 0), SenseInfo('05097536-n', 5), SenseInfo('14520670-n', 0), SenseInfo('14405621-n', 0), SenseInfo('14405452-n', 0), SenseInfo('08584618-n', 0), SenseInfo('08409617-n', 0), SenseInfo('03518631-n', 0) ],
"_arterial_a_1_rel" : [ SenseInfo('02641856-a', 6) ],
"_communism_n_1_rel" : [ SenseInfo('08365855-n', 35), SenseInfo('06214744-n', 4) ],
"_ion_n_1_rel" : [ SenseInfo('09315159-n', 8) ],
"_charge_v_with_rel" : [ SenseInfo('01121719-v', 16), SenseInfo('00843468-v', 10), SenseInfo('02320374-v', 7), SenseInfo('02055267-v', 6), SenseInfo('02475922-v', 4), SenseInfo('00869931-v', 3), SenseInfo('00843959-v', 3), SenseInfo('01488956-v', 2), SenseInfo('02321046-v', 1), SenseInfo('02348568-v', 0), SenseInfo('02347637-v', 0), SenseInfo('02317289-v', 0), SenseInfo('01985424-v', 0), SenseInfo('01762528-v', 0), SenseInfo('01685960-v', 0), SenseInfo('01490336-v', 0), SenseInfo('01152214-v', 0), SenseInfo('00750532-v', 0), SenseInfo('00750345-v', 0), SenseInfo('00750172-v', 0), SenseInfo('00727991-v', 0), SenseInfo('00700517-v', 0), SenseInfo('00518115-v', 0), SenseInfo('00517847-v', 0), SenseInfo('00498016-v', 0) ],
"_activate_v_1_rel" : [ SenseInfo('01643657-v', 3), SenseInfo('00190682-v', 2), SenseInfo('00191385-v', 0), SenseInfo('00190999-v', 0), SenseInfo('00190886-v', 0) ],
"_hop_n_1_rel" : [ SenseInfo('00120010-n', 1), SenseInfo('12397864-n', 0), SenseInfo('07449548-n', 0) ],
"_correlative_a_1_rel" : [ SenseInfo('01974298-a', 0), SenseInfo('01946267-a', 0) ],
"_precisely_x_deg_rel" : [ SenseInfo('00158309-r', 20), SenseInfo('00368287-r', 4), SenseInfo('00368663-r', 3) ],
"_oracle_n_1_rel" : [ SenseInfo('10483530-n', 0), SenseInfo('06750339-n', 0), SenseInfo('03852908-n', 0) ],
"_herd_v_1_rel" : [ SenseInfo('02028722-v', 1), SenseInfo('02028616-v', 1), SenseInfo('02652158-v', 0), SenseInfo('02028722-v', 1), SenseInfo('02028616-v', 1), SenseInfo('02652158-v', 0) ],
"_salon_n_1_rel" : [ SenseInfo('04131113-n', 2), SenseInfo('04131208-n', 0), SenseInfo('04131015-n', 0) ],
"_bloke_n_1_rel" : [ SenseInfo('09908025-n', 1) ],
"_excite_v_1_rel" : [ SenseInfo('01772960-v', 8), SenseInfo('00503164-v', 4), SenseInfo('02116118-v', 0), SenseInfo('01762528-v', 0), SenseInfo('01762283-v', 0), SenseInfo('01761706-v', 0), SenseInfo('00559102-v', 0), SenseInfo('00558963-v', 0), SenseInfo('01772960-v', 8), SenseInfo('00503164-v', 4), SenseInfo('02116118-v', 0), SenseInfo('01762528-v', 0), SenseInfo('01762283-v', 0), SenseInfo('01761706-v', 0), SenseInfo('00559102-v', 0), SenseInfo('00558963-v', 0), SenseInfo('01772960-v', 8), SenseInfo('00503164-v', 4), SenseInfo('02116118-v', 0), SenseInfo('01762528-v', 0), SenseInfo('01762283-v', 0), SenseInfo('01761706-v', 0), SenseInfo('00559102-v', 0), SenseInfo('00558963-v', 0), SenseInfo('01772960-v', 8), SenseInfo('00503164-v', 4), SenseInfo('02116118-v', 0), SenseInfo('01762528-v', 0), SenseInfo('01762283-v', 0), SenseInfo('01761706-v', 0), SenseInfo('00559102-v', 0), SenseInfo('00558963-v', 0) ],
"_about-face_n_1_rel" : [ SenseInfo('00346936-n', 0), SenseInfo('00163406-n', 0), SenseInfo('00346936-n', 0), SenseInfo('00163406-n', 0) ],
"_mean_n_1_rel" : [ SenseInfo('06023969-n', 10) ],
"_the+fuck_x_rel" : [ SenseInfo('00846021-n', 0), SenseInfo('01426397-v', 0) ],
"_coward_n_1_rel" : [ SenseInfo('09614047-n', 4), SenseInfo('10913641-n', 0) ],
"_bore_v_1_rel" : [ SenseInfo('01821884-v', 7), SenseInfo('01443021-v', 4), SenseInfo('01821884-v', 7), SenseInfo('01443021-v', 4), SenseInfo('01821884-v', 7), SenseInfo('01443021-v', 4), SenseInfo('01821884-v', 7), SenseInfo('01443021-v', 4) ],
"_pistol_n_1_rel" : [ SenseInfo('03948459-n', 17) ],
"_deviant_a_1_rel" : [ SenseInfo('01596122-a', 1) ],
"_defiant_a_1_rel" : [ SenseInfo('00695523-a', 2) ],
"_inexperienced_a_1_rel" : [ SenseInfo('00936740-a', 3) ],
"_workout_n_1_rel" : [ SenseInfo('00624738-n', 6) ],
"_accord_v_with_rel" : [ SenseInfo('02700104-v', 20), SenseInfo('02255268-v', 5) ],
"_centennial_n_1_rel" : [ SenseInfo('15251336-n', 1) ],
"_singe_v_cause_rel" : [ SenseInfo('00378521-v', 1), SenseInfo('00582743-v', 0) ],
"_mexican_a_1_rel" : [ SenseInfo('03026902-a', 4) ],
"_these_q_dem_rel" : [  ],
"_antics_n_1_rel" : [ SenseInfo('00427580-n', 0) ],
"_broad_n_1_rel" : [ SenseInfo('09875663-n', 0) ],
"_muscle_v_1_rel" : [ SenseInfo('02019431-v', 0), SenseInfo('02019431-v', 0) ],
"_conjugate_v_1_rel" : [ SenseInfo('00396513-v', 1), SenseInfo('00983123-v', 0), SenseInfo('00574218-v', 0) ],
"_permeate_v_1_rel" : [ SenseInfo('01229071-v', 2), SenseInfo('01457954-v', 0), SenseInfo('01227235-v', 0) ],
"_pilfer_v_1_rel" : [ SenseInfo('02276866-v', 2) ],
"_northwester_n_1_rel" : [ SenseInfo('11448475-n', 0) ],
"_trick+or+treat_v_1_rel" : [  ],
"_contemporary_a_1_rel" : [ SenseInfo('01536094-a', 10), SenseInfo('00667079-a', 5), SenseInfo('02378872-a', 1), SenseInfo('01536094-a', 10), SenseInfo('00667079-a', 5), SenseInfo('02378872-a', 1) ],
"_antagonize_v_1_rel" : [ SenseInfo('01807314-v', 2), SenseInfo('02564841-v', 0) ],
"_choice_n_of_rel" : [ SenseInfo('05790242-n', 11), SenseInfo('00161243-n', 8), SenseInfo('05790944-n', 3), SenseInfo('05790242-n', 11), SenseInfo('00161243-n', 8), SenseInfo('05790944-n', 3), SenseInfo('05790242-n', 11), SenseInfo('00161243-n', 8), SenseInfo('05790944-n', 3) ],
"_perform_v_1_rel" : [ SenseInfo('01712704-v', 25), SenseInfo('02374764-v', 19), SenseInfo('01714208-v', 19), SenseInfo('02561995-v', 2) ],
"_in+fact_a_1_rel" : [  ],
"_showcase_v_1_rel" : [  ],
"_forehead_n_1_rel" : [ SenseInfo('05602548-n', 8), SenseInfo('05541231-n', 0) ],
"_ouch_a_1_rel" : [  ],
"_polish_a_1_rel" : [ SenseInfo('02961258-a', 3) ],
"_weed_v_out_rel" : [ SenseInfo('00313171-v', 0) ],
"_loudspeaker_n_1_rel" : [ SenseInfo('03691459-n', 1) ],
"_narrate_v_1_rel" : [ SenseInfo('00954271-v', 1), SenseInfo('00953216-v', 0) ],
"_such+as_p_rel" : [  ],
"_not+least_a_1_rel" : [ SenseInfo('01556061-a', 2) ],
"_four-bagger_n_1_rel" : [  ],
"_a+good+deal_x_deg_rel" : [ SenseInfo('00059171-r', 0) ],
"_refuse_n_1_rel" : [ SenseInfo('14857151-n', 1) ],
"_anthropology_n_1_rel" : [ SenseInfo('06143546-n', 2) ],
"_unselfish_a_1_rel" : [ SenseInfo('02099019-a', 1), SenseInfo('01112471-a', 0), SenseInfo('02099019-a', 1), SenseInfo('01112471-a', 0), SenseInfo('02099019-a', 1), SenseInfo('01112471-a', 0) ],
"_frequent_a_1_rel" : [ SenseInfo('01066542-a', 9), SenseInfo('00486990-a', 3), SenseInfo('01066542-a', 9), SenseInfo('00486990-a', 3), SenseInfo('01066542-a', 9), SenseInfo('00486990-a', 3), SenseInfo('01066542-a', 9), SenseInfo('00486990-a', 3), SenseInfo('01066542-a', 9), SenseInfo('00486990-a', 3) ],
"_widen_v_cause_rel" : [ SenseInfo('00303465-v', 7), SenseInfo('00303940-v', 1), SenseInfo('00303661-v', 1), SenseInfo('00540235-v', 0) ],
"_scrap_v_1_rel" : [ SenseInfo('02223238-v', 1), SenseInfo('00775156-v', 0), SenseInfo('00569870-v', 0) ],
"_rap_n_1_rel" : [ SenseInfo('06713752-n', 1), SenseInfo('07410021-n', 0), SenseInfo('07388987-n', 0), SenseInfo('07141537-n', 0), SenseInfo('07064055-n', 0), SenseInfo('00133338-n', 0) ],
"_throw_v_on_rel" : [ SenseInfo('01508368-v', 53), SenseInfo('02097204-v', 9), SenseInfo('01513430-v', 7), SenseInfo('01499265-v', 7), SenseInfo('01060317-v', 6), SenseInfo('01510173-v', 5), SenseInfo('01632897-v', 4), SenseInfo('02097341-v', 2), SenseInfo('01791232-v', 2), SenseInfo('01067664-v', 2), SenseInfo('01733477-v', 1), SenseInfo('01663443-v', 0), SenseInfo('01527754-v', 0), SenseInfo('01437011-v', 0), SenseInfo('00621734-v', 0) ],
"_sovereign_a_1_rel" : [ SenseInfo('01062393-a', 4), SenseInfo('00792641-a', 2) ],
"_slap_v_1_rel" : [ SenseInfo('01416871-v', 15) ],
"_deterioration_n_of_rel" : [ SenseInfo('14561618-n', 1), SenseInfo('13464204-n', 0) ],
"_geographical_a_1_rel" : [ SenseInfo('03021543-a', 2), SenseInfo('01470496-a', 0), SenseInfo('03021543-a', 2), SenseInfo('01470496-a', 0) ],
"_crosscut_v_1_rel" : [ SenseInfo('01601025-v', 0), SenseInfo('01601025-v', 0), SenseInfo('01601025-v', 0) ],
"_slit_n_1_rel" : [ SenseInfo('04241940-n', 5), SenseInfo('05521514-n', 1), SenseInfo('13904843-n', 0), SenseInfo('09437369-n', 0) ],
"_slim_a_1_rel" : [ SenseInfo('00990855-a', 4), SenseInfo('01394744-a', 0), SenseInfo('00990855-a', 4), SenseInfo('01394744-a', 0), SenseInfo('00990855-a', 4), SenseInfo('01394744-a', 0) ],
"_tenacity_n_1_rel" : [ SenseInfo('04864515-n', 1) ],
"_nubble_n_1_rel" : [ SenseInfo('13895622-n', 0) ],
"_valedictory_a_1_rel" : [ SenseInfo('02822229-a', 0), SenseInfo('01291098-a', 0) ],
"_yeah_a_1_rel" : [  ],
"_slighting_a_1_rel" : [ SenseInfo('00906655-a', 0) ],
"_memorial_n_1_rel" : [ SenseInfo('06688522-n', 1), SenseInfo('06513624-n', 0), SenseInfo('03743902-n', 0) ],
"_forearm_n_1_rel" : [ SenseInfo('05564323-n', 1) ],
"_convince_v_of_rel" : [ SenseInfo('00769553-v', 15), SenseInfo('00769553-v', 15), SenseInfo('00769553-v', 15), SenseInfo('00769553-v', 15), SenseInfo('00769553-v', 15), SenseInfo('00769553-v', 15) ],
"_hairpin_n_1_rel" : [ SenseInfo('03476313-n', 0), SenseInfo('03476313-n', 0) ],
"_turnaround_n_1_rel" : [ SenseInfo('15137295-n', 0), SenseInfo('05789808-n', 0), SenseInfo('04499660-n', 0), SenseInfo('01144555-n', 0), SenseInfo('00346693-n', 0), SenseInfo('15137295-n', 0), SenseInfo('05789808-n', 0), SenseInfo('04499660-n', 0), SenseInfo('01144555-n', 0), SenseInfo('00346693-n', 0) ],
"_shame_v_1_rel" : [ SenseInfo('02547225-v', 1), SenseInfo('02508078-v', 0), SenseInfo('01792287-v', 0), SenseInfo('01108053-v', 0) ],
"_span_v_1_rel" : [ SenseInfo('02685390-v', 8) ],
"_practitioner_n_1_rel" : [ SenseInfo('10462860-n', 1) ],
"_worst_a_1_rel" : [ SenseInfo('00229630-a', 9) ],
"_per+mol_p_rel" : [  ],
"_leviathan_n_1_rel" : [ SenseInfo('10255728-n', 0), SenseInfo('09496802-n', 0) ],
"_all+night+long_a_1_rel" : [  ],
"_toss_n_of_rel" : [ SenseInfo('01246086-n', 3), SenseInfo('00105820-n', 2), SenseInfo('00345817-n', 0) ],
"_peroxide_n_1_rel" : [ SenseInfo('14781225-n', 1), SenseInfo('14980087-n', 0) ],
"_push_v_down_rel" : [ SenseInfo('01871979-v', 56), SenseInfo('00765977-v', 7), SenseInfo('00976653-v', 6), SenseInfo('02406916-v', 3), SenseInfo('01872645-v', 3), SenseInfo('02054864-v', 1), SenseInfo('02589576-v', 0), SenseInfo('02245555-v', 0), SenseInfo('01872877-v', 0), SenseInfo('01447632-v', 0) ],
"_await_v_1_rel" : [ SenseInfo('00720063-v', 25) ],
"_harmony_n_1_rel" : [ SenseInfo('04713118-n', 6), SenseInfo('07027180-n', 3), SenseInfo('13969243-n', 1), SenseInfo('07180183-n', 0), SenseInfo('04984180-n', 0) ],
"_neither_a_also_rel" : [ SenseInfo('00524607-a', 0) ],
"_flail_n_1_rel" : [ SenseInfo('03356279-n', 1) ],
"_miraculous_a_1_rel" : [ SenseInfo('01576551-a', 1), SenseInfo('01048976-a', 0), SenseInfo('01576551-a', 1), SenseInfo('01048976-a', 0) ],
"_kill_n_1_rel" : [ SenseInfo('00219012-n', 3), SenseInfo('00217593-n', 1) ],
"_pass_v_off_rel" : [ SenseInfo('02050132-v', 32), SenseInfo('02051694-v', 31), SenseInfo('02466670-v', 29), SenseInfo('02072849-v', 17), SenseInfo('02230772-v', 13), SenseInfo('02685951-v', 8), SenseInfo('02049696-v', 8), SenseInfo('00339934-v', 7), SenseInfo('02523351-v', 4), SenseInfo('02708420-v', 3), SenseInfo('01212230-v', 3), SenseInfo('00742320-v', 3), SenseInfo('00421691-v', 3), SenseInfo('02525044-v', 2), SenseInfo('02669081-v', 1), SenseInfo('02523953-v', 1), SenseInfo('02423513-v', 1), SenseInfo('02221635-v', 1), SenseInfo('01972131-v', 1), SenseInfo('02231473-v', 0), SenseInfo('02229550-v', 0), SenseInfo('02052476-v', 0), SenseInfo('00803325-v', 0), SenseInfo('00358431-v', 0), SenseInfo('00072989-v', 0) ],
"_predict_v_1_rel" : [ SenseInfo('00917772-v', 28), SenseInfo('00871942-v', 2), SenseInfo('00917772-v', 28), SenseInfo('00871942-v', 2), SenseInfo('00917772-v', 28), SenseInfo('00871942-v', 2) ],
"_sniff_v_out_rel" : [ SenseInfo('02125032-v', 5), SenseInfo('00007549-v', 1) ],
"_lift_v_cause_rel" : [ SenseInfo('01974062-v', 31), SenseInfo('01579153-v', 10), SenseInfo('01973759-v', 2), SenseInfo('01968569-v', 2), SenseInfo('00986074-v', 2), SenseInfo('00799798-v', 2), SenseInfo('02276866-v', 1), SenseInfo('01455184-v', 1), SenseInfo('00549982-v', 1), SenseInfo('00544549-v', 1), SenseInfo('00178652-v', 1), SenseInfo('02696801-v', 0), SenseInfo('02352181-v', 0), SenseInfo('02278061-v', 0), SenseInfo('02277138-v', 0), SenseInfo('01452057-v', 0), SenseInfo('01311608-v', 0), SenseInfo('00792921-v', 0), SenseInfo('00357198-v', 0), SenseInfo('00354195-v', 0), SenseInfo('00198623-v', 0), SenseInfo('00178773-v', 0), SenseInfo('00178502-v', 0), SenseInfo('00061933-v', 0) ],
"_some_n_meas_rel" : [ SenseInfo('02267308-a', 130), SenseInfo('01554063-a', 7), SenseInfo('01552634-a', 7), SenseInfo('01678586-a', 0) ],
"_lant_n_1_rel" : [  ],
"_house_v_1_rel" : [ SenseInfo('02701828-v', 13), SenseInfo('02459173-v', 4) ],
"_mathematician_n_1_rel" : [ SenseInfo('10301261-n', 0) ],
"_parallelizable_a_1_rel" : [  ],
"_trot_n_1_rel" : [ SenseInfo('00294190-n', 1), SenseInfo('10731013-n', 0), SenseInfo('06347225-n', 0), SenseInfo('00287561-n', 0) ],
"_roll_v_over_rel" : [ SenseInfo('01866192-v', 22), SenseInfo('01887020-v', 10), SenseInfo('02687251-v', 7), SenseInfo('01391280-v', 6), SenseInfo('02198014-v', 2), SenseInfo('01522276-v', 2), SenseInfo('01526139-v', 1), SenseInfo('00143204-v', 1), SenseInfo('00100410-v', 1), SenseInfo('02322596-v', 0), SenseInfo('01901783-v', 0), SenseInfo('01881180-v', 0), SenseInfo('01875684-v', 0), SenseInfo('01866610-v', 0), SenseInfo('01055978-v', 0), SenseInfo('00324427-v', 0), SenseInfo('00125289-v', 0), SenseInfo('00125078-v', 0), SenseInfo('01866192-v', 22), SenseInfo('01887020-v', 10), SenseInfo('02687251-v', 7), SenseInfo('01391280-v', 6), SenseInfo('02198014-v', 2), SenseInfo('01522276-v', 2), SenseInfo('01526139-v', 1), SenseInfo('00143204-v', 1), SenseInfo('00100410-v', 1), SenseInfo('02322596-v', 0), SenseInfo('01901783-v', 0), SenseInfo('01881180-v', 0), SenseInfo('01875684-v', 0), SenseInfo('01866610-v', 0), SenseInfo('01055978-v', 0), SenseInfo('00324427-v', 0), SenseInfo('00125289-v', 0), SenseInfo('00125078-v', 0) ],
"_espalier_n_1_rel" : [ SenseInfo('03297226-n', 0) ],
"_thistle_n_1_rel" : [ SenseInfo('11944196-n', 0) ],
"_hook_n_1_rel" : [ SenseInfo('03532919-n', 1), SenseInfo('13869547-n', 0), SenseInfo('05695232-n', 0), SenseInfo('03532672-n', 0), SenseInfo('03532342-n', 0), SenseInfo('00572285-n', 0), SenseInfo('00135799-n', 0), SenseInfo('00111358-n', 0) ],
"_fasten_v_1_rel" : [ SenseInfo('01340439-v', 13), SenseInfo('01343892-v', 4), SenseInfo('01290133-v', 2), SenseInfo('00420132-v', 0) ],
"_green_v_1_rel" : [ SenseInfo('00521478-v', 0) ],
"_hemp_n_1_rel" : [ SenseInfo('14906500-n', 0), SenseInfo('12396924-n', 0), SenseInfo('03491724-n', 0) ],
"_integrate_v_into_rel" : [ SenseInfo('00466651-v', 6), SenseInfo('02481900-v', 2), SenseInfo('00467451-v', 1), SenseInfo('00642980-v', 0), SenseInfo('00466651-v', 6), SenseInfo('02481900-v', 2), SenseInfo('00467451-v', 1), SenseInfo('00642980-v', 0) ],
"_puppet_n_1_rel" : [ SenseInfo('04025350-n', 1), SenseInfo('09976551-n', 0), SenseInfo('04025130-n', 0) ],
"_ready_v_1_rel" : [ SenseInfo('01664172-v', 1), SenseInfo('00406243-v', 1) ],
"_release_v_1_rel" : [ SenseInfo('01474550-v', 12), SenseInfo('02421374-v', 6), SenseInfo('01436518-v', 4), SenseInfo('00967625-v', 3), SenseInfo('00104868-v', 3), SenseInfo('00069295-v', 3), SenseInfo('02494047-v', 1), SenseInfo('02316304-v', 0), SenseInfo('01757994-v', 0), SenseInfo('00269682-v', 0), SenseInfo('01474550-v', 12), SenseInfo('02421374-v', 6), SenseInfo('01436518-v', 4), SenseInfo('00967625-v', 3), SenseInfo('00104868-v', 3), SenseInfo('00069295-v', 3), SenseInfo('02494047-v', 1), SenseInfo('02316304-v', 0), SenseInfo('01757994-v', 0), SenseInfo('00269682-v', 0) ],
"_bet_n_1_rel" : [ SenseInfo('13343526-n', 1), SenseInfo('00506658-n', 0), SenseInfo('13343526-n', 1), SenseInfo('00506658-n', 0) ],
"_smack_v_1_rel" : [ SenseInfo('01414916-v', 2), SenseInfo('02194723-v', 1), SenseInfo('02194495-v', 0), SenseInfo('01431879-v', 0), SenseInfo('01197208-v', 0) ],
"_futility_n_1_rel" : [ SenseInfo('05150855-n', 5) ],
"_furl_v_1_rel" : [ SenseInfo('00435853-v', 1) ],
"_pray_v_to_rel" : [ SenseInfo('00759944-v', 21), SenseInfo('00759269-v', 2), SenseInfo('00759944-v', 21), SenseInfo('00759269-v', 2) ],
"_accusation_n_of_rel" : [ SenseInfo('07234230-n', 3), SenseInfo('06730780-n', 0), SenseInfo('07234230-n', 3), SenseInfo('06730780-n', 0), SenseInfo('07234230-n', 3), SenseInfo('06730780-n', 0) ],
"_snug_a_1_rel" : [ SenseInfo('01885991-a', 1), SenseInfo('01447937-a', 0), SenseInfo('01399096-a', 0), SenseInfo('00477284-a', 0), SenseInfo('01885991-a', 1), SenseInfo('01447937-a', 0), SenseInfo('01399096-a', 0), SenseInfo('00477284-a', 0), SenseInfo('01885991-a', 1), SenseInfo('01447937-a', 0), SenseInfo('01399096-a', 0), SenseInfo('00477284-a', 0), SenseInfo('01885991-a', 1), SenseInfo('01447937-a', 0), SenseInfo('01399096-a', 0), SenseInfo('00477284-a', 0) ],
"_squash_v_1_rel" : [ SenseInfo('01593937-v', 1) ],
"_recite_v_1_rel" : [ SenseInfo('01051364-v', 2), SenseInfo('00945255-v', 2), SenseInfo('01703454-v', 0), SenseInfo('00953216-v', 0), SenseInfo('00946105-v', 0) ],
"_retract_v_1_rel" : [ SenseInfo('00798717-v', 3), SenseInfo('02061366-v', 0), SenseInfo('01609773-v', 0), SenseInfo('01506583-v', 0) ],
"_fear_n_of_rel" : [ SenseInfo('07519253-n', 73), SenseInfo('07524529-n', 7), SenseInfo('07521039-n', 0), SenseInfo('07519253-n', 73), SenseInfo('07524529-n', 7), SenseInfo('07521039-n', 0) ],
"_sprout_v_cause_rel" : [ SenseInfo('00357332-v', 4), SenseInfo('00095377-v', 0) ],
"_modify_v_1_rel" : [ SenseInfo('00169806-v', 17), SenseInfo('00171127-v', 1), SenseInfo('00126264-v', 0) ],
"_personify_v_1_rel" : [ SenseInfo('02698944-v', 2), SenseInfo('02697725-v', 2), SenseInfo('00727573-v', 0) ],
"_argue_v_about_rel" : [ SenseInfo('00772189-v', 34), SenseInfo('00773432-v', 17), SenseInfo('00772640-v', 0) ],
"_straighten_v_1_rel" : [ SenseInfo('02035781-v', 7), SenseInfo('01368597-v', 6), SenseInfo('01982044-v', 3), SenseInfo('00275843-v', 1), SenseInfo('01487185-v', 0), SenseInfo('00277935-v', 0) ],
"_manacle_n_1_rel" : [ SenseInfo('03484576-n', 0) ],
"_discriminate_v_1_rel" : [ SenseInfo('00650016-v', 2), SenseInfo('02512305-v', 1), SenseInfo('02193765-v', 0), SenseInfo('00650016-v', 2), SenseInfo('02512305-v', 1), SenseInfo('02193765-v', 0) ],
"_soap_v_up_rel" : [ SenseInfo('00036932-v', 0), SenseInfo('00036932-v', 0) ],
"_journal_n_1_rel" : [ SenseInfo('06402031-n', 2), SenseInfo('06597466-n', 1), SenseInfo('13405166-n', 0), SenseInfo('03602562-n', 0), SenseInfo('03602465-n', 0) ],
"_take_v_down_rel" : [ SenseInfo('02599636-v', 92), SenseInfo('02267989-v', 74), SenseInfo('01999798-v', 73), SenseInfo('01214265-v', 50), SenseInfo('00524682-v', 38), SenseInfo('00624476-v', 36), SenseInfo('02077656-v', 32), SenseInfo('02205272-v', 28), SenseInfo('01842690-v', 26), SenseInfo('00674607-v', 26), SenseInfo('02236124-v', 25), SenseInfo('02394183-v', 22), SenseInfo('00734054-v', 22), SenseInfo('02627934-v', 21), SenseInfo('02109045-v', 21), SenseInfo('01002740-v', 16), SenseInfo('00173338-v', 16), SenseInfo('01156834-v', 15), SenseInfo('00669762-v', 15), SenseInfo('02209936-v', 14), SenseInfo('02206619-v', 13), SenseInfo('01982395-v', 10), SenseInfo('02236624-v', 8), SenseInfo('00523095-v', 7), SenseInfo('00599992-v', 6), SenseInfo('00756076-v', 5), SenseInfo('02075857-v', 4), SenseInfo('01151110-v', 4), SenseInfo('00557404-v', 4), SenseInfo('02717102-v', 2), SenseInfo('02208537-v', 2), SenseInfo('02209745-v', 1), SenseInfo('02208118-v', 1), SenseInfo('02201138-v', 1), SenseInfo('01427127-v', 1), SenseInfo('00758333-v', 1), SenseInfo('02741546-v', 0), SenseInfo('02701210-v', 0), SenseInfo('02590253-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01100830-v', 0), SenseInfo('00087736-v', 0) ],
"_year+end_n_1_rel" : [ SenseInfo('15201994-n', 1), SenseInfo('15201994-n', 1) ],
"_pane_n_1_rel" : [ SenseInfo('03881893-n', 3), SenseInfo('03882611-n', 0), SenseInfo('02675657-n', 0) ],
"_grant_n_1_rel" : [ SenseInfo('13266892-n', 5), SenseInfo('00087423-n', 5), SenseInfo('13254237-n', 3), SenseInfo('11011559-n', 0), SenseInfo('11011398-n', 0), SenseInfo('11011123-n', 0), SenseInfo('06526619-n', 0), SenseInfo('05176477-n', 0), SenseInfo('13266892-n', 5), SenseInfo('00087423-n', 5), SenseInfo('13254237-n', 3), SenseInfo('11011559-n', 0), SenseInfo('11011398-n', 0), SenseInfo('11011123-n', 0), SenseInfo('06526619-n', 0), SenseInfo('05176477-n', 0), SenseInfo('13266892-n', 5), SenseInfo('00087423-n', 5), SenseInfo('13254237-n', 3), SenseInfo('11011559-n', 0), SenseInfo('11011398-n', 0), SenseInfo('11011123-n', 0), SenseInfo('06526619-n', 0), SenseInfo('05176477-n', 0) ],
"_across_p_temp_rel" : [ SenseInfo('00272951-r', 4), SenseInfo('00272844-r', 1), SenseInfo('00272951-r', 4), SenseInfo('00272844-r', 1) ],
"_backing_n_1_rel" : [ SenseInfo('01213886-n', 2), SenseInfo('02769460-n', 1), SenseInfo('13365698-n', 0) ],
"_disbelief_n_1_rel" : [ SenseInfo('05698982-n', 3), SenseInfo('05979909-n', 0) ],
"_solemn_a_1_rel" : [ SenseInfo('02119213-a', 2), SenseInfo('02118840-a', 0), SenseInfo('02119213-a', 2), SenseInfo('02118840-a', 0) ],
"_apse_n_1_rel" : [ SenseInfo('02731398-n', 0) ],
"_vigor_n_1_rel" : [ SenseInfo('05035961-n', 1), SenseInfo('05030806-n', 0), SenseInfo('04633197-n', 0) ],
"_bring_v_back_rel" : [ SenseInfo('02077656-v', 122), SenseInfo('01438902-v', 55), SenseInfo('01629589-v', 31), SenseInfo('01433294-v', 19), SenseInfo('00135857-v', 9), SenseInfo('01434140-v', 4), SenseInfo('01618547-v', 3), SenseInfo('02324478-v', 2), SenseInfo('02247390-v', 1), SenseInfo('01808218-v', 0), SenseInfo('00767334-v', 0), SenseInfo('02077656-v', 122), SenseInfo('01438902-v', 55), SenseInfo('01629589-v', 31), SenseInfo('01433294-v', 19), SenseInfo('00135857-v', 9), SenseInfo('01434140-v', 4), SenseInfo('01618547-v', 3), SenseInfo('02324478-v', 2), SenseInfo('02247390-v', 1), SenseInfo('01808218-v', 0), SenseInfo('00767334-v', 0) ],
"_motivated_a_1_rel" : [ SenseInfo('01558385-a', 3) ],
"_undies_n_1_rel" : [ SenseInfo('04509171-n', 0), SenseInfo('04509171-n', 0) ],
"_deliberative_a_1_rel" : [ SenseInfo('02420215-a', 0) ],
"_grueling_a_for_rel" : [ SenseInfo('00836544-a', 0), SenseInfo('00836544-a', 0), SenseInfo('00836544-a', 0) ],
"_beverage_n_1_rel" : [ SenseInfo('07881800-n', 2), SenseInfo('07881800-n', 2), SenseInfo('07881800-n', 2) ],
"_math_n_1_rel" : [ SenseInfo('06000644-n', 1) ],
"_carribean_a_1_rel" : [  ],
"_daring_a_1_rel" : [ SenseInfo('00066146-a', 1), SenseInfo('01686906-a', 0), SenseInfo('00066146-a', 1), SenseInfo('01686906-a', 0) ],
"_sort_v_through_rel" : [ SenseInfo('02400378-v', 0), SenseInfo('00654625-v', 0) ],
"_yay_a_1_rel" : [ SenseInfo('06936461-n', 0) ],
"_colon_n_1_rel" : [ SenseInfo('05535869-n', 2), SenseInfo('13667643-n', 0), SenseInfo('13667372-n', 0), SenseInfo('08739669-n', 0), SenseInfo('06842660-n', 0) ],
"_cylindrical_a_1_rel" : [ SenseInfo('02045723-a', 5) ],
"_rappel_v_1_rel" : [ SenseInfo('01923058-v', 0) ],
"_split_v_up-with_rel" : [ SenseInfo('02467662-v', 4), SenseInfo('01556572-v', 3), SenseInfo('02431320-v', 2), SenseInfo('02030158-v', 2), SenseInfo('00309310-v', 2) ],
"_let_v_on_rel" : [ SenseInfo('02423183-v', 219), SenseInfo('00771490-v', 15), SenseInfo('00802318-v', 2), SenseInfo('00120796-v', 2), SenseInfo('00496673-v', 1), SenseInfo('02208903-v', 0), SenseInfo('02423183-v', 219), SenseInfo('00771490-v', 15), SenseInfo('00802318-v', 2), SenseInfo('00120796-v', 2), SenseInfo('00496673-v', 1), SenseInfo('02208903-v', 0) ],
"_destined_a_1_rel" : [ SenseInfo('01682822-a', 0), SenseInfo('00340626-a', 0) ],
"_path_n_1_rel" : [ SenseInfo('00415676-n', 10), SenseInfo('03899328-n', 8), SenseInfo('08616311-n', 3), SenseInfo('09387222-n', 0) ],
"_meteorologist_n_1_rel" : [ SenseInfo('10312287-n', 0) ],
"_intransitive_a_1_rel" : [ SenseInfo('02488907-a', 0) ],
"_elderly_n_1_rel" : [ SenseInfo('07943870-n', 0), SenseInfo('07943870-n', 0) ],
"_synonymy_n_1_rel" : [ SenseInfo('13808161-n', 0) ],
"_inch_v_1_rel" : [ SenseInfo('02072501-v', 1) ],
"_relish_n_1_rel" : [ SenseInfo('07491981-n', 2), SenseInfo('07582441-n', 0), SenseInfo('05715864-n', 0) ],
"_preparative_n_1_rel" : [ SenseInfo('00126830-a', 1) ],
"_outlaw_n_1_rel" : [ SenseInfo('09977660-n', 1) ],
"_scarf_v_1_rel" : [ SenseInfo('01431132-v', 0), SenseInfo('01294889-v', 0), SenseInfo('00051060-v', 0) ],
"_phoneme_n_1_rel" : [ SenseInfo('07111711-n', 2) ],
"_lock_v_cause_rel" : [ SenseInfo('01348174-v', 8), SenseInfo('01510827-v', 7), SenseInfo('00219775-v', 4), SenseInfo('01606736-v', 2), SenseInfo('01606018-v', 2), SenseInfo('01810320-v', 1), SenseInfo('01347678-v', 1), SenseInfo('02050865-v', 0), SenseInfo('01655347-v', 0) ],
"_panic_v_1_rel" : [ SenseInfo('01782218-v', 1), SenseInfo('01781983-v', 1) ],
"_seem_v_1_rel" : [ SenseInfo('02133435-v', 607), SenseInfo('02134672-v', 84), SenseInfo('02745882-v', 0), SenseInfo('02198234-v', 0), SenseInfo('02133435-v', 607), SenseInfo('02134672-v', 84), SenseInfo('02745882-v', 0), SenseInfo('02198234-v', 0) ],
"_carefree_a_1_rel" : [ SenseInfo('02459465-a', 4), SenseInfo('01998260-a', 0) ],
"_tougher_a_for_rel" : [  ],
"_therewith_p_rel" : [ SenseInfo('00468447-r', 2) ],
"_scuff_v_1_rel" : [ SenseInfo('01917845-v', 1), SenseInfo('01370439-v', 0), SenseInfo('01370336-v', 0), SenseInfo('01370245-v', 0) ],
"_impact_v_1_rel" : [ SenseInfo('01343482-v', 0), SenseInfo('00137313-v', 0) ],
"_projector_n_of_rel" : [ SenseInfo('04009801-n', 0), SenseInfo('04009552-n', 0) ],
"_rugby_n_1_rel" : [ SenseInfo('00470966-n', 0) ],
"_abandon_n_1_rel" : [ SenseInfo('04885398-n', 4), SenseInfo('07481223-n', 0) ],
"_snap_n_1_rel" : [ SenseInfo('00138956-n', 1), SenseInfo('15299097-n', 0), SenseInfo('07728053-n', 0), SenseInfo('07636384-n', 0), SenseInfo('07394236-n', 0), SenseInfo('07381423-n', 0), SenseInfo('07367708-n', 0), SenseInfo('05020358-n', 0), SenseInfo('04248607-n', 0), SenseInfo('04248209-n', 0), SenseInfo('00575365-n', 0), SenseInfo('00344699-n', 0), SenseInfo('00120943-n', 0), SenseInfo('00138956-n', 1), SenseInfo('15299097-n', 0), SenseInfo('07728053-n', 0), SenseInfo('07636384-n', 0), SenseInfo('07394236-n', 0), SenseInfo('07381423-n', 0), SenseInfo('07367708-n', 0), SenseInfo('05020358-n', 0), SenseInfo('04248607-n', 0), SenseInfo('04248209-n', 0), SenseInfo('00575365-n', 0), SenseInfo('00344699-n', 0), SenseInfo('00120943-n', 0), SenseInfo('00138956-n', 1), SenseInfo('15299097-n', 0), SenseInfo('07728053-n', 0), SenseInfo('07636384-n', 0), SenseInfo('07394236-n', 0), SenseInfo('07381423-n', 0), SenseInfo('07367708-n', 0), SenseInfo('05020358-n', 0), SenseInfo('04248607-n', 0), SenseInfo('04248209-n', 0), SenseInfo('00575365-n', 0), SenseInfo('00344699-n', 0), SenseInfo('00120943-n', 0) ],
"_evil_a_1_rel" : [ SenseInfo('01131043-a', 9), SenseInfo('02514099-a', 1), SenseInfo('00224515-a', 0) ],
"_freshman_n_1_rel" : [ SenseInfo('10111688-n', 2), SenseInfo('10355449-n', 1), SenseInfo('10111688-n', 2), SenseInfo('10355449-n', 1), SenseInfo('10111688-n', 2), SenseInfo('10355449-n', 1) ],
"_myriad_n_of_rel" : [ SenseInfo('13776726-n', 1), SenseInfo('13751265-n', 0) ],
"_resume_v_1_rel" : [ SenseInfo('00350104-v', 17), SenseInfo('00350283-v', 5), SenseInfo('02381951-v', 4), SenseInfo('01007924-v', 0) ],
"_first+base_n_1_rel" : [ SenseInfo('03349771-n', 0), SenseInfo('00723547-n', 0), SenseInfo('00243662-n', 0) ],
"_fool_n_1_rel" : [ SenseInfo('10100761-n', 25), SenseInfo('09921409-n', 10), SenseInfo('10221312-n', 1) ],
"_philosophy_n_1_rel" : [ SenseInfo('05943300-n', 12), SenseInfo('06158346-n', 8), SenseInfo('05944686-n', 1) ],
"_hold_v_out_rel" : [ SenseInfo('02681795-v', 79), SenseInfo('01216670-v', 65), SenseInfo('01733477-v', 62), SenseInfo('02203362-v', 26), SenseInfo('00693780-v', 20), SenseInfo('01773130-v', 17), SenseInfo('01301410-v', 17), SenseInfo('02283324-v', 14), SenseInfo('02302220-v', 9), SenseInfo('01217043-v', 9), SenseInfo('02700867-v', 7), SenseInfo('02732798-v', 3), SenseInfo('02683489-v', 3), SenseInfo('01601234-v', 3), SenseInfo('02648502-v', 2), SenseInfo('00683771-v', 2), SenseInfo('02746275-v', 1), SenseInfo('02701210-v', 1), SenseInfo('02498320-v', 1), SenseInfo('01129876-v', 1), SenseInfo('00885217-v', 1), SenseInfo('00736586-v', 1), SenseInfo('00607000-v', 1), SenseInfo('02706816-v', 0), SenseInfo('02676789-v', 0), SenseInfo('02643574-v', 0), SenseInfo('02510337-v', 0), SenseInfo('02450989-v', 0), SenseInfo('02441897-v', 0), SenseInfo('01859586-v', 0), SenseInfo('01334744-v', 0), SenseInfo('01205153-v', 0), SenseInfo('01151753-v', 0), SenseInfo('00822367-v', 0), SenseInfo('00805376-v', 0), SenseInfo('00004492-v', 0), SenseInfo('02681795-v', 79), SenseInfo('01216670-v', 65), SenseInfo('01733477-v', 62), SenseInfo('02203362-v', 26), SenseInfo('00693780-v', 20), SenseInfo('01773130-v', 17), SenseInfo('01301410-v', 17), SenseInfo('02283324-v', 14), SenseInfo('02302220-v', 9), SenseInfo('01217043-v', 9), SenseInfo('02700867-v', 7), SenseInfo('02732798-v', 3), SenseInfo('02683489-v', 3), SenseInfo('01601234-v', 3), SenseInfo('02648502-v', 2), SenseInfo('00683771-v', 2), SenseInfo('02746275-v', 1), SenseInfo('02701210-v', 1), SenseInfo('02498320-v', 1), SenseInfo('01129876-v', 1), SenseInfo('00885217-v', 1), SenseInfo('00736586-v', 1), SenseInfo('00607000-v', 1), SenseInfo('02706816-v', 0), SenseInfo('02676789-v', 0), SenseInfo('02643574-v', 0), SenseInfo('02510337-v', 0), SenseInfo('02450989-v', 0), SenseInfo('02441897-v', 0), SenseInfo('01859586-v', 0), SenseInfo('01334744-v', 0), SenseInfo('01205153-v', 0), SenseInfo('01151753-v', 0), SenseInfo('00822367-v', 0), SenseInfo('00805376-v', 0), SenseInfo('00004492-v', 0) ],
"_time_a_expl-for_rel" : [ SenseInfo('07309599-n', 219), SenseInfo('15270431-n', 160), SenseInfo('15122231-n', 114), SenseInfo('15245515-n', 43), SenseInfo('00028270-n', 36), SenseInfo('07288215-n', 10), SenseInfo('15129927-n', 7), SenseInfo('15135822-n', 5), SenseInfo('04991738-n', 1), SenseInfo('15224692-n', 0), SenseInfo('07309599-n', 219), SenseInfo('15270431-n', 160), SenseInfo('15122231-n', 114), SenseInfo('15245515-n', 43), SenseInfo('00028270-n', 36), SenseInfo('07288215-n', 10), SenseInfo('15129927-n', 7), SenseInfo('15135822-n', 5), SenseInfo('04991738-n', 1), SenseInfo('15224692-n', 0), SenseInfo('07309599-n', 219), SenseInfo('15270431-n', 160), SenseInfo('15122231-n', 114), SenseInfo('15245515-n', 43), SenseInfo('00028270-n', 36), SenseInfo('07288215-n', 10), SenseInfo('15129927-n', 7), SenseInfo('15135822-n', 5), SenseInfo('04991738-n', 1), SenseInfo('15224692-n', 0), SenseInfo('07309599-n', 219), SenseInfo('15270431-n', 160), SenseInfo('15122231-n', 114), SenseInfo('15245515-n', 43), SenseInfo('00028270-n', 36), SenseInfo('07288215-n', 10), SenseInfo('15129927-n', 7), SenseInfo('15135822-n', 5), SenseInfo('04991738-n', 1), SenseInfo('15224692-n', 0) ],
"_slush_n_1_rel" : [ SenseInfo('15043308-n', 0) ],
"_lead_v_1_rel" : [ SenseInfo('01999798-v', 40), SenseInfo('02635659-v', 35), SenseInfo('02635956-v', 27), SenseInfo('01999423-v', 17), SenseInfo('00771632-v', 17), SenseInfo('02685951-v', 13), SenseInfo('02440244-v', 13), SenseInfo('02687385-v', 10), SenseInfo('02555908-v', 9), SenseInfo('01732921-v', 8), SenseInfo('02686471-v', 5), SenseInfo('01999218-v', 2), SenseInfo('02686625-v', 1), SenseInfo('00813790-v', 0), SenseInfo('01999798-v', 40), SenseInfo('02635659-v', 35), SenseInfo('02635956-v', 27), SenseInfo('01999423-v', 17), SenseInfo('00771632-v', 17), SenseInfo('02685951-v', 13), SenseInfo('02440244-v', 13), SenseInfo('02687385-v', 10), SenseInfo('02555908-v', 9), SenseInfo('01732921-v', 8), SenseInfo('02686471-v', 5), SenseInfo('01999218-v', 2), SenseInfo('02686625-v', 1), SenseInfo('00813790-v', 0), SenseInfo('01999798-v', 40), SenseInfo('02635659-v', 35), SenseInfo('02635956-v', 27), SenseInfo('01999423-v', 17), SenseInfo('00771632-v', 17), SenseInfo('02685951-v', 13), SenseInfo('02440244-v', 13), SenseInfo('02687385-v', 10), SenseInfo('02555908-v', 9), SenseInfo('01732921-v', 8), SenseInfo('02686471-v', 5), SenseInfo('01999218-v', 2), SenseInfo('02686625-v', 1), SenseInfo('00813790-v', 0), SenseInfo('01999798-v', 40), SenseInfo('02635659-v', 35), SenseInfo('02635956-v', 27), SenseInfo('01999423-v', 17), SenseInfo('00771632-v', 17), SenseInfo('02685951-v', 13), SenseInfo('02440244-v', 13), SenseInfo('02687385-v', 10), SenseInfo('02555908-v', 9), SenseInfo('01732921-v', 8), SenseInfo('02686471-v', 5), SenseInfo('01999218-v', 2), SenseInfo('02686625-v', 1), SenseInfo('00813790-v', 0) ],
"_verify_v_1_rel" : [ SenseInfo('00664483-v', 7), SenseInfo('02520997-v', 2), SenseInfo('01012395-v', 0), SenseInfo('01011031-v', 0), SenseInfo('00664483-v', 7), SenseInfo('02520997-v', 2), SenseInfo('01012395-v', 0), SenseInfo('01011031-v', 0), SenseInfo('00664483-v', 7), SenseInfo('02520997-v', 2), SenseInfo('01012395-v', 0), SenseInfo('01011031-v', 0) ],
"_moisten_v_1_rel" : [ SenseInfo('00217956-v', 3), SenseInfo('01376082-v', 0) ],
"_checkout_n_1_rel" : [ SenseInfo('00141806-n', 1), SenseInfo('15181282-n', 0), SenseInfo('03011741-n', 0), SenseInfo('00141806-n', 1), SenseInfo('15181282-n', 0), SenseInfo('03011741-n', 0) ],
"_reasonableness_n_1_rel" : [ SenseInfo('14379829-n', 0), SenseInfo('05160574-n', 0), SenseInfo('05146904-n', 0), SenseInfo('05118062-n', 0), SenseInfo('04783888-n', 0) ],
"_palistinian_n_1_rel" : [  ],
"_association_n_of_rel" : [ SenseInfo('08049401-n', 10), SenseInfo('01081628-n', 6), SenseInfo('14421139-n', 3), SenseInfo('05763916-n', 3), SenseInfo('13930385-n', 1), SenseInfo('13782769-n', 0), SenseInfo('13435152-n', 0), SenseInfo('07990377-n', 0), SenseInfo('08049401-n', 10), SenseInfo('01081628-n', 6), SenseInfo('14421139-n', 3), SenseInfo('05763916-n', 3), SenseInfo('13930385-n', 1), SenseInfo('13782769-n', 0), SenseInfo('13435152-n', 0), SenseInfo('07990377-n', 0) ],
"_molecule_n_1_rel" : [ SenseInfo('14682133-n', 9), SenseInfo('14585519-n', 0) ],
"_splitoff_n_1_rel" : [  ],
"_short-term_a_1_rel" : [ SenseInfo('01443842-a', 5), SenseInfo('01443842-a', 5) ],
"_subdivision_n_of_rel" : [ SenseInfo('08674251-n', 2), SenseInfo('00398427-n', 2), SenseInfo('08401248-n', 1), SenseInfo('06392001-n', 0), SenseInfo('04348548-n', 0) ],
"_dispute_v_1_rel" : [ SenseInfo('00869126-v', 4), SenseInfo('00775156-v', 2), SenseInfo('00869126-v', 4), SenseInfo('00775156-v', 2) ],
"_tasty_a_1_rel" : [ SenseInfo('02395115-a', 0), SenseInfo('02395115-a', 0), SenseInfo('02395115-a', 0) ],
"_idiotic_a_1_rel" : [ SenseInfo('02075737-a', 3), SenseInfo('02570643-a', 0), SenseInfo('01840880-a', 0) ],
"_convertible_a_1_rel" : [ SenseInfo('00916706-a', 0), SenseInfo('01027988-a', 0), SenseInfo('00348537-a', 0) ],
"_reverend_n_1_rel" : [ SenseInfo('09927451-n', 1), SenseInfo('06341773-n', 0) ],
"_redefinition_n_of_rel" : [ SenseInfo('06745628-n', 2) ],
"_veracity_n_1_rel" : [ SenseInfo('04872414-n', 1) ],
"_dressing_n_1_rel" : [ SenseInfo('07832902-n', 0), SenseInfo('07678729-n', 0), SenseInfo('07434473-n', 0), SenseInfo('03237639-n', 0), SenseInfo('00828862-n', 0), SenseInfo('00828237-n', 0), SenseInfo('00696882-n', 0) ],
"_mysticism_n_1_rel" : [ SenseInfo('05948857-n', 0), SenseInfo('05784560-n', 0) ],
"_topographical_a_1_rel" : [ SenseInfo('03018112-a', 1) ],
"_goalie_n_1_rel" : [ SenseInfo('10134001-n', 0), SenseInfo('00464037-n', 0) ],
"_insertion_n_of_rel" : [ SenseInfo('06722186-n', 0), SenseInfo('00320852-n', 0) ],
"_whack_v_off_rel" : [ SenseInfo('01415807-v', 2), SenseInfo('01415807-v', 2) ],
"_korean_n_1_rel" : [ SenseInfo('09718936-n', 1), SenseInfo('06929171-n', 0) ],
"_including_a_1_rel" : [  ],
"_picky_a_1_rel" : [ SenseInfo('00984624-a', 0), SenseInfo('00984624-a', 0), SenseInfo('00984624-a', 0) ],
"_off+and+on_a_1_rel" : [ SenseInfo('00290593-a', 0) ],
"_trick_v_1_rel" : [ SenseInfo('02575723-v', 1), SenseInfo('02575723-v', 1) ],
"_stubborn_a_1_rel" : [ SenseInfo('02326695-a', 5), SenseInfo('02452562-a', 0), SenseInfo('02326695-a', 5), SenseInfo('02452562-a', 0), SenseInfo('02326695-a', 5), SenseInfo('02452562-a', 0) ],
"_firm_v_up_rel" : [ SenseInfo('00420549-v', 0), SenseInfo('00420434-v', 0), SenseInfo('00420549-v', 0), SenseInfo('00420434-v', 0) ],
"_twirl_v_cause_rel" : [ SenseInfo('02048891-v', 2), SenseInfo('02048051-v', 1) ],
"_windblown_a_1_rel" : [ SenseInfo('02314236-a', 1) ],
"_for+once_a_1_rel" : [  ],
"_splinter_v_1_rel" : [ SenseInfo('02535457-v', 1), SenseInfo('02469274-v', 1), SenseInfo('00337903-v', 1) ],
"_house_n_of_rel" : [ SenseInfo('03544360-n', 157), SenseInfo('08059870-n', 2), SenseInfo('08224580-n', 1), SenseInfo('08222966-n', 1), SenseInfo('08163025-n', 1), SenseInfo('07971449-n', 1), SenseInfo('00432164-n', 1), SenseInfo('08685677-n', 0), SenseInfo('08381296-n', 0), SenseInfo('08078020-n', 0), SenseInfo('04417809-n', 0), SenseInfo('03545150-n', 0), SenseInfo('03544360-n', 157), SenseInfo('08059870-n', 2), SenseInfo('08224580-n', 1), SenseInfo('08222966-n', 1), SenseInfo('08163025-n', 1), SenseInfo('07971449-n', 1), SenseInfo('00432164-n', 1), SenseInfo('08685677-n', 0), SenseInfo('08381296-n', 0), SenseInfo('08078020-n', 0), SenseInfo('04417809-n', 0), SenseInfo('03545150-n', 0) ],
"_rubber-neck_v_1_rel" : [ SenseInfo('02150740-v', 0), SenseInfo('02150740-v', 0) ],
"_dirty_v_1_rel" : [ SenseInfo('01534147-v', 0) ],
"_gash_n_1_rel" : [ SenseInfo('14287113-n', 0), SenseInfo('03152619-n', 0), SenseInfo('00388065-n', 0) ],
"_glacial_a_1_rel" : [ SenseInfo('02736015-a', 0), SenseInfo('01258264-a', 0), SenseInfo('01252151-a', 0), SenseInfo('02736015-a', 0), SenseInfo('01258264-a', 0), SenseInfo('01252151-a', 0) ],
"_attendant_a_upon_rel" : [ SenseInfo('01846815-a', 0), SenseInfo('00122844-a', 0), SenseInfo('01846815-a', 0), SenseInfo('00122844-a', 0) ],
"_give_v_away_rel" : [ SenseInfo('02316868-v', 179), SenseInfo('02339171-v', 160), SenseInfo('02199590-v', 96), SenseInfo('02235842-v', 78), SenseInfo('01060494-v', 32), SenseInfo('01733477-v', 29), SenseInfo('01060317-v', 24), SenseInfo('02200686-v', 20), SenseInfo('01629403-v', 18), SenseInfo('00732224-v', 18), SenseInfo('01629000-v', 16), SenseInfo('02296153-v', 14), SenseInfo('01647672-v', 14), SenseInfo('02200498-v', 12), SenseInfo('02562901-v', 10), SenseInfo('02343595-v', 10), SenseInfo('02230772-v', 10), SenseInfo('00887463-v', 8), SenseInfo('02309374-v', 5), SenseInfo('02309165-v', 5), SenseInfo('01060746-v', 5), SenseInfo('02317094-v', 4), SenseInfo('01848465-v', 4), SenseInfo('01178565-v', 4), SenseInfo('02308741-v', 3), SenseInfo('01989053-v', 1), SenseInfo('00673571-v', 1), SenseInfo('02564052-v', 0), SenseInfo('02359553-v', 0), SenseInfo('02358034-v', 0), SenseInfo('01716283-v', 0), SenseInfo('01716112-v', 0), SenseInfo('01449796-v', 0), SenseInfo('01175810-v', 0), SenseInfo('01069638-v', 0), SenseInfo('00944247-v', 0), SenseInfo('00888009-v', 0), SenseInfo('00878876-v', 0), SenseInfo('00771806-v', 0), SenseInfo('00748972-v', 0), SenseInfo('00748616-v', 0), SenseInfo('00341184-v', 0), SenseInfo('00108747-v', 0), SenseInfo('00108604-v', 0) ],
"_reboiler_n_1_rel" : [  ],
"_taker_n_of_rel" : [ SenseInfo('10689784-n', 0), SenseInfo('09852081-n', 0) ],
"_flunk_v_1_rel" : [ SenseInfo('02523521-v', 0) ],
"_incisor_n_1_rel" : [ SenseInfo('05307641-n', 0) ],
"_redemption_n_of_rel" : [ SenseInfo('00094001-n', 1), SenseInfo('13299804-n', 0), SenseInfo('00079212-n', 0) ],
"_tow_v_1_rel" : [ SenseInfo('01454431-v', 0), SenseInfo('01454431-v', 0) ],
"_ordinal_n_1_rel" : [ SenseInfo('13597280-n', 0) ],
"_utilization_n_of_rel" : [ SenseInfo('00947128-n', 3), SenseInfo('14580476-n', 0), SenseInfo('00947128-n', 3), SenseInfo('14580476-n', 0) ],
"_slide_n_1_rel" : [ SenseInfo('04237924-n', 2), SenseInfo('07404944-n', 1), SenseInfo('06857264-n', 1), SenseInfo('04238128-n', 1), SenseInfo('00328502-n', 1), SenseInfo('04237773-n', 0), SenseInfo('03029603-n', 0) ],
"_leadsman_n_1_rel" : [  ],
"_illustrate_v_1_rel" : [ SenseInfo('01021128-v', 33), SenseInfo('01687401-v', 5), SenseInfo('01668421-v', 3), SenseInfo('01021128-v', 33), SenseInfo('01687401-v', 5), SenseInfo('01668421-v', 3), SenseInfo('01021128-v', 33), SenseInfo('01687401-v', 5), SenseInfo('01668421-v', 3) ],
"_euphoric_a_1_rel" : [ SenseInfo('00908929-a', 1), SenseInfo('00908929-a', 1) ],
"_console_v_1_rel" : [ SenseInfo('01814815-v', 1), SenseInfo('01814815-v', 1), SenseInfo('01814815-v', 1), SenseInfo('01814815-v', 1) ],
"_management_n_1_rel" : [ SenseInfo('01133281-n', 19), SenseInfo('08381165-n', 8) ],
"_step_n_meas_rel" : [ SenseInfo('00174412-n', 36), SenseInfo('13757249-n', 13), SenseInfo('00285557-n', 7), SenseInfo('04314914-n', 2), SenseInfo('14429608-n', 1), SenseInfo('13762579-n', 0), SenseInfo('07383823-n', 0), SenseInfo('06859056-n', 0), SenseInfo('06645039-n', 0), SenseInfo('04315185-n', 0), SenseInfo('00533922-n', 0) ],
"_domestic_n_1_rel" : [ SenseInfo('10024119-n', 0) ],
"_blossom_n_1_rel" : [ SenseInfo('11669335-n', 6), SenseInfo('15295045-n', 0) ],
"_conspiracy_n_1_rel" : [ SenseInfo('06524935-n', 3), SenseInfo('05908882-n', 3), SenseInfo('08251303-n', 2), SenseInfo('06524935-n', 3), SenseInfo('05908882-n', 3), SenseInfo('08251303-n', 2) ],
"_use_v_1_rel" : [ SenseInfo('01158872-v', 603), SenseInfo('01165043-v', 12), SenseInfo('01158572-v', 8), SenseInfo('02600490-v', 0), SenseInfo('02561332-v', 0), SenseInfo('02370131-v', 0), SenseInfo('01158872-v', 603), SenseInfo('01165043-v', 12), SenseInfo('01158572-v', 8), SenseInfo('02600490-v', 0), SenseInfo('02561332-v', 0), SenseInfo('02370131-v', 0), SenseInfo('01158872-v', 603), SenseInfo('01165043-v', 12), SenseInfo('01158572-v', 8), SenseInfo('02600490-v', 0), SenseInfo('02561332-v', 0), SenseInfo('02370131-v', 0) ],
"_vicar_n_1_rel" : [ SenseInfo('10750031-n', 1), SenseInfo('10750365-n', 0), SenseInfo('10750188-n', 0) ],
"_juicy_a_1_rel" : [ SenseInfo('01368793-a', 1), SenseInfo('02132967-a', 1), SenseInfo('01871349-a', 1), SenseInfo('02132224-a', 0), SenseInfo('01368793-a', 1), SenseInfo('02132967-a', 1), SenseInfo('01871349-a', 1), SenseInfo('02132224-a', 0), SenseInfo('01368793-a', 1), SenseInfo('02132967-a', 1), SenseInfo('01871349-a', 1), SenseInfo('02132224-a', 0) ],
"_chef_n_1_rel" : [ SenseInfo('09963574-n', 0) ],
"_aging_n_1_rel" : [ SenseInfo('13551965-n', 0), SenseInfo('13429006-n', 0) ],
"_growl_v_1_rel" : [ SenseInfo('01045719-v', 4), SenseInfo('01045719-v', 4) ],
"_call_v_1_rel" : [ SenseInfo('01028748-v', 91), SenseInfo('00971015-v', 51), SenseInfo('00789448-v', 38), SenseInfo('00913065-v', 25), SenseInfo('00792471-v', 25), SenseInfo('02487573-v', 9), SenseInfo('02429810-v', 9), SenseInfo('01067995-v', 1), SenseInfo('01062739-v', 1), SenseInfo('00975036-v', 1), SenseInfo('02643421-v', 0), SenseInfo('02601456-v', 0), SenseInfo('02487901-v', 0), SenseInfo('02359061-v', 0), SenseInfo('02300060-v', 0), SenseInfo('01899017-v', 0), SenseInfo('01068793-v', 0), SenseInfo('00917772-v', 0), SenseInfo('00874002-v', 0), SenseInfo('00869393-v', 0), SenseInfo('00822746-v', 0), SenseInfo('00783523-v', 0), SenseInfo('00754156-v', 0), SenseInfo('00753881-v', 0), SenseInfo('00738747-v', 0), SenseInfo('00738583-v', 0), SenseInfo('00691516-v', 0), SenseInfo('00107231-v', 0), SenseInfo('01028748-v', 91), SenseInfo('00971015-v', 51), SenseInfo('00789448-v', 38), SenseInfo('00913065-v', 25), SenseInfo('00792471-v', 25), SenseInfo('02487573-v', 9), SenseInfo('02429810-v', 9), SenseInfo('01067995-v', 1), SenseInfo('01062739-v', 1), SenseInfo('00975036-v', 1), SenseInfo('02643421-v', 0), SenseInfo('02601456-v', 0), SenseInfo('02487901-v', 0), SenseInfo('02359061-v', 0), SenseInfo('02300060-v', 0), SenseInfo('01899017-v', 0), SenseInfo('01068793-v', 0), SenseInfo('00917772-v', 0), SenseInfo('00874002-v', 0), SenseInfo('00869393-v', 0), SenseInfo('00822746-v', 0), SenseInfo('00783523-v', 0), SenseInfo('00754156-v', 0), SenseInfo('00753881-v', 0), SenseInfo('00738747-v', 0), SenseInfo('00738583-v', 0), SenseInfo('00691516-v', 0), SenseInfo('00107231-v', 0), SenseInfo('01028748-v', 91), SenseInfo('00971015-v', 51), SenseInfo('00789448-v', 38), SenseInfo('00913065-v', 25), SenseInfo('00792471-v', 25), SenseInfo('02487573-v', 9), SenseInfo('02429810-v', 9), SenseInfo('01067995-v', 1), SenseInfo('01062739-v', 1), SenseInfo('00975036-v', 1), SenseInfo('02643421-v', 0), SenseInfo('02601456-v', 0), SenseInfo('02487901-v', 0), SenseInfo('02359061-v', 0), SenseInfo('02300060-v', 0), SenseInfo('01899017-v', 0), SenseInfo('01068793-v', 0), SenseInfo('00917772-v', 0), SenseInfo('00874002-v', 0), SenseInfo('00869393-v', 0), SenseInfo('00822746-v', 0), SenseInfo('00783523-v', 0), SenseInfo('00754156-v', 0), SenseInfo('00753881-v', 0), SenseInfo('00738747-v', 0), SenseInfo('00738583-v', 0), SenseInfo('00691516-v', 0), SenseInfo('00107231-v', 0), SenseInfo('01028748-v', 91), SenseInfo('00971015-v', 51), SenseInfo('00789448-v', 38), SenseInfo('00913065-v', 25), SenseInfo('00792471-v', 25), SenseInfo('02487573-v', 9), SenseInfo('02429810-v', 9), SenseInfo('01067995-v', 1), SenseInfo('01062739-v', 1), SenseInfo('00975036-v', 1), SenseInfo('02643421-v', 0), SenseInfo('02601456-v', 0), SenseInfo('02487901-v', 0), SenseInfo('02359061-v', 0), SenseInfo('02300060-v', 0), SenseInfo('01899017-v', 0), SenseInfo('01068793-v', 0), SenseInfo('00917772-v', 0), SenseInfo('00874002-v', 0), SenseInfo('00869393-v', 0), SenseInfo('00822746-v', 0), SenseInfo('00783523-v', 0), SenseInfo('00754156-v', 0), SenseInfo('00753881-v', 0), SenseInfo('00738747-v', 0), SenseInfo('00738583-v', 0), SenseInfo('00691516-v', 0), SenseInfo('00107231-v', 0), SenseInfo('01028748-v', 91), SenseInfo('00971015-v', 51), SenseInfo('00789448-v', 38), SenseInfo('00913065-v', 25), SenseInfo('00792471-v', 25), SenseInfo('02487573-v', 9), SenseInfo('02429810-v', 9), SenseInfo('01067995-v', 1), SenseInfo('01062739-v', 1), SenseInfo('00975036-v', 1), SenseInfo('02643421-v', 0), SenseInfo('02601456-v', 0), SenseInfo('02487901-v', 0), SenseInfo('02359061-v', 0), SenseInfo('02300060-v', 0), SenseInfo('01899017-v', 0), SenseInfo('01068793-v', 0), SenseInfo('00917772-v', 0), SenseInfo('00874002-v', 0), SenseInfo('00869393-v', 0), SenseInfo('00822746-v', 0), SenseInfo('00783523-v', 0), SenseInfo('00754156-v', 0), SenseInfo('00753881-v', 0), SenseInfo('00738747-v', 0), SenseInfo('00738583-v', 0), SenseInfo('00691516-v', 0), SenseInfo('00107231-v', 0), SenseInfo('01028748-v', 91), SenseInfo('00971015-v', 51), SenseInfo('00789448-v', 38), SenseInfo('00913065-v', 25), SenseInfo('00792471-v', 25), SenseInfo('02487573-v', 9), SenseInfo('02429810-v', 9), SenseInfo('01067995-v', 1), SenseInfo('01062739-v', 1), SenseInfo('00975036-v', 1), SenseInfo('02643421-v', 0), SenseInfo('02601456-v', 0), SenseInfo('02487901-v', 0), SenseInfo('02359061-v', 0), SenseInfo('02300060-v', 0), SenseInfo('01899017-v', 0), SenseInfo('01068793-v', 0), SenseInfo('00917772-v', 0), SenseInfo('00874002-v', 0), SenseInfo('00869393-v', 0), SenseInfo('00822746-v', 0), SenseInfo('00783523-v', 0), SenseInfo('00754156-v', 0), SenseInfo('00753881-v', 0), SenseInfo('00738747-v', 0), SenseInfo('00738583-v', 0), SenseInfo('00691516-v', 0), SenseInfo('00107231-v', 0) ],
"_titanium_n_1_rel" : [ SenseInfo('14659211-n', 0) ],
"_browbeaten_a_1_rel" : [  ],
"_old-fashioned_a_1_rel" : [ SenseInfo('00974159-a', 1), SenseInfo('00974159-a', 1) ],
"_mortgage_n_1_rel" : [ SenseInfo('13352138-n', 4) ],
"_in+addition+to_p_rel" : [  ],
"_weigh_v_on_rel" : [ SenseInfo('02704818-v', 17), SenseInfo('00950431-v', 4), SenseInfo('02704617-v', 2), SenseInfo('02645839-v', 1), SenseInfo('02646064-v', 0), SenseInfo('02704818-v', 17), SenseInfo('00950431-v', 4), SenseInfo('02704617-v', 2), SenseInfo('02645839-v', 1), SenseInfo('02646064-v', 0) ],
"_s+a_n_1_rel" : [ SenseInfo('08212146-n', 0), SenseInfo('08212146-n', 0), SenseInfo('08212146-n', 0), SenseInfo('08212146-n', 0), SenseInfo('08212146-n', 0), SenseInfo('08212146-n', 0) ],
"_center_v_on_rel" : [ SenseInfo('02676496-v', 11), SenseInfo('00722232-v', 5), SenseInfo('01852701-v', 0), SenseInfo('02676496-v', 11), SenseInfo('00722232-v', 5), SenseInfo('01852701-v', 0), SenseInfo('02676496-v', 11), SenseInfo('00722232-v', 5), SenseInfo('01852701-v', 0) ],
"_burglar_n_1_rel" : [ SenseInfo('09880741-n', 1) ],
"_sir_n_1_rel" : [ SenseInfo('10601451-n', 19), SenseInfo('10601526-n', 0) ],
"_ordinance_n_1_rel" : [ SenseInfo('06664051-n', 1), SenseInfo('06565788-n', 0), SenseInfo('00165298-n', 0) ],
"_cube_v_1_rel" : [ SenseInfo('00640262-v', 1), SenseInfo('01256867-v', 0) ],
"_unwillingness_n_1_rel" : [ SenseInfo('04645599-n', 3), SenseInfo('04645599-n', 3) ],
"_smile_n_1_rel" : [ SenseInfo('06878071-n', 29) ],
"_no+good_a_1_rel" : [ SenseInfo('02502578-a', 0), SenseInfo('01129021-a', 0) ],
"_free+rein_n_1_rel" : [ SenseInfo('13993842-n', 1) ],
"_disappointment_n_at_rel" : [ SenseInfo('07540602-n', 7), SenseInfo('00068755-n', 1), SenseInfo('07540602-n', 7), SenseInfo('00068755-n', 1) ],
"_blasé_a_1_rel" : [  ],
"_perish_v_1_rel" : [ SenseInfo('00358431-v', 5) ],
"_die-off_n_1_rel" : [  ],
"_puck_n_1_rel" : [ SenseInfo('09541809-n', 0), SenseInfo('04019541-n', 0) ],
"_beep_v_cause_rel" : [ SenseInfo('02183175-v', 0), SenseInfo('00791372-v', 0) ],
"_eightfold_a_1_rel" : [ SenseInfo('02219988-a', 0), SenseInfo('02219988-a', 0) ],
"_chirp_n_1_rel" : [ SenseInfo('07379409-n', 0) ],
"_at_p_temp_rel" : [ SenseInfo('14629561-n', 0), SenseInfo('13681048-n', 0) ],
"_vessel_n_1_rel" : [ SenseInfo('05397333-n', 6), SenseInfo('04530566-n', 6), SenseInfo('04531098-n', 0) ],
"_die_v_away_rel" : [ SenseInfo('00358431-v', 141), SenseInfo('02109818-v', 1), SenseInfo('01784953-v', 1), SenseInfo('00434374-v', 1), SenseInfo('01829475-v', 0), SenseInfo('01785242-v', 0), SenseInfo('01555034-v', 0), SenseInfo('01074914-v', 0), SenseInfo('00538323-v', 0), SenseInfo('00354845-v', 0), SenseInfo('00224295-v', 0) ],
"_namely_p_rel" : [ SenseInfo('00188510-r', 9), SenseInfo('00188510-r', 9) ],
"_burdensome_a_1_rel" : [ SenseInfo('01189109-a', 0) ],
"_drum_v_cause_rel" : [ SenseInfo('02174830-v', 1), SenseInfo('01732532-v', 1), SenseInfo('00605783-v', 0) ],
"_type_v_1_rel" : [ SenseInfo('01004692-v', 2), SenseInfo('00618682-v', 1) ],
"_underpopulate_v_1_rel" : [  ],
"_bloodshed_n_1_rel" : [ SenseInfo('00221178-n', 2), SenseInfo('00224260-n', 0) ],
"_tights_n_1_rel" : [ SenseInfo('04434932-n', 0), SenseInfo('04434932-n', 0) ],
"_abandon_v_1_rel" : [ SenseInfo('02228031-v', 10), SenseInfo('02227741-v', 6), SenseInfo('02076676-v', 6), SenseInfo('00613393-v', 5), SenseInfo('00614057-v', 3) ],
"_woods_n_1_rel" : [ SenseInfo('08438533-n', 43), SenseInfo('08438533-n', 43) ],
"_adjourn_v_1_rel" : [ SenseInfo('00364297-v', 4), SenseInfo('02428487-v', 0) ],
"_piston_n_1_rel" : [ SenseInfo('11235926-n', 0), SenseInfo('03948950-n', 0) ],
"_fauna_n_1_rel" : [ SenseInfo('07993279-n', 0), SenseInfo('00015388-n', 0) ],
"_comic_n_1_rel" : [ SenseInfo('09940146-n', 0) ],
"_jaeger_n_1_rel" : [ SenseInfo('02044178-n', 0) ],
"_tummy_n_1_rel" : [ SenseInfo('05556071-n', 0), SenseInfo('05395690-n', 0) ],
"_peculiar_a_1_rel" : [ SenseInfo('00968010-a', 9), SenseInfo('01104026-a', 6), SenseInfo('00491089-a', 0), SenseInfo('00357790-a', 0), SenseInfo('00968010-a', 9), SenseInfo('01104026-a', 6), SenseInfo('00491089-a', 0), SenseInfo('00357790-a', 0) ],
"_unemployment_n_1_rel" : [ SenseInfo('13968308-n', 3) ],
"_exempt_v_from_rel" : [ SenseInfo('02564146-v', 1), SenseInfo('00893878-v', 0), SenseInfo('02564146-v', 1), SenseInfo('00893878-v', 0), SenseInfo('02564146-v', 1), SenseInfo('00893878-v', 0) ],
"_fork_v_off_rel" : [ SenseInfo('01579340-v', 0), SenseInfo('01118888-v', 0), SenseInfo('00328802-v', 0), SenseInfo('00141914-v', 0) ],
"_price_v_1_rel" : [ SenseInfo('02351010-v', 4), SenseInfo('00721889-v', 0) ],
"_intend_v_as_rel" : [ SenseInfo('00708538-v', 32), SenseInfo('00709379-v', 6), SenseInfo('00955148-v', 4), SenseInfo('00931852-v', 0) ],
"_hypothesize_v_1_rel" : [ SenseInfo('00633443-v', 3), SenseInfo('00633443-v', 3), SenseInfo('00633443-v', 3), SenseInfo('00633443-v', 3) ],
"_vulpine_a_1_rel" : [ SenseInfo('02839865-a', 1) ],
"_danger_n_of_rel" : [ SenseInfo('14540765-n', 18), SenseInfo('00802238-n', 8), SenseInfo('14541044-n', 6), SenseInfo('08644213-n', 1), SenseInfo('14540765-n', 18), SenseInfo('00802238-n', 8), SenseInfo('14541044-n', 6), SenseInfo('08644213-n', 1) ],
"_Chicano_n_1_rel" : [ SenseInfo('09722817-n', 0) ],
"_boatswain_n_1_rel" : [ SenseInfo('09862183-n', 3) ],
"_astonishment_n_1_rel" : [ SenseInfo('07509572-n', 8) ],
"_resident_n_of_rel" : [ SenseInfo('10523519-n', 6), SenseInfo('10189278-n', 0) ],
"_irritating_a_1_rel" : [ SenseInfo('00089550-a', 1), SenseInfo('02310185-a', 0), SenseInfo('00478685-a', 0) ],
"_interpretive_a_1_rel" : [ SenseInfo('01325017-a', 0), SenseInfo('01325017-a', 0) ],
"_recalcitrant_n_1_rel" : [ SenseInfo('01614127-a', 0), SenseInfo('00696335-a', 0) ],
"_goretex_n_1_rel" : [  ],
"_burden_v_1_rel" : [ SenseInfo('01487311-v', 0), SenseInfo('00750532-v', 0) ],
"_foolish_a_1_rel" : [ SenseInfo('02570282-a', 6), SenseInfo('00439905-a', 0), SenseInfo('02570282-a', 6), SenseInfo('00439905-a', 0) ],
"_rue_n_1_rel" : [ SenseInfo('12707199-n', 0), SenseInfo('07820297-n', 0), SenseInfo('07535670-n', 0), SenseInfo('04117917-n', 0) ],
"_nibble_v_at_rel" : [ SenseInfo('01446729-v', 0), SenseInfo('01446420-v', 0), SenseInfo('01174294-v', 0) ],
"_intoxicate_v_1_rel" : [ SenseInfo('01811736-v', 0), SenseInfo('01190494-v', 0), SenseInfo('00088532-v', 0) ],
"_tongue-in-cheek_a_1_rel" : [ SenseInfo('01264913-a', 2), SenseInfo('01264913-a', 2), SenseInfo('01264913-a', 2), SenseInfo('01264913-a', 2), SenseInfo('01264913-a', 2) ],
"_chime_v_in_rel" : [ SenseInfo('02182342-v', 0) ],
"_the+hardest_a_1_rel" : [  ],
"_insult_n_1_rel" : [ SenseInfo('06715223-n', 2), SenseInfo('01225027-n', 0) ],
"_heaven_n_1_rel" : [ SenseInfo('08565506-n', 1), SenseInfo('05627785-n', 0) ],
"_appreciate_v_1_rel" : [ SenseInfo('01805982-v', 12), SenseInfo('00592341-v', 11), SenseInfo('02256109-v', 5), SenseInfo('00316195-v', 0), SenseInfo('00315605-v', 0), SenseInfo('01805982-v', 12), SenseInfo('00592341-v', 11), SenseInfo('02256109-v', 5), SenseInfo('00316195-v', 0), SenseInfo('00315605-v', 0) ],
"_veer_v_1_rel" : [ SenseInfo('02033295-v', 8), SenseInfo('00560764-v', 0), SenseInfo('02033295-v', 8), SenseInfo('00560764-v', 0) ],
"_slay_v_1_rel" : [ SenseInfo('02482425-v', 0) ],
"_hearing_n_1_rel" : [ SenseInfo('01199697-n', 10), SenseInfo('14484778-n', 4), SenseInfo('08560785-n', 3), SenseInfo('00882159-n', 2), SenseInfo('07147267-n', 0), SenseInfo('05657718-n', 0) ],
"_faint_a_1_rel" : [ SenseInfo('01747364-a', 5), SenseInfo('00782216-a', 5), SenseInfo('02325097-a', 4), SenseInfo('02544525-a', 1), SenseInfo('00782568-a', 0), SenseInfo('00265989-a', 0), SenseInfo('01747364-a', 5), SenseInfo('00782216-a', 5), SenseInfo('02325097-a', 4), SenseInfo('02544525-a', 1), SenseInfo('00782568-a', 0), SenseInfo('00265989-a', 0), SenseInfo('01747364-a', 5), SenseInfo('00782216-a', 5), SenseInfo('02325097-a', 4), SenseInfo('02544525-a', 1), SenseInfo('00782568-a', 0), SenseInfo('00265989-a', 0), SenseInfo('01747364-a', 5), SenseInfo('00782216-a', 5), SenseInfo('02325097-a', 4), SenseInfo('02544525-a', 1), SenseInfo('00782568-a', 0), SenseInfo('00265989-a', 0) ],
"_midnight_n_1_rel" : [ SenseInfo('15168185-n', 7) ],
"_whirl_n_1_rel" : [ SenseInfo('07442068-n', 1), SenseInfo('13878112-n', 0), SenseInfo('00787061-n', 0), SenseInfo('00343249-n', 0) ],
"_sunburned_a_1_rel" : [ SenseInfo('01178345-a', 0) ],
"_off-exchange_a_1_rel" : [  ],
"_prisoner_n_1_rel" : [ SenseInfo('10476086-n', 12) ],
"_test_n_of_rel" : [ SenseInfo('05799212-n', 19), SenseInfo('01006675-n', 7), SenseInfo('07197021-n', 2), SenseInfo('00794367-n', 2), SenseInfo('00791078-n', 2), SenseInfo('01904699-n', 0) ],
"_recovery_n_1_rel" : [ SenseInfo('07419792-n', 3), SenseInfo('13452347-n', 2), SenseInfo('00045907-n', 2) ],
"_sundae_n_1_rel" : [ SenseInfo('07616487-n', 0) ],
"_die_v_out_rel" : [ SenseInfo('00358431-v', 141), SenseInfo('02109818-v', 1), SenseInfo('01784953-v', 1), SenseInfo('00434374-v', 1), SenseInfo('01829475-v', 0), SenseInfo('01785242-v', 0), SenseInfo('01555034-v', 0), SenseInfo('01074914-v', 0), SenseInfo('00538323-v', 0), SenseInfo('00354845-v', 0), SenseInfo('00224295-v', 0) ],
"_smash_v_1_rel" : [ SenseInfo('01401772-v', 6), SenseInfo('00335923-v', 5), SenseInfo('02318165-v', 0), SenseInfo('02104373-v', 0), SenseInfo('01800195-v', 0), SenseInfo('01566705-v', 0), SenseInfo('01561583-v', 0), SenseInfo('01561408-v', 0), SenseInfo('01083576-v', 0), SenseInfo('00334649-v', 0), SenseInfo('01401772-v', 6), SenseInfo('00335923-v', 5), SenseInfo('02318165-v', 0), SenseInfo('02104373-v', 0), SenseInfo('01800195-v', 0), SenseInfo('01566705-v', 0), SenseInfo('01561583-v', 0), SenseInfo('01561408-v', 0), SenseInfo('01083576-v', 0), SenseInfo('00334649-v', 0) ],
"_off+of_p_rel" : [  ],
"_dismantle_v_1_rel" : [ SenseInfo('01661804-v', 0), SenseInfo('01657977-v', 0), SenseInfo('00194534-v', 0) ],
"_untamed_a_1_rel" : [ SenseInfo('02389220-a', 0), SenseInfo('02389220-a', 0) ],
"_engrave_v_1_rel" : [ SenseInfo('01321895-v', 1), SenseInfo('01768630-v', 0), SenseInfo('01749790-v', 0), SenseInfo('01322223-v', 0) ],
"_thence_a_1_rel" : [  ],
"_refute_v_1_rel" : [ SenseInfo('00814850-v', 2), SenseInfo('00667747-v', 1) ],
"_euro_n_cur_rel" : [ SenseInfo('13661820-n', 0) ],
"_fjordside_a_1_rel" : [  ],
"_godson_n_1_rel" : [ SenseInfo('10135129-n', 0) ],
"_obliged_a_1_rel" : [ SenseInfo('01616891-a', 7) ],
"_maelstrom_n_1_rel" : [ SenseInfo('07433145-n', 0) ],
"_justice_n_1_rel" : [ SenseInfo('04850117-n', 16), SenseInfo('00694681-n', 6), SenseInfo('10225219-n', 1), SenseInfo('08135342-n', 0) ],
"_partake_v_1_rel" : [ SenseInfo('02736660-v', 1), SenseInfo('02295208-v', 0), SenseInfo('01172701-v', 0) ],
"_conductor_n_of_rel" : [ SenseInfo('09952539-n', 6), SenseInfo('14821043-n', 1), SenseInfo('09953052-n', 1), SenseInfo('03088707-n', 0) ],
"_moth_n_1_rel" : [ SenseInfo('02283201-n', 3) ],
"_outlaw_v_1_rel" : [ SenseInfo('02480923-v', 2) ],
"_teeter_v_1_rel" : [ SenseInfo('01881034-v', 2) ],
"_cooperative_n_1_rel" : [ SenseInfo('01100877-n', 3), SenseInfo('08227088-n', 1), SenseInfo('01100877-n', 3), SenseInfo('08227088-n', 1), SenseInfo('01100877-n', 3), SenseInfo('08227088-n', 1) ],
"_outline_n_1_rel" : [ SenseInfo('08612786-n', 3), SenseInfo('06468951-n', 2), SenseInfo('05891572-n', 1) ],
"_oxidize_v_cause_rel" : [ SenseInfo('00239321-v', 0), SenseInfo('00238867-v', 0) ],
"_nationalist_a_1_rel" : [ SenseInfo('01568092-a', 0) ],
"_haze_n_1_rel" : [ SenseInfo('11465888-n', 8), SenseInfo('05684561-n', 1) ],
"_stagger_n_1_rel" : [ SenseInfo('00289388-n', 0) ],
"_rash_a_1_rel" : [ SenseInfo('01900188-a', 0), SenseInfo('00250739-a', 0), SenseInfo('01900188-a', 0), SenseInfo('00250739-a', 0), SenseInfo('01900188-a', 0), SenseInfo('00250739-a', 0) ],
"_soapy_a_1_rel" : [ SenseInfo('03026319-a', 0), SenseInfo('02181432-a', 0) ],
"_unit_n_2_rel" : [ SenseInfo('13583724-n', 14), SenseInfo('13810323-n', 13), SenseInfo('08189659-n', 9), SenseInfo('05869857-n', 6), SenseInfo('09465459-n', 2), SenseInfo('00003553-n', 0) ],
"_adjectival_a_1_rel" : [ SenseInfo('02936020-a', 2) ],
"_lake+fish_v_1_rel" : [  ],
"_violent_a_1_rel" : [ SenseInfo('02510879-a', 8), SenseInfo('01570747-a', 1), SenseInfo('01514141-a', 1), SenseInfo('01511854-a', 0), SenseInfo('00248560-a', 0), SenseInfo('02510879-a', 8), SenseInfo('01570747-a', 1), SenseInfo('01514141-a', 1), SenseInfo('01511854-a', 0), SenseInfo('00248560-a', 0) ],
"_hostage_n_1_rel" : [ SenseInfo('10187557-n', 0) ],
"_ocean_n_1_rel" : [ SenseInfo('09376198-n', 8), SenseInfo('13776971-n', 0) ],
"_pygmy_n_1_rel" : [ SenseInfo('10496626-n', 0), SenseInfo('10496489-n', 0) ],
"_middleware_n_1_rel" : [  ],
"_polarity_n_1_rel" : [ SenseInfo('13856110-n', 3), SenseInfo('13856574-n', 1) ],
"_esi_n_1_rel" : [  ],
"_dimension_n_1_rel" : [ SenseInfo('05093581-n', 7), SenseInfo('05849040-n', 5), SenseInfo('06011446-n', 1), SenseInfo('05091194-n', 1) ],
"_closed_a_1_rel" : [ SenseInfo('01653538-a', 8), SenseInfo('01660135-a', 6), SenseInfo('01652782-a', 6), SenseInfo('01655162-a', 3), SenseInfo('02474377-a', 1), SenseInfo('02256659-a', 0), SenseInfo('02002580-a', 0), SenseInfo('01986349-a', 0), SenseInfo('01657760-a', 0) ],
"_sober_v_1_rel" : [ SenseInfo('00149469-v', 0), SenseInfo('00149296-v', 0), SenseInfo('00149118-v', 0), SenseInfo('00149469-v', 0), SenseInfo('00149296-v', 0), SenseInfo('00149118-v', 0), SenseInfo('00149469-v', 0), SenseInfo('00149296-v', 0), SenseInfo('00149118-v', 0), SenseInfo('00149469-v', 0), SenseInfo('00149296-v', 0), SenseInfo('00149118-v', 0), SenseInfo('00149469-v', 0), SenseInfo('00149296-v', 0), SenseInfo('00149118-v', 0) ],
"_guidebook_n_of_rel" : [ SenseInfo('06422740-n', 0) ],
"_precipitate_v_cause_rel" : [ SenseInfo('01644339-v', 4), SenseInfo('00474994-v', 4), SenseInfo('02756821-v', 0), SenseInfo('01971750-v', 0), SenseInfo('01507596-v', 0) ],
"_haggard_a_1_rel" : [ SenseInfo('02433000-a', 2), SenseInfo('00988988-a', 1) ],
"_compel_v_1_rel" : [ SenseInfo('02506546-v', 21), SenseInfo('02635420-v', 0), SenseInfo('02506546-v', 21), SenseInfo('02635420-v', 0), SenseInfo('02506546-v', 21), SenseInfo('02635420-v', 0), SenseInfo('02506546-v', 21), SenseInfo('02635420-v', 0) ],
"_synagogue_n_1_rel" : [ SenseInfo('04374735-n', 2), SenseInfo('04374735-n', 2) ],
"_narrative_n_1_rel" : [ SenseInfo('07221094-n', 8) ],
"_preface_v_1_rel" : [ SenseInfo('00901799-v', 1) ],
"_womens+rights_n_1_rel" : [  ],
"_biker_n_1_rel" : [  ],
"_communicative_a_1_rel" : [ SenseInfo('02956371-a', 3), SenseInfo('00494907-a', 0) ],
"_anglican_a_1_rel" : [ SenseInfo('02954459-a', 8) ],
"_grant_v_1_rel" : [ SenseInfo('02255462-v', 14), SenseInfo('02262278-v', 9), SenseInfo('00806049-v', 5), SenseInfo('02255268-v', 3), SenseInfo('02317094-v', 2), SenseInfo('02316649-v', 0), SenseInfo('02255942-v', 0), SenseInfo('02255462-v', 14), SenseInfo('02262278-v', 9), SenseInfo('00806049-v', 5), SenseInfo('02255268-v', 3), SenseInfo('02317094-v', 2), SenseInfo('02316649-v', 0), SenseInfo('02255942-v', 0), SenseInfo('02255462-v', 14), SenseInfo('02262278-v', 9), SenseInfo('00806049-v', 5), SenseInfo('02255268-v', 3), SenseInfo('02317094-v', 2), SenseInfo('02316649-v', 0), SenseInfo('02255942-v', 0) ],
"_variety_n_of-n_rel" : [ SenseInfo('08398773-n', 22), SenseInfo('04751305-n', 7), SenseInfo('08101085-n', 1), SenseInfo('07020239-n', 0), SenseInfo('05839024-n', 0), SenseInfo('04752034-n', 0), SenseInfo('08398773-n', 22), SenseInfo('04751305-n', 7), SenseInfo('08101085-n', 1), SenseInfo('07020239-n', 0), SenseInfo('05839024-n', 0), SenseInfo('04752034-n', 0), SenseInfo('08398773-n', 22), SenseInfo('04751305-n', 7), SenseInfo('08101085-n', 1), SenseInfo('07020239-n', 0), SenseInfo('05839024-n', 0), SenseInfo('04752034-n', 0) ],
"_slash_v_at_rel" : [ SenseInfo('01322675-v', 7), SenseInfo('01411085-v', 3), SenseInfo('01322509-v', 3), SenseInfo('00430261-v', 2), SenseInfo('01890792-v', 0), SenseInfo('01322675-v', 7), SenseInfo('01411085-v', 3), SenseInfo('01322509-v', 3), SenseInfo('00430261-v', 2), SenseInfo('01890792-v', 0) ],
"_swirl_v_1_rel" : [ SenseInfo('02048891-v', 3), SenseInfo('02047650-v', 3) ],
"_gaiter_n_1_rel" : [ SenseInfo('04269822-n', 0), SenseInfo('03411079-n', 0), SenseInfo('03410938-n', 0) ],
"_push_v_forward_rel" : [ SenseInfo('01871979-v', 56), SenseInfo('00765977-v', 7), SenseInfo('00976653-v', 6), SenseInfo('02406916-v', 3), SenseInfo('01872645-v', 3), SenseInfo('02054864-v', 1), SenseInfo('02589576-v', 0), SenseInfo('02245555-v', 0), SenseInfo('01872877-v', 0), SenseInfo('01447632-v', 0), SenseInfo('01871979-v', 56), SenseInfo('00765977-v', 7), SenseInfo('00976653-v', 6), SenseInfo('02406916-v', 3), SenseInfo('01872645-v', 3), SenseInfo('02054864-v', 1), SenseInfo('02589576-v', 0), SenseInfo('02245555-v', 0), SenseInfo('01872877-v', 0), SenseInfo('01447632-v', 0) ],
"_register_v_1_rel" : [ SenseInfo('02471690-v', 7), SenseInfo('01001857-v', 6), SenseInfo('02471087-v', 4), SenseInfo('02105810-v', 3), SenseInfo('00922867-v', 2), SenseInfo('02472033-v', 1), SenseInfo('02139740-v', 0), SenseInfo('01726605-v', 0), SenseInfo('01032326-v', 0), SenseInfo('00728224-v', 0) ],
"_crms_n_1_rel" : [  ],
"_adequate_a_1_rel" : [ SenseInfo('00051045-a', 17), SenseInfo('02336109-a', 4), SenseInfo('02080937-a', 1), SenseInfo('00051045-a', 17), SenseInfo('02336109-a', 4), SenseInfo('02080937-a', 1) ],
"_sprinter_n_1_rel" : [ SenseInfo('10641413-n', 2) ],
"_premiere_n_1_rel" : [ SenseInfo('06893285-n', 1) ],
"_paintbrush_n_1_rel" : [ SenseInfo('03876231-n', 0) ],
"_underwing_n_1_rel" : [ SenseInfo('02295870-n', 0) ],
"_deficient_a_1_rel" : [ SenseInfo('00052012-a', 1), SenseInfo('02336449-a', 0), SenseInfo('02297409-a', 0) ],
"_snowfield_n_1_rel" : [ SenseInfo('09439032-n', 0) ],
"_morning_n_1_rel" : [ SenseInfo('15165289-n', 86), SenseInfo('06632671-n', 2), SenseInfo('15168790-n', 0), SenseInfo('07326108-n', 0) ],
"_ahold_n_i_rel" : [  ],
"_barbiturate_n_1_rel" : [ SenseInfo('02792049-n', 1) ],
"_filbert_n_1_rel" : [ SenseInfo('12289433-n', 0), SenseInfo('07772788-n', 0) ],
"_solstitial_a_1_rel" : [  ],
"_a+ways_x_much_rel" : [  ],
"_cheek_n_1_rel" : [ SenseInfo('05602835-n', 22), SenseInfo('06721813-n', 0), SenseInfo('05559727-n', 0), SenseInfo('04838210-n', 0) ],
"_resigned_a_1_rel" : [  ],
"_cavalryman_n_1_rel" : [ SenseInfo('09902611-n', 1), SenseInfo('09902353-n', 1) ],
"_factor_v_cause_rel" : [ SenseInfo('00640385-v', 2), SenseInfo('02324901-v', 0), SenseInfo('00640650-v', 0) ],
"_system_n_of_rel" : [ SenseInfo('04377057-n', 43), SenseInfo('08435388-n', 23), SenseInfo('14981183-n', 14), SenseInfo('05661996-n', 10), SenseInfo('05726596-n', 8), SenseInfo('05237227-n', 7), SenseInfo('05902872-n', 6), SenseInfo('05219097-n', 1), SenseInfo('04768657-n', 0), SenseInfo('04377057-n', 43), SenseInfo('08435388-n', 23), SenseInfo('14981183-n', 14), SenseInfo('05661996-n', 10), SenseInfo('05726596-n', 8), SenseInfo('05237227-n', 7), SenseInfo('05902872-n', 6), SenseInfo('05219097-n', 1), SenseInfo('04768657-n', 0), SenseInfo('04377057-n', 43), SenseInfo('08435388-n', 23), SenseInfo('14981183-n', 14), SenseInfo('05661996-n', 10), SenseInfo('05726596-n', 8), SenseInfo('05237227-n', 7), SenseInfo('05902872-n', 6), SenseInfo('05219097-n', 1), SenseInfo('04768657-n', 0), SenseInfo('04377057-n', 43), SenseInfo('08435388-n', 23), SenseInfo('14981183-n', 14), SenseInfo('05661996-n', 10), SenseInfo('05726596-n', 8), SenseInfo('05237227-n', 7), SenseInfo('05902872-n', 6), SenseInfo('05219097-n', 1), SenseInfo('04768657-n', 0) ],
"_morose_a_1_rel" : [ SenseInfo('01137378-a', 2) ],
"_enormity_n_1_rel" : [ SenseInfo('04903247-n', 1), SenseInfo('05105009-n', 0), SenseInfo('04853124-n', 0), SenseInfo('00746033-n', 0) ],
"_initiator_n_1_rel" : [ SenseInfo('10209082-n', 0) ],
"_violin_n_1_rel" : [ SenseInfo('04536866-n', 3) ],
"_once_a_1_rel" : [  ],
"_win_v_over_rel" : [ SenseInfo('01100145-v', 71), SenseInfo('02288295-v', 42), SenseInfo('01111028-v', 2), SenseInfo('02524171-v', 0) ],
"_granddad_n_1_rel" : [ SenseInfo('10142391-n', 0) ],
"_mulch_v_1_rel" : [ SenseInfo('01234379-v', 0) ],
"_temper_n_1_rel" : [ SenseInfo('07518468-n', 3), SenseInfo('07551052-n', 2), SenseInfo('04642258-n', 2), SenseInfo('05021535-n', 0), SenseInfo('07518468-n', 3), SenseInfo('07551052-n', 2), SenseInfo('04642258-n', 2), SenseInfo('05021535-n', 0) ],
"_age_v_1_rel" : [ SenseInfo('00248512-v', 1), SenseInfo('00248026-v', 1), SenseInfo('00249679-v', 0) ],
"_steal_v_away_rel" : [ SenseInfo('02321757-v', 23), SenseInfo('01888295-v', 4), SenseInfo('01111458-v', 3) ],
"_wheel_v_out_rel" : [ SenseInfo('02046075-v', 7), SenseInfo('02046441-v', 3), SenseInfo('01887020-v', 3), SenseInfo('01935476-v', 0), SenseInfo('02046075-v', 7), SenseInfo('02046441-v', 3), SenseInfo('01887020-v', 3), SenseInfo('01935476-v', 0) ],
"_police_v_1_rel" : [ SenseInfo('02454939-v', 4) ],
"_furry_a_1_rel" : [ SenseInfo('00214001-a', 1) ],
"_doorman_n_1_rel" : [ SenseInfo('10026553-n', 3) ],
"_greek_a_1_rel" : [ SenseInfo('03016202-a', 18) ],
"_bundle_v_up_rel" : [ SenseInfo('01487008-v', 2), SenseInfo('01484392-v', 0), SenseInfo('01483779-v', 0), SenseInfo('00015163-v', 0), SenseInfo('01487008-v', 2), SenseInfo('01484392-v', 0), SenseInfo('01483779-v', 0), SenseInfo('00015163-v', 0) ],
"_loins_n_1_rel" : [ SenseInfo('07658678-n', 0), SenseInfo('02463403-n', 0), SenseInfo('07658678-n', 0), SenseInfo('02463403-n', 0) ],
"_question_v_1_rel" : [ SenseInfo('00867409-v', 17), SenseInfo('00788184-v', 14), SenseInfo('00785008-v', 5), SenseInfo('00808855-v', 3), SenseInfo('00925110-v', 2), SenseInfo('00867409-v', 17), SenseInfo('00788184-v', 14), SenseInfo('00785008-v', 5), SenseInfo('00808855-v', 3), SenseInfo('00925110-v', 2), SenseInfo('00867409-v', 17), SenseInfo('00788184-v', 14), SenseInfo('00785008-v', 5), SenseInfo('00808855-v', 3), SenseInfo('00925110-v', 2), SenseInfo('00867409-v', 17), SenseInfo('00788184-v', 14), SenseInfo('00785008-v', 5), SenseInfo('00808855-v', 3), SenseInfo('00925110-v', 2), SenseInfo('00867409-v', 17), SenseInfo('00788184-v', 14), SenseInfo('00785008-v', 5), SenseInfo('00808855-v', 3), SenseInfo('00925110-v', 2) ],
"_naval_a_1_rel" : [ SenseInfo('02767701-a', 8) ],
"_menial_n_1_rel" : [ SenseInfo('10308938-n', 0) ],
"_online_a_1_rel" : [ SenseInfo('01650883-a', 0), SenseInfo('01650401-a', 0), SenseInfo('00667936-a', 0), SenseInfo('01650883-a', 0), SenseInfo('01650401-a', 0), SenseInfo('00667936-a', 0), SenseInfo('01650883-a', 0), SenseInfo('01650401-a', 0), SenseInfo('00667936-a', 0) ],
"_starlet_n_1_rel" : [ SenseInfo('10649197-n', 1), SenseInfo('09444942-n', 0) ],
"_scalp_v_1_rel" : [ SenseInfo('02241911-v', 0), SenseInfo('00198477-v', 0) ],
"_discorporate_a_1_rel" : [ SenseInfo('00631040-a', 1) ],
"_mandatory_a_1_rel" : [ SenseInfo('00848466-a', 3) ],
"_kronor_n_1_rel" : [  ],
"_thing_n_of-about_rel" : [ SenseInfo('13943968-n', 72), SenseInfo('00034479-n', 52), SenseInfo('05855004-n', 36), SenseInfo('04424218-n', 36), SenseInfo('07289831-n', 32), SenseInfo('05671325-n', 32), SenseInfo('06723908-n', 26), SenseInfo('04424418-n', 26), SenseInfo('04617289-n', 20), SenseInfo('05984182-n', 4), SenseInfo('07480356-n', 0), SenseInfo('00002452-n', 0), SenseInfo('13943968-n', 72), SenseInfo('00034479-n', 52), SenseInfo('05855004-n', 36), SenseInfo('04424218-n', 36), SenseInfo('07289831-n', 32), SenseInfo('05671325-n', 32), SenseInfo('06723908-n', 26), SenseInfo('04424418-n', 26), SenseInfo('04617289-n', 20), SenseInfo('05984182-n', 4), SenseInfo('07480356-n', 0), SenseInfo('00002452-n', 0) ],
"_like+minded_a_1_rel" : [ SenseInfo('01410036-a', 2), SenseInfo('01410036-a', 2), SenseInfo('01410036-a', 2) ],
"_look_v_up-dir_rel" : [ SenseInfo('02130524-v', 274), SenseInfo('02133435-v', 126), SenseInfo('00033599-v', 25), SenseInfo('02153709-v', 8), SenseInfo('02693319-v', 1), SenseInfo('02549581-v', 1), SenseInfo('00929362-v', 1), SenseInfo('00720063-v', 1), SenseInfo('02658447-v', 0), SenseInfo('00712708-v', 0) ],
"_herd_n_of_rel" : [ SenseInfo('07994331-n', 5), SenseInfo('07994555-n', 2), SenseInfo('08183046-n', 0), SenseInfo('07994331-n', 5), SenseInfo('07994555-n', 2), SenseInfo('08183046-n', 0) ],
"_debugger_n_1_rel" : [ SenseInfo('06574334-n', 0) ],
"_button_v_1_rel" : [ SenseInfo('01368126-v', 0), SenseInfo('01367862-v', 0) ],
"_flap_v_1_rel" : [ SenseInfo('01901783-v', 4), SenseInfo('01880888-v', 2), SenseInfo('02093610-v', 1), SenseInfo('02093390-v', 0), SenseInfo('01819911-v', 0), SenseInfo('01055558-v', 0) ],
"_reliability_n_1_rel" : [ SenseInfo('04670022-n', 2) ],
"_unawares_a_1_rel" : [  ],
"_overtired_a_1_rel" : [  ],
"_enthusiast_n_1_rel" : [ SenseInfo('10059582-n', 1), SenseInfo('10078131-n', 0) ],
"_scoot_v_1_rel" : [ SenseInfo('02061495-v', 3), SenseInfo('02061495-v', 3) ],
"_ten+four_a_1_rel" : [  ],
"_equilibrium_n_1_rel" : [ SenseInfo('13934900-n', 4), SenseInfo('13446197-n', 2), SenseInfo('13897996-n', 0), SenseInfo('05659365-n', 0) ],
"_hungry_a_1_rel" : [ SenseInfo('01269073-a', 7), SenseInfo('00888200-a', 1), SenseInfo('01269073-a', 7), SenseInfo('00888200-a', 1), SenseInfo('01269073-a', 7), SenseInfo('00888200-a', 1), SenseInfo('01269073-a', 7), SenseInfo('00888200-a', 1) ],
"_predecessor_n_1_rel" : [ SenseInfo('10464711-n', 4), SenseInfo('06802571-n', 0) ],
"_cloud_v_1_rel" : [ SenseInfo('02770717-v', 1), SenseInfo('02157731-v', 1), SenseInfo('02041577-v', 1), SenseInfo('01769565-v', 0), SenseInfo('01537959-v', 0), SenseInfo('00587962-v', 0), SenseInfo('00510364-v', 0), SenseInfo('00391833-v', 0) ],
"_repurchase_n_1_rel" : [ SenseInfo('00079212-n', 0) ],
"_pour_v_off_rel" : [ SenseInfo('02069551-v', 12), SenseInfo('02028366-v', 7), SenseInfo('02070296-v', 6), SenseInfo('02069248-v', 4), SenseInfo('02355806-v', 1), SenseInfo('02758033-v', 0), SenseInfo('02069551-v', 12), SenseInfo('02028366-v', 7), SenseInfo('02070296-v', 6), SenseInfo('02069248-v', 4), SenseInfo('02355806-v', 1), SenseInfo('02758033-v', 0) ],
"_hostility_n_1_rel" : [ SenseInfo('04658106-n', 3), SenseInfo('13980288-n', 0), SenseInfo('07547805-n', 0), SenseInfo('00964569-n', 0) ],
"_all+night_a_1_rel" : [ SenseInfo('01441530-a', 0), SenseInfo('01441530-a', 0) ],
"_meaningful_a_1_rel" : [ SenseInfo('01496976-a', 8) ],
"_pick+up_n_1_rel" : [ SenseInfo('03930630-n', 2), SenseInfo('06547832-n', 1), SenseInfo('03930777-n', 1), SenseInfo('10432053-n', 0), SenseInfo('05061003-n', 0), SenseInfo('04450465-n', 0), SenseInfo('02971940-n', 0), SenseInfo('01016201-n', 0), SenseInfo('00319176-n', 0), SenseInfo('03930630-n', 2), SenseInfo('06547832-n', 1), SenseInfo('03930777-n', 1), SenseInfo('10432053-n', 0), SenseInfo('05061003-n', 0), SenseInfo('04450465-n', 0), SenseInfo('02971940-n', 0), SenseInfo('01016201-n', 0), SenseInfo('00319176-n', 0) ],
"_US$_n_1_rel" : [  ],
"_shoot_n_1_rel" : [ SenseInfo('13164763-n', 0), SenseInfo('00122954-n', 0) ],
"_criminal_n_1_rel" : [ SenseInfo('09977660-n', 12) ],
"_misjudge_v_1_rel" : [ SenseInfo('00671190-v', 2), SenseInfo('00671190-v', 2) ],
"_hardness_n_1_rel" : [ SenseInfo('04937848-n', 0), SenseInfo('04937587-n', 0), SenseInfo('04844625-n', 0), SenseInfo('04710588-n', 0), SenseInfo('04639732-n', 0) ],
"_trigonometric_a_1_rel" : [ SenseInfo('02912518-a', 0) ],
"_self-determination_n_1_rel" : [ SenseInfo('13992738-n', 3), SenseInfo('05199151-n', 0) ],
"_oilskin_n_1_rel" : [ SenseInfo('03844815-n', 0) ],
"_shuttle_v_1_rel" : [ SenseInfo('02062081-v', 2) ],
"_advantage_n_i_rel" : [ SenseInfo('05155821-n', 23), SenseInfo('13610426-n', 0), SenseInfo('05142863-n', 0) ],
"_snowball_n_1_rel" : [ SenseInfo('11837020-n', 2), SenseInfo('07616265-n', 0), SenseInfo('07616174-n', 0), SenseInfo('04251560-n', 0) ],
"_reverse_n_of_rel" : [ SenseInfo('13858604-n', 1), SenseInfo('04085017-n', 1), SenseInfo('07475870-n', 0), SenseInfo('04085181-n', 0), SenseInfo('00559916-n', 0), SenseInfo('00346693-n', 0), SenseInfo('13858604-n', 1), SenseInfo('04085017-n', 1), SenseInfo('07475870-n', 0), SenseInfo('04085181-n', 0), SenseInfo('00559916-n', 0), SenseInfo('00346693-n', 0) ],
"_stub_v_1_rel" : [ SenseInfo('01567183-v', 0), SenseInfo('01210622-v', 0), SenseInfo('00313354-v', 0), SenseInfo('00102420-v', 0) ],
"_fax_n_1_rel" : [ SenseInfo('03316105-n', 0) ],
"_musician_n_1_rel" : [ SenseInfo('10340312-n', 15), SenseInfo('10339966-n', 3) ],
"_bargain_n_1_rel" : [ SenseInfo('06771159-n', 3), SenseInfo('13253751-n', 0) ],
"_golf_n_1_rel" : [ SenseInfo('00464894-n', 9) ],
"_tableau_n_1_rel" : [ SenseInfo('08372715-n', 1), SenseInfo('05934780-n', 1) ],
"_escort_v_1_rel" : [ SenseInfo('02025829-v', 7), SenseInfo('02026086-v', 0) ],
"_poisonous_a_1_rel" : [ SenseInfo('02450512-a', 0), SenseInfo('00829656-a', 0), SenseInfo('00226105-a', 0) ],
"_slow_v_1_rel" : [ SenseInfo('00439958-v', 9), SenseInfo('00440580-v', 2), SenseInfo('00440786-v', 1) ],
"_live-in_a_1_rel" : [  ],
"_uncommon_a_1_rel" : [ SenseInfo('00487653-a', 4), SenseInfo('01678112-a', 0), SenseInfo('00487653-a', 4), SenseInfo('01678112-a', 0), SenseInfo('00487653-a', 4), SenseInfo('01678112-a', 0) ],
"_warm+up_n_1_rel" : [ SenseInfo('01144716-n', 1), SenseInfo('01144716-n', 1) ],
"_at+liberty_a_1_rel" : [  ],
"_lift_v_up_rel" : [ SenseInfo('01974062-v', 31), SenseInfo('01579153-v', 10), SenseInfo('01973759-v', 2), SenseInfo('01968569-v', 2), SenseInfo('00986074-v', 2), SenseInfo('00799798-v', 2), SenseInfo('02276866-v', 1), SenseInfo('01455184-v', 1), SenseInfo('00549982-v', 1), SenseInfo('00544549-v', 1), SenseInfo('00178652-v', 1), SenseInfo('02696801-v', 0), SenseInfo('02352181-v', 0), SenseInfo('02278061-v', 0), SenseInfo('02277138-v', 0), SenseInfo('01452057-v', 0), SenseInfo('01311608-v', 0), SenseInfo('00792921-v', 0), SenseInfo('00357198-v', 0), SenseInfo('00354195-v', 0), SenseInfo('00198623-v', 0), SenseInfo('00178773-v', 0), SenseInfo('00178502-v', 0), SenseInfo('00061933-v', 0), SenseInfo('01974062-v', 31), SenseInfo('01579153-v', 10), SenseInfo('01973759-v', 2), SenseInfo('01968569-v', 2), SenseInfo('00986074-v', 2), SenseInfo('00799798-v', 2), SenseInfo('02276866-v', 1), SenseInfo('01455184-v', 1), SenseInfo('00549982-v', 1), SenseInfo('00544549-v', 1), SenseInfo('00178652-v', 1), SenseInfo('02696801-v', 0), SenseInfo('02352181-v', 0), SenseInfo('02278061-v', 0), SenseInfo('02277138-v', 0), SenseInfo('01452057-v', 0), SenseInfo('01311608-v', 0), SenseInfo('00792921-v', 0), SenseInfo('00357198-v', 0), SenseInfo('00354195-v', 0), SenseInfo('00198623-v', 0), SenseInfo('00178773-v', 0), SenseInfo('00178502-v', 0), SenseInfo('00061933-v', 0) ],
"_derby_n_1_rel" : [ SenseInfo('02881757-n', 0) ],
"_conceptacle_n_1_rel" : [  ],
"_needful_a_1_rel" : [ SenseInfo('01580775-a', 0) ],
"_slave_n_1_rel" : [ SenseInfo('10609325-n', 18), SenseInfo('10609556-n', 1), SenseInfo('10609686-n', 0) ],
"_wash_v_up_rel" : [ SenseInfo('01270199-v', 13), SenseInfo('00036362-v', 9), SenseInfo('01535246-v', 7), SenseInfo('02098179-v', 2), SenseInfo('02742842-v', 0), SenseInfo('02703153-v', 0), SenseInfo('01536344-v', 0), SenseInfo('01269844-v', 0), SenseInfo('00557686-v', 0), SenseInfo('00274942-v', 0), SenseInfo('00217956-v', 0), SenseInfo('00217576-v', 0), SenseInfo('00036178-v', 0), SenseInfo('01270199-v', 13), SenseInfo('00036362-v', 9), SenseInfo('01535246-v', 7), SenseInfo('02098179-v', 2), SenseInfo('02742842-v', 0), SenseInfo('02703153-v', 0), SenseInfo('01536344-v', 0), SenseInfo('01269844-v', 0), SenseInfo('00557686-v', 0), SenseInfo('00274942-v', 0), SenseInfo('00217956-v', 0), SenseInfo('00217576-v', 0), SenseInfo('00036178-v', 0) ],
"_pace_p_latin_rel" : [ SenseInfo('15280497-n', 10), SenseInfo('01929254-v', 10), SenseInfo('13757249-n', 6), SenseInfo('02091165-v', 6), SenseInfo('05058580-n', 4), SenseInfo('00490722-v', 2), SenseInfo('00285889-n', 1), SenseInfo('15283097-n', 0), SenseInfo('13650447-n', 0), SenseInfo('00702601-v', 0) ],
"_treble_v_1_rel" : [ SenseInfo('01051271-v', 0), SenseInfo('00246746-v', 0) ],
"_door_n_1_rel" : [ SenseInfo('03221720-n', 98), SenseInfo('03224032-n', 36), SenseInfo('05180881-n', 5), SenseInfo('03222318-n', 0), SenseInfo('03222176-n', 0) ],
"_fantastic_a_1_rel" : [ SenseInfo('00967646-a', 4), SenseInfo('01676517-a', 3), SenseInfo('01942732-a', 2), SenseInfo('01936778-a', 1), SenseInfo('01796452-a', 0), SenseInfo('00967646-a', 4), SenseInfo('01676517-a', 3), SenseInfo('01942732-a', 2), SenseInfo('01936778-a', 1), SenseInfo('01796452-a', 0) ],
"_choose_v_as_rel" : [ SenseInfo('00674607-v', 80), SenseInfo('00679389-v', 19), SenseInfo('00679937-v', 11), SenseInfo('00674607-v', 80), SenseInfo('00679389-v', 19), SenseInfo('00679937-v', 11) ],
"_opinion_n_of_rel" : [ SenseInfo('05945642-n', 21), SenseInfo('06782019-n', 4), SenseInfo('05949726-n', 3), SenseInfo('06551784-n', 2), SenseInfo('01191158-n', 2), SenseInfo('05916739-n', 0), SenseInfo('05945642-n', 21), SenseInfo('06782019-n', 4), SenseInfo('05949726-n', 3), SenseInfo('06551784-n', 2), SenseInfo('01191158-n', 2), SenseInfo('05916739-n', 0), SenseInfo('05945642-n', 21), SenseInfo('06782019-n', 4), SenseInfo('05949726-n', 3), SenseInfo('06551784-n', 2), SenseInfo('01191158-n', 2), SenseInfo('05916739-n', 0) ],
"_textile_n_1_rel" : [ SenseInfo('03309808-n', 7), SenseInfo('03309808-n', 7), SenseInfo('03309808-n', 7) ],
"_bandstand_n_1_rel" : [ SenseInfo('02786984-n', 1) ],
"_surrender_v_1_rel" : [ SenseInfo('01115585-v', 5), SenseInfo('02235229-v', 2), SenseInfo('01115585-v', 5), SenseInfo('02235229-v', 2) ],
"_parchment_n_1_rel" : [ SenseInfo('14975779-n', 1), SenseInfo('14759003-n', 0) ],
"_slaughter_n_1_rel" : [ SenseInfo('00223854-n', 3), SenseInfo('07476623-n', 1), SenseInfo('00223983-n', 0) ],
"_callosity_n_1_rel" : [ SenseInfo('14364566-n', 0), SenseInfo('04844625-n', 0) ],
"_rainy_a_1_rel" : [ SenseInfo('02550333-a', 0), SenseInfo('02550333-a', 0), SenseInfo('02550333-a', 0), SenseInfo('02550333-a', 0), SenseInfo('02550333-a', 0), SenseInfo('02550333-a', 0) ],
"_amenity_n_1_rel" : [ SenseInfo('04779053-n', 0), SenseInfo('04779053-n', 0), SenseInfo('04779053-n', 0) ],
"_jeans_n_1_rel" : [ SenseInfo('03594734-n', 0), SenseInfo('03175189-n', 0), SenseInfo('03594734-n', 0), SenseInfo('03175189-n', 0) ],
"_unpromising_a_1_rel" : [ SenseInfo('00176991-a', 1), SenseInfo('00176991-a', 1) ],
"_distasteful_a_1_rel" : [ SenseInfo('01716971-a', 0), SenseInfo('01625893-a', 0), SenseInfo('01716971-a', 0), SenseInfo('01625893-a', 0), SenseInfo('01716971-a', 0), SenseInfo('01625893-a', 0) ],
"_wait_v_for_rel" : [ SenseInfo('02637938-v', 100), SenseInfo('02641463-v', 49), SenseInfo('00720063-v', 33), SenseInfo('02413290-v', 2) ],
"_shucks_a_1_rel" : [ SenseInfo('05140793-n', 1), SenseInfo('06605682-n', 0), SenseInfo('05140793-n', 1), SenseInfo('06605682-n', 0) ],
"_garden_n_1_rel" : [ SenseInfo('03417345-n', 7), SenseInfo('08439808-n', 6), SenseInfo('03417749-n', 6), SenseInfo('03417345-n', 7), SenseInfo('08439808-n', 6), SenseInfo('03417749-n', 6) ],
"_lean_v_toward_rel" : [ SenseInfo('02038357-v', 24), SenseInfo('01606574-v', 6), SenseInfo('02719399-v', 3), SenseInfo('00688261-v', 1), SenseInfo('02039013-v', 0) ],
"_USA_n_1_rel" : [ SenseInfo('09044862-n', 0), SenseInfo('08394922-n', 0) ],
"_basin_n_1_rel" : [ SenseInfo('02801525-n', 2), SenseInfo('13765086-n', 0), SenseInfo('09215437-n', 0), SenseInfo('08518940-n', 0), SenseInfo('04553920-n', 0) ],
"_toward_p_rel" : [  ],
"_fidget_v_1_rel" : [ SenseInfo('02058448-v', 2) ],
"_undertake_v_1_rel" : [ SenseInfo('01651293-v', 26), SenseInfo('02569630-v', 2), SenseInfo('00889555-v', 2), SenseInfo('00888786-v', 2), SenseInfo('02539686-v', 0), SenseInfo('01651293-v', 26), SenseInfo('02569630-v', 2), SenseInfo('00889555-v', 2), SenseInfo('00888786-v', 2), SenseInfo('02539686-v', 0) ],
"_exuberant_a_1_rel" : [ SenseInfo('02279723-a', 4), SenseInfo('02000968-a', 0), SenseInfo('00015247-a', 0) ],
"_kbit_n_1_rel" : [ SenseInfo('13627810-n', 0) ],
"_schematic_n_1_rel" : [ SenseInfo('04145578-n', 0) ],
"_toxin_n_1_rel" : [ SenseInfo('15034074-n', 1) ],
"_sculptor_n_1_rel" : [ SenseInfo('10566072-n', 3), SenseInfo('09426494-n', 0) ],
"_stop_v_1_rel" : [ SenseInfo('01860795-v', 57), SenseInfo('02680814-v', 56), SenseInfo('02559752-v', 25), SenseInfo('01862918-v', 7), SenseInfo('01859221-v', 7), SenseInfo('00362348-v', 4), SenseInfo('01131473-v', 3), SenseInfo('01440378-v', 2), SenseInfo('02609764-v', 1), SenseInfo('01478002-v', 0), SenseInfo('00362610-v', 0) ],
"_sudden_a_1_rel" : [ SenseInfo('01143279-a', 33), SenseInfo('01143279-a', 33), SenseInfo('01143279-a', 33) ],
"_loyalty_n_to_rel" : [ SenseInfo('04877530-n', 7), SenseInfo('07546389-n', 2), SenseInfo('01206153-n', 1), SenseInfo('04877530-n', 7), SenseInfo('07546389-n', 2), SenseInfo('01206153-n', 1) ],
"_dramaturgy_n_1_rel" : [ SenseInfo('07006119-n', 0) ],
"_empty_a_1_rel" : [ SenseInfo('01086545-a', 30), SenseInfo('01498084-a', 6), SenseInfo('01269319-a', 0), SenseInfo('01088749-a', 0), SenseInfo('01086545-a', 30), SenseInfo('01498084-a', 6), SenseInfo('01269319-a', 0), SenseInfo('01088749-a', 0) ],
"_mat_v_1_rel" : [ SenseInfo('01462928-v', 0), SenseInfo('00565592-v', 0) ],
"_weigh_v_1_rel" : [ SenseInfo('02704818-v', 17), SenseInfo('00950431-v', 4), SenseInfo('02704617-v', 2), SenseInfo('02645839-v', 1), SenseInfo('02646064-v', 0) ],
"_stop_v_by_rel" : [ SenseInfo('01860795-v', 57), SenseInfo('02680814-v', 56), SenseInfo('02559752-v', 25), SenseInfo('01862918-v', 7), SenseInfo('01859221-v', 7), SenseInfo('00362348-v', 4), SenseInfo('01131473-v', 3), SenseInfo('01440378-v', 2), SenseInfo('02609764-v', 1), SenseInfo('01478002-v', 0), SenseInfo('00362610-v', 0) ],
"_misplace_v_1_rel" : [ SenseInfo('01503101-v', 1), SenseInfo('01501793-v', 1) ],
"_act_v_up_rel" : [ SenseInfo('02367363-v', 35), SenseInfo('00010435-v', 22), SenseInfo('01719302-v', 7), SenseInfo('01095899-v', 4), SenseInfo('00013615-v', 1), SenseInfo('02744977-v', 0), SenseInfo('02525447-v', 0), SenseInfo('02419073-v', 0), SenseInfo('01721556-v', 0), SenseInfo('01719921-v', 0) ],
"_almost_a_1_rel" : [  ],
"_succumb_v_to_rel" : [ SenseInfo('00804476-v', 4), SenseInfo('02620466-v', 0) ],
"_intelligibility_n_1_rel" : [ SenseInfo('04819496-n', 0) ],
"_stop_v_over_rel" : [ SenseInfo('01860795-v', 57), SenseInfo('02680814-v', 56), SenseInfo('02559752-v', 25), SenseInfo('01862918-v', 7), SenseInfo('01859221-v', 7), SenseInfo('00362348-v', 4), SenseInfo('01131473-v', 3), SenseInfo('01440378-v', 2), SenseInfo('02609764-v', 1), SenseInfo('01478002-v', 0), SenseInfo('00362610-v', 0) ],
"_cobalt_a_1_rel" : [ SenseInfo('14635290-n', 0) ],
"_effect_v_1_rel" : [ SenseInfo('01642924-v', 17), SenseInfo('02560767-v', 3) ],
"_embark_v_1_rel" : [ SenseInfo('01979462-v', 1), SenseInfo('00348252-v', 1), SenseInfo('02373336-v', 0), SenseInfo('01979462-v', 1), SenseInfo('00348252-v', 1), SenseInfo('02373336-v', 0) ],
"_doctor_n_1_rel" : [ SenseInfo('10020890-n', 73), SenseInfo('10022111-n', 1), SenseInfo('00432356-n', 1), SenseInfo('10021892-n', 0) ],
"_unabashed_a_1_rel" : [ SenseInfo('00155886-a', 0), SenseInfo('00155886-a', 0) ],
"_march_v_cause_rel" : [ SenseInfo('01996735-v', 24), SenseInfo('02084380-v', 5), SenseInfo('01919391-v', 5), SenseInfo('02521816-v', 1), SenseInfo('01924712-v', 1), SenseInfo('02084587-v', 0), SenseInfo('01466978-v', 0) ],
"_coyote_n_1_rel" : [ SenseInfo('02114855-n', 1), SenseInfo('09973903-n', 0), SenseInfo('09973749-n', 0) ],
"_lengthen_v_1_rel" : [ SenseInfo('00317700-v', 1), SenseInfo('00316631-v', 0) ],
"_spoke_n_1_rel" : [ SenseInfo('04283378-n', 2), SenseInfo('04119751-n', 0) ],
"_uprightness_n_1_rel" : [ SenseInfo('05083054-n', 0), SenseInfo('05079638-n', 0), SenseInfo('04826623-n', 0) ],
"_motto_n_1_rel" : [ SenseInfo('07152259-n', 2) ],
"_biscuit_n_1_rel" : [ SenseInfo('07693972-n', 4), SenseInfo('07635155-n', 1), SenseInfo('07693972-n', 4), SenseInfo('07635155-n', 1) ],
"_grease_v_1_rel" : [ SenseInfo('01269379-v', 1) ],
"_color_v_1_rel" : [ SenseInfo('00283911-v', 7), SenseInfo('00836926-v', 2), SenseInfo('02537092-v', 1), SenseInfo('01696648-v', 0), SenseInfo('00837133-v', 0), SenseInfo('00281101-v', 0), SenseInfo('00283911-v', 7), SenseInfo('00836926-v', 2), SenseInfo('02537092-v', 1), SenseInfo('01696648-v', 0), SenseInfo('00837133-v', 0), SenseInfo('00281101-v', 0), SenseInfo('00283911-v', 7), SenseInfo('00836926-v', 2), SenseInfo('02537092-v', 1), SenseInfo('01696648-v', 0), SenseInfo('00837133-v', 0), SenseInfo('00281101-v', 0), SenseInfo('00283911-v', 7), SenseInfo('00836926-v', 2), SenseInfo('02537092-v', 1), SenseInfo('01696648-v', 0), SenseInfo('00837133-v', 0), SenseInfo('00281101-v', 0) ],
"_belong_v_to_rel" : [ SenseInfo('02301680-v', 10), SenseInfo('02737724-v', 4), SenseInfo('02737876-v', 3), SenseInfo('02737569-v', 2), SenseInfo('02756359-v', 0), SenseInfo('02719930-v', 0), SenseInfo('02301680-v', 10), SenseInfo('02737724-v', 4), SenseInfo('02737876-v', 3), SenseInfo('02737569-v', 2), SenseInfo('02756359-v', 0), SenseInfo('02719930-v', 0) ],
"_plenty_x_deg_rel" : [ SenseInfo('05115568-n', 13), SenseInfo('00145713-r', 6), SenseInfo('13774404-n', 2) ],
"_pat_n_1_rel" : [ SenseInfo('07388987-n', 0), SenseInfo('00125436-n', 0) ],
"_dizziness_n_1_rel" : [ SenseInfo('14372513-n', 0) ],
"_duct_n_1_rel" : [ SenseInfo('05250659-n', 2), SenseInfo('13091057-n', 0), SenseInfo('03253398-n', 0) ],
"_fan_v_1_rel" : [ SenseInfo('01409763-v', 3), SenseInfo('00227805-v', 2), SenseInfo('01885580-v', 1), SenseInfo('01460937-v', 0) ],
"_aboard_p_rel" : [ SenseInfo('00249878-r', 4), SenseInfo('00249736-r', 1), SenseInfo('00250056-r', 0), SenseInfo('00249964-r', 0), SenseInfo('00249878-r', 4), SenseInfo('00249736-r', 1), SenseInfo('00250056-r', 0), SenseInfo('00249964-r', 0), SenseInfo('00249878-r', 4), SenseInfo('00249736-r', 1), SenseInfo('00250056-r', 0), SenseInfo('00249964-r', 0) ],
"_polyol_n_1_rel" : [  ],
"_paraphernalia_n_1_rel" : [ SenseInfo('03430959-n', 1) ],
"_digital_n_1_rel" : [ SenseInfo('02713232-a', 0), SenseInfo('02713096-a', 0), SenseInfo('00110701-a', 0) ],
"_rank-order_v_1_rel" : [  ],
"_quartet_n_of_rel" : [ SenseInfo('13744304-n', 0), SenseInfo('08247251-n', 0), SenseInfo('07988089-n', 0), SenseInfo('07987380-n', 0), SenseInfo('07041688-n', 0) ],
"_refrigerator_n_1_rel" : [ SenseInfo('04070727-n', 2) ],
"_panda_n_1_rel" : [ SenseInfo('02510455-n', 0), SenseInfo('02509815-n', 0) ],
"_long+ago_p_rel" : [ SenseInfo('00022401-r', 14) ],
"_overhaul_v_1_rel" : [ SenseInfo('02049696-v', 1), SenseInfo('00262076-v', 1) ],
"_pivot_v_around_rel" : [ SenseInfo('02046572-v', 1) ],
"_width_n_of_rel" : [ SenseInfo('05136150-n', 4) ],
"_buck_v_1_rel" : [ SenseInfo('02531500-v', 2), SenseInfo('02378851-v', 1), SenseInfo('02055267-v', 0), SenseInfo('01884383-v', 0) ],
"_click_n_1_rel" : [ SenseInfo('07379223-n', 2), SenseInfo('07118210-n', 0), SenseInfo('03901548-n', 0), SenseInfo('00112828-n', 0) ],
"_vicissitude_n_1_rel" : [ SenseInfo('07337694-n', 0), SenseInfo('04741655-n', 0) ],
"_confidential_a_1_rel" : [ SenseInfo('01859801-a', 2), SenseInfo('01859571-a', 0), SenseInfo('00452605-a', 0), SenseInfo('00415696-a', 0) ],
"_glove_n_1_rel" : [ SenseInfo('02800213-n', 6), SenseInfo('03441112-n', 0), SenseInfo('02885462-n', 0) ],
"_leftover_a_1_rel" : [ SenseInfo('00926505-a', 0) ],
"_lastnamed_a_1_rel" : [  ],
"_threedot-pnct_a_1_rel" : [  ],
"_yuan_n_1_rel" : [ SenseInfo('13709992-n', 0), SenseInfo('08160146-n', 0) ],
"_thicken_v_cause_rel" : [ SenseInfo('00431327-v', 2), SenseInfo('00431117-v', 2), SenseInfo('00431610-v', 0) ],
"_electromagnetic_a_1_rel" : [ SenseInfo('02926320-a', 1), SenseInfo('02926320-a', 1) ],
"_dominant_a_1_rel" : [ SenseInfo('00791227-a', 51), SenseInfo('00793793-a', 0), SenseInfo('01066787-a', 0) ],
"_blow_v_1_rel" : [ SenseInfo('00007012-v', 6), SenseInfo('02769241-v', 5), SenseInfo('00034948-v', 3), SenseInfo('01902783-v', 2), SenseInfo('02135877-v', 1), SenseInfo('00477247-v', 1), SenseInfo('02527651-v', 0), SenseInfo('02268351-v', 0), SenseInfo('02266148-v', 0), SenseInfo('02178340-v', 0), SenseInfo('02135727-v', 0), SenseInfo('02117170-v', 0), SenseInfo('02101046-v', 0), SenseInfo('02100632-v', 0), SenseInfo('02068745-v', 0), SenseInfo('01849054-v', 0), SenseInfo('01545208-v', 0), SenseInfo('00934965-v', 0), SenseInfo('00883226-v', 0), SenseInfo('00779804-v', 0), SenseInfo('00435294-v', 0), SenseInfo('00310155-v', 0), SenseInfo('00007012-v', 6), SenseInfo('02769241-v', 5), SenseInfo('00034948-v', 3), SenseInfo('01902783-v', 2), SenseInfo('02135877-v', 1), SenseInfo('00477247-v', 1), SenseInfo('02527651-v', 0), SenseInfo('02268351-v', 0), SenseInfo('02266148-v', 0), SenseInfo('02178340-v', 0), SenseInfo('02135727-v', 0), SenseInfo('02117170-v', 0), SenseInfo('02101046-v', 0), SenseInfo('02100632-v', 0), SenseInfo('02068745-v', 0), SenseInfo('01849054-v', 0), SenseInfo('01545208-v', 0), SenseInfo('00934965-v', 0), SenseInfo('00883226-v', 0), SenseInfo('00779804-v', 0), SenseInfo('00435294-v', 0), SenseInfo('00310155-v', 0) ],
"_helicobacter+pylori_n_1_rel" : [  ],
"_bristle_n_1_rel" : [ SenseInfo('02902535-n', 5), SenseInfo('01901610-n', 1) ],
"_swerve_n_1_rel" : [ SenseInfo('01263257-n', 1), SenseInfo('07411350-n', 0) ],
"_chug_v_1_rel" : [ SenseInfo('02179372-v', 1) ],
"_revival_n_of_rel" : [ SenseInfo('01047338-n', 1), SenseInfo('08386143-n', 0) ],
"_squad_n_of_rel" : [ SenseInfo('08218122-n', 8), SenseInfo('08208560-n', 4), SenseInfo('08080947-n', 0), SenseInfo('08218122-n', 8), SenseInfo('08208560-n', 4), SenseInfo('08080947-n', 0) ],
"_lolly_n_1_rel" : [ SenseInfo('13385216-n', 0), SenseInfo('07615774-n', 0) ],
"_loft_v_1_rel" : [ SenseInfo('02282252-v', 0), SenseInfo('01604442-v', 0), SenseInfo('01604012-v', 0), SenseInfo('00711420-v', 0), SenseInfo('02282252-v', 0), SenseInfo('01604442-v', 0), SenseInfo('01604012-v', 0), SenseInfo('00711420-v', 0) ],
"_drain_n_1_rel" : [ SenseInfo('00396029-n', 1), SenseInfo('03232158-n', 0), SenseInfo('03231912-n', 0), SenseInfo('01062255-n', 0) ],
"_take_v_up_rel" : [ SenseInfo('02599636-v', 92), SenseInfo('02267989-v', 74), SenseInfo('01999798-v', 73), SenseInfo('01214265-v', 50), SenseInfo('00524682-v', 38), SenseInfo('00624476-v', 36), SenseInfo('02077656-v', 32), SenseInfo('02205272-v', 28), SenseInfo('01842690-v', 26), SenseInfo('00674607-v', 26), SenseInfo('02236124-v', 25), SenseInfo('02394183-v', 22), SenseInfo('00734054-v', 22), SenseInfo('02627934-v', 21), SenseInfo('02109045-v', 21), SenseInfo('01002740-v', 16), SenseInfo('00173338-v', 16), SenseInfo('01156834-v', 15), SenseInfo('00669762-v', 15), SenseInfo('02209936-v', 14), SenseInfo('02206619-v', 13), SenseInfo('01982395-v', 10), SenseInfo('02236624-v', 8), SenseInfo('00523095-v', 7), SenseInfo('00599992-v', 6), SenseInfo('00756076-v', 5), SenseInfo('02075857-v', 4), SenseInfo('01151110-v', 4), SenseInfo('00557404-v', 4), SenseInfo('02717102-v', 2), SenseInfo('02208537-v', 2), SenseInfo('02209745-v', 1), SenseInfo('02208118-v', 1), SenseInfo('02201138-v', 1), SenseInfo('01427127-v', 1), SenseInfo('00758333-v', 1), SenseInfo('02741546-v', 0), SenseInfo('02701210-v', 0), SenseInfo('02590253-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01100830-v', 0), SenseInfo('00087736-v', 0) ],
"_oversight_n_1_rel" : [ SenseInfo('05706815-n', 0), SenseInfo('01135529-n', 0), SenseInfo('00074524-n', 0) ],
"_journalese_n_1_rel" : [ SenseInfo('07071250-n', 2) ],
"_lavatory_n_1_rel" : [ SenseInfo('04446276-n', 2), SenseInfo('04553920-n', 0), SenseInfo('03371875-n', 0) ],
"_maroon_v_1_rel" : [ SenseInfo('02228355-v', 1), SenseInfo('00496489-v', 0) ],
"_suck_v_2_rel" : [ SenseInfo('01169704-v', 4), SenseInfo('01854888-v', 2), SenseInfo('02765692-v', 0), SenseInfo('02674340-v', 0), SenseInfo('02117170-v', 0), SenseInfo('01539063-v', 0), SenseInfo('01186428-v', 0) ],
"_catfish_n_1_rel" : [ SenseInfo('07780038-n', 0), SenseInfo('02616851-n', 0), SenseInfo('02517442-n', 0) ],
"_covetous_a_1_rel" : [ SenseInfo('00888765-a', 0), SenseInfo('00029933-a', 0) ],
"_mash_n_1_rel" : [ SenseInfo('14948645-n', 0), SenseInfo('07805254-n', 0) ],
"_sober_v_up_rel" : [ SenseInfo('00149469-v', 0), SenseInfo('00149296-v', 0), SenseInfo('00149118-v', 0), SenseInfo('00149469-v', 0), SenseInfo('00149296-v', 0), SenseInfo('00149118-v', 0) ],
"_philanthropist_n_1_rel" : [ SenseInfo('10421956-n', 1) ],
"_excitation_n_of_rel" : [ SenseInfo('14037011-n', 0), SenseInfo('14036356-n', 0), SenseInfo('01260867-n', 0) ],
"_war_v_1_rel" : [ SenseInfo('01093172-v', 0) ],
"_talk_v_about_rel" : [ SenseInfo('00962447-v', 108), SenseInfo('00941990-v', 26), SenseInfo('00963570-v', 8), SenseInfo('00952841-v', 4), SenseInfo('00937208-v', 2), SenseInfo('00830761-v', 0), SenseInfo('00962447-v', 108), SenseInfo('00941990-v', 26), SenseInfo('00963570-v', 8), SenseInfo('00952841-v', 4), SenseInfo('00937208-v', 2), SenseInfo('00830761-v', 0) ],
"_tail_v_off_rel" : [ SenseInfo('02001858-v', 0), SenseInfo('01556178-v', 0), SenseInfo('01321796-v', 0) ],
"_drug_v_1_rel" : [ SenseInfo('00084738-v', 1), SenseInfo('01200440-v', 0), SenseInfo('00084738-v', 1), SenseInfo('01200440-v', 0) ],
"_clutch_v_1_rel" : [ SenseInfo('01212572-v', 16), SenseInfo('01220303-v', 1), SenseInfo('00737656-v', 0) ],
"_corner_n_of_rel" : [ SenseInfo('08544419-n', 20), SenseInfo('08544275-n', 15), SenseInfo('03109881-n', 11), SenseInfo('03109486-n', 9), SenseInfo('08659993-n', 5), SenseInfo('13872421-n', 3), SenseInfo('14445072-n', 1), SenseInfo('14408951-n', 1), SenseInfo('09257011-n', 1), SenseInfo('08544593-n', 0), SenseInfo('03109693-n', 0) ],
"_sci-fi_n_1_rel" : [  ],
"_stir_v_up_rel" : [ SenseInfo('01894320-v', 7), SenseInfo('01893988-v', 5), SenseInfo('02116118-v', 4), SenseInfo('01761706-v', 4), SenseInfo('01770802-v', 1), SenseInfo('01629958-v', 1), SenseInfo('01894164-v', 0), SenseInfo('01541467-v', 0) ],
"_breakdown_n_1_rel" : [ SenseInfo('00553362-n', 5), SenseInfo('14066492-n', 0), SenseInfo('07421316-n', 0), SenseInfo('05781800-n', 0), SenseInfo('00553362-n', 5), SenseInfo('14066492-n', 0), SenseInfo('07421316-n', 0), SenseInfo('05781800-n', 0), SenseInfo('00553362-n', 5), SenseInfo('14066492-n', 0), SenseInfo('07421316-n', 0), SenseInfo('05781800-n', 0) ],
"_make_v_of_rel" : [ SenseInfo('02560585-v', 508), SenseInfo('00120316-v', 459), SenseInfo('01617192-v', 243), SenseInfo('00770437-v', 85), SenseInfo('01645601-v', 78), SenseInfo('01621555-v', 52), SenseInfo('00730758-v', 33), SenseInfo('01646075-v', 17), SenseInfo('01640207-v', 16), SenseInfo('02289295-v', 14), SenseInfo('01619014-v', 14), SenseInfo('02621395-v', 12), SenseInfo('02022162-v', 12), SenseInfo('02674708-v', 10), SenseInfo('01653873-v', 9), SenseInfo('01755816-v', 8), SenseInfo('01654628-v', 5), SenseInfo('00556855-v', 5), SenseInfo('00012267-v', 5), SenseInfo('02396716-v', 4), SenseInfo('02355596-v', 4), SenseInfo('02020590-v', 4), SenseInfo('00665476-v', 4), SenseInfo('02582921-v', 3), SenseInfo('02598483-v', 2), SenseInfo('01733477-v', 2), SenseInfo('00276068-v', 2), SenseInfo('02075857-v', 1), SenseInfo('00074038-v', 1), SenseInfo('02748759-v', 0), SenseInfo('02748627-v', 0), SenseInfo('02745332-v', 0), SenseInfo('02665124-v', 0), SenseInfo('02621133-v', 0), SenseInfo('02134050-v', 0), SenseInfo('02051031-v', 0), SenseInfo('02021532-v', 0), SenseInfo('01755504-v', 0), SenseInfo('01664172-v', 0), SenseInfo('01428578-v', 0), SenseInfo('00891038-v', 0), SenseInfo('00838524-v', 0), SenseInfo('00698256-v', 0), SenseInfo('00698104-v', 0), SenseInfo('00562182-v', 0), SenseInfo('00562067-v', 0), SenseInfo('00545953-v', 0), SenseInfo('00107369-v', 0), SenseInfo('00072012-v', 0) ],
"_mobility_n_1_rel" : [ SenseInfo('04773351-n', 2) ],
"_assist_v_1_rel" : [ SenseInfo('02547586-v', 21), SenseInfo('02414710-v', 4), SenseInfo('02540670-v', 0) ],
"_calm_v_1_rel" : [ SenseInfo('01764800-v', 5), SenseInfo('00416571-v', 1), SenseInfo('01763829-v', 0), SenseInfo('00022316-v', 0), SenseInfo('01764800-v', 5), SenseInfo('00416571-v', 1), SenseInfo('01763829-v', 0), SenseInfo('00022316-v', 0), SenseInfo('01764800-v', 5), SenseInfo('00416571-v', 1), SenseInfo('01763829-v', 0), SenseInfo('00022316-v', 0), SenseInfo('01764800-v', 5), SenseInfo('00416571-v', 1), SenseInfo('01763829-v', 0), SenseInfo('00022316-v', 0), SenseInfo('01764800-v', 5), SenseInfo('00416571-v', 1), SenseInfo('01763829-v', 0), SenseInfo('00022316-v', 0) ],
"_increase_v_cause_rel" : [ SenseInfo('00156601-v', 86), SenseInfo('00153263-v', 61) ],
"_stay_n_1_rel" : [ SenseInfo('01053617-n', 2), SenseInfo('14010927-n', 0), SenseInfo('06542267-n', 0), SenseInfo('04307619-n', 0), SenseInfo('04307419-n', 0) ],
"_airfield_n_1_rel" : [ SenseInfo('02687992-n', 0) ],
"_poll_v_1_rel" : [ SenseInfo('02454312-v', 1), SenseInfo('02463298-v', 0), SenseInfo('02454835-v', 0), SenseInfo('01320669-v', 0) ],
"_right_n_of_rel" : [ SenseInfo('05174653-n', 41), SenseInfo('08625073-n', 27), SenseInfo('04091839-n', 5), SenseInfo('08416652-n', 4), SenseInfo('05565337-n', 2), SenseInfo('00351000-n', 2), SenseInfo('04850341-n', 1), SenseInfo('13341756-n', 0) ],
"_pull_v_away_rel" : [ SenseInfo('01448100-v', 44), SenseInfo('01505254-v', 8), SenseInfo('02057499-v', 6), SenseInfo('01609287-v', 3), SenseInfo('02582615-v', 2), SenseInfo('01995211-v', 2), SenseInfo('02057337-v', 1), SenseInfo('00071803-v', 1), SenseInfo('02103162-v', 0), SenseInfo('01947247-v', 0), SenseInfo('01858573-v', 0), SenseInfo('01573276-v', 0), SenseInfo('01407059-v', 0), SenseInfo('01384275-v', 0), SenseInfo('01351170-v', 0), SenseInfo('01148710-v', 0), SenseInfo('00571596-v', 0), SenseInfo('01448100-v', 44), SenseInfo('01505254-v', 8), SenseInfo('02057499-v', 6), SenseInfo('01609287-v', 3), SenseInfo('02582615-v', 2), SenseInfo('01995211-v', 2), SenseInfo('02057337-v', 1), SenseInfo('00071803-v', 1), SenseInfo('02103162-v', 0), SenseInfo('01947247-v', 0), SenseInfo('01858573-v', 0), SenseInfo('01573276-v', 0), SenseInfo('01407059-v', 0), SenseInfo('01384275-v', 0), SenseInfo('01351170-v', 0), SenseInfo('01148710-v', 0), SenseInfo('00571596-v', 0) ],
"_friend_n_1_rel" : [ SenseInfo('10112591-n', 169), SenseInfo('09785042-n', 1), SenseInfo('09763784-n', 1), SenseInfo('10677713-n', 0), SenseInfo('09679708-n', 0) ],
"_subpage_n_1_rel" : [  ],
"_effervesce_v_1_rel" : [ SenseInfo('00519363-v', 0) ],
"_valedictory_n_1_rel" : [ SenseInfo('07243565-n', 0) ],
"_woodland_n_1_rel" : [ SenseInfo('09284015-n', 0) ],
"_involuntary_a_1_rel" : [ SenseInfo('02521353-a', 1), SenseInfo('02522417-a', 0), SenseInfo('02521353-a', 1), SenseInfo('02522417-a', 0) ],
"_arresting_a_1_rel" : [ SenseInfo('01282921-a', 0) ],
"_swing_n_1_rel" : [ SenseInfo('14009946-n', 1), SenseInfo('04371774-n', 1), SenseInfo('01173660-n', 1), SenseInfo('00327824-n', 1), SenseInfo('07066042-n', 0), SenseInfo('04992008-n', 0), SenseInfo('00571609-n', 0), SenseInfo('00571444-n', 0), SenseInfo('00541178-n', 0) ],
"_grid_n_1_rel" : [ SenseInfo('05931512-n', 0), SenseInfo('03997027-n', 0), SenseInfo('03458753-n', 0), SenseInfo('03458552-n', 0), SenseInfo('03458422-n', 0), SenseInfo('05931512-n', 0), SenseInfo('03997027-n', 0), SenseInfo('03458753-n', 0), SenseInfo('03458552-n', 0), SenseInfo('03458422-n', 0) ],
"_odoriferous_a_1_rel" : [ SenseInfo('01628200-a', 0), SenseInfo('01054504-a', 0), SenseInfo('01052611-a', 0), SenseInfo('01628200-a', 0), SenseInfo('01054504-a', 0), SenseInfo('01052611-a', 0) ],
"_trickiest_a_for_rel" : [  ],
"_responsive_a_1_rel" : [ SenseInfo('03110741-a', 0), SenseInfo('01999306-a', 0), SenseInfo('02105176-a', 0) ],
"_single-handedly_a_1_rel" : [  ],
"_scenarist_n_1_rel" : [ SenseInfo('10555936-n', 0) ],
"_presidency_n_1_rel" : [ SenseInfo('15266265-n', 1), SenseInfo('00596807-n', 0) ],
"_cranberry_n_1_rel" : [ SenseInfo('12245695-n', 0), SenseInfo('07743902-n', 0) ],
"_flare_v_cause_rel" : [ SenseInfo('02762806-v', 1), SenseInfo('00304252-v', 1), SenseInfo('02762981-v', 0), SenseInfo('00307785-v', 0) ],
"_maintenance_n_1_rel" : [ SenseInfo('00267522-n', 6), SenseInfo('13366311-n', 1), SenseInfo('13283620-n', 0), SenseInfo('01216191-n', 0), SenseInfo('00765791-n', 0) ],
"_finite_a_1_rel" : [ SenseInfo('01006566-a', 11), SenseInfo('01008439-a', 0) ],
"_berry_n_1_rel" : [ SenseInfo('07742704-n', 3), SenseInfo('13137409-n', 0), SenseInfo('10849083-n', 0) ],
"_directive_n_1_rel" : [ SenseInfo('07170080-n', 1), SenseInfo('07170080-n', 1), SenseInfo('07170080-n', 1), SenseInfo('07170080-n', 1) ],
"_welcome_v_1_rel" : [ SenseInfo('02237206-v', 15), SenseInfo('00900583-v', 4), SenseInfo('01470098-v', 2), SenseInfo('02237206-v', 15), SenseInfo('00900583-v', 4), SenseInfo('01470098-v', 2), SenseInfo('02237206-v', 15), SenseInfo('00900583-v', 4), SenseInfo('01470098-v', 2) ],
"_subskill_n_1_rel" : [  ],
"_death+row_n_1_rel" : [ SenseInfo('03166809-n', 0) ],
"_proclaim_v_to_rel" : [ SenseInfo('00978173-v', 13), SenseInfo('00977336-v', 10), SenseInfo('01017001-v', 3), SenseInfo('00860620-v', 1), SenseInfo('00978173-v', 13), SenseInfo('00977336-v', 10), SenseInfo('01017001-v', 3), SenseInfo('00860620-v', 1) ],
"_mhm_a_1_rel" : [  ],
"_shot_n_of_rel" : [ SenseInfo('00122661-n', 24), SenseInfo('04205759-n', 20), SenseInfo('00565302-n', 6), SenseInfo('14485673-n', 1), SenseInfo('10593115-n', 1), SenseInfo('06614729-n', 1), SenseInfo('00697365-n', 1), SenseInfo('13773250-n', 0), SenseInfo('06767922-n', 0), SenseInfo('05803938-n', 0), SenseInfo('04248607-n', 0), SenseInfo('04206070-n', 0), SenseInfo('04205983-n', 0), SenseInfo('01175633-n', 0), SenseInfo('00788632-n', 0), SenseInfo('00788473-n', 0), SenseInfo('00103590-n', 0) ],
"_meanwhile_p_rel" : [ SenseInfo('00065184-r', 10), SenseInfo('00064946-r', 6), SenseInfo('15272887-n', 0) ],
"_dredge_v_1_rel" : [ SenseInfo('01261773-v', 0), SenseInfo('01244692-v', 0), SenseInfo('01244516-v', 0) ],
"_incapable_a_of_rel" : [ SenseInfo('00307474-a', 4), SenseInfo('02364066-a', 1), SenseInfo('00308188-a', 0), SenseInfo('00052246-a', 0) ],
"_upward_a_1_rel" : [ SenseInfo('02491836-a', 2), SenseInfo('02485488-a', 1) ],
"_display-all_a_1_rel" : [  ],
"_inflammation_n_1_rel" : [ SenseInfo('14336539-n', 0), SenseInfo('14037011-n', 0), SenseInfo('01261712-n', 0), SenseInfo('00378479-n', 0) ],
"_spare_n_1_rel" : [ SenseInfo('04267870-n', 0), SenseInfo('03334912-n', 0), SenseInfo('00187890-n', 0) ],
"_regardless_a_of_rel" : [ SenseInfo('01194099-a', 0) ],
"_sister_n_of_rel" : [ SenseInfo('10602985-n', 20), SenseInfo('10602470-n', 0), SenseInfo('10602258-n', 0), SenseInfo('09827363-n', 0) ],
"_mean_v_to_rel" : [ SenseInfo('00955148-v', 93), SenseInfo('02635189-v', 89), SenseInfo('00931852-v', 43), SenseInfo('00708538-v', 27), SenseInfo('02742482-v', 9), SenseInfo('00730052-v', 8), SenseInfo('00708840-v', 0) ],
"_satisfied_a_1_rel" : [ SenseInfo('00589344-a', 11), SenseInfo('01519673-a', 0) ],
"_flame_n_1_rel" : [ SenseInfo('13480848-n', 15) ],
"_sincerity_n_1_rel" : [ SenseInfo('07512315-n', 2), SenseInfo('04867130-n', 2), SenseInfo('04786595-n', 1), SenseInfo('04646548-n', 0) ],
"_reactionary_n_1_rel" : [ SenseInfo('10508475-n', 5) ],
"_rudder_n_1_rel" : [ SenseInfo('04117464-n', 1), SenseInfo('04117216-n', 0) ],
"_shoulder_n_1_rel" : [ SenseInfo('05548840-n', 65), SenseInfo('07661583-n', 0), SenseInfo('05549061-n', 0), SenseInfo('04207151-n', 0), SenseInfo('04206948-n', 0) ],
"_by+the+numbers_a_1_rel" : [  ],
"_turnip_n_1_rel" : [ SenseInfo('11877646-n', 0), SenseInfo('07735803-n', 0) ],
"_discussion_n_of_rel" : [ SenseInfo('07138085-n', 27), SenseInfo('07140659-n', 25), SenseInfo('07138085-n', 27), SenseInfo('07140659-n', 25) ],
"_renew_v_1_rel" : [ SenseInfo('01631072-v', 7), SenseInfo('00167652-v', 3) ],
"_as+to_p_rel" : [  ],
"_lure_v_1_rel" : [ SenseInfo('00782527-v', 6) ],
"_flip_v_out_rel" : [ SenseInfo('01893079-v', 3), SenseInfo('01510173-v', 1), SenseInfo('02153023-v', 0), SenseInfo('01893601-v', 0), SenseInfo('01893465-v', 0), SenseInfo('01512625-v', 0), SenseInfo('01241614-v', 0), SenseInfo('01222958-v', 0), SenseInfo('00717921-v', 0), SenseInfo('00584810-v', 0), SenseInfo('00121678-v', 0) ],
"_breastband_n_1_rel" : [  ],
"_chaff_n_1_rel" : [ SenseInfo('14805899-n', 0), SenseInfo('02999001-n', 0) ],
"_husband_n_1_rel" : [ SenseInfo('10193967-n', 68) ],
"_condition_v_1_rel" : [ SenseInfo('02571768-v', 2), SenseInfo('02553697-v', 1), SenseInfo('01018928-v', 1), SenseInfo('00207418-v', 0), SenseInfo('00041687-v', 0), SenseInfo('02571768-v', 2), SenseInfo('02553697-v', 1), SenseInfo('01018928-v', 1), SenseInfo('00207418-v', 0), SenseInfo('00041687-v', 0) ],
"_narrow_v_cause_rel" : [ SenseInfo('00305109-v', 2), SenseInfo('00715541-v', 1), SenseInfo('00437449-v', 1), SenseInfo('00304422-v', 1) ],
"_blonde_n_1_rel" : [ SenseInfo('09860506-n', 2), SenseInfo('04966017-n', 0) ],
"_lift_v_out_rel" : [ SenseInfo('01312371-v', 1), SenseInfo('01312371-v', 1) ],
"_prior_a_1_rel" : [ SenseInfo('00122128-a', 22) ],
"_exclusive_a_of_rel" : [ SenseInfo('02152985-a', 6), SenseInfo('01862386-a', 0), SenseInfo('00539389-a', 0), SenseInfo('02152985-a', 6), SenseInfo('01862386-a', 0), SenseInfo('00539389-a', 0) ],
"_trade_v_in_rel" : [ SenseInfo('02260362-v', 6), SenseInfo('02260085-v', 6), SenseInfo('02728784-v', 2), SenseInfo('02259005-v', 2), SenseInfo('02244956-v', 0), SenseInfo('02260362-v', 6), SenseInfo('02260085-v', 6), SenseInfo('02728784-v', 2), SenseInfo('02259005-v', 2), SenseInfo('02244956-v', 0) ],
"_instinct_n_1_rel" : [ SenseInfo('05622723-n', 4) ],
"_burn_v_off_rel" : [ SenseInfo('00378664-v', 11), SenseInfo('02768874-v', 10), SenseInfo('00377002-v', 9), SenseInfo('02120451-v', 4), SenseInfo('02762468-v', 2), SenseInfo('01829292-v', 2), SenseInfo('00378042-v', 2), SenseInfo('02485322-v', 1), SenseInfo('02268881-v', 1), SenseInfo('02121048-v', 1), SenseInfo('00373766-v', 1), SenseInfo('00104299-v', 1), SenseInfo('01756277-v', 0), SenseInfo('01205000-v', 0), SenseInfo('00196364-v', 0), SenseInfo('00378664-v', 11), SenseInfo('02768874-v', 10), SenseInfo('00377002-v', 9), SenseInfo('02120451-v', 4), SenseInfo('02762468-v', 2), SenseInfo('01829292-v', 2), SenseInfo('00378042-v', 2), SenseInfo('02485322-v', 1), SenseInfo('02268881-v', 1), SenseInfo('02121048-v', 1), SenseInfo('00373766-v', 1), SenseInfo('00104299-v', 1), SenseInfo('01756277-v', 0), SenseInfo('01205000-v', 0), SenseInfo('00196364-v', 0) ],
"_tumble_n_1_rel" : [ SenseInfo('00437788-n', 1), SenseInfo('00076884-n', 0) ],
"_yearning_n_1_rel" : [ SenseInfo('07486628-n', 5) ],
"_mature_a_1_rel" : [ SenseInfo('01491775-a', 4), SenseInfo('00742316-a', 4), SenseInfo('01488245-a', 1), SenseInfo('01493173-a', 0), SenseInfo('01095914-a', 0) ],
"_fracture_n_1_rel" : [ SenseInfo('14292090-n', 0), SenseInfo('09278537-n', 0), SenseInfo('00376994-n', 0) ],
"_wilt_v_cause_rel" : [ SenseInfo('00469794-v', 1), SenseInfo('00469637-v', 0) ],
"_mechanistic_a_1_rel" : [ SenseInfo('01500416-a', 1), SenseInfo('02911112-a', 0) ],
"_committee_n_of_rel" : [ SenseInfo('08324514-n', 16), SenseInfo('08325686-n', 1), SenseInfo('08324514-n', 16), SenseInfo('08325686-n', 1) ],
"_held_a_1_rel" : [ SenseInfo('03149347-a', 1) ],
"_forlorn_a_1_rel" : [ SenseInfo('01230387-a', 0) ],
"_short_v_cause_rel" : [ SenseInfo('02572667-v', 0), SenseInfo('01618884-v', 0) ],
"_imac_n_1_rel" : [  ],
"_damp_v_down_rel" : [ SenseInfo('02191311-v', 0), SenseInfo('00573085-v', 0), SenseInfo('00390560-v', 0), SenseInfo('00390215-v', 0) ],
"_anticipate_v_1_rel" : [ SenseInfo('00719734-v', 8), SenseInfo('02565491-v', 5), SenseInfo('00720808-v', 4), SenseInfo('00917772-v', 3), SenseInfo('01804961-v', 2), SenseInfo('00342640-v', 1), SenseInfo('00719734-v', 8), SenseInfo('02565491-v', 5), SenseInfo('00720808-v', 4), SenseInfo('00917772-v', 3), SenseInfo('01804961-v', 2), SenseInfo('00342640-v', 1), SenseInfo('00719734-v', 8), SenseInfo('02565491-v', 5), SenseInfo('00720808-v', 4), SenseInfo('00917772-v', 3), SenseInfo('01804961-v', 2), SenseInfo('00342640-v', 1) ],
"_horizontal_a_1_rel" : [ SenseInfo('01232635-a', 4), SenseInfo('01232635-a', 4) ],
"_discard_v_1_rel" : [ SenseInfo('02222318-v', 3) ],
"_set_v_aside_rel" : [ SenseInfo('01494310-v', 30), SenseInfo('00699815-v', 29), SenseInfo('00947077-v', 12), SenseInfo('01062395-v', 10), SenseInfo('00298896-v', 9), SenseInfo('01607445-v', 6), SenseInfo('00406243-v', 5), SenseInfo('00298556-v', 5), SenseInfo('01711749-v', 3), SenseInfo('01970646-v', 2), SenseInfo('01706129-v', 2), SenseInfo('01567275-v', 2), SenseInfo('01628899-v', 1), SenseInfo('00442669-v', 1), SenseInfo('01744888-v', 0), SenseInfo('01613239-v', 0), SenseInfo('01530273-v', 0), SenseInfo('01247322-v', 0), SenseInfo('01115006-v', 0), SenseInfo('00673448-v', 0), SenseInfo('00408085-v', 0), SenseInfo('00407848-v', 0), SenseInfo('00296178-v', 0), SenseInfo('00056188-v', 0), SenseInfo('00038849-v', 0) ],
"_motif_n_1_rel" : [ SenseInfo('03789014-n', 5), SenseInfo('07029682-n', 1), SenseInfo('05920272-n', 1) ],
"_hutch_n_1_rel" : [ SenseInfo('03550289-n', 0), SenseInfo('03547054-n', 0) ],
"_appendant_n_1_rel" : [ SenseInfo('00158864-a', 0) ],
"_hangman_n_game_rel" : [ SenseInfo('10159615-n', 0), SenseInfo('10159615-n', 0) ],
"_hectare_n_1_rel" : [ SenseInfo('13613985-n', 0) ],
"_digital_a_1_rel" : [ SenseInfo('02713232-a', 0), SenseInfo('02713096-a', 0), SenseInfo('00110701-a', 0), SenseInfo('02713232-a', 0), SenseInfo('02713096-a', 0), SenseInfo('00110701-a', 0) ],
"_horsepower_n_1_rel" : [ SenseInfo('13645010-n', 0) ],
"_stiff_n_1_rel" : [ SenseInfo('10656120-n', 2), SenseInfo('05218119-n', 0) ],
"_actuate_v_1_rel" : [ SenseInfo('01643657-v', 2), SenseInfo('01649999-v', 0) ],
"_entwist_v_1_rel" : [  ],
"_oblige_v_1_rel" : [ SenseInfo('02506546-v', 14), SenseInfo('00885217-v', 1), SenseInfo('00885925-v', 0), SenseInfo('02506546-v', 14), SenseInfo('00885217-v', 1), SenseInfo('00885925-v', 0), SenseInfo('02506546-v', 14), SenseInfo('00885217-v', 1), SenseInfo('00885925-v', 0) ],
"_unworthy_a_of_rel" : [ SenseInfo('02588099-a', 1), SenseInfo('02588421-a', 0), SenseInfo('01133017-a', 0), SenseInfo('02588099-a', 1), SenseInfo('02588421-a', 0), SenseInfo('01133017-a', 0) ],
"_descend_v_1_rel" : [ SenseInfo('01970826-v', 12), SenseInfo('02737187-v', 3), SenseInfo('02591312-v', 1), SenseInfo('00342164-v', 0), SenseInfo('01970826-v', 12), SenseInfo('02737187-v', 3), SenseInfo('02591312-v', 1), SenseInfo('00342164-v', 0) ],
"_psalmody_n_1_rel" : [ SenseInfo('01255549-n', 0) ],
"_gestalt_n_1_rel" : [ SenseInfo('05931341-n', 0) ],
"_professor_n_of_rel" : [ SenseInfo('10480730-n', 19), SenseInfo('10480730-n', 19), SenseInfo('10480730-n', 19), SenseInfo('10480730-n', 19) ],
"_contend_v_1_rel" : [ SenseInfo('00756898-v', 10), SenseInfo('00773432-v', 3), SenseInfo('00869596-v', 2), SenseInfo('02587532-v', 1), SenseInfo('01072262-v', 1), SenseInfo('01090335-v', 0), SenseInfo('00756898-v', 10), SenseInfo('00773432-v', 3), SenseInfo('00869596-v', 2), SenseInfo('02587532-v', 1), SenseInfo('01072262-v', 1), SenseInfo('01090335-v', 0) ],
"_intellectual_n_1_rel" : [ SenseInfo('09621545-n', 3) ],
"_lull_v_to_rel" : [ SenseInfo('01763643-v', 2), SenseInfo('00558061-v', 1), SenseInfo('01764800-v', 0) ],
"_squire_n_1_rel" : [ SenseInfo('10643937-n', 2), SenseInfo('10643837-n', 1), SenseInfo('10644062-n', 0) ],
"_discourse_v_on-upon_rel" : [ SenseInfo('01034312-v', 0), SenseInfo('00964694-v', 0), SenseInfo('00814621-v', 0), SenseInfo('01034312-v', 0), SenseInfo('00964694-v', 0), SenseInfo('00814621-v', 0), SenseInfo('01034312-v', 0), SenseInfo('00964694-v', 0), SenseInfo('00814621-v', 0) ],
"_convoluted_a_1_rel" : [ SenseInfo('02317800-a', 0), SenseInfo('02176841-a', 0) ],
"_charm_v_1_rel" : [ SenseInfo('01806505-v', 2), SenseInfo('02586458-v', 0), SenseInfo('01130455-v', 0), SenseInfo('00776523-v', 0), SenseInfo('01806505-v', 2), SenseInfo('02586458-v', 0), SenseInfo('01130455-v', 0), SenseInfo('00776523-v', 0), SenseInfo('01806505-v', 2), SenseInfo('02586458-v', 0), SenseInfo('01130455-v', 0), SenseInfo('00776523-v', 0) ],
"_claimant_n_1_rel" : [ SenseInfo('09925592-n', 8) ],
"_pass_v_along_rel" : [ SenseInfo('02050132-v', 32), SenseInfo('02051694-v', 31), SenseInfo('02466670-v', 29), SenseInfo('02072849-v', 17), SenseInfo('02230772-v', 13), SenseInfo('02685951-v', 8), SenseInfo('02049696-v', 8), SenseInfo('00339934-v', 7), SenseInfo('02523351-v', 4), SenseInfo('02708420-v', 3), SenseInfo('01212230-v', 3), SenseInfo('00742320-v', 3), SenseInfo('00421691-v', 3), SenseInfo('02525044-v', 2), SenseInfo('02669081-v', 1), SenseInfo('02523953-v', 1), SenseInfo('02423513-v', 1), SenseInfo('02221635-v', 1), SenseInfo('01972131-v', 1), SenseInfo('02231473-v', 0), SenseInfo('02229550-v', 0), SenseInfo('02052476-v', 0), SenseInfo('00803325-v', 0), SenseInfo('00358431-v', 0), SenseInfo('00072989-v', 0) ],
"_stump_n_1_rel" : [ SenseInfo('13111504-n', 5), SenseInfo('05560631-n', 1), SenseInfo('04346003-n', 0), SenseInfo('03159640-n', 0) ],
"_novitiate_n_1_rel" : [ SenseInfo('15294884-n', 1), SenseInfo('10364198-n', 0) ],
"_result_n_of_rel" : [ SenseInfo('11410625-n', 83), SenseInfo('06743506-n', 25), SenseInfo('07292694-n', 24), SenseInfo('06333285-n', 0), SenseInfo('11410625-n', 83), SenseInfo('06743506-n', 25), SenseInfo('07292694-n', 24), SenseInfo('06333285-n', 0) ],
"_pronominal_a_1_rel" : [ SenseInfo('02937433-a', 0), SenseInfo('02937433-a', 0) ],
"_tamp_v_1_rel" : [ SenseInfo('01574571-v', 0) ],
"_twilight_n_1_rel" : [ SenseInfo('15169421-n', 1), SenseInfo('11515935-n', 1), SenseInfo('14423740-n', 0) ],
"_granddaughter_n_of_rel" : [ SenseInfo('10141732-n', 0) ],
"_jolly_a_1_rel" : [ SenseInfo('01367651-a', 2), SenseInfo('01367651-a', 2), SenseInfo('01367651-a', 2) ],
"_oblique_a_1_rel" : [ SenseInfo('01718867-a', 2), SenseInfo('00768098-a', 0), SenseInfo('01718867-a', 2), SenseInfo('00768098-a', 0) ],
"_firemans_a_1_rel" : [  ],
"_lumber_n_1_rel" : [ SenseInfo('14943580-n', 6), SenseInfo('02799175-n', 0) ],
"_shriek_n_1_rel" : [ SenseInfo('07123012-n', 4), SenseInfo('07393161-n', 1) ],
"_archepiscopal_a_1_rel" : [ SenseInfo('02639895-a', 0) ],
"_appropriation_n_of_rel" : [ SenseInfo('13289845-n', 3), SenseInfo('00373418-n', 0), SenseInfo('00083975-n', 0) ],
"_endorsement_n_of_rel" : [ SenseInfo('07248060-n', 0), SenseInfo('07180372-n', 0), SenseInfo('06687358-n', 0), SenseInfo('06405198-n', 0), SenseInfo('01215168-n', 0) ],
"_entry_n_1_rel" : [ SenseInfo('06503724-n', 10), SenseInfo('00238022-n', 5), SenseInfo('13405296-n', 2), SenseInfo('07167578-n', 1), SenseInfo('03290771-n', 1), SenseInfo('00049003-n', 0) ],
"_stumble_v_1_rel" : [ SenseInfo('01901133-v', 11), SenseInfo('01900408-v', 9), SenseInfo('02206462-v', 2), SenseInfo('00618057-v', 0) ],
"_apply_v_2_rel" : [ SenseInfo('01158872-v', 45), SenseInfo('02676789-v', 29), SenseInfo('00765396-v', 13), SenseInfo('01363648-v', 11), SenseInfo('02707429-v', 4), SenseInfo('02309165-v', 2), SenseInfo('02561332-v', 1), SenseInfo('02560164-v', 1), SenseInfo('01026558-v', 1), SenseInfo('02595523-v', 0) ],
"_unwell_a_1_rel" : [ SenseInfo('02542325-a', 0), SenseInfo('02542325-a', 0) ],
"_as_x_prd_rel" : [ SenseInfo('13658027-n', 6), SenseInfo('15089803-n', 0), SenseInfo('14829565-n', 0), SenseInfo('14706889-n', 0), SenseInfo('13637376-n', 0), SenseInfo('06831177-n', 0), SenseInfo('05400860-n', 0) ],
"_perennial_a_1_rel" : [ SenseInfo('00678473-a', 2), SenseInfo('01441729-a', 0), SenseInfo('00592880-a', 0) ],
"_shuffle_v_1_rel" : [ SenseInfo('01917549-v', 4), SenseInfo('02012973-v', 1), SenseInfo('01418667-v', 0) ],
"_wrist_n_1_rel" : [ SenseInfo('05584928-n', 9) ],
"_laugh_n_1_rel" : [ SenseInfo('07127006-n', 16), SenseInfo('06878404-n', 1), SenseInfo('06778102-n', 0) ],
"_equinoctial_a_1_rel" : [ SenseInfo('02721762-a', 0), SenseInfo('02721618-a', 0) ],
"_parallel_a_to_rel" : [ SenseInfo('01718158-a', 10), SenseInfo('02379157-a', 0) ],
"_antibody_n_1_rel" : [ SenseInfo('15027189-n', 17) ],
"_neutral_a_1_rel" : [ SenseInfo('01615625-a', 4), SenseInfo('01930004-a', 3), SenseInfo('00732160-a', 2), SenseInfo('01818992-a', 0), SenseInfo('00386392-a', 0), SenseInfo('00408284-a', 0), SenseInfo('00359160-a', 0), SenseInfo('01615625-a', 4), SenseInfo('01930004-a', 3), SenseInfo('00732160-a', 2), SenseInfo('01818992-a', 0), SenseInfo('00386392-a', 0), SenseInfo('00408284-a', 0), SenseInfo('00359160-a', 0) ],
"_take_v_1_rel" : [ SenseInfo('02599636-v', 92), SenseInfo('02267989-v', 74), SenseInfo('01999798-v', 73), SenseInfo('01214265-v', 50), SenseInfo('00524682-v', 38), SenseInfo('00624476-v', 36), SenseInfo('02077656-v', 32), SenseInfo('02205272-v', 28), SenseInfo('01842690-v', 26), SenseInfo('00674607-v', 26), SenseInfo('02236124-v', 25), SenseInfo('02394183-v', 22), SenseInfo('00734054-v', 22), SenseInfo('02627934-v', 21), SenseInfo('02109045-v', 21), SenseInfo('01002740-v', 16), SenseInfo('00173338-v', 16), SenseInfo('01156834-v', 15), SenseInfo('00669762-v', 15), SenseInfo('02209936-v', 14), SenseInfo('02206619-v', 13), SenseInfo('01982395-v', 10), SenseInfo('02236624-v', 8), SenseInfo('00523095-v', 7), SenseInfo('00599992-v', 6), SenseInfo('00756076-v', 5), SenseInfo('02075857-v', 4), SenseInfo('01151110-v', 4), SenseInfo('00557404-v', 4), SenseInfo('02717102-v', 2), SenseInfo('02208537-v', 2), SenseInfo('02209745-v', 1), SenseInfo('02208118-v', 1), SenseInfo('02201138-v', 1), SenseInfo('01427127-v', 1), SenseInfo('00758333-v', 1), SenseInfo('02741546-v', 0), SenseInfo('02701210-v', 0), SenseInfo('02590253-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01100830-v', 0), SenseInfo('00087736-v', 0), SenseInfo('02599636-v', 92), SenseInfo('02267989-v', 74), SenseInfo('01999798-v', 73), SenseInfo('01214265-v', 50), SenseInfo('00524682-v', 38), SenseInfo('00624476-v', 36), SenseInfo('02077656-v', 32), SenseInfo('02205272-v', 28), SenseInfo('01842690-v', 26), SenseInfo('00674607-v', 26), SenseInfo('02236124-v', 25), SenseInfo('02394183-v', 22), SenseInfo('00734054-v', 22), SenseInfo('02627934-v', 21), SenseInfo('02109045-v', 21), SenseInfo('01002740-v', 16), SenseInfo('00173338-v', 16), SenseInfo('01156834-v', 15), SenseInfo('00669762-v', 15), SenseInfo('02209936-v', 14), SenseInfo('02206619-v', 13), SenseInfo('01982395-v', 10), SenseInfo('02236624-v', 8), SenseInfo('00523095-v', 7), SenseInfo('00599992-v', 6), SenseInfo('00756076-v', 5), SenseInfo('02075857-v', 4), SenseInfo('01151110-v', 4), SenseInfo('00557404-v', 4), SenseInfo('02717102-v', 2), SenseInfo('02208537-v', 2), SenseInfo('02209745-v', 1), SenseInfo('02208118-v', 1), SenseInfo('02201138-v', 1), SenseInfo('01427127-v', 1), SenseInfo('00758333-v', 1), SenseInfo('02741546-v', 0), SenseInfo('02701210-v', 0), SenseInfo('02590253-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01100830-v', 0), SenseInfo('00087736-v', 0), SenseInfo('02599636-v', 92), SenseInfo('02267989-v', 74), SenseInfo('01999798-v', 73), SenseInfo('01214265-v', 50), SenseInfo('00524682-v', 38), SenseInfo('00624476-v', 36), SenseInfo('02077656-v', 32), SenseInfo('02205272-v', 28), SenseInfo('01842690-v', 26), SenseInfo('00674607-v', 26), SenseInfo('02236124-v', 25), SenseInfo('02394183-v', 22), SenseInfo('00734054-v', 22), SenseInfo('02627934-v', 21), SenseInfo('02109045-v', 21), SenseInfo('01002740-v', 16), SenseInfo('00173338-v', 16), SenseInfo('01156834-v', 15), SenseInfo('00669762-v', 15), SenseInfo('02209936-v', 14), SenseInfo('02206619-v', 13), SenseInfo('01982395-v', 10), SenseInfo('02236624-v', 8), SenseInfo('00523095-v', 7), SenseInfo('00599992-v', 6), SenseInfo('00756076-v', 5), SenseInfo('02075857-v', 4), SenseInfo('01151110-v', 4), SenseInfo('00557404-v', 4), SenseInfo('02717102-v', 2), SenseInfo('02208537-v', 2), SenseInfo('02209745-v', 1), SenseInfo('02208118-v', 1), SenseInfo('02201138-v', 1), SenseInfo('01427127-v', 1), SenseInfo('00758333-v', 1), SenseInfo('02741546-v', 0), SenseInfo('02701210-v', 0), SenseInfo('02590253-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01100830-v', 0), SenseInfo('00087736-v', 0), SenseInfo('02599636-v', 92), SenseInfo('02267989-v', 74), SenseInfo('01999798-v', 73), SenseInfo('01214265-v', 50), SenseInfo('00524682-v', 38), SenseInfo('00624476-v', 36), SenseInfo('02077656-v', 32), SenseInfo('02205272-v', 28), SenseInfo('01842690-v', 26), SenseInfo('00674607-v', 26), SenseInfo('02236124-v', 25), SenseInfo('02394183-v', 22), SenseInfo('00734054-v', 22), SenseInfo('02627934-v', 21), SenseInfo('02109045-v', 21), SenseInfo('01002740-v', 16), SenseInfo('00173338-v', 16), SenseInfo('01156834-v', 15), SenseInfo('00669762-v', 15), SenseInfo('02209936-v', 14), SenseInfo('02206619-v', 13), SenseInfo('01982395-v', 10), SenseInfo('02236624-v', 8), SenseInfo('00523095-v', 7), SenseInfo('00599992-v', 6), SenseInfo('00756076-v', 5), SenseInfo('02075857-v', 4), SenseInfo('01151110-v', 4), SenseInfo('00557404-v', 4), SenseInfo('02717102-v', 2), SenseInfo('02208537-v', 2), SenseInfo('02209745-v', 1), SenseInfo('02208118-v', 1), SenseInfo('02201138-v', 1), SenseInfo('01427127-v', 1), SenseInfo('00758333-v', 1), SenseInfo('02741546-v', 0), SenseInfo('02701210-v', 0), SenseInfo('02590253-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01100830-v', 0), SenseInfo('00087736-v', 0) ],
"_congenial_a_1_rel" : [ SenseInfo('00560586-a', 0), SenseInfo('00507789-a', 0) ],
"_perhaps_x_deg_rel" : [ SenseInfo('00300247-r', 123) ],
"_thinker_n_1_rel" : [ SenseInfo('10708292-n', 1), SenseInfo('10708454-n', 0) ],
"_listen_v_in_rel" : [ SenseInfo('02169891-v', 60), SenseInfo('02171039-v', 34), SenseInfo('02571901-v', 4) ],
"_tract_n_of_rel" : [ SenseInfo('08673395-n', 3), SenseInfo('05510907-n', 3), SenseInfo('06409290-n', 1), SenseInfo('05475878-n', 0) ],
"_cathedral_n_1_rel" : [ SenseInfo('02984061-n', 4), SenseInfo('02984203-n', 0), SenseInfo('02984061-n', 4), SenseInfo('02984203-n', 0) ],
"_antonym_n_1_rel" : [ SenseInfo('06288024-n', 0) ],
"_hobble_v_1_rel" : [ SenseInfo('01917244-v', 2), SenseInfo('02452240-v', 1), SenseInfo('01289633-v', 0) ],
"_purity_n_1_rel" : [ SenseInfo('14486767-n', 3), SenseInfo('13990064-n', 1), SenseInfo('04849972-n', 0) ],
"_westbound_a_1_rel" : [ SenseInfo('00824509-a', 0) ],
"_liking_n_1_rel" : [ SenseInfo('07497473-n', 4) ],
"_speculative_a_1_rel" : [ SenseInfo('02274537-a', 1), SenseInfo('00861818-a', 1), SenseInfo('00664879-a', 0) ],
"_rota_n_1_rel" : [ SenseInfo('08335414-n', 0), SenseInfo('06496862-n', 0) ],
"_mine_v_1_rel" : [ SenseInfo('01163620-v', 3), SenseInfo('01125724-v', 0) ],
"_foremost_a_1_rel" : [ SenseInfo('00228294-a', 2), SenseInfo('00198610-a', 1), SenseInfo('01033249-a', 0), SenseInfo('00228294-a', 2), SenseInfo('00198610-a', 1), SenseInfo('01033249-a', 0) ],
"_necessary_a_for_rel" : [ SenseInfo('01580050-a', 81), SenseInfo('00343552-a', 1), SenseInfo('01580050-a', 81), SenseInfo('00343552-a', 1), SenseInfo('01580050-a', 81), SenseInfo('00343552-a', 1), SenseInfo('01580050-a', 81), SenseInfo('00343552-a', 1) ],
"_piss_v_on_rel" : [ SenseInfo('00072012-v', 1) ],
"_cheyenne_n_1_rel" : [ SenseInfo('09159675-n', 2), SenseInfo('06908700-n', 1), SenseInfo('09651968-n', 0) ],
"_reachable_a_1_rel" : [ SenseInfo('00019349-a', 0) ],
"_disturbed_a_1_rel" : [ SenseInfo('01681882-a', 2), SenseInfo('02457167-a', 1), SenseInfo('01584017-a', 1), SenseInfo('02075321-a', 0) ],
"_mutant_a_1_rel" : [ SenseInfo('02987454-a', 0) ],
"_apology_n_1_rel" : [ SenseInfo('06633363-n', 2), SenseInfo('06740919-n', 0), SenseInfo('05821102-n', 0) ],
"_complete_a_1_rel" : [ SenseInfo('00520214-a', 67), SenseInfo('01750386-a', 4), SenseInfo('02226028-a', 0), SenseInfo('01520091-a', 0), SenseInfo('01003277-a', 0) ],
"_turnout_n_1_rel" : [ SenseInfo('07987216-n', 0), SenseInfo('04500866-n', 0), SenseInfo('04216106-n', 0), SenseInfo('03860882-n', 0), SenseInfo('03859958-n', 0), SenseInfo('01233917-n', 0), SenseInfo('00534480-n', 0) ],
"_censure_n_1_rel" : [ SenseInfo('06709998-n', 1), SenseInfo('14413993-n', 0) ],
"_pocket_v_1_rel" : [ SenseInfo('02278592-v', 1), SenseInfo('02292432-v', 0) ],
"_effective_a_1_rel" : [ SenseInfo('00834198-a', 29), SenseInfo('00510644-a', 14), SenseInfo('00839225-a', 8), SenseInfo('00832784-a', 4), SenseInfo('00044132-a', 1), SenseInfo('01660712-a', 0), SenseInfo('00834198-a', 29), SenseInfo('00510644-a', 14), SenseInfo('00839225-a', 8), SenseInfo('00832784-a', 4), SenseInfo('00044132-a', 1), SenseInfo('01660712-a', 0) ],
"_a+few_a_1_rel" : [ SenseInfo('01553340-a', 138), SenseInfo('01553340-a', 138) ],
"_plum_n_1_rel" : [ SenseInfo('12638218-n', 0), SenseInfo('07751451-n', 0), SenseInfo('00596081-n', 0) ],
"_unhook_v_1_rel" : [ SenseInfo('01366321-v', 0), SenseInfo('01366321-v', 0) ],
"_adverse_a_1_rel" : [ SenseInfo('00997036-a', 4), SenseInfo('00995647-a', 0), SenseInfo('00997036-a', 4), SenseInfo('00995647-a', 0) ],
"_refugee_n_1_rel" : [ SenseInfo('10516016-n', 5) ],
"_jam_v_up_rel" : [ SenseInfo('02064131-v', 1), SenseInfo('01993668-v', 1), SenseInfo('01492944-v', 1), SenseInfo('01057034-v', 1), SenseInfo('01525177-v', 0), SenseInfo('01524298-v', 0), SenseInfo('01476483-v', 0) ],
"_countermovement_n_1_rel" : [  ],
"_sentence_n_1_rel" : [ SenseInfo('06285090-n', 31), SenseInfo('01189282-n', 5), SenseInfo('15224692-n', 3), SenseInfo('06285090-n', 31), SenseInfo('01189282-n', 5), SenseInfo('15224692-n', 3) ],
"_rearward_a_1_rel" : [ SenseInfo('00197891-a', 1), SenseInfo('00202250-a', 0) ],
"_not+quite_a_rel" : [  ],
"_avert_v_from_rel" : [ SenseInfo('02453321-v', 5), SenseInfo('02034511-v', 1), SenseInfo('02453321-v', 5), SenseInfo('02034511-v', 1) ],
"_intact_a_1_rel" : [ SenseInfo('00515870-a', 5), SenseInfo('01319434-a', 1), SenseInfo('02137394-a', 0), SenseInfo('00681268-a', 0) ],
"_event_n_item_rel" : [ SenseInfo('00029378-n', 62), SenseInfo('13943400-n', 6), SenseInfo('11453860-n', 0), SenseInfo('11410625-n', 0) ],
"_go_v_ahead_rel" : [ SenseInfo('01835496-v', 343), SenseInfo('02372605-v', 95), SenseInfo('01848718-v', 49), SenseInfo('00149583-v', 29), SenseInfo('02653862-v', 14), SenseInfo('02721284-v', 10), SenseInfo('02685951-v', 10), SenseInfo('00341560-v', 10), SenseInfo('00359916-v', 9), SenseInfo('02618001-v', 7), SenseInfo('02176268-v', 3), SenseInfo('01525666-v', 3), SenseInfo('01192773-v', 3), SenseInfo('00539110-v', 3), SenseInfo('02618149-v', 2), SenseInfo('02617798-v', 2), SenseInfo('00358431-v', 2), SenseInfo('02737876-v', 1), SenseInfo('02729819-v', 1), SenseInfo('01864230-v', 1), SenseInfo('01076615-v', 1), SenseInfo('02700772-v', 0), SenseInfo('02700666-v', 0), SenseInfo('02700455-v', 0), SenseInfo('02686471-v', 0), SenseInfo('02659763-v', 0), SenseInfo('01318849-v', 0), SenseInfo('01192992-v', 0), SenseInfo('00676267-v', 0), SenseInfo('00434374-v', 0) ],
"_phonetic_a_1_rel" : [ SenseInfo('02857893-a', 2), SenseInfo('02857726-a', 0) ],
"_amalgamate_v_cause_rel" : [ SenseInfo('01462005-v', 0), SenseInfo('01462005-v', 0), SenseInfo('01462005-v', 0) ],
"_setup_n_1_rel" : [ SenseInfo('02727825-n', 2), SenseInfo('04931267-n', 1), SenseInfo('00751398-n', 0), SenseInfo('02727825-n', 2), SenseInfo('04931267-n', 1), SenseInfo('00751398-n', 0), SenseInfo('02727825-n', 2), SenseInfo('04931267-n', 1), SenseInfo('00751398-n', 0) ],
"_undergo_v_1_rel" : [ SenseInfo('02108377-v', 0) ],
"_duke_n_1_rel" : [ SenseInfo('10038620-n', 1), SenseInfo('10038778-n', 0) ],
"_peachy_a_1_rel" : [ SenseInfo('01123879-a', 0), SenseInfo('00379267-a', 0), SenseInfo('01123879-a', 0), SenseInfo('00379267-a', 0), SenseInfo('01123879-a', 0), SenseInfo('00379267-a', 0) ],
"_questioning_a_1_rel" : [ SenseInfo('01766784-a', 1), SenseInfo('02463847-a', 0), SenseInfo('00664879-a', 0) ],
"_subarea_n_of_rel" : [  ],
"_mince_v_1_rel" : [ SenseInfo('01058036-v', 2), SenseInfo('01929927-v', 0), SenseInfo('01560583-v', 0) ],
"_zebra_n_1_rel" : [ SenseInfo('02391049-n', 0) ],
"_negligible_a_1_rel" : [ SenseInfo('01496462-a', 7), SenseInfo('02502994-a', 0), SenseInfo('01496462-a', 7), SenseInfo('02502994-a', 0) ],
"_balinese_n_1_rel" : [ SenseInfo('06939656-n', 1), SenseInfo('06939656-n', 1), SenseInfo('06939656-n', 1) ],
"_hole_n_1_rel" : [ SenseInfo('09304465-n', 12), SenseInfo('03526198-n', 9), SenseInfo('03526805-n', 5), SenseInfo('13911429-n', 2), SenseInfo('09304750-n', 2), SenseInfo('14464793-n', 0), SenseInfo('14409489-n', 0), SenseInfo('05302307-n', 0) ],
"_friendless_a_1_rel" : [ SenseInfo('02528440-a', 0) ],
"_solely_x_deg_rel" : [ SenseInfo('00008600-r', 9) ],
"_simmer_n_1_rel" : [ SenseInfo('05014556-n', 0) ],
"_plaster_v_1_rel" : [ SenseInfo('01362430-v', 1), SenseInfo('01612964-v', 0), SenseInfo('01612818-v', 0), SenseInfo('01362568-v', 0), SenseInfo('01360899-v', 0), SenseInfo('00082929-v', 0) ],
"_south+american_a_1_rel" : [ SenseInfo('02928728-a', 0) ],
"_urethra_n_1_rel" : [ SenseInfo('05513020-n', 0) ],
"_prestressed_a_1_rel" : [  ],
"_campaign_n_1_rel" : [ SenseInfo('07472929-n', 9), SenseInfo('00798245-n', 5), SenseInfo('00968155-n', 4), SenseInfo('00309906-n', 0), SenseInfo('07472929-n', 9), SenseInfo('00798245-n', 5), SenseInfo('00968155-n', 4), SenseInfo('00309906-n', 0), SenseInfo('07472929-n', 9), SenseInfo('00798245-n', 5), SenseInfo('00968155-n', 4), SenseInfo('00309906-n', 0) ],
"_dip_n_1_rel" : [ SenseInfo('13904506-n', 0), SenseInfo('13892897-n', 0), SenseInfo('10431907-n', 0), SenseInfo('07582609-n', 0), SenseInfo('07364434-n', 0), SenseInfo('05111835-n', 0), SenseInfo('03203089-n', 0), SenseInfo('00442847-n', 0), SenseInfo('00435013-n', 0) ],
"_day_n_of_rel" : [ SenseInfo('15155220-n', 169), SenseInfo('15123115-n', 70), SenseInfo('15157225-n', 54), SenseInfo('15164957-n', 38), SenseInfo('15136453-n', 11), SenseInfo('15249236-n', 7), SenseInfo('15208540-n', 0), SenseInfo('15208333-n', 0), SenseInfo('14484516-n', 0), SenseInfo('10925772-n', 0) ],
"_lease_v_1_rel" : [ SenseInfo('02460199-v', 2), SenseInfo('02460619-v', 0), SenseInfo('02208903-v', 0), SenseInfo('02208537-v', 0) ],
"_wipe_v_1_rel" : [ SenseInfo('01392237-v', 17), SenseInfo('01392237-v', 17) ],
"_vest_n_1_rel" : [ SenseInfo('04531873-n', 2), SenseInfo('04223299-n', 0) ],
"_siding_n_1_rel" : [ SenseInfo('04216106-n', 1), SenseInfo('15041050-n', 0) ],
"_sauna_n_1_rel" : [ SenseInfo('04139395-n', 0) ],
"_hike_n_1_rel" : [ SenseInfo('00288970-n', 2), SenseInfo('05110408-n', 0), SenseInfo('05110185-n', 0), SenseInfo('00288970-n', 2), SenseInfo('05110408-n', 0), SenseInfo('05110185-n', 0) ],
"_blueberry_n_1_rel" : [ SenseInfo('12246232-n', 0), SenseInfo('07743544-n', 0) ],
"_to+boot_p_rel" : [ SenseInfo('00046167-r', 1) ],
"_centenary_n_1_rel" : [ SenseInfo('15251336-n', 0) ],
"_disdainful_a_1_rel" : [ SenseInfo('01995288-a', 1), SenseInfo('01891109-a', 0) ],
"_pretty_a_1_rel" : [ SenseInfo('00220082-a', 20), SenseInfo('01128871-a', 3), SenseInfo('00220082-a', 20), SenseInfo('01128871-a', 3), SenseInfo('00220082-a', 20), SenseInfo('01128871-a', 3), SenseInfo('00220082-a', 20), SenseInfo('01128871-a', 3) ],
"_mayhap_a_1_rel" : [  ],
"_librarian_n_1_rel" : [ SenseInfo('10257948-n', 1) ],
"_hm_a_1_rel" : [ SenseInfo('13659604-n', 0) ],
"_walkman_n_1_rel" : [ SenseInfo('04546340-n', 0) ],
"_admonition_n_1_rel" : [ SenseInfo('06672297-n', 3), SenseInfo('06714420-n', 0) ],
"_usage_n_of_rel" : [ SenseInfo('00947128-n', 9), SenseInfo('00413239-n', 1), SenseInfo('06283459-n', 0) ],
"_writedown_n_1_rel" : [  ],
"_pronounce_v_1_rel" : [ SenseInfo('00978549-v', 3), SenseInfo('00971650-v', 3), SenseInfo('00978549-v', 3), SenseInfo('00971650-v', 3), SenseInfo('00978549-v', 3), SenseInfo('00971650-v', 3) ],
"_pop_v_1_rel" : [ SenseInfo('02081946-v', 3), SenseInfo('01404913-v', 3), SenseInfo('02185988-v', 1), SenseInfo('01134071-v', 1), SenseInfo('02186192-v', 0), SenseInfo('02157519-v', 0), SenseInfo('01499510-v', 0), SenseInfo('01474980-v', 0), SenseInfo('01401005-v', 0), SenseInfo('01202374-v', 0), SenseInfo('01199487-v', 0), SenseInfo('00309792-v', 0), SenseInfo('00309582-v', 0), SenseInfo('02081946-v', 3), SenseInfo('01404913-v', 3), SenseInfo('02185988-v', 1), SenseInfo('01134071-v', 1), SenseInfo('02186192-v', 0), SenseInfo('02157519-v', 0), SenseInfo('01499510-v', 0), SenseInfo('01474980-v', 0), SenseInfo('01401005-v', 0), SenseInfo('01202374-v', 0), SenseInfo('01199487-v', 0), SenseInfo('00309792-v', 0), SenseInfo('00309582-v', 0), SenseInfo('02081946-v', 3), SenseInfo('01404913-v', 3), SenseInfo('02185988-v', 1), SenseInfo('01134071-v', 1), SenseInfo('02186192-v', 0), SenseInfo('02157519-v', 0), SenseInfo('01499510-v', 0), SenseInfo('01474980-v', 0), SenseInfo('01401005-v', 0), SenseInfo('01202374-v', 0), SenseInfo('01199487-v', 0), SenseInfo('00309792-v', 0), SenseInfo('00309582-v', 0) ],
"_territory_n_1_rel" : [ SenseInfo('08552138-n', 6), SenseInfo('05999134-n', 2), SenseInfo('08493064-n', 0), SenseInfo('08552138-n', 6), SenseInfo('05999134-n', 2), SenseInfo('08493064-n', 0) ],
"_sell-off_n_1_rel" : [ SenseInfo('01119949-n', 0), SenseInfo('01119949-n', 0) ],
"_quiet_v_cause_rel" : [ SenseInfo('02190188-v', 1), SenseInfo('01764800-v', 1) ],
"_augen+gneiss_n_1_rel" : [  ],
"_recency_n_1_rel" : [ SenseInfo('05049808-n', 0), SenseInfo('04927268-n', 0) ],
"_eccentricity_n_1_rel" : [ SenseInfo('04798881-n', 2), SenseInfo('13877129-n', 0), SenseInfo('05073888-n', 0) ],
"_blindfold_v_1_rel" : [ SenseInfo('01337927-v', 0), SenseInfo('01337927-v', 0) ],
"_outflow_n_1_rel" : [ SenseInfo('07436661-n', 1), SenseInfo('13529295-n', 0), SenseInfo('09443453-n', 0) ],
"_pectoral_n_1_rel" : [ SenseInfo('05551711-n', 3), SenseInfo('03903290-n', 0) ],
"_riot_n_1_rel" : [ SenseInfo('01170502-n', 1), SenseInfo('13977043-n', 0), SenseInfo('06778925-n', 0), SenseInfo('00511212-n', 0) ],
"_flare_v_1_rel" : [ SenseInfo('02762806-v', 1), SenseInfo('00304252-v', 1), SenseInfo('02762981-v', 0), SenseInfo('00307785-v', 0) ],
"_prey_v_upon_rel" : [ SenseInfo('01203715-v', 1), SenseInfo('01203500-v', 0), SenseInfo('01203715-v', 1), SenseInfo('01203500-v', 0) ],
"_short_a_sel_rel" : [ SenseInfo('01442186-a', 43), SenseInfo('01436003-a', 21), SenseInfo('02386612-a', 7), SenseInfo('02336904-a', 3), SenseInfo('02006031-a', 0), SenseInfo('01444620-a', 0), SenseInfo('01444230-a', 0), SenseInfo('02337329-a', 0), SenseInfo('01896046-a', 0), SenseInfo('00709021-a', 0), SenseInfo('00640660-a', 0) ],
"_boxcar_n_1_rel" : [ SenseInfo('02885108-n', 5) ],
"_stressful_a_1_rel" : [ SenseInfo('00090408-a', 0), SenseInfo('00090408-a', 0) ],
"_toiletry_n_1_rel" : [ SenseInfo('04447443-n', 0) ],
"_topological_a_1_rel" : [ SenseInfo('02817533-a', 0) ],
"_chronic_a_1_rel" : [ SenseInfo('00045123-a', 9), SenseInfo('01438963-a', 0), SenseInfo('00489768-a', 0) ],
"_banter_v_1_rel" : [ SenseInfo('00855295-v', 1) ],
"_instant_n_1_rel" : [ SenseInfo('15247110-n', 22), SenseInfo('15244650-n', 9) ],
"_reconcile_v_1_rel" : [ SenseInfo('00482893-v', 2), SenseInfo('00482473-v', 2), SenseInfo('00764902-v', 1), SenseInfo('00732394-v', 1) ],
"_middling_a_1_rel" : [ SenseInfo('01673061-a', 0) ],
"_while_p_1_rel" : [ SenseInfo('15246353-n', 23), SenseInfo('15246353-n', 23) ],
"_valentine_n_1_rel" : [ SenseInfo('10745181-n', 0), SenseInfo('06627816-n', 0) ],
"_prominent_a_1_rel" : [ SenseInfo('00580805-a', 13), SenseInfo('00579622-a', 9), SenseInfo('00580805-a', 13), SenseInfo('00579622-a', 9) ],
"_cart_v_away_rel" : [ SenseInfo('01454810-v', 1), SenseInfo('01451502-v', 0) ],
"_sailboat_n_1_rel" : [ SenseInfo('04128499-n', 0) ],
"_pen_v_1_rel" : [ SenseInfo('01698271-v', 3) ],
"_immeasurable_a_1_rel" : [ SenseInfo('01498957-a', 0), SenseInfo('00302436-a', 0) ],
"_calliope_n_1_rel" : [ SenseInfo('09566320-n', 0), SenseInfo('02940706-n', 0) ],
"_ringmaster_n_1_rel" : [ SenseInfo('10531948-n', 0) ],
"_physicalness_n_1_rel" : [ SenseInfo('04760771-n', 1) ],
"_long+time_a_1_rel" : [ SenseInfo('01640261-a', 0) ],
"_co-exist_v_1_rel" : [ SenseInfo('02604618-v', 1), SenseInfo('02604477-v', 0), SenseInfo('02604618-v', 1), SenseInfo('02604477-v', 0) ],
"_cherish_v_as_rel" : [ SenseInfo('01776214-v', 13), SenseInfo('01776214-v', 13) ],
"_cyclic_a_1_rel" : [ SenseInfo('02708232-a', 0), SenseInfo('00677545-a', 0), SenseInfo('00676555-a', 0), SenseInfo('00675701-a', 0), SenseInfo('01967803-a', 0) ],
"_motor_v_1_rel" : [ SenseInfo('01930117-v', 1) ],
"_encyclopedia_n_of_rel" : [ SenseInfo('06427387-n', 1) ],
"_memorial_a_1_rel" : [ SenseInfo('06688522-n', 1), SenseInfo('06513624-n', 0), SenseInfo('03743902-n', 0) ],
"_chase_v_up_rel" : [ SenseInfo('02001858-v', 10), SenseInfo('02535093-v', 0), SenseInfo('01583881-v', 0), SenseInfo('01277649-v', 0) ],
"_affluent_n_1_rel" : [ SenseInfo('09776642-n', 0), SenseInfo('09278997-n', 0) ],
"_embroil_v_1_rel" : [ SenseInfo('02677797-v', 1) ],
"_topic_n_of_rel" : [ SenseInfo('06599788-n', 5), SenseInfo('05814291-n', 2) ],
"_clan_n_1_rel" : [ SenseInfo('07969695-n', 1) ],
"_slim_v_cause_rel" : [ SenseInfo('00045817-v', 0), SenseInfo('00045817-v', 0) ],
"_middle_a_1_rel" : [ SenseInfo('01014953-a', 5), SenseInfo('00330506-a', 4), SenseInfo('00820458-a', 1), SenseInfo('00815941-a', 1) ],
"_squirt_v_cause_rel" : [ SenseInfo('01375637-v', 1), SenseInfo('01313411-v', 0) ],
"_carnivora_n_1_rel" : [ SenseInfo('02074915-n', 0) ],
"_ce_p_temp_rel" : [ SenseInfo('14633957-n', 0), SenseInfo('00001981-r', 0), SenseInfo('14633957-n', 0), SenseInfo('00001981-r', 0), SenseInfo('14633957-n', 0), SenseInfo('00001981-r', 0), SenseInfo('14633957-n', 0), SenseInfo('00001981-r', 0) ],
"_unassisted_a_1_rel" : [ SenseInfo('02353488-a', 2), SenseInfo('02354129-a', 0), SenseInfo('02353488-a', 2), SenseInfo('02354129-a', 0) ],
"_evince_v_1_rel" : [ SenseInfo('00943837-v', 0) ],
"_billing_n_1_rel" : [ SenseInfo('07190941-n', 0) ],
"_liquor_n_1_rel" : [ SenseInfo('07901587-n', 11), SenseInfo('14941230-n', 7), SenseInfo('07584727-n', 0) ],
"_privative_a_1_rel" : [  ],
"_fuchsia_n_1_rel" : [ SenseInfo('12343480-n', 0) ],
"_emetic_a_1_rel" : [ SenseInfo('03283519-n', 0) ],
"_tyrant_n_1_rel" : [ SenseInfo('10735298-n', 1), SenseInfo('10735707-n', 0), SenseInfo('10735564-n', 0) ],
"_sound_v_cause_rel" : [ SenseInfo('02134927-v', 38), SenseInfo('02176268-v', 14), SenseInfo('02135048-v', 9), SenseInfo('02180529-v', 1), SenseInfo('00952182-v', 1), SenseInfo('02179518-v', 0), SenseInfo('00491689-v', 0) ],
"_physics_n_1_rel" : [ SenseInfo('04025748-n', 0) ],
"_crime_n_1_rel" : [ SenseInfo('00766234-n', 18), SenseInfo('00767477-n', 2) ],
"_grassy_a_1_rel" : [ SenseInfo('00209620-a', 0), SenseInfo('00209620-a', 0), SenseInfo('00209620-a', 0) ],
"_superhero_n_1_rel" : [  ],
"_style_a_1_rel" : [ SenseInfo('04928903-n', 28), SenseInfo('07066659-n', 7), SenseInfo('05844105-n', 7), SenseInfo('05750163-n', 2), SenseInfo('11677259-n', 0), SenseInfo('06789215-n', 0), SenseInfo('04812871-n', 0), SenseInfo('04346511-n', 0), SenseInfo('01901213-n', 0) ],
"_profitability_n_1_rel" : [ SenseInfo('05157866-n', 1) ],
"_beneficiary_n_1_rel" : [ SenseInfo('09850121-n', 2), SenseInfo('06332545-n', 0) ],
"_carbine_n_1_rel" : [ SenseInfo('02961451-n', 2) ],
"_historical-comparative_a_1_rel" : [  ],
"_area_n_of_rel" : [ SenseInfo('08497294-n', 146), SenseInfo('05815517-n', 27), SenseInfo('05221895-n', 20), SenseInfo('14514039-n', 9), SenseInfo('02735688-n', 8), SenseInfo('05128519-n', 5), SenseInfo('08497294-n', 146), SenseInfo('05815517-n', 27), SenseInfo('05221895-n', 20), SenseInfo('14514039-n', 9), SenseInfo('02735688-n', 8), SenseInfo('05128519-n', 5) ],
"_verdant_a_1_rel" : [ SenseInfo('00016647-a', 0) ],
"_explanation_n_1_rel" : [ SenseInfo('06738281-n', 28), SenseInfo('05793000-n', 8), SenseInfo('07232421-n', 0) ],
"_ozone_n_1_rel" : [ SenseInfo('14972807-n', 3) ],
"_palladium_n_1_rel" : [ SenseInfo('14648754-n', 0) ],
"_fold_v_1_rel" : [ SenseInfo('01277974-v', 5), SenseInfo('00398138-v', 1), SenseInfo('02426395-v', 0), SenseInfo('01345877-v', 0), SenseInfo('00564695-v', 0) ],
"_icicle_n_1_rel" : [ SenseInfo('14915928-n', 1) ],
"_quarter-hour_n_1_rel" : [ SenseInfo('15228267-n', 0), SenseInfo('15228267-n', 0) ],
"_morale_n_1_rel" : [ SenseInfo('14374273-n', 2), SenseInfo('04625129-n', 2) ],
"_buy_n_1_rel" : [ SenseInfo('13253751-n', 0) ],
"_limited_a_1_rel" : [ SenseInfo('01415021-a', 25), SenseInfo('02002470-a', 3), SenseInfo('00529191-a', 3), SenseInfo('01913642-a', 0), SenseInfo('01532586-a', 0), SenseInfo('01103844-a', 0), SenseInfo('01007258-a', 0), SenseInfo('01415021-a', 25), SenseInfo('02002470-a', 3), SenseInfo('00529191-a', 3), SenseInfo('01913642-a', 0), SenseInfo('01532586-a', 0), SenseInfo('01103844-a', 0), SenseInfo('01007258-a', 0) ],
"_artificial_a_1_rel" : [ SenseInfo('01571363-a', 4), SenseInfo('00073465-a', 2), SenseInfo('01680417-a', 0), SenseInfo('01571363-a', 4), SenseInfo('00073465-a', 2), SenseInfo('01680417-a', 0) ],
"_exact_v_from_rel" : [ SenseInfo('01017826-v', 1), SenseInfo('00756076-v', 0) ],
"_back_v_away_rel" : [ SenseInfo('02453889-v', 7), SenseInfo('01997119-v', 6), SenseInfo('02556817-v', 4), SenseInfo('01997512-v', 4), SenseInfo('02217695-v', 2), SenseInfo('02693965-v', 0), SenseInfo('01139104-v', 0), SenseInfo('00560628-v', 0), SenseInfo('00223109-v', 0), SenseInfo('00185857-v', 0) ],
"_move_v_1_rel" : [ SenseInfo('01835496-v', 110), SenseInfo('01850315-v', 57), SenseInfo('01831531-v', 52), SenseInfo('01855606-v', 20), SenseInfo('02372605-v', 15), SenseInfo('00014549-v', 7), SenseInfo('00124442-v', 6), SenseInfo('02367363-v', 3), SenseInfo('01767949-v', 3), SenseInfo('01649999-v', 3), SenseInfo('01771390-v', 2), SenseInfo('02355959-v', 1), SenseInfo('00539110-v', 1), SenseInfo('02598863-v', 0), SenseInfo('01076615-v', 0), SenseInfo('00879356-v', 0), SenseInfo('01835496-v', 110), SenseInfo('01850315-v', 57), SenseInfo('01831531-v', 52), SenseInfo('01855606-v', 20), SenseInfo('02372605-v', 15), SenseInfo('00014549-v', 7), SenseInfo('00124442-v', 6), SenseInfo('02367363-v', 3), SenseInfo('01767949-v', 3), SenseInfo('01649999-v', 3), SenseInfo('01771390-v', 2), SenseInfo('02355959-v', 1), SenseInfo('00539110-v', 1), SenseInfo('02598863-v', 0), SenseInfo('01076615-v', 0), SenseInfo('00879356-v', 0), SenseInfo('01835496-v', 110), SenseInfo('01850315-v', 57), SenseInfo('01831531-v', 52), SenseInfo('01855606-v', 20), SenseInfo('02372605-v', 15), SenseInfo('00014549-v', 7), SenseInfo('00124442-v', 6), SenseInfo('02367363-v', 3), SenseInfo('01767949-v', 3), SenseInfo('01649999-v', 3), SenseInfo('01771390-v', 2), SenseInfo('02355959-v', 1), SenseInfo('00539110-v', 1), SenseInfo('02598863-v', 0), SenseInfo('01076615-v', 0), SenseInfo('00879356-v', 0), SenseInfo('01835496-v', 110), SenseInfo('01850315-v', 57), SenseInfo('01831531-v', 52), SenseInfo('01855606-v', 20), SenseInfo('02372605-v', 15), SenseInfo('00014549-v', 7), SenseInfo('00124442-v', 6), SenseInfo('02367363-v', 3), SenseInfo('01767949-v', 3), SenseInfo('01649999-v', 3), SenseInfo('01771390-v', 2), SenseInfo('02355959-v', 1), SenseInfo('00539110-v', 1), SenseInfo('02598863-v', 0), SenseInfo('01076615-v', 0), SenseInfo('00879356-v', 0) ],
"_engraving_n_1_rel" : [ SenseInfo('03289268-n', 0), SenseInfo('03289025-n', 0), SenseInfo('00938791-n', 0) ],
"_diagonal_a_1_rel" : [ SenseInfo('01719870-a', 4), SenseInfo('01234747-a', 0), SenseInfo('01719870-a', 4), SenseInfo('01234747-a', 0) ],
"_underdeveloped_a_1_rel" : [ SenseInfo('01302544-a', 2), SenseInfo('01491691-a', 0) ],
"_horseback+ride_v_1_rel" : [  ],
"_coerce_v_1_rel" : [ SenseInfo('02504562-v', 2), SenseInfo('02504562-v', 2) ],
"_witch_n_1_rel" : [ SenseInfo('10055297-n', 3), SenseInfo('09503282-n', 2), SenseInfo('10780105-n', 0), SenseInfo('10155485-n', 0) ],
"_invigorate_v_1_rel" : [ SenseInfo('01812720-v', 0), SenseInfo('00442063-v', 0), SenseInfo('00192836-v', 0), SenseInfo('00028362-v', 0), SenseInfo('01812720-v', 0), SenseInfo('00442063-v', 0), SenseInfo('00192836-v', 0), SenseInfo('00028362-v', 0), SenseInfo('01812720-v', 0), SenseInfo('00442063-v', 0), SenseInfo('00192836-v', 0), SenseInfo('00028362-v', 0), SenseInfo('01812720-v', 0), SenseInfo('00442063-v', 0), SenseInfo('00192836-v', 0), SenseInfo('00028362-v', 0), SenseInfo('01812720-v', 0), SenseInfo('00442063-v', 0), SenseInfo('00192836-v', 0), SenseInfo('00028362-v', 0) ],
"_estate_n_1_rel" : [ SenseInfo('13250930-n', 9), SenseInfo('13246662-n', 2), SenseInfo('08167365-n', 0) ],
"_arrogant_a_1_rel" : [ SenseInfo('01889819-a', 1) ],
"_statesman_n_1_rel" : [ SenseInfo('10650162-n', 4) ],
"_alcoholic_n_1_rel" : [ SenseInfo('09782167-n', 0) ],
"_tradable_a_1_rel" : [  ],
"_believe_v_1_rel" : [ SenseInfo('00683280-v', 118), SenseInfo('00689344-v', 72), SenseInfo('00721098-v', 37), SenseInfo('00684273-v', 10), SenseInfo('00684068-v', 2), SenseInfo('00683280-v', 118), SenseInfo('00689344-v', 72), SenseInfo('00721098-v', 37), SenseInfo('00684273-v', 10), SenseInfo('00684068-v', 2), SenseInfo('00683280-v', 118), SenseInfo('00689344-v', 72), SenseInfo('00721098-v', 37), SenseInfo('00684273-v', 10), SenseInfo('00684068-v', 2), SenseInfo('00683280-v', 118), SenseInfo('00689344-v', 72), SenseInfo('00721098-v', 37), SenseInfo('00684273-v', 10), SenseInfo('00684068-v', 2) ],
"_dash_v_1_rel" : [ SenseInfo('02061495-v', 7), SenseInfo('00335923-v', 2), SenseInfo('01507407-v', 1), SenseInfo('02558703-v', 0), SenseInfo('01785748-v', 0), SenseInfo('00184377-v', 0) ],
"_insist_v_on_rel" : [ SenseInfo('00818974-v', 59), SenseInfo('00777931-v', 4), SenseInfo('00717045-v', 1) ],
"_dingy_a_1_rel" : [ SenseInfo('00420650-a', 4), SenseInfo('01909077-a', 0), SenseInfo('00364881-a', 0), SenseInfo('00420650-a', 4), SenseInfo('01909077-a', 0), SenseInfo('00364881-a', 0), SenseInfo('00420650-a', 4), SenseInfo('01909077-a', 0), SenseInfo('00364881-a', 0) ],
"_makeup_n_1_rel" : [ SenseInfo('03714235-n', 1), SenseInfo('07322769-n', 0), SenseInfo('04933544-n', 0), SenseInfo('03714235-n', 1), SenseInfo('07322769-n', 0), SenseInfo('04933544-n', 0), SenseInfo('03714235-n', 1), SenseInfo('07322769-n', 0), SenseInfo('04933544-n', 0) ],
"_NV_n_1_rel" : [ SenseInfo('09110422-n', 0), SenseInfo('09110422-n', 0), SenseInfo('09110422-n', 0) ],
"_colorline_n_1_rel" : [  ],
"_connective_n_1_rel" : [ SenseInfo('06325826-n', 0), SenseInfo('03091374-n', 0) ],
"_nomore_a_1_rel" : [  ],
"_tiresome_a_1_rel" : [ SenseInfo('01345307-a', 1), SenseInfo('01345307-a', 1) ],
"_cedar_n_1_rel" : [ SenseInfo('11630017-n', 0), SenseInfo('11623304-n', 0), SenseInfo('11623105-n', 0) ],
"_senior_n_1_rel" : [ SenseInfo('10579062-n', 3), SenseInfo('10048218-n', 0), SenseInfo('10579062-n', 3), SenseInfo('10048218-n', 0), SenseInfo('10579062-n', 3), SenseInfo('10048218-n', 0) ],
"_clean_v_1_rel" : [ SenseInfo('01532589-v', 16), SenseInfo('00177714-v', 3), SenseInfo('01533442-v', 2), SenseInfo('00035758-v', 1), SenseInfo('02741960-v', 0), SenseInfo('01608951-v', 0), SenseInfo('01608706-v', 0), SenseInfo('01532434-v', 0), SenseInfo('00180837-v', 0), SenseInfo('00177861-v', 0), SenseInfo('01532589-v', 16), SenseInfo('00177714-v', 3), SenseInfo('01533442-v', 2), SenseInfo('00035758-v', 1), SenseInfo('02741960-v', 0), SenseInfo('01608951-v', 0), SenseInfo('01608706-v', 0), SenseInfo('01532434-v', 0), SenseInfo('00180837-v', 0), SenseInfo('00177861-v', 0) ],
"_on+the+part+of_p_rel" : [  ],
"_waterbag_n_1_rel" : [  ],
"_dryer_n_1_rel" : [ SenseInfo('03251766-n', 0) ],
"_watch_v_1_rel" : [ SenseInfo('02150510-v', 77), SenseInfo('02455407-v', 64), SenseInfo('02150948-v', 24), SenseInfo('02128653-v', 10), SenseInfo('02151966-v', 1), SenseInfo('02131963-v', 0), SenseInfo('00920336-v', 0), SenseInfo('02150510-v', 77), SenseInfo('02455407-v', 64), SenseInfo('02150948-v', 24), SenseInfo('02128653-v', 10), SenseInfo('02151966-v', 1), SenseInfo('02131963-v', 0), SenseInfo('00920336-v', 0), SenseInfo('02150510-v', 77), SenseInfo('02455407-v', 64), SenseInfo('02150948-v', 24), SenseInfo('02128653-v', 10), SenseInfo('02151966-v', 1), SenseInfo('02131963-v', 0), SenseInfo('00920336-v', 0) ],
"_summertime_a_1_rel" : [ SenseInfo('15237250-n', 0) ],
"_exhibitor_n_1_rel" : [ SenseInfo('10070563-n', 0) ],
"_motoric_a_1_rel" : [  ],
"_drink_v_down_rel" : [ SenseInfo('01170052-v', 30), SenseInfo('01171183-v', 10), SenseInfo('01175467-v', 1), SenseInfo('00737005-v', 1), SenseInfo('01172275-v', 0) ],
"_euchre_n_1_rel" : [ SenseInfo('00492309-n', 0) ],
"_distinction_n_1_rel" : [ SenseInfo('05748285-n', 11), SenseInfo('14435445-n', 5), SenseInfo('04806655-n', 4), SenseInfo('04749572-n', 3) ],
"_astound_v_1_rel" : [ SenseInfo('00724832-v', 3), SenseInfo('00724832-v', 3), SenseInfo('00724832-v', 3), SenseInfo('00724832-v', 3) ],
"_dawn_n_1_rel" : [ SenseInfo('15168790-n', 11), SenseInfo('07326108-n', 1), SenseInfo('15267945-n', 0) ],
"_elite_a_1_rel" : [ SenseInfo('02123579-a', 0) ],
"_identity_n_1_rel" : [ SenseInfo('04618070-n', 12), SenseInfo('05763412-n', 6), SenseInfo('13786748-n', 2), SenseInfo('04743024-n', 2) ],
"_organophosphorus_n_1_rel" : [  ],
"_fascist_a_1_rel" : [ SenseInfo('02920769-a', 1) ],
"_inviting_a_1_rel" : [ SenseInfo('01358363-a', 2) ],
"_bastion_n_1_rel" : [ SenseInfo('08064372-n', 1), SenseInfo('02806088-n', 0), SenseInfo('02805983-n', 0) ],
"_flare_v_up_rel" : [ SenseInfo('02762806-v', 1), SenseInfo('00304252-v', 1), SenseInfo('02762981-v', 0), SenseInfo('00307785-v', 0) ],
"_mitral_a_1_rel" : [ SenseInfo('03019576-a', 1), SenseInfo('03019709-a', 0) ],
"_relieving_a_1_rel" : [  ],
"_yellowish_a_1_rel" : [ SenseInfo('00385756-a', 0) ],
"_wedge_n_of_rel" : [ SenseInfo('13919547-n', 1), SenseInfo('07697825-n', 0), SenseInfo('06823259-n', 0), SenseInfo('04569983-n', 0), SenseInfo('04569822-n', 0), SenseInfo('04569520-n', 0), SenseInfo('03023878-n', 0) ],
"_pharmaceutical_a_1_rel" : [ SenseInfo('03098803-a', 1), SenseInfo('03099131-a', 0) ],
"_firm_v_1_rel" : [ SenseInfo('00420549-v', 0), SenseInfo('00420434-v', 0) ],
"_persuade_v_of_rel" : [ SenseInfo('02586121-v', 17), SenseInfo('00766418-v', 12), SenseInfo('02586121-v', 17), SenseInfo('00766418-v', 12), SenseInfo('02586121-v', 17), SenseInfo('00766418-v', 12), SenseInfo('02586121-v', 17), SenseInfo('00766418-v', 12) ],
"_three-bagger_n_1_rel" : [ SenseInfo('00132982-n', 0), SenseInfo('00132982-n', 0) ],
"_yes_a_1_rel" : [ SenseInfo('07203900-n', 15), SenseInfo('07203900-n', 15) ],
"_radiance_n_1_rel" : [ SenseInfo('11463371-n', 2), SenseInfo('04953954-n', 1), SenseInfo('14051201-n', 0) ],
"_harper_n_1_rel" : [ SenseInfo('10160770-n', 0) ],
"_crows+nest_n_1_rel" : [  ],
"_evacuation_n_of_rel" : [ SenseInfo('00395797-n', 2), SenseInfo('00054821-n', 1), SenseInfo('13473097-n', 0) ],
"_gesticulation_n_1_rel" : [ SenseInfo('06876771-n', 0) ],
"_write_v_out_rel" : [ SenseInfo('01698271-v', 112), SenseInfo('00993014-v', 94), SenseInfo('01744611-v', 33), SenseInfo('01007027-v', 15), SenseInfo('01031966-v', 10), SenseInfo('01705494-v', 9), SenseInfo('01691057-v', 8), SenseInfo('00998886-v', 4), SenseInfo('01699896-v', 1), SenseInfo('01692834-v', 0) ],
"_chap_n_1_rel" : [ SenseInfo('09908025-n', 1), SenseInfo('13907272-n', 0), SenseInfo('09241929-n', 0), SenseInfo('03006903-n', 0) ],
"_puff_n_1_rel" : [ SenseInfo('11497888-n', 0), SenseInfo('07628470-n', 0), SenseInfo('06695110-n', 0), SenseInfo('04033995-n', 0), SenseInfo('03994874-n', 0), SenseInfo('03858418-n', 0), SenseInfo('00837675-n', 0), SenseInfo('00835501-n', 0) ],
"_motorist_n_1_rel" : [ SenseInfo('10334101-n', 0) ],
"_workforce_n_1_rel" : [ SenseInfo('08212347-n', 0) ],
"_masterpiece_n_1_rel" : [ SenseInfo('03727605-n', 4), SenseInfo('00037006-n', 2) ],
"_landfill_n_1_rel" : [ SenseInfo('09335809-n', 0) ],
"_seam_n_1_rel" : [ SenseInfo('04160372-n', 2), SenseInfo('13905792-n', 0), SenseInfo('08659076-n', 0) ],
"_signpost_v_1_rel" : [ SenseInfo('00922320-v', 0) ],
"_shaggy_a_1_rel" : [ SenseInfo('02428610-a', 1), SenseInfo('02242887-a', 0) ],
"_thermometer_n_1_rel" : [ SenseInfo('04421872-n', 10) ],
"_road+south_n_1_rel" : [  ],
"_painting_n_of_rel" : [ SenseInfo('03876519-n', 13), SenseInfo('00936620-n', 9), SenseInfo('00717208-n', 4), SenseInfo('00609236-n', 1) ],
"_liquid_a_1_rel" : [ SenseInfo('02261386-a', 19), SenseInfo('02473371-a', 1), SenseInfo('00432453-a', 1), SenseInfo('01505991-a', 0), SenseInfo('01505041-a', 0), SenseInfo('01139832-a', 0), SenseInfo('00778017-a', 0) ],
"_laid+back_a_1_rel" : [ SenseInfo('02408011-a', 0), SenseInfo('02408011-a', 0) ],
"_green_a_1_rel" : [ SenseInfo('00375969-a', 26), SenseInfo('03069937-a', 0), SenseInfo('01493897-a', 0), SenseInfo('02545257-a', 0), SenseInfo('02272485-a', 0), SenseInfo('00375969-a', 26), SenseInfo('03069937-a', 0), SenseInfo('01493897-a', 0), SenseInfo('02545257-a', 0), SenseInfo('02272485-a', 0), SenseInfo('00375969-a', 26), SenseInfo('03069937-a', 0), SenseInfo('01493897-a', 0), SenseInfo('02545257-a', 0), SenseInfo('02272485-a', 0) ],
"_juice_n_1_rel" : [ SenseInfo('07923748-n', 2), SenseInfo('14050434-n', 0), SenseInfo('11470348-n', 0), SenseInfo('05398609-n', 0) ],
"_peerless_a_1_rel" : [ SenseInfo('00505410-a', 0) ],
"_bishop_n_1_rel" : [ SenseInfo('09857200-n', 6), SenseInfo('07913300-n', 0), SenseInfo('02844056-n', 0) ],
"_methylate_v_1_rel" : [  ],
"_sampler_n_1_rel" : [ SenseInfo('04133346-n', 1), SenseInfo('10692482-n', 0), SenseInfo('08463817-n', 0), SenseInfo('04133211-n', 0) ],
"time_n_rel" : [ SenseInfo('07309599-n', 219), SenseInfo('15270431-n', 160), SenseInfo('15122231-n', 114), SenseInfo('15245515-n', 43), SenseInfo('00028270-n', 36), SenseInfo('07288215-n', 10), SenseInfo('15129927-n', 7), SenseInfo('15135822-n', 5), SenseInfo('04991738-n', 1), SenseInfo('15224692-n', 0), SenseInfo('07309599-n', 219), SenseInfo('15270431-n', 160), SenseInfo('15122231-n', 114), SenseInfo('15245515-n', 43), SenseInfo('00028270-n', 36), SenseInfo('07288215-n', 10), SenseInfo('15129927-n', 7), SenseInfo('15135822-n', 5), SenseInfo('04991738-n', 1), SenseInfo('15224692-n', 0), SenseInfo('07309599-n', 219), SenseInfo('15270431-n', 160), SenseInfo('15122231-n', 114), SenseInfo('15245515-n', 43), SenseInfo('00028270-n', 36), SenseInfo('07288215-n', 10), SenseInfo('15129927-n', 7), SenseInfo('15135822-n', 5), SenseInfo('04991738-n', 1), SenseInfo('15224692-n', 0), SenseInfo('07309599-n', 219), SenseInfo('15270431-n', 160), SenseInfo('15122231-n', 114), SenseInfo('15245515-n', 43), SenseInfo('00028270-n', 36), SenseInfo('07288215-n', 10), SenseInfo('15129927-n', 7), SenseInfo('15135822-n', 5), SenseInfo('04991738-n', 1), SenseInfo('15224692-n', 0), SenseInfo('07309599-n', 219), SenseInfo('15270431-n', 160), SenseInfo('15122231-n', 114), SenseInfo('15245515-n', 43), SenseInfo('00028270-n', 36), SenseInfo('07288215-n', 10), SenseInfo('15129927-n', 7), SenseInfo('15135822-n', 5), SenseInfo('04991738-n', 1), SenseInfo('15224692-n', 0), SenseInfo('07309599-n', 219), SenseInfo('15270431-n', 160), SenseInfo('15122231-n', 114), SenseInfo('15245515-n', 43), SenseInfo('00028270-n', 36), SenseInfo('07288215-n', 10), SenseInfo('15129927-n', 7), SenseInfo('15135822-n', 5), SenseInfo('04991738-n', 1), SenseInfo('15224692-n', 0), SenseInfo('07309599-n', 219), SenseInfo('15270431-n', 160), SenseInfo('15122231-n', 114), SenseInfo('15245515-n', 43), SenseInfo('00028270-n', 36), SenseInfo('07288215-n', 10), SenseInfo('15129927-n', 7), SenseInfo('15135822-n', 5), SenseInfo('04991738-n', 1), SenseInfo('15224692-n', 0), SenseInfo('07309599-n', 219), SenseInfo('15270431-n', 160), SenseInfo('15122231-n', 114), SenseInfo('15245515-n', 43), SenseInfo('00028270-n', 36), SenseInfo('07288215-n', 10), SenseInfo('15129927-n', 7), SenseInfo('15135822-n', 5), SenseInfo('04991738-n', 1), SenseInfo('15224692-n', 0), SenseInfo('07309599-n', 219), SenseInfo('15270431-n', 160), SenseInfo('15122231-n', 114), SenseInfo('15245515-n', 43), SenseInfo('00028270-n', 36), SenseInfo('07288215-n', 10), SenseInfo('15129927-n', 7), SenseInfo('15135822-n', 5), SenseInfo('04991738-n', 1), SenseInfo('15224692-n', 0), SenseInfo('07309599-n', 219), SenseInfo('15270431-n', 160), SenseInfo('15122231-n', 114), SenseInfo('15245515-n', 43), SenseInfo('00028270-n', 36), SenseInfo('07288215-n', 10), SenseInfo('15129927-n', 7), SenseInfo('15135822-n', 5), SenseInfo('04991738-n', 1), SenseInfo('15224692-n', 0), SenseInfo('07309599-n', 219), SenseInfo('15270431-n', 160), SenseInfo('15122231-n', 114), SenseInfo('15245515-n', 43), SenseInfo('00028270-n', 36), SenseInfo('07288215-n', 10), SenseInfo('15129927-n', 7), SenseInfo('15135822-n', 5), SenseInfo('04991738-n', 1), SenseInfo('15224692-n', 0), SenseInfo('07309599-n', 219), SenseInfo('15270431-n', 160), SenseInfo('15122231-n', 114), SenseInfo('15245515-n', 43), SenseInfo('00028270-n', 36), SenseInfo('07288215-n', 10), SenseInfo('15129927-n', 7), SenseInfo('15135822-n', 5), SenseInfo('04991738-n', 1), SenseInfo('15224692-n', 0), SenseInfo('07309599-n', 219), SenseInfo('15270431-n', 160), SenseInfo('15122231-n', 114), SenseInfo('15245515-n', 43), SenseInfo('00028270-n', 36), SenseInfo('07288215-n', 10), SenseInfo('15129927-n', 7), SenseInfo('15135822-n', 5), SenseInfo('04991738-n', 1), SenseInfo('15224692-n', 0), SenseInfo('07309599-n', 219), SenseInfo('15270431-n', 160), SenseInfo('15122231-n', 114), SenseInfo('15245515-n', 43), SenseInfo('00028270-n', 36), SenseInfo('07288215-n', 10), SenseInfo('15129927-n', 7), SenseInfo('15135822-n', 5), SenseInfo('04991738-n', 1), SenseInfo('15224692-n', 0), SenseInfo('07309599-n', 219), SenseInfo('15270431-n', 160), SenseInfo('15122231-n', 114), SenseInfo('15245515-n', 43), SenseInfo('00028270-n', 36), SenseInfo('07288215-n', 10), SenseInfo('15129927-n', 7), SenseInfo('15135822-n', 5), SenseInfo('04991738-n', 1), SenseInfo('15224692-n', 0), SenseInfo('07309599-n', 219), SenseInfo('15270431-n', 160), SenseInfo('15122231-n', 114), SenseInfo('15245515-n', 43), SenseInfo('00028270-n', 36), SenseInfo('07288215-n', 10), SenseInfo('15129927-n', 7), SenseInfo('15135822-n', 5), SenseInfo('04991738-n', 1), SenseInfo('15224692-n', 0), SenseInfo('07309599-n', 219), SenseInfo('15270431-n', 160), SenseInfo('15122231-n', 114), SenseInfo('15245515-n', 43), SenseInfo('00028270-n', 36), SenseInfo('07288215-n', 10), SenseInfo('15129927-n', 7), SenseInfo('15135822-n', 5), SenseInfo('04991738-n', 1), SenseInfo('15224692-n', 0), SenseInfo('07309599-n', 219), SenseInfo('15270431-n', 160), SenseInfo('15122231-n', 114), SenseInfo('15245515-n', 43), SenseInfo('00028270-n', 36), SenseInfo('07288215-n', 10), SenseInfo('15129927-n', 7), SenseInfo('15135822-n', 5), SenseInfo('04991738-n', 1), SenseInfo('15224692-n', 0), SenseInfo('07309599-n', 219), SenseInfo('15270431-n', 160), SenseInfo('15122231-n', 114), SenseInfo('15245515-n', 43), SenseInfo('00028270-n', 36), SenseInfo('07288215-n', 10), SenseInfo('15129927-n', 7), SenseInfo('15135822-n', 5), SenseInfo('04991738-n', 1), SenseInfo('15224692-n', 0), SenseInfo('07309599-n', 219), SenseInfo('15270431-n', 160), SenseInfo('15122231-n', 114), SenseInfo('15245515-n', 43), SenseInfo('00028270-n', 36), SenseInfo('07288215-n', 10), SenseInfo('15129927-n', 7), SenseInfo('15135822-n', 5), SenseInfo('04991738-n', 1), SenseInfo('15224692-n', 0), SenseInfo('07309599-n', 219), SenseInfo('15270431-n', 160), SenseInfo('15122231-n', 114), SenseInfo('15245515-n', 43), SenseInfo('00028270-n', 36), SenseInfo('07288215-n', 10), SenseInfo('15129927-n', 7), SenseInfo('15135822-n', 5), SenseInfo('04991738-n', 1), SenseInfo('15224692-n', 0), SenseInfo('07309599-n', 219), SenseInfo('15270431-n', 160), SenseInfo('15122231-n', 114), SenseInfo('15245515-n', 43), SenseInfo('00028270-n', 36), SenseInfo('07288215-n', 10), SenseInfo('15129927-n', 7), SenseInfo('15135822-n', 5), SenseInfo('04991738-n', 1), SenseInfo('15224692-n', 0), SenseInfo('07309599-n', 219), SenseInfo('15270431-n', 160), SenseInfo('15122231-n', 114), SenseInfo('15245515-n', 43), SenseInfo('00028270-n', 36), SenseInfo('07288215-n', 10), SenseInfo('15129927-n', 7), SenseInfo('15135822-n', 5), SenseInfo('04991738-n', 1), SenseInfo('15224692-n', 0), SenseInfo('07309599-n', 219), SenseInfo('15270431-n', 160), SenseInfo('15122231-n', 114), SenseInfo('15245515-n', 43), SenseInfo('00028270-n', 36), SenseInfo('07288215-n', 10), SenseInfo('15129927-n', 7), SenseInfo('15135822-n', 5), SenseInfo('04991738-n', 1), SenseInfo('15224692-n', 0), SenseInfo('07309599-n', 219), SenseInfo('15270431-n', 160), SenseInfo('15122231-n', 114), SenseInfo('15245515-n', 43), SenseInfo('00028270-n', 36), SenseInfo('07288215-n', 10), SenseInfo('15129927-n', 7), SenseInfo('15135822-n', 5), SenseInfo('04991738-n', 1), SenseInfo('15224692-n', 0), SenseInfo('07309599-n', 219), SenseInfo('15270431-n', 160), SenseInfo('15122231-n', 114), SenseInfo('15245515-n', 43), SenseInfo('00028270-n', 36), SenseInfo('07288215-n', 10), SenseInfo('15129927-n', 7), SenseInfo('15135822-n', 5), SenseInfo('04991738-n', 1), SenseInfo('15224692-n', 0), SenseInfo('07309599-n', 219), SenseInfo('15270431-n', 160), SenseInfo('15122231-n', 114), SenseInfo('15245515-n', 43), SenseInfo('00028270-n', 36), SenseInfo('07288215-n', 10), SenseInfo('15129927-n', 7), SenseInfo('15135822-n', 5), SenseInfo('04991738-n', 1), SenseInfo('15224692-n', 0), SenseInfo('07309599-n', 219), SenseInfo('15270431-n', 160), SenseInfo('15122231-n', 114), SenseInfo('15245515-n', 43), SenseInfo('00028270-n', 36), SenseInfo('07288215-n', 10), SenseInfo('15129927-n', 7), SenseInfo('15135822-n', 5), SenseInfo('04991738-n', 1), SenseInfo('15224692-n', 0), SenseInfo('07309599-n', 219), SenseInfo('15270431-n', 160), SenseInfo('15122231-n', 114), SenseInfo('15245515-n', 43), SenseInfo('00028270-n', 36), SenseInfo('07288215-n', 10), SenseInfo('15129927-n', 7), SenseInfo('15135822-n', 5), SenseInfo('04991738-n', 1), SenseInfo('15224692-n', 0), SenseInfo('07309599-n', 219), SenseInfo('15270431-n', 160), SenseInfo('15122231-n', 114), SenseInfo('15245515-n', 43), SenseInfo('00028270-n', 36), SenseInfo('07288215-n', 10), SenseInfo('15129927-n', 7), SenseInfo('15135822-n', 5), SenseInfo('04991738-n', 1), SenseInfo('15224692-n', 0) ],
"_ploy_n_1_rel" : [ SenseInfo('06765531-n', 0), SenseInfo('00172490-n', 0), SenseInfo('06765531-n', 0), SenseInfo('00172490-n', 0) ],
"_map_n_of_rel" : [ SenseInfo('03720163-n', 7), SenseInfo('13783816-n', 0) ],
"_unanimity_n_1_rel" : [ SenseInfo('13972387-n', 0) ],
"_misunderstanding_n_1_rel" : [ SenseInfo('07174433-n', 1), SenseInfo('05895723-n', 0) ],
"_uniqueness_n_1_rel" : [ SenseInfo('04763650-n', 3) ],
"_unwise_a_for_rel" : [ SenseInfo('02572657-a', 2), SenseInfo('01814252-a', 0), SenseInfo('02572657-a', 2), SenseInfo('01814252-a', 0) ],
"_crop_n_1_rel" : [ SenseInfo('13085864-n', 8), SenseInfo('11530512-n', 0), SenseInfo('07955566-n', 0), SenseInfo('03134595-n', 0), SenseInfo('03134496-n', 0), SenseInfo('01974055-n', 0) ],
"_reward_v_1_rel" : [ SenseInfo('02546075-v', 1), SenseInfo('00787660-v', 1), SenseInfo('02344381-v', 0), SenseInfo('02546075-v', 1), SenseInfo('00787660-v', 1), SenseInfo('02344381-v', 0), SenseInfo('02546075-v', 1), SenseInfo('00787660-v', 1), SenseInfo('02344381-v', 0), SenseInfo('02546075-v', 1), SenseInfo('00787660-v', 1), SenseInfo('02344381-v', 0) ],
"_underneath_p_rel" : [ SenseInfo('00487623-r', 0), SenseInfo('00487408-r', 0), SenseInfo('00487623-r', 0), SenseInfo('00487408-r', 0) ],
"_last+place_n_1_rel" : [  ],
"_methodist_n_1_rel" : [ SenseInfo('10312600-n', 0) ],
"_telegraph_n_1_rel" : [ SenseInfo('04400499-n', 3) ],
"_horticulturist_n_1_rel" : [ SenseInfo('10186350-n', 0) ],
"_nodding_a_1_rel" : [ SenseInfo('01238486-a', 0) ],
"_scrabble_v_1_rel" : [ SenseInfo('01314440-v', 0), SenseInfo('01006239-v', 0) ],
"_impedance_n_1_rel" : [ SenseInfo('11503968-n', 0) ],
"_mostly_x_deg_rel" : [ SenseInfo('00006105-r', 10), SenseInfo('00155621-r', 3), SenseInfo('00006105-r', 10), SenseInfo('00155621-r', 3), SenseInfo('00006105-r', 10), SenseInfo('00155621-r', 3) ],
"_buy_v_into_rel" : [ SenseInfo('02207206-v', 102), SenseInfo('02284096-v', 2), SenseInfo('02646757-v', 0), SenseInfo('02212103-v', 0), SenseInfo('00683670-v', 0) ],
"_convoke_v_1_rel" : [ SenseInfo('00793037-v', 0) ],
"_message_n_of_rel" : [ SenseInfo('06253690-n', 20), SenseInfo('06598915-n', 11), SenseInfo('06253690-n', 20), SenseInfo('06598915-n', 11), SenseInfo('06253690-n', 20), SenseInfo('06598915-n', 11), SenseInfo('06253690-n', 20), SenseInfo('06598915-n', 11), SenseInfo('06253690-n', 20), SenseInfo('06598915-n', 11) ],
"_instructor_n_1_rel" : [ SenseInfo('10694258-n', 5) ],
"_source_n_2_rel" : [ SenseInfo('08507558-n', 34), SenseInfo('06675122-n', 12), SenseInfo('05834758-n', 12), SenseInfo('04263614-n', 8), SenseInfo('10205985-n', 3), SenseInfo('10126177-n', 1), SenseInfo('13558953-n', 0), SenseInfo('09407867-n', 0), SenseInfo('07258664-n', 0), SenseInfo('08507558-n', 34), SenseInfo('06675122-n', 12), SenseInfo('05834758-n', 12), SenseInfo('04263614-n', 8), SenseInfo('10205985-n', 3), SenseInfo('10126177-n', 1), SenseInfo('13558953-n', 0), SenseInfo('09407867-n', 0), SenseInfo('07258664-n', 0) ],
"_willful_a_1_rel" : [ SenseInfo('02520693-a', 1), SenseInfo('01614372-a', 0) ],
"_germ_n_1_rel" : [ SenseInfo('05834758-n', 1), SenseInfo('05229805-n', 0), SenseInfo('01384491-n', 0) ],
"_control_n_of_rel" : [ SenseInfo('05196375-n', 19), SenseInfo('13827205-n', 16), SenseInfo('00830448-n', 7), SenseInfo('05798569-n', 5), SenseInfo('00803617-n', 5), SenseInfo('14441825-n', 4), SenseInfo('04882968-n', 3), SenseInfo('05641959-n', 2), SenseInfo('03096960-n', 1), SenseInfo('09504790-n', 0), SenseInfo('06657202-n', 0), SenseInfo('05196375-n', 19), SenseInfo('13827205-n', 16), SenseInfo('00830448-n', 7), SenseInfo('05798569-n', 5), SenseInfo('00803617-n', 5), SenseInfo('14441825-n', 4), SenseInfo('04882968-n', 3), SenseInfo('05641959-n', 2), SenseInfo('03096960-n', 1), SenseInfo('09504790-n', 0), SenseInfo('06657202-n', 0), SenseInfo('05196375-n', 19), SenseInfo('13827205-n', 16), SenseInfo('00830448-n', 7), SenseInfo('05798569-n', 5), SenseInfo('00803617-n', 5), SenseInfo('14441825-n', 4), SenseInfo('04882968-n', 3), SenseInfo('05641959-n', 2), SenseInfo('03096960-n', 1), SenseInfo('09504790-n', 0), SenseInfo('06657202-n', 0) ],
"_draw_v_out_rel" : [ SenseInfo('01448100-v', 13), SenseInfo('02293148-v', 10), SenseInfo('01582645-v', 10), SenseInfo('00730758-v', 10), SenseInfo('01995211-v', 9), SenseInfo('01690294-v', 7), SenseInfo('01854132-v', 6), SenseInfo('00987071-v', 6), SenseInfo('00675901-v', 6), SenseInfo('01760300-v', 5), SenseInfo('01199009-v', 5), SenseInfo('02088107-v', 4), SenseInfo('02311387-v', 3), SenseInfo('01078050-v', 3), SenseInfo('01643297-v', 2), SenseInfo('00556593-v', 2), SenseInfo('02097800-v', 1), SenseInfo('01690816-v', 1), SenseInfo('01643464-v', 1), SenseInfo('01243148-v', 1), SenseInfo('02742107-v', 0), SenseInfo('02628832-v', 0), SenseInfo('02483564-v', 0), SenseInfo('02103162-v', 0), SenseInfo('01539063-v', 0), SenseInfo('01505254-v', 0), SenseInfo('01359432-v', 0), SenseInfo('01243298-v', 0), SenseInfo('01212230-v', 0), SenseInfo('01115190-v', 0), SenseInfo('00476965-v', 0), SenseInfo('00430808-v', 0), SenseInfo('00327982-v', 0), SenseInfo('00197590-v', 0), SenseInfo('00143338-v', 0), SenseInfo('00097029-v', 0) ],
"_glum_a_1_rel" : [ SenseInfo('00704270-a', 1), SenseInfo('01137378-a', 0) ],
"_researcher_n_of_rel" : [ SenseInfo('10523076-n', 3) ],
"_flick_v_through_rel" : [ SenseInfo('02160177-v', 1), SenseInfo('02153023-v', 1), SenseInfo('01893465-v', 1), SenseInfo('01591158-v', 1), SenseInfo('02763609-v', 0), SenseInfo('01591357-v', 0), SenseInfo('01242208-v', 0), SenseInfo('01242071-v', 0), SenseInfo('00190586-v', 0) ],
"_larder_n_1_rel" : [ SenseInfo('07572616-n', 0), SenseInfo('03885535-n', 0) ],
"_predictable_a_1_rel" : [ SenseInfo('01841544-a', 5) ],
"_oscarreaction_v_1_rel" : [  ],
"_hodge-podge_a_1_rel" : [  ],
"_eastward_a_1_rel" : [ SenseInfo('00823556-a', 1) ],
"_freezer_n_1_rel" : [ SenseInfo('03170635-n', 0) ],
"_scatter_v_1_rel" : [ SenseInfo('02030424-v', 5), SenseInfo('02028994-v', 4), SenseInfo('01376245-v', 2), SenseInfo('01501676-v', 1), SenseInfo('00330565-v', 1), SenseInfo('02082690-v', 0), SenseInfo('02030424-v', 5), SenseInfo('02028994-v', 4), SenseInfo('01376245-v', 2), SenseInfo('01501676-v', 1), SenseInfo('00330565-v', 1), SenseInfo('02082690-v', 0) ],
"_lodge_v_1_rel" : [ SenseInfo('02652494-v', 3), SenseInfo('01528069-v', 1), SenseInfo('00869931-v', 1), SenseInfo('02651424-v', 0) ],
"_sponsor_v_1_rel" : [ SenseInfo('02219940-v', 26), SenseInfo('02220148-v', 7), SenseInfo('02466134-v', 0) ],
"_optimum_n_1_rel" : [ SenseInfo('05143864-n', 1) ],
"_seaweed_n_1_rel" : [ SenseInfo('01397497-n', 1) ],
"_many+a_q_rel" : [  ],
"_flip_v_cause_rel" : [ SenseInfo('01893079-v', 3), SenseInfo('01510173-v', 1), SenseInfo('02153023-v', 0), SenseInfo('01893601-v', 0), SenseInfo('01893465-v', 0), SenseInfo('01512625-v', 0), SenseInfo('01241614-v', 0), SenseInfo('01222958-v', 0), SenseInfo('00717921-v', 0), SenseInfo('00584810-v', 0), SenseInfo('00121678-v', 0) ],
"_duty-bound_a_1_rel" : [ SenseInfo('01616891-a', 0), SenseInfo('01616891-a', 0) ],
"_knife_v_1_rel" : [ SenseInfo('01231652-v', 0) ],
"_strategy_n_of_rel" : [ SenseInfo('05905348-n', 12), SenseInfo('06249177-n', 0), SenseInfo('05905348-n', 12), SenseInfo('06249177-n', 0), SenseInfo('05905348-n', 12), SenseInfo('06249177-n', 0), SenseInfo('05905348-n', 12), SenseInfo('06249177-n', 0) ],
"_lusty_a_1_rel" : [ SenseInfo('01727133-a', 1), SenseInfo('01171746-a', 1), SenseInfo('01727133-a', 1), SenseInfo('01171746-a', 1), SenseInfo('01727133-a', 1), SenseInfo('01171746-a', 1) ],
"_crystal_n_1_rel" : [ SenseInfo('14883206-n', 4), SenseInfo('03142912-n', 2), SenseInfo('09260466-n', 1), SenseInfo('14879750-n', 0), SenseInfo('03142834-n', 0), SenseInfo('03142679-n', 0) ],
"_unanimous_a_1_rel" : [ SenseInfo('00553732-a', 3), SenseInfo('00784215-a', 0), SenseInfo('00553732-a', 3), SenseInfo('00784215-a', 0) ],
"_liberate_v_1_rel" : [ SenseInfo('02497400-v', 2), SenseInfo('02421374-v', 1), SenseInfo('02497062-v', 0), SenseInfo('01757994-v', 0) ],
"_make_v_for-i_rel" : [ SenseInfo('02560585-v', 508), SenseInfo('00120316-v', 459), SenseInfo('01617192-v', 243), SenseInfo('00770437-v', 85), SenseInfo('01645601-v', 78), SenseInfo('01621555-v', 52), SenseInfo('00730758-v', 33), SenseInfo('01646075-v', 17), SenseInfo('01640207-v', 16), SenseInfo('02289295-v', 14), SenseInfo('01619014-v', 14), SenseInfo('02621395-v', 12), SenseInfo('02022162-v', 12), SenseInfo('02674708-v', 10), SenseInfo('01653873-v', 9), SenseInfo('01755816-v', 8), SenseInfo('01654628-v', 5), SenseInfo('00556855-v', 5), SenseInfo('00012267-v', 5), SenseInfo('02396716-v', 4), SenseInfo('02355596-v', 4), SenseInfo('02020590-v', 4), SenseInfo('00665476-v', 4), SenseInfo('02582921-v', 3), SenseInfo('02598483-v', 2), SenseInfo('01733477-v', 2), SenseInfo('00276068-v', 2), SenseInfo('02075857-v', 1), SenseInfo('00074038-v', 1), SenseInfo('02748759-v', 0), SenseInfo('02748627-v', 0), SenseInfo('02745332-v', 0), SenseInfo('02665124-v', 0), SenseInfo('02621133-v', 0), SenseInfo('02134050-v', 0), SenseInfo('02051031-v', 0), SenseInfo('02021532-v', 0), SenseInfo('01755504-v', 0), SenseInfo('01664172-v', 0), SenseInfo('01428578-v', 0), SenseInfo('00891038-v', 0), SenseInfo('00838524-v', 0), SenseInfo('00698256-v', 0), SenseInfo('00698104-v', 0), SenseInfo('00562182-v', 0), SenseInfo('00562067-v', 0), SenseInfo('00545953-v', 0), SenseInfo('00107369-v', 0), SenseInfo('00072012-v', 0) ],
"_avid_a_1_rel" : [ SenseInfo('00888477-a', 0), SenseInfo('00886253-a', 0) ],
"_learn_v_about_rel" : [ SenseInfo('00597915-v', 90), SenseInfo('00598954-v', 53), SenseInfo('00604576-v', 6), SenseInfo('00599992-v', 3), SenseInfo('00829107-v', 2), SenseInfo('00920336-v', 0) ],
"_full+well_a_1_rel" : [  ],
"_on_p_sel_rel" : [ SenseInfo('00068368-r', 40), SenseInfo('01651196-a', 6), SenseInfo('00069346-r', 2), SenseInfo('00069472-r', 1), SenseInfo('01651741-a', 0) ],
"_ok+doke_a_1_rel" : [  ],
"_convent_n_1_rel" : [ SenseInfo('03099454-n', 1), SenseInfo('08224413-n', 0) ],
"_noisy_a_1_rel" : [ SenseInfo('01919931-a', 4), SenseInfo('00407766-a', 0), SenseInfo('01919931-a', 4), SenseInfo('00407766-a', 0), SenseInfo('01919931-a', 4), SenseInfo('00407766-a', 0), SenseInfo('01919931-a', 4), SenseInfo('00407766-a', 0) ],
"_apposition_n_1_rel" : [ SenseInfo('13801217-n', 0), SenseInfo('13433948-n', 0), SenseInfo('01051801-n', 0) ],
"_commendable_a_1_rel" : [ SenseInfo('02585545-a', 2) ],
"_bureaucratic_a_1_rel" : [ SenseInfo('03051619-a', 3) ],
"_light_n_1_rel" : [ SenseInfo('11473954-n', 46), SenseInfo('03665366-n', 23), SenseInfo('06210791-n', 13), SenseInfo('05018103-n', 10), SenseInfo('08646188-n', 7), SenseInfo('14563784-n', 4), SenseInfo('04951373-n', 4), SenseInfo('10276659-n', 3), SenseInfo('13983304-n', 2), SenseInfo('05807933-n', 2), SenseInfo('04953380-n', 2), SenseInfo('05612706-n', 1), SenseInfo('09184668-n', 0), SenseInfo('06874019-n', 0), SenseInfo('03666591-n', 0) ],
"_stock_v_1_rel" : [ SenseInfo('02285392-v', 2), SenseInfo('02329883-v', 0), SenseInfo('02329733-v', 0), SenseInfo('02329578-v', 0), SenseInfo('02323286-v', 0), SenseInfo('02323059-v', 0), SenseInfo('00095377-v', 0) ],
"_grow_v_over_rel" : [ SenseInfo('00125841-v', 70), SenseInfo('00230746-v', 62), SenseInfo('00231557-v', 32), SenseInfo('00245457-v', 12), SenseInfo('00250181-v', 8), SenseInfo('02624263-v', 7), SenseInfo('01739814-v', 3), SenseInfo('00094460-v', 3), SenseInfo('00543410-v', 2), SenseInfo('00250539-v', 0) ],
"_sibilant_n_1_rel" : [ SenseInfo('07118747-n', 0) ],
"_audit_v_1_rel" : [ SenseInfo('00697062-v', 1), SenseInfo('00600235-v', 0) ],
"_denial_n_of_rel" : [ SenseInfo('07204401-n', 4), SenseInfo('07204240-n', 3), SenseInfo('13461951-n', 1), SenseInfo('00205649-n', 1), SenseInfo('01198750-n', 0), SenseInfo('07204401-n', 4), SenseInfo('07204240-n', 3), SenseInfo('13461951-n', 1), SenseInfo('00205649-n', 1), SenseInfo('01198750-n', 0) ],
"_acrobat_n_1_rel" : [ SenseInfo('09764381-n', 0) ],
"_slop_v_1_rel" : [ SenseInfo('01542207-v', 2), SenseInfo('01921591-v', 1), SenseInfo('01579488-v', 0), SenseInfo('01178220-v', 0), SenseInfo('01542207-v', 2), SenseInfo('01921591-v', 1), SenseInfo('01579488-v', 0), SenseInfo('01178220-v', 0) ],
"_missive_n_1_rel" : [ SenseInfo('06624161-n', 1) ],
"_sling_n_1_rel" : [ SenseInfo('07917618-n', 0), SenseInfo('04240097-n', 0), SenseInfo('04239786-n', 0), SenseInfo('04239639-n', 0), SenseInfo('04239436-n', 0) ],
"_overhanging_a_1_rel" : [  ],
"_rubbish_a_1_rel" : [ SenseInfo('14857497-n', 1), SenseInfo('06611998-n', 0), SenseInfo('14857497-n', 1), SenseInfo('06611998-n', 0) ],
"_northerly_a_1_rel" : [ SenseInfo('01601297-a', 1), SenseInfo('01601069-a', 0) ],
"_homework_n_1_rel" : [ SenseInfo('00729108-n', 0) ],
"_upon_p_rel" : [  ],
"_pp_n_1_rel" : [  ],
"_time_n_of_rel" : [ SenseInfo('07309599-n', 219), SenseInfo('15270431-n', 160), SenseInfo('15122231-n', 114), SenseInfo('15245515-n', 43), SenseInfo('00028270-n', 36), SenseInfo('07288215-n', 10), SenseInfo('15129927-n', 7), SenseInfo('15135822-n', 5), SenseInfo('04991738-n', 1), SenseInfo('15224692-n', 0), SenseInfo('07309599-n', 219), SenseInfo('15270431-n', 160), SenseInfo('15122231-n', 114), SenseInfo('15245515-n', 43), SenseInfo('00028270-n', 36), SenseInfo('07288215-n', 10), SenseInfo('15129927-n', 7), SenseInfo('15135822-n', 5), SenseInfo('04991738-n', 1), SenseInfo('15224692-n', 0), SenseInfo('07309599-n', 219), SenseInfo('15270431-n', 160), SenseInfo('15122231-n', 114), SenseInfo('15245515-n', 43), SenseInfo('00028270-n', 36), SenseInfo('07288215-n', 10), SenseInfo('15129927-n', 7), SenseInfo('15135822-n', 5), SenseInfo('04991738-n', 1), SenseInfo('15224692-n', 0) ],
"_stow_v_1_rel" : [ SenseInfo('01493234-v', 1), SenseInfo('01493234-v', 1) ],
"_radioscopy_n_1_rel" : [ SenseInfo('00903309-n', 0) ],
"_abundance_n_1_rel" : [ SenseInfo('05115040-n', 2), SenseInfo('13820239-n', 0), SenseInfo('13820000-n', 0) ],
"_double-entendre_n_1_rel" : [ SenseInfo('06605780-n', 2), SenseInfo('06605780-n', 2) ],
"_schoolroom_n_1_rel" : [ SenseInfo('03038685-n', 3) ],
"_powerline_n_1_rel" : [  ],
"_disconnect_n_1_rel" : [ SenseInfo('04753060-n', 0) ],
"_elevate_v_cause-to_rel" : [ SenseInfo('02397637-v', 3), SenseInfo('01974062-v', 2), SenseInfo('00544549-v', 2), SenseInfo('02397637-v', 3), SenseInfo('01974062-v', 2), SenseInfo('00544549-v', 2) ],
"_redeem_v_for_rel" : [ SenseInfo('02551602-v', 3), SenseInfo('02551501-v', 0), SenseInfo('02257232-v', 0), SenseInfo('02256998-v', 0), SenseInfo('02256853-v', 0), SenseInfo('02256732-v', 0), SenseInfo('02551602-v', 3), SenseInfo('02551501-v', 0), SenseInfo('02257232-v', 0), SenseInfo('02256998-v', 0), SenseInfo('02256853-v', 0), SenseInfo('02256732-v', 0) ],
"_clear_v_up_rel" : [ SenseInfo('00181664-v', 16), SenseInfo('00195617-v', 5), SenseInfo('02771169-v', 2), SenseInfo('00803325-v', 2), SenseInfo('00195342-v', 2), SenseInfo('02523351-v', 1), SenseInfo('02289134-v', 1), SenseInfo('02156844-v', 1), SenseInfo('02081178-v', 1), SenseInfo('00621058-v', 1), SenseInfo('02422409-v', 0), SenseInfo('02350440-v', 0), SenseInfo('02291548-v', 0), SenseInfo('02291258-v', 0), SenseInfo('02289295-v', 0), SenseInfo('02208409-v', 0), SenseInfo('02053490-v', 0), SenseInfo('00904046-v', 0), SenseInfo('00761454-v', 0), SenseInfo('00549217-v', 0), SenseInfo('00450863-v', 0), SenseInfo('00450691-v', 0), SenseInfo('00450565-v', 0), SenseInfo('00178235-v', 0), SenseInfo('00181664-v', 16), SenseInfo('00195617-v', 5), SenseInfo('02771169-v', 2), SenseInfo('00803325-v', 2), SenseInfo('00195342-v', 2), SenseInfo('02523351-v', 1), SenseInfo('02289134-v', 1), SenseInfo('02156844-v', 1), SenseInfo('02081178-v', 1), SenseInfo('00621058-v', 1), SenseInfo('02422409-v', 0), SenseInfo('02350440-v', 0), SenseInfo('02291548-v', 0), SenseInfo('02291258-v', 0), SenseInfo('02289295-v', 0), SenseInfo('02208409-v', 0), SenseInfo('02053490-v', 0), SenseInfo('00904046-v', 0), SenseInfo('00761454-v', 0), SenseInfo('00549217-v', 0), SenseInfo('00450863-v', 0), SenseInfo('00450691-v', 0), SenseInfo('00450565-v', 0), SenseInfo('00178235-v', 0) ],
"_until+recently_p_rel" : [  ],
"_donate_v_to_rel" : [ SenseInfo('02263027-v', 7), SenseInfo('02263027-v', 7) ],
"_slumber_v_1_rel" : [ SenseInfo('00014742-v', 2) ],
"_elimination_n_of_rel" : [ SenseInfo('00395333-n', 3), SenseInfo('13473097-n', 0), SenseInfo('05782245-n', 0), SenseInfo('00395503-n', 0), SenseInfo('00223720-n', 0) ],
"_pressurization_n_1_rel" : [  ],
"_teammate_n_1_rel" : [ SenseInfo('10695050-n', 2) ],
"_county_n_of_rel" : [ SenseInfo('08546183-n', 34), SenseInfo('08546870-n', 0), SenseInfo('08546183-n', 34), SenseInfo('08546870-n', 0) ],
"_communion_n_1_rel" : [ SenseInfo('01036333-n', 4), SenseInfo('07134575-n', 3), SenseInfo('08147019-n', 0) ],
"_weekday_n_1_rel" : [ SenseInfo('15163157-n', 1) ],
"_pale_n_1_rel" : [ SenseInfo('03929952-n', 1) ],
"_oftener_a_1_rel" : [  ],
"_colloid_n_1_rel" : [ SenseInfo('14588219-n', 0) ],
"_effusive_a_1_rel" : [ SenseInfo('00806064-a', 0), SenseInfo('00720524-a', 0) ],
"_unsuccessful_a_1_rel" : [ SenseInfo('02333453-a', 2), SenseInfo('01082714-a', 2), SenseInfo('02333453-a', 2), SenseInfo('01082714-a', 2), SenseInfo('02333453-a', 2), SenseInfo('01082714-a', 2) ],
"_spool_n_1_rel" : [ SenseInfo('02860415-n', 0) ],
"_chaise_n_1_rel" : [ SenseInfo('03002711-n', 1), SenseInfo('03002555-n', 0) ],
"_insemination_n_of_rel" : [ SenseInfo('00919692-n', 0), SenseInfo('00845178-n', 0) ],
"_adapt_v_to_rel" : [ SenseInfo('00299580-v', 7), SenseInfo('00150287-v', 3), SenseInfo('00299580-v', 7), SenseInfo('00150287-v', 3) ],
"_chattel_n_1_rel" : [ SenseInfo('13245846-n', 0) ],
"_kite_n_1_rel" : [ SenseInfo('13382471-n', 0), SenseInfo('13382306-n', 0), SenseInfo('03621473-n', 0), SenseInfo('01608432-n', 0) ],
"_recess_v_1_rel" : [ SenseInfo('01498872-v', 2), SenseInfo('01277305-v', 0), SenseInfo('00364297-v', 0) ],
"_cry_v_out_rel" : [ SenseInfo('00913065-v', 17), SenseInfo('00066191-v', 12), SenseInfo('00912048-v', 11), SenseInfo('00974786-v', 2), SenseInfo('01188987-v', 0), SenseInfo('00985464-v', 0), SenseInfo('00066685-v', 0), SenseInfo('00913065-v', 17), SenseInfo('00066191-v', 12), SenseInfo('00912048-v', 11), SenseInfo('00974786-v', 2), SenseInfo('01188987-v', 0), SenseInfo('00985464-v', 0), SenseInfo('00066685-v', 0) ],
"_write_v_up_rel" : [ SenseInfo('01698271-v', 112), SenseInfo('00993014-v', 94), SenseInfo('01744611-v', 33), SenseInfo('01007027-v', 15), SenseInfo('01031966-v', 10), SenseInfo('01705494-v', 9), SenseInfo('01691057-v', 8), SenseInfo('00998886-v', 4), SenseInfo('01699896-v', 1), SenseInfo('01692834-v', 0) ],
"_clump_n_of_rel" : [ SenseInfo('07959943-n', 9), SenseInfo('07961016-n', 1), SenseInfo('07396945-n', 0) ],
"_ruffle_v_1_rel" : [ SenseInfo('02040054-v', 1), SenseInfo('01789047-v', 1), SenseInfo('01916634-v', 0), SenseInfo('01790538-v', 0), SenseInfo('01591357-v', 0), SenseInfo('01418667-v', 0), SenseInfo('01391806-v', 0), SenseInfo('01387493-v', 0), SenseInfo('01387301-v', 0) ],
"_goblin_n_1_rel" : [ SenseInfo('09543748-n', 0) ],
"_wool_n_1_rel" : [ SenseInfo('04599235-n', 3), SenseInfo('15104217-n', 0), SenseInfo('01899593-n', 0) ],
"_with+respect+to_p_rel" : [  ],
"_appropriate_a_1_rel" : [ SenseInfo('00134701-a', 29) ],
"_according_a_1_rel" : [ SenseInfo('00553140-a', 0), SenseInfo('00471572-a', 0) ],
"_rigidity_n_1_rel" : [ SenseInfo('05023741-n', 0), SenseInfo('04660261-n', 0) ],
"_chromium_n_1_rel" : [ SenseInfo('14635092-n', 4) ],
"_menace_v_1_rel" : [ SenseInfo('02697120-v', 1), SenseInfo('01067194-v', 1), SenseInfo('00012137-v', 0), SenseInfo('02697120-v', 1), SenseInfo('01067194-v', 1), SenseInfo('00012137-v', 0), SenseInfo('02697120-v', 1), SenseInfo('01067194-v', 1), SenseInfo('00012137-v', 0) ],
"_allegation_n_1_rel" : [ SenseInfo('07236077-n', 1), SenseInfo('06731186-n', 1), SenseInfo('07236077-n', 1), SenseInfo('06731186-n', 1), SenseInfo('07236077-n', 1), SenseInfo('06731186-n', 1) ],
"_nt_n_1_rel" : [ SenseInfo('08049125-n', 0) ],
"_crunch_v_1_rel" : [ SenseInfo('01058224-v', 1), SenseInfo('01594978-v', 0), SenseInfo('01201693-v', 0), SenseInfo('00331082-v', 0) ],
"_point-of-sale_a_1_rel" : [ SenseInfo('03143374-a', 0), SenseInfo('03143374-a', 0), SenseInfo('03143374-a', 0) ],
"_flock_n_of_rel" : [ SenseInfo('07991272-n', 2), SenseInfo('07990956-n', 2), SenseInfo('13774404-n', 1), SenseInfo('08274565-n', 1), SenseInfo('07991169-n', 0), SenseInfo('07991272-n', 2), SenseInfo('07990956-n', 2), SenseInfo('13774404-n', 1), SenseInfo('08274565-n', 1), SenseInfo('07991169-n', 0) ],
"_than_p_compar_rel" : [  ],
"_strike_v_1_rel" : [ SenseInfo('01410223-v', 18), SenseInfo('01767949-v', 16), SenseInfo('01236164-v', 14), SenseInfo('01123887-v', 7), SenseInfo('00923622-v', 5), SenseInfo('01209135-v', 4), SenseInfo('02412647-v', 3), SenseInfo('02611976-v', 2), SenseInfo('02526811-v', 2), SenseInfo('01209426-v', 2), SenseInfo('00143540-v', 2), SenseInfo('02286687-v', 1), SenseInfo('01675073-v', 1), SenseInfo('01549420-v', 1), SenseInfo('02108791-v', 0), SenseInfo('02104161-v', 0), SenseInfo('01982395-v', 0), SenseInfo('01639105-v', 0), SenseInfo('01308008-v', 0), SenseInfo('01228235-v', 0), SenseInfo('00635904-v', 0), SenseInfo('01410223-v', 18), SenseInfo('01767949-v', 16), SenseInfo('01236164-v', 14), SenseInfo('01123887-v', 7), SenseInfo('00923622-v', 5), SenseInfo('01209135-v', 4), SenseInfo('02412647-v', 3), SenseInfo('02611976-v', 2), SenseInfo('02526811-v', 2), SenseInfo('01209426-v', 2), SenseInfo('00143540-v', 2), SenseInfo('02286687-v', 1), SenseInfo('01675073-v', 1), SenseInfo('01549420-v', 1), SenseInfo('02108791-v', 0), SenseInfo('02104161-v', 0), SenseInfo('01982395-v', 0), SenseInfo('01639105-v', 0), SenseInfo('01308008-v', 0), SenseInfo('01228235-v', 0), SenseInfo('00635904-v', 0), SenseInfo('01410223-v', 18), SenseInfo('01767949-v', 16), SenseInfo('01236164-v', 14), SenseInfo('01123887-v', 7), SenseInfo('00923622-v', 5), SenseInfo('01209135-v', 4), SenseInfo('02412647-v', 3), SenseInfo('02611976-v', 2), SenseInfo('02526811-v', 2), SenseInfo('01209426-v', 2), SenseInfo('00143540-v', 2), SenseInfo('02286687-v', 1), SenseInfo('01675073-v', 1), SenseInfo('01549420-v', 1), SenseInfo('02108791-v', 0), SenseInfo('02104161-v', 0), SenseInfo('01982395-v', 0), SenseInfo('01639105-v', 0), SenseInfo('01308008-v', 0), SenseInfo('01228235-v', 0), SenseInfo('00635904-v', 0), SenseInfo('01410223-v', 18), SenseInfo('01767949-v', 16), SenseInfo('01236164-v', 14), SenseInfo('01123887-v', 7), SenseInfo('00923622-v', 5), SenseInfo('01209135-v', 4), SenseInfo('02412647-v', 3), SenseInfo('02611976-v', 2), SenseInfo('02526811-v', 2), SenseInfo('01209426-v', 2), SenseInfo('00143540-v', 2), SenseInfo('02286687-v', 1), SenseInfo('01675073-v', 1), SenseInfo('01549420-v', 1), SenseInfo('02108791-v', 0), SenseInfo('02104161-v', 0), SenseInfo('01982395-v', 0), SenseInfo('01639105-v', 0), SenseInfo('01308008-v', 0), SenseInfo('01228235-v', 0), SenseInfo('00635904-v', 0) ],
"_sympathize_v_with_rel" : [ SenseInfo('01822724-v', 2), SenseInfo('00594058-v', 1), SenseInfo('01822248-v', 0), SenseInfo('01822724-v', 2), SenseInfo('00594058-v', 1), SenseInfo('01822248-v', 0), SenseInfo('01822724-v', 2), SenseInfo('00594058-v', 1), SenseInfo('01822248-v', 0), SenseInfo('01822724-v', 2), SenseInfo('00594058-v', 1), SenseInfo('01822248-v', 0) ],
"_multifold_a_1_rel" : [  ],
"_liquefy_v_1_rel" : [ SenseInfo('02757304-v', 0), SenseInfo('00444309-v', 0), SenseInfo('00443984-v', 0), SenseInfo('02757304-v', 0), SenseInfo('00444309-v', 0), SenseInfo('00443984-v', 0) ],
"_rough_v_in_rel" : [ SenseInfo('01754452-v', 1) ],
"_lift_v_away_rel" : [ SenseInfo('01974062-v', 31), SenseInfo('01579153-v', 10), SenseInfo('01973759-v', 2), SenseInfo('01968569-v', 2), SenseInfo('00986074-v', 2), SenseInfo('00799798-v', 2), SenseInfo('02276866-v', 1), SenseInfo('01455184-v', 1), SenseInfo('00549982-v', 1), SenseInfo('00544549-v', 1), SenseInfo('00178652-v', 1), SenseInfo('02696801-v', 0), SenseInfo('02352181-v', 0), SenseInfo('02278061-v', 0), SenseInfo('02277138-v', 0), SenseInfo('01452057-v', 0), SenseInfo('01311608-v', 0), SenseInfo('00792921-v', 0), SenseInfo('00357198-v', 0), SenseInfo('00354195-v', 0), SenseInfo('00198623-v', 0), SenseInfo('00178773-v', 0), SenseInfo('00178502-v', 0), SenseInfo('00061933-v', 0), SenseInfo('01974062-v', 31), SenseInfo('01579153-v', 10), SenseInfo('01973759-v', 2), SenseInfo('01968569-v', 2), SenseInfo('00986074-v', 2), SenseInfo('00799798-v', 2), SenseInfo('02276866-v', 1), SenseInfo('01455184-v', 1), SenseInfo('00549982-v', 1), SenseInfo('00544549-v', 1), SenseInfo('00178652-v', 1), SenseInfo('02696801-v', 0), SenseInfo('02352181-v', 0), SenseInfo('02278061-v', 0), SenseInfo('02277138-v', 0), SenseInfo('01452057-v', 0), SenseInfo('01311608-v', 0), SenseInfo('00792921-v', 0), SenseInfo('00357198-v', 0), SenseInfo('00354195-v', 0), SenseInfo('00198623-v', 0), SenseInfo('00178773-v', 0), SenseInfo('00178502-v', 0), SenseInfo('00061933-v', 0) ],
"_shadow_n_1_rel" : [ SenseInfo('13984944-n', 17), SenseInfo('08646306-n', 8), SenseInfo('05897553-n', 3), SenseInfo('07522418-n', 1), SenseInfo('06646628-n', 1), SenseInfo('05155349-n', 1), SenseInfo('13959642-n', 0), SenseInfo('10689104-n', 0), SenseInfo('10585359-n', 0) ],
"_landmark_n_1_rel" : [ SenseInfo('08624891-n', 2), SenseInfo('07417851-n', 1), SenseInfo('07259319-n', 0), SenseInfo('05230357-n', 0) ],
"_loose_a_sel_rel" : [ SenseInfo('00503321-a', 2), SenseInfo('00600725-a', 2), SenseInfo('01446749-a', 1), SenseInfo('01634027-a', 1), SenseInfo('00916199-a', 1), SenseInfo('00638841-a', 1), SenseInfo('00159381-a', 0), SenseInfo('02404421-a', 0), SenseInfo('02232112-a', 0), SenseInfo('01998835-a', 0), SenseInfo('01739582-a', 0), SenseInfo('01062114-a', 0), SenseInfo('00361837-a', 0), SenseInfo('00503321-a', 2), SenseInfo('00600725-a', 2), SenseInfo('01446749-a', 1), SenseInfo('01634027-a', 1), SenseInfo('00916199-a', 1), SenseInfo('00638841-a', 1), SenseInfo('00159381-a', 0), SenseInfo('02404421-a', 0), SenseInfo('02232112-a', 0), SenseInfo('01998835-a', 0), SenseInfo('01739582-a', 0), SenseInfo('01062114-a', 0), SenseInfo('00361837-a', 0) ],
"_long+after_a_1_rel" : [  ],
"_special+order_v_1_rel" : [  ],
"_face_n_1_rel" : [ SenseInfo('05600637-n', 193), SenseInfo('04679738-n', 23), SenseInfo('04679419-n', 22), SenseInfo('03313873-n', 4), SenseInfo('09618957-n', 2), SenseInfo('08510666-n', 1), SenseInfo('05601198-n', 1), SenseInfo('03313602-n', 1), SenseInfo('06877578-n', 0), SenseInfo('06825399-n', 0), SenseInfo('05168795-n', 0), SenseInfo('04838210-n', 0), SenseInfo('03313456-n', 0) ],
"_postalveolar_a_1_rel" : [  ],
"_unconsolidated_a_1_rel" : [ SenseInfo('00503876-a', 0), SenseInfo('00503876-a', 0) ],
"_presbyterian_n_1_rel" : [ SenseInfo('10465922-n', 1) ],
"_convert_v_from-to_rel" : [ SenseInfo('00381013-v', 13), SenseInfo('00115157-v', 5), SenseInfo('00384411-v', 3), SenseInfo('00161225-v', 3), SenseInfo('00385385-v', 1), SenseInfo('01084866-v', 0), SenseInfo('01084724-v', 0), SenseInfo('01084588-v', 0), SenseInfo('00769553-v', 0), SenseInfo('00161987-v', 0), SenseInfo('00114837-v', 0), SenseInfo('00381013-v', 13), SenseInfo('00115157-v', 5), SenseInfo('00384411-v', 3), SenseInfo('00161225-v', 3), SenseInfo('00385385-v', 1), SenseInfo('01084866-v', 0), SenseInfo('01084724-v', 0), SenseInfo('01084588-v', 0), SenseInfo('00769553-v', 0), SenseInfo('00161987-v', 0), SenseInfo('00114837-v', 0), SenseInfo('00381013-v', 13), SenseInfo('00115157-v', 5), SenseInfo('00384411-v', 3), SenseInfo('00161225-v', 3), SenseInfo('00385385-v', 1), SenseInfo('01084866-v', 0), SenseInfo('01084724-v', 0), SenseInfo('01084588-v', 0), SenseInfo('00769553-v', 0), SenseInfo('00161987-v', 0), SenseInfo('00114837-v', 0), SenseInfo('00381013-v', 13), SenseInfo('00115157-v', 5), SenseInfo('00384411-v', 3), SenseInfo('00161225-v', 3), SenseInfo('00385385-v', 1), SenseInfo('01084866-v', 0), SenseInfo('01084724-v', 0), SenseInfo('01084588-v', 0), SenseInfo('00769553-v', 0), SenseInfo('00161987-v', 0), SenseInfo('00114837-v', 0) ],
"_gill_n_1_rel" : [ SenseInfo('13621660-n', 0), SenseInfo('13619028-n', 0), SenseInfo('13011679-n', 0), SenseInfo('02510769-n', 0) ],
"_concretion_n_1_rel" : [ SenseInfo('13451073-n', 0), SenseInfo('09230768-n', 0), SenseInfo('07419233-n', 0), SenseInfo('00382109-n', 0) ],
"_purchase_n_of_rel" : [ SenseInfo('00079018-n', 8), SenseInfo('13253612-n', 3), SenseInfo('11415342-n', 1), SenseInfo('11473138-n', 0), SenseInfo('00079018-n', 8), SenseInfo('13253612-n', 3), SenseInfo('11415342-n', 1), SenseInfo('11473138-n', 0) ],
"_plastics_n_1_rel" : [ SenseInfo('14592610-n', 2), SenseInfo('13376012-n', 0), SenseInfo('14592610-n', 2), SenseInfo('13376012-n', 0) ],
"_zigzag_v_1_rel" : [ SenseInfo('01991744-v', 2), SenseInfo('01991744-v', 2) ],
"_icelandic_n_1_rel" : [ SenseInfo('06954183-n', 1) ],
"_hand-pick_v_1_rel" : [ SenseInfo('00676714-v', 0), SenseInfo('00676714-v', 0) ],
"_gust_v_1_rel" : [  ],
"_halve_v_cause_rel" : [ SenseInfo('00642357-v', 0) ],
"_knock_v_off_rel" : [ SenseInfo('01238640-v', 7), SenseInfo('01414467-v', 6), SenseInfo('01239619-v', 4), SenseInfo('02185373-v', 0), SenseInfo('02178866-v', 0), SenseInfo('00826509-v', 0) ],
"_eery_a_1_rel" : [ SenseInfo('00968522-a', 0), SenseInfo('00968522-a', 0) ],
"_means_n_of_rel" : [ SenseInfo('06023969-n', 10) ],
"_just-in-time_a_1_rel" : [  ],
"_prevent_v_from_rel" : [ SenseInfo('02452885-v', 62), SenseInfo('02450505-v', 40), SenseInfo('02452885-v', 62), SenseInfo('02450505-v', 40) ],
"_flock_v_1_rel" : [ SenseInfo('02025353-v', 2), SenseInfo('02025009-v', 0) ],
"_eaves_n_1_rel" : [ SenseInfo('03263076-n', 0), SenseInfo('03263076-n', 0) ],
"_retardation_n_of_rel" : [ SenseInfo('05061345-n', 1), SenseInfo('15275598-n', 0), SenseInfo('09408250-n', 0), SenseInfo('05646218-n', 0), SenseInfo('01067577-n', 0) ],
"_snort_v_at_rel" : [ SenseInfo('01045073-v', 3), SenseInfo('00006523-v', 3), SenseInfo('01200245-v', 1), SenseInfo('01199755-v', 0) ],
"_offset_v_1_rel" : [ SenseInfo('02718015-v', 5), SenseInfo('02717831-v', 2), SenseInfo('02232044-v', 0), SenseInfo('01747085-v', 0), SenseInfo('01746940-v', 0) ],
"_scathing_a_1_rel" : [ SenseInfo('00648614-a', 1) ],
"_close_x_deg_rel" : [ SenseInfo('00446921-a', 38), SenseInfo('01345109-v', 32), SenseInfo('00451510-a', 23), SenseInfo('01346978-v', 20), SenseInfo('02426395-v', 18), SenseInfo('00409709-r', 17), SenseInfo('02425913-v', 13), SenseInfo('15267536-n', 8), SenseInfo('00444519-a', 6), SenseInfo('00505226-r', 4), SenseInfo('00309945-a', 4), SenseInfo('00022219-a', 3), SenseInfo('00890622-a', 2), SenseInfo('02610628-v', 2), SenseInfo('00558738-a', 1), SenseInfo('00763831-v', 1), SenseInfo('06398401-n', 0), SenseInfo('00210797-n', 0), SenseInfo('02509484-a', 0), SenseInfo('02232739-a', 0), SenseInfo('02000298-a', 0), SenseInfo('01859368-a', 0), SenseInfo('01447937-a', 0), SenseInfo('01436567-a', 0), SenseInfo('01113225-a', 0), SenseInfo('00501004-a', 0), SenseInfo('02754276-v', 0), SenseInfo('02375619-v', 0), SenseInfo('02140781-v', 0), SenseInfo('02104503-v', 0), SenseInfo('02054541-v', 0), SenseInfo('02054382-v', 0), SenseInfo('01607288-v', 0), SenseInfo('01478423-v', 0), SenseInfo('01423285-v', 0), SenseInfo('01291941-v', 0), SenseInfo('00352137-v', 0), SenseInfo('00446921-a', 38), SenseInfo('01345109-v', 32), SenseInfo('00451510-a', 23), SenseInfo('01346978-v', 20), SenseInfo('02426395-v', 18), SenseInfo('00409709-r', 17), SenseInfo('02425913-v', 13), SenseInfo('15267536-n', 8), SenseInfo('00444519-a', 6), SenseInfo('00505226-r', 4), SenseInfo('00309945-a', 4), SenseInfo('00022219-a', 3), SenseInfo('00890622-a', 2), SenseInfo('02610628-v', 2), SenseInfo('00558738-a', 1), SenseInfo('00763831-v', 1), SenseInfo('06398401-n', 0), SenseInfo('00210797-n', 0), SenseInfo('02509484-a', 0), SenseInfo('02232739-a', 0), SenseInfo('02000298-a', 0), SenseInfo('01859368-a', 0), SenseInfo('01447937-a', 0), SenseInfo('01436567-a', 0), SenseInfo('01113225-a', 0), SenseInfo('00501004-a', 0), SenseInfo('02754276-v', 0), SenseInfo('02375619-v', 0), SenseInfo('02140781-v', 0), SenseInfo('02104503-v', 0), SenseInfo('02054541-v', 0), SenseInfo('02054382-v', 0), SenseInfo('01607288-v', 0), SenseInfo('01478423-v', 0), SenseInfo('01423285-v', 0), SenseInfo('01291941-v', 0), SenseInfo('00352137-v', 0), SenseInfo('00446921-a', 38), SenseInfo('01345109-v', 32), SenseInfo('00451510-a', 23), SenseInfo('01346978-v', 20), SenseInfo('02426395-v', 18), SenseInfo('00409709-r', 17), SenseInfo('02425913-v', 13), SenseInfo('15267536-n', 8), SenseInfo('00444519-a', 6), SenseInfo('00505226-r', 4), SenseInfo('00309945-a', 4), SenseInfo('00022219-a', 3), SenseInfo('00890622-a', 2), SenseInfo('02610628-v', 2), SenseInfo('00558738-a', 1), SenseInfo('00763831-v', 1), SenseInfo('06398401-n', 0), SenseInfo('00210797-n', 0), SenseInfo('02509484-a', 0), SenseInfo('02232739-a', 0), SenseInfo('02000298-a', 0), SenseInfo('01859368-a', 0), SenseInfo('01447937-a', 0), SenseInfo('01436567-a', 0), SenseInfo('01113225-a', 0), SenseInfo('00501004-a', 0), SenseInfo('02754276-v', 0), SenseInfo('02375619-v', 0), SenseInfo('02140781-v', 0), SenseInfo('02104503-v', 0), SenseInfo('02054541-v', 0), SenseInfo('02054382-v', 0), SenseInfo('01607288-v', 0), SenseInfo('01478423-v', 0), SenseInfo('01423285-v', 0), SenseInfo('01291941-v', 0), SenseInfo('00352137-v', 0) ],
"_nudist_n_1_rel" : [ SenseInfo('10365701-n', 0) ],
"_acculturation_n_1_rel" : [ SenseInfo('01128984-n', 1), SenseInfo('05984936-n', 0), SenseInfo('05757049-n', 0) ],
"_inconsiderable_a_1_rel" : [ SenseInfo('00625170-a', 1) ],
"_outrageous_a_1_rel" : [ SenseInfo('01626562-a', 1), SenseInfo('01534282-a', 0), SenseInfo('01626562-a', 1), SenseInfo('01534282-a', 0) ],
"_hire_n_1_rel" : [ SenseInfo('10170060-n', 0), SenseInfo('00809074-n', 0) ],
"_dishwashing_n_1_rel" : [ SenseInfo('00255600-n', 0) ],
"_slovak_n_1_rel" : [ SenseInfo('09699536-n', 0), SenseInfo('06944820-n', 0), SenseInfo('09699536-n', 0), SenseInfo('06944820-n', 0), SenseInfo('09699536-n', 0), SenseInfo('06944820-n', 0) ],
"_feminine_n_1_rel" : [ SenseInfo('06328996-n', 0) ],
"_provision_n_1_rel" : [ SenseInfo('06755947-n', 27), SenseInfo('01057200-n', 4), SenseInfo('05794694-n', 1), SenseInfo('13367448-n', 0), SenseInfo('06755947-n', 27), SenseInfo('01057200-n', 4), SenseInfo('05794694-n', 1), SenseInfo('13367448-n', 0) ],
"_underbrush_n_1_rel" : [ SenseInfo('08439476-n', 2) ],
"_spy_v_1_rel" : [ SenseInfo('02154312-v', 2), SenseInfo('00785690-v', 2), SenseInfo('02163746-v', 0), SenseInfo('00785470-v', 0) ],
"_tiller_n_1_rel" : [ SenseInfo('13164970-n', 0), SenseInfo('10711005-n', 0), SenseInfo('04435759-n', 0), SenseInfo('03146846-n', 0) ],
"_goddam_a_1_rel" : [ SenseInfo('00669942-a', 3) ],
"_grieve_v_1_rel" : [ SenseInfo('01797347-v', 1), SenseInfo('01797582-v', 0) ],
"_thanks_a_1_rel" : [ SenseInfo('07228971-n', 7), SenseInfo('01208797-n', 2), SenseInfo('07228971-n', 7), SenseInfo('01208797-n', 2), SenseInfo('07228971-n', 7), SenseInfo('01208797-n', 2), SenseInfo('07228971-n', 7), SenseInfo('01208797-n', 2) ],
"_accredited_a_1_rel" : [ SenseInfo('00178811-a', 0) ],
"_destabilize_v_cause_rel" : [ SenseInfo('00272177-v', 0), SenseInfo('00271711-v', 0), SenseInfo('00272177-v', 0), SenseInfo('00271711-v', 0), SenseInfo('00272177-v', 0), SenseInfo('00271711-v', 0), SenseInfo('00272177-v', 0), SenseInfo('00271711-v', 0), SenseInfo('00272177-v', 0), SenseInfo('00271711-v', 0) ],
"_intercept_n_1_rel" : [ SenseInfo('06011793-n', 1) ],
"_AU$_n_1_rel" : [  ],
"_exhilarating_a_1_rel" : [ SenseInfo('01357342-a', 1), SenseInfo('00921538-a', 0) ],
"_artifact_n_1_rel" : [ SenseInfo('00021939-n', 1), SenseInfo('00021939-n', 1) ],
"_desolate_v_1_rel" : [ SenseInfo('00614057-v', 0), SenseInfo('00531302-v', 0), SenseInfo('00388635-v', 0) ],
"_drive_v_away_rel" : [ SenseInfo('01930874-v', 56), SenseInfo('01930117-v', 24), SenseInfo('02056971-v', 13), SenseInfo('01516534-v', 13), SenseInfo('02505358-v', 6), SenseInfo('01506157-v', 5), SenseInfo('01646300-v', 4), SenseInfo('01512259-v', 2), SenseInfo('01509584-v', 2), SenseInfo('02406916-v', 1), SenseInfo('01026975-v', 1), SenseInfo('02742232-v', 0), SenseInfo('02408281-v', 0), SenseInfo('02057656-v', 0), SenseInfo('01939553-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01407904-v', 0), SenseInfo('01407722-v', 0), SenseInfo('01310964-v', 0), SenseInfo('01181741-v', 0), SenseInfo('01142636-v', 0), SenseInfo('01142490-v', 0) ],
"_crash_v_into_rel" : [ SenseInfo('01972570-v', 9), SenseInfo('02088627-v', 3), SenseInfo('01561819-v', 2), SenseInfo('02019282-v', 1), SenseInfo('01562061-v', 1), SenseInfo('02657080-v', 0), SenseInfo('02177512-v', 0), SenseInfo('02019011-v', 0), SenseInfo('01562209-v', 0), SenseInfo('01507407-v', 0), SenseInfo('00583064-v', 0), SenseInfo('00434919-v', 0), SenseInfo('00017674-v', 0) ],
"_rectitude_n_1_rel" : [ SenseInfo('04826623-n', 1) ],
"_romance_n_1_rel" : [ SenseInfo('13931436-n', 4), SenseInfo('05208422-n', 1), SenseInfo('06963951-n', 0), SenseInfo('06371267-n', 0), SenseInfo('06369216-n', 0) ],
"_incomparably_x_deg_rel" : [ SenseInfo('00370421-r', 0) ],
"_unique_a_to_rel" : [ SenseInfo('00505853-a', 10), SenseInfo('01105042-a', 2), SenseInfo('02215087-a', 0), SenseInfo('00491511-a', 0) ],
"_rank_v_as_rel" : [ SenseInfo('00660102-v', 2), SenseInfo('00658052-v', 1), SenseInfo('02673844-v', 0) ],
"_aggravate_v_1_rel" : [ SenseInfo('00208210-v', 3), SenseInfo('01820901-v', 2), SenseInfo('00208210-v', 3), SenseInfo('01820901-v', 2) ],
"_fancy_n_1_rel" : [ SenseInfo('05896059-n', 1), SenseInfo('05632272-n', 1), SenseInfo('07497797-n', 0) ],
"_slime_v_1_rel" : [ SenseInfo('01252730-v', 1) ],
"_activation_n_of_rel" : [ SenseInfo('13426376-n', 0), SenseInfo('01046984-n', 0), SenseInfo('00236821-n', 0) ],
"_shop_n_of_rel" : [ SenseInfo('04202417-n', 9), SenseInfo('04603081-n', 1), SenseInfo('00892254-n', 0) ],
"_trampoline_n_1_rel" : [ SenseInfo('04469514-n', 0) ],
"_tote_v_up_rel" : [ SenseInfo('01454246-v', 0) ],
"_hold_v_up_rel" : [ SenseInfo('02681795-v', 79), SenseInfo('01216670-v', 65), SenseInfo('01733477-v', 62), SenseInfo('02203362-v', 26), SenseInfo('00693780-v', 20), SenseInfo('01773130-v', 17), SenseInfo('01301410-v', 17), SenseInfo('02283324-v', 14), SenseInfo('02302220-v', 9), SenseInfo('01217043-v', 9), SenseInfo('02700867-v', 7), SenseInfo('02732798-v', 3), SenseInfo('02683489-v', 3), SenseInfo('01601234-v', 3), SenseInfo('02648502-v', 2), SenseInfo('00683771-v', 2), SenseInfo('02746275-v', 1), SenseInfo('02701210-v', 1), SenseInfo('02498320-v', 1), SenseInfo('01129876-v', 1), SenseInfo('00885217-v', 1), SenseInfo('00736586-v', 1), SenseInfo('00607000-v', 1), SenseInfo('02706816-v', 0), SenseInfo('02676789-v', 0), SenseInfo('02643574-v', 0), SenseInfo('02510337-v', 0), SenseInfo('02450989-v', 0), SenseInfo('02441897-v', 0), SenseInfo('01859586-v', 0), SenseInfo('01334744-v', 0), SenseInfo('01205153-v', 0), SenseInfo('01151753-v', 0), SenseInfo('00822367-v', 0), SenseInfo('00805376-v', 0), SenseInfo('00004492-v', 0), SenseInfo('02681795-v', 79), SenseInfo('01216670-v', 65), SenseInfo('01733477-v', 62), SenseInfo('02203362-v', 26), SenseInfo('00693780-v', 20), SenseInfo('01773130-v', 17), SenseInfo('01301410-v', 17), SenseInfo('02283324-v', 14), SenseInfo('02302220-v', 9), SenseInfo('01217043-v', 9), SenseInfo('02700867-v', 7), SenseInfo('02732798-v', 3), SenseInfo('02683489-v', 3), SenseInfo('01601234-v', 3), SenseInfo('02648502-v', 2), SenseInfo('00683771-v', 2), SenseInfo('02746275-v', 1), SenseInfo('02701210-v', 1), SenseInfo('02498320-v', 1), SenseInfo('01129876-v', 1), SenseInfo('00885217-v', 1), SenseInfo('00736586-v', 1), SenseInfo('00607000-v', 1), SenseInfo('02706816-v', 0), SenseInfo('02676789-v', 0), SenseInfo('02643574-v', 0), SenseInfo('02510337-v', 0), SenseInfo('02450989-v', 0), SenseInfo('02441897-v', 0), SenseInfo('01859586-v', 0), SenseInfo('01334744-v', 0), SenseInfo('01205153-v', 0), SenseInfo('01151753-v', 0), SenseInfo('00822367-v', 0), SenseInfo('00805376-v', 0), SenseInfo('00004492-v', 0), SenseInfo('02681795-v', 79), SenseInfo('01216670-v', 65), SenseInfo('01733477-v', 62), SenseInfo('02203362-v', 26), SenseInfo('00693780-v', 20), SenseInfo('01773130-v', 17), SenseInfo('01301410-v', 17), SenseInfo('02283324-v', 14), SenseInfo('02302220-v', 9), SenseInfo('01217043-v', 9), SenseInfo('02700867-v', 7), SenseInfo('02732798-v', 3), SenseInfo('02683489-v', 3), SenseInfo('01601234-v', 3), SenseInfo('02648502-v', 2), SenseInfo('00683771-v', 2), SenseInfo('02746275-v', 1), SenseInfo('02701210-v', 1), SenseInfo('02498320-v', 1), SenseInfo('01129876-v', 1), SenseInfo('00885217-v', 1), SenseInfo('00736586-v', 1), SenseInfo('00607000-v', 1), SenseInfo('02706816-v', 0), SenseInfo('02676789-v', 0), SenseInfo('02643574-v', 0), SenseInfo('02510337-v', 0), SenseInfo('02450989-v', 0), SenseInfo('02441897-v', 0), SenseInfo('01859586-v', 0), SenseInfo('01334744-v', 0), SenseInfo('01205153-v', 0), SenseInfo('01151753-v', 0), SenseInfo('00822367-v', 0), SenseInfo('00805376-v', 0), SenseInfo('00004492-v', 0) ],
"_just_a_1_rel" : [ SenseInfo('01369663-a', 4), SenseInfo('00958151-a', 0), SenseInfo('00956131-a', 0), SenseInfo('02036934-a', 0), SenseInfo('01369663-a', 4), SenseInfo('00958151-a', 0), SenseInfo('00956131-a', 0), SenseInfo('02036934-a', 0), SenseInfo('01369663-a', 4), SenseInfo('00958151-a', 0), SenseInfo('00956131-a', 0), SenseInfo('02036934-a', 0) ],
"_computational_a_1_rel" : [ SenseInfo('02907473-a', 0) ],
"_cats+ear_n_1_rel" : [  ],
"_shape_v_1_rel" : [ SenseInfo('00701040-v', 11), SenseInfo('01659248-v', 6), SenseInfo('00142191-v', 3), SenseInfo('00701040-v', 11), SenseInfo('01659248-v', 6), SenseInfo('00142191-v', 3) ],
"_brief_n_1_rel" : [ SenseInfo('06543781-n', 2), SenseInfo('06468640-n', 0) ],
"_contend_v_with_rel" : [ SenseInfo('00756898-v', 10), SenseInfo('00773432-v', 3), SenseInfo('00869596-v', 2), SenseInfo('02587532-v', 1), SenseInfo('01072262-v', 1), SenseInfo('01090335-v', 0) ],
"_lecture_n_1_rel" : [ SenseInfo('07240549-n', 8), SenseInfo('06713930-n', 0), SenseInfo('00892861-n', 0) ],
"_crevassed_a_1_rel" : [  ],
"_insert_n_1_rel" : [ SenseInfo('06396812-n', 0), SenseInfo('03573282-n', 0), SenseInfo('00384510-n', 0), SenseInfo('00384329-n', 0) ],
"_suck_v_i_rel" : [ SenseInfo('01169704-v', 4), SenseInfo('01854888-v', 2), SenseInfo('02765692-v', 0), SenseInfo('02674340-v', 0), SenseInfo('02117170-v', 0), SenseInfo('01539063-v', 0), SenseInfo('01186428-v', 0) ],
"_bewhiskered_a_1_rel" : [ SenseInfo('02153965-a', 2) ],
"_autosampler_n_1_rel" : [  ],
"_ping_n_1_rel" : [ SenseInfo('09392507-n', 0), SenseInfo('07389569-n', 0) ],
"_lump_n_1_rel" : [ SenseInfo('07961016-n', 2), SenseInfo('14315192-n', 1), SenseInfo('10274639-n', 1), SenseInfo('09307300-n', 1) ],
"_telnet_n_1_rel" : [  ],
"_align_v_1_rel" : [ SenseInfo('00464321-v', 2), SenseInfo('02658867-v', 1), SenseInfo('00733632-v', 1), SenseInfo('00466053-v', 0) ],
"_romanticism_n_1_rel" : [ SenseInfo('05152902-n', 1), SenseInfo('06155075-n', 0), SenseInfo('05208422-n', 0) ],
"_fatty_a_1_rel" : [ SenseInfo('00991838-a', 1) ],
"_knitwear_n_1_rel" : [ SenseInfo('03625943-n', 0) ],
"_gooey_a_1_rel" : [ SenseInfo('00054109-a', 0) ],
"_mythology_n_1_rel" : [ SenseInfo('07978423-n', 3), SenseInfo('06147873-n', 0) ],
"_socialism_n_1_rel" : [ SenseInfo('06220616-n', 11), SenseInfo('08366202-n', 0) ],
"_root_v_1_rel" : [ SenseInfo('00358135-v', 2), SenseInfo('02623731-v', 0), SenseInfo('01529194-v', 0), SenseInfo('01282413-v', 0), SenseInfo('00415398-v', 0), SenseInfo('00358314-v', 0), SenseInfo('00358135-v', 2), SenseInfo('02623731-v', 0), SenseInfo('01529194-v', 0), SenseInfo('01282413-v', 0), SenseInfo('00415398-v', 0), SenseInfo('00358314-v', 0), SenseInfo('00358135-v', 2), SenseInfo('02623731-v', 0), SenseInfo('01529194-v', 0), SenseInfo('01282413-v', 0), SenseInfo('00415398-v', 0), SenseInfo('00358314-v', 0) ],
"_exterior_a_to_rel" : [ SenseInfo('00952395-a', 2) ],
"_travel_v_1_rel" : [ SenseInfo('01835496-v', 34), SenseInfo('01845720-v', 9), SenseInfo('01843055-v', 3), SenseInfo('01846916-v', 2), SenseInfo('01841079-v', 1), SenseInfo('02102002-v', 0), SenseInfo('01835496-v', 34), SenseInfo('01845720-v', 9), SenseInfo('01843055-v', 3), SenseInfo('01846916-v', 2), SenseInfo('01841079-v', 1), SenseInfo('02102002-v', 0) ],
"_carafe_n_1_rel" : [ SenseInfo('02960903-n', 0) ],
"_fortune_n_1_rel" : [ SenseInfo('11418138-n', 4), SenseInfo('13370938-n', 3), SenseInfo('11418460-n', 2), SenseInfo('14473222-n', 1) ],
"_curvaceous_a_1_rel" : [ SenseInfo('02138989-a', 0), SenseInfo('02138989-a', 0) ],
"_connectionism_n_1_rel" : [  ],
"_chieftain_n_1_rel" : [ SenseInfo('09893344-n', 3), SenseInfo('10164025-n', 0) ],
"_diverge_v_1_rel" : [ SenseInfo('02032415-v', 1), SenseInfo('02732603-v', 0), SenseInfo('02709906-v', 0), SenseInfo('02661252-v', 0) ],
"_hockey_n_1_rel" : [ SenseInfo('00467995-n', 0), SenseInfo('00463543-n', 0) ],
"_toothpaste_n_1_rel" : [ SenseInfo('04453298-n', 1) ],
"_collision_n_1_rel" : [ SenseInfo('07302542-n', 6), SenseInfo('07301543-n', 0), SenseInfo('07183000-n', 0) ],
"_briefing_n_of_rel" : [ SenseInfo('07217782-n', 1) ],
"_assume_v_1_rel" : [ SenseInfo('00632236-v', 68), SenseInfo('02381726-v', 13), SenseInfo('00524682-v', 13), SenseInfo('02301825-v', 6), SenseInfo('01982395-v', 3), SenseInfo('02274482-v', 0), SenseInfo('01721754-v', 0), SenseInfo('01470856-v', 0), SenseInfo('00050652-v', 0), SenseInfo('00632236-v', 68), SenseInfo('02381726-v', 13), SenseInfo('00524682-v', 13), SenseInfo('02301825-v', 6), SenseInfo('01982395-v', 3), SenseInfo('02274482-v', 0), SenseInfo('01721754-v', 0), SenseInfo('01470856-v', 0), SenseInfo('00050652-v', 0), SenseInfo('00632236-v', 68), SenseInfo('02381726-v', 13), SenseInfo('00524682-v', 13), SenseInfo('02301825-v', 6), SenseInfo('01982395-v', 3), SenseInfo('02274482-v', 0), SenseInfo('01721754-v', 0), SenseInfo('01470856-v', 0), SenseInfo('00050652-v', 0) ],
"_international_a_1_rel" : [ SenseInfo('01568375-a', 19), SenseInfo('01037885-a', 8), SenseInfo('01568375-a', 19), SenseInfo('01037885-a', 8) ],
"_repulse_v_1_rel" : [ SenseInfo('01131197-v', 2), SenseInfo('01808769-v', 0), SenseInfo('01506157-v', 0) ],
"_laundry_n_1_rel" : [ SenseInfo('03648219-n', 1), SenseInfo('03648066-n', 0) ],
"_snowpile_n_1_rel" : [  ],
"_castrate_v_1_rel" : [ SenseInfo('00541953-v', 0), SenseInfo('00201034-v', 0), SenseInfo('00060833-v', 0), SenseInfo('00060477-v', 0) ],
"_quality_n_1_rel" : [ SenseInfo('04723816-n', 42), SenseInfo('04728068-n', 16), SenseInfo('05849284-n', 12), SenseInfo('04987620-n', 6), SenseInfo('13948026-n', 0) ],
"_belfry_n_1_rel" : [ SenseInfo('02946127-n', 1), SenseInfo('02824319-n', 0) ],
"_snowpack_n_1_rel" : [  ],
"_ball_v_up_rel" : [ SenseInfo('01523270-v', 1) ],
"_thing_n_do-be_rel" : [ SenseInfo('13943968-n', 72), SenseInfo('00034479-n', 52), SenseInfo('05855004-n', 36), SenseInfo('04424218-n', 36), SenseInfo('07289831-n', 32), SenseInfo('05671325-n', 32), SenseInfo('06723908-n', 26), SenseInfo('04424418-n', 26), SenseInfo('04617289-n', 20), SenseInfo('05984182-n', 4), SenseInfo('07480356-n', 0), SenseInfo('00002452-n', 0), SenseInfo('13943968-n', 72), SenseInfo('00034479-n', 52), SenseInfo('05855004-n', 36), SenseInfo('04424218-n', 36), SenseInfo('07289831-n', 32), SenseInfo('05671325-n', 32), SenseInfo('06723908-n', 26), SenseInfo('04424418-n', 26), SenseInfo('04617289-n', 20), SenseInfo('05984182-n', 4), SenseInfo('07480356-n', 0), SenseInfo('00002452-n', 0), SenseInfo('13943968-n', 72), SenseInfo('00034479-n', 52), SenseInfo('05855004-n', 36), SenseInfo('04424218-n', 36), SenseInfo('07289831-n', 32), SenseInfo('05671325-n', 32), SenseInfo('06723908-n', 26), SenseInfo('04424418-n', 26), SenseInfo('04617289-n', 20), SenseInfo('05984182-n', 4), SenseInfo('07480356-n', 0), SenseInfo('00002452-n', 0) ],
"_quest_n_for_rel" : [ SenseInfo('05770391-n', 1), SenseInfo('00946650-n', 0), SenseInfo('05770391-n', 1), SenseInfo('00946650-n', 0) ],
"_realm_n_1_rel" : [ SenseInfo('14514805-n', 6), SenseInfo('08558155-n', 0), SenseInfo('05997814-n', 0) ],
"_seasoned_a_1_rel" : [ SenseInfo('01494959-a', 0), SenseInfo('00936523-a', 0) ],
"_deutschmark_n_1_rel" : [ SenseInfo('13688033-n', 0), SenseInfo('13688033-n', 0), SenseInfo('13688033-n', 0), SenseInfo('13688033-n', 0), SenseInfo('13688033-n', 0), SenseInfo('13688033-n', 0) ],
"_match_v_up_rel" : [ SenseInfo('02657219-v', 16), SenseInfo('02332627-v', 12), SenseInfo('01292885-v', 6), SenseInfo('02672187-v', 5), SenseInfo('00456740-v', 3), SenseInfo('02594674-v', 0), SenseInfo('01293389-v', 0), SenseInfo('01081152-v', 0), SenseInfo('00456596-v', 0), SenseInfo('00417001-v', 0), SenseInfo('02657219-v', 16), SenseInfo('02332627-v', 12), SenseInfo('01292885-v', 6), SenseInfo('02672187-v', 5), SenseInfo('00456740-v', 3), SenseInfo('02594674-v', 0), SenseInfo('01293389-v', 0), SenseInfo('01081152-v', 0), SenseInfo('00456596-v', 0), SenseInfo('00417001-v', 0), SenseInfo('02657219-v', 16), SenseInfo('02332627-v', 12), SenseInfo('01292885-v', 6), SenseInfo('02672187-v', 5), SenseInfo('00456740-v', 3), SenseInfo('02594674-v', 0), SenseInfo('01293389-v', 0), SenseInfo('01081152-v', 0), SenseInfo('00456596-v', 0), SenseInfo('00417001-v', 0), SenseInfo('02657219-v', 16), SenseInfo('02332627-v', 12), SenseInfo('01292885-v', 6), SenseInfo('02672187-v', 5), SenseInfo('00456740-v', 3), SenseInfo('02594674-v', 0), SenseInfo('01293389-v', 0), SenseInfo('01081152-v', 0), SenseInfo('00456596-v', 0), SenseInfo('00417001-v', 0) ],
"_already_x_deg_rel" : [ SenseInfo('00031798-r', 107), SenseInfo('00031798-r', 107) ],
"_ancestry_n_1_rel" : [ SenseInfo('08101937-n', 3), SenseInfo('04922787-n', 0) ],
"_vomit_n_1_rel" : [ SenseInfo('14855992-n', 0), SenseInfo('03283519-n', 0), SenseInfo('00118733-n', 0) ],
"_micron-scale_n_1_rel" : [  ],
"_express_a_1_rel" : [ SenseInfo('00941148-a', 1), SenseInfo('00977699-a', 0), SenseInfo('00941148-a', 1), SenseInfo('00977699-a', 0) ],
"_oppressive_a_1_rel" : [ SenseInfo('01189998-a', 0), SenseInfo('00788474-a', 0), SenseInfo('01189998-a', 0), SenseInfo('00788474-a', 0) ],
"_hack_v_1_rel" : [ SenseInfo('01257173-v', 1), SenseInfo('02588280-v', 0), SenseInfo('01257817-v', 0), SenseInfo('01148199-v', 0), SenseInfo('01148101-v', 0), SenseInfo('00526441-v', 0), SenseInfo('00201618-v', 0), SenseInfo('00006100-v', 0) ],
"_sweep_n_1_rel" : [ SenseInfo('05127959-n', 3), SenseInfo('09919061-n', 0), SenseInfo('07474645-n', 0), SenseInfo('04370955-n', 0), SenseInfo('00559555-n', 0), SenseInfo('00345149-n', 0) ],
"_rub_v_1_rel" : [ SenseInfo('01249724-v', 19), SenseInfo('01250908-v', 1), SenseInfo('02119874-v', 0), SenseInfo('01249724-v', 19), SenseInfo('01250908-v', 1), SenseInfo('02119874-v', 0) ],
"_mower_n_1_rel" : [ SenseInfo('03649909-n', 0) ],
"_marina_n_1_rel" : [ SenseInfo('03721590-n', 0) ],
"_weekend_n_of_rel" : [ SenseInfo('15170504-n', 13), SenseInfo('15170504-n', 13), SenseInfo('15170504-n', 13), SenseInfo('15170504-n', 13), SenseInfo('15170504-n', 13), SenseInfo('15170504-n', 13), SenseInfo('15170504-n', 13), SenseInfo('15170504-n', 13) ],
"_panoramic_a_1_rel" : [ SenseInfo('02561123-a', 1) ],
"_glen_n_1_rel" : [ SenseInfo('09289596-n', 0) ],
"_twin_n_1_rel" : [ SenseInfo('10734394-n', 1), SenseInfo('09752519-n', 0), SenseInfo('09464335-n', 0), SenseInfo('03117939-n', 0) ],
"_pretense_n_1_rel" : [ SenseInfo('00754956-n', 1), SenseInfo('06759349-n', 0), SenseInfo('05769930-n', 0), SenseInfo('04788853-n', 0), SenseInfo('04678908-n', 0) ],
"_relatively_x_deg_rel" : [ SenseInfo('00160834-r', 36) ],
"_rendering_n_of_rel" : [ SenseInfo('06893565-n', 1), SenseInfo('05766247-n', 1), SenseInfo('00100543-n', 1), SenseInfo('06536389-n', 0), SenseInfo('04075715-n', 0), SenseInfo('04075615-n', 0), SenseInfo('01122037-n', 0) ],
"_favorite_a_1_rel" : [ SenseInfo('01816376-a', 1), SenseInfo('01462882-a', 1), SenseInfo('01816376-a', 1), SenseInfo('01462882-a', 1) ],
"_moo_n_1_rel" : [ SenseInfo('07386821-n', 0) ],
"_repository_n_1_rel" : [ SenseInfo('03177349-n', 2), SenseInfo('10521928-n', 1), SenseInfo('04076713-n', 0) ],
"_sound_v_seem-to_rel" : [ SenseInfo('02134927-v', 38), SenseInfo('02176268-v', 14), SenseInfo('02135048-v', 9), SenseInfo('02180529-v', 1), SenseInfo('00952182-v', 1), SenseInfo('02179518-v', 0), SenseInfo('00491689-v', 0), SenseInfo('02134927-v', 38), SenseInfo('02176268-v', 14), SenseInfo('02135048-v', 9), SenseInfo('02180529-v', 1), SenseInfo('00952182-v', 1), SenseInfo('02179518-v', 0), SenseInfo('00491689-v', 0), SenseInfo('02134927-v', 38), SenseInfo('02176268-v', 14), SenseInfo('02135048-v', 9), SenseInfo('02180529-v', 1), SenseInfo('00952182-v', 1), SenseInfo('02179518-v', 0), SenseInfo('00491689-v', 0) ],
"_date_v_back_rel" : [ SenseInfo('02485844-v', 1), SenseInfo('00735389-v', 1), SenseInfo('00619183-v', 1), SenseInfo('02486232-v', 0), SenseInfo('00734927-v', 0) ],
"_back+to+front_p_1_rel" : [  ],
"_hospitable_a_1_rel" : [ SenseInfo('01242101-a', 1), SenseInfo('01243825-a', 0), SenseInfo('01986134-a', 0) ],
"_exemplary_a_1_rel" : [ SenseInfo('02586446-a', 0), SenseInfo('02469119-a', 0), SenseInfo('01771124-a', 0) ],
"_race_v_1_rel" : [ SenseInfo('02058994-v', 15), SenseInfo('01086103-v', 3), SenseInfo('02369948-v', 0), SenseInfo('02059462-v', 0), SenseInfo('02058994-v', 15), SenseInfo('01086103-v', 3), SenseInfo('02369948-v', 0), SenseInfo('02059462-v', 0) ],
"_revealing_a_1_rel" : [ SenseInfo('01305344-a', 1), SenseInfo('02091165-a', 0) ],
"_edition_n_1_rel" : [ SenseInfo('06590446-n', 3), SenseInfo('07959393-n', 2), SenseInfo('06597204-n', 0), SenseInfo('05840650-n', 0) ],
"_subliterary_a_1_rel" : [ SenseInfo('01046994-a', 1) ],
"_port+of+call_n_1_rel" : [ SenseInfo('08639479-n', 0), SenseInfo('08639479-n', 0), SenseInfo('08639479-n', 0) ],
"_nondeliverable_a_1_rel" : [  ],
"_fuselage_n_1_rel" : [ SenseInfo('03408054-n', 0) ],
"_presage_v_1_rel" : [ SenseInfo('00871942-v', 1) ],
"_microwave_n_1_rel" : [ SenseInfo('11482312-n', 2), SenseInfo('03761084-n', 0) ],
"_oops_a_1_rel" : [  ],
"_clot_v_cause_rel" : [ SenseInfo('00457998-v', 1), SenseInfo('00458276-v', 0), SenseInfo('00457770-v', 0), SenseInfo('00368367-v', 0) ],
"_crown_v_1_rel" : [ SenseInfo('02390949-v', 2), SenseInfo('00485891-v', 2), SenseInfo('02694677-v', 0), SenseInfo('01338247-v', 0), SenseInfo('02390949-v', 2), SenseInfo('00485891-v', 2), SenseInfo('02694677-v', 0), SenseInfo('01338247-v', 0) ],
"_otter_n_1_rel" : [ SenseInfo('14765785-n', 0), SenseInfo('02444819-n', 0) ],
"_koldtbord_n_1_rel" : [  ],
"_rumbling_n_1_rel" : [ SenseInfo('07392483-n', 0), SenseInfo('07392483-n', 0) ],
"_text-to-speech_n_1_rel" : [  ],
"_down-regulate_v_1_rel" : [  ],
"_abaculus_n_1_rel" : [  ],
"_lexical-functional_a_1_rel" : [  ],
"_a-_n_1_rel" : [ SenseInfo('13658027-n', 6), SenseInfo('15089803-n', 0), SenseInfo('14829565-n', 0), SenseInfo('14706889-n', 0), SenseInfo('13637376-n', 0), SenseInfo('06831177-n', 0), SenseInfo('05400860-n', 0) ],
"_station_v_1_rel" : [ SenseInfo('01088923-v', 4) ],
"_categorize_v_1_rel" : [ SenseInfo('00657260-v', 1) ],
"_bridle_n_1_rel" : [ SenseInfo('02900160-n', 4), SenseInfo('01146039-n', 0) ],
"_debate_v_1_rel" : [ SenseInfo('00714884-v', 2), SenseInfo('00813044-v', 1), SenseInfo('00812580-v', 1), SenseInfo('00773432-v', 1), SenseInfo('00714884-v', 2), SenseInfo('00813044-v', 1), SenseInfo('00812580-v', 1), SenseInfo('00773432-v', 1) ],
"_grader_n_1_rel" : [ SenseInfo('10140783-n', 0) ],
"_pst_a_1_rel" : [ SenseInfo('15132638-n', 0) ],
"_pro+rata_p_rel" : [ SenseInfo('00260532-r', 2) ],
"_cottonseed_n_1_rel" : [ SenseInfo('11689815-n', 0) ],
"_flammable_a_1_rel" : [ SenseInfo('00473658-a', 0) ],
"_shipping+and+handling_n_1_rel" : [  ],
"_rescue_n_1_rel" : [ SenseInfo('00093483-n', 3) ],
"_crevasse_n_1_rel" : [ SenseInfo('09259677-n', 0) ],
"_scrub_n_1_rel" : [ SenseInfo('08438223-n', 0), SenseInfo('00251780-n', 0) ],
"_beagle_n_1_rel" : [ SenseInfo('02088364-n', 0) ],
"_liquefy_v_cause_rel" : [ SenseInfo('02757304-v', 0), SenseInfo('00444309-v', 0), SenseInfo('00443984-v', 0), SenseInfo('02757304-v', 0), SenseInfo('00444309-v', 0), SenseInfo('00443984-v', 0) ],
"_locker_n_1_rel" : [ SenseInfo('02933462-n', 4), SenseInfo('03683606-n', 0), SenseInfo('03380301-n', 0) ],
"_pay_per_view_a_1_rel" : [  ],
"_lob_v_1_rel" : [ SenseInfo('01513290-v', 1) ],
"_impurity_n_1_rel" : [ SenseInfo('14583670-n', 8), SenseInfo('14487184-n', 3) ],
"_energize_v_cause_rel" : [ SenseInfo('00022686-v', 1), SenseInfo('00559102-v', 0) ],
"superl_rel" : [  ],
"_northeaster_n_1_rel" : [ SenseInfo('11462951-n', 0) ],
"_fat_n_1_rel" : [ SenseInfo('14864360-n', 2), SenseInfo('05268965-n', 1), SenseInfo('04999401-n', 0) ],
"_now_a_2_rel" : [ SenseInfo('15119919-n', 10), SenseInfo('15119919-n', 10) ],
"_concerned_a_about_rel" : [ SenseInfo('00543603-a', 15), SenseInfo('01515692-a', 12), SenseInfo('01516346-a', 0), SenseInfo('00543603-a', 15), SenseInfo('01515692-a', 12), SenseInfo('01516346-a', 0) ],
"_stagger_v_1_rel" : [ SenseInfo('01924882-v', 10), SenseInfo('01925170-v', 6), SenseInfo('01504130-v', 1), SenseInfo('01810126-v', 0), SenseInfo('01924882-v', 10), SenseInfo('01925170-v', 6), SenseInfo('01504130-v', 1), SenseInfo('01810126-v', 0), SenseInfo('01924882-v', 10), SenseInfo('01925170-v', 6), SenseInfo('01504130-v', 1), SenseInfo('01810126-v', 0) ],
"_aria_n_1_rel" : [ SenseInfo('07049514-n', 0) ],
"_daytime_n_1_rel" : [ SenseInfo('15164957-n', 1) ],
"_plain_a_to_rel" : [ SenseInfo('01618376-a', 8), SenseInfo('01791911-a', 1), SenseInfo('01785906-a', 1), SenseInfo('01907103-a', 1), SenseInfo('00765666-a', 1), SenseInfo('00060605-a', 1), SenseInfo('00169432-a', 0), SenseInfo('01618376-a', 8), SenseInfo('01791911-a', 1), SenseInfo('01785906-a', 1), SenseInfo('01907103-a', 1), SenseInfo('00765666-a', 1), SenseInfo('00060605-a', 1), SenseInfo('00169432-a', 0) ],
"_pregnant_a_with_rel" : [ SenseInfo('00173220-a', 3), SenseInfo('01497387-a', 1), SenseInfo('01084900-a', 0) ],
"_mien_n_1_rel" : [ SenseInfo('04910377-n', 1) ],
"_netiquette_n_1_rel" : [  ],
"_elect_a_1_rel" : [ SenseInfo('02123579-a', 0), SenseInfo('01294857-a', 0) ],
"_look_v_back-at_rel" : [ SenseInfo('02130524-v', 274), SenseInfo('02133435-v', 126), SenseInfo('00033599-v', 25), SenseInfo('02153709-v', 8), SenseInfo('02693319-v', 1), SenseInfo('02549581-v', 1), SenseInfo('00929362-v', 1), SenseInfo('00720063-v', 1), SenseInfo('02658447-v', 0), SenseInfo('00712708-v', 0) ],
"_quake_n_1_rel" : [ SenseInfo('07428954-n', 3) ],
"_massacre_v_1_rel" : [ SenseInfo('00479176-v', 1) ],
"_acidic_a_1_rel" : [ SenseInfo('00025238-a', 0), SenseInfo('02369335-a', 0) ],
"_partake_v_of_rel" : [ SenseInfo('02736660-v', 1), SenseInfo('02295208-v', 0), SenseInfo('01172701-v', 0) ],
"_tool_n_1_rel" : [ SenseInfo('04451818-n', 15), SenseInfo('00173761-n', 5), SenseInfo('09976551-n', 0), SenseInfo('05526713-n', 0) ],
"_take_v_along_rel" : [ SenseInfo('02599636-v', 92), SenseInfo('02267989-v', 74), SenseInfo('01999798-v', 73), SenseInfo('01214265-v', 50), SenseInfo('00524682-v', 38), SenseInfo('00624476-v', 36), SenseInfo('02077656-v', 32), SenseInfo('02205272-v', 28), SenseInfo('01842690-v', 26), SenseInfo('00674607-v', 26), SenseInfo('02236124-v', 25), SenseInfo('02394183-v', 22), SenseInfo('00734054-v', 22), SenseInfo('02627934-v', 21), SenseInfo('02109045-v', 21), SenseInfo('01002740-v', 16), SenseInfo('00173338-v', 16), SenseInfo('01156834-v', 15), SenseInfo('00669762-v', 15), SenseInfo('02209936-v', 14), SenseInfo('02206619-v', 13), SenseInfo('01982395-v', 10), SenseInfo('02236624-v', 8), SenseInfo('00523095-v', 7), SenseInfo('00599992-v', 6), SenseInfo('00756076-v', 5), SenseInfo('02075857-v', 4), SenseInfo('01151110-v', 4), SenseInfo('00557404-v', 4), SenseInfo('02717102-v', 2), SenseInfo('02208537-v', 2), SenseInfo('02209745-v', 1), SenseInfo('02208118-v', 1), SenseInfo('02201138-v', 1), SenseInfo('01427127-v', 1), SenseInfo('00758333-v', 1), SenseInfo('02741546-v', 0), SenseInfo('02701210-v', 0), SenseInfo('02590253-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01100830-v', 0), SenseInfo('00087736-v', 0) ],
"_encroachment_n_1_rel" : [ SenseInfo('07429976-n', 3), SenseInfo('00733483-n', 0), SenseInfo('00157957-n', 0) ],
"_pioneer_n_1_rel" : [ SenseInfo('10434725-n', 1), SenseInfo('10434424-n', 1) ],
"_whisky_n_1_rel" : [ SenseInfo('07906284-n', 19) ],
"_heartwood_n_1_rel" : [ SenseInfo('13097752-n', 0) ],
"_provision_n_for_rel" : [ SenseInfo('06755947-n', 27), SenseInfo('01057200-n', 4), SenseInfo('05794694-n', 1), SenseInfo('13367448-n', 0), SenseInfo('06755947-n', 27), SenseInfo('01057200-n', 4), SenseInfo('05794694-n', 1), SenseInfo('13367448-n', 0) ],
"_asian_a_1_rel" : [ SenseInfo('02968525-a', 0) ],
"_congelifraction_n_1_rel" : [  ],
"_snap-in_a_1_rel" : [  ],
"_anger_v_1_rel" : [ SenseInfo('01785971-v', 1), SenseInfo('01787106-v', 0), SenseInfo('01785971-v', 1), SenseInfo('01787106-v', 0) ],
"_ram_n_1_rel" : [ SenseInfo('04052757-n', 1), SenseInfo('09752246-n', 0), SenseInfo('08686129-n', 0), SenseInfo('04050410-n', 0), SenseInfo('02412080-n', 0) ],
"_snuggle_v_up_rel" : [ SenseInfo('01424948-v', 3), SenseInfo('01425348-v', 0) ],
"_nigh_a_1_rel" : [ SenseInfo('00444519-a', 0), SenseInfo('02033556-a', 0), SenseInfo('00444519-a', 0), SenseInfo('02033556-a', 0) ],
"_uniform_n_1_rel" : [ SenseInfo('04509592-n', 18), SenseInfo('04509592-n', 18), SenseInfo('04509592-n', 18) ],
"_closet_n_1_rel" : [ SenseInfo('03148324-n', 4), SenseInfo('04558478-n', 1), SenseInfo('04550184-n', 1), SenseInfo('03049457-n', 0) ],
"_nickname_v_1_rel" : [ SenseInfo('01028640-v', 1), SenseInfo('01028640-v', 1) ],
"_undermine_v_1_rel" : [ SenseInfo('02543607-v', 7), SenseInfo('01283033-v', 0) ],
"_belgian_n_1_rel" : [ SenseInfo('09694109-n', 0) ],
"_pissed+off_a_1_rel" : [ SenseInfo('01806106-a', 0) ],
"_island_n_1_rel" : [ SenseInfo('09316454-n', 13), SenseInfo('03587318-n', 2), SenseInfo('09316454-n', 13), SenseInfo('03587318-n', 2) ],
"_first+and+foremost_x_deg_rel" : [  ],
"_silent_a_1_rel" : [ SenseInfo('01919428-a', 18), SenseInfo('00501820-a', 10), SenseInfo('00942163-a', 0), SenseInfo('00175123-a', 0), SenseInfo('00174983-a', 0), SenseInfo('00151855-a', 0), SenseInfo('01919428-a', 18), SenseInfo('00501820-a', 10), SenseInfo('00942163-a', 0), SenseInfo('00175123-a', 0), SenseInfo('00174983-a', 0), SenseInfo('00151855-a', 0) ],
"_bc_p_temp_rel" : [ SenseInfo('00002142-r', 0), SenseInfo('00002142-r', 0), SenseInfo('00002142-r', 0), SenseInfo('00002142-r', 0), SenseInfo('00002142-r', 0) ],
"_tongue_v_1_rel" : [ SenseInfo('01734300-v', 0), SenseInfo('01432353-v', 0) ],
"_cowboy_n_1_rel" : [ SenseInfo('09972661-n', 9), SenseInfo('09973072-n', 0), SenseInfo('09972946-n', 0) ],
"_ascendant_a_1_rel" : [ SenseInfo('02484638-a', 0), SenseInfo('00791631-a', 0) ],
"_interior_a_to_rel" : [ SenseInfo('00952867-a', 1), SenseInfo('01038332-a', 0), SenseInfo('00951831-a', 0), SenseInfo('00949115-a', 0), SenseInfo('00463917-a', 0) ],
"_run_v_back_rel" : [ SenseInfo('01926311-v', 106), SenseInfo('02075049-v', 38), SenseInfo('02685951-v', 21), SenseInfo('02443849-v', 20), SenseInfo('02721284-v', 10), SenseInfo('02066939-v', 9), SenseInfo('01525666-v', 8), SenseInfo('02727039-v', 7), SenseInfo('01094086-v', 7), SenseInfo('01717169-v', 5), SenseInfo('02099829-v', 4), SenseInfo('02719399-v', 3), SenseInfo('01526290-v', 3), SenseInfo('00549063-v', 3), SenseInfo('00517529-v', 3), SenseInfo('02720904-v', 2), SenseInfo('02647497-v', 2), SenseInfo('02612234-v', 2), SenseInfo('02563327-v', 2), SenseInfo('01746359-v', 2), SenseInfo('01641545-v', 2), SenseInfo('01212230-v', 2), SenseInfo('02686625-v', 1), SenseInfo('02525312-v', 1), SenseInfo('02242256-v', 1), SenseInfo('02092309-v', 1), SenseInfo('02060792-v', 1), SenseInfo('01927903-v', 1), SenseInfo('01914947-v', 1), SenseInfo('02648110-v', 0), SenseInfo('02421921-v', 0), SenseInfo('01927747-v', 0), SenseInfo('01927447-v', 0), SenseInfo('01926984-v', 0), SenseInfo('01864038-v', 0), SenseInfo('01143838-v', 0), SenseInfo('01086103-v', 0), SenseInfo('00539110-v', 0), SenseInfo('00444629-v', 0), SenseInfo('00334803-v', 0), SenseInfo('00332672-v', 0) ],
"_yank_v_1_rel" : [ SenseInfo('01592072-v', 5) ],
"_rather+than_p_1_rel" : [  ],
"_hangout_n_1_rel" : [ SenseInfo('08581503-n', 1) ],
"_arrest_v_1_rel" : [ SenseInfo('01215137-v', 20), SenseInfo('01131473-v', 2), SenseInfo('01505958-v', 1), SenseInfo('01859586-v', 0) ],
"_bottom-up_a_1_rel" : [ SenseInfo('02443406-a', 0), SenseInfo('02443406-a', 0) ],
"_streetlight_n_1_rel" : [ SenseInfo('04335886-n', 2) ],
"_protest_n_1_rel" : [ SenseInfo('07210225-n', 11), SenseInfo('01177033-n', 4), SenseInfo('07210553-n', 1), SenseInfo('07210225-n', 11), SenseInfo('01177033-n', 4), SenseInfo('07210553-n', 1) ],
"_melt_n_1_rel" : [ SenseInfo('13566535-n', 0) ],
"_disapproval_n_of_rel" : [ SenseInfo('07502829-n', 6), SenseInfo('06709533-n', 1), SenseInfo('06200741-n', 0), SenseInfo('00874621-n', 0) ],
"_of+age_a_1_rel" : [ SenseInfo('01644541-a', 4) ],
"_confuse_v_with_rel" : [ SenseInfo('00619610-v', 10), SenseInfo('00621734-v', 5), SenseInfo('01790739-v', 0), SenseInfo('01657254-v', 0), SenseInfo('00620673-v', 0) ],
"_nausea_n_1_rel" : [ SenseInfo('14359952-n', 2), SenseInfo('07504111-n', 0) ],
"_cavalier_a_1_rel" : [ SenseInfo('00788145-a', 0) ],
"_run_v_1_rel" : [ SenseInfo('01926311-v', 106), SenseInfo('02075049-v', 38), SenseInfo('02685951-v', 21), SenseInfo('02443849-v', 20), SenseInfo('02721284-v', 10), SenseInfo('02066939-v', 9), SenseInfo('01525666-v', 8), SenseInfo('02727039-v', 7), SenseInfo('01094086-v', 7), SenseInfo('01717169-v', 5), SenseInfo('02099829-v', 4), SenseInfo('02719399-v', 3), SenseInfo('01526290-v', 3), SenseInfo('00549063-v', 3), SenseInfo('00517529-v', 3), SenseInfo('02720904-v', 2), SenseInfo('02647497-v', 2), SenseInfo('02612234-v', 2), SenseInfo('02563327-v', 2), SenseInfo('01746359-v', 2), SenseInfo('01641545-v', 2), SenseInfo('01212230-v', 2), SenseInfo('02686625-v', 1), SenseInfo('02525312-v', 1), SenseInfo('02242256-v', 1), SenseInfo('02092309-v', 1), SenseInfo('02060792-v', 1), SenseInfo('01927903-v', 1), SenseInfo('01914947-v', 1), SenseInfo('02648110-v', 0), SenseInfo('02421921-v', 0), SenseInfo('01927747-v', 0), SenseInfo('01927447-v', 0), SenseInfo('01926984-v', 0), SenseInfo('01864038-v', 0), SenseInfo('01143838-v', 0), SenseInfo('01086103-v', 0), SenseInfo('00539110-v', 0), SenseInfo('00444629-v', 0), SenseInfo('00334803-v', 0), SenseInfo('00332672-v', 0), SenseInfo('01926311-v', 106), SenseInfo('02075049-v', 38), SenseInfo('02685951-v', 21), SenseInfo('02443849-v', 20), SenseInfo('02721284-v', 10), SenseInfo('02066939-v', 9), SenseInfo('01525666-v', 8), SenseInfo('02727039-v', 7), SenseInfo('01094086-v', 7), SenseInfo('01717169-v', 5), SenseInfo('02099829-v', 4), SenseInfo('02719399-v', 3), SenseInfo('01526290-v', 3), SenseInfo('00549063-v', 3), SenseInfo('00517529-v', 3), SenseInfo('02720904-v', 2), SenseInfo('02647497-v', 2), SenseInfo('02612234-v', 2), SenseInfo('02563327-v', 2), SenseInfo('01746359-v', 2), SenseInfo('01641545-v', 2), SenseInfo('01212230-v', 2), SenseInfo('02686625-v', 1), SenseInfo('02525312-v', 1), SenseInfo('02242256-v', 1), SenseInfo('02092309-v', 1), SenseInfo('02060792-v', 1), SenseInfo('01927903-v', 1), SenseInfo('01914947-v', 1), SenseInfo('02648110-v', 0), SenseInfo('02421921-v', 0), SenseInfo('01927747-v', 0), SenseInfo('01927447-v', 0), SenseInfo('01926984-v', 0), SenseInfo('01864038-v', 0), SenseInfo('01143838-v', 0), SenseInfo('01086103-v', 0), SenseInfo('00539110-v', 0), SenseInfo('00444629-v', 0), SenseInfo('00334803-v', 0), SenseInfo('00332672-v', 0), SenseInfo('01926311-v', 106), SenseInfo('02075049-v', 38), SenseInfo('02685951-v', 21), SenseInfo('02443849-v', 20), SenseInfo('02721284-v', 10), SenseInfo('02066939-v', 9), SenseInfo('01525666-v', 8), SenseInfo('02727039-v', 7), SenseInfo('01094086-v', 7), SenseInfo('01717169-v', 5), SenseInfo('02099829-v', 4), SenseInfo('02719399-v', 3), SenseInfo('01526290-v', 3), SenseInfo('00549063-v', 3), SenseInfo('00517529-v', 3), SenseInfo('02720904-v', 2), SenseInfo('02647497-v', 2), SenseInfo('02612234-v', 2), SenseInfo('02563327-v', 2), SenseInfo('01746359-v', 2), SenseInfo('01641545-v', 2), SenseInfo('01212230-v', 2), SenseInfo('02686625-v', 1), SenseInfo('02525312-v', 1), SenseInfo('02242256-v', 1), SenseInfo('02092309-v', 1), SenseInfo('02060792-v', 1), SenseInfo('01927903-v', 1), SenseInfo('01914947-v', 1), SenseInfo('02648110-v', 0), SenseInfo('02421921-v', 0), SenseInfo('01927747-v', 0), SenseInfo('01927447-v', 0), SenseInfo('01926984-v', 0), SenseInfo('01864038-v', 0), SenseInfo('01143838-v', 0), SenseInfo('01086103-v', 0), SenseInfo('00539110-v', 0), SenseInfo('00444629-v', 0), SenseInfo('00334803-v', 0), SenseInfo('00332672-v', 0) ],
"_opt_v_1_rel" : [ SenseInfo('00679389-v', 0) ],
"_allocate_v_to_rel" : [ SenseInfo('02234087-v', 6) ],
"_birchwood_n_1_rel" : [  ],
"_intend_v_for_rel" : [ SenseInfo('00708538-v', 32), SenseInfo('00709379-v', 6), SenseInfo('00955148-v', 4), SenseInfo('00931852-v', 0), SenseInfo('00708538-v', 32), SenseInfo('00709379-v', 6), SenseInfo('00955148-v', 4), SenseInfo('00931852-v', 0), SenseInfo('00708538-v', 32), SenseInfo('00709379-v', 6), SenseInfo('00955148-v', 4), SenseInfo('00931852-v', 0), SenseInfo('00708538-v', 32), SenseInfo('00709379-v', 6), SenseInfo('00955148-v', 4), SenseInfo('00931852-v', 0), SenseInfo('00708538-v', 32), SenseInfo('00709379-v', 6), SenseInfo('00955148-v', 4), SenseInfo('00931852-v', 0) ],
"_temerity_n_1_rel" : [ SenseInfo('04859449-n', 2) ],
"_creme_n_1_rel" : [  ],
"_attachment_n_of_rel" : [ SenseInfo('07545161-n', 1), SenseInfo('02755244-n', 1), SenseInfo('06554981-n', 0), SenseInfo('02755352-n', 0), SenseInfo('01212882-n', 0), SenseInfo('00379422-n', 0), SenseInfo('00147595-n', 0) ],
"_favor_v_1_rel" : [ SenseInfo('02400037-v', 17), SenseInfo('00692143-v', 7), SenseInfo('02464725-v', 1), SenseInfo('02453692-v', 1), SenseInfo('02400037-v', 17), SenseInfo('00692143-v', 7), SenseInfo('02464725-v', 1), SenseInfo('02453692-v', 1) ],
"_esteem_v_1_rel" : [ SenseInfo('00694068-v', 1), SenseInfo('00689950-v', 0) ],
"_carnita_n_1_rel" : [  ],
"_gloat_v_1_rel" : [ SenseInfo('00883635-v', 1), SenseInfo('02166861-v', 0), SenseInfo('00883635-v', 1), SenseInfo('02166861-v', 0) ],
"_employment_n_1_rel" : [ SenseInfo('13968092-n', 9), SenseInfo('00584367-n', 9), SenseInfo('01217859-n', 6), SenseInfo('00947128-n', 1) ],
"_slate_n_of_rel" : [ SenseInfo('04234670-n', 1), SenseInfo('15043002-n', 0), SenseInfo('14700162-n', 0), SenseInfo('06495948-n', 0) ],
"_use_n_of_rel" : [ SenseInfo('00947128-n', 90), SenseInfo('05149325-n', 18), SenseInfo('05149978-n', 7), SenseInfo('13451804-n', 1), SenseInfo('00414179-n', 1), SenseInfo('00158185-n', 1), SenseInfo('05190106-n', 0) ],
"_larch_n_1_rel" : [ SenseInfo('11619136-n', 0), SenseInfo('11618861-n', 0) ],
"_neuter_v_1_rel" : [ SenseInfo('00060477-v', 0) ],
"_worthy_a_of_rel" : [ SenseInfo('02584981-a', 13), SenseInfo('00852197-a', 1), SenseInfo('01021120-a', 0), SenseInfo('02584981-a', 13), SenseInfo('00852197-a', 1), SenseInfo('01021120-a', 0), SenseInfo('02584981-a', 13), SenseInfo('00852197-a', 1), SenseInfo('01021120-a', 0), SenseInfo('02584981-a', 13), SenseInfo('00852197-a', 1), SenseInfo('01021120-a', 0), SenseInfo('02584981-a', 13), SenseInfo('00852197-a', 1), SenseInfo('01021120-a', 0) ],
"_disadvantaged_n_1_rel" : [ SenseInfo('01864666-a', 0) ],
"_right-wing_a_1_rel" : [ SenseInfo('02030793-a', 0), SenseInfo('02030793-a', 0) ],
"_merino_n_1_rel" : [ SenseInfo('02414290-n', 0) ],
"_ambition_n_1_rel" : [ SenseInfo('07484547-n', 9), SenseInfo('04836268-n', 2), SenseInfo('07484547-n', 9), SenseInfo('04836268-n', 2) ],
"_succumb_v_1_rel" : [ SenseInfo('00804476-v', 4), SenseInfo('02620466-v', 0) ],
"_switchback_n_1_rel" : [  ],
"_mpg_n_1_rel" : [  ],
"_all+winter+long_a_1_rel" : [  ],
"_shrug_n_1_rel" : [ SenseInfo('07273924-n', 3) ],
"_smallpox_n_1_rel" : [ SenseInfo('14124423-n', 1) ],
"_water_n_1_rel" : [ SenseInfo('14845743-n', 136), SenseInfo('09225146-n', 41), SenseInfo('14847357-n', 2), SenseInfo('04562658-n', 2), SenseInfo('14855724-n', 0), SenseInfo('07935504-n', 0) ],
"_workaholic_n_1_rel" : [ SenseInfo('10791002-n', 0) ],
"_sell_v_off_rel" : [ SenseInfo('02242464-v', 73), SenseInfo('02727883-v', 12), SenseInfo('00767635-v', 5), SenseInfo('02244956-v', 4), SenseInfo('02235666-v', 2), SenseInfo('02748355-v', 0), SenseInfo('02748206-v', 0), SenseInfo('02537407-v', 0) ],
"_shenanigan_n_1_rel" : [ SenseInfo('00736375-n', 2), SenseInfo('00752954-n', 1) ],
"_chairman_n_of_rel" : [ SenseInfo('10468962-n', 8), SenseInfo('10468962-n', 8) ],
"_terminate_v_1_rel" : [ SenseInfo('00352826-v', 8), SenseInfo('02609764-v', 2), SenseInfo('02735418-v', 0), SenseInfo('02402825-v', 0) ],
"_father_n_of_rel" : [ SenseInfo('10080869-n', 72), SenseInfo('10102800-n', 2), SenseInfo('10081204-n', 2), SenseInfo('09921792-n', 2), SenseInfo('10081456-n', 1), SenseInfo('09536973-n', 1), SenseInfo('10107303-n', 0), SenseInfo('10025295-n', 0) ],
"_grow_v_on_rel" : [ SenseInfo('00125841-v', 70), SenseInfo('00230746-v', 62), SenseInfo('00231557-v', 32), SenseInfo('00245457-v', 12), SenseInfo('00250181-v', 8), SenseInfo('02624263-v', 7), SenseInfo('01739814-v', 3), SenseInfo('00094460-v', 3), SenseInfo('00543410-v', 2), SenseInfo('00250539-v', 0) ],
"_polish_n_1_rel" : [ SenseInfo('04955160-n', 2), SenseInfo('14459824-n', 1), SenseInfo('14996020-n', 0), SenseInfo('06944720-n', 0), SenseInfo('04955160-n', 2), SenseInfo('14459824-n', 1), SenseInfo('14996020-n', 0), SenseInfo('06944720-n', 0), SenseInfo('04955160-n', 2), SenseInfo('14459824-n', 1), SenseInfo('14996020-n', 0), SenseInfo('06944720-n', 0) ],
"_stuff_n_1_rel" : [ SenseInfo('14580897-n', 5), SenseInfo('04345288-n', 5), SenseInfo('13251154-n', 1), SenseInfo('06609909-n', 1), SenseInfo('05210534-n', 1), SenseInfo('07219004-n', 0), SenseInfo('05922305-n', 0) ],
"_warrant_v_1_rel" : [ SenseInfo('00896803-v', 12), SenseInfo('00891936-v', 0), SenseInfo('00896803-v', 12), SenseInfo('00891936-v', 0), SenseInfo('00896803-v', 12), SenseInfo('00891936-v', 0), SenseInfo('00896803-v', 12), SenseInfo('00891936-v', 0) ],
"_ruffle_n_1_rel" : [ SenseInfo('03397532-n', 0), SenseInfo('03024746-n', 0), SenseInfo('01176335-n', 0) ],
"_outrage_n_1_rel" : [ SenseInfo('07517737-n', 1), SenseInfo('00425090-n', 1), SenseInfo('07306252-n', 0), SenseInfo('01225397-n', 0), SenseInfo('07517737-n', 1), SenseInfo('00425090-n', 1), SenseInfo('07306252-n', 0), SenseInfo('01225397-n', 0) ],
"_heading_n_1_rel" : [ SenseInfo('06343971-n', 1), SenseInfo('08680888-n', 0), SenseInfo('03239399-n', 0) ],
"_aft+of_p_rel" : [  ],
"_ration_v_1_rel" : [ SenseInfo('02234988-v', 0), SenseInfo('02234803-v', 0) ],
"_quote_v_1_rel" : [ SenseInfo('01023259-v', 30), SenseInfo('01023925-v', 0), SenseInfo('01023574-v', 0), SenseInfo('01004403-v', 0) ],
"_antiseptic_n_1_rel" : [ SenseInfo('02724207-n', 0) ],
"_id_n_of_rel" : [ SenseInfo('09081213-n', 0), SenseInfo('06887278-n', 0), SenseInfo('05613794-n', 0), SenseInfo('09081213-n', 0), SenseInfo('06887278-n', 0), SenseInfo('05613794-n', 0), SenseInfo('09081213-n', 0), SenseInfo('06887278-n', 0), SenseInfo('05613794-n', 0), SenseInfo('09081213-n', 0), SenseInfo('06887278-n', 0), SenseInfo('05613794-n', 0), SenseInfo('09081213-n', 0), SenseInfo('06887278-n', 0), SenseInfo('05613794-n', 0) ],
"_assorted_a_1_rel" : [ SenseInfo('01199083-a', 1), SenseInfo('02065665-a', 0) ],
"_clown_n_1_rel" : [ SenseInfo('09931165-n', 1), SenseInfo('09930876-n', 1) ],
"_propagandist_n_1_rel" : [ SenseInfo('10482921-n', 7) ],
"_mane_n_1_rel" : [ SenseInfo('01899746-n', 1), SenseInfo('05256085-n', 0) ],
"_judicial_a_1_rel" : [ SenseInfo('01400961-a', 1), SenseInfo('02753205-a', 0), SenseInfo('02752987-a', 0), SenseInfo('00650135-a', 0) ],
"_firmament_n_1_rel" : [ SenseInfo('08521267-n', 0) ],
"_enrich_v_with_rel" : [ SenseInfo('00171586-v', 7), SenseInfo('02318648-v', 0), SenseInfo('00171586-v', 7), SenseInfo('02318648-v', 0), SenseInfo('00171586-v', 7), SenseInfo('02318648-v', 0), SenseInfo('00171586-v', 7), SenseInfo('02318648-v', 0), SenseInfo('00171586-v', 7), SenseInfo('02318648-v', 0), SenseInfo('00171586-v', 7), SenseInfo('02318648-v', 0) ],
"_to+blame_a_for_rel" : [  ],
"_thatch_v_1_rel" : [ SenseInfo('01233838-v', 0) ],
"_bloodstone_n_1_rel" : [ SenseInfo('14781631-n', 0) ],
"_collaboration_n_with_rel" : [ SenseInfo('01205156-n', 4), SenseInfo('01205341-n', 0) ],
"_sawmill_n_1_rel" : [ SenseInfo('04140777-n', 0), SenseInfo('03697007-n', 0) ],
"_lay_v_off_rel" : [ SenseInfo('01494310-v', 24), SenseInfo('01544692-v', 11), SenseInfo('01651972-v', 5), SenseInfo('01545079-v', 4), SenseInfo('02307261-v', 1) ],
"_shallows_n_1_rel" : [ SenseInfo('09433134-n', 0), SenseInfo('09433134-n', 0) ],
"_chinchilla_n_1_rel" : [ SenseInfo('14764715-n', 0), SenseInfo('03018614-n', 0), SenseInfo('02367492-n', 0) ],
"_zodiac_n_1_rel" : [ SenseInfo('08685188-n', 0), SenseInfo('04615456-n', 0) ],
"_forbidding_a_1_rel" : [ SenseInfo('01802932-a', 0), SenseInfo('00194357-a', 0) ],
"_regular_a_1_rel" : [ SenseInfo('01959294-a', 17), SenseInfo('02469577-a', 8), SenseInfo('02296632-a', 5), SenseInfo('02366927-a', 2), SenseInfo('00489863-a', 2), SenseInfo('02302187-a', 1), SenseInfo('01067003-a', 1), SenseInfo('01970777-a', 0), SenseInfo('01961937-a', 0), SenseInfo('00638501-a', 0), SenseInfo('02372520-a', 0), SenseInfo('01595312-a', 0), SenseInfo('01089275-a', 0), SenseInfo('01959294-a', 17), SenseInfo('02469577-a', 8), SenseInfo('02296632-a', 5), SenseInfo('02366927-a', 2), SenseInfo('00489863-a', 2), SenseInfo('02302187-a', 1), SenseInfo('01067003-a', 1), SenseInfo('01970777-a', 0), SenseInfo('01961937-a', 0), SenseInfo('00638501-a', 0), SenseInfo('02372520-a', 0), SenseInfo('01595312-a', 0), SenseInfo('01089275-a', 0) ],
"_specificity_n_1_rel" : [ SenseInfo('04762915-n', 7), SenseInfo('04763147-n', 1) ],
"_all+the+more_x_deg_rel" : [  ],
"_wetness_n_1_rel" : [ SenseInfo('14534696-n', 1) ],
"_ail_v_1_rel" : [ SenseInfo('00078665-v', 0), SenseInfo('00070816-v', 0) ],
"_brother+in+law_n_1_rel" : [ SenseInfo('09877288-n', 1), SenseInfo('09877288-n', 1) ],
"_yoke_v_1_rel" : [ SenseInfo('01492283-v', 0), SenseInfo('01492052-v', 0), SenseInfo('01490958-v', 0) ],
"_drive_v_1_rel" : [ SenseInfo('01930874-v', 56), SenseInfo('01930117-v', 24), SenseInfo('02056971-v', 13), SenseInfo('01516534-v', 13), SenseInfo('02505358-v', 6), SenseInfo('01506157-v', 5), SenseInfo('01646300-v', 4), SenseInfo('01512259-v', 2), SenseInfo('01509584-v', 2), SenseInfo('02406916-v', 1), SenseInfo('01026975-v', 1), SenseInfo('02742232-v', 0), SenseInfo('02408281-v', 0), SenseInfo('02057656-v', 0), SenseInfo('01939553-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01407904-v', 0), SenseInfo('01407722-v', 0), SenseInfo('01310964-v', 0), SenseInfo('01181741-v', 0), SenseInfo('01142636-v', 0), SenseInfo('01142490-v', 0), SenseInfo('01930874-v', 56), SenseInfo('01930117-v', 24), SenseInfo('02056971-v', 13), SenseInfo('01516534-v', 13), SenseInfo('02505358-v', 6), SenseInfo('01506157-v', 5), SenseInfo('01646300-v', 4), SenseInfo('01512259-v', 2), SenseInfo('01509584-v', 2), SenseInfo('02406916-v', 1), SenseInfo('01026975-v', 1), SenseInfo('02742232-v', 0), SenseInfo('02408281-v', 0), SenseInfo('02057656-v', 0), SenseInfo('01939553-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01407904-v', 0), SenseInfo('01407722-v', 0), SenseInfo('01310964-v', 0), SenseInfo('01181741-v', 0), SenseInfo('01142636-v', 0), SenseInfo('01142490-v', 0), SenseInfo('01930874-v', 56), SenseInfo('01930117-v', 24), SenseInfo('02056971-v', 13), SenseInfo('01516534-v', 13), SenseInfo('02505358-v', 6), SenseInfo('01506157-v', 5), SenseInfo('01646300-v', 4), SenseInfo('01512259-v', 2), SenseInfo('01509584-v', 2), SenseInfo('02406916-v', 1), SenseInfo('01026975-v', 1), SenseInfo('02742232-v', 0), SenseInfo('02408281-v', 0), SenseInfo('02057656-v', 0), SenseInfo('01939553-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01407904-v', 0), SenseInfo('01407722-v', 0), SenseInfo('01310964-v', 0), SenseInfo('01181741-v', 0), SenseInfo('01142636-v', 0), SenseInfo('01142490-v', 0), SenseInfo('01930874-v', 56), SenseInfo('01930117-v', 24), SenseInfo('02056971-v', 13), SenseInfo('01516534-v', 13), SenseInfo('02505358-v', 6), SenseInfo('01506157-v', 5), SenseInfo('01646300-v', 4), SenseInfo('01512259-v', 2), SenseInfo('01509584-v', 2), SenseInfo('02406916-v', 1), SenseInfo('01026975-v', 1), SenseInfo('02742232-v', 0), SenseInfo('02408281-v', 0), SenseInfo('02057656-v', 0), SenseInfo('01939553-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01407904-v', 0), SenseInfo('01407722-v', 0), SenseInfo('01310964-v', 0), SenseInfo('01181741-v', 0), SenseInfo('01142636-v', 0), SenseInfo('01142490-v', 0), SenseInfo('01930874-v', 56), SenseInfo('01930117-v', 24), SenseInfo('02056971-v', 13), SenseInfo('01516534-v', 13), SenseInfo('02505358-v', 6), SenseInfo('01506157-v', 5), SenseInfo('01646300-v', 4), SenseInfo('01512259-v', 2), SenseInfo('01509584-v', 2), SenseInfo('02406916-v', 1), SenseInfo('01026975-v', 1), SenseInfo('02742232-v', 0), SenseInfo('02408281-v', 0), SenseInfo('02057656-v', 0), SenseInfo('01939553-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01407904-v', 0), SenseInfo('01407722-v', 0), SenseInfo('01310964-v', 0), SenseInfo('01181741-v', 0), SenseInfo('01142636-v', 0), SenseInfo('01142490-v', 0) ],
"_like_n_1_rel" : [ SenseInfo('05845888-n', 0), SenseInfo('05845419-n', 0) ],
"_wherever_x_subord_rel" : [ SenseInfo('00495377-r', 0) ],
"_mononucleosis_n_1_rel" : [ SenseInfo('14135277-n', 0) ],
"_consent_v_to_rel" : [ SenseInfo('00797697-v', 6), SenseInfo('00797697-v', 6) ],
"_articulate_a_1_rel" : [ SenseInfo('00150202-a', 1), SenseInfo('00153410-a', 0) ],
"_stoat_n_1_rel" : [ SenseInfo('02442336-n', 0) ],
"_unhinge_v_1_rel" : [ SenseInfo('01764171-v', 0), SenseInfo('00179852-v', 0) ],
"_psycho_a_1_rel" : [ SenseInfo('10490141-n', 0) ],
"_maze_n_1_rel" : [ SenseInfo('03733281-n', 2), SenseInfo('05685879-n', 0) ],
"_thinking_n_1_rel" : [ SenseInfo('05770926-n', 11) ],
"_night+and+day_a_1_rel" : [  ],
"_superposed_a_1_rel" : [  ],
"_mete_v_out_rel" : [  ],
"_taboo_n_1_rel" : [ SenseInfo('05950234-n', 0), SenseInfo('04884302-n', 0) ],
"_out+of+bounds_a_1_rel" : [ SenseInfo('00956049-a', 3), SenseInfo('02002683-a', 2) ],
"_skipper_v_1_rel" : [ SenseInfo('02447001-v', 0) ],
"_dj_n_1_rel" : [ SenseInfo('10017272-n', 0) ],
"_villa_n_1_rel" : [ SenseInfo('11366405-n', 0), SenseInfo('04535524-n', 0), SenseInfo('04535370-n', 0), SenseInfo('04535252-n', 0) ],
"_constrictor_n_1_rel" : [ SenseInfo('01741562-n', 0) ],
"_silo_n_1_rel" : [ SenseInfo('04220250-n', 2), SenseInfo('04220344-n', 0) ],
"_sleep_v_off_rel" : [ SenseInfo('00014742-v', 58), SenseInfo('02701445-v', 0) ],
"_cleanup_n_1_rel" : [ SenseInfo('13259797-n', 0), SenseInfo('06486405-n', 0), SenseInfo('00251013-n', 0), SenseInfo('13259797-n', 0), SenseInfo('06486405-n', 0), SenseInfo('00251013-n', 0) ],
"_creation_n_of_rel" : [ SenseInfo('00908492-n', 5), SenseInfo('03129123-n', 4), SenseInfo('07328942-n', 2), SenseInfo('00240184-n', 2), SenseInfo('00237869-n', 1), SenseInfo('09466280-n', 0) ],
"_indian_a_1_rel" : [ SenseInfo('02928347-a', 3), SenseInfo('02928066-a', 1) ],
"_crater_n_1_rel" : [ SenseInfo('09472413-n', 0), SenseInfo('09259376-n', 0), SenseInfo('09259219-n', 0) ],
"_either_a_also_rel" : [  ],
"_panties_n_1_rel" : [ SenseInfo('03885028-n', 0), SenseInfo('03885028-n', 0) ],
"_astonishing_a_1_rel" : [ SenseInfo('02359789-a', 4), SenseInfo('01283155-a', 0) ],
"_opera_n_1_rel" : [ SenseInfo('07026352-n', 10), SenseInfo('06571938-n', 0), SenseInfo('03849814-n', 0) ],
"_ordinate_a_1_rel" : [ SenseInfo('06011692-n', 1) ],
"_dispense_v_1_rel" : [ SenseInfo('02294436-v', 3), SenseInfo('02534307-v', 0), SenseInfo('00081072-v', 0) ],
"_prompt_v_1_rel" : [ SenseInfo('01649999-v', 9), SenseInfo('00771961-v', 2), SenseInfo('00877848-v', 0), SenseInfo('01649999-v', 9), SenseInfo('00771961-v', 2), SenseInfo('00877848-v', 0) ],
"_pursue_v_1_rel" : [ SenseInfo('02375131-v', 11), SenseInfo('02000868-v', 9), SenseInfo('01317533-v', 6), SenseInfo('02376429-v', 4) ],
"_idyll_n_1_rel" : [ SenseInfo('07307297-n', 0), SenseInfo('07043824-n', 0), SenseInfo('06379439-n', 0) ],
"_garb_n_1_rel" : [ SenseInfo('02756098-n', 1) ],
"_blustery_a_1_rel" : [ SenseInfo('00304670-a', 1), SenseInfo('00788032-a', 0), SenseInfo('00304670-a', 1), SenseInfo('00788032-a', 0) ],
"_collection_n_of_rel" : [ SenseInfo('07951464-n', 12), SenseInfo('06591442-n', 1), SenseInfo('06513764-n', 1), SenseInfo('01014066-n', 1), SenseInfo('07951464-n', 12), SenseInfo('06591442-n', 1), SenseInfo('06513764-n', 1), SenseInfo('01014066-n', 1) ],
"_syllogism_n_1_rel" : [ SenseInfo('05779116-n', 0) ],
"_tv_n_1_rel" : [ SenseInfo('06277280-n', 9), SenseInfo('04405907-n', 1), SenseInfo('06277280-n', 9), SenseInfo('04405907-n', 1) ],
"_prefix_n_1_rel" : [ SenseInfo('06308304-n', 1) ],
"_beforehand_p_rel" : [ SenseInfo('00067045-r', 0), SenseInfo('00813915-a', 0) ],
"_thanks+to_p_rel" : [  ],
"_ambiance_n_1_rel" : [ SenseInfo('14524849-n', 1), SenseInfo('08494133-n', 0) ],
"_prepossessing_a_1_rel" : [ SenseInfo('00168910-a', 0) ],
"_no+less+than_x_rel" : [  ],
"_if+and+when_x_rel" : [  ],
"_up+to_p_rel" : [ SenseInfo('00294056-a', 3), SenseInfo('00051373-a', 2), SenseInfo('00294056-a', 3), SenseInfo('00051373-a', 2), SenseInfo('00294056-a', 3), SenseInfo('00051373-a', 2) ],
"_sacred_n_1_rel" : [ SenseInfo('02055062-a', 4), SenseInfo('02587261-a', 1), SenseInfo('02054310-a', 1), SenseInfo('02054610-a', 0), SenseInfo('00519823-a', 0) ],
"_firmness_n_1_rel" : [ SenseInfo('05031849-n', 1), SenseInfo('04861486-n', 1), SenseInfo('04938110-n', 0), SenseInfo('04777852-n', 0) ],
"_detail_v_1_rel" : [ SenseInfo('00956250-v', 1), SenseInfo('00678105-v', 1), SenseInfo('00956250-v', 1), SenseInfo('00678105-v', 1) ],
"_please_a_1_rel" : [  ],
"_stub_v_out_rel" : [ SenseInfo('01567183-v', 0), SenseInfo('01210622-v', 0), SenseInfo('00313354-v', 0), SenseInfo('00102420-v', 0) ],
"_mumble_v_1_rel" : [ SenseInfo('01044533-v', 6), SenseInfo('01175224-v', 0), SenseInfo('01044533-v', 6), SenseInfo('01175224-v', 0) ],
"_least+of+all_a_1_rel" : [  ],
"_make_v_out_rel" : [ SenseInfo('02560585-v', 508), SenseInfo('00120316-v', 459), SenseInfo('01617192-v', 243), SenseInfo('00770437-v', 85), SenseInfo('01645601-v', 78), SenseInfo('01621555-v', 52), SenseInfo('00730758-v', 33), SenseInfo('01646075-v', 17), SenseInfo('01640207-v', 16), SenseInfo('02289295-v', 14), SenseInfo('01619014-v', 14), SenseInfo('02621395-v', 12), SenseInfo('02022162-v', 12), SenseInfo('02674708-v', 10), SenseInfo('01653873-v', 9), SenseInfo('01755816-v', 8), SenseInfo('01654628-v', 5), SenseInfo('00556855-v', 5), SenseInfo('00012267-v', 5), SenseInfo('02396716-v', 4), SenseInfo('02355596-v', 4), SenseInfo('02020590-v', 4), SenseInfo('00665476-v', 4), SenseInfo('02582921-v', 3), SenseInfo('02598483-v', 2), SenseInfo('01733477-v', 2), SenseInfo('00276068-v', 2), SenseInfo('02075857-v', 1), SenseInfo('00074038-v', 1), SenseInfo('02748759-v', 0), SenseInfo('02748627-v', 0), SenseInfo('02745332-v', 0), SenseInfo('02665124-v', 0), SenseInfo('02621133-v', 0), SenseInfo('02134050-v', 0), SenseInfo('02051031-v', 0), SenseInfo('02021532-v', 0), SenseInfo('01755504-v', 0), SenseInfo('01664172-v', 0), SenseInfo('01428578-v', 0), SenseInfo('00891038-v', 0), SenseInfo('00838524-v', 0), SenseInfo('00698256-v', 0), SenseInfo('00698104-v', 0), SenseInfo('00562182-v', 0), SenseInfo('00562067-v', 0), SenseInfo('00545953-v', 0), SenseInfo('00107369-v', 0), SenseInfo('00072012-v', 0), SenseInfo('02560585-v', 508), SenseInfo('00120316-v', 459), SenseInfo('01617192-v', 243), SenseInfo('00770437-v', 85), SenseInfo('01645601-v', 78), SenseInfo('01621555-v', 52), SenseInfo('00730758-v', 33), SenseInfo('01646075-v', 17), SenseInfo('01640207-v', 16), SenseInfo('02289295-v', 14), SenseInfo('01619014-v', 14), SenseInfo('02621395-v', 12), SenseInfo('02022162-v', 12), SenseInfo('02674708-v', 10), SenseInfo('01653873-v', 9), SenseInfo('01755816-v', 8), SenseInfo('01654628-v', 5), SenseInfo('00556855-v', 5), SenseInfo('00012267-v', 5), SenseInfo('02396716-v', 4), SenseInfo('02355596-v', 4), SenseInfo('02020590-v', 4), SenseInfo('00665476-v', 4), SenseInfo('02582921-v', 3), SenseInfo('02598483-v', 2), SenseInfo('01733477-v', 2), SenseInfo('00276068-v', 2), SenseInfo('02075857-v', 1), SenseInfo('00074038-v', 1), SenseInfo('02748759-v', 0), SenseInfo('02748627-v', 0), SenseInfo('02745332-v', 0), SenseInfo('02665124-v', 0), SenseInfo('02621133-v', 0), SenseInfo('02134050-v', 0), SenseInfo('02051031-v', 0), SenseInfo('02021532-v', 0), SenseInfo('01755504-v', 0), SenseInfo('01664172-v', 0), SenseInfo('01428578-v', 0), SenseInfo('00891038-v', 0), SenseInfo('00838524-v', 0), SenseInfo('00698256-v', 0), SenseInfo('00698104-v', 0), SenseInfo('00562182-v', 0), SenseInfo('00562067-v', 0), SenseInfo('00545953-v', 0), SenseInfo('00107369-v', 0), SenseInfo('00072012-v', 0), SenseInfo('02560585-v', 508), SenseInfo('00120316-v', 459), SenseInfo('01617192-v', 243), SenseInfo('00770437-v', 85), SenseInfo('01645601-v', 78), SenseInfo('01621555-v', 52), SenseInfo('00730758-v', 33), SenseInfo('01646075-v', 17), SenseInfo('01640207-v', 16), SenseInfo('02289295-v', 14), SenseInfo('01619014-v', 14), SenseInfo('02621395-v', 12), SenseInfo('02022162-v', 12), SenseInfo('02674708-v', 10), SenseInfo('01653873-v', 9), SenseInfo('01755816-v', 8), SenseInfo('01654628-v', 5), SenseInfo('00556855-v', 5), SenseInfo('00012267-v', 5), SenseInfo('02396716-v', 4), SenseInfo('02355596-v', 4), SenseInfo('02020590-v', 4), SenseInfo('00665476-v', 4), SenseInfo('02582921-v', 3), SenseInfo('02598483-v', 2), SenseInfo('01733477-v', 2), SenseInfo('00276068-v', 2), SenseInfo('02075857-v', 1), SenseInfo('00074038-v', 1), SenseInfo('02748759-v', 0), SenseInfo('02748627-v', 0), SenseInfo('02745332-v', 0), SenseInfo('02665124-v', 0), SenseInfo('02621133-v', 0), SenseInfo('02134050-v', 0), SenseInfo('02051031-v', 0), SenseInfo('02021532-v', 0), SenseInfo('01755504-v', 0), SenseInfo('01664172-v', 0), SenseInfo('01428578-v', 0), SenseInfo('00891038-v', 0), SenseInfo('00838524-v', 0), SenseInfo('00698256-v', 0), SenseInfo('00698104-v', 0), SenseInfo('00562182-v', 0), SenseInfo('00562067-v', 0), SenseInfo('00545953-v', 0), SenseInfo('00107369-v', 0), SenseInfo('00072012-v', 0) ],
"_sitemap_n_1_rel" : [  ],
"_biblical_a_1_rel" : [ SenseInfo('02854521-a', 8), SenseInfo('02854747-a', 0) ],
"_usher_v_1_rel" : [ SenseInfo('02000547-v', 2) ],
"_up+front_p_rel" : [ SenseInfo('00766348-a', 0) ],
"_pistachio_n_1_rel" : [ SenseInfo('12761702-n', 0), SenseInfo('07775050-n', 0) ],
"_pungent_a_1_rel" : [ SenseInfo('02398608-a', 0), SenseInfo('02079313-a', 0), SenseInfo('02398608-a', 0), SenseInfo('02079313-a', 0) ],
"_invalid_n_1_rel" : [ SenseInfo('10214230-n', 1) ],
"_unquestionable_a_for_rel" : [ SenseInfo('01918184-a', 0), SenseInfo('01115635-a', 0), SenseInfo('00897363-a', 0), SenseInfo('01918184-a', 0), SenseInfo('01115635-a', 0), SenseInfo('00897363-a', 0), SenseInfo('01918184-a', 0), SenseInfo('01115635-a', 0), SenseInfo('00897363-a', 0), SenseInfo('01918184-a', 0), SenseInfo('01115635-a', 0), SenseInfo('00897363-a', 0) ],
"_steeply_x_deg_rel" : [ SenseInfo('00466131-r', 1) ],
"_substantial_a_1_rel" : [ SenseInfo('00625055-a', 22), SenseInfo('00901969-a', 1), SenseInfo('00625393-a', 0), SenseInfo('02558528-a', 0), SenseInfo('02275412-a', 0), SenseInfo('00625055-a', 22), SenseInfo('00901969-a', 1), SenseInfo('00625393-a', 0), SenseInfo('02558528-a', 0), SenseInfo('02275412-a', 0) ],
"_alpine_a_1_rel" : [ SenseInfo('03025746-a', 0), SenseInfo('03025590-a', 0), SenseInfo('01219373-a', 0) ],
"_tease_n_1_rel" : [ SenseInfo('10695555-n', 1), SenseInfo('09965134-n', 0), SenseInfo('00425905-n', 0) ],
"_stale_a_1_rel" : [ SenseInfo('01068726-a', 1), SenseInfo('01689580-a', 0), SenseInfo('01068726-a', 1), SenseInfo('01689580-a', 0), SenseInfo('01068726-a', 1), SenseInfo('01689580-a', 0) ],
"_yam_n_1_rel" : [ SenseInfo('12088223-n', 0), SenseInfo('12087961-n', 0), SenseInfo('07712267-n', 0), SenseInfo('07711907-n', 0) ],
"_redistribution_n_of_rel" : [ SenseInfo('01083350-n', 0) ],
"_runaway_n_1_rel" : [ SenseInfo('07475107-n', 1), SenseInfo('10115082-n', 0) ],
"_scripture_n_1_rel" : [ SenseInfo('06431740-n', 5), SenseInfo('06430385-n', 0), SenseInfo('06431740-n', 5), SenseInfo('06430385-n', 0) ],
"_dim_v_1_rel" : [ SenseInfo('02162310-v', 0), SenseInfo('00313585-v', 0), SenseInfo('00313464-v', 0), SenseInfo('00312278-v', 0), SenseInfo('00311113-v', 0) ],
"_abide_v_2_rel" : [ SenseInfo('02637202-v', 2), SenseInfo('00668099-v', 1), SenseInfo('02637202-v', 2), SenseInfo('00668099-v', 1) ],
"_utopian_a_1_rel" : [ SenseInfo('03020193-a', 13), SenseInfo('02497938-a', 0) ],
"_singlet_n_1_rel" : [ SenseInfo('04223299-n', 0) ],
"_cell+phone_n_1_rel" : [ SenseInfo('02992529-n', 0) ],
"_renowned_a_1_rel" : [ SenseInfo('01375831-a', 0) ],
"_trace_v_down_rel" : [ SenseInfo('00729109-v', 9), SenseInfo('01582645-v', 5), SenseInfo('02004352-v', 2), SenseInfo('02003601-v', 2), SenseInfo('02156063-v', 0), SenseInfo('01995949-v', 0), SenseInfo('01694376-v', 0), SenseInfo('00626130-v', 0) ],
"_agitate_v_1_rel" : [ SenseInfo('02585050-v', 2), SenseInfo('01762528-v', 1), SenseInfo('02589576-v', 0), SenseInfo('01893988-v', 0), SenseInfo('01889610-v', 0), SenseInfo('01419473-v', 0) ],
"_shaper_n_1_rel" : [ SenseInfo('10284064-n', 0), SenseInfo('04184435-n', 0) ],
"_austere_a_1_rel" : [ SenseInfo('01792387-a', 1), SenseInfo('01300187-a', 0), SenseInfo('00009618-a', 0) ],
"_compost_v_1_rel" : [ SenseInfo('00527232-v', 0) ],
"_shrink_n_1_rel" : [ SenseInfo('10488016-n', 0) ],
"_years-end_n_1_rel" : [  ],
"_tooth-and-nail_a_1_rel" : [  ],
"_commander_n_of_rel" : [ SenseInfo('09941964-n', 10), SenseInfo('09941383-n', 3), SenseInfo('09941571-n', 0), SenseInfo('09780828-n', 0) ],
"_divest_v_of_rel" : [ SenseInfo('02314275-v', 1), SenseInfo('02385372-v', 0), SenseInfo('02313906-v', 0), SenseInfo('00177243-v', 0), SenseInfo('02314275-v', 1), SenseInfo('02385372-v', 0), SenseInfo('02313906-v', 0), SenseInfo('00177243-v', 0) ],
"_testimony_n_1_rel" : [ SenseInfo('06734467-n', 5), SenseInfo('06732710-n', 4), SenseInfo('06648207-n', 2), SenseInfo('06734467-n', 5), SenseInfo('06732710-n', 4), SenseInfo('06648207-n', 2), SenseInfo('06734467-n', 5), SenseInfo('06732710-n', 4), SenseInfo('06648207-n', 2) ],
"_abatis_n_1_rel" : [ SenseInfo('02666735-n', 0) ],
"_lecture_v_on_rel" : [ SenseInfo('00830761-v', 4), SenseInfo('00824767-v', 1) ],
"_inseparable_a_1_rel" : [ SenseInfo('00786173-a', 1) ],
"_scant_a_1_rel" : [ SenseInfo('02337329-a', 2), SenseInfo('02337329-a', 2), SenseInfo('02337329-a', 2) ],
"_oral_n_1_rel" : [ SenseInfo('07198846-n', 0) ],
"_wipe_v_off_rel" : [ SenseInfo('01392237-v', 17), SenseInfo('01392237-v', 17) ],
"_dynamite_n_1_rel" : [ SenseInfo('03260293-n', 1) ],
"_salvage_v_1_rel" : [ SenseInfo('02550868-v', 3), SenseInfo('01381357-v', 0) ],
"_buckle_v_cause_rel" : [ SenseInfo('01548290-v', 1), SenseInfo('01279186-v', 1), SenseInfo('00356954-v', 1) ],
"_parishioner_n_1_rel" : [ SenseInfo('10400108-n', 1) ],
"_arm+in+arm_a_1_rel" : [  ],
"_tirade_n_1_rel" : [ SenseInfo('07233415-n', 0), SenseInfo('07233415-n', 0) ],
"_bicycle_n_1_rel" : [ SenseInfo('02834778-n', 5) ],
"_opposite_p_rel" : [ SenseInfo('02070887-a', 9), SenseInfo('01663201-a', 4), SenseInfo('02071139-a', 4), SenseInfo('02070711-a', 3), SenseInfo('02067913-a', 3), SenseInfo('06288024-n', 2), SenseInfo('13858604-n', 1), SenseInfo('10379620-n', 1), SenseInfo('02066312-a', 1), SenseInfo('13858833-n', 0), SenseInfo('00044861-r', 0) ],
"_fateful_a_1_rel" : [ SenseInfo('00685113-a', 2), SenseInfo('01883106-a', 0), SenseInfo('01050088-a', 0), SenseInfo('00343226-a', 0) ],
"_sidecut_n_1_rel" : [  ],
"_armadillo_n_1_rel" : [ SenseInfo('02454379-n', 2) ],
"_clarify_v_to_rel" : [ SenseInfo('00939857-v', 3), SenseInfo('00505151-v', 0), SenseInfo('00939857-v', 3), SenseInfo('00505151-v', 0) ],
"_unfulfilling_a_1_rel" : [  ],
"_single_v_out_rel" : [ SenseInfo('01409374-v', 6) ],
"_hundred-yard+dash_n_1_rel" : [  ],
"_sacrifice_n_1_rel" : [ SenseInfo('00205891-n', 7), SenseInfo('07340895-n', 1), SenseInfo('13328073-n', 0), SenseInfo('00227595-n', 0), SenseInfo('00130846-n', 0) ],
"_industry_n_1_rel" : [ SenseInfo('08065234-n', 56), SenseInfo('00923444-n', 15), SenseInfo('04865114-n', 0) ],
"_religious_a_1_rel" : [ SenseInfo('02056265-a', 10), SenseInfo('01783158-a', 3), SenseInfo('01782981-a', 0), SenseInfo('02085740-a', 0), SenseInfo('02056265-a', 10), SenseInfo('01783158-a', 3), SenseInfo('01782981-a', 0), SenseInfo('02085740-a', 0) ],
"_a_p_per_rel" : [ SenseInfo('13658027-n', 6), SenseInfo('15089803-n', 0), SenseInfo('14829565-n', 0), SenseInfo('14706889-n', 0), SenseInfo('13637376-n', 0), SenseInfo('06831177-n', 0), SenseInfo('05400860-n', 0), SenseInfo('13658027-n', 6), SenseInfo('15089803-n', 0), SenseInfo('14829565-n', 0), SenseInfo('14706889-n', 0), SenseInfo('13637376-n', 0), SenseInfo('06831177-n', 0), SenseInfo('05400860-n', 0), SenseInfo('13658027-n', 6), SenseInfo('15089803-n', 0), SenseInfo('14829565-n', 0), SenseInfo('14706889-n', 0), SenseInfo('13637376-n', 0), SenseInfo('06831177-n', 0), SenseInfo('05400860-n', 0), SenseInfo('13658027-n', 6), SenseInfo('15089803-n', 0), SenseInfo('14829565-n', 0), SenseInfo('14706889-n', 0), SenseInfo('13637376-n', 0), SenseInfo('06831177-n', 0), SenseInfo('05400860-n', 0) ],
"_overview_n_of_rel" : [ SenseInfo('06469223-n', 0) ],
"_constrain_v_1_rel" : [ SenseInfo('01301051-v', 0), SenseInfo('00418765-v', 0), SenseInfo('01301051-v', 0), SenseInfo('00418765-v', 0) ],
"_inform_v_about_rel" : [ SenseInfo('00831651-v', 46), SenseInfo('00522613-v', 2), SenseInfo('00833199-v', 1) ],
"_investor_n_1_rel" : [ SenseInfo('10216106-n', 3) ],
"_screw_v_1_rel" : [ SenseInfo('01426397-v', 0), SenseInfo('01353169-v', 0), SenseInfo('01352996-v', 0), SenseInfo('01352806-v', 0), SenseInfo('01104624-v', 0) ],
"_car_n_1_rel" : [ SenseInfo('02958343-n', 71), SenseInfo('02959942-n', 2), SenseInfo('02960501-n', 0), SenseInfo('02960352-n', 0), SenseInfo('02934451-n', 0) ],
"_headwall_n_1_rel" : [  ],
"_ignorance_n_of_rel" : [ SenseInfo('05988282-n', 5) ],
"_offspring_n_1_rel" : [ SenseInfo('10373998-n', 3), SenseInfo('07295047-n', 1), SenseInfo('01321579-n', 0) ],
"_pari-mutuel_n_1_rel" : [ SenseInfo('00507162-n', 2) ],
"_prelim_n_1_rel" : [ SenseInfo('07457599-n', 0), SenseInfo('07199013-n', 0) ],
"_used_a_to_rel" : [ SenseInfo('02494923-a', 4), SenseInfo('02495687-a', 1), SenseInfo('01640482-a', 1) ],
"_domain_n_of_rel" : [ SenseInfo('14514039-n', 4), SenseInfo('08556491-n', 2), SenseInfo('08000118-n', 0), SenseInfo('07965937-n', 0), SenseInfo('05999266-n', 0) ],
"_finnish_a_1_rel" : [ SenseInfo('02959553-a', 0) ],
"_racial_a_1_rel" : [ SenseInfo('03141609-a', 6), SenseInfo('01927654-a', 1) ],
"_fungus_n_1_rel" : [ SenseInfo('12992868-n', 0) ],
"_inefficient_a_1_rel" : [ SenseInfo('00840902-a', 0), SenseInfo('00511739-a', 0) ],
"_fire_v_1_rel" : [ SenseInfo('01135783-v', 30), SenseInfo('01133825-v', 16), SenseInfo('00320536-v', 10), SenseInfo('02402825-v', 7), SenseInfo('01134238-v', 5), SenseInfo('02002410-v', 1), SenseInfo('01759326-v', 1), SenseInfo('00378664-v', 1), SenseInfo('02356420-v', 0) ],
"_mean_v_by_rel" : [ SenseInfo('00955148-v', 93), SenseInfo('02635189-v', 89), SenseInfo('00931852-v', 43), SenseInfo('00708538-v', 27), SenseInfo('02742482-v', 9), SenseInfo('00730052-v', 8), SenseInfo('00708840-v', 0) ],
"_pinion_v_1_rel" : [ SenseInfo('01300565-v', 0), SenseInfo('00512749-v', 0) ],
"_enervation_n_1_rel" : [ SenseInfo('05041871-n', 1), SenseInfo('07331210-n', 0), SenseInfo('00673494-n', 0) ],
"_glaze_v_over_rel" : [ SenseInfo('01269521-v', 6), SenseInfo('00125447-v', 1), SenseInfo('02335363-v', 0), SenseInfo('02196378-v', 0) ],
"_domesticate_v_1_rel" : [ SenseInfo('00302464-v', 0), SenseInfo('00302130-v', 0), SenseInfo('00301856-v', 0) ],
"_box_v_in_rel" : [ SenseInfo('01485158-v', 1), SenseInfo('01420765-v', 0), SenseInfo('01419982-v', 0) ],
"_ice_v_cause_rel" : [ SenseInfo('01517175-v', 0), SenseInfo('00375579-v', 0), SenseInfo('00370921-v', 0) ],
"_retort_n_1_rel" : [ SenseInfo('07199922-n', 1), SenseInfo('04083649-n', 0), SenseInfo('07199922-n', 1), SenseInfo('04083649-n', 0) ],
"_establish_v_1_rel" : [ SenseInfo('02427103-v', 50), SenseInfo('01647229-v', 28), SenseInfo('00664788-v', 23), SenseInfo('00665476-v', 15), SenseInfo('01647672-v', 6), SenseInfo('01570108-v', 2), SenseInfo('01655505-v', 1), SenseInfo('00636888-v', 1), SenseInfo('02427103-v', 50), SenseInfo('01647229-v', 28), SenseInfo('00664788-v', 23), SenseInfo('00665476-v', 15), SenseInfo('01647672-v', 6), SenseInfo('01570108-v', 2), SenseInfo('01655505-v', 1), SenseInfo('00636888-v', 1) ],
"_narrator_n_1_rel" : [ SenseInfo('10345804-n', 0) ],
"_exile_v_to_rel" : [ SenseInfo('02499312-v', 1) ],
"_reforestation_n_of_rel" : [ SenseInfo('00400449-n', 0) ],
"_thunderbird_n_1_rel" : [ SenseInfo('10709979-n', 0) ],
"_plausibility_n_1_rel" : [ SenseInfo('04783724-n', 0) ],
"_eruption_n_1_rel" : [ SenseInfo('07436475-n', 1), SenseInfo('14321469-n', 0), SenseInfo('14008567-n', 0), SenseInfo('07435273-n', 0), SenseInfo('07376257-n', 0), SenseInfo('07320176-n', 0) ],
"_toolbar_n_1_rel" : [  ],
"_bearberry_n_1_rel" : [ SenseInfo('13141564-n', 0), SenseInfo('12757303-n', 0), SenseInfo('12231192-n', 0) ],
"_utter_a_of_rel" : [ SenseInfo('01520091-a', 3), SenseInfo('00522349-a', 0) ],
"_group_v_into_rel" : [ SenseInfo('00656576-v', 4), SenseInfo('01089878-v', 1) ],
"_posture_n_1_rel" : [ SenseInfo('05079866-n', 9), SenseInfo('05002822-n', 1), SenseInfo('06196284-n', 0), SenseInfo('05203649-n', 0) ],
"_lathe_n_1_rel" : [ SenseInfo('03646296-n', 0) ],
"_a+little_q_rel" : [  ],
"_concentration_n_of_rel" : [ SenseInfo('05038593-n', 25), SenseInfo('05088804-n', 5), SenseInfo('00375071-n', 3), SenseInfo('07413899-n', 2), SenseInfo('05704266-n', 2), SenseInfo('01231980-n', 1), SenseInfo('04865502-n', 0) ],
"_snowy_a_1_rel" : [ SenseInfo('01698231-a', 0), SenseInfo('01697592-a', 0), SenseInfo('00392093-a', 0), SenseInfo('01698231-a', 0), SenseInfo('01697592-a', 0), SenseInfo('00392093-a', 0), SenseInfo('01698231-a', 0), SenseInfo('01697592-a', 0), SenseInfo('00392093-a', 0), SenseInfo('01698231-a', 0), SenseInfo('01697592-a', 0), SenseInfo('00392093-a', 0) ],
"_quadrangle_n_1_rel" : [ SenseInfo('13879126-n', 0), SenseInfo('04030518-n', 0) ],
"_decayed_a_1_rel" : [ SenseInfo('02275892-a', 0) ],
"_pebble_n_1_rel" : [ SenseInfo('09388023-n', 5) ],
"_seek_v_out_rel" : [ SenseInfo('02240481-v', 44), SenseInfo('01315613-v', 41), SenseInfo('02530167-v', 32), SenseInfo('01839170-v', 0), SenseInfo('01069989-v', 0) ],
"_tactile_a_1_rel" : [ SenseInfo('02869097-a', 2), SenseInfo('02391683-a', 0) ],
"_surprisingly_x_deg_rel" : [ SenseInfo('00145228-r', 5), SenseInfo('00213301-r', 2) ],
"_muddle_v_1_rel" : [ SenseInfo('01419867-v', 0), SenseInfo('00620532-v', 0) ],
"_ascribe_v_to_rel" : [ SenseInfo('00726300-v', 3), SenseInfo('00726300-v', 3) ],
"_avalanche_n_1_rel" : [ SenseInfo('07405137-n', 0), SenseInfo('07285036-n', 0) ],
"_reel_v_in_rel" : [ SenseInfo('01924882-v', 2), SenseInfo('02046755-v', 1), SenseInfo('01523105-v', 0) ],
"_formant_n_1_rel" : [  ],
"_thick_n_1_rel" : [ SenseInfo('08588699-n', 1), SenseInfo('08588699-n', 1) ],
"_indonesian_a_1_rel" : [ SenseInfo('02972194-a', 0) ],
"_situate_v_1_rel" : [ SenseInfo('02694933-v', 3), SenseInfo('01575675-v', 1), SenseInfo('02694933-v', 3), SenseInfo('01575675-v', 1) ],
"_dependent_n_1_rel" : [ SenseInfo('10004804-n', 2) ],
"_refinery_n_1_rel" : [ SenseInfo('04068441-n', 0) ],
"_step_v_out_rel" : [ SenseInfo('01928838-v', 23), SenseInfo('02091410-v', 7), SenseInfo('02563616-v', 0), SenseInfo('02516594-v', 0), SenseInfo('02330247-v', 0), SenseInfo('02091885-v', 0), SenseInfo('02091689-v', 0), SenseInfo('01256487-v', 0), SenseInfo('00490722-v', 0), SenseInfo('00124659-v', 0) ],
"_sumptuous_a_1_rel" : [ SenseInfo('02024928-a', 2) ],
"_strengthen_v_1_rel" : [ SenseInfo('00220869-v', 24), SenseInfo('00220461-v', 1), SenseInfo('00101277-v', 0) ],
"_messy_a_1_rel" : [ SenseInfo('02426042-a', 1), SenseInfo('02426042-a', 1), SenseInfo('02426042-a', 1) ],
"_attribute_n_1_rel" : [ SenseInfo('05849040-n', 2), SenseInfo('00024264-n', 1) ],
"_weed_v_1_rel" : [ SenseInfo('00313171-v', 0) ],
"_package_v_1_rel" : [ SenseInfo('01485158-v', 2) ],
"_tyvek_n_1_rel" : [  ],
"_overeat_v_1_rel" : [ SenseInfo('01193099-v', 1), SenseInfo('01193099-v', 1) ],
"_expose_v_1_rel" : [ SenseInfo('02112029-v', 14), SenseInfo('00933821-v', 7), SenseInfo('02140033-v', 4), SenseInfo('01339505-v', 3), SenseInfo('02137710-v', 2), SenseInfo('01036319-v', 1), SenseInfo('02113430-v', 0), SenseInfo('00853195-v', 0), SenseInfo('00614444-v', 0) ],
"_fight_v_back_rel" : [ SenseInfo('01090335-v', 112), SenseInfo('01091427-v', 34), SenseInfo('02407338-v', 8), SenseInfo('02589576-v', 5) ],
"_seal_v_out_rel" : [ SenseInfo('01354006-v', 3), SenseInfo('01353405-v', 3), SenseInfo('00698732-v', 2), SenseInfo('01356582-v', 0), SenseInfo('01269008-v', 0), SenseInfo('01143498-v', 0) ],
"_childrens_a_1_rel" : [  ],
"_torture_n_of_rel" : [ SenseInfo('07496755-n', 1), SenseInfo('14333433-n', 0), SenseInfo('07495551-n', 0), SenseInfo('00751529-n', 0), SenseInfo('00421437-n', 0) ],
"_fling_v_1_rel" : [ SenseInfo('01512465-v', 13), SenseInfo('02094428-v', 1), SenseInfo('02269003-v', 0), SenseInfo('02222318-v', 0), SenseInfo('01512465-v', 13), SenseInfo('02094428-v', 1), SenseInfo('02269003-v', 0), SenseInfo('02222318-v', 0) ],
"_attend_v_to_rel" : [ SenseInfo('02612762-v', 84), SenseInfo('02549581-v', 2), SenseInfo('02716567-v', 1), SenseInfo('02540670-v', 1), SenseInfo('02170427-v', 1) ],
"_defendant_n_1_rel" : [ SenseInfo('09762101-n', 4) ],
"_stretch_v_1_rel" : [ SenseInfo('02607830-v', 16), SenseInfo('00027268-v', 11), SenseInfo('02054989-v', 4), SenseInfo('00240810-v', 4), SenseInfo('00318816-v', 3), SenseInfo('01985271-v', 1), SenseInfo('01449591-v', 1), SenseInfo('00541746-v', 1), SenseInfo('00487748-v', 0), SenseInfo('00154141-v', 0), SenseInfo('00101434-v', 0), SenseInfo('02607830-v', 16), SenseInfo('00027268-v', 11), SenseInfo('02054989-v', 4), SenseInfo('00240810-v', 4), SenseInfo('00318816-v', 3), SenseInfo('01985271-v', 1), SenseInfo('01449591-v', 1), SenseInfo('00541746-v', 1), SenseInfo('00487748-v', 0), SenseInfo('00154141-v', 0), SenseInfo('00101434-v', 0) ],
"_fortitude_n_1_rel" : [ SenseInfo('05032193-n', 3) ],
"_shroud_v_1_rel" : [ SenseInfo('01582200-v', 1), SenseInfo('02749768-v', 0), SenseInfo('01300437-v', 0), SenseInfo('01582200-v', 1), SenseInfo('02749768-v', 0), SenseInfo('01300437-v', 0) ],
"_reminiscent_a_of_rel" : [ SenseInfo('01977669-a', 0) ],
"_regulate_v_1_rel" : [ SenseInfo('00299341-v', 6), SenseInfo('02511551-v', 4), SenseInfo('00701040-v', 1), SenseInfo('00234988-v', 0), SenseInfo('00299341-v', 6), SenseInfo('02511551-v', 4), SenseInfo('00701040-v', 1), SenseInfo('00234988-v', 0) ],
"_louisianan_n_1_rel" : [ SenseInfo('09743383-n', 1) ],
"_bayesian_a_1_rel" : [ SenseInfo('02625430-a', 0) ],
"_misgiving_n_1_rel" : [ SenseInfo('07525555-n', 3), SenseInfo('05951566-n', 1), SenseInfo('05698791-n', 0) ],
"_penniless_a_1_rel" : [ SenseInfo('02023661-a', 0) ],
"_holidaymaker_n_1_rel" : [ SenseInfo('10718131-n', 0) ],
"_church-goer_n_1_rel" : [ SenseInfo('09922485-n', 1), SenseInfo('09922485-n', 1) ],
"_cow_n_1_rel" : [ SenseInfo('02403454-n', 20), SenseInfo('01887787-n', 1), SenseInfo('09972587-n', 0), SenseInfo('02403454-n', 20), SenseInfo('01887787-n', 1), SenseInfo('09972587-n', 0) ],
"_proprietorship_n_1_rel" : [ SenseInfo('13243780-n', 10) ],
"_gift_n_of-to_rel" : [ SenseInfo('13265011-n', 8), SenseInfo('05624042-n', 4), SenseInfo('01086081-n', 2) ],
"_calendar_n_1_rel" : [ SenseInfo('15173479-n', 1), SenseInfo('06487395-n', 1), SenseInfo('08266849-n', 0) ],
"_care_v_for_rel" : [ SenseInfo('01822936-v', 64), SenseInfo('02550296-v', 9), SenseInfo('01824736-v', 7), SenseInfo('02436349-v', 4), SenseInfo('01766748-v', 1) ],
"_cobbler_n_1_rel" : [ SenseInfo('09933098-n', 1), SenseInfo('07913774-n', 0), SenseInfo('07625831-n', 0) ],
"_party_n_of-to_rel" : [ SenseInfo('08256968-n', 29), SenseInfo('08252602-n', 14), SenseInfo('08264897-n', 12), SenseInfo('07447641-n', 6), SenseInfo('10402824-n', 1), SenseInfo('08256968-n', 29), SenseInfo('08252602-n', 14), SenseInfo('08264897-n', 12), SenseInfo('07447641-n', 6), SenseInfo('10402824-n', 1), SenseInfo('08256968-n', 29), SenseInfo('08252602-n', 14), SenseInfo('08264897-n', 12), SenseInfo('07447641-n', 6), SenseInfo('10402824-n', 1) ],
"_serum_n_1_rel" : [ SenseInfo('05403149-n', 34) ],
"_special_n_1_rel" : [ SenseInfo('07166851-n', 1), SenseInfo('07580253-n', 0), SenseInfo('07017534-n', 0) ],
"_forte+piano_n_1_rel" : [ SenseInfo('03928116-n', 1), SenseInfo('03928116-n', 1) ],
"_sign_v_1_rel" : [ SenseInfo('00996485-v', 16), SenseInfo('02464866-v', 13), SenseInfo('00889229-v', 8), SenseInfo('02409941-v', 2), SenseInfo('01039330-v', 1), SenseInfo('01498319-v', 0), SenseInfo('00929160-v', 0), SenseInfo('00867231-v', 0) ],
"_peg_v_1_rel" : [ SenseInfo('02524897-v', 0), SenseInfo('01442203-v', 0), SenseInfo('01340283-v', 0), SenseInfo('00271201-v', 0) ],
"_sight_v_1_rel" : [ SenseInfo('02163746-v', 4), SenseInfo('02199307-v', 0) ],
"_united_a_1_rel" : [ SenseInfo('02475855-a', 3), SenseInfo('01481812-a', 0) ],
"_flare_v_into_rel" : [ SenseInfo('02762806-v', 1), SenseInfo('00304252-v', 1), SenseInfo('02762981-v', 0), SenseInfo('00307785-v', 0) ],
"_goods_n_1_rel" : [ SenseInfo('05159725-n', 11), SenseInfo('04849241-n', 9), SenseInfo('05142180-n', 6), SenseInfo('03076708-n', 0), SenseInfo('05159725-n', 11), SenseInfo('04849241-n', 9), SenseInfo('05142180-n', 6), SenseInfo('03076708-n', 0), SenseInfo('05159725-n', 11), SenseInfo('04849241-n', 9), SenseInfo('05142180-n', 6), SenseInfo('03076708-n', 0), SenseInfo('05159725-n', 11), SenseInfo('04849241-n', 9), SenseInfo('05142180-n', 6), SenseInfo('03076708-n', 0) ],
"_render_v_1_rel" : [ SenseInfo('00120675-v', 12), SenseInfo('02327200-v', 10), SenseInfo('01732172-v', 4), SenseInfo('01629000-v', 2), SenseInfo('01062253-v', 1), SenseInfo('02310328-v', 0), SenseInfo('02310007-v', 0), SenseInfo('02293321-v', 0), SenseInfo('01686956-v', 0), SenseInfo('01361240-v', 0), SenseInfo('01060746-v', 0), SenseInfo('00959827-v', 0), SenseInfo('00444975-v', 0), SenseInfo('00120675-v', 12), SenseInfo('02327200-v', 10), SenseInfo('01732172-v', 4), SenseInfo('01629000-v', 2), SenseInfo('01062253-v', 1), SenseInfo('02310328-v', 0), SenseInfo('02310007-v', 0), SenseInfo('02293321-v', 0), SenseInfo('01686956-v', 0), SenseInfo('01361240-v', 0), SenseInfo('01060746-v', 0), SenseInfo('00959827-v', 0), SenseInfo('00444975-v', 0) ],
"_eurocity_n_1_rel" : [  ],
"_ford_v_1_rel" : [ SenseInfo('01913849-v', 0) ],
"_bicyclist_n_1_rel" : [ SenseInfo('09986189-n', 0) ],
"_circa_x_deg_rel" : [  ],
"_person_n_1_rel" : [ SenseInfo('00007846-n', 6833), SenseInfo('05217688-n', 1), SenseInfo('06326797-n', 0) ],
"_vanity_n_1_rel" : [ SenseInfo('07508996-n', 4), SenseInfo('05141040-n', 0), SenseInfo('04887129-n', 0), SenseInfo('03238586-n', 0) ],
"_glassy_a_1_rel" : [ SenseInfo('02237761-a', 1), SenseInfo('01087388-a', 1), SenseInfo('01119661-a', 0), SenseInfo('02237761-a', 1), SenseInfo('01087388-a', 1), SenseInfo('01119661-a', 0), SenseInfo('02237761-a', 1), SenseInfo('01087388-a', 1), SenseInfo('01119661-a', 0) ],
"_tick_n_1_rel" : [ SenseInfo('07397761-n', 2), SenseInfo('01776313-n', 1), SenseInfo('06818747-n', 0), SenseInfo('04432308-n', 0) ],
"_leave_v_behind_rel" : [ SenseInfo('02009433-v', 146), SenseInfo('00613683-v', 63), SenseInfo('02729414-v', 56), SenseInfo('00136991-v', 27), SenseInfo('02015598-v', 20), SenseInfo('02721438-v', 19), SenseInfo('02635659-v', 16), SenseInfo('02383440-v', 14), SenseInfo('02356230-v', 8), SenseInfo('02229055-v', 7), SenseInfo('02730135-v', 5), SenseInfo('00360092-v', 5), SenseInfo('02296153-v', 3), SenseInfo('00613018-v', 3) ],
"_privatization_n_of_rel" : [ SenseInfo('01152033-n', 0), SenseInfo('01152033-n', 0) ],
"_counterbalance_v_1_rel" : [ SenseInfo('02672540-v', 1), SenseInfo('02666531-v', 0), SenseInfo('02543874-v', 0), SenseInfo('02672540-v', 1), SenseInfo('02666531-v', 0), SenseInfo('02543874-v', 0), SenseInfo('02672540-v', 1), SenseInfo('02666531-v', 0), SenseInfo('02543874-v', 0), SenseInfo('02672540-v', 1), SenseInfo('02666531-v', 0), SenseInfo('02543874-v', 0) ],
"_appendage_n_1_rel" : [ SenseInfo('05559908-n', 0), SenseInfo('05470189-n', 0), SenseInfo('02728763-n', 0) ],
"_rub_v_off_rel" : [ SenseInfo('01249724-v', 19), SenseInfo('01250908-v', 1), SenseInfo('02119874-v', 0) ],
"_aerial_a_1_rel" : [ SenseInfo('01380267-a', 0), SenseInfo('00626136-a', 0) ],
"_ego_n_1_rel" : [ SenseInfo('07508806-n', 6), SenseInfo('05675601-n', 1), SenseInfo('05613170-n', 0) ],
"_underpin_v_1_rel" : [ SenseInfo('01218918-v', 1), SenseInfo('02663340-v', 0) ],
"_fringe_n_1_rel" : [ SenseInfo('13903576-n', 8), SenseInfo('08690792-n', 1), SenseInfo('11459748-n', 0), SenseInfo('07974850-n', 0), SenseInfo('05258985-n', 0), SenseInfo('03397762-n', 0) ],
"_chart_v_1_rel" : [ SenseInfo('00710803-v', 5), SenseInfo('00705095-v', 1), SenseInfo('01755137-v', 0) ],
"_right+hander_n_1_rel" : [ SenseInfo('10530959-n', 0), SenseInfo('10530959-n', 0) ],
"_snicker_v_1_rel" : [ SenseInfo('00030010-v', 2), SenseInfo('00030010-v', 2) ],
"_metadata_n_1_rel" : [ SenseInfo('08462721-n', 0), SenseInfo('08462721-n', 0), SenseInfo('08462721-n', 0), SenseInfo('08462721-n', 0) ],
"_building_n_1_rel" : [ SenseInfo('02913152-n', 48), SenseInfo('00911048-n', 3), SenseInfo('01104637-n', 1), SenseInfo('07973241-n', 0), SenseInfo('02913152-n', 48), SenseInfo('00911048-n', 3), SenseInfo('01104637-n', 1), SenseInfo('07973241-n', 0) ],
"_somali_n_1_rel" : [ SenseInfo('09749880-n', 0), SenseInfo('06991004-n', 0) ],
"_little_x_deg_rel" : [ SenseInfo('01391351-a', 163), SenseInfo('01554510-a', 71), SenseInfo('00100002-r', 16), SenseInfo('13762717-n', 12), SenseInfo('01649031-a', 12), SenseInfo('01280908-a', 8), SenseInfo('01455732-a', 3), SenseInfo('02386612-a', 0), SenseInfo('01467534-a', 0), SenseInfo('00855670-a', 0) ],
"_indigent_a_1_rel" : [ SenseInfo('02023430-a', 0) ],
"_proceedings_n_1_rel" : [ SenseInfo('01184814-n', 1), SenseInfo('01184814-n', 1) ],
"_leave_v_out_rel" : [ SenseInfo('02009433-v', 146), SenseInfo('00613683-v', 63), SenseInfo('02729414-v', 56), SenseInfo('00136991-v', 27), SenseInfo('02015598-v', 20), SenseInfo('02721438-v', 19), SenseInfo('02635659-v', 16), SenseInfo('02383440-v', 14), SenseInfo('02356230-v', 8), SenseInfo('02229055-v', 7), SenseInfo('02730135-v', 5), SenseInfo('00360092-v', 5), SenseInfo('02296153-v', 3), SenseInfo('00613018-v', 3) ],
"_earthy_a_1_rel" : [ SenseInfo('00683531-a', 2), SenseInfo('01570286-a', 1), SenseInfo('01317362-a', 1), SenseInfo('02905151-a', 0), SenseInfo('01940472-a', 0), SenseInfo('00683531-a', 2), SenseInfo('01570286-a', 1), SenseInfo('01317362-a', 1), SenseInfo('02905151-a', 0), SenseInfo('01940472-a', 0), SenseInfo('00683531-a', 2), SenseInfo('01570286-a', 1), SenseInfo('01317362-a', 1), SenseInfo('02905151-a', 0), SenseInfo('01940472-a', 0) ],
"_diamond_n_1_rel" : [ SenseInfo('13371958-n', 3), SenseInfo('14834563-n', 1), SenseInfo('13882961-n', 0), SenseInfo('03187972-n', 0), SenseInfo('02799593-n', 0), SenseInfo('02780916-n', 0) ],
"_millstone_n_1_rel" : [ SenseInfo('05689645-n', 0), SenseInfo('03767112-n', 0), SenseInfo('03766935-n', 0) ],
"_talk_v_out+of_rel" : [ SenseInfo('00962447-v', 108), SenseInfo('00941990-v', 26), SenseInfo('00963570-v', 8), SenseInfo('00952841-v', 4), SenseInfo('00937208-v', 2), SenseInfo('00830761-v', 0) ],
"_wall_n_of_rel" : [ SenseInfo('04546855-n', 82), SenseInfo('09474162-n', 15), SenseInfo('05604254-n', 1), SenseInfo('14564779-n', 0), SenseInfo('09474412-n', 0), SenseInfo('04547821-n', 0), SenseInfo('04547592-n', 0), SenseInfo('04051825-n', 0), SenseInfo('04546855-n', 82), SenseInfo('09474162-n', 15), SenseInfo('05604254-n', 1), SenseInfo('14564779-n', 0), SenseInfo('09474412-n', 0), SenseInfo('04547821-n', 0), SenseInfo('04547592-n', 0), SenseInfo('04051825-n', 0), SenseInfo('04546855-n', 82), SenseInfo('09474162-n', 15), SenseInfo('05604254-n', 1), SenseInfo('14564779-n', 0), SenseInfo('09474412-n', 0), SenseInfo('04547821-n', 0), SenseInfo('04547592-n', 0), SenseInfo('04051825-n', 0) ],
"_cavalry_n_1_rel" : [ SenseInfo('08397856-n', 7), SenseInfo('08389710-n', 0) ],
"_eyelid_n_1_rel" : [ SenseInfo('05313822-n', 3) ],
"_commitment_n_to_rel" : [ SenseInfo('04646990-n', 2), SenseInfo('01206153-n', 2), SenseInfo('01239868-n', 1), SenseInfo('06684383-n', 0), SenseInfo('01165692-n', 0), SenseInfo('04646990-n', 2), SenseInfo('01206153-n', 2), SenseInfo('01239868-n', 1), SenseInfo('06684383-n', 0), SenseInfo('01165692-n', 0) ],
"_summit_n_1_rel" : [ SenseInfo('13940456-n', 0), SenseInfo('08617963-n', 0), SenseInfo('08312359-n', 0), SenseInfo('13940456-n', 0), SenseInfo('08617963-n', 0), SenseInfo('08312359-n', 0) ],
"_anapophysis_n_1_rel" : [  ],
"_crocidolite_n_1_rel" : [  ],
"_transmute_v_1_rel" : [ SenseInfo('00381601-v', 2), SenseInfo('00382635-v', 1), SenseInfo('00382493-v', 0) ],
"_contract_n_1_rel" : [ SenseInfo('06520944-n', 19), SenseInfo('06737394-n', 2), SenseInfo('00491366-n', 0), SenseInfo('06520944-n', 19), SenseInfo('06737394-n', 2), SenseInfo('00491366-n', 0), SenseInfo('06520944-n', 19), SenseInfo('06737394-n', 2), SenseInfo('00491366-n', 0), SenseInfo('06520944-n', 19), SenseInfo('06737394-n', 2), SenseInfo('00491366-n', 0), SenseInfo('06520944-n', 19), SenseInfo('06737394-n', 2), SenseInfo('00491366-n', 0) ],
"_downhill_n_1_rel" : [ SenseInfo('09269472-n', 0), SenseInfo('07463872-n', 0) ],
"_coachman_n_1_rel" : [ SenseInfo('09932336-n', 0) ],
"_gable_n_1_rel" : [ SenseInfo('03409393-n', 1), SenseInfo('10986437-n', 0) ],
"_traveller_n_1_rel" : [ SenseInfo('09629752-n', 1) ],
"_low+tech_a_1_rel" : [ SenseInfo('01208919-a', 0), SenseInfo('01208919-a', 0) ],
"_fell_v_1_rel" : [ SenseInfo('01258302-v', 4), SenseInfo('02073065-v', 0), SenseInfo('01331237-v', 0) ],
"_overlap_n_of_rel" : [ SenseInfo('05764365-n', 0), SenseInfo('05048833-n', 0), SenseInfo('03641706-n', 0) ],
"_pea_n_1_rel" : [ SenseInfo('07725376-n', 3), SenseInfo('12560282-n', 0), SenseInfo('12560016-n', 0) ],
"_commanding_a_1_rel" : [ SenseInfo('01205232-a', 1) ],
"_boot_v_up_rel" : [ SenseInfo('01372556-v', 0), SenseInfo('00098346-v', 0), SenseInfo('01372556-v', 0), SenseInfo('00098346-v', 0) ],
"_turn_v_out_rel" : [ SenseInfo('01907258-v', 187), SenseInfo('00146138-v', 21), SenseInfo('02626604-v', 12), SenseInfo('02089984-v', 8), SenseInfo('00138508-v', 7), SenseInfo('01909812-v', 5), SenseInfo('00125841-v', 5), SenseInfo('01436518-v', 2), SenseInfo('02096167-v', 1), SenseInfo('02089420-v', 1), SenseInfo('01952208-v', 1), SenseInfo('01741864-v', 1), SenseInfo('01584450-v', 1), SenseInfo('00282523-v', 1), SenseInfo('00091124-v', 1), SenseInfo('02626934-v', 0), SenseInfo('02562425-v', 0), SenseInfo('02211948-v', 0), SenseInfo('02090435-v', 0), SenseInfo('01951937-v', 0), SenseInfo('01280014-v', 0), SenseInfo('01225215-v', 0), SenseInfo('01151889-v', 0), SenseInfo('00794640-v', 0), SenseInfo('00458471-v', 0), SenseInfo('00248387-v', 0), SenseInfo('01907258-v', 187), SenseInfo('00146138-v', 21), SenseInfo('02626604-v', 12), SenseInfo('02089984-v', 8), SenseInfo('00138508-v', 7), SenseInfo('01909812-v', 5), SenseInfo('00125841-v', 5), SenseInfo('01436518-v', 2), SenseInfo('02096167-v', 1), SenseInfo('02089420-v', 1), SenseInfo('01952208-v', 1), SenseInfo('01741864-v', 1), SenseInfo('01584450-v', 1), SenseInfo('00282523-v', 1), SenseInfo('00091124-v', 1), SenseInfo('02626934-v', 0), SenseInfo('02562425-v', 0), SenseInfo('02211948-v', 0), SenseInfo('02090435-v', 0), SenseInfo('01951937-v', 0), SenseInfo('01280014-v', 0), SenseInfo('01225215-v', 0), SenseInfo('01151889-v', 0), SenseInfo('00794640-v', 0), SenseInfo('00458471-v', 0), SenseInfo('00248387-v', 0), SenseInfo('01907258-v', 187), SenseInfo('00146138-v', 21), SenseInfo('02626604-v', 12), SenseInfo('02089984-v', 8), SenseInfo('00138508-v', 7), SenseInfo('01909812-v', 5), SenseInfo('00125841-v', 5), SenseInfo('01436518-v', 2), SenseInfo('02096167-v', 1), SenseInfo('02089420-v', 1), SenseInfo('01952208-v', 1), SenseInfo('01741864-v', 1), SenseInfo('01584450-v', 1), SenseInfo('00282523-v', 1), SenseInfo('00091124-v', 1), SenseInfo('02626934-v', 0), SenseInfo('02562425-v', 0), SenseInfo('02211948-v', 0), SenseInfo('02090435-v', 0), SenseInfo('01951937-v', 0), SenseInfo('01280014-v', 0), SenseInfo('01225215-v', 0), SenseInfo('01151889-v', 0), SenseInfo('00794640-v', 0), SenseInfo('00458471-v', 0), SenseInfo('00248387-v', 0), SenseInfo('01907258-v', 187), SenseInfo('00146138-v', 21), SenseInfo('02626604-v', 12), SenseInfo('02089984-v', 8), SenseInfo('00138508-v', 7), SenseInfo('01909812-v', 5), SenseInfo('00125841-v', 5), SenseInfo('01436518-v', 2), SenseInfo('02096167-v', 1), SenseInfo('02089420-v', 1), SenseInfo('01952208-v', 1), SenseInfo('01741864-v', 1), SenseInfo('01584450-v', 1), SenseInfo('00282523-v', 1), SenseInfo('00091124-v', 1), SenseInfo('02626934-v', 0), SenseInfo('02562425-v', 0), SenseInfo('02211948-v', 0), SenseInfo('02090435-v', 0), SenseInfo('01951937-v', 0), SenseInfo('01280014-v', 0), SenseInfo('01225215-v', 0), SenseInfo('01151889-v', 0), SenseInfo('00794640-v', 0), SenseInfo('00458471-v', 0), SenseInfo('00248387-v', 0), SenseInfo('01907258-v', 187), SenseInfo('00146138-v', 21), SenseInfo('02626604-v', 12), SenseInfo('02089984-v', 8), SenseInfo('00138508-v', 7), SenseInfo('01909812-v', 5), SenseInfo('00125841-v', 5), SenseInfo('01436518-v', 2), SenseInfo('02096167-v', 1), SenseInfo('02089420-v', 1), SenseInfo('01952208-v', 1), SenseInfo('01741864-v', 1), SenseInfo('01584450-v', 1), SenseInfo('00282523-v', 1), SenseInfo('00091124-v', 1), SenseInfo('02626934-v', 0), SenseInfo('02562425-v', 0), SenseInfo('02211948-v', 0), SenseInfo('02090435-v', 0), SenseInfo('01951937-v', 0), SenseInfo('01280014-v', 0), SenseInfo('01225215-v', 0), SenseInfo('01151889-v', 0), SenseInfo('00794640-v', 0), SenseInfo('00458471-v', 0), SenseInfo('00248387-v', 0) ],
"_so_x_comp_rel" : [ SenseInfo('00146594-r', 322), SenseInfo('00118363-r', 79), SenseInfo('00146926-r', 73), SenseInfo('00147126-r', 7), SenseInfo('00147272-r', 6), SenseInfo('00121135-r', 2), SenseInfo('00146763-r', 1), SenseInfo('00117620-r', 1), SenseInfo('06868844-n', 0), SenseInfo('00043003-r', 0), SenseInfo('00037641-r', 0) ],
"_nominal_n_1_rel" : [ SenseInfo('06316480-n', 0) ],
"_triumphant_a_1_rel" : [ SenseInfo('00704898-a', 3), SenseInfo('00695209-a', 1) ],
"_extravagant_a_1_rel" : [ SenseInfo('02000968-a', 3), SenseInfo('02422242-a', 1), SenseInfo('02000968-a', 3), SenseInfo('02422242-a', 1) ],
"_consultation_n_of_rel" : [ SenseInfo('07143624-n', 2), SenseInfo('07143137-n', 2), SenseInfo('01264050-n', 0) ],
"_penthouse_n_1_rel" : [ SenseInfo('03912821-n', 1) ],
"_fluorine_n_1_rel" : [ SenseInfo('14637507-n', 1) ],
"_disunite_v_1_rel" : [ SenseInfo('02430580-v', 0), SenseInfo('01556921-v', 0) ],
"_low-key_a_1_rel" : [ SenseInfo('02000406-a', 0), SenseInfo('02000406-a', 0) ],
"_any_q_rel" : [  ],
"_puzzle_v_1_rel" : [ SenseInfo('00622384-v', 6), SenseInfo('01831308-v', 0), SenseInfo('00622384-v', 6), SenseInfo('01831308-v', 0), SenseInfo('00622384-v', 6), SenseInfo('01831308-v', 0), SenseInfo('00622384-v', 6), SenseInfo('01831308-v', 0), SenseInfo('00622384-v', 6), SenseInfo('01831308-v', 0) ],
"_rebut_v_1_rel" : [ SenseInfo('00814850-v', 7), SenseInfo('00667747-v', 1), SenseInfo('00814850-v', 7), SenseInfo('00667747-v', 1) ],
"_wakeup_n_1_rel" : [  ],
"_numeration_n_1_rel" : [ SenseInfo('07230959-n', 0), SenseInfo('00634586-n', 0) ],
"_power_v_down_rel" : [ SenseInfo('01181559-v', 3), SenseInfo('01181559-v', 3) ],
"_party-pooper_n_1_rel" : [ SenseInfo('10638136-n', 0), SenseInfo('10638136-n', 0) ],
"_typically_x_deg_rel" : [ SenseInfo('00128168-r', 7) ],
"_forward-looking_a_1_rel" : [ SenseInfo('01876261-a', 0), SenseInfo('01876261-a', 0), SenseInfo('01876261-a', 0) ],
"_evil_n_1_rel" : [ SenseInfo('00745637-n', 6), SenseInfo('05144663-n', 4), SenseInfo('04852088-n', 3), SenseInfo('00745637-n', 6), SenseInfo('05144663-n', 4), SenseInfo('04852088-n', 3) ],
"_am_x_rel" : [ SenseInfo('14628494-n', 0), SenseInfo('06701001-n', 0), SenseInfo('06281594-n', 0), SenseInfo('14628494-n', 0), SenseInfo('06701001-n', 0), SenseInfo('06281594-n', 0), SenseInfo('14628494-n', 0), SenseInfo('06701001-n', 0), SenseInfo('06281594-n', 0), SenseInfo('14628494-n', 0), SenseInfo('06701001-n', 0), SenseInfo('06281594-n', 0), SenseInfo('14628494-n', 0), SenseInfo('06701001-n', 0), SenseInfo('06281594-n', 0), SenseInfo('14628494-n', 0), SenseInfo('06701001-n', 0), SenseInfo('06281594-n', 0), SenseInfo('14628494-n', 0), SenseInfo('06701001-n', 0), SenseInfo('06281594-n', 0), SenseInfo('14628494-n', 0), SenseInfo('06701001-n', 0), SenseInfo('06281594-n', 0) ],
"_rouse_v_1_rel" : [ SenseInfo('02083806-v', 2), SenseInfo('02056466-v', 0), SenseInfo('01762528-v', 0), SenseInfo('00018813-v', 0) ],
"_plain_a_1_rel" : [ SenseInfo('01618376-a', 8), SenseInfo('01791911-a', 1), SenseInfo('01785906-a', 1), SenseInfo('01907103-a', 1), SenseInfo('00765666-a', 1), SenseInfo('00060605-a', 1), SenseInfo('00169432-a', 0), SenseInfo('01618376-a', 8), SenseInfo('01791911-a', 1), SenseInfo('01785906-a', 1), SenseInfo('01907103-a', 1), SenseInfo('00765666-a', 1), SenseInfo('00060605-a', 1), SenseInfo('00169432-a', 0), SenseInfo('01618376-a', 8), SenseInfo('01791911-a', 1), SenseInfo('01785906-a', 1), SenseInfo('01907103-a', 1), SenseInfo('00765666-a', 1), SenseInfo('00060605-a', 1), SenseInfo('00169432-a', 0) ],
"_close+to_p_rel" : [ SenseInfo('00007015-r', 3) ],
"_substandard_a_1_rel" : [ SenseInfo('02297409-a', 0) ],
"_gee_n_1_rel" : [ SenseInfo('13648596-n', 2) ],
"_spin_v_1_rel" : [ SenseInfo('02046755-v', 11), SenseInfo('02068062-v', 5), SenseInfo('02048051-v', 0), SenseInfo('01639500-v', 0), SenseInfo('01639364-v', 0), SenseInfo('01518772-v', 0), SenseInfo('00953700-v', 0), SenseInfo('00318706-v', 0) ],
"_global_a_1_rel" : [ SenseInfo('01568684-a', 1), SenseInfo('02041229-a', 0), SenseInfo('01568684-a', 1), SenseInfo('02041229-a', 0) ],
"_comma_n_1_rel" : [ SenseInfo('06842852-n', 0), SenseInfo('02278024-n', 0) ],
"_clouds_n_i_rel" : [ SenseInfo('11439690-n', 24), SenseInfo('09247410-n', 16), SenseInfo('13960357-n', 1), SenseInfo('14525108-n', 0), SenseInfo('13982999-n', 0), SenseInfo('07996149-n', 0) ],
"_call_v_name_rel" : [ SenseInfo('01028748-v', 91), SenseInfo('00971015-v', 51), SenseInfo('00789448-v', 38), SenseInfo('00913065-v', 25), SenseInfo('00792471-v', 25), SenseInfo('02487573-v', 9), SenseInfo('02429810-v', 9), SenseInfo('01067995-v', 1), SenseInfo('01062739-v', 1), SenseInfo('00975036-v', 1), SenseInfo('02643421-v', 0), SenseInfo('02601456-v', 0), SenseInfo('02487901-v', 0), SenseInfo('02359061-v', 0), SenseInfo('02300060-v', 0), SenseInfo('01899017-v', 0), SenseInfo('01068793-v', 0), SenseInfo('00917772-v', 0), SenseInfo('00874002-v', 0), SenseInfo('00869393-v', 0), SenseInfo('00822746-v', 0), SenseInfo('00783523-v', 0), SenseInfo('00754156-v', 0), SenseInfo('00753881-v', 0), SenseInfo('00738747-v', 0), SenseInfo('00738583-v', 0), SenseInfo('00691516-v', 0), SenseInfo('00107231-v', 0) ],
"_smack_v_of_rel" : [ SenseInfo('01414916-v', 2), SenseInfo('02194723-v', 1), SenseInfo('02194495-v', 0), SenseInfo('01431879-v', 0), SenseInfo('01197208-v', 0) ],
"_earl_n_1_rel" : [ SenseInfo('10041373-n', 1) ],
"_silver_v_1_rel" : [ SenseInfo('01395493-v', 0), SenseInfo('00289532-v', 0), SenseInfo('00282652-v', 0) ],
"_rockslide_n_1_rel" : [ SenseInfo('07405817-n', 0) ],
"_chrysanthemum_n_1_rel" : [ SenseInfo('11951271-n', 1), SenseInfo('11950345-n', 0) ],
"_trade_n_of_rel" : [ SenseInfo('01091905-n', 16), SenseInfo('00606370-n', 16), SenseInfo('01096454-n', 6), SenseInfo('01110274-n', 3), SenseInfo('08436562-n', 2), SenseInfo('11519949-n', 0), SenseInfo('01109687-n', 0) ],
"_inert_a_1_rel" : [ SenseInfo('01565038-a', 2), SenseInfo('01930004-a', 1), SenseInfo('00034322-a', 0) ],
"_whip_n_1_rel" : [ SenseInfo('04577769-n', 3), SenseInfo('10776766-n', 0), SenseInfo('07612367-n', 0), SenseInfo('05022902-n', 0), SenseInfo('00134574-n', 0) ],
"_offensive_a_1_rel" : [ SenseInfo('01631386-a', 1), SenseInfo('01628946-a', 0), SenseInfo('01628302-a', 0), SenseInfo('01627965-a', 0), SenseInfo('01624633-a', 0), SenseInfo('00908672-a', 0), SenseInfo('02560035-a', 0) ],
"_buxom_a_1_rel" : [ SenseInfo('02138989-a', 0), SenseInfo('00986975-a', 0) ],
"_proficient_a_1_rel" : [ SenseInfo('02226162-a', 3), SenseInfo('02809220-a', 0) ],
"_accrue_v_to_rel" : [ SenseInfo('00155869-v', 2), SenseInfo('02230056-v', 0) ],
"_efficiency_n_1_rel" : [ SenseInfo('13820993-n', 12), SenseInfo('05644527-n', 9) ],
"_anew_a_1_rel" : [  ],
"_corporate_a_1_rel" : [ SenseInfo('02984781-a', 4), SenseInfo('00630466-a', 2), SenseInfo('02112701-a', 0), SenseInfo('01670669-a', 0), SenseInfo('02984781-a', 4), SenseInfo('00630466-a', 2), SenseInfo('02112701-a', 0), SenseInfo('01670669-a', 0) ],
"_strengthen_v_cause_rel" : [ SenseInfo('00220869-v', 24), SenseInfo('00220461-v', 1), SenseInfo('00101277-v', 0) ],
"_therapy_n_1_rel" : [ SenseInfo('00661091-n', 7) ],
"_as+far+as_p_rel" : [  ],
"_migration_n_1_rel" : [ SenseInfo('01123095-n', 2), SenseInfo('07966421-n', 0), SenseInfo('07312829-n', 0), SenseInfo('07312616-n', 0) ],
"_minus_p_rel" : [ SenseInfo('01819821-a', 0), SenseInfo('00871862-n', 0), SenseInfo('00065667-a', 0) ],
"_dot_v_1_rel" : [ SenseInfo('02689882-v', 3), SenseInfo('01376245-v', 0), SenseInfo('00998294-v', 0), SenseInfo('00507913-v', 0) ],
"_tip-over_n_1_rel" : [  ],
"_probe_v_for_rel" : [ SenseInfo('00788564-v', 7), SenseInfo('01226875-v', 2), SenseInfo('00788564-v', 7), SenseInfo('01226875-v', 2) ],
"_cooperate_v_with_rel" : [ SenseInfo('02416278-v', 20) ],
"_sound_v_out_rel" : [ SenseInfo('02134927-v', 38), SenseInfo('02176268-v', 14), SenseInfo('02135048-v', 9), SenseInfo('02180529-v', 1), SenseInfo('00952182-v', 1), SenseInfo('02179518-v', 0), SenseInfo('00491689-v', 0) ],
"_crude_n_1_rel" : [ SenseInfo('14980579-n', 0) ],
"_grope_n_1_rel" : [ SenseInfo('00141027-n', 0) ],
"_daydream_n_1_rel" : [ SenseInfo('05769471-n', 0), SenseInfo('05769471-n', 0) ],
"_speckle_v_1_rel" : [ SenseInfo('01538469-v', 0), SenseInfo('01538310-v', 0) ],
"_mass_v_1_rel" : [ SenseInfo('02024168-v', 3) ],
"_confiscate_v_1_rel" : [ SenseInfo('02273293-v', 2) ],
"_back_n_1_rel" : [ SenseInfo('05558717-n', 53), SenseInfo('04059701-n', 12), SenseInfo('08625846-n', 4), SenseInfo('09830194-n', 0), SenseInfo('05588174-n', 0), SenseInfo('02840619-n', 0), SenseInfo('02767665-n', 0), SenseInfo('02767433-n', 0), SenseInfo('00725775-n', 0), SenseInfo('05558717-n', 53), SenseInfo('04059701-n', 12), SenseInfo('08625846-n', 4), SenseInfo('09830194-n', 0), SenseInfo('05588174-n', 0), SenseInfo('02840619-n', 0), SenseInfo('02767665-n', 0), SenseInfo('02767433-n', 0), SenseInfo('00725775-n', 0) ],
"_lifestyle_n_1_rel" : [ SenseInfo('04930632-n', 0) ],
"_speckle_n_1_rel" : [ SenseInfo('04682462-n', 0) ],
"_scenario_n_1_rel" : [ SenseInfo('07012135-n', 1), SenseInfo('08568430-n', 0), SenseInfo('06756111-n', 0) ],
"_fore+and+aft_p_rel" : [ SenseInfo('01445320-a', 0), SenseInfo('01445320-a', 0), SenseInfo('01445320-a', 0) ],
"_low_a_on_rel" : [ SenseInfo('01212469-a', 55), SenseInfo('01206474-a', 23), SenseInfo('01455888-a', 11), SenseInfo('01951008-a', 6), SenseInfo('01215421-a', 4), SenseInfo('00904745-a', 3), SenseInfo('02340458-a', 0), SenseInfo('02336759-a', 0), SenseInfo('01893303-a', 0), SenseInfo('00703615-a', 0) ],
"_soccer_n_1_rel" : [ SenseInfo('00478262-n', 0) ],
"_disband_v_cause_rel" : [ SenseInfo('02030967-v', 1), SenseInfo('02029944-v', 1) ],
"_illustration_n_of_rel" : [ SenseInfo('06999233-n', 4), SenseInfo('06880533-n', 3), SenseInfo('05820620-n', 1), SenseInfo('03561345-n', 1), SenseInfo('06999233-n', 4), SenseInfo('06880533-n', 3), SenseInfo('05820620-n', 1), SenseInfo('03561345-n', 1), SenseInfo('06999233-n', 4), SenseInfo('06880533-n', 3), SenseInfo('05820620-n', 1), SenseInfo('03561345-n', 1), SenseInfo('06999233-n', 4), SenseInfo('06880533-n', 3), SenseInfo('05820620-n', 1), SenseInfo('03561345-n', 1) ],
"_buzz_n_1_rel" : [ SenseInfo('07378234-n', 1), SenseInfo('01260008-n', 1) ],
"_win_v_back_rel" : [ SenseInfo('01100145-v', 71), SenseInfo('02288295-v', 42), SenseInfo('01111028-v', 2), SenseInfo('02524171-v', 0) ],
"_compose_v_1_rel" : [ SenseInfo('02621244-v', 14), SenseInfo('01705494-v', 5), SenseInfo('01698271-v', 4), SenseInfo('01626138-v', 3), SenseInfo('01765178-v', 1), SenseInfo('00706804-v', 0), SenseInfo('02621244-v', 14), SenseInfo('01705494-v', 5), SenseInfo('01698271-v', 4), SenseInfo('01626138-v', 3), SenseInfo('01765178-v', 1), SenseInfo('00706804-v', 0) ],
"_balustrade_n_1_rel" : [ SenseInfo('02788148-n', 3) ],
"_muse_n_1_rel" : [ SenseInfo('09565999-n', 1), SenseInfo('05835162-n', 0) ],
"_put_v_in_rel" : [ SenseInfo('01494310-v', 138), SenseInfo('01493741-v', 98), SenseInfo('00981276-v', 28), SenseInfo('01160370-v', 6), SenseInfo('02271137-v', 3), SenseInfo('00673448-v', 2), SenseInfo('02111499-v', 0), SenseInfo('01706375-v', 0), SenseInfo('00735571-v', 0), SenseInfo('01494310-v', 138), SenseInfo('01493741-v', 98), SenseInfo('00981276-v', 28), SenseInfo('01160370-v', 6), SenseInfo('02271137-v', 3), SenseInfo('00673448-v', 2), SenseInfo('02111499-v', 0), SenseInfo('01706375-v', 0), SenseInfo('00735571-v', 0) ],
"_rhetoric_n_1_rel" : [ SenseInfo('07072698-n', 0), SenseInfo('07070429-n', 0), SenseInfo('06609503-n', 0), SenseInfo('06170498-n', 0) ],
"_harmonica_n_1_rel" : [ SenseInfo('03494278-n', 0) ],
"_rover_n_1_rel" : [ SenseInfo('10765679-n', 0), SenseInfo('10540984-n', 0) ],
"_babble_v_on_rel" : [ SenseInfo('01065630-v', 3), SenseInfo('01037650-v', 2), SenseInfo('02187922-v', 0), SenseInfo('00937208-v', 0), SenseInfo('01065630-v', 3), SenseInfo('01037650-v', 2), SenseInfo('02187922-v', 0), SenseInfo('00937208-v', 0) ],
"_look_v_through_rel" : [ SenseInfo('02130524-v', 274), SenseInfo('02133435-v', 126), SenseInfo('00033599-v', 25), SenseInfo('02153709-v', 8), SenseInfo('02693319-v', 1), SenseInfo('02549581-v', 1), SenseInfo('00929362-v', 1), SenseInfo('00720063-v', 1), SenseInfo('02658447-v', 0), SenseInfo('00712708-v', 0) ],
"_timeport_n_1_rel" : [  ],
"_judge_v_1_rel" : [ SenseInfo('00672277-v', 11), SenseInfo('00670261-v', 8), SenseInfo('00672433-v', 6), SenseInfo('00971650-v', 1), SenseInfo('02501278-v', 0), SenseInfo('00672277-v', 11), SenseInfo('00670261-v', 8), SenseInfo('00672433-v', 6), SenseInfo('00971650-v', 1), SenseInfo('02501278-v', 0), SenseInfo('00672277-v', 11), SenseInfo('00670261-v', 8), SenseInfo('00672433-v', 6), SenseInfo('00971650-v', 1), SenseInfo('02501278-v', 0), SenseInfo('00672277-v', 11), SenseInfo('00670261-v', 8), SenseInfo('00672433-v', 6), SenseInfo('00971650-v', 1), SenseInfo('02501278-v', 0) ],
"_doorbell_n_1_rel" : [ SenseInfo('03222516-n', 1) ],
"_prototype_n_1_rel" : [ SenseInfo('05937524-n', 2) ],
"_prince_n_of_rel" : [ SenseInfo('10472799-n', 1), SenseInfo('10472799-n', 1) ],
"_dash_n_1_rel" : [ SenseInfo('04812871-n', 1), SenseInfo('00294452-n', 1), SenseInfo('07469043-n', 0), SenseInfo('06843148-n', 0), SenseInfo('06805962-n', 0), SenseInfo('00555983-n', 0) ],
"_enumerate_v_1_rel" : [ SenseInfo('00946105-v', 1), SenseInfo('00948071-v', 0) ],
"_frightening_a_for_rel" : [ SenseInfo('00193799-a', 6), SenseInfo('00193799-a', 6), SenseInfo('00193799-a', 6) ],
"_purr_n_1_rel" : [ SenseInfo('07390645-n', 0) ],
"_turn_v_back_rel" : [ SenseInfo('01907258-v', 187), SenseInfo('00146138-v', 21), SenseInfo('02626604-v', 12), SenseInfo('02089984-v', 8), SenseInfo('00138508-v', 7), SenseInfo('01909812-v', 5), SenseInfo('00125841-v', 5), SenseInfo('01436518-v', 2), SenseInfo('02096167-v', 1), SenseInfo('02089420-v', 1), SenseInfo('01952208-v', 1), SenseInfo('01741864-v', 1), SenseInfo('01584450-v', 1), SenseInfo('00282523-v', 1), SenseInfo('00091124-v', 1), SenseInfo('02626934-v', 0), SenseInfo('02562425-v', 0), SenseInfo('02211948-v', 0), SenseInfo('02090435-v', 0), SenseInfo('01951937-v', 0), SenseInfo('01280014-v', 0), SenseInfo('01225215-v', 0), SenseInfo('01151889-v', 0), SenseInfo('00794640-v', 0), SenseInfo('00458471-v', 0), SenseInfo('00248387-v', 0) ],
"_ethic_n_1_rel" : [ SenseInfo('05956019-n', 2), SenseInfo('06663617-n', 0) ],
"_haul_v_off-2_rel" : [ SenseInfo('01454810-v', 7), SenseInfo('01452255-v', 5) ],
"_isomorphic_a_1_rel" : [ SenseInfo('02828917-a', 0) ],
"_reconcile_v_with_rel" : [ SenseInfo('00482893-v', 2), SenseInfo('00482473-v', 2), SenseInfo('00764902-v', 1), SenseInfo('00732394-v', 1) ],
"_once+again_a_1_rel" : [  ],
"_intangible_a_1_rel" : [ SenseInfo('02392654-a', 0), SenseInfo('02391867-a', 0), SenseInfo('01273454-a', 0), SenseInfo('00627643-a', 0) ],
"_ordinal_a_1_rel" : [ SenseInfo('02996466-a', 0), SenseInfo('02200035-a', 0) ],
"_scratchy_a_1_rel" : [ SenseInfo('02239289-a', 1), SenseInfo('01136541-a', 0), SenseInfo('00578662-a', 0), SenseInfo('00299476-a', 0) ],
"_casualty_n_1_rel" : [ SenseInfo('09899782-n', 0), SenseInfo('09899671-n', 0), SenseInfo('07361717-n', 0), SenseInfo('07340094-n', 0) ],
"_propagation_n_of_rel" : [ SenseInfo('06253518-n', 1), SenseInfo('00849982-n', 1), SenseInfo('11512992-n', 0) ],
"_tally_v_cause_rel" : [ SenseInfo('02657219-v', 0), SenseInfo('01111816-v', 0), SenseInfo('00949841-v', 0), SenseInfo('00949288-v', 0) ],
"_directorate_n_1_rel" : [ SenseInfo('08380768-n', 0) ],
"_cash_v_in_rel" : [ SenseInfo('02256354-v', 2), SenseInfo('02256354-v', 2), SenseInfo('02256354-v', 2) ],
"_wince_v_1_rel" : [ SenseInfo('02061069-v', 2), SenseInfo('00008977-v', 1) ],
"_demonstrative_a_1_rel" : [ SenseInfo('00720296-a', 0), SenseInfo('01323962-a', 0) ],
"_flush_a_with_rel" : [ SenseInfo('00910542-a', 1), SenseInfo('02022167-a', 0) ],
"_diary_n_1_rel" : [ SenseInfo('06402031-n', 3), SenseInfo('03189707-n', 0) ],
"_genome_n_1_rel" : [ SenseInfo('08457543-n', 0) ],
"_possession_n_of_rel" : [ SenseInfo('00809465-n', 10), SenseInfo('00032613-n', 6), SenseInfo('14407795-n', 0), SenseInfo('09182524-n', 0), SenseInfo('08631531-n', 0), SenseInfo('04862005-n', 0), SenseInfo('00809702-n', 0) ],
"_peddler_n_1_rel" : [ SenseInfo('10411551-n', 3), SenseInfo('10495555-n', 0) ],
"_refuge_n_1_rel" : [ SenseInfo('08643933-n', 0), SenseInfo('05155123-n', 0), SenseInfo('04071102-n', 0), SenseInfo('01208597-n', 0) ],
"_randomize_v_1_rel" : [ SenseInfo('00278899-v', 0) ],
"_submerge_v_1_rel" : [ SenseInfo('01991472-v', 2), SenseInfo('01339294-v', 1), SenseInfo('01578254-v', 0), SenseInfo('00217700-v', 0) ],
"_yelp_v_1_rel" : [ SenseInfo('01048171-v', 3), SenseInfo('01048171-v', 3), SenseInfo('01048171-v', 3) ],
"_satin_n_1_rel" : [ SenseInfo('04138261-n', 1) ],
"_lobby_n_1_rel" : [ SenseInfo('02715513-n', 6), SenseInfo('08375912-n', 0), SenseInfo('08375526-n', 0) ],
"_cathartic_a_1_rel" : [ SenseInfo('01165830-a', 0), SenseInfo('00854869-a', 0), SenseInfo('00638067-a', 0) ],
"_tweak_n_1_rel" : [ SenseInfo('00357275-n', 0) ],
"_lizard_n_1_rel" : [ SenseInfo('01674464-n', 1), SenseInfo('10274474-n', 0) ],
"_trainer_n_1_rel" : [ SenseInfo('10722575-n', 0), SenseInfo('03363363-n', 0) ],
"_pointless_a_for_rel" : [ SenseInfo('01811504-a', 0), SenseInfo('02503305-a', 0), SenseInfo('01811504-a', 0), SenseInfo('02503305-a', 0) ],
"_infer_v_1_rel" : [ SenseInfo('00636574-v', 3), SenseInfo('01022420-v', 1), SenseInfo('00944924-v', 0), SenseInfo('00636061-v', 0), SenseInfo('00593522-v', 0), SenseInfo('00636574-v', 3), SenseInfo('01022420-v', 1), SenseInfo('00944924-v', 0), SenseInfo('00636061-v', 0), SenseInfo('00593522-v', 0), SenseInfo('00636574-v', 3), SenseInfo('01022420-v', 1), SenseInfo('00944924-v', 0), SenseInfo('00636061-v', 0), SenseInfo('00593522-v', 0) ],
"_unless_p_1_rel" : [  ],
"_motorway_n_1_rel" : [ SenseInfo('03306610-n', 0), SenseInfo('03306610-n', 0) ],
"_accede_v_1_rel" : [ SenseInfo('00878348-v', 1), SenseInfo('02381397-v', 0), SenseInfo('00804139-v', 0) ],
"_movie_n_of_rel" : [ SenseInfo('06613686-n', 26) ],
"_southeasterly_a_1_rel" : [ SenseInfo('01603649-a', 0), SenseInfo('01603518-a', 0), SenseInfo('01603649-a', 0), SenseInfo('01603518-a', 0) ],
"_takings_n_1_rel" : [ SenseInfo('00714477-n', 0), SenseInfo('00714477-n', 0) ],
"_evocative_a_of_rel" : [ SenseInfo('01977669-a', 0) ],
"_condo_n_1_rel" : [ SenseInfo('03088580-n', 0) ],
"_produce_v_1_rel" : [ SenseInfo('01752495-v', 69), SenseInfo('01621555-v', 38), SenseInfo('01752884-v', 26), SenseInfo('02141146-v', 12), SenseInfo('01739814-v', 6), SenseInfo('02157100-v', 5), SenseInfo('00094460-v', 0) ],
"_see_v_as_rel" : [ SenseInfo('02129289-v', 613), SenseInfo('00591115-v', 159), SenseInfo('02128873-v', 140), SenseInfo('01635432-v', 58), SenseInfo('00690614-v', 47), SenseInfo('00598954-v', 40), SenseInfo('02150948-v', 29), SenseInfo('02023107-v', 27), SenseInfo('00920336-v', 27), SenseInfo('00662589-v', 22), SenseInfo('02488304-v', 13), SenseInfo('02488488-v', 12), SenseInfo('02493030-v', 10), SenseInfo('02549581-v', 7), SenseInfo('01470670-v', 4), SenseInfo('02486232-v', 1), SenseInfo('02129709-v', 1), SenseInfo('00703708-v', 1), SenseInfo('02156225-v', 0), SenseInfo('02131279-v', 0), SenseInfo('02110220-v', 0), SenseInfo('02026086-v', 0), SenseInfo('01156568-v', 0), SenseInfo('00623151-v', 0), SenseInfo('02129289-v', 613), SenseInfo('00591115-v', 159), SenseInfo('02128873-v', 140), SenseInfo('01635432-v', 58), SenseInfo('00690614-v', 47), SenseInfo('00598954-v', 40), SenseInfo('02150948-v', 29), SenseInfo('02023107-v', 27), SenseInfo('00920336-v', 27), SenseInfo('00662589-v', 22), SenseInfo('02488304-v', 13), SenseInfo('02488488-v', 12), SenseInfo('02493030-v', 10), SenseInfo('02549581-v', 7), SenseInfo('01470670-v', 4), SenseInfo('02486232-v', 1), SenseInfo('02129709-v', 1), SenseInfo('00703708-v', 1), SenseInfo('02156225-v', 0), SenseInfo('02131279-v', 0), SenseInfo('02110220-v', 0), SenseInfo('02026086-v', 0), SenseInfo('01156568-v', 0), SenseInfo('00623151-v', 0) ],
"_mitigate_v_1_rel" : [ SenseInfo('00906037-v', 3), SenseInfo('00198850-v', 0) ],
"_strand_v_1_rel" : [ SenseInfo('02228355-v', 2), SenseInfo('02087377-v', 0), SenseInfo('02022486-v', 0), SenseInfo('02228355-v', 2), SenseInfo('02087377-v', 0), SenseInfo('02022486-v', 0) ],
"_plunge_v_into_rel" : [ SenseInfo('01577635-v', 6), SenseInfo('01967373-v', 4), SenseInfo('01834053-v', 4), SenseInfo('00347918-v', 4), SenseInfo('00601378-v', 1), SenseInfo('01977080-v', 0), SenseInfo('01577093-v', 0), SenseInfo('00601043-v', 0) ],
"_pocket_n_1_rel" : [ SenseInfo('03972524-n', 21), SenseInfo('13914473-n', 2), SenseInfo('13356774-n', 2), SenseInfo('13911660-n', 0), SenseInfo('13894306-n', 0), SenseInfo('11423028-n', 0), SenseInfo('07950090-n', 0), SenseInfo('05516848-n', 0), SenseInfo('03972799-n', 0) ],
"_mexican_n_1_rel" : [ SenseInfo('09722658-n', 17) ],
"_attorneys_a_1_rel" : [  ],
"_or+whatever_a_1_rel" : [  ],
"_speck_n_1_rel" : [ SenseInfo('04681230-n', 2), SenseInfo('14585519-n', 1), SenseInfo('13774115-n', 1) ],
"_persistence_n_1_rel" : [ SenseInfo('05054130-n', 5), SenseInfo('04864515-n', 2), SenseInfo('01021579-n', 0) ],
"_hobnail_n_1_rel" : [ SenseInfo('03523849-n', 0) ],
"_interbank_a_1_rel" : [  ],
"_shut_v_off_rel" : [ SenseInfo('01345109-v', 10), SenseInfo('01346978-v', 2), SenseInfo('02449340-v', 1), SenseInfo('01345109-v', 10), SenseInfo('01346978-v', 2), SenseInfo('02449340-v', 1) ],
"_clasp_v_1_rel" : [ SenseInfo('01216522-v', 4), SenseInfo('01548576-v', 0), SenseInfo('01548290-v', 0), SenseInfo('01222328-v', 0) ],
"_delight_v_1_rel" : [ SenseInfo('01815628-v', 5), SenseInfo('01190948-v', 3), SenseInfo('01817314-v', 0), SenseInfo('01815628-v', 5), SenseInfo('01190948-v', 3), SenseInfo('01817314-v', 0), SenseInfo('01815628-v', 5), SenseInfo('01190948-v', 3), SenseInfo('01817314-v', 0) ],
"_infantry_n_1_rel" : [ SenseInfo('08390157-n', 13) ],
"_rollerlike_a_1_rel" : [  ],
"_phase_v_out_rel" : [ SenseInfo('01648894-v', 0), SenseInfo('00394381-v', 0), SenseInfo('01648894-v', 0), SenseInfo('00394381-v', 0) ],
"_woodworking_n_1_rel" : [ SenseInfo('00607775-n', 0) ],
"_turn_v_off_rel" : [ SenseInfo('01907258-v', 187), SenseInfo('00146138-v', 21), SenseInfo('02626604-v', 12), SenseInfo('02089984-v', 8), SenseInfo('00138508-v', 7), SenseInfo('01909812-v', 5), SenseInfo('00125841-v', 5), SenseInfo('01436518-v', 2), SenseInfo('02096167-v', 1), SenseInfo('02089420-v', 1), SenseInfo('01952208-v', 1), SenseInfo('01741864-v', 1), SenseInfo('01584450-v', 1), SenseInfo('00282523-v', 1), SenseInfo('00091124-v', 1), SenseInfo('02626934-v', 0), SenseInfo('02562425-v', 0), SenseInfo('02211948-v', 0), SenseInfo('02090435-v', 0), SenseInfo('01951937-v', 0), SenseInfo('01280014-v', 0), SenseInfo('01225215-v', 0), SenseInfo('01151889-v', 0), SenseInfo('00794640-v', 0), SenseInfo('00458471-v', 0), SenseInfo('00248387-v', 0), SenseInfo('01907258-v', 187), SenseInfo('00146138-v', 21), SenseInfo('02626604-v', 12), SenseInfo('02089984-v', 8), SenseInfo('00138508-v', 7), SenseInfo('01909812-v', 5), SenseInfo('00125841-v', 5), SenseInfo('01436518-v', 2), SenseInfo('02096167-v', 1), SenseInfo('02089420-v', 1), SenseInfo('01952208-v', 1), SenseInfo('01741864-v', 1), SenseInfo('01584450-v', 1), SenseInfo('00282523-v', 1), SenseInfo('00091124-v', 1), SenseInfo('02626934-v', 0), SenseInfo('02562425-v', 0), SenseInfo('02211948-v', 0), SenseInfo('02090435-v', 0), SenseInfo('01951937-v', 0), SenseInfo('01280014-v', 0), SenseInfo('01225215-v', 0), SenseInfo('01151889-v', 0), SenseInfo('00794640-v', 0), SenseInfo('00458471-v', 0), SenseInfo('00248387-v', 0) ],
"_loyal_a_to_rel" : [ SenseInfo('00961392-a', 6), SenseInfo('01740207-a', 0), SenseInfo('00959244-a', 0) ],
"_demand_n_1_rel" : [ SenseInfo('07191279-n', 22), SenseInfo('13461162-n', 9), SenseInfo('05892651-n', 6), SenseInfo('01061333-n', 3), SenseInfo('14449126-n', 1), SenseInfo('07191279-n', 22), SenseInfo('13461162-n', 9), SenseInfo('05892651-n', 6), SenseInfo('01061333-n', 3), SenseInfo('14449126-n', 1), SenseInfo('07191279-n', 22), SenseInfo('13461162-n', 9), SenseInfo('05892651-n', 6), SenseInfo('01061333-n', 3), SenseInfo('14449126-n', 1), SenseInfo('07191279-n', 22), SenseInfo('13461162-n', 9), SenseInfo('05892651-n', 6), SenseInfo('01061333-n', 3), SenseInfo('14449126-n', 1), SenseInfo('07191279-n', 22), SenseInfo('13461162-n', 9), SenseInfo('05892651-n', 6), SenseInfo('01061333-n', 3), SenseInfo('14449126-n', 1) ],
"_slit_v_1_rel" : [ SenseInfo('01559055-v', 1), SenseInfo('01558883-v', 1) ],
"_numeral_n_1_rel" : [ SenseInfo('06807198-n', 0) ],
"_intravenous_a_1_rel" : [ SenseInfo('02890703-a', 0), SenseInfo('02890703-a', 0) ],
"_vent_v_1_rel" : [ SenseInfo('00944548-v', 3), SenseInfo('00488770-v', 0) ],
"_live_v_up_rel" : [ SenseInfo('02649830-v', 129), SenseInfo('02614387-v', 51), SenseInfo('02618149-v', 29), SenseInfo('02616713-v', 16), SenseInfo('02614181-v', 14), SenseInfo('00596644-v', 1), SenseInfo('02614970-v', 0) ],
"_storm_n_1_rel" : [ SenseInfo('11462526-n', 8), SenseInfo('13978344-n', 3), SenseInfo('00974630-n', 0) ],
"_titanic_a_1_rel" : [ SenseInfo('01390683-a', 1) ],
"_tactical_a_1_rel" : [ SenseInfo('02951000-a', 0) ],
"_drain_v_of_rel" : [ SenseInfo('02071457-v', 2), SenseInfo('01158022-v', 1), SenseInfo('00451648-v', 1), SenseInfo('00389638-v', 0) ],
"_billionaire_n_1_rel" : [ SenseInfo('10529684-n', 0) ],
"_rush_v_through_rel" : [ SenseInfo('02058994-v', 20), SenseInfo('01119950-v', 6), SenseInfo('00459296-v', 2), SenseInfo('00459498-v', 1), SenseInfo('02059770-v', 0), SenseInfo('02059462-v', 0), SenseInfo('01644522-v', 0) ],
"_boom_v_1_rel" : [ SenseInfo('02187510-v', 5), SenseInfo('01401772-v', 1), SenseInfo('02770535-v', 0), SenseInfo('02174662-v', 0), SenseInfo('00310386-v', 0) ],
"_unhitch_v_1_rel" : [ SenseInfo('01328340-v', 2), SenseInfo('01328340-v', 2), SenseInfo('01328340-v', 2) ],
"_haul_v_off_rel" : [ SenseInfo('01454810-v', 7), SenseInfo('01452255-v', 5) ],
"_numeric_a_1_rel" : [ SenseInfo('02769933-a', 0), SenseInfo('01915586-a', 0) ],
"_leg_n_1_rel" : [ SenseInfo('05560787-n', 75), SenseInfo('05561507-n', 7), SenseInfo('03654826-n', 2), SenseInfo('13913849-n', 1), SenseInfo('07655505-n', 0), SenseInfo('03906106-n', 0), SenseInfo('03654576-n', 0), SenseInfo('00307176-n', 0), SenseInfo('00306900-n', 0) ],
"_tidewater_n_1_rel" : [ SenseInfo('09458372-n', 1), SenseInfo('09051898-n', 1) ],
"_therein_p_rel" : [ SenseInfo('00240707-r', 6) ],
"_player_n_of_rel" : [ SenseInfo('10439851-n', 20), SenseInfo('10340312-n', 3), SenseInfo('09765278-n', 1), SenseInfo('10440580-n', 0), SenseInfo('10440387-n', 0) ],
"_wealth_n_of_rel" : [ SenseInfo('14491271-n', 6), SenseInfo('05116128-n', 5), SenseInfo('13353280-n', 1), SenseInfo('13250398-n', 1) ],
"_except_x_h_rel" : [ SenseInfo('00807941-v', 1), SenseInfo('00615774-v', 1) ],
"_floe_n_1_rel" : [ SenseInfo('09309168-n', 0) ],
"_move_v_in_rel" : [ SenseInfo('01835496-v', 110), SenseInfo('01850315-v', 57), SenseInfo('01831531-v', 52), SenseInfo('01855606-v', 20), SenseInfo('02372605-v', 15), SenseInfo('00014549-v', 7), SenseInfo('00124442-v', 6), SenseInfo('02367363-v', 3), SenseInfo('01767949-v', 3), SenseInfo('01649999-v', 3), SenseInfo('01771390-v', 2), SenseInfo('02355959-v', 1), SenseInfo('00539110-v', 1), SenseInfo('02598863-v', 0), SenseInfo('01076615-v', 0), SenseInfo('00879356-v', 0), SenseInfo('01835496-v', 110), SenseInfo('01850315-v', 57), SenseInfo('01831531-v', 52), SenseInfo('01855606-v', 20), SenseInfo('02372605-v', 15), SenseInfo('00014549-v', 7), SenseInfo('00124442-v', 6), SenseInfo('02367363-v', 3), SenseInfo('01767949-v', 3), SenseInfo('01649999-v', 3), SenseInfo('01771390-v', 2), SenseInfo('02355959-v', 1), SenseInfo('00539110-v', 1), SenseInfo('02598863-v', 0), SenseInfo('01076615-v', 0), SenseInfo('00879356-v', 0) ],
"_shoot_v_1_rel" : [ SenseInfo('01137138-v', 28), SenseInfo('02484570-v', 27), SenseInfo('01134781-v', 26), SenseInfo('01002740-v', 7), SenseInfo('02096047-v', 3), SenseInfo('02061495-v', 3), SenseInfo('02055267-v', 1), SenseInfo('01597286-v', 1), SenseInfo('01003249-v', 1), SenseInfo('02768259-v', 0), SenseInfo('02123175-v', 0), SenseInfo('01585523-v', 0), SenseInfo('01519184-v', 0), SenseInfo('01437144-v', 0), SenseInfo('01195804-v', 0), SenseInfo('01084466-v', 0), SenseInfo('00985219-v', 0), SenseInfo('00647508-v', 0), SenseInfo('00357332-v', 0), SenseInfo('00086320-v', 0), SenseInfo('01137138-v', 28), SenseInfo('02484570-v', 27), SenseInfo('01134781-v', 26), SenseInfo('01002740-v', 7), SenseInfo('02096047-v', 3), SenseInfo('02061495-v', 3), SenseInfo('02055267-v', 1), SenseInfo('01597286-v', 1), SenseInfo('01003249-v', 1), SenseInfo('02768259-v', 0), SenseInfo('02123175-v', 0), SenseInfo('01585523-v', 0), SenseInfo('01519184-v', 0), SenseInfo('01437144-v', 0), SenseInfo('01195804-v', 0), SenseInfo('01084466-v', 0), SenseInfo('00985219-v', 0), SenseInfo('00647508-v', 0), SenseInfo('00357332-v', 0), SenseInfo('00086320-v', 0), SenseInfo('01137138-v', 28), SenseInfo('02484570-v', 27), SenseInfo('01134781-v', 26), SenseInfo('01002740-v', 7), SenseInfo('02096047-v', 3), SenseInfo('02061495-v', 3), SenseInfo('02055267-v', 1), SenseInfo('01597286-v', 1), SenseInfo('01003249-v', 1), SenseInfo('02768259-v', 0), SenseInfo('02123175-v', 0), SenseInfo('01585523-v', 0), SenseInfo('01519184-v', 0), SenseInfo('01437144-v', 0), SenseInfo('01195804-v', 0), SenseInfo('01084466-v', 0), SenseInfo('00985219-v', 0), SenseInfo('00647508-v', 0), SenseInfo('00357332-v', 0), SenseInfo('00086320-v', 0), SenseInfo('01137138-v', 28), SenseInfo('02484570-v', 27), SenseInfo('01134781-v', 26), SenseInfo('01002740-v', 7), SenseInfo('02096047-v', 3), SenseInfo('02061495-v', 3), SenseInfo('02055267-v', 1), SenseInfo('01597286-v', 1), SenseInfo('01003249-v', 1), SenseInfo('02768259-v', 0), SenseInfo('02123175-v', 0), SenseInfo('01585523-v', 0), SenseInfo('01519184-v', 0), SenseInfo('01437144-v', 0), SenseInfo('01195804-v', 0), SenseInfo('01084466-v', 0), SenseInfo('00985219-v', 0), SenseInfo('00647508-v', 0), SenseInfo('00357332-v', 0), SenseInfo('00086320-v', 0) ],
"_front+to+back_p_1_rel" : [  ],
"_levy_n_1_rel" : [ SenseInfo('13308864-n', 0), SenseInfo('01158064-n', 0) ],
"_discoloration_n_1_rel" : [ SenseInfo('04695176-n', 0), SenseInfo('00274707-n', 0), SenseInfo('04695176-n', 0), SenseInfo('00274707-n', 0) ],
"_operative_n_1_rel" : [ SenseInfo('10569411-n', 0), SenseInfo('10476671-n', 0) ],
"_interactive_a_1_rel" : [ SenseInfo('00623356-a', 0), SenseInfo('01946439-a', 0), SenseInfo('00623356-a', 0), SenseInfo('01946439-a', 0) ],
"_testable_a_1_rel" : [  ],
"_damaging_a_to_rel" : [ SenseInfo('01161984-a', 1), SenseInfo('00587890-a', 0) ],
"_drag_v_out_rel" : [ SenseInfo('01453433-v', 16), SenseInfo('01454810-v', 13), SenseInfo('02677797-v', 1), SenseInfo('02099544-v', 1), SenseInfo('02058756-v', 1), SenseInfo('01199009-v', 1), SenseInfo('02101789-v', 0), SenseInfo('01917845-v', 0), SenseInfo('01244692-v', 0), SenseInfo('00783689-v', 0), SenseInfo('00341757-v', 0), SenseInfo('01453433-v', 16), SenseInfo('01454810-v', 13), SenseInfo('02677797-v', 1), SenseInfo('02099544-v', 1), SenseInfo('02058756-v', 1), SenseInfo('01199009-v', 1), SenseInfo('02101789-v', 0), SenseInfo('01917845-v', 0), SenseInfo('01244692-v', 0), SenseInfo('00783689-v', 0), SenseInfo('00341757-v', 0) ],
"_bonnie_a_1_rel" : [ SenseInfo('00218440-a', 0) ],
"_pair_n_of_rel" : [ SenseInfo('07985223-n', 18), SenseInfo('13743605-n', 10), SenseInfo('07976936-n', 7), SenseInfo('07958407-n', 0) ],
"_guess_n_1_rel" : [ SenseInfo('06782680-n', 2), SenseInfo('05803938-n', 1), SenseInfo('06782680-n', 2), SenseInfo('05803938-n', 1) ],
"_frighten_v_1_rel" : [ SenseInfo('01779165-v', 10), SenseInfo('01780104-v', 1), SenseInfo('01779165-v', 10), SenseInfo('01780104-v', 1), SenseInfo('01779165-v', 10), SenseInfo('01780104-v', 1), SenseInfo('01779165-v', 10), SenseInfo('01780104-v', 1), SenseInfo('01779165-v', 10), SenseInfo('01780104-v', 1), SenseInfo('01779165-v', 10), SenseInfo('01780104-v', 1), SenseInfo('01779165-v', 10), SenseInfo('01780104-v', 1) ],
"_taunt_v_as_rel" : [ SenseInfo('00850501-v', 5), SenseInfo('00850501-v', 5), SenseInfo('00850501-v', 5) ],
"_furl_v_cause_rel" : [ SenseInfo('00435853-v', 1) ],
"_soapsud_n_1_rel" : [  ],
"_involving_a_1_rel" : [  ],
"_compare_v_1_rel" : [ SenseInfo('00652900-v', 57), SenseInfo('02729632-v', 12), SenseInfo('00653620-v', 9), SenseInfo('00982779-v', 0) ],
"_unwelcoming_a_1_rel" : [  ],
"_soft-spoken_a_1_rel" : [ SenseInfo('01456572-a', 1), SenseInfo('01456572-a', 1) ],
"_foresee_v_1_rel" : [ SenseInfo('00720808-v', 5), SenseInfo('01636221-v', 3), SenseInfo('02565491-v', 2), SenseInfo('00720808-v', 5), SenseInfo('01636221-v', 3), SenseInfo('02565491-v', 2) ],
"_serialize_v_1_rel" : [ SenseInfo('00279075-v', 0) ],
"_three+d+cinema_n_1_rel" : [  ],
"_etch_v_away_rel" : [ SenseInfo('01750421-v', 1), SenseInfo('02199119-v', 0), SenseInfo('01749790-v', 0), SenseInfo('01322223-v', 0), SenseInfo('00448110-v', 0) ],
"_shrimp_n_1_rel" : [ SenseInfo('10543544-n', 0), SenseInfo('07794159-n', 0), SenseInfo('01986806-n', 0) ],
"_say_v_about-of_rel" : [ SenseInfo('01009240-v', 1861), SenseInfo('01016002-v', 254), SenseInfo('00917300-v', 29), SenseInfo('02730813-v', 8), SenseInfo('00746718-v', 8), SenseInfo('00978549-v', 4), SenseInfo('00928959-v', 2), SenseInfo('00979870-v', 1), SenseInfo('01009821-v', 0), SenseInfo('00945499-v', 0), SenseInfo('00923197-v', 0), SenseInfo('01009240-v', 1861), SenseInfo('01016002-v', 254), SenseInfo('00917300-v', 29), SenseInfo('02730813-v', 8), SenseInfo('00746718-v', 8), SenseInfo('00978549-v', 4), SenseInfo('00928959-v', 2), SenseInfo('00979870-v', 1), SenseInfo('01009821-v', 0), SenseInfo('00945499-v', 0), SenseInfo('00923197-v', 0) ],
"_arrival_n_1_rel" : [ SenseInfo('00048225-n', 4), SenseInfo('00048374-n', 3), SenseInfo('09810166-n', 1), SenseInfo('00048225-n', 4), SenseInfo('00048374-n', 3), SenseInfo('09810166-n', 1) ],
"_talent_n_1_rel" : [ SenseInfo('05624042-n', 14), SenseInfo('10689878-n', 4) ],
"_terminate_v_cause_rel" : [ SenseInfo('00352826-v', 8), SenseInfo('02609764-v', 2), SenseInfo('02735418-v', 0), SenseInfo('02402825-v', 0) ],
"_dry_v_out_rel" : [ SenseInfo('00218475-v', 12), SenseInfo('00219403-v', 11), SenseInfo('00218475-v', 12), SenseInfo('00219403-v', 11) ],
"_report_v_to_rel" : [ SenseInfo('00965035-v', 64), SenseInfo('00966809-v', 52), SenseInfo('00965687-v', 12), SenseInfo('00965390-v', 5), SenseInfo('00967098-v', 1), SenseInfo('00965542-v', 1), SenseInfo('00965035-v', 64), SenseInfo('00966809-v', 52), SenseInfo('00965687-v', 12), SenseInfo('00965390-v', 5), SenseInfo('00967098-v', 1), SenseInfo('00965542-v', 1), SenseInfo('00965035-v', 64), SenseInfo('00966809-v', 52), SenseInfo('00965687-v', 12), SenseInfo('00965390-v', 5), SenseInfo('00967098-v', 1), SenseInfo('00965542-v', 1), SenseInfo('00965035-v', 64), SenseInfo('00966809-v', 52), SenseInfo('00965687-v', 12), SenseInfo('00965390-v', 5), SenseInfo('00967098-v', 1), SenseInfo('00965542-v', 1), SenseInfo('00965035-v', 64), SenseInfo('00966809-v', 52), SenseInfo('00965687-v', 12), SenseInfo('00965390-v', 5), SenseInfo('00967098-v', 1), SenseInfo('00965542-v', 1), SenseInfo('00965035-v', 64), SenseInfo('00966809-v', 52), SenseInfo('00965687-v', 12), SenseInfo('00965390-v', 5), SenseInfo('00967098-v', 1), SenseInfo('00965542-v', 1), SenseInfo('00965035-v', 64), SenseInfo('00966809-v', 52), SenseInfo('00965687-v', 12), SenseInfo('00965390-v', 5), SenseInfo('00967098-v', 1), SenseInfo('00965542-v', 1), SenseInfo('00965035-v', 64), SenseInfo('00966809-v', 52), SenseInfo('00965687-v', 12), SenseInfo('00965390-v', 5), SenseInfo('00967098-v', 1), SenseInfo('00965542-v', 1) ],
"_crazy_a_1_rel" : [ SenseInfo('02075321-a', 10), SenseInfo('01836766-a', 2), SenseInfo('00919984-a', 1), SenseInfo('00967897-a', 0), SenseInfo('00886448-a', 0), SenseInfo('02075321-a', 10), SenseInfo('01836766-a', 2), SenseInfo('00919984-a', 1), SenseInfo('00967897-a', 0), SenseInfo('00886448-a', 0), SenseInfo('02075321-a', 10), SenseInfo('01836766-a', 2), SenseInfo('00919984-a', 1), SenseInfo('00967897-a', 0), SenseInfo('00886448-a', 0), SenseInfo('02075321-a', 10), SenseInfo('01836766-a', 2), SenseInfo('00919984-a', 1), SenseInfo('00967897-a', 0), SenseInfo('00886448-a', 0), SenseInfo('02075321-a', 10), SenseInfo('01836766-a', 2), SenseInfo('00919984-a', 1), SenseInfo('00967897-a', 0), SenseInfo('00886448-a', 0), SenseInfo('02075321-a', 10), SenseInfo('01836766-a', 2), SenseInfo('00919984-a', 1), SenseInfo('00967897-a', 0), SenseInfo('00886448-a', 0) ],
"_whiff_n_1_rel" : [ SenseInfo('11497888-n', 1), SenseInfo('02662239-n', 0), SenseInfo('00130512-n', 0) ],
"_due+to_p_rel" : [  ],
"_not+insignificant_a_1_rel" : [ SenseInfo('01288298-a', 2), SenseInfo('01498298-a', 1), SenseInfo('01473353-a', 1), SenseInfo('02164402-a', 0) ],
"_screen_v_1_rel" : [ SenseInfo('02533109-v', 2), SenseInfo('00697419-v', 2), SenseInfo('02400378-v', 0), SenseInfo('02139883-v', 0), SenseInfo('01477538-v', 0), SenseInfo('01460785-v', 0), SenseInfo('01130169-v', 0) ],
"_turnover_n_1_rel" : [ SenseInfo('13826221-n', 2), SenseInfo('07624466-n', 0), SenseInfo('05112308-n', 0), SenseInfo('00348312-n', 0) ],
"_hollow_n_1_rel" : [ SenseInfo('13910895-n', 2), SenseInfo('09305031-n', 1), SenseInfo('09304750-n', 1) ],
"_counterpoint_n_1_rel" : [ SenseInfo('07025419-n', 2), SenseInfo('07025419-n', 2), SenseInfo('07025419-n', 2), SenseInfo('07025419-n', 2), SenseInfo('07025419-n', 2), SenseInfo('07025419-n', 2), SenseInfo('07025419-n', 2), SenseInfo('07025419-n', 2) ],
"_unhealthy_a_1_rel" : [ SenseInfo('01172889-a', 1), SenseInfo('02559534-a', 0), SenseInfo('01168845-a', 0), SenseInfo('01172889-a', 1), SenseInfo('02559534-a', 0), SenseInfo('01168845-a', 0) ],
"_unharmed_a_1_rel" : [ SenseInfo('01319712-a', 0), SenseInfo('01319712-a', 0) ],
"_medial_a_1_rel" : [ SenseInfo('00779133-a', 0), SenseInfo('00331030-a', 0) ],
"_depravity_n_1_rel" : [ SenseInfo('04850996-n', 3), SenseInfo('00746866-n', 1) ],
"_lysis_n_1_rel" : [ SenseInfo('13509843-n', 0), SenseInfo('13509528-n', 0) ],
"_cloudy_a_1_rel" : [ SenseInfo('00781974-a', 1), SenseInfo('00461311-a', 0), SenseInfo('00433529-a', 0), SenseInfo('00781974-a', 1), SenseInfo('00461311-a', 0), SenseInfo('00433529-a', 0), SenseInfo('00781974-a', 1), SenseInfo('00461311-a', 0), SenseInfo('00433529-a', 0), SenseInfo('00781974-a', 1), SenseInfo('00461311-a', 0), SenseInfo('00433529-a', 0), SenseInfo('00781974-a', 1), SenseInfo('00461311-a', 0), SenseInfo('00433529-a', 0), SenseInfo('00781974-a', 1), SenseInfo('00461311-a', 0), SenseInfo('00433529-a', 0) ],
"_date_v_from_rel" : [ SenseInfo('02485844-v', 1), SenseInfo('00735389-v', 1), SenseInfo('00619183-v', 1), SenseInfo('02486232-v', 0), SenseInfo('00734927-v', 0) ],
"_disrepair_n_1_rel" : [ SenseInfo('14560538-n', 2) ],
"_communicate_v_with_rel" : [ SenseInfo('00742320-v', 9), SenseInfo('00740577-v', 8), SenseInfo('02231661-v', 0), SenseInfo('01355518-v', 0), SenseInfo('01070102-v', 0), SenseInfo('01030678-v', 0), SenseInfo('00760402-v', 0) ],
"_chromatography_n_1_rel" : [ SenseInfo('13448778-n', 5) ],
"_dusk_n_1_rel" : [ SenseInfo('15169421-n', 5) ],
"_grab_v_1_rel" : [ SenseInfo('01439190-v', 27), SenseInfo('02304648-v', 4), SenseInfo('02099239-v', 1), SenseInfo('02358217-v', 0), SenseInfo('01350283-v', 0), SenseInfo('00737476-v', 0) ],
"_flea_n_1_rel" : [ SenseInfo('02186153-n', 1) ],
"_victorious_a_1_rel" : [ SenseInfo('02333314-a', 0), SenseInfo('00695209-a', 0) ],
"_blur_v_out_rel" : [ SenseInfo('02158034-v', 2), SenseInfo('02161758-v', 1), SenseInfo('00620673-v', 1), SenseInfo('01251928-v', 0), SenseInfo('00312990-v', 0), SenseInfo('00311113-v', 0) ],
"_interface_n_1_rel" : [ SenseInfo('03578435-n', 3), SenseInfo('06575227-n', 0), SenseInfo('05764779-n', 0), SenseInfo('03578656-n', 0) ],
"_pre-_a_ante_rel" : [  ],
"_amenable_a_to_rel" : [ SenseInfo('00696828-a', 1), SenseInfo('02362499-a', 0), SenseInfo('02361325-a', 0), SenseInfo('01997415-a', 0) ],
"_subway_n_1_rel" : [ SenseInfo('03757138-n', 3), SenseInfo('04508804-n', 0) ],
"_habituate_v_to_rel" : [ SenseInfo('01165043-v', 0), SenseInfo('00273445-v', 0), SenseInfo('01165043-v', 0), SenseInfo('00273445-v', 0) ],
"_riverbed_n_1_rel" : [ SenseInfo('09415671-n', 0) ],
"_classicism_n_1_rel" : [ SenseInfo('06154724-n', 0) ],
"_end_v_cause_rel" : [ SenseInfo('02609764-v', 53), SenseInfo('00352826-v', 29), SenseInfo('02735418-v', 10), SenseInfo('01620854-v', 0) ],
"_nah_a_1_rel" : [  ],
"_fill_v_cause_rel" : [ SenseInfo('00452512-v', 61), SenseInfo('00451838-v', 12), SenseInfo('02649042-v', 8), SenseInfo('02394183-v', 5), SenseInfo('01183573-v', 5), SenseInfo('02394081-v', 1), SenseInfo('01203893-v', 1), SenseInfo('01193721-v', 1), SenseInfo('00261533-v', 1), SenseInfo('00452512-v', 61), SenseInfo('00451838-v', 12), SenseInfo('02649042-v', 8), SenseInfo('02394183-v', 5), SenseInfo('01183573-v', 5), SenseInfo('02394081-v', 1), SenseInfo('01203893-v', 1), SenseInfo('01193721-v', 1), SenseInfo('00261533-v', 1), SenseInfo('00452512-v', 61), SenseInfo('00451838-v', 12), SenseInfo('02649042-v', 8), SenseInfo('02394183-v', 5), SenseInfo('01183573-v', 5), SenseInfo('02394081-v', 1), SenseInfo('01203893-v', 1), SenseInfo('01193721-v', 1), SenseInfo('00261533-v', 1) ],
"_after+sail_n_1_rel" : [  ],
"_parade_n_1_rel" : [ SenseInfo('08428485-n', 3), SenseInfo('08460395-n', 1), SenseInfo('00521085-n', 0) ],
"_pond_n_1_rel" : [ SenseInfo('09397391-n', 26), SenseInfo('09397391-n', 26) ],
"_expedite_v_1_rel" : [ SenseInfo('02548893-v', 2), SenseInfo('02438730-v', 0) ],
"_telescope_v_cause_rel" : [ SenseInfo('01594782-v', 1), SenseInfo('00244923-v', 0) ],
"_extracurricular_a_1_rel" : [ SenseInfo('01693425-a', 0), SenseInfo('01693311-a', 0), SenseInfo('01550779-a', 0), SenseInfo('01693425-a', 0), SenseInfo('01693311-a', 0), SenseInfo('01550779-a', 0) ],
"_riot_v_1_rel" : [ SenseInfo('02584661-v', 0), SenseInfo('02493260-v', 0) ],
"_profit_v_1_rel" : [ SenseInfo('02290461-v', 2), SenseInfo('02278830-v', 2) ],
"_tack_v_1_rel" : [ SenseInfo('01357429-v', 3), SenseInfo('01946408-v', 1), SenseInfo('01656788-v', 0), SenseInfo('01331348-v', 0), SenseInfo('01328513-v', 0), SenseInfo('00121678-v', 0), SenseInfo('01357429-v', 3), SenseInfo('01946408-v', 1), SenseInfo('01656788-v', 0), SenseInfo('01331348-v', 0), SenseInfo('01328513-v', 0), SenseInfo('00121678-v', 0) ],
"_all+out_a_1_rel" : [ SenseInfo('00521811-a', 2), SenseInfo('00521811-a', 2) ],
"_sulphate_n_1_rel" : [ SenseInfo('15063493-n', 0) ],
"_insistence_n_on_rel" : [ SenseInfo('07191777-n', 4), SenseInfo('14451349-n', 0), SenseInfo('01214557-n', 0), SenseInfo('07191777-n', 4), SenseInfo('14451349-n', 0), SenseInfo('01214557-n', 0) ],
"_cheek+by+jowl_a_1_rel" : [  ],
"_photograph_v_1_rel" : [ SenseInfo('01003249-v', 9), SenseInfo('02734653-v', 1) ],
"_immunity_n_1_rel" : [ SenseInfo('14526764-n', 5), SenseInfo('14527171-n', 0), SenseInfo('05033906-n', 0), SenseInfo('00213903-n', 0) ],
"_jalapeno_n_1_rel" : [ SenseInfo('12900987-n', 0), SenseInfo('07721678-n', 0), SenseInfo('12900987-n', 0), SenseInfo('07721678-n', 0) ],
"_chartreuse_a_1_rel" : [ SenseInfo('00373067-a', 0) ],
"_overtime_n_1_rel" : [ SenseInfo('15137194-n', 1), SenseInfo('15233989-n', 0) ],
"_wheel_n_1_rel" : [ SenseInfo('04574999-n', 12), SenseInfo('04313503-n', 5), SenseInfo('05195920-n', 0), SenseInfo('04575723-n', 0), SenseInfo('04113406-n', 0), SenseInfo('04039041-n', 0), SenseInfo('02834778-n', 0) ],
"_vinyl_n_1_rel" : [ SenseInfo('15088308-n', 1), SenseInfo('15088183-n', 0) ],
"_kilobyte_n_1_rel" : [ SenseInfo('13627681-n', 0), SenseInfo('13627516-n', 0) ],
"_hurt_n_1_rel" : [ SenseInfo('14285662-n', 6), SenseInfo('07496463-n', 1), SenseInfo('07495327-n', 0), SenseInfo('07420538-n', 0), SenseInfo('00403092-n', 0) ],
"_nodal_a_1_rel" : [  ],
"_apart_a_1_rel" : [ SenseInfo('00567860-a', 1), SenseInfo('02110161-a', 0) ],
"_pertain_v_to_rel" : [ SenseInfo('02676054-v', 9), SenseInfo('02653706-v', 1), SenseInfo('02676054-v', 9), SenseInfo('02653706-v', 1) ],
"_spruce_n_1_rel" : [ SenseInfo('11624840-n', 0), SenseInfo('11624531-n', 0) ],
"_disillusion_v_1_rel" : [ SenseInfo('01817755-v', 0), SenseInfo('01817755-v', 0) ],
"_count_v_in_rel" : [ SenseInfo('00948071-v', 23), SenseInfo('02645839-v', 7), SenseInfo('00950431-v', 4), SenseInfo('00947857-v', 3), SenseInfo('02731632-v', 2), SenseInfo('00685081-v', 2), SenseInfo('02747140-v', 0), SenseInfo('00712708-v', 0), SenseInfo('00712556-v', 0) ],
"_starve_v_1_rel" : [ SenseInfo('01188144-v', 4), SenseInfo('01187537-v', 3), SenseInfo('01187740-v', 1), SenseInfo('01188485-v', 0), SenseInfo('01187948-v', 0) ],
"_comprehensible_a_to_rel" : [ SenseInfo('00532892-a', 0) ],
"_degenerate_a_1_rel" : [ SenseInfo('01549568-a', 0) ],
"_must-see_n_1_rel" : [  ],
"_elementary_a_1_rel" : [ SenseInfo('00750296-a', 2), SenseInfo('02719685-a', 0), SenseInfo('01856238-a', 0) ],
"_worrisome_a_for_rel" : [ SenseInfo('00197447-a', 0), SenseInfo('01189386-a', 0), SenseInfo('00197447-a', 0), SenseInfo('01189386-a', 0), SenseInfo('00197447-a', 0), SenseInfo('01189386-a', 0) ],
"_lily_n_1_rel" : [ SenseInfo('12426248-n', 0) ],
"_finance_n_1_rel" : [ SenseInfo('01098698-n', 4), SenseInfo('06150633-n', 0), SenseInfo('01134037-n', 0) ],
"_contest_n_1_rel" : [ SenseInfo('07456188-n', 8), SenseInfo('01168961-n', 1) ],
"_rate_v_as_rel" : [ SenseInfo('00658052-v', 9), SenseInfo('02646227-v', 2), SenseInfo('00660971-v', 1) ],
"_moody_a_1_rel" : [ SenseInfo('01137378-a', 0), SenseInfo('00856325-a', 0), SenseInfo('01137378-a', 0), SenseInfo('00856325-a', 0), SenseInfo('01137378-a', 0), SenseInfo('00856325-a', 0), SenseInfo('01137378-a', 0), SenseInfo('00856325-a', 0) ],
"_pose_v_as_rel" : [ SenseInfo('02722663-v', 7), SenseInfo('02142775-v', 4), SenseInfo('00837288-v', 1), SenseInfo('02519183-v', 0), SenseInfo('01494310-v', 0), SenseInfo('00622384-v', 0), SenseInfo('02722663-v', 7), SenseInfo('02142775-v', 4), SenseInfo('00837288-v', 1), SenseInfo('02519183-v', 0), SenseInfo('01494310-v', 0), SenseInfo('00622384-v', 0), SenseInfo('02722663-v', 7), SenseInfo('02142775-v', 4), SenseInfo('00837288-v', 1), SenseInfo('02519183-v', 0), SenseInfo('01494310-v', 0), SenseInfo('00622384-v', 0), SenseInfo('02722663-v', 7), SenseInfo('02142775-v', 4), SenseInfo('00837288-v', 1), SenseInfo('02519183-v', 0), SenseInfo('01494310-v', 0), SenseInfo('00622384-v', 0), SenseInfo('02722663-v', 7), SenseInfo('02142775-v', 4), SenseInfo('00837288-v', 1), SenseInfo('02519183-v', 0), SenseInfo('01494310-v', 0), SenseInfo('00622384-v', 0) ],
"_terrain_n_1_rel" : [ SenseInfo('08674563-n', 2) ],
"_malevolency_n_1_rel" : [ SenseInfo('04842313-n', 1) ],
"_brigadier+general_n_1_rel" : [ SenseInfo('09875540-n', 1) ],
"_attracted_a_to_rel" : [  ],
"_stammer_n_1_rel" : [ SenseInfo('14402922-n', 0) ],
"_flake_n_1_rel" : [ SenseInfo('11509066-n', 0), SenseInfo('10042845-n', 0), SenseInfo('09222051-n', 0) ],
"_befitting_a_1_rel" : [ SenseInfo('00135092-a', 0), SenseInfo('00135092-a', 0) ],
"_once_p_rel" : [ SenseInfo('00118869-r', 98), SenseInfo('00181342-r', 28), SenseInfo('00118965-r', 21), SenseInfo('00118869-r', 98), SenseInfo('00181342-r', 28), SenseInfo('00118965-r', 21) ],
"_fragile_a_1_rel" : [ SenseInfo('00709215-a', 3), SenseInfo('00706688-a', 2), SenseInfo('02164913-a', 0) ],
"_pivot_n_1_rel" : [ SenseInfo('10436707-n', 0), SenseInfo('03951971-n', 0), SenseInfo('00342916-n', 0) ],
"_utterance_n_1_rel" : [ SenseInfo('07109847-n', 1) ],
"_stick_v_up-for_rel" : [ SenseInfo('01528069-v', 5), SenseInfo('01857392-v', 2), SenseInfo('01356750-v', 2), SenseInfo('02754032-v', 0), SenseInfo('02647798-v', 0), SenseInfo('02638845-v', 0), SenseInfo('02638630-v', 0), SenseInfo('01667969-v', 0), SenseInfo('01614581-v', 0), SenseInfo('01614426-v', 0), SenseInfo('01614235-v', 0), SenseInfo('01441993-v', 0), SenseInfo('01441793-v', 0), SenseInfo('01220885-v', 0), SenseInfo('00748084-v', 0), SenseInfo('00622384-v', 0) ],
"_steepness_n_1_rel" : [ SenseInfo('05069624-n', 0) ],
"_tire_v_out_rel" : [ SenseInfo('00076114-v', 3), SenseInfo('00075021-v', 3), SenseInfo('02280869-v', 0), SenseInfo('01821884-v', 0), SenseInfo('00076114-v', 3), SenseInfo('00075021-v', 3), SenseInfo('02280869-v', 0), SenseInfo('01821884-v', 0) ],
"_supervision_n_of_rel" : [ SenseInfo('01135529-n', 6) ],
"_meditate_v_1_rel" : [ SenseInfo('00630380-v', 4), SenseInfo('00704388-v', 0) ],
"_piece_v_together_rel" : [ SenseInfo('01590171-v', 1), SenseInfo('01656788-v', 0), SenseInfo('01294992-v', 0), SenseInfo('01174294-v', 0), SenseInfo('00261705-v', 0) ],
"_theater_n_1_rel" : [ SenseInfo('04417809-n', 7), SenseInfo('07006119-n', 3), SenseInfo('08551628-n', 0), SenseInfo('04417809-n', 7), SenseInfo('07006119-n', 3), SenseInfo('08551628-n', 0) ],
"_thanks+so+much_a_1_rel" : [  ],
"_base_n_1_rel" : [ SenseInfo('02798290-n', 4), SenseInfo('03387016-n', 3), SenseInfo('02797881-n', 3), SenseInfo('09215315-n', 2), SenseInfo('08511777-n', 2), SenseInfo('06658118-n', 2), SenseInfo('05793554-n', 2), SenseInfo('02797692-n', 2), SenseInfo('14964590-n', 0), SenseInfo('14618253-n', 0), SenseInfo('13897837-n', 0), SenseInfo('13809769-n', 0), SenseInfo('13597794-n', 0), SenseInfo('08490402-n', 0), SenseInfo('08013845-n', 0), SenseInfo('06300193-n', 0), SenseInfo('03569964-n', 0), SenseInfo('02798769-n', 0), SenseInfo('02798574-n', 0), SenseInfo('02798117-n', 0), SenseInfo('02798290-n', 4), SenseInfo('03387016-n', 3), SenseInfo('02797881-n', 3), SenseInfo('09215315-n', 2), SenseInfo('08511777-n', 2), SenseInfo('06658118-n', 2), SenseInfo('05793554-n', 2), SenseInfo('02797692-n', 2), SenseInfo('14964590-n', 0), SenseInfo('14618253-n', 0), SenseInfo('13897837-n', 0), SenseInfo('13809769-n', 0), SenseInfo('13597794-n', 0), SenseInfo('08490402-n', 0), SenseInfo('08013845-n', 0), SenseInfo('06300193-n', 0), SenseInfo('03569964-n', 0), SenseInfo('02798769-n', 0), SenseInfo('02798574-n', 0), SenseInfo('02798117-n', 0), SenseInfo('02798290-n', 4), SenseInfo('03387016-n', 3), SenseInfo('02797881-n', 3), SenseInfo('09215315-n', 2), SenseInfo('08511777-n', 2), SenseInfo('06658118-n', 2), SenseInfo('05793554-n', 2), SenseInfo('02797692-n', 2), SenseInfo('14964590-n', 0), SenseInfo('14618253-n', 0), SenseInfo('13897837-n', 0), SenseInfo('13809769-n', 0), SenseInfo('13597794-n', 0), SenseInfo('08490402-n', 0), SenseInfo('08013845-n', 0), SenseInfo('06300193-n', 0), SenseInfo('03569964-n', 0), SenseInfo('02798769-n', 0), SenseInfo('02798574-n', 0), SenseInfo('02798117-n', 0), SenseInfo('02798290-n', 4), SenseInfo('03387016-n', 3), SenseInfo('02797881-n', 3), SenseInfo('09215315-n', 2), SenseInfo('08511777-n', 2), SenseInfo('06658118-n', 2), SenseInfo('05793554-n', 2), SenseInfo('02797692-n', 2), SenseInfo('14964590-n', 0), SenseInfo('14618253-n', 0), SenseInfo('13897837-n', 0), SenseInfo('13809769-n', 0), SenseInfo('13597794-n', 0), SenseInfo('08490402-n', 0), SenseInfo('08013845-n', 0), SenseInfo('06300193-n', 0), SenseInfo('03569964-n', 0), SenseInfo('02798769-n', 0), SenseInfo('02798574-n', 0), SenseInfo('02798117-n', 0) ],
"_concerted_a_1_rel" : [ SenseInfo('02112108-a', 1) ],
"_item_n_of_rel" : [ SenseInfo('06482401-n', 31), SenseInfo('13809920-n', 16), SenseInfo('03588414-n', 16), SenseInfo('05817845-n', 2), SenseInfo('06795746-n', 0) ],
"_draw_v_away_rel" : [ SenseInfo('01448100-v', 13), SenseInfo('02293148-v', 10), SenseInfo('01582645-v', 10), SenseInfo('00730758-v', 10), SenseInfo('01995211-v', 9), SenseInfo('01690294-v', 7), SenseInfo('01854132-v', 6), SenseInfo('00987071-v', 6), SenseInfo('00675901-v', 6), SenseInfo('01760300-v', 5), SenseInfo('01199009-v', 5), SenseInfo('02088107-v', 4), SenseInfo('02311387-v', 3), SenseInfo('01078050-v', 3), SenseInfo('01643297-v', 2), SenseInfo('00556593-v', 2), SenseInfo('02097800-v', 1), SenseInfo('01690816-v', 1), SenseInfo('01643464-v', 1), SenseInfo('01243148-v', 1), SenseInfo('02742107-v', 0), SenseInfo('02628832-v', 0), SenseInfo('02483564-v', 0), SenseInfo('02103162-v', 0), SenseInfo('01539063-v', 0), SenseInfo('01505254-v', 0), SenseInfo('01359432-v', 0), SenseInfo('01243298-v', 0), SenseInfo('01212230-v', 0), SenseInfo('01115190-v', 0), SenseInfo('00476965-v', 0), SenseInfo('00430808-v', 0), SenseInfo('00327982-v', 0), SenseInfo('00197590-v', 0), SenseInfo('00143338-v', 0), SenseInfo('00097029-v', 0), SenseInfo('01448100-v', 13), SenseInfo('02293148-v', 10), SenseInfo('01582645-v', 10), SenseInfo('00730758-v', 10), SenseInfo('01995211-v', 9), SenseInfo('01690294-v', 7), SenseInfo('01854132-v', 6), SenseInfo('00987071-v', 6), SenseInfo('00675901-v', 6), SenseInfo('01760300-v', 5), SenseInfo('01199009-v', 5), SenseInfo('02088107-v', 4), SenseInfo('02311387-v', 3), SenseInfo('01078050-v', 3), SenseInfo('01643297-v', 2), SenseInfo('00556593-v', 2), SenseInfo('02097800-v', 1), SenseInfo('01690816-v', 1), SenseInfo('01643464-v', 1), SenseInfo('01243148-v', 1), SenseInfo('02742107-v', 0), SenseInfo('02628832-v', 0), SenseInfo('02483564-v', 0), SenseInfo('02103162-v', 0), SenseInfo('01539063-v', 0), SenseInfo('01505254-v', 0), SenseInfo('01359432-v', 0), SenseInfo('01243298-v', 0), SenseInfo('01212230-v', 0), SenseInfo('01115190-v', 0), SenseInfo('00476965-v', 0), SenseInfo('00430808-v', 0), SenseInfo('00327982-v', 0), SenseInfo('00197590-v', 0), SenseInfo('00143338-v', 0), SenseInfo('00097029-v', 0) ],
"_ceramics_n_1_rel" : [ SenseInfo('02997391-n', 0) ],
"_generic_a_1_rel" : [ SenseInfo('02734016-a', 0), SenseInfo('01109599-a', 0), SenseInfo('01102164-a', 0) ],
"_mail_v_in_rel" : [ SenseInfo('01437888-v', 12), SenseInfo('01031256-v', 0) ],
"_quick_n_1_rel" : [ SenseInfo('05597980-n', 0) ],
"_rv_n_1_rel" : [ SenseInfo('04065272-n', 0), SenseInfo('04065272-n', 0) ],
"_a+little+bit_x_deg_rel" : [  ],
"_scrubby_a_1_rel" : [ SenseInfo('02574294-a', 0), SenseInfo('02347915-a', 0), SenseInfo('02574294-a', 0), SenseInfo('02347915-a', 0), SenseInfo('02574294-a', 0), SenseInfo('02347915-a', 0) ],
"_bleep_v_out_rel" : [ SenseInfo('02187171-v', 0) ],
"_simmer_v_down_rel" : [ SenseInfo('00324231-v', 5) ],
"_all+year+long_a_1_rel" : [  ],
"_main_a_1_rel" : [ SenseInfo('01277426-a', 33), SenseInfo('00730215-a', 0), SenseInfo('01512527-a', 0), SenseInfo('01277426-a', 33), SenseInfo('00730215-a', 0), SenseInfo('01512527-a', 0), SenseInfo('01277426-a', 33), SenseInfo('00730215-a', 0), SenseInfo('01512527-a', 0), SenseInfo('01277426-a', 33), SenseInfo('00730215-a', 0), SenseInfo('01512527-a', 0) ],
"_turn_v_on_rel" : [ SenseInfo('01907258-v', 187), SenseInfo('00146138-v', 21), SenseInfo('02626604-v', 12), SenseInfo('02089984-v', 8), SenseInfo('00138508-v', 7), SenseInfo('01909812-v', 5), SenseInfo('00125841-v', 5), SenseInfo('01436518-v', 2), SenseInfo('02096167-v', 1), SenseInfo('02089420-v', 1), SenseInfo('01952208-v', 1), SenseInfo('01741864-v', 1), SenseInfo('01584450-v', 1), SenseInfo('00282523-v', 1), SenseInfo('00091124-v', 1), SenseInfo('02626934-v', 0), SenseInfo('02562425-v', 0), SenseInfo('02211948-v', 0), SenseInfo('02090435-v', 0), SenseInfo('01951937-v', 0), SenseInfo('01280014-v', 0), SenseInfo('01225215-v', 0), SenseInfo('01151889-v', 0), SenseInfo('00794640-v', 0), SenseInfo('00458471-v', 0), SenseInfo('00248387-v', 0), SenseInfo('01907258-v', 187), SenseInfo('00146138-v', 21), SenseInfo('02626604-v', 12), SenseInfo('02089984-v', 8), SenseInfo('00138508-v', 7), SenseInfo('01909812-v', 5), SenseInfo('00125841-v', 5), SenseInfo('01436518-v', 2), SenseInfo('02096167-v', 1), SenseInfo('02089420-v', 1), SenseInfo('01952208-v', 1), SenseInfo('01741864-v', 1), SenseInfo('01584450-v', 1), SenseInfo('00282523-v', 1), SenseInfo('00091124-v', 1), SenseInfo('02626934-v', 0), SenseInfo('02562425-v', 0), SenseInfo('02211948-v', 0), SenseInfo('02090435-v', 0), SenseInfo('01951937-v', 0), SenseInfo('01280014-v', 0), SenseInfo('01225215-v', 0), SenseInfo('01151889-v', 0), SenseInfo('00794640-v', 0), SenseInfo('00458471-v', 0), SenseInfo('00248387-v', 0) ],
"_po+plus_n_1_rel" : [  ],
"_sparse_a_1_rel" : [ SenseInfo('00542359-a', 3), SenseInfo('00542359-a', 3), SenseInfo('00542359-a', 3), SenseInfo('00542359-a', 3) ],
"_battle_v_against_rel" : [ SenseInfo('01092366-v', 6) ],
"_unborn_n_1_rel" : [ SenseInfo('01733661-a', 1) ],
"_doctors_a_1_rel" : [  ],
"_summation_n_of_rel" : [ SenseInfo('06469874-n', 1), SenseInfo('13563139-n', 0), SenseInfo('07959016-n', 0), SenseInfo('00872107-n', 0) ],
"_void_v_1_rel" : [ SenseInfo('02478059-v', 0), SenseInfo('00450303-v', 0), SenseInfo('00448440-v', 0), SenseInfo('00073343-v', 0) ],
"_wail_n_1_rel" : [ SenseInfo('07211950-n', 2) ],
"_statement_n_of_rel" : [ SenseInfo('06722453-n', 58), SenseInfo('06648724-n', 10), SenseInfo('07029819-n', 1), SenseInfo('06723452-n', 1), SenseInfo('07203126-n', 0), SenseInfo('06584891-n', 0), SenseInfo('06516595-n', 0), SenseInfo('06722453-n', 58), SenseInfo('06648724-n', 10), SenseInfo('07029819-n', 1), SenseInfo('06723452-n', 1), SenseInfo('07203126-n', 0), SenseInfo('06584891-n', 0), SenseInfo('06516595-n', 0) ],
"_aft_a_1_rel" : [ SenseInfo('01033371-a', 0) ],
"_stand-in_n_1_rel" : [ SenseInfo('10648237-n', 0), SenseInfo('10648237-n', 0) ],
"_mousse_v_1_rel" : [ SenseInfo('00039950-v', 0) ],
"_sear_v_1_rel" : [ SenseInfo('00377715-v', 2), SenseInfo('00582743-v', 0), SenseInfo('00379440-v', 0), SenseInfo('00218330-v', 0) ],
"_magnetism_n_1_rel" : [ SenseInfo('11479058-n', 6), SenseInfo('06120769-n', 0) ],
"_supplement_v_1_rel" : [ SenseInfo('02342132-v', 10), SenseInfo('02752931-v', 0), SenseInfo('01328705-v', 0), SenseInfo('02342132-v', 10), SenseInfo('02752931-v', 0), SenseInfo('01328705-v', 0) ],
"_prime_a_1_rel" : [ SenseInfo('01012990-a', 6), SenseInfo('01013171-a', 3), SenseInfo('02342899-a', 2), SenseInfo('03012209-a', 0), SenseInfo('01489557-a', 0) ],
"_bid_v_on_rel" : [ SenseInfo('02298632-v', 6), SenseInfo('00902932-v', 3), SenseInfo('00759657-v', 3), SenseInfo('02300060-v', 1), SenseInfo('02240674-v', 1), SenseInfo('00793580-v', 1) ],
"_conceive_v_of_rel" : [ SenseInfo('01633343-v', 21), SenseInfo('00689344-v', 10), SenseInfo('00054285-v', 2) ],
"_cordage_n_1_rel" : [ SenseInfo('13579829-n', 0), SenseInfo('03107046-n', 0) ],
"_pollock_n_1_rel" : [ SenseInfo('11241106-n', 0), SenseInfo('07789240-n', 0), SenseInfo('02524202-n', 0) ],
"_bract_n_1_rel" : [ SenseInfo('13154841-n', 0) ],
"_mission_n_1_rel" : [ SenseInfo('08403225-n', 18), SenseInfo('00970645-n', 8), SenseInfo('00731222-n', 8), SenseInfo('00730984-n', 7), SenseInfo('08402442-n', 0) ],
"_self-esteem_n_1_rel" : [ SenseInfo('07508705-n', 3), SenseInfo('07508705-n', 3), SenseInfo('07508705-n', 3), SenseInfo('07508705-n', 3) ],
"_nominee_n_1_rel" : [ SenseInfo('09889691-n', 0) ],
"_double_v_cause_rel" : [ SenseInfo('00246217-v', 12), SenseInfo('01409523-v', 2), SenseInfo('02063309-v', 1), SenseInfo('01525505-v', 1), SenseInfo('02300425-v', 0), SenseInfo('01734502-v', 0) ],
"_undersheriff_n_1_rel" : [  ],
"_vexation_n_1_rel" : [ SenseInfo('07518261-n', 1), SenseInfo('14406573-n', 0), SenseInfo('05832264-n', 0), SenseInfo('00418394-n', 0) ],
"_abb_n_1_rel" : [ SenseInfo('08011266-n', 0) ],
"_swan_v_1_rel" : [ SenseInfo('01011031-v', 1), SenseInfo('01881180-v', 0), SenseInfo('01869893-v', 0) ],
"_graduate_v_1_rel" : [ SenseInfo('02264397-v', 7), SenseInfo('02264179-v', 3), SenseInfo('00295697-v', 0) ],
"_spokesman_n_1_rel" : [ SenseInfo('10638310-n', 1) ],
"_dump_v_out_rel" : [ SenseInfo('02225204-v', 12), SenseInfo('02224945-v', 1), SenseInfo('02350878-v', 0), SenseInfo('01977545-v', 0), SenseInfo('01977080-v', 0), SenseInfo('01412346-v', 0) ],
"_conversion_n_of_rel" : [ SenseInfo('07415730-n', 9), SenseInfo('05802912-n', 3), SenseInfo('00189106-n', 2), SenseInfo('00094788-n', 1), SenseInfo('13452947-n', 0), SenseInfo('07355194-n', 0), SenseInfo('07102483-n', 0), SenseInfo('01093380-n', 0), SenseInfo('00400083-n', 0) ],
"_true_a_of_rel" : [ SenseInfo('02460502-a', 83), SenseInfo('00023120-a', 3), SenseInfo('00959530-a', 2), SenseInfo('01225398-a', 0), SenseInfo('02469756-a', 0), SenseInfo('02465519-a', 0), SenseInfo('02180277-a', 0), SenseInfo('01938508-a', 0), SenseInfo('01470649-a', 0), SenseInfo('01407267-a', 0), SenseInfo('01163759-a', 0), SenseInfo('00911204-a', 0), SenseInfo('02460502-a', 83), SenseInfo('00023120-a', 3), SenseInfo('00959530-a', 2), SenseInfo('01225398-a', 0), SenseInfo('02469756-a', 0), SenseInfo('02465519-a', 0), SenseInfo('02180277-a', 0), SenseInfo('01938508-a', 0), SenseInfo('01470649-a', 0), SenseInfo('01407267-a', 0), SenseInfo('01163759-a', 0), SenseInfo('00911204-a', 0), SenseInfo('02460502-a', 83), SenseInfo('00023120-a', 3), SenseInfo('00959530-a', 2), SenseInfo('01225398-a', 0), SenseInfo('02469756-a', 0), SenseInfo('02465519-a', 0), SenseInfo('02180277-a', 0), SenseInfo('01938508-a', 0), SenseInfo('01470649-a', 0), SenseInfo('01407267-a', 0), SenseInfo('01163759-a', 0), SenseInfo('00911204-a', 0) ],
"_review_n_of_rel" : [ SenseInfo('05747582-n', 4), SenseInfo('06410391-n', 2), SenseInfo('00143251-n', 1), SenseInfo('13411533-n', 0), SenseInfo('07019866-n', 0), SenseInfo('06597758-n', 0), SenseInfo('06469377-n', 0), SenseInfo('01197258-n', 0), SenseInfo('00897811-n', 0), SenseInfo('00879271-n', 0) ],
"_nook_n_1_rel" : [ SenseInfo('08643648-n', 0), SenseInfo('03109881-n', 0) ],
"_beacon_n_1_rel" : [ SenseInfo('07264213-n', 1), SenseInfo('04041930-n', 0), SenseInfo('02814860-n', 0) ],
"_break_v_even_rel" : [ SenseInfo('00364064-v', 15), SenseInfo('00334186-v', 13), SenseInfo('00258665-v', 9), SenseInfo('01369758-v', 8), SenseInfo('00334996-v', 8), SenseInfo('02566528-v', 5), SenseInfo('02073233-v', 4), SenseInfo('02029369-v', 4), SenseInfo('01785395-v', 4), SenseInfo('00362348-v', 4), SenseInfo('02570684-v', 3), SenseInfo('00202569-v', 3), SenseInfo('02668523-v', 2), SenseInfo('01106864-v', 2), SenseInfo('00933821-v', 2), SenseInfo('00558536-v', 2), SenseInfo('00434374-v', 2), SenseInfo('02535716-v', 1), SenseInfo('02030764-v', 1), SenseInfo('01972976-v', 1), SenseInfo('00390215-v', 1), SenseInfo('00202784-v', 1), SenseInfo('02746617-v', 0), SenseInfo('02746449-v', 0), SenseInfo('02681639-v', 0), SenseInfo('02681524-v', 0), SenseInfo('02625187-v', 0), SenseInfo('02600082-v', 0), SenseInfo('02559395-v', 0), SenseInfo('02478469-v', 0), SenseInfo('02431320-v', 0), SenseInfo('02399331-v', 0), SenseInfo('02318165-v', 0), SenseInfo('02101373-v', 0), SenseInfo('01991347-v', 0), SenseInfo('01989053-v', 0), SenseInfo('01896484-v', 0), SenseInfo('01610666-v', 0), SenseInfo('01610463-v', 0), SenseInfo('01597995-v', 0), SenseInfo('01557646-v', 0), SenseInfo('01369346-v', 0), SenseInfo('01298931-v', 0), SenseInfo('01228524-v', 0), SenseInfo('01228396-v', 0), SenseInfo('00935987-v', 0), SenseInfo('00779061-v', 0), SenseInfo('00778745-v', 0), SenseInfo('00744439-v', 0), SenseInfo('00738440-v', 0), SenseInfo('00738314-v', 0), SenseInfo('00551412-v', 0), SenseInfo('00339464-v', 0), SenseInfo('00336260-v', 0), SenseInfo('00258366-v', 0), SenseInfo('00155046-v', 0), SenseInfo('00107739-v', 0), SenseInfo('00107604-v', 0), SenseInfo('00030463-v', 0) ],
"_invulnerable_a_to_rel" : [ SenseInfo('02525206-a', 1) ],
"_absurd_a_for_rel" : [ SenseInfo('01431112-a', 7), SenseInfo('02570643-a', 1), SenseInfo('01431112-a', 7), SenseInfo('02570643-a', 1), SenseInfo('01431112-a', 7), SenseInfo('02570643-a', 1) ],
"_proximal_a_1_rel" : [ SenseInfo('00778509-a', 2) ],
"_case+in+point_n_1_rel" : [ SenseInfo('05821486-n', 2) ],
"_constant_a_1_rel" : [ SenseInfo('02506029-a', 14), SenseInfo('00583239-a', 2), SenseInfo('00595299-a', 0), SenseInfo('02506029-a', 14), SenseInfo('00583239-a', 2), SenseInfo('00595299-a', 0) ],
"_robe_n_1_rel" : [ SenseInfo('04097866-n', 3), SenseInfo('03450516-n', 1) ],
"_nationalize_v_1_rel" : [ SenseInfo('00411547-v', 2), SenseInfo('00578295-v', 0) ],
"_quadruped_n_1_rel" : [ SenseInfo('02156871-n', 0) ],
"_pajamas_n_1_rel" : [ SenseInfo('03877674-n', 0), SenseInfo('03877472-n', 0), SenseInfo('03877674-n', 0), SenseInfo('03877472-n', 0) ],
"_pucker_v_1_rel" : [ SenseInfo('01278817-v', 3), SenseInfo('01330822-v', 0), SenseInfo('01279015-v', 0) ],
"_countertop_n_1_rel" : [ SenseInfo('03118245-n', 0) ],
"_literature_n_1_rel" : [ SenseInfo('06364641-n', 60), SenseInfo('06169488-n', 6), SenseInfo('06365102-n', 5), SenseInfo('00610592-n', 2) ],
"_pivotal_a_1_rel" : [ SenseInfo('00656507-a', 0) ],
"_unhappy_a_1_rel" : [ SenseInfo('01149494-a', 6), SenseInfo('00909363-a', 1), SenseInfo('01805064-a', 0), SenseInfo('01051814-a', 0), SenseInfo('01149494-a', 6), SenseInfo('00909363-a', 1), SenseInfo('01805064-a', 0), SenseInfo('01051814-a', 0), SenseInfo('01149494-a', 6), SenseInfo('00909363-a', 1), SenseInfo('01805064-a', 0), SenseInfo('01051814-a', 0), SenseInfo('01149494-a', 6), SenseInfo('00909363-a', 1), SenseInfo('01805064-a', 0), SenseInfo('01051814-a', 0), SenseInfo('01149494-a', 6), SenseInfo('00909363-a', 1), SenseInfo('01805064-a', 0), SenseInfo('01051814-a', 0), SenseInfo('01149494-a', 6), SenseInfo('00909363-a', 1), SenseInfo('01805064-a', 0), SenseInfo('01051814-a', 0), SenseInfo('01149494-a', 6), SenseInfo('00909363-a', 1), SenseInfo('01805064-a', 0), SenseInfo('01051814-a', 0), SenseInfo('01149494-a', 6), SenseInfo('00909363-a', 1), SenseInfo('01805064-a', 0), SenseInfo('01051814-a', 0), SenseInfo('01149494-a', 6), SenseInfo('00909363-a', 1), SenseInfo('01805064-a', 0), SenseInfo('01051814-a', 0) ],
"_papa_n_1_rel" : [ SenseInfo('09988063-n', 23) ],
"_topsoil_n_1_rel" : [ SenseInfo('14695737-n', 1) ],
"_specially_x_deg_rel" : [ SenseInfo('00502710-r', 3), SenseInfo('00084223-r', 2) ],
"_worshiper_n_1_rel" : [ SenseInfo('10792335-n', 0), SenseInfo('09847727-n', 0) ],
"_nerd_n_1_rel" : [ SenseInfo('10684630-n', 0), SenseInfo('10353598-n', 0) ],
"_time-elapsed_a_1_rel" : [  ],
"_excrete_v_1_rel" : [ SenseInfo('00072989-v', 0) ],
"_mer_n_1_rel" : [  ],
"_used_a_1_rel" : [ SenseInfo('02494923-a', 4), SenseInfo('02495687-a', 1), SenseInfo('01640482-a', 1) ],
"_aversion_n_to_rel" : [ SenseInfo('07502669-n', 1), SenseInfo('00204022-n', 0) ],
"_lavish_v_on_rel" : [ SenseInfo('02264601-v', 2), SenseInfo('02264601-v', 2) ],
"_examine_v_1_rel" : [ SenseInfo('00644583-v', 17), SenseInfo('02131279-v', 11), SenseInfo('00788564-v', 7), SenseInfo('00786816-v', 2), SenseInfo('02531625-v', 1), SenseInfo('00644583-v', 17), SenseInfo('02131279-v', 11), SenseInfo('00788564-v', 7), SenseInfo('00786816-v', 2), SenseInfo('02531625-v', 1) ],
"_clap_n_1_rel" : [ SenseInfo('07376257-n', 2), SenseInfo('14133543-n', 0), SenseInfo('07379963-n', 0) ],
"_break_v_open_rel" : [ SenseInfo('00364064-v', 15), SenseInfo('00334186-v', 13), SenseInfo('00258665-v', 9), SenseInfo('01369758-v', 8), SenseInfo('00334996-v', 8), SenseInfo('02566528-v', 5), SenseInfo('02073233-v', 4), SenseInfo('02029369-v', 4), SenseInfo('01785395-v', 4), SenseInfo('00362348-v', 4), SenseInfo('02570684-v', 3), SenseInfo('00202569-v', 3), SenseInfo('02668523-v', 2), SenseInfo('01106864-v', 2), SenseInfo('00933821-v', 2), SenseInfo('00558536-v', 2), SenseInfo('00434374-v', 2), SenseInfo('02535716-v', 1), SenseInfo('02030764-v', 1), SenseInfo('01972976-v', 1), SenseInfo('00390215-v', 1), SenseInfo('00202784-v', 1), SenseInfo('02746617-v', 0), SenseInfo('02746449-v', 0), SenseInfo('02681639-v', 0), SenseInfo('02681524-v', 0), SenseInfo('02625187-v', 0), SenseInfo('02600082-v', 0), SenseInfo('02559395-v', 0), SenseInfo('02478469-v', 0), SenseInfo('02431320-v', 0), SenseInfo('02399331-v', 0), SenseInfo('02318165-v', 0), SenseInfo('02101373-v', 0), SenseInfo('01991347-v', 0), SenseInfo('01989053-v', 0), SenseInfo('01896484-v', 0), SenseInfo('01610666-v', 0), SenseInfo('01610463-v', 0), SenseInfo('01597995-v', 0), SenseInfo('01557646-v', 0), SenseInfo('01369346-v', 0), SenseInfo('01298931-v', 0), SenseInfo('01228524-v', 0), SenseInfo('01228396-v', 0), SenseInfo('00935987-v', 0), SenseInfo('00779061-v', 0), SenseInfo('00778745-v', 0), SenseInfo('00744439-v', 0), SenseInfo('00738440-v', 0), SenseInfo('00738314-v', 0), SenseInfo('00551412-v', 0), SenseInfo('00339464-v', 0), SenseInfo('00336260-v', 0), SenseInfo('00258366-v', 0), SenseInfo('00155046-v', 0), SenseInfo('00107739-v', 0), SenseInfo('00107604-v', 0), SenseInfo('00030463-v', 0), SenseInfo('00364064-v', 15), SenseInfo('00334186-v', 13), SenseInfo('00258665-v', 9), SenseInfo('01369758-v', 8), SenseInfo('00334996-v', 8), SenseInfo('02566528-v', 5), SenseInfo('02073233-v', 4), SenseInfo('02029369-v', 4), SenseInfo('01785395-v', 4), SenseInfo('00362348-v', 4), SenseInfo('02570684-v', 3), SenseInfo('00202569-v', 3), SenseInfo('02668523-v', 2), SenseInfo('01106864-v', 2), SenseInfo('00933821-v', 2), SenseInfo('00558536-v', 2), SenseInfo('00434374-v', 2), SenseInfo('02535716-v', 1), SenseInfo('02030764-v', 1), SenseInfo('01972976-v', 1), SenseInfo('00390215-v', 1), SenseInfo('00202784-v', 1), SenseInfo('02746617-v', 0), SenseInfo('02746449-v', 0), SenseInfo('02681639-v', 0), SenseInfo('02681524-v', 0), SenseInfo('02625187-v', 0), SenseInfo('02600082-v', 0), SenseInfo('02559395-v', 0), SenseInfo('02478469-v', 0), SenseInfo('02431320-v', 0), SenseInfo('02399331-v', 0), SenseInfo('02318165-v', 0), SenseInfo('02101373-v', 0), SenseInfo('01991347-v', 0), SenseInfo('01989053-v', 0), SenseInfo('01896484-v', 0), SenseInfo('01610666-v', 0), SenseInfo('01610463-v', 0), SenseInfo('01597995-v', 0), SenseInfo('01557646-v', 0), SenseInfo('01369346-v', 0), SenseInfo('01298931-v', 0), SenseInfo('01228524-v', 0), SenseInfo('01228396-v', 0), SenseInfo('00935987-v', 0), SenseInfo('00779061-v', 0), SenseInfo('00778745-v', 0), SenseInfo('00744439-v', 0), SenseInfo('00738440-v', 0), SenseInfo('00738314-v', 0), SenseInfo('00551412-v', 0), SenseInfo('00339464-v', 0), SenseInfo('00336260-v', 0), SenseInfo('00258366-v', 0), SenseInfo('00155046-v', 0), SenseInfo('00107739-v', 0), SenseInfo('00107604-v', 0), SenseInfo('00030463-v', 0) ],
"_amount_v_to_rel" : [ SenseInfo('02664992-v', 10), SenseInfo('02645007-v', 4), SenseInfo('02627363-v', 4) ],
"_pertinency_n_1_rel" : [ SenseInfo('13795180-n', 0) ],
"_funding_n_of_rel" : [ SenseInfo('13365698-n', 0), SenseInfo('01099109-n', 0) ],
"_household_n_1_rel" : [ SenseInfo('08078020-n', 8) ],
"_annotation_n_of_rel" : [ SenseInfo('06763273-n', 0), SenseInfo('00371735-n', 0) ],
"_keep_v_up_rel" : [ SenseInfo('02681795-v', 206), SenseInfo('02684924-v', 39), SenseInfo('02202384-v', 32), SenseInfo('02450505-v', 22), SenseInfo('02578872-v', 10), SenseInfo('00732552-v', 9), SenseInfo('02202928-v', 8), SenseInfo('01065877-v', 4), SenseInfo('02651853-v', 3), SenseInfo('02410175-v', 3), SenseInfo('01184625-v', 3), SenseInfo('02734800-v', 2), SenseInfo('02578510-v', 2), SenseInfo('02422663-v', 2), SenseInfo('02733122-v', 1), SenseInfo('02652016-v', 0), SenseInfo('02283716-v', 0), SenseInfo('02204094-v', 0), SenseInfo('02203844-v', 0), SenseInfo('02203168-v', 0), SenseInfo('01302019-v', 0), SenseInfo('00212414-v', 0), SenseInfo('02681795-v', 206), SenseInfo('02684924-v', 39), SenseInfo('02202384-v', 32), SenseInfo('02450505-v', 22), SenseInfo('02578872-v', 10), SenseInfo('00732552-v', 9), SenseInfo('02202928-v', 8), SenseInfo('01065877-v', 4), SenseInfo('02651853-v', 3), SenseInfo('02410175-v', 3), SenseInfo('01184625-v', 3), SenseInfo('02734800-v', 2), SenseInfo('02578510-v', 2), SenseInfo('02422663-v', 2), SenseInfo('02733122-v', 1), SenseInfo('02652016-v', 0), SenseInfo('02283716-v', 0), SenseInfo('02204094-v', 0), SenseInfo('02203844-v', 0), SenseInfo('02203168-v', 0), SenseInfo('01302019-v', 0), SenseInfo('00212414-v', 0), SenseInfo('02681795-v', 206), SenseInfo('02684924-v', 39), SenseInfo('02202384-v', 32), SenseInfo('02450505-v', 22), SenseInfo('02578872-v', 10), SenseInfo('00732552-v', 9), SenseInfo('02202928-v', 8), SenseInfo('01065877-v', 4), SenseInfo('02651853-v', 3), SenseInfo('02410175-v', 3), SenseInfo('01184625-v', 3), SenseInfo('02734800-v', 2), SenseInfo('02578510-v', 2), SenseInfo('02422663-v', 2), SenseInfo('02733122-v', 1), SenseInfo('02652016-v', 0), SenseInfo('02283716-v', 0), SenseInfo('02204094-v', 0), SenseInfo('02203844-v', 0), SenseInfo('02203168-v', 0), SenseInfo('01302019-v', 0), SenseInfo('00212414-v', 0) ],
"_tile_v_1_rel" : [ SenseInfo('01338663-v', 0) ],
"_suit_n_of_rel" : [ SenseInfo('04350905-n', 13), SenseInfo('01182654-n', 3), SenseInfo('10673946-n', 0), SenseInfo('07188685-n', 0), SenseInfo('07188570-n', 0), SenseInfo('04351233-n', 0) ],
"_filtration_n_of_rel" : [ SenseInfo('13480667-n', 0), SenseInfo('00191980-n', 0) ],
"_drag_n_1_rel" : [ SenseInfo('11504898-n', 1), SenseInfo('05690091-n', 0), SenseInfo('05206445-n', 0), SenseInfo('03231476-n', 0), SenseInfo('00837675-n', 0), SenseInfo('00114871-n', 0), SenseInfo('11504898-n', 1), SenseInfo('05690091-n', 0), SenseInfo('05206445-n', 0), SenseInfo('03231476-n', 0), SenseInfo('00837675-n', 0), SenseInfo('00114871-n', 0) ],
"_drop-down_a_1_rel" : [  ],
"_arrange_v_with_rel" : [ SenseInfo('01463963-v', 13), SenseInfo('01021629-v', 7), SenseInfo('01648126-v', 3), SenseInfo('01745141-v', 2), SenseInfo('00038849-v', 2), SenseInfo('01706129-v', 0), SenseInfo('00735571-v', 0), SenseInfo('01463963-v', 13), SenseInfo('01021629-v', 7), SenseInfo('01648126-v', 3), SenseInfo('01745141-v', 2), SenseInfo('00038849-v', 2), SenseInfo('01706129-v', 0), SenseInfo('00735571-v', 0) ],
"_alloy_v_1_rel" : [ SenseInfo('00493517-v', 0), SenseInfo('00396880-v', 0) ],
"_orchid_a_1_rel" : [ SenseInfo('12041446-n', 1) ],
"_prominence_n_1_rel" : [ SenseInfo('14433587-n', 3), SenseInfo('05169507-n', 2), SenseInfo('13894434-n', 0) ],
"_mull_v_1_rel" : [ SenseInfo('00630380-v', 1), SenseInfo('02196540-v', 0), SenseInfo('00630380-v', 1), SenseInfo('02196540-v', 0) ],
"_lever_v_1_rel" : [ SenseInfo('01593254-v', 0), SenseInfo('01593254-v', 0) ],
"_generate_v_1_rel" : [ SenseInfo('01627355-v', 14), SenseInfo('01629000-v', 3), SenseInfo('01628197-v', 1), SenseInfo('00054628-v', 1) ],
"_affordable_a_1_rel" : [ SenseInfo('00935103-a', 0) ],
"_reflexive_n_1_rel" : [ SenseInfo('06328207-n', 0) ],
"_potent_a_1_rel" : [ SenseInfo('01830599-a', 2), SenseInfo('01826979-a', 2), SenseInfo('01824244-a', 1), SenseInfo('01825419-a', 0) ],
"_believe_v_in_rel" : [ SenseInfo('00683280-v', 118), SenseInfo('00689344-v', 72), SenseInfo('00721098-v', 37), SenseInfo('00684273-v', 10), SenseInfo('00684068-v', 2) ],
"_charter_v_1_rel" : [ SenseInfo('02460619-v', 1), SenseInfo('02447692-v', 0), SenseInfo('02208537-v', 0) ],
"_immediately_x_deg_rel" : [ SenseInfo('00048739-r', 46), SenseInfo('00504043-r', 5), SenseInfo('00504153-r', 0) ],
"_approval_n_of_rel" : [ SenseInfo('01215392-n', 11), SenseInfo('07500159-n', 3), SenseInfo('14412374-n', 1), SenseInfo('06686736-n', 0), SenseInfo('01215392-n', 11), SenseInfo('07500159-n', 3), SenseInfo('14412374-n', 1), SenseInfo('06686736-n', 0) ],
"_crouch_v_1_rel" : [ SenseInfo('02062632-v', 9), SenseInfo('01545314-v', 7) ],
"_snowflake_n_1_rel" : [ SenseInfo('11509066-n', 0), SenseInfo('01538630-n', 0) ],
"_better_a_1_rel" : [ SenseInfo('00230335-a', 69), SenseInfo('00231761-a', 23), SenseInfo('00067379-a', 8), SenseInfo('01471260-a', 0), SenseInfo('00230335-a', 69), SenseInfo('00231761-a', 23), SenseInfo('00067379-a', 8), SenseInfo('01471260-a', 0) ],
"_countdown_n_1_rel" : [ SenseInfo('00653518-n', 0) ],
"_timberland_n_1_rel" : [ SenseInfo('09284015-n', 0) ],
"_separate_a_from_rel" : [ SenseInfo('02109678-a', 20), SenseInfo('00160768-a', 2), SenseInfo('01327371-a', 0), SenseInfo('00568541-a', 0), SenseInfo('02109678-a', 20), SenseInfo('00160768-a', 2), SenseInfo('01327371-a', 0), SenseInfo('00568541-a', 0) ],
"_shooting_n_1_rel" : [ SenseInfo('00122661-n', 21), SenseInfo('00225150-n', 4) ],
"_altruistic_a_1_rel" : [ SenseInfo('00101609-a', 0) ],
"_raunchy_a_1_rel" : [ SenseInfo('02134701-a', 0), SenseInfo('00425740-a', 0), SenseInfo('00420650-a', 0), SenseInfo('02134701-a', 0), SenseInfo('00425740-a', 0), SenseInfo('00420650-a', 0), SenseInfo('02134701-a', 0), SenseInfo('00425740-a', 0), SenseInfo('00420650-a', 0) ],
"_scale_v_back_rel" : [ SenseInfo('02728388-v', 1), SenseInfo('01744082-v', 1), SenseInfo('02207036-v', 0), SenseInfo('01999082-v', 0), SenseInfo('01922466-v', 0), SenseInfo('01264148-v', 0), SenseInfo('00490428-v', 0), SenseInfo('00319406-v', 0), SenseInfo('02728388-v', 1), SenseInfo('01744082-v', 1), SenseInfo('02207036-v', 0), SenseInfo('01999082-v', 0), SenseInfo('01922466-v', 0), SenseInfo('01264148-v', 0), SenseInfo('00490428-v', 0), SenseInfo('00319406-v', 0) ],
"_watcher_n_1_rel" : [ SenseInfo('10633450-n', 1), SenseInfo('10770059-n', 0), SenseInfo('10769782-n', 0) ],
"_barrage_n_1_rel" : [ SenseInfo('07083441-n', 2), SenseInfo('00987863-n', 1) ],
"_about_x_deg_rel" : [ SenseInfo('00007015-r', 55), SenseInfo('00071840-r', 10), SenseInfo('00071165-r', 5), SenseInfo('00072329-r', 3), SenseInfo('00072201-r', 3), SenseInfo('00358114-r', 2), SenseInfo('00073033-r', 1), SenseInfo('00032358-a', 0) ],
"_pain_n_of_rel" : [ SenseInfo('14322699-n', 32), SenseInfo('07494363-n', 14), SenseInfo('05724694-n', 9), SenseInfo('10391513-n', 0), SenseInfo('05830059-n', 0), SenseInfo('14322699-n', 32), SenseInfo('07494363-n', 14), SenseInfo('05724694-n', 9), SenseInfo('10391513-n', 0), SenseInfo('05830059-n', 0), SenseInfo('14322699-n', 32), SenseInfo('07494363-n', 14), SenseInfo('05724694-n', 9), SenseInfo('10391513-n', 0), SenseInfo('05830059-n', 0) ],
"_scour_v_1_rel" : [ SenseInfo('01317276-v', 1), SenseInfo('01251228-v', 1), SenseInfo('01251651-v', 0), SenseInfo('00455529-v', 0), SenseInfo('01317276-v', 1), SenseInfo('01251228-v', 1), SenseInfo('01251651-v', 0), SenseInfo('00455529-v', 0), SenseInfo('01317276-v', 1), SenseInfo('01251228-v', 1), SenseInfo('01251651-v', 0), SenseInfo('00455529-v', 0) ],
"_bran_n_1_rel" : [ SenseInfo('14806176-n', 0), SenseInfo('07568991-n', 0) ],
"_bookstall_n_1_rel" : [ SenseInfo('02871525-n', 0) ],
"_queer_a_1_rel" : [ SenseInfo('00968010-a', 9), SenseInfo('01201937-a', 0), SenseInfo('00968010-a', 9), SenseInfo('01201937-a', 0), SenseInfo('00968010-a', 9), SenseInfo('01201937-a', 0) ],
"_sun_v_1_rel" : [ SenseInfo('00104147-v', 1), SenseInfo('02112546-v', 0) ],
"_wiggle_v_cause_rel" : [ SenseInfo('01898282-v', 5) ],
"_ask_v_for_rel" : [ SenseInfo('00784342-v', 244), SenseInfo('00752493-v', 165), SenseInfo('00784727-v', 16), SenseInfo('00755745-v', 2), SenseInfo('00897746-v', 1), SenseInfo('02627934-v', 0), SenseInfo('01068565-v', 0) ],
"_scar_v_1_rel" : [ SenseInfo('01551195-v', 0) ],
"_fuss_v_over_rel" : [ SenseInfo('01793933-v', 4), SenseInfo('02550516-v', 1) ],
"_neckerchief_n_1_rel" : [ SenseInfo('03814817-n', 0) ],
"_forbid_v_from_rel" : [ SenseInfo('00795863-v', 15), SenseInfo('02452885-v', 1) ],
"_dominance_n_of_rel" : [ SenseInfo('04998417-n', 4), SenseInfo('14441825-n', 3), SenseInfo('11413800-n', 0), SenseInfo('05196582-n', 0) ],
"_wetsuit_n_1_rel" : [  ],
"_heartbeat_n_1_rel" : [ SenseInfo('07400906-n', 2), SenseInfo('15247110-n', 0), SenseInfo('05195653-n', 0) ],
"_waterpark_n_1_rel" : [  ],
"_tiptoe_n_1_rel" : [ SenseInfo('05577304-n', 0) ],
"_veterinarian_n_1_rel" : [ SenseInfo('10749715-n', 0) ],
"_die_v_of_rel" : [ SenseInfo('00358431-v', 141), SenseInfo('02109818-v', 1), SenseInfo('01784953-v', 1), SenseInfo('00434374-v', 1), SenseInfo('01829475-v', 0), SenseInfo('01785242-v', 0), SenseInfo('01555034-v', 0), SenseInfo('01074914-v', 0), SenseInfo('00538323-v', 0), SenseInfo('00354845-v', 0), SenseInfo('00224295-v', 0) ],
"_different_a_than-from_rel" : [ SenseInfo('02064745-a', 88), SenseInfo('02070030-a', 41), SenseInfo('00490413-a', 2), SenseInfo('01410363-a', 1), SenseInfo('02070342-a', 0), SenseInfo('02064745-a', 88), SenseInfo('02070030-a', 41), SenseInfo('00490413-a', 2), SenseInfo('01410363-a', 1), SenseInfo('02070342-a', 0) ],
"_stream_n_1_rel" : [ SenseInfo('09448361-n', 20), SenseInfo('08461595-n', 4), SenseInfo('00329227-n', 3), SenseInfo('14005892-n', 2), SenseInfo('07406765-n', 2) ],
"_since_x_subord_rel" : [  ],
"_profane_v_1_rel" : [ SenseInfo('02579447-v', 0), SenseInfo('02568065-v', 0) ],
"_briefs_n_1_rel" : [ SenseInfo('06543781-n', 2), SenseInfo('06468640-n', 0), SenseInfo('06543781-n', 2), SenseInfo('06468640-n', 0) ],
"_fraud_n_1_rel" : [ SenseInfo('00769092-n', 5), SenseInfo('10201535-n', 2), SenseInfo('00753685-n', 2) ],
"_wedding_n_of_rel" : [ SenseInfo('07452074-n', 3), SenseInfo('01036996-n', 1), SenseInfo('08256735-n', 0) ],
"_culminate_v_in_rel" : [ SenseInfo('00485609-v', 8), SenseInfo('00354030-v', 1), SenseInfo('02526934-v', 0), SenseInfo('02021773-v', 0), SenseInfo('00144040-v', 0) ],
"_peer_v_1_rel" : [ SenseInfo('02168965-v', 30) ],
"_shoelace_n_1_rel" : [ SenseInfo('04200637-n', 1) ],
"_questionnaire_n_1_rel" : [ SenseInfo('06474122-n', 4) ],
"_sonuvabitch_a_1_rel" : [  ],
"_regret_v_1_rel" : [ SenseInfo('01796582-v', 8), SenseInfo('01796924-v', 2), SenseInfo('00911761-v', 1), SenseInfo('00911562-v', 1), SenseInfo('01796582-v', 8), SenseInfo('01796924-v', 2), SenseInfo('00911761-v', 1), SenseInfo('00911562-v', 1), SenseInfo('01796582-v', 8), SenseInfo('01796924-v', 2), SenseInfo('00911761-v', 1), SenseInfo('00911562-v', 1) ],
"_breakage_n_1_rel" : [ SenseInfo('13754948-n', 0), SenseInfo('13293512-n', 0), SenseInfo('00376400-n', 0) ],
"_halve_v_1_rel" : [ SenseInfo('00642357-v', 0) ],
"_filing_n_1_rel" : [ SenseInfo('07167954-n', 3), SenseInfo('09279345-n', 0), SenseInfo('00925489-n', 0), SenseInfo('00811491-n', 0) ],
"_positive_a_1_rel" : [ SenseInfo('01817500-a', 20), SenseInfo('00337172-a', 3), SenseInfo('00065064-a', 2), SenseInfo('01820481-a', 1), SenseInfo('01043505-a', 1), SenseInfo('00721838-a', 1), SenseInfo('02782815-a', 0), SenseInfo('01820103-a', 0), SenseInfo('01819692-a', 0), SenseInfo('00358678-a', 0), SenseInfo('00339288-a', 0), SenseInfo('01817500-a', 20), SenseInfo('00337172-a', 3), SenseInfo('00065064-a', 2), SenseInfo('01820481-a', 1), SenseInfo('01043505-a', 1), SenseInfo('00721838-a', 1), SenseInfo('02782815-a', 0), SenseInfo('01820103-a', 0), SenseInfo('01819692-a', 0), SenseInfo('00358678-a', 0), SenseInfo('00339288-a', 0), SenseInfo('01817500-a', 20), SenseInfo('00337172-a', 3), SenseInfo('00065064-a', 2), SenseInfo('01820481-a', 1), SenseInfo('01043505-a', 1), SenseInfo('00721838-a', 1), SenseInfo('02782815-a', 0), SenseInfo('01820103-a', 0), SenseInfo('01819692-a', 0), SenseInfo('00358678-a', 0), SenseInfo('00339288-a', 0) ],
"_break_v_down_rel" : [ SenseInfo('00364064-v', 15), SenseInfo('00334186-v', 13), SenseInfo('00258665-v', 9), SenseInfo('01369758-v', 8), SenseInfo('00334996-v', 8), SenseInfo('02566528-v', 5), SenseInfo('02073233-v', 4), SenseInfo('02029369-v', 4), SenseInfo('01785395-v', 4), SenseInfo('00362348-v', 4), SenseInfo('02570684-v', 3), SenseInfo('00202569-v', 3), SenseInfo('02668523-v', 2), SenseInfo('01106864-v', 2), SenseInfo('00933821-v', 2), SenseInfo('00558536-v', 2), SenseInfo('00434374-v', 2), SenseInfo('02535716-v', 1), SenseInfo('02030764-v', 1), SenseInfo('01972976-v', 1), SenseInfo('00390215-v', 1), SenseInfo('00202784-v', 1), SenseInfo('02746617-v', 0), SenseInfo('02746449-v', 0), SenseInfo('02681639-v', 0), SenseInfo('02681524-v', 0), SenseInfo('02625187-v', 0), SenseInfo('02600082-v', 0), SenseInfo('02559395-v', 0), SenseInfo('02478469-v', 0), SenseInfo('02431320-v', 0), SenseInfo('02399331-v', 0), SenseInfo('02318165-v', 0), SenseInfo('02101373-v', 0), SenseInfo('01991347-v', 0), SenseInfo('01989053-v', 0), SenseInfo('01896484-v', 0), SenseInfo('01610666-v', 0), SenseInfo('01610463-v', 0), SenseInfo('01597995-v', 0), SenseInfo('01557646-v', 0), SenseInfo('01369346-v', 0), SenseInfo('01298931-v', 0), SenseInfo('01228524-v', 0), SenseInfo('01228396-v', 0), SenseInfo('00935987-v', 0), SenseInfo('00779061-v', 0), SenseInfo('00778745-v', 0), SenseInfo('00744439-v', 0), SenseInfo('00738440-v', 0), SenseInfo('00738314-v', 0), SenseInfo('00551412-v', 0), SenseInfo('00339464-v', 0), SenseInfo('00336260-v', 0), SenseInfo('00258366-v', 0), SenseInfo('00155046-v', 0), SenseInfo('00107739-v', 0), SenseInfo('00107604-v', 0), SenseInfo('00030463-v', 0), SenseInfo('00364064-v', 15), SenseInfo('00334186-v', 13), SenseInfo('00258665-v', 9), SenseInfo('01369758-v', 8), SenseInfo('00334996-v', 8), SenseInfo('02566528-v', 5), SenseInfo('02073233-v', 4), SenseInfo('02029369-v', 4), SenseInfo('01785395-v', 4), SenseInfo('00362348-v', 4), SenseInfo('02570684-v', 3), SenseInfo('00202569-v', 3), SenseInfo('02668523-v', 2), SenseInfo('01106864-v', 2), SenseInfo('00933821-v', 2), SenseInfo('00558536-v', 2), SenseInfo('00434374-v', 2), SenseInfo('02535716-v', 1), SenseInfo('02030764-v', 1), SenseInfo('01972976-v', 1), SenseInfo('00390215-v', 1), SenseInfo('00202784-v', 1), SenseInfo('02746617-v', 0), SenseInfo('02746449-v', 0), SenseInfo('02681639-v', 0), SenseInfo('02681524-v', 0), SenseInfo('02625187-v', 0), SenseInfo('02600082-v', 0), SenseInfo('02559395-v', 0), SenseInfo('02478469-v', 0), SenseInfo('02431320-v', 0), SenseInfo('02399331-v', 0), SenseInfo('02318165-v', 0), SenseInfo('02101373-v', 0), SenseInfo('01991347-v', 0), SenseInfo('01989053-v', 0), SenseInfo('01896484-v', 0), SenseInfo('01610666-v', 0), SenseInfo('01610463-v', 0), SenseInfo('01597995-v', 0), SenseInfo('01557646-v', 0), SenseInfo('01369346-v', 0), SenseInfo('01298931-v', 0), SenseInfo('01228524-v', 0), SenseInfo('01228396-v', 0), SenseInfo('00935987-v', 0), SenseInfo('00779061-v', 0), SenseInfo('00778745-v', 0), SenseInfo('00744439-v', 0), SenseInfo('00738440-v', 0), SenseInfo('00738314-v', 0), SenseInfo('00551412-v', 0), SenseInfo('00339464-v', 0), SenseInfo('00336260-v', 0), SenseInfo('00258366-v', 0), SenseInfo('00155046-v', 0), SenseInfo('00107739-v', 0), SenseInfo('00107604-v', 0), SenseInfo('00030463-v', 0) ],
"_wreathe_v_1_rel" : [ SenseInfo('01868899-v', 1), SenseInfo('01517055-v', 0), SenseInfo('01516965-v', 0) ],
"_stateswoman_n_1_rel" : [ SenseInfo('10652511-n', 0) ],
"_whatever_a_1_rel" : [ SenseInfo('02267686-a', 0), SenseInfo('02267686-a', 0) ],
"_scholar_n_1_rel" : [ SenseInfo('10557854-n', 7), SenseInfo('10251779-n', 1), SenseInfo('10558773-n', 0) ],
"_compaction_n_1_rel" : [ SenseInfo('07419233-n', 0), SenseInfo('00358089-n', 0) ],
"_shine_v_1_rel" : [ SenseInfo('02765924-v', 9), SenseInfo('02763740-v', 6), SenseInfo('02162947-v', 5), SenseInfo('02733334-v', 3), SenseInfo('02655958-v', 1), SenseInfo('02161530-v', 1), SenseInfo('02763283-v', 0), SenseInfo('02611976-v', 0), SenseInfo('01829747-v', 0), SenseInfo('01245637-v', 0), SenseInfo('02765924-v', 9), SenseInfo('02763740-v', 6), SenseInfo('02162947-v', 5), SenseInfo('02733334-v', 3), SenseInfo('02655958-v', 1), SenseInfo('02161530-v', 1), SenseInfo('02763283-v', 0), SenseInfo('02611976-v', 0), SenseInfo('01829747-v', 0), SenseInfo('01245637-v', 0) ],
"_planer_n_1_rel" : [ SenseInfo('03955296-n', 0) ],
"_ahead+of_p_rel" : [  ],
"_fetching_a_1_rel" : [ SenseInfo('00167829-a', 1), SenseInfo('00167829-a', 1) ],
"_rule_v_out_rel" : [ SenseInfo('02586619-v', 12), SenseInfo('00715868-v', 9), SenseInfo('02644234-v', 2), SenseInfo('00971999-v', 1), SenseInfo('02716995-v', 0), SenseInfo('01690020-v', 0), SenseInfo('00234857-v', 0), SenseInfo('02586619-v', 12), SenseInfo('00715868-v', 9), SenseInfo('02644234-v', 2), SenseInfo('00971999-v', 1), SenseInfo('02716995-v', 0), SenseInfo('01690020-v', 0), SenseInfo('00234857-v', 0) ],
"_wobble_n_1_rel" : [ SenseInfo('07364700-n', 0) ],
"_getaway_n_1_rel" : [ SenseInfo('05061003-n', 0), SenseInfo('00060201-n', 0) ],
"_selfish_a_1_rel" : [ SenseInfo('02098325-a', 3), SenseInfo('02098325-a', 3) ],
"_court_v_1_rel" : [ SenseInfo('02534492-v', 5), SenseInfo('02534936-v', 1), SenseInfo('02534761-v', 0) ],
"_knot_v_1_rel" : [ SenseInfo('01673732-v', 1), SenseInfo('01300144-v', 1), SenseInfo('01521124-v', 0) ],
"_topgallant_n_1_rel" : [ SenseInfo('04454792-n', 0), SenseInfo('04454654-n', 0) ],
"_especially_a_1_rel" : [  ],
"_poor_a_1_rel" : [ SenseInfo('01050890-a', 18), SenseInfo('02022953-a', 12), SenseInfo('02025498-a', 2), SenseInfo('02024411-a', 0), SenseInfo('02336904-a', 0), SenseInfo('01128719-a', 0), SenseInfo('01050890-a', 18), SenseInfo('02022953-a', 12), SenseInfo('02025498-a', 2), SenseInfo('02024411-a', 0), SenseInfo('02336904-a', 0), SenseInfo('01128719-a', 0), SenseInfo('01050890-a', 18), SenseInfo('02022953-a', 12), SenseInfo('02025498-a', 2), SenseInfo('02024411-a', 0), SenseInfo('02336904-a', 0), SenseInfo('01128719-a', 0), SenseInfo('01050890-a', 18), SenseInfo('02022953-a', 12), SenseInfo('02025498-a', 2), SenseInfo('02024411-a', 0), SenseInfo('02336904-a', 0), SenseInfo('01128719-a', 0) ],
"_foster_a_1_rel" : [ SenseInfo('01406418-a', 0) ],
"_coconut_n_1_rel" : [ SenseInfo('07773238-n', 3), SenseInfo('07772935-n', 1), SenseInfo('12587803-n', 0) ],
"_as+it+happens_a_1_rel" : [  ],
"_power_n_1_rel" : [ SenseInfo('05190804-n', 62), SenseInfo('11453016-n', 13), SenseInfo('05616246-n', 13), SenseInfo('13945102-n', 7), SenseInfo('10461424-n', 7), SenseInfo('06812417-n', 7), SenseInfo('05030680-n', 5), SenseInfo('08177592-n', 1), SenseInfo('09840217-n', 0), SenseInfo('05190804-n', 62), SenseInfo('11453016-n', 13), SenseInfo('05616246-n', 13), SenseInfo('13945102-n', 7), SenseInfo('10461424-n', 7), SenseInfo('06812417-n', 7), SenseInfo('05030680-n', 5), SenseInfo('08177592-n', 1), SenseInfo('09840217-n', 0) ],
"_patent_v_1_rel" : [ SenseInfo('02239692-v', 1), SenseInfo('02445356-v', 0), SenseInfo('00568483-v', 0) ],
"_seize_v_on_rel" : [ SenseInfo('01212572-v', 13), SenseInfo('01213614-v', 5), SenseInfo('02272549-v', 4), SenseInfo('02273293-v', 3), SenseInfo('02274482-v', 0), SenseInfo('01365839-v', 0), SenseInfo('00737656-v', 0), SenseInfo('00737476-v', 0) ],
"_standpipe_n_1_rel" : [ SenseInfo('04302527-n', 0) ],
"_think_v_about_rel" : [ SenseInfo('00689344-v', 274), SenseInfo('00631737-v', 188), SenseInfo('00628491-v', 111), SenseInfo('00607780-v', 8), SenseInfo('01637166-v', 4), SenseInfo('00723056-v', 3), SenseInfo('00708538-v', 2), SenseInfo('00739340-v', 0), SenseInfo('00739082-v', 0), SenseInfo('00689809-v', 0), SenseInfo('00629738-v', 0), SenseInfo('00608808-v', 0), SenseInfo('00561887-v', 0) ],
"_pixie_n_1_rel" : [ SenseInfo('09540739-n', 1), SenseInfo('12251740-n', 0) ],
"_competitive_a_1_rel" : [ SenseInfo('00512487-a', 12), SenseInfo('00297755-a', 4), SenseInfo('00083003-a', 1) ],
"_stockade_n_1_rel" : [ SenseInfo('04322531-n', 1), SenseInfo('03086183-n', 0) ],
"_tighten_v_cause_rel" : [ SenseInfo('00420132-v', 8), SenseInfo('00419950-v', 1), SenseInfo('00418765-v', 1), SenseInfo('00233203-v', 0) ],
"_courage_n_1_rel" : [ SenseInfo('04857083-n', 15), SenseInfo('04857083-n', 15) ],
"_crofting_n_1_rel" : [  ],
"_dissatisfaction_n_at-with_rel" : [ SenseInfo('07539511-n', 2), SenseInfo('07539511-n', 2) ],
"_extermination_n_of_rel" : [ SenseInfo('07332691-n', 0), SenseInfo('01245061-n', 0) ],
"_leg_v_1_rel" : [  ],
"_social+security_n_1_rel" : [ SenseInfo('01087939-n', 2), SenseInfo('01087939-n', 2) ],
"_zip_n_1_rel" : [ SenseInfo('13740168-n', 0), SenseInfo('06355705-n', 0), SenseInfo('05035961-n', 0), SenseInfo('04238321-n', 0) ],
"_foreboding_a_1_rel" : [ SenseInfo('01883106-a', 0) ],
"_arise_v_1_rel" : [ SenseInfo('02624263-v', 29), SenseInfo('02625786-v', 9), SenseInfo('01983264-v', 8), SenseInfo('00339738-v', 7), SenseInfo('01968569-v', 1), SenseInfo('02583139-v', 0), SenseInfo('00018158-v', 0) ],
"_orangey_a_1_rel" : [  ],
"_hoot_v_1_rel" : [ SenseInfo('01042725-v', 3), SenseInfo('01053221-v', 0), SenseInfo('01042725-v', 3), SenseInfo('01053221-v', 0) ],
"_waterproofing_n_1_rel" : [ SenseInfo('00830099-n', 1), SenseInfo('04561857-n', 0) ],
"_translator_n_1_rel" : [ SenseInfo('10725280-n', 0), SenseInfo('10212501-n', 0), SenseInfo('06581268-n', 0) ],
"_sleet_n_1_rel" : [ SenseInfo('11507951-n', 0) ],
"_change_v_into_rel" : [ SenseInfo('00126264-v', 57), SenseInfo('00109660-v', 54), SenseInfo('00123170-v', 13), SenseInfo('00550117-v', 7), SenseInfo('00169458-v', 6), SenseInfo('00161225-v', 5), SenseInfo('02257370-v', 3), SenseInfo('02088241-v', 3), SenseInfo('00551210-v', 0), SenseInfo('00163251-v', 0), SenseInfo('00126264-v', 57), SenseInfo('00109660-v', 54), SenseInfo('00123170-v', 13), SenseInfo('00550117-v', 7), SenseInfo('00169458-v', 6), SenseInfo('00161225-v', 5), SenseInfo('02257370-v', 3), SenseInfo('02088241-v', 3), SenseInfo('00551210-v', 0), SenseInfo('00163251-v', 0) ],
"_trend_v_1_rel" : [ SenseInfo('02033295-v', 0) ],
"_alleyway_n_1_rel" : [ SenseInfo('02697759-n', 1) ],
"_water_v_1_rel" : [ SenseInfo('00228236-v', 3), SenseInfo('02357873-v', 2), SenseInfo('00069570-v', 2), SenseInfo('00452098-v', 0) ],
"_shower_v_1_rel" : [ SenseInfo('02264601-v', 2), SenseInfo('01372994-v', 2), SenseInfo('00035259-v', 2), SenseInfo('02757651-v', 0), SenseInfo('01184333-v', 0) ],
"_quiet_a_1_rel" : [ SenseInfo('01922763-a', 13), SenseInfo('01918984-a', 10), SenseInfo('01849170-a', 3), SenseInfo('01455540-a', 1), SenseInfo('00302951-a', 1), SenseInfo('00043615-a', 0), SenseInfo('01922763-a', 13), SenseInfo('01918984-a', 10), SenseInfo('01849170-a', 3), SenseInfo('01455540-a', 1), SenseInfo('00302951-a', 1), SenseInfo('00043615-a', 0), SenseInfo('01922763-a', 13), SenseInfo('01918984-a', 10), SenseInfo('01849170-a', 3), SenseInfo('01455540-a', 1), SenseInfo('00302951-a', 1), SenseInfo('00043615-a', 0), SenseInfo('01922763-a', 13), SenseInfo('01918984-a', 10), SenseInfo('01849170-a', 3), SenseInfo('01455540-a', 1), SenseInfo('00302951-a', 1), SenseInfo('00043615-a', 0) ],
"_equivalent_n_of_rel" : [ SenseInfo('05695554-n', 17), SenseInfo('05026508-n', 0) ],
"_bloodshot_a_1_rel" : [ SenseInfo('01175007-a', 0) ],
"_row_v_1_rel" : [ SenseInfo('01946996-v', 4) ],
"_slobber_v_1_rel" : [ SenseInfo('00102974-v', 0) ],
"_vendor_n_of_rel" : [ SenseInfo('10577284-n', 2) ],
"_dart_v_1_rel" : [ SenseInfo('01899891-v', 3), SenseInfo('02061495-v', 1), SenseInfo('01899708-v', 1) ],
"_manifest_n_1_rel" : [ SenseInfo('06501918-n', 0) ],
"_keel_n_1_rel" : [ SenseInfo('13919919-n', 0), SenseInfo('05228374-n', 0), SenseInfo('03609542-n', 0) ],
"_malaysian_n_1_rel" : [ SenseInfo('09721883-n', 0), SenseInfo('06939051-n', 0) ],
"_microscope_n_1_rel" : [ SenseInfo('03760671-n', 7) ],
"_thresh_v_1_rel" : [ SenseInfo('01890792-v', 1), SenseInfo('02093920-v', 0), SenseInfo('01416364-v', 0), SenseInfo('01416193-v', 0) ],
"_container_n_of_rel" : [ SenseInfo('03094503-n', 5) ],
"_serge_n_1_rel" : [ SenseInfo('04174026-n', 1) ],
"_straighten_v_up_rel" : [ SenseInfo('02035781-v', 7), SenseInfo('01368597-v', 6), SenseInfo('01982044-v', 3), SenseInfo('00275843-v', 1), SenseInfo('01487185-v', 0), SenseInfo('00277935-v', 0), SenseInfo('02035781-v', 7), SenseInfo('01368597-v', 6), SenseInfo('01982044-v', 3), SenseInfo('00275843-v', 1), SenseInfo('01487185-v', 0), SenseInfo('00277935-v', 0) ],
"_second_v_1_rel" : [ SenseInfo('02556817-v', 0), SenseInfo('02393304-v', 0) ],
"_evidence_v_1_rel" : [ SenseInfo('00820976-v', 10), SenseInfo('01015244-v', 3), SenseInfo('00954422-v', 1), SenseInfo('00820976-v', 10), SenseInfo('01015244-v', 3), SenseInfo('00954422-v', 1), SenseInfo('00820976-v', 10), SenseInfo('01015244-v', 3), SenseInfo('00954422-v', 1) ],
"_hhh_a_1_rel" : [  ],
"_substantiality_n_1_rel" : [ SenseInfo('04761212-n', 0) ],
"_staple_v_1_rel" : [ SenseInfo('01367069-v', 0) ],
"_disuse_n_1_rel" : [ SenseInfo('14423428-n', 0) ],
"_bellows_n_1_rel" : [ SenseInfo('07121361-n', 2), SenseInfo('10843228-n', 0), SenseInfo('07121361-n', 2), SenseInfo('10843228-n', 0), SenseInfo('07121361-n', 2), SenseInfo('10843228-n', 0) ],
"_sure_a_1_rel" : [ SenseInfo('00336831-a', 51), SenseInfo('00309740-a', 23), SenseInfo('00340239-a', 4), SenseInfo('02094633-a', 1), SenseInfo('00724397-a', 1), SenseInfo('02465978-a', 0), SenseInfo('02461586-a', 0), SenseInfo('02302822-a', 0), SenseInfo('00335895-a', 0), SenseInfo('00336831-a', 51), SenseInfo('00309740-a', 23), SenseInfo('00340239-a', 4), SenseInfo('02094633-a', 1), SenseInfo('00724397-a', 1), SenseInfo('02465978-a', 0), SenseInfo('02461586-a', 0), SenseInfo('02302822-a', 0), SenseInfo('00335895-a', 0), SenseInfo('00336831-a', 51), SenseInfo('00309740-a', 23), SenseInfo('00340239-a', 4), SenseInfo('02094633-a', 1), SenseInfo('00724397-a', 1), SenseInfo('02465978-a', 0), SenseInfo('02461586-a', 0), SenseInfo('02302822-a', 0), SenseInfo('00335895-a', 0), SenseInfo('00336831-a', 51), SenseInfo('00309740-a', 23), SenseInfo('00340239-a', 4), SenseInfo('02094633-a', 1), SenseInfo('00724397-a', 1), SenseInfo('02465978-a', 0), SenseInfo('02461586-a', 0), SenseInfo('02302822-a', 0), SenseInfo('00335895-a', 0), SenseInfo('00336831-a', 51), SenseInfo('00309740-a', 23), SenseInfo('00340239-a', 4), SenseInfo('02094633-a', 1), SenseInfo('00724397-a', 1), SenseInfo('02465978-a', 0), SenseInfo('02461586-a', 0), SenseInfo('02302822-a', 0), SenseInfo('00335895-a', 0), SenseInfo('00336831-a', 51), SenseInfo('00309740-a', 23), SenseInfo('00340239-a', 4), SenseInfo('02094633-a', 1), SenseInfo('00724397-a', 1), SenseInfo('02465978-a', 0), SenseInfo('02461586-a', 0), SenseInfo('02302822-a', 0), SenseInfo('00335895-a', 0), SenseInfo('00336831-a', 51), SenseInfo('00309740-a', 23), SenseInfo('00340239-a', 4), SenseInfo('02094633-a', 1), SenseInfo('00724397-a', 1), SenseInfo('02465978-a', 0), SenseInfo('02461586-a', 0), SenseInfo('02302822-a', 0), SenseInfo('00335895-a', 0), SenseInfo('00336831-a', 51), SenseInfo('00309740-a', 23), SenseInfo('00340239-a', 4), SenseInfo('02094633-a', 1), SenseInfo('00724397-a', 1), SenseInfo('02465978-a', 0), SenseInfo('02461586-a', 0), SenseInfo('02302822-a', 0), SenseInfo('00335895-a', 0) ],
"_team_v_up_rel" : [ SenseInfo('01089285-v', 0) ],
"_quotient_n_1_rel" : [ SenseInfo('13824815-n', 0), SenseInfo('13733316-n', 0) ],
"_fake_a_1_rel" : [ SenseInfo('01117477-a', 7), SenseInfo('01573238-a', 0) ],
"_joint_n_1_rel" : [ SenseInfo('05595083-n', 3), SenseInfo('03601335-n', 1), SenseInfo('13911151-n', 0), SenseInfo('07580782-n', 0), SenseInfo('03600977-n', 0), SenseInfo('03600806-n', 0) ],
"_paw_n_1_rel" : [ SenseInfo('02439929-n', 2), SenseInfo('05564590-n', 0) ],
"_thumb_n_1_rel" : [ SenseInfo('05567217-n', 5), SenseInfo('04430896-n', 0), SenseInfo('03866721-n', 0) ],
"_monadnock_n_1_rel" : [  ],
"_writ_n_1_rel" : [ SenseInfo('06552984-n', 2) ],
"_unrestricted_a_1_rel" : [ SenseInfo('02002814-a', 1), SenseInfo('01064167-a', 1), SenseInfo('01862296-a', 0), SenseInfo('01541258-a', 0), SenseInfo('00416651-a', 0), SenseInfo('02002814-a', 1), SenseInfo('01064167-a', 1), SenseInfo('01862296-a', 0), SenseInfo('01541258-a', 0), SenseInfo('00416651-a', 0) ],
"_disagreement_n_1_rel" : [ SenseInfo('13982357-n', 3), SenseInfo('04749709-n', 2), SenseInfo('07180787-n', 0), SenseInfo('13982357-n', 3), SenseInfo('04749709-n', 2), SenseInfo('07180787-n', 0) ],
"_wry_a_1_rel" : [ SenseInfo('01266092-a', 1), SenseInfo('02314371-a', 0), SenseInfo('01266092-a', 1), SenseInfo('02314371-a', 0), SenseInfo('01266092-a', 1), SenseInfo('02314371-a', 0) ],
"_radiate_v_1_rel" : [ SenseInfo('02767116-v', 2), SenseInfo('00291163-v', 1), SenseInfo('02686952-v', 0), SenseInfo('02161530-v', 0), SenseInfo('02160552-v', 0), SenseInfo('01829747-v', 0), SenseInfo('00529582-v', 0), SenseInfo('00436668-v', 0) ],
"_count_v_out_rel" : [ SenseInfo('00948071-v', 23), SenseInfo('02645839-v', 7), SenseInfo('00950431-v', 4), SenseInfo('00947857-v', 3), SenseInfo('02731632-v', 2), SenseInfo('00685081-v', 2), SenseInfo('02747140-v', 0), SenseInfo('00712708-v', 0), SenseInfo('00712556-v', 0), SenseInfo('00948071-v', 23), SenseInfo('02645839-v', 7), SenseInfo('00950431-v', 4), SenseInfo('00947857-v', 3), SenseInfo('02731632-v', 2), SenseInfo('00685081-v', 2), SenseInfo('02747140-v', 0), SenseInfo('00712708-v', 0), SenseInfo('00712556-v', 0) ],
"_summon_v_up_rel" : [ SenseInfo('00791134-v', 8), SenseInfo('01041762-v', 2), SenseInfo('01381549-v', 0), SenseInfo('00270215-v', 0) ],
"_groan_a_1_rel" : [ SenseInfo('07126383-n', 2), SenseInfo('07126383-n', 2) ],
"_send_v_back_rel" : [ SenseInfo('01951480-v', 79), SenseInfo('01437254-v', 20), SenseInfo('01031256-v', 20), SenseInfo('01950798-v', 14), SenseInfo('01088923-v', 5), SenseInfo('01062555-v', 5), SenseInfo('02348568-v', 3), SenseInfo('00973056-v', 2) ],
"_enchant_v_1_rel" : [ SenseInfo('01817314-v', 2), SenseInfo('01806505-v', 0), SenseInfo('00776988-v', 0), SenseInfo('01817314-v', 2), SenseInfo('01806505-v', 0), SenseInfo('00776988-v', 0), SenseInfo('01817314-v', 2), SenseInfo('01806505-v', 0), SenseInfo('00776988-v', 0) ],
"_instate_v_1_rel" : [  ],
"_display_v_to_rel" : [ SenseInfo('02140033-v', 35), SenseInfo('02535227-v', 0), SenseInfo('02140033-v', 35), SenseInfo('02535227-v', 0) ],
"_electorate_n_1_rel" : [ SenseInfo('08161068-n', 0) ],
"_levy_v_against_rel" : [ SenseInfo('02306462-v', 4), SenseInfo('01098452-v', 0), SenseInfo('02306462-v', 4), SenseInfo('01098452-v', 0) ],
"_crystallize_v_1_rel" : [ SenseInfo('00143704-v', 2), SenseInfo('00621058-v', 1), SenseInfo('00445940-v', 1), SenseInfo('00443670-v', 0), SenseInfo('00143704-v', 2), SenseInfo('00621058-v', 1), SenseInfo('00445940-v', 1), SenseInfo('00443670-v', 0) ],
"_luncheon_n_1_rel" : [ SenseInfo('07575076-n', 1) ],
"_shackle_v_1_rel" : [ SenseInfo('01300565-v', 0), SenseInfo('01288052-v', 0) ],
"_last+report_n_of_rel" : [  ],
"_sea_n_of_rel" : [ SenseInfo('09426788-n', 37), SenseInfo('13776971-n', 3), SenseInfo('11521404-n', 0), SenseInfo('09426788-n', 37), SenseInfo('13776971-n', 3), SenseInfo('11521404-n', 0) ],
"_mouthful_n_1_rel" : [ SenseInfo('13768343-n', 1), SenseInfo('07578879-n', 0) ],
"_mold_v_1_rel" : [ SenseInfo('01697027-v', 4), SenseInfo('00210738-v', 1), SenseInfo('01662771-v', 0), SenseInfo('01659248-v', 0), SenseInfo('01221405-v', 0), SenseInfo('00701040-v', 0), SenseInfo('01697027-v', 4), SenseInfo('00210738-v', 1), SenseInfo('01662771-v', 0), SenseInfo('01659248-v', 0), SenseInfo('01221405-v', 0), SenseInfo('00701040-v', 0) ],
"_as+though_p_1_rel" : [  ],
"_reflex_n_1_rel" : [ SenseInfo('00863513-n', 5) ],
"_defer_v_1_rel" : [ SenseInfo('02642814-v', 2), SenseInfo('00878348-v', 1) ],
"_effrontery_n_1_rel" : [ SenseInfo('04838727-n', 0), SenseInfo('04838727-n', 0) ],
"_anise_n_1_rel" : [ SenseInfo('12943049-n', 0), SenseInfo('07826653-n', 0) ],
"_snap_v_at_rel" : [ SenseInfo('00916274-v', 7), SenseInfo('01573515-v', 3), SenseInfo('00337065-v', 3), SenseInfo('01893771-v', 2), SenseInfo('00355670-v', 2), SenseInfo('02182851-v', 1), SenseInfo('02088949-v', 1), SenseInfo('01439745-v', 1), SenseInfo('01402872-v', 1), SenseInfo('01242208-v', 1), SenseInfo('01784295-v', 0), SenseInfo('01446301-v', 0), SenseInfo('01003249-v', 0) ],
"_nope_a_1_rel" : [  ],
"_chock+full_a_of_rel" : [ SenseInfo('01084297-a', 0), SenseInfo('01084297-a', 0), SenseInfo('01084297-a', 0) ],
"_hen_n_1_rel" : [ SenseInfo('01792640-n', 22), SenseInfo('01514859-n', 1), SenseInfo('07646067-n', 0), SenseInfo('01321123-n', 0) ],
"_quarter_n_of_rel" : [ SenseInfo('13737480-n', 7), SenseInfo('08627919-n', 4), SenseInfo('15258450-n', 0), SenseInfo('15234942-n', 0), SenseInfo('15226046-n', 0), SenseInfo('15206590-n', 0), SenseInfo('13830166-n', 0), SenseInfo('13720852-n', 0), SenseInfo('13623054-n', 0), SenseInfo('13390244-n', 0), SenseInfo('10498699-n', 0), SenseInfo('04316646-n', 0), SenseInfo('04031600-n', 0), SenseInfo('01258579-n', 0) ],
"_attitude_n_1_rel" : [ SenseInfo('06193203-n', 65), SenseInfo('05079866-n', 12), SenseInfo('00755863-n', 1), SenseInfo('13828343-n', 0) ],
"_conical_a_1_rel" : [ SenseInfo('02844728-a', 0) ],
"_wild_n_1_rel" : [ SenseInfo('13939353-n', 0), SenseInfo('08683548-n', 0) ],
"_ascension_n_1_rel" : [ SenseInfo('15193052-n', 0), SenseInfo('07445480-n', 0), SenseInfo('07311822-n', 0), SenseInfo('07311661-n', 0), SenseInfo('00324384-n', 0) ],
"_deceptive_a_1_rel" : [ SenseInfo('01938975-a', 2), SenseInfo('01224253-a', 0) ],
"_dismissive_a_1_rel" : [ SenseInfo('01343411-a', 0), SenseInfo('00076580-a', 0), SenseInfo('01343411-a', 0), SenseInfo('00076580-a', 0) ],
"_overlap_v_1_rel" : [ SenseInfo('02660631-v', 5), SenseInfo('02688794-v', 1) ],
"_unavoidable_a_1_rel" : [ SenseInfo('00343360-a', 5), SenseInfo('00343360-a', 5) ],
"_simply_x_deg_rel" : [ SenseInfo('00004722-r', 46), SenseInfo('00246296-r', 9), SenseInfo('00004967-r', 7), SenseInfo('00005055-r', 3), SenseInfo('00004722-r', 46), SenseInfo('00246296-r', 9), SenseInfo('00004967-r', 7), SenseInfo('00005055-r', 3) ],
"_prevalent_a_1_rel" : [ SenseInfo('01066787-a', 0) ],
"_hungarian_a_1_rel" : [ SenseInfo('02961505-a', 1) ],
"_victim_n_i_rel" : [ SenseInfo('10752093-n', 8), SenseInfo('10752480-n', 4) ],
"_distinguishable_a_1_rel" : [ SenseInfo('00582314-a', 4), SenseInfo('02067063-a', 0) ],
"_realism_n_1_rel" : [ SenseInfo('05151869-n', 3), SenseInfo('13955461-n', 2), SenseInfo('05975659-n', 1), SenseInfo('08469457-n', 0), SenseInfo('05974564-n', 0) ],
"_sr_n_ttl_rel" : [ SenseInfo('14655731-n', 0), SenseInfo('13612791-n', 0) ],
"_draw_v_in_rel" : [ SenseInfo('01448100-v', 13), SenseInfo('02293148-v', 10), SenseInfo('01582645-v', 10), SenseInfo('00730758-v', 10), SenseInfo('01995211-v', 9), SenseInfo('01690294-v', 7), SenseInfo('01854132-v', 6), SenseInfo('00987071-v', 6), SenseInfo('00675901-v', 6), SenseInfo('01760300-v', 5), SenseInfo('01199009-v', 5), SenseInfo('02088107-v', 4), SenseInfo('02311387-v', 3), SenseInfo('01078050-v', 3), SenseInfo('01643297-v', 2), SenseInfo('00556593-v', 2), SenseInfo('02097800-v', 1), SenseInfo('01690816-v', 1), SenseInfo('01643464-v', 1), SenseInfo('01243148-v', 1), SenseInfo('02742107-v', 0), SenseInfo('02628832-v', 0), SenseInfo('02483564-v', 0), SenseInfo('02103162-v', 0), SenseInfo('01539063-v', 0), SenseInfo('01505254-v', 0), SenseInfo('01359432-v', 0), SenseInfo('01243298-v', 0), SenseInfo('01212230-v', 0), SenseInfo('01115190-v', 0), SenseInfo('00476965-v', 0), SenseInfo('00430808-v', 0), SenseInfo('00327982-v', 0), SenseInfo('00197590-v', 0), SenseInfo('00143338-v', 0), SenseInfo('00097029-v', 0) ],
"_like+number_n_of_rel" : [  ],
"_opine_v_to_rel" : [ SenseInfo('01027668-v', 0), SenseInfo('00631737-v', 0) ],
"_read_v_out_rel" : [ SenseInfo('00625119-v', 115), SenseInfo('02730813-v', 17), SenseInfo('00626428-v', 15), SenseInfo('00627520-v', 5), SenseInfo('00627091-v', 5), SenseInfo('00624476-v', 5), SenseInfo('00599992-v', 4), SenseInfo('00922867-v', 3), SenseInfo('01718755-v', 0), SenseInfo('00620239-v', 0), SenseInfo('00593852-v', 0) ],
"_sleight_v_1_rel" : [  ],
"_leap_n_1_rel" : [ SenseInfo('00120202-n', 5), SenseInfo('07358985-n', 2), SenseInfo('07414222-n', 0), SenseInfo('05086740-n', 0) ],
"_entertaining_a_1_rel" : [ SenseInfo('01344344-a', 0), SenseInfo('01344344-a', 0) ],
"_probably_x_deg_rel" : [ SenseInfo('00138611-r', 112), SenseInfo('00296131-r', 0) ],
"_forage_n_1_rel" : [ SenseInfo('07801091-n', 0), SenseInfo('00945916-n', 0) ],
"_reject_n_1_rel" : [ SenseInfo('05790572-n', 0) ],
"_clearing_n_1_rel" : [ SenseInfo('08541288-n', 3), SenseInfo('01247647-n', 0), SenseInfo('00264192-n', 0) ],
"_upside+down_a_1_rel" : [ SenseInfo('02467559-a', 1), SenseInfo('02467559-a', 1) ],
"_in+earnest_p_1_rel" : [ SenseInfo('00165018-r', 0) ],
"_census_n_of_rel" : [ SenseInfo('00653388-n', 1) ],
"_serial_a_1_rel" : [ SenseInfo('01667729-a', 1), SenseInfo('02797257-a', 0), SenseInfo('02797021-a', 0), SenseInfo('02380358-a', 0), SenseInfo('01667729-a', 1), SenseInfo('02797257-a', 0), SenseInfo('02797021-a', 0), SenseInfo('02380358-a', 0) ],
"_bankrupt_a_1_rel" : [ SenseInfo('02026629-a', 1) ],
"_chloroplast_n_1_rel" : [ SenseInfo('12962992-n', 0) ],
"_southwest_n_of_rel" : [ SenseInfo('13833886-n', 1), SenseInfo('08563627-n', 1), SenseInfo('13836018-n', 0), SenseInfo('08561714-n', 0), SenseInfo('13833886-n', 1), SenseInfo('08563627-n', 1), SenseInfo('13836018-n', 0), SenseInfo('08561714-n', 0), SenseInfo('13833886-n', 1), SenseInfo('08563627-n', 1), SenseInfo('13836018-n', 0), SenseInfo('08561714-n', 0), SenseInfo('13833886-n', 1), SenseInfo('08563627-n', 1), SenseInfo('13836018-n', 0), SenseInfo('08561714-n', 0), SenseInfo('13833886-n', 1), SenseInfo('08563627-n', 1), SenseInfo('13836018-n', 0), SenseInfo('08561714-n', 0), SenseInfo('13833886-n', 1), SenseInfo('08563627-n', 1), SenseInfo('13836018-n', 0), SenseInfo('08561714-n', 0), SenseInfo('13833886-n', 1), SenseInfo('08563627-n', 1), SenseInfo('13836018-n', 0), SenseInfo('08561714-n', 0) ],
"_execution_n_of_rel" : [ SenseInfo('01163779-n', 4), SenseInfo('00097504-n', 2), SenseInfo('13477462-n', 0), SenseInfo('06554078-n', 0), SenseInfo('06553846-n', 0), SenseInfo('01127379-n', 0), SenseInfo('00220522-n', 0) ],
"_analytics_n_1_rel" : [  ],
"_surfeit_n_1_rel" : [ SenseInfo('14452294-n', 0), SenseInfo('05119837-n', 0), SenseInfo('00841628-n', 0) ],
"_blond_n_1_rel" : [ SenseInfo('09860506-n', 0), SenseInfo('04966017-n', 0) ],
"_granted_n_i_rel" : [ SenseInfo('00028280-a', 4) ],
"_freeze_n_1_rel" : [ SenseInfo('13484644-n', 0), SenseInfo('11440521-n', 0), SenseInfo('01063697-n', 0), SenseInfo('00808767-n', 0) ],
"_moor_n_1_rel" : [ SenseInfo('09723361-n', 0), SenseInfo('09358751-n', 0) ],
"_solo_v_1_rel" : [ SenseInfo('01941987-v', 0), SenseInfo('01715040-v', 0) ],
"_worst+of+all_a_1_rel" : [  ],
"_applicable_a_1_rel" : [ SenseInfo('01975448-a', 6) ],
"_depart_v_1_rel" : [ SenseInfo('01848718-v', 11), SenseInfo('02661252-v', 5), SenseInfo('02014165-v', 3), SenseInfo('02008396-v', 1), SenseInfo('02383440-v', 0), SenseInfo('02066304-v', 0) ],
"_bassinet_n_1_rel" : [ SenseInfo('02804414-n', 1), SenseInfo('02804515-n', 0) ],
"_automated_a_1_rel" : [ SenseInfo('00182086-a', 0) ],
"_boulevard_n_1_rel" : [ SenseInfo('02763472-n', 1), SenseInfo('02763472-n', 1) ],
"_peck_v_1_rel" : [ SenseInfo('01243474-v', 3), SenseInfo('01173813-v', 1), SenseInfo('01431879-v', 0), SenseInfo('01173656-v', 0), SenseInfo('00844941-v', 0) ],
"_gendarme_n_1_rel" : [ SenseInfo('10123122-n', 0) ],
"_comprehend_v_1_rel" : [ SenseInfo('00588221-v', 11), SenseInfo('02106506-v', 1), SenseInfo('02629793-v', 0), SenseInfo('00588221-v', 11), SenseInfo('02106506-v', 1), SenseInfo('02629793-v', 0), SenseInfo('00588221-v', 11), SenseInfo('02106506-v', 1), SenseInfo('02629793-v', 0) ],
"_distend_v_1_rel" : [ SenseInfo('00305537-v', 0), SenseInfo('00257087-v', 0), SenseInfo('00256862-v', 0) ],
"_down_v_1_rel" : [ SenseInfo('01202374-v', 3), SenseInfo('01197014-v', 1), SenseInfo('01103336-v', 1), SenseInfo('01981279-v', 0), SenseInfo('01239862-v', 0), SenseInfo('00474017-v', 0) ],
"_friendly_a_to_rel" : [ SenseInfo('01074650-a', 25), SenseInfo('01246801-a', 4), SenseInfo('01077995-a', 0), SenseInfo('01077638-a', 0) ],
"_nudge_v_1_rel" : [ SenseInfo('01231252-v', 3), SenseInfo('00766289-v', 0), SenseInfo('01231252-v', 3), SenseInfo('00766289-v', 0) ],
"_co-educational_a_1_rel" : [ SenseInfo('01326415-a', 0), SenseInfo('01326415-a', 0) ],
"_surface_v_1_rel" : [ SenseInfo('01990281-v', 1), SenseInfo('01264283-v', 0), SenseInfo('00423702-v', 0) ],
"_personalize_v_1_rel" : [ SenseInfo('00388065-v', 1) ],
"_fetter_v_1_rel" : [ SenseInfo('01288052-v', 0) ],
"_miniature_n_1_rel" : [ SenseInfo('03769397-n', 1), SenseInfo('03769235-n', 1) ],
"_awaken_v_cause_rel" : [ SenseInfo('00018813-v', 8), SenseInfo('00018526-v', 8), SenseInfo('00736095-v', 1) ],
"_lodger_n_1_rel" : [ SenseInfo('10269458-n', 0) ],
"_renounce_v_1_rel" : [ SenseInfo('02379198-v', 0), SenseInfo('02367032-v', 0), SenseInfo('02227487-v', 0), SenseInfo('00757544-v', 0) ],
"_koala_n_1_rel" : [ SenseInfo('01882714-n', 0) ],
"_conform_v_with_rel" : [ SenseInfo('02662979-v', 1), SenseInfo('00150287-v', 1) ],
"_change_v_cause_rel" : [ SenseInfo('00126264-v', 57), SenseInfo('00109660-v', 54), SenseInfo('00123170-v', 13), SenseInfo('00550117-v', 7), SenseInfo('00169458-v', 6), SenseInfo('00161225-v', 5), SenseInfo('02257370-v', 3), SenseInfo('02088241-v', 3), SenseInfo('00551210-v', 0), SenseInfo('00163251-v', 0) ],
"_kiss_v_1_rel" : [ SenseInfo('01431230-v', 18), SenseInfo('01431723-v', 0) ],
"_get_v_away-with_rel" : [ SenseInfo('02210855-v', 235), SenseInfo('00149583-v', 157), SenseInfo('00120796-v', 82), SenseInfo('00522751-v', 64), SenseInfo('02005948-v', 58), SenseInfo('01433294-v', 45), SenseInfo('02108026-v', 36), SenseInfo('01153947-v', 14), SenseInfo('02355596-v', 9), SenseInfo('00770437-v', 7), SenseInfo('01215421-v', 4), SenseInfo('00094460-v', 4), SenseInfo('00087736-v', 4), SenseInfo('01066036-v', 3), SenseInfo('00120316-v', 3), SenseInfo('01026975-v', 2), SenseInfo('00589904-v', 2), SenseInfo('01505958-v', 1), SenseInfo('01401115-v', 1), SenseInfo('00639849-v', 1), SenseInfo('02359340-v', 0), SenseInfo('02208265-v', 0), SenseInfo('02189398-v', 0), SenseInfo('02109645-v', 0), SenseInfo('02108654-v', 0), SenseInfo('02010864-v', 0), SenseInfo('02006573-v', 0), SenseInfo('01771194-v', 0), SenseInfo('01771039-v', 0), SenseInfo('01738107-v', 0), SenseInfo('01643297-v', 0), SenseInfo('01565211-v', 0), SenseInfo('00622384-v', 0), SenseInfo('00345761-v', 0), SenseInfo('00065639-v', 0), SenseInfo('00054628-v', 0) ],
"_legislate_v_1_rel" : [ SenseInfo('02466670-v', 1) ],
"_gourd_n_1_rel" : [ SenseInfo('03449451-n', 1), SenseInfo('12158031-n', 0), SenseInfo('12157769-n', 0) ],
"_distinct_a_1_rel" : [ SenseInfo('02067063-a', 14), SenseInfo('00779374-a', 10), SenseInfo('02110778-a', 1), SenseInfo('00701299-a', 0), SenseInfo('00429016-a', 0), SenseInfo('02067063-a', 14), SenseInfo('00779374-a', 10), SenseInfo('02110778-a', 1), SenseInfo('00701299-a', 0), SenseInfo('00429016-a', 0) ],
"_belly_n_1_rel" : [ SenseInfo('05556943-n', 8), SenseInfo('05555917-n', 2), SenseInfo('13895262-n', 0), SenseInfo('08588486-n', 0), SenseInfo('02157415-n', 0) ],
"_roommate_n_1_rel" : [ SenseInfo('10538518-n', 0), SenseInfo('10538518-n', 0) ],
"_formalize_v_1_rel" : [ SenseInfo('02478936-v', 0), SenseInfo('02478701-v', 0), SenseInfo('02478936-v', 0), SenseInfo('02478701-v', 0) ],
"_open_v_cause_rel" : [ SenseInfo('01346003-v', 66), SenseInfo('02426171-v', 45), SenseInfo('01346804-v', 17), SenseInfo('02425462-v', 14), SenseInfo('01579813-v', 4), SenseInfo('00539936-v', 4), SenseInfo('00540101-v', 2), SenseInfo('02744651-v', 1), SenseInfo('01077887-v', 1), SenseInfo('02358034-v', 0), SenseInfo('02140630-v', 0) ],
"_mortality_n_1_rel" : [ SenseInfo('05055974-n', 4), SenseInfo('15277118-n', 0) ],
"_investigation_n_of_rel" : [ SenseInfo('05800611-n', 16), SenseInfo('00633864-n', 8) ],
"_syndrome_n_1_rel" : [ SenseInfo('05870790-n', 1), SenseInfo('14304060-n', 0), SenseInfo('05870790-n', 1), SenseInfo('14304060-n', 0) ],
"_fatigue_n_1_rel" : [ SenseInfo('14016361-n', 4), SenseInfo('14463676-n', 0), SenseInfo('07540081-n', 0), SenseInfo('00730708-n', 0) ],
"_nettle_n_1_rel" : [ SenseInfo('12392070-n', 0) ],
"_lactic_a_1_rel" : [ SenseInfo('02848787-a', 0) ],
"_parade_v_cause_rel" : [ SenseInfo('01924712-v', 2), SenseInfo('01924505-v', 1) ],
"_facility_n_1_rel" : [ SenseInfo('03315023-n', 35), SenseInfo('05642175-n', 0), SenseInfo('04708796-n', 0), SenseInfo('00585406-n', 0), SenseInfo('00578549-n', 0), SenseInfo('03315023-n', 35), SenseInfo('05642175-n', 0), SenseInfo('04708796-n', 0), SenseInfo('00585406-n', 0), SenseInfo('00578549-n', 0), SenseInfo('03315023-n', 35), SenseInfo('05642175-n', 0), SenseInfo('04708796-n', 0), SenseInfo('00585406-n', 0), SenseInfo('00578549-n', 0), SenseInfo('03315023-n', 35), SenseInfo('05642175-n', 0), SenseInfo('04708796-n', 0), SenseInfo('00585406-n', 0), SenseInfo('00578549-n', 0) ],
"_illumine_v_1_rel" : [ SenseInfo('00291873-v', 6) ],
"_witness_n_1_rel" : [ SenseInfo('10786033-n', 7), SenseInfo('10633450-n', 3), SenseInfo('06734702-n', 2), SenseInfo('10786270-n', 1), SenseInfo('10786517-n', 0) ],
"_disobey_v_1_rel" : [ SenseInfo('02543181-v', 4) ],
"_stammer_v_1_rel" : [ SenseInfo('00981544-v', 6), SenseInfo('00981544-v', 6) ],
"_guru_n_1_rel" : [ SenseInfo('10152616-n', 1), SenseInfo('10152889-n', 0), SenseInfo('10152763-n', 0) ],
"_much+as_x_1_rel" : [ SenseInfo('00188600-r', 3) ],
"_stage_n_of_rel" : [ SenseInfo('15290337-n', 25), SenseInfo('13939892-n', 18), SenseInfo('04296562-n', 15), SenseInfo('07006712-n', 6), SenseInfo('04297098-n', 2), SenseInfo('00306900-n', 2), SenseInfo('08646566-n', 1), SenseInfo('04296949-n', 0), SenseInfo('15290337-n', 25), SenseInfo('13939892-n', 18), SenseInfo('04296562-n', 15), SenseInfo('07006712-n', 6), SenseInfo('04297098-n', 2), SenseInfo('00306900-n', 2), SenseInfo('08646566-n', 1), SenseInfo('04296949-n', 0) ],
"_calculator_n_1_rel" : [ SenseInfo('09887034-n', 0), SenseInfo('02938886-n', 0) ],
"_forefather_n_1_rel" : [ SenseInfo('10102800-n', 1), SenseInfo('10102969-n', 0) ],
"_enthrall_v_1_rel" : [ SenseInfo('01817314-v', 1), SenseInfo('01817314-v', 1) ],
"_detonate_v_1_rel" : [ SenseInfo('00306723-v', 3), SenseInfo('00306298-v', 0) ],
"_cut_v_down_rel" : [ SenseInfo('01552519-v', 58), SenseInfo('00429060-v', 18), SenseInfo('02033295-v', 3), SenseInfo('01610834-v', 2), SenseInfo('02422283-v', 1), SenseInfo('01754915-v', 1), SenseInfo('01666717-v', 1), SenseInfo('01413917-v', 1), SenseInfo('01064799-v', 1), SenseInfo('00201722-v', 1), SenseInfo('02613860-v', 0), SenseInfo('02588280-v', 0), SenseInfo('02134232-v', 0), SenseInfo('02101649-v', 0), SenseInfo('01915865-v', 0), SenseInfo('01915730-v', 0), SenseInfo('01860107-v', 0), SenseInfo('01859995-v', 0), SenseInfo('01756563-v', 0), SenseInfo('01756416-v', 0), SenseInfo('01756277-v', 0), SenseInfo('01754737-v', 0), SenseInfo('01713491-v', 0), SenseInfo('01611123-v', 0), SenseInfo('01610990-v', 0), SenseInfo('01555437-v', 0), SenseInfo('01510576-v', 0), SenseInfo('01320424-v', 0), SenseInfo('01319738-v', 0), SenseInfo('01227088-v', 0), SenseInfo('01059564-v', 0), SenseInfo('00561090-v', 0), SenseInfo('00473322-v', 0), SenseInfo('00447654-v', 0), SenseInfo('00429968-v', 0), SenseInfo('00292507-v', 0), SenseInfo('00243900-v', 0), SenseInfo('00226071-v', 0), SenseInfo('00108475-v', 0), SenseInfo('00096136-v', 0), SenseInfo('00061219-v', 0), SenseInfo('01552519-v', 58), SenseInfo('00429060-v', 18), SenseInfo('02033295-v', 3), SenseInfo('01610834-v', 2), SenseInfo('02422283-v', 1), SenseInfo('01754915-v', 1), SenseInfo('01666717-v', 1), SenseInfo('01413917-v', 1), SenseInfo('01064799-v', 1), SenseInfo('00201722-v', 1), SenseInfo('02613860-v', 0), SenseInfo('02588280-v', 0), SenseInfo('02134232-v', 0), SenseInfo('02101649-v', 0), SenseInfo('01915865-v', 0), SenseInfo('01915730-v', 0), SenseInfo('01860107-v', 0), SenseInfo('01859995-v', 0), SenseInfo('01756563-v', 0), SenseInfo('01756416-v', 0), SenseInfo('01756277-v', 0), SenseInfo('01754737-v', 0), SenseInfo('01713491-v', 0), SenseInfo('01611123-v', 0), SenseInfo('01610990-v', 0), SenseInfo('01555437-v', 0), SenseInfo('01510576-v', 0), SenseInfo('01320424-v', 0), SenseInfo('01319738-v', 0), SenseInfo('01227088-v', 0), SenseInfo('01059564-v', 0), SenseInfo('00561090-v', 0), SenseInfo('00473322-v', 0), SenseInfo('00447654-v', 0), SenseInfo('00429968-v', 0), SenseInfo('00292507-v', 0), SenseInfo('00243900-v', 0), SenseInfo('00226071-v', 0), SenseInfo('00108475-v', 0), SenseInfo('00096136-v', 0), SenseInfo('00061219-v', 0), SenseInfo('01552519-v', 58), SenseInfo('00429060-v', 18), SenseInfo('02033295-v', 3), SenseInfo('01610834-v', 2), SenseInfo('02422283-v', 1), SenseInfo('01754915-v', 1), SenseInfo('01666717-v', 1), SenseInfo('01413917-v', 1), SenseInfo('01064799-v', 1), SenseInfo('00201722-v', 1), SenseInfo('02613860-v', 0), SenseInfo('02588280-v', 0), SenseInfo('02134232-v', 0), SenseInfo('02101649-v', 0), SenseInfo('01915865-v', 0), SenseInfo('01915730-v', 0), SenseInfo('01860107-v', 0), SenseInfo('01859995-v', 0), SenseInfo('01756563-v', 0), SenseInfo('01756416-v', 0), SenseInfo('01756277-v', 0), SenseInfo('01754737-v', 0), SenseInfo('01713491-v', 0), SenseInfo('01611123-v', 0), SenseInfo('01610990-v', 0), SenseInfo('01555437-v', 0), SenseInfo('01510576-v', 0), SenseInfo('01320424-v', 0), SenseInfo('01319738-v', 0), SenseInfo('01227088-v', 0), SenseInfo('01059564-v', 0), SenseInfo('00561090-v', 0), SenseInfo('00473322-v', 0), SenseInfo('00447654-v', 0), SenseInfo('00429968-v', 0), SenseInfo('00292507-v', 0), SenseInfo('00243900-v', 0), SenseInfo('00226071-v', 0), SenseInfo('00108475-v', 0), SenseInfo('00096136-v', 0), SenseInfo('00061219-v', 0) ],
"_thumbs-down_n_1_rel" : [  ],
"_drown_v_1_rel" : [ SenseInfo('01339294-v', 3), SenseInfo('00472532-v', 2), SenseInfo('00360501-v', 2), SenseInfo('00479060-v', 1), SenseInfo('02755911-v', 0) ],
"_mispronounce_v_1_rel" : [ SenseInfo('00951601-v', 0), SenseInfo('00951601-v', 0) ],
"_backflip_n_1_rel" : [  ],
"_ransack_v_1_rel" : [ SenseInfo('02344568-v', 3), SenseInfo('01319193-v', 3) ],
"_guide_n_1_rel" : [ SenseInfo('10741821-n', 1), SenseInfo('10151570-n', 1), SenseInfo('06422740-n', 1), SenseInfo('05938976-n', 1), SenseInfo('10562749-n', 0), SenseInfo('03466027-n', 0) ],
"_cinema_n_1_rel" : [ SenseInfo('06262567-n', 1), SenseInfo('03032252-n', 0), SenseInfo('06262567-n', 1), SenseInfo('03032252-n', 0) ],
"_lice_n_1_rel" : [ SenseInfo('02183857-n', 2), SenseInfo('10792028-n', 0), SenseInfo('02251775-n', 0), SenseInfo('02185481-n', 0) ],
"_tingle_n_1_rel" : [ SenseInfo('07520112-n', 0), SenseInfo('05722868-n', 0) ],
"_coal_n_1_rel" : [ SenseInfo('14814616-n', 5), SenseInfo('09273130-n', 0) ],
"_crappy_a_1_rel" : [ SenseInfo('01127782-a', 0) ],
"_font_n_1_rel" : [ SenseInfo('06825399-n', 0), SenseInfo('02788572-n', 0) ],
"_exploitation_n_of_rel" : [ SenseInfo('00948206-n', 2), SenseInfo('00418903-n', 2) ],
"_riffle_n_1_rel" : [ SenseInfo('07344663-n', 0), SenseInfo('00340838-n', 0) ],
"_budget_n_1_rel" : [ SenseInfo('13421832-n', 4), SenseInfo('13421462-n', 3), SenseInfo('13421832-n', 4), SenseInfo('13421462-n', 3) ],
"_needy_a_1_rel" : [ SenseInfo('02023430-a', 0), SenseInfo('00710909-a', 0) ],
"_for-sale_a_1_rel" : [ SenseInfo('00185607-a', 2), SenseInfo('00185607-a', 2) ],
"_unshaven_a_1_rel" : [ SenseInfo('02153817-a', 1), SenseInfo('02153817-a', 1) ],
"_bavarian_a_1_rel" : [ SenseInfo('02969775-a', 0) ],
"_top_v_1_rel" : [ SenseInfo('02669081-v', 2), SenseInfo('02081178-v', 1), SenseInfo('02691722-v', 0), SenseInfo('02687385-v', 0), SenseInfo('02360497-v', 0), SenseInfo('02021376-v', 0), SenseInfo('01406897-v', 0), SenseInfo('01321509-v', 0), SenseInfo('00485891-v', 0), SenseInfo('00484712-v', 0) ],
"_neanderthal_a_1_rel" : [ SenseInfo('01949859-a', 1), SenseInfo('03089121-a', 0) ],
"_emerge_v_1_rel" : [ SenseInfo('00423971-v', 36), SenseInfo('00528990-v', 9), SenseInfo('00426581-v', 5), SenseInfo('01990694-v', 3), SenseInfo('02625016-v', 0), SenseInfo('00423971-v', 36), SenseInfo('00528990-v', 9), SenseInfo('00426581-v', 5), SenseInfo('01990694-v', 3), SenseInfo('02625016-v', 0) ],
"_chip_v_away_rel" : [ SenseInfo('01259691-v', 1), SenseInfo('01259005-v', 1), SenseInfo('01598140-v', 0), SenseInfo('01260291-v', 0), SenseInfo('01259458-v', 0), SenseInfo('01259691-v', 1), SenseInfo('01259005-v', 1), SenseInfo('01598140-v', 0), SenseInfo('01260291-v', 0), SenseInfo('01259458-v', 0) ],
"_storehouse_n_1_rel" : [ SenseInfo('04329190-n', 3) ],
"_key_n_1_rel" : [ SenseInfo('03613294-n', 14), SenseInfo('05794057-n', 4), SenseInfo('04986147-n', 2), SenseInfo('06863751-n', 1), SenseInfo('13724838-n', 0), SenseInfo('12036226-n', 0), SenseInfo('11103104-n', 0), SenseInfo('09325395-n', 0), SenseInfo('08590909-n', 0), SenseInfo('06492438-n', 0), SenseInfo('06492188-n', 0), SenseInfo('06424869-n', 0), SenseInfo('04586581-n', 0), SenseInfo('03615133-n', 0), SenseInfo('03613592-n', 0) ],
"_tour_v_1_rel" : [ SenseInfo('01845229-v', 3) ],
"_consignment_n_of_rel" : [ SenseInfo('02964389-n', 0), SenseInfo('01165692-n', 0), SenseInfo('00317917-n', 0) ],
"_trace_v_back_rel" : [ SenseInfo('00729109-v', 9), SenseInfo('01582645-v', 5), SenseInfo('02004352-v', 2), SenseInfo('02003601-v', 2), SenseInfo('02156063-v', 0), SenseInfo('01995949-v', 0), SenseInfo('01694376-v', 0), SenseInfo('00626130-v', 0), SenseInfo('00729109-v', 9), SenseInfo('01582645-v', 5), SenseInfo('02004352-v', 2), SenseInfo('02003601-v', 2), SenseInfo('02156063-v', 0), SenseInfo('01995949-v', 0), SenseInfo('01694376-v', 0), SenseInfo('00626130-v', 0) ],
"_tidy_a_1_rel" : [ SenseInfo('02422685-a', 0), SenseInfo('02427594-a', 0), SenseInfo('00624576-a', 0), SenseInfo('02422685-a', 0), SenseInfo('02427594-a', 0), SenseInfo('00624576-a', 0), SenseInfo('02422685-a', 0), SenseInfo('02427594-a', 0), SenseInfo('00624576-a', 0) ],
"_feel_v_for_rel" : [ SenseInfo('01771535-v', 181), SenseInfo('00715239-v', 150), SenseInfo('02106006-v', 66), SenseInfo('00105958-v', 39), SenseInfo('00690305-v', 37), SenseInfo('02110552-v', 34), SenseInfo('02730471-v', 14), SenseInfo('02127613-v', 5), SenseInfo('01209678-v', 4), SenseInfo('01210352-v', 3), SenseInfo('02286027-v', 1), SenseInfo('02134350-v', 0), SenseInfo('01210152-v', 0) ],
"_room_n_capacity_rel" : [ SenseInfo('04105893-n', 116), SenseInfo('13777764-n', 10), SenseInfo('14485436-n', 3), SenseInfo('07985948-n', 0), SenseInfo('04105893-n', 116), SenseInfo('13777764-n', 10), SenseInfo('14485436-n', 3), SenseInfo('07985948-n', 0), SenseInfo('04105893-n', 116), SenseInfo('13777764-n', 10), SenseInfo('14485436-n', 3), SenseInfo('07985948-n', 0) ],
"_political_a_1_rel" : [ SenseInfo('01814385-a', 45), SenseInfo('02857407-a', 11), SenseInfo('02857587-a', 6), SenseInfo('01814385-a', 45), SenseInfo('02857407-a', 11), SenseInfo('02857587-a', 6) ],
"_a+bit_a_1_rel" : [  ],
"_pay-per-view_a_1_rel" : [  ],
"_misspell_v_1_rel" : [ SenseInfo('00938146-v', 0), SenseInfo('00938146-v', 0) ],
"_rain_v_1_rel" : [ SenseInfo('02756558-v', 13), SenseInfo('02756558-v', 13) ],
"_hello_n_1_rel" : [ SenseInfo('06632511-n', 1) ],
"_clueless_a_1_rel" : [ SenseInfo('01308736-a', 0) ],
"_fiver_n_1_rel" : [ SenseInfo('13395515-n', 0) ],
"_maidservant_n_1_rel" : [ SenseInfo('10282672-n', 0) ],
"_topmast_n_1_rel" : [ SenseInfo('04455250-n', 0) ],
"_conduction_n_1_rel" : [ SenseInfo('11512818-n', 2) ],
"_dole_n_1_rel" : [ SenseInfo('13285855-n', 0), SenseInfo('01088304-n', 0) ],
"_backport_v_1_rel" : [  ],
"_entity_n_1_rel" : [ SenseInfo('00001740-n', 11) ],
"_levity_n_1_rel" : [ SenseInfo('07511906-n', 0), SenseInfo('04648749-n', 0) ],
"_bereave_v_of_rel" : [ SenseInfo('02315421-v', 0) ],
"_connectivity_n_1_rel" : [ SenseInfo('04918053-n', 0) ],
"_after_x_h_rel" : [ SenseInfo('00061203-r', 5), SenseInfo('00508070-r', 0), SenseInfo('01033542-a', 0) ],
"_bale_n_1_rel" : [ SenseInfo('02778456-n', 1), SenseInfo('09032483-n', 0) ],
"_run_n_of_rel" : [ SenseInfo('00189565-n', 18), SenseInfo('00791078-n', 5), SenseInfo('07460104-n', 2), SenseInfo('08460585-n', 1), SenseInfo('00558883-n', 1), SenseInfo('00308871-n', 1), SenseInfo('00293916-n', 1), SenseInfo('15262120-n', 0), SenseInfo('13995935-n', 0), SenseInfo('13760129-n', 0), SenseInfo('09415938-n', 0), SenseInfo('07472929-n', 0), SenseInfo('07443010-n', 0), SenseInfo('07407777-n', 0), SenseInfo('05045841-n', 0), SenseInfo('00309011-n', 0) ],
"_class_v_into_rel" : [ SenseInfo('00654625-v', 2) ],
"_sports_n_1_rel" : [ SenseInfo('00523513-n', 11), SenseInfo('00433216-n', 6), SenseInfo('10639238-n', 0), SenseInfo('10639047-n', 0), SenseInfo('10638922-n', 0), SenseInfo('10341660-n', 0), SenseInfo('06780882-n', 0) ],
"_nitrogen_n_1_rel" : [ SenseInfo('14647235-n', 5) ],
"_anemone_n_1_rel" : [ SenseInfo('11725015-n', 0), SenseInfo('01914609-n', 0) ],
"_equip_v_1_rel" : [ SenseInfo('02339413-v', 11), SenseInfo('00513177-v', 1) ],
"_prodigious_a_1_rel" : [ SenseInfo('01384730-a', 4), SenseInfo('02164165-a', 0), SenseInfo('01676026-a', 0) ],
"_irrigation_n_1_rel" : [ SenseInfo('01057631-n', 2), SenseInfo('00695448-n', 0) ],
"_frill_n_1_rel" : [ SenseInfo('05547149-n', 0), SenseInfo('05546997-n', 0), SenseInfo('03397532-n', 0), SenseInfo('03376438-n', 0) ],
"_muslin_n_1_rel" : [ SenseInfo('03802393-n', 0) ],
"_customizable_a_for_rel" : [  ],
"_childs_a_1_rel" : [  ],
"_hallmark_n_1_rel" : [ SenseInfo('04732543-n', 2), SenseInfo('06855035-n', 0) ],
"_doff_v_1_rel" : [ SenseInfo('01590658-v', 0) ],
"_upright_n_1_rel" : [ SenseInfo('04515129-n', 0), SenseInfo('04515003-n', 0) ],
"_fit_a_1_rel" : [ SenseInfo('01020393-a', 4), SenseInfo('01931203-a', 4), SenseInfo('01017161-a', 3), SenseInfo('01020393-a', 4), SenseInfo('01931203-a', 4), SenseInfo('01017161-a', 3), SenseInfo('01020393-a', 4), SenseInfo('01931203-a', 4), SenseInfo('01017161-a', 3), SenseInfo('01020393-a', 4), SenseInfo('01931203-a', 4), SenseInfo('01017161-a', 3) ],
"_executable_n_1_rel" : [ SenseInfo('01822563-a', 0) ],
"_mettle_n_1_rel" : [ SenseInfo('04857490-n', 0) ],
"_ditch_n_1_rel" : [ SenseInfo('03214253-n', 2), SenseInfo('09267758-n', 0) ],
"_memorize_v_1_rel" : [ SenseInfo('00604576-v', 6) ],
"_lug_v_1_rel" : [ SenseInfo('01454246-v', 5), SenseInfo('01479333-v', 0), SenseInfo('01454246-v', 5), SenseInfo('01479333-v', 0) ],
"_tickle_n_1_rel" : [ SenseInfo('05723417-n', 0), SenseInfo('00144445-n', 0) ],
"_payment_n_of_rel" : [ SenseInfo('13278375-n', 32), SenseInfo('01120448-n', 23), SenseInfo('01235137-n', 0) ],
"_incurable_a_1_rel" : [ SenseInfo('00994567-a', 1), SenseInfo('00349759-a', 0) ],
"_stratus_a_1_rel" : [ SenseInfo('09448251-n', 0) ],
"_countermeasure_n_1_rel" : [ SenseInfo('00174663-n', 0), SenseInfo('00174663-n', 0), SenseInfo('00174663-n', 0), SenseInfo('00174663-n', 0) ],
"_substance_n_1_rel" : [ SenseInfo('00019613-n', 17), SenseInfo('05921123-n', 2), SenseInfo('05919866-n', 2), SenseInfo('14580597-n', 0), SenseInfo('13353858-n', 0), SenseInfo('06598915-n', 0), SenseInfo('00020090-n', 0) ],
"_go_v_over_rel" : [ SenseInfo('01835496-v', 343), SenseInfo('02372605-v', 95), SenseInfo('01848718-v', 49), SenseInfo('00149583-v', 29), SenseInfo('02653862-v', 14), SenseInfo('02721284-v', 10), SenseInfo('02685951-v', 10), SenseInfo('00341560-v', 10), SenseInfo('00359916-v', 9), SenseInfo('02618001-v', 7), SenseInfo('02176268-v', 3), SenseInfo('01525666-v', 3), SenseInfo('01192773-v', 3), SenseInfo('00539110-v', 3), SenseInfo('02618149-v', 2), SenseInfo('02617798-v', 2), SenseInfo('00358431-v', 2), SenseInfo('02737876-v', 1), SenseInfo('02729819-v', 1), SenseInfo('01864230-v', 1), SenseInfo('01076615-v', 1), SenseInfo('02700772-v', 0), SenseInfo('02700666-v', 0), SenseInfo('02700455-v', 0), SenseInfo('02686471-v', 0), SenseInfo('02659763-v', 0), SenseInfo('01318849-v', 0), SenseInfo('01192992-v', 0), SenseInfo('00676267-v', 0), SenseInfo('00434374-v', 0) ],
"_glide_v_1_rel" : [ SenseInfo('01887576-v', 3), SenseInfo('01942347-v', 0), SenseInfo('01887901-v', 0), SenseInfo('01887576-v', 3), SenseInfo('01942347-v', 0), SenseInfo('01887901-v', 0) ],
"_least+squares_n_1_rel" : [ SenseInfo('06021013-n', 0), SenseInfo('06021013-n', 0) ],
"_sooty_a_1_rel" : [ SenseInfo('00388849-a', 1), SenseInfo('00423431-a', 0), SenseInfo('00388849-a', 1), SenseInfo('00423431-a', 0), SenseInfo('00388849-a', 1), SenseInfo('00423431-a', 0) ],
"_hour_n_1_rel" : [ SenseInfo('15227846-n', 92), SenseInfo('15228378-n', 22), SenseInfo('15228910-n', 1), SenseInfo('05131023-n', 0), SenseInfo('15227846-n', 92), SenseInfo('15228378-n', 22), SenseInfo('15228910-n', 1), SenseInfo('05131023-n', 0), SenseInfo('15227846-n', 92), SenseInfo('15228378-n', 22), SenseInfo('15228910-n', 1), SenseInfo('05131023-n', 0), SenseInfo('15227846-n', 92), SenseInfo('15228378-n', 22), SenseInfo('15228910-n', 1), SenseInfo('05131023-n', 0), SenseInfo('15227846-n', 92), SenseInfo('15228378-n', 22), SenseInfo('15228910-n', 1), SenseInfo('05131023-n', 0), SenseInfo('15227846-n', 92), SenseInfo('15228378-n', 22), SenseInfo('15228910-n', 1), SenseInfo('05131023-n', 0) ],
"_carrier_n_of_rel" : [ SenseInfo('09897696-n', 3), SenseInfo('02970100-n', 3), SenseInfo('02687172-n', 3), SenseInfo('14727153-n', 1), SenseInfo('08057633-n', 1), SenseInfo('11501230-n', 0), SenseInfo('10283037-n', 0), SenseInfo('09897603-n', 0), SenseInfo('09897350-n', 0), SenseInfo('02969886-n', 0), SenseInfo('01314145-n', 0) ],
"_kittenish_a_1_rel" : [ SenseInfo('02123007-a', 1) ],
"_complicate_v_1_rel" : [ SenseInfo('00402539-v', 5), SenseInfo('00400883-v', 2) ],
"_branch_v_off_rel" : [ SenseInfo('00329244-v', 0), SenseInfo('00328802-v', 0) ],
"_call_v_in_rel" : [ SenseInfo('01028748-v', 91), SenseInfo('00971015-v', 51), SenseInfo('00789448-v', 38), SenseInfo('00913065-v', 25), SenseInfo('00792471-v', 25), SenseInfo('02487573-v', 9), SenseInfo('02429810-v', 9), SenseInfo('01067995-v', 1), SenseInfo('01062739-v', 1), SenseInfo('00975036-v', 1), SenseInfo('02643421-v', 0), SenseInfo('02601456-v', 0), SenseInfo('02487901-v', 0), SenseInfo('02359061-v', 0), SenseInfo('02300060-v', 0), SenseInfo('01899017-v', 0), SenseInfo('01068793-v', 0), SenseInfo('00917772-v', 0), SenseInfo('00874002-v', 0), SenseInfo('00869393-v', 0), SenseInfo('00822746-v', 0), SenseInfo('00783523-v', 0), SenseInfo('00754156-v', 0), SenseInfo('00753881-v', 0), SenseInfo('00738747-v', 0), SenseInfo('00738583-v', 0), SenseInfo('00691516-v', 0), SenseInfo('00107231-v', 0), SenseInfo('01028748-v', 91), SenseInfo('00971015-v', 51), SenseInfo('00789448-v', 38), SenseInfo('00913065-v', 25), SenseInfo('00792471-v', 25), SenseInfo('02487573-v', 9), SenseInfo('02429810-v', 9), SenseInfo('01067995-v', 1), SenseInfo('01062739-v', 1), SenseInfo('00975036-v', 1), SenseInfo('02643421-v', 0), SenseInfo('02601456-v', 0), SenseInfo('02487901-v', 0), SenseInfo('02359061-v', 0), SenseInfo('02300060-v', 0), SenseInfo('01899017-v', 0), SenseInfo('01068793-v', 0), SenseInfo('00917772-v', 0), SenseInfo('00874002-v', 0), SenseInfo('00869393-v', 0), SenseInfo('00822746-v', 0), SenseInfo('00783523-v', 0), SenseInfo('00754156-v', 0), SenseInfo('00753881-v', 0), SenseInfo('00738747-v', 0), SenseInfo('00738583-v', 0), SenseInfo('00691516-v', 0), SenseInfo('00107231-v', 0) ],
"_leach_v_1_rel" : [ SenseInfo('02071837-v', 0), SenseInfo('02071627-v', 0), SenseInfo('00488617-v', 0) ],
"_pretentious_a_1_rel" : [ SenseInfo('01849288-a', 0), SenseInfo('01848355-a', 0), SenseInfo('02394975-a', 0) ],
"_bowler_n_1_rel" : [ SenseInfo('09870096-n', 0), SenseInfo('09869961-n', 0), SenseInfo('02881757-n', 0) ],
"_hogback_a_1_rel" : [ SenseInfo('09304376-n', 0) ],
"_likes_n_of_rel" : [ SenseInfo('05845888-n', 0), SenseInfo('05845419-n', 0) ],
"_stay_v_1_rel" : [ SenseInfo('00117985-v', 43), SenseInfo('01857392-v', 32), SenseInfo('02637202-v', 22), SenseInfo('02727462-v', 17), SenseInfo('02009200-v', 7), SenseInfo('00460900-v', 3), SenseInfo('02731024-v', 0), SenseInfo('02619122-v', 0), SenseInfo('02560021-v', 0), SenseInfo('01344643-v', 0), SenseInfo('01194114-v', 0), SenseInfo('00117985-v', 43), SenseInfo('01857392-v', 32), SenseInfo('02637202-v', 22), SenseInfo('02727462-v', 17), SenseInfo('02009200-v', 7), SenseInfo('00460900-v', 3), SenseInfo('02731024-v', 0), SenseInfo('02619122-v', 0), SenseInfo('02560021-v', 0), SenseInfo('01344643-v', 0), SenseInfo('01194114-v', 0) ],
"_vest_v_with_rel" : [ SenseInfo('02386388-v', 3), SenseInfo('02362916-v', 0), SenseInfo('02222179-v', 0), SenseInfo('00052253-v', 0), SenseInfo('00052043-v', 0), SenseInfo('02386388-v', 3), SenseInfo('02362916-v', 0), SenseInfo('02222179-v', 0), SenseInfo('00052253-v', 0), SenseInfo('00052043-v', 0) ],
"_turn_v_in_rel" : [ SenseInfo('01907258-v', 187), SenseInfo('00146138-v', 21), SenseInfo('02626604-v', 12), SenseInfo('02089984-v', 8), SenseInfo('00138508-v', 7), SenseInfo('01909812-v', 5), SenseInfo('00125841-v', 5), SenseInfo('01436518-v', 2), SenseInfo('02096167-v', 1), SenseInfo('02089420-v', 1), SenseInfo('01952208-v', 1), SenseInfo('01741864-v', 1), SenseInfo('01584450-v', 1), SenseInfo('00282523-v', 1), SenseInfo('00091124-v', 1), SenseInfo('02626934-v', 0), SenseInfo('02562425-v', 0), SenseInfo('02211948-v', 0), SenseInfo('02090435-v', 0), SenseInfo('01951937-v', 0), SenseInfo('01280014-v', 0), SenseInfo('01225215-v', 0), SenseInfo('01151889-v', 0), SenseInfo('00794640-v', 0), SenseInfo('00458471-v', 0), SenseInfo('00248387-v', 0) ],
"_fog_n_1_rel" : [ SenseInfo('11458314-n', 15), SenseInfo('14521648-n', 3), SenseInfo('05684561-n', 2) ],
"_housekeeping_n_1_rel" : [ SenseInfo('00580961-n', 2) ],
"_base-line_n_1_rel" : [ SenseInfo('13854318-n', 1), SenseInfo('08650919-n', 0), SenseInfo('08573140-n', 0) ],
"_hmm_a_1_rel" : [  ],
"_wacky_a_1_rel" : [ SenseInfo('02571536-a', 1), SenseInfo('02074929-a', 0), SenseInfo('02571536-a', 1), SenseInfo('02074929-a', 0), SenseInfo('02571536-a', 1), SenseInfo('02074929-a', 0) ],
"_boat_n_1_rel" : [ SenseInfo('02858304-n', 14), SenseInfo('03456024-n', 0) ],
"_top_n_1_rel" : [ SenseInfo('08663860-n', 23), SenseInfo('08663354-n', 15), SenseInfo('08617963-n', 8), SenseInfo('15256022-n', 3), SenseInfo('13940456-n', 3), SenseInfo('05037617-n', 1), SenseInfo('04454540-n', 0), SenseInfo('04454240-n', 0), SenseInfo('04453910-n', 0), SenseInfo('04453666-n', 0), SenseInfo('03035252-n', 0), SenseInfo('08663860-n', 23), SenseInfo('08663354-n', 15), SenseInfo('08617963-n', 8), SenseInfo('15256022-n', 3), SenseInfo('13940456-n', 3), SenseInfo('05037617-n', 1), SenseInfo('04454540-n', 0), SenseInfo('04454240-n', 0), SenseInfo('04453910-n', 0), SenseInfo('04453666-n', 0), SenseInfo('03035252-n', 0) ],
"_blend_v_1_rel" : [ SenseInfo('01462468-v', 7), SenseInfo('02700455-v', 1), SenseInfo('00394813-v', 0) ],
"_ex+president_n_1_rel" : [ SenseInfo('09618880-n', 0), SenseInfo('09618880-n', 0) ],
"_measure_v_1_rel" : [ SenseInfo('00647094-v', 35), SenseInfo('00489837-v', 20), SenseInfo('02704349-v', 14), SenseInfo('00681429-v', 10) ],
"_resolution_n_of_rel" : [ SenseInfo('06511874-n', 12), SenseInfo('11505769-n', 2), SenseInfo('04861486-n', 2), SenseInfo('00153809-n', 2), SenseInfo('05789089-n', 1), SenseInfo('05782884-n', 1), SenseInfo('11505952-n', 0), SenseInfo('07420217-n', 0), SenseInfo('07028221-n', 0), SenseInfo('06743506-n', 0), SenseInfo('00180228-n', 0) ],
"_periwinkle_n_1_rel" : [ SenseInfo('11777929-n', 1), SenseInfo('11772408-n', 0), SenseInfo('07782668-n', 0), SenseInfo('01948446-n', 0) ],
"_rev_n_1_rel" : [ SenseInfo('15281870-n', 0), SenseInfo('15281870-n', 0) ],
"_website_n_1_rel" : [ SenseInfo('06359193-n', 0) ],
"_story_n_of_rel" : [ SenseInfo('07221094-n', 36), SenseInfo('06369829-n', 14), SenseInfo('03365991-n', 7), SenseInfo('06514093-n', 3), SenseInfo('06681551-n', 2), SenseInfo('06757057-n', 1), SenseInfo('07221094-n', 36), SenseInfo('06369829-n', 14), SenseInfo('03365991-n', 7), SenseInfo('06514093-n', 3), SenseInfo('06681551-n', 2), SenseInfo('06757057-n', 1) ],
"_journalism_n_1_rel" : [ SenseInfo('06266417-n', 4), SenseInfo('00611674-n', 0) ],
"_territorial_a_1_rel" : [ SenseInfo('02812482-a', 2), SenseInfo('02409500-a', 0), SenseInfo('02408611-a', 0) ],
"_peer_n_1_rel" : [ SenseInfo('09626238-n', 4), SenseInfo('10412910-n', 0) ],
"_explore_v_1_rel" : [ SenseInfo('00648224-v', 14), SenseInfo('00649481-v', 4), SenseInfo('00646271-v', 2), SenseInfo('00645939-v', 0), SenseInfo('00648224-v', 14), SenseInfo('00649481-v', 4), SenseInfo('00646271-v', 2), SenseInfo('00645939-v', 0), SenseInfo('00648224-v', 14), SenseInfo('00649481-v', 4), SenseInfo('00646271-v', 2), SenseInfo('00645939-v', 0), SenseInfo('00648224-v', 14), SenseInfo('00649481-v', 4), SenseInfo('00646271-v', 2), SenseInfo('00645939-v', 0) ],
"_lowbrow_a_1_rel" : [ SenseInfo('01334075-a', 0) ],
"_knocker_n_1_rel" : [ SenseInfo('10239928-n', 0), SenseInfo('10239761-n', 0), SenseInfo('10009671-n', 0), SenseInfo('05554405-n', 0), SenseInfo('03626760-n', 0) ],
"_longstanding_a_1_rel" : [ SenseInfo('01441271-a', 1) ],
"_ever+before_p_rel" : [  ],
"_conscience_n_1_rel" : [ SenseInfo('09184136-n', 12), SenseInfo('04848492-n', 6), SenseInfo('07506797-n', 1) ],
"_flutter_n_1_rel" : [ SenseInfo('00348571-n', 1), SenseInfo('14111355-n', 0), SenseInfo('13977366-n', 0), SenseInfo('07439284-n', 0) ],
"_week_n_1_rel" : [ SenseInfo('15169873-n', 103), SenseInfo('15135996-n', 3), SenseInfo('15136147-n', 1) ],
"_nanostructure_v_1_rel" : [  ],
"_wheelhouse_n_1_rel" : [ SenseInfo('03939677-n', 0) ],
"_d_a_parens_rel" : [ SenseInfo('02198631-a', 0), SenseInfo('02198631-a', 0) ],
"_slow_v_up_rel" : [ SenseInfo('00439958-v', 9), SenseInfo('00440580-v', 2), SenseInfo('00440786-v', 1) ],
"_dissociate_v_cause_rel" : [ SenseInfo('02430580-v', 0), SenseInfo('00714273-v', 0), SenseInfo('00209598-v', 0) ],
"_profane_n_1_rel" : [ SenseInfo('00425002-a', 1), SenseInfo('02056880-a', 0), SenseInfo('02054926-a', 0), SenseInfo('02012748-a', 0) ],
"_retard_v_1_rel" : [ SenseInfo('00438752-v', 1), SenseInfo('02752567-v', 0), SenseInfo('00440286-v', 0), SenseInfo('00439958-v', 0) ],
"_jury-rig_v_1_rel" : [  ],
"_further_v_1_rel" : [ SenseInfo('02554422-v', 7), SenseInfo('02554922-v', 2), SenseInfo('02554422-v', 7), SenseInfo('02554922-v', 2) ],
"_straightforward_a_1_rel" : [ SenseInfo('00897223-a', 2), SenseInfo('00766102-a', 2), SenseInfo('02318728-a', 0), SenseInfo('00761734-a', 0), SenseInfo('00897223-a', 2), SenseInfo('00766102-a', 2), SenseInfo('02318728-a', 0), SenseInfo('00761734-a', 0) ],
"_democrat_n_1_rel" : [ SenseInfo('10002151-n', 4), SenseInfo('10002031-n', 1) ],
"_customize_v_1_rel" : [ SenseInfo('01623489-v', 0), SenseInfo('00387919-v', 0) ],
"_quarrel_n_1_rel" : [ SenseInfo('07184149-n', 2), SenseInfo('04031481-n', 0) ],
"_babysit_v_1_rel" : [  ],
"_come_v_1_rel" : [ SenseInfo('01849221-v', 276), SenseInfo('02005948-v', 235), SenseInfo('00341917-v', 147), SenseInfo('00542120-v', 41), SenseInfo('02625339-v', 40), SenseInfo('00342812-v', 11), SenseInfo('02743921-v', 9), SenseInfo('02743214-v', 7), SenseInfo('02686805-v', 6), SenseInfo('02743565-v', 3), SenseInfo('01839690-v', 3), SenseInfo('02729963-v', 2), SenseInfo('00344886-v', 2), SenseInfo('02645007-v', 1), SenseInfo('02627363-v', 1), SenseInfo('02006709-v', 1), SenseInfo('00723349-v', 1), SenseInfo('02737187-v', 0), SenseInfo('02617567-v', 0), SenseInfo('02197360-v', 0), SenseInfo('00659984-v', 0), SenseInfo('01849221-v', 276), SenseInfo('02005948-v', 235), SenseInfo('00341917-v', 147), SenseInfo('00542120-v', 41), SenseInfo('02625339-v', 40), SenseInfo('00342812-v', 11), SenseInfo('02743921-v', 9), SenseInfo('02743214-v', 7), SenseInfo('02686805-v', 6), SenseInfo('02743565-v', 3), SenseInfo('01839690-v', 3), SenseInfo('02729963-v', 2), SenseInfo('00344886-v', 2), SenseInfo('02645007-v', 1), SenseInfo('02627363-v', 1), SenseInfo('02006709-v', 1), SenseInfo('00723349-v', 1), SenseInfo('02737187-v', 0), SenseInfo('02617567-v', 0), SenseInfo('02197360-v', 0), SenseInfo('00659984-v', 0), SenseInfo('01849221-v', 276), SenseInfo('02005948-v', 235), SenseInfo('00341917-v', 147), SenseInfo('00542120-v', 41), SenseInfo('02625339-v', 40), SenseInfo('00342812-v', 11), SenseInfo('02743921-v', 9), SenseInfo('02743214-v', 7), SenseInfo('02686805-v', 6), SenseInfo('02743565-v', 3), SenseInfo('01839690-v', 3), SenseInfo('02729963-v', 2), SenseInfo('00344886-v', 2), SenseInfo('02645007-v', 1), SenseInfo('02627363-v', 1), SenseInfo('02006709-v', 1), SenseInfo('00723349-v', 1), SenseInfo('02737187-v', 0), SenseInfo('02617567-v', 0), SenseInfo('02197360-v', 0), SenseInfo('00659984-v', 0), SenseInfo('01849221-v', 276), SenseInfo('02005948-v', 235), SenseInfo('00341917-v', 147), SenseInfo('00542120-v', 41), SenseInfo('02625339-v', 40), SenseInfo('00342812-v', 11), SenseInfo('02743921-v', 9), SenseInfo('02743214-v', 7), SenseInfo('02686805-v', 6), SenseInfo('02743565-v', 3), SenseInfo('01839690-v', 3), SenseInfo('02729963-v', 2), SenseInfo('00344886-v', 2), SenseInfo('02645007-v', 1), SenseInfo('02627363-v', 1), SenseInfo('02006709-v', 1), SenseInfo('00723349-v', 1), SenseInfo('02737187-v', 0), SenseInfo('02617567-v', 0), SenseInfo('02197360-v', 0), SenseInfo('00659984-v', 0) ],
"_resolve_v_1_rel" : [ SenseInfo('00698855-v', 8), SenseInfo('01021420-v', 6), SenseInfo('00699626-v', 6), SenseInfo('00635523-v', 3), SenseInfo('02193612-v', 1), SenseInfo('00733044-v', 1), SenseInfo('00447309-v', 0), SenseInfo('00698855-v', 8), SenseInfo('01021420-v', 6), SenseInfo('00699626-v', 6), SenseInfo('00635523-v', 3), SenseInfo('02193612-v', 1), SenseInfo('00733044-v', 1), SenseInfo('00447309-v', 0) ],
"_tout_n_1_rel" : [ SenseInfo('10718509-n', 0), SenseInfo('10718349-n', 0), SenseInfo('10712835-n', 0) ],
"_glimmer_n_1_rel" : [ SenseInfo('07412478-n', 1), SenseInfo('05916306-n', 0) ],
"_aggregate_n_1_rel" : [ SenseInfo('04353803-n', 1), SenseInfo('14594925-n', 0), SenseInfo('08418103-n', 0) ],
"_pride_v_on_rel" : [ SenseInfo('01772498-v', 2) ],
"_predefined_a_1_rel" : [  ],
"_incite_v_to_rel" : [ SenseInfo('01649999-v', 2), SenseInfo('00851239-v', 2), SenseInfo('01230710-v', 0), SenseInfo('01649999-v', 2), SenseInfo('00851239-v', 2), SenseInfo('01230710-v', 0), SenseInfo('01649999-v', 2), SenseInfo('00851239-v', 2), SenseInfo('01230710-v', 0) ],
"_salt_n_1_rel" : [ SenseInfo('15010703-n', 9), SenseInfo('07813107-n', 5), SenseInfo('07149582-n', 0), SenseInfo('05717342-n', 0) ],
"_peruvian_n_1_rel" : [ SenseInfo('09726499-n', 0) ],
"_geodetic_a_1_rel" : [ SenseInfo('02993362-a', 0) ],
"_sociology_n_1_rel" : [ SenseInfo('06151693-n', 0) ],
"_hurried_a_1_rel" : [ SenseInfo('01270175-a', 3) ],
"_frequent_v_1_rel" : [ SenseInfo('02466134-v', 1), SenseInfo('01844431-v', 1) ],
"_chin_v_1_rel" : [ SenseInfo('01975387-v', 2) ],
"_decorum_n_1_rel" : [ SenseInfo('04898804-n', 1) ],
"_tee_v_off_rel" : [ SenseInfo('01499692-v', 0), SenseInfo('01355810-v', 0), SenseInfo('01499692-v', 0), SenseInfo('01355810-v', 0) ],
"_ground_a_1_rel" : [ SenseInfo('09334396-n', 86), SenseInfo('09178999-n', 11), SenseInfo('14842992-n', 7), SenseInfo('13790912-n', 1), SenseInfo('08580134-n', 1), SenseInfo('05933834-n', 1), SenseInfo('09335240-n', 0), SenseInfo('05930574-n', 0), SenseInfo('03462747-n', 0), SenseInfo('03462594-n', 0), SenseInfo('03360845-n', 0) ],
"_hesitant_a_1_rel" : [ SenseInfo('00686573-a', 0) ],
"_gluemaker_n_1_rel" : [  ],
"_extract_n_1_rel" : [ SenseInfo('14848785-n', 3), SenseInfo('06400510-n', 0) ],
"_for+the+time+being_a_1_rel" : [  ],
"_inventory_n_1_rel" : [ SenseInfo('06492664-n', 5), SenseInfo('04321534-n', 2), SenseInfo('13412533-n', 1), SenseInfo('05634059-n', 1), SenseInfo('01011425-n', 0) ],
"_every_q_rel" : [  ],
"_rhyme_n_1_rel" : [ SenseInfo('07096661-n', 1), SenseInfo('06381869-n', 1) ],
"_skater_n_1_rel" : [ SenseInfo('10604491-n', 0) ],
"_hence_x_rel" : [ SenseInfo('00043003-r', 25), SenseInfo('00043521-r', 0), SenseInfo('00043436-r', 0), SenseInfo('00043003-r', 25), SenseInfo('00043521-r', 0), SenseInfo('00043436-r', 0) ],
"_hand_v_1_rel" : [ SenseInfo('02230772-v', 25), SenseInfo('02000133-v', 0) ],
"_snare_v_1_rel" : [ SenseInfo('01480770-v', 1), SenseInfo('00783042-v', 0) ],
"_hatch_n_1_rel" : [ SenseInfo('13491464-n', 0), SenseInfo('04681797-n', 0), SenseInfo('03498536-n', 0) ],
"_hard-charging_a_1_rel" : [  ],
"_celebrant_n_1_rel" : [ SenseInfo('09902954-n', 2), SenseInfo('09902851-n', 0) ],
"_incompetence_n_1_rel" : [ SenseInfo('05154241-n', 1), SenseInfo('14076126-n', 0) ],
"_lengthwise_a_1_rel" : [ SenseInfo('01444813-a', 0), SenseInfo('01444813-a', 0), SenseInfo('01444813-a', 0) ],
"_twenty-two_n_gun_rel" : [ SenseInfo('13748367-n', 1), SenseInfo('04502851-n', 0), SenseInfo('13748367-n', 1), SenseInfo('04502851-n', 0) ],
"_winghook_n_1_rel" : [  ],
"_musk_n_1_rel" : [ SenseInfo('14846646-n', 0), SenseInfo('05714332-n', 0) ],
"_sure_a_of_rel" : [ SenseInfo('00336831-a', 51), SenseInfo('00309740-a', 23), SenseInfo('00340239-a', 4), SenseInfo('02094633-a', 1), SenseInfo('00724397-a', 1), SenseInfo('02465978-a', 0), SenseInfo('02461586-a', 0), SenseInfo('02302822-a', 0), SenseInfo('00335895-a', 0), SenseInfo('00336831-a', 51), SenseInfo('00309740-a', 23), SenseInfo('00340239-a', 4), SenseInfo('02094633-a', 1), SenseInfo('00724397-a', 1), SenseInfo('02465978-a', 0), SenseInfo('02461586-a', 0), SenseInfo('02302822-a', 0), SenseInfo('00335895-a', 0), SenseInfo('00336831-a', 51), SenseInfo('00309740-a', 23), SenseInfo('00340239-a', 4), SenseInfo('02094633-a', 1), SenseInfo('00724397-a', 1), SenseInfo('02465978-a', 0), SenseInfo('02461586-a', 0), SenseInfo('02302822-a', 0), SenseInfo('00335895-a', 0) ],
"_traitor_n_1_rel" : [ SenseInfo('10722965-n', 4), SenseInfo('10027590-n', 0) ],
"_irrespective_a_of_rel" : [  ],
"_come_v_in_rel" : [ SenseInfo('01849221-v', 276), SenseInfo('02005948-v', 235), SenseInfo('00341917-v', 147), SenseInfo('00542120-v', 41), SenseInfo('02625339-v', 40), SenseInfo('00342812-v', 11), SenseInfo('02743921-v', 9), SenseInfo('02743214-v', 7), SenseInfo('02686805-v', 6), SenseInfo('02743565-v', 3), SenseInfo('01839690-v', 3), SenseInfo('02729963-v', 2), SenseInfo('00344886-v', 2), SenseInfo('02645007-v', 1), SenseInfo('02627363-v', 1), SenseInfo('02006709-v', 1), SenseInfo('00723349-v', 1), SenseInfo('02737187-v', 0), SenseInfo('02617567-v', 0), SenseInfo('02197360-v', 0), SenseInfo('00659984-v', 0) ],
"_pose_v_to_rel" : [ SenseInfo('02722663-v', 7), SenseInfo('02142775-v', 4), SenseInfo('00837288-v', 1), SenseInfo('02519183-v', 0), SenseInfo('01494310-v', 0), SenseInfo('00622384-v', 0) ],
"_tune_v_out_rel" : [ SenseInfo('00295966-v', 1), SenseInfo('00295346-v', 0), SenseInfo('00295966-v', 1), SenseInfo('00295346-v', 0) ],
"_pear_n_1_rel" : [ SenseInfo('07767847-n', 3), SenseInfo('12651611-n', 0) ],
"_kayaker_n_1_rel" : [  ],
"_frisbee_n_1_rel" : [ SenseInfo('03397947-n', 0) ],
"_singe_v_1_rel" : [ SenseInfo('00378521-v', 1), SenseInfo('00582743-v', 0) ],
"_target_n_of_rel" : [ SenseInfo('07262108-n', 6), SenseInfo('10470460-n', 4), SenseInfo('08660934-n', 4), SenseInfo('04394261-n', 3), SenseInfo('05981230-n', 2), SenseInfo('07262108-n', 6), SenseInfo('10470460-n', 4), SenseInfo('08660934-n', 4), SenseInfo('04394261-n', 3), SenseInfo('05981230-n', 2), SenseInfo('07262108-n', 6), SenseInfo('10470460-n', 4), SenseInfo('08660934-n', 4), SenseInfo('04394261-n', 3), SenseInfo('05981230-n', 2) ],
"_multitask_v_cause_rel" : [  ],
"_next_x_deg_rel" : [ SenseInfo('00127948-a', 90), SenseInfo('00447472-a', 24), SenseInfo('00054212-r', 11), SenseInfo('01294975-a', 7) ],
"_sward_n_1_rel" : [ SenseInfo('09463919-n', 2) ],
"_theorem_n_1_rel" : [ SenseInfo('06752293-n', 14), SenseInfo('05918267-n', 0) ],
"_along_p_sel_rel" : [ SenseInfo('00068368-r', 25), SenseInfo('00068577-r', 9), SenseInfo('00068986-r', 2), SenseInfo('00068753-r', 2), SenseInfo('00069164-r', 0) ],
"_syntactic_a_1_rel" : [ SenseInfo('02880557-a', 1) ],
"_composure_n_1_rel" : [ SenseInfo('04903813-n', 3) ],
"_metaphor_n_1_rel" : [ SenseInfo('07106800-n', 3) ],
"_expend_v_1_rel" : [ SenseInfo('01158572-v', 7), SenseInfo('02267060-v', 2) ],
"_overreaction_n_1_rel" : [ SenseInfo('00859863-n', 0) ],
"_taffy_n_1_rel" : [ SenseInfo('07609407-n', 2) ],
"_net_v_out_rel" : [ SenseInfo('02291258-v', 1), SenseInfo('02291548-v', 0), SenseInfo('01672168-v', 0), SenseInfo('01365945-v', 0) ],
"_bus_v_in_rel" : [ SenseInfo('01950128-v', 0), SenseInfo('01949110-v', 0), SenseInfo('00180728-v', 0) ],
"_annoy_v_1_rel" : [ SenseInfo('01787955-v', 5), SenseInfo('01787955-v', 5), SenseInfo('01787955-v', 5), SenseInfo('01787955-v', 5), SenseInfo('01787955-v', 5) ],
"_route_v_1_rel" : [ SenseInfo('01955364-v', 0), SenseInfo('01952750-v', 0), SenseInfo('01952564-v', 0), SenseInfo('01955364-v', 0), SenseInfo('01952750-v', 0), SenseInfo('01952564-v', 0) ],
"_childish_a_1_rel" : [ SenseInfo('01493016-a', 8) ],
"_screw_v_in_rel" : [ SenseInfo('01426397-v', 0), SenseInfo('01353169-v', 0), SenseInfo('01352996-v', 0), SenseInfo('01352806-v', 0), SenseInfo('01104624-v', 0) ],
"_scurry_v_1_rel" : [ SenseInfo('01902405-v', 2) ],
"_magnate_n_1_rel" : [ SenseInfo('09840217-n', 0) ],
"_jail_v_1_rel" : [ SenseInfo('02494356-v', 1) ],
"_fox_n_1_rel" : [ SenseInfo('02118333-n', 3), SenseInfo('10022759-n', 1), SenseInfo('14764910-n', 0), SenseInfo('10976997-n', 0), SenseInfo('10976862-n', 0), SenseInfo('09655569-n', 0), SenseInfo('06909848-n', 0) ],
"_carry+on_n_1_rel" : [  ],
"_elk_n_1_rel" : [ SenseInfo('02432983-n', 0), SenseInfo('02431785-n', 0), SenseInfo('02431122-n', 0) ],
"_lethargy_n_1_rel" : [ SenseInfo('14014990-n', 2), SenseInfo('05042138-n', 1), SenseInfo('04635953-n', 0) ],
"_crow_n_1_rel" : [ SenseInfo('01579028-n', 2), SenseInfo('07382286-n', 1), SenseInfo('09654259-n', 0), SenseInfo('09257429-n', 0), SenseInfo('07229747-n', 0), SenseInfo('06909391-n', 0) ],
"_totter_v_1_rel" : [ SenseInfo('01919042-v', 4), SenseInfo('01918803-v', 0), SenseInfo('01881034-v', 0) ],
"_boatbuilding_n_1_rel" : [  ],
"_deranged_a_1_rel" : [ SenseInfo('02075847-a', 2) ],
"_putative_a_1_rel" : [ SenseInfo('00028471-a', 0) ],
"_hold+up_n_1_rel" : [ SenseInfo('00781912-n', 1), SenseInfo('01066163-n', 0), SenseInfo('00781912-n', 1), SenseInfo('01066163-n', 0) ],
"_apologize_v_1_rel" : [ SenseInfo('00892923-v', 3), SenseInfo('00894738-v', 0), SenseInfo('00892923-v', 3), SenseInfo('00894738-v', 0) ],
"_legislative_a_1_rel" : [ SenseInfo('02829565-a', 5), SenseInfo('02829422-a', 3) ],
"_gunnery_n_1_rel" : [ SenseInfo('03469832-n', 0) ],
"_throw_v_over_rel" : [ SenseInfo('01508368-v', 53), SenseInfo('02097204-v', 9), SenseInfo('01513430-v', 7), SenseInfo('01499265-v', 7), SenseInfo('01060317-v', 6), SenseInfo('01510173-v', 5), SenseInfo('01632897-v', 4), SenseInfo('02097341-v', 2), SenseInfo('01791232-v', 2), SenseInfo('01067664-v', 2), SenseInfo('01733477-v', 1), SenseInfo('01663443-v', 0), SenseInfo('01527754-v', 0), SenseInfo('01437011-v', 0), SenseInfo('00621734-v', 0) ],
"_possibly_x_deg_rel" : [ SenseInfo('00300247-r', 26), SenseInfo('00300496-r', 0) ],
"_single_a_1_rel" : [ SenseInfo('00493460-a', 74), SenseInfo('02220571-a', 0), SenseInfo('02213947-a', 0), SenseInfo('01482228-a', 0), SenseInfo('02153174-a', 0), SenseInfo('01966740-a', 0), SenseInfo('00539389-a', 0), SenseInfo('00493460-a', 74), SenseInfo('02220571-a', 0), SenseInfo('02213947-a', 0), SenseInfo('01482228-a', 0), SenseInfo('02153174-a', 0), SenseInfo('01966740-a', 0), SenseInfo('00539389-a', 0) ],
"_powerless_n_1_rel" : [ SenseInfo('01827535-a', 1) ],
"_exactly_a_1_rel" : [  ],
"_yearbook_n_1_rel" : [ SenseInfo('07282497-n', 0), SenseInfo('06426468-n', 0) ],
"_define_v_away_rel" : [ SenseInfo('02611630-v', 20), SenseInfo('00957378-v', 13), SenseInfo('02698319-v', 9), SenseInfo('02736778-v', 2), SenseInfo('00947077-v', 0) ],
"_tunnyfish_n_1_rel" : [  ],
"_outwash_n_1_rel" : [  ],
"_bearing_n_1_rel" : [ SenseInfo('13795695-n', 1), SenseInfo('08680888-n', 1), SenseInfo('04910377-n', 1), SenseInfo('05002822-n', 0), SenseInfo('03008565-n', 0), SenseInfo('02817031-n', 0) ],
"_pronounced_a_1_rel" : [ SenseInfo('01287808-a', 4) ],
"_unsteady_a_1_rel" : [ SenseInfo('02303077-a', 0), SenseInfo('01061310-a', 0), SenseInfo('02303077-a', 0), SenseInfo('01061310-a', 0), SenseInfo('02303077-a', 0), SenseInfo('01061310-a', 0), SenseInfo('02303077-a', 0), SenseInfo('01061310-a', 0), SenseInfo('02303077-a', 0), SenseInfo('01061310-a', 0), SenseInfo('02303077-a', 0), SenseInfo('01061310-a', 0) ],
"_indirect_a_1_rel" : [ SenseInfo('00770993-a', 8), SenseInfo('00762355-a', 2), SenseInfo('01417228-a', 0), SenseInfo('00766457-a', 0), SenseInfo('01854546-a', 0), SenseInfo('00770993-a', 8), SenseInfo('00762355-a', 2), SenseInfo('01417228-a', 0), SenseInfo('00766457-a', 0), SenseInfo('01854546-a', 0) ],
"_at+the+very+least_a_1_rel" : [  ],
"_duet_n_1_rel" : [ SenseInfo('13743605-n', 0), SenseInfo('08247021-n', 0), SenseInfo('07985628-n', 0), SenseInfo('07041451-n', 0), SenseInfo('00529224-n', 0) ],
"_crisp_n_1_rel" : [ SenseInfo('07712559-n', 1) ],
"_juncture_n_1_rel" : [ SenseInfo('07416714-n', 1), SenseInfo('14033185-n', 0), SenseInfo('13911151-n', 0) ],
"_learners_a_1_rel" : [  ],
"_louse_v_up_rel" : [  ],
"_spot_v_1_rel" : [ SenseInfo('02154312-v', 18), SenseInfo('02193194-v', 0), SenseInfo('01538161-v', 0), SenseInfo('01531998-v', 0), SenseInfo('00509958-v', 0), SenseInfo('00509607-v', 0), SenseInfo('02154312-v', 18), SenseInfo('02193194-v', 0), SenseInfo('01538161-v', 0), SenseInfo('01531998-v', 0), SenseInfo('00509958-v', 0), SenseInfo('00509607-v', 0) ],
"_rural_a_1_rel" : [ SenseInfo('02050452-a', 18), SenseInfo('02790726-a', 7) ],
"_resolute_a_1_rel" : [ SenseInfo('01989669-a', 1), SenseInfo('00685924-a', 0), SenseInfo('01989669-a', 1), SenseInfo('00685924-a', 0) ],
"_foul_a_of_rel" : [ SenseInfo('01625893-a', 1), SenseInfo('01053634-a', 1), SenseInfo('00957743-a', 1), SenseInfo('00955915-a', 0), SenseInfo('01405390-a', 0), SenseInfo('00425313-a', 0), SenseInfo('00421590-a', 0), SenseInfo('00255308-a', 0), SenseInfo('01625893-a', 1), SenseInfo('01053634-a', 1), SenseInfo('00957743-a', 1), SenseInfo('00955915-a', 0), SenseInfo('01405390-a', 0), SenseInfo('00425313-a', 0), SenseInfo('00421590-a', 0), SenseInfo('00255308-a', 0), SenseInfo('01625893-a', 1), SenseInfo('01053634-a', 1), SenseInfo('00957743-a', 1), SenseInfo('00955915-a', 0), SenseInfo('01405390-a', 0), SenseInfo('00425313-a', 0), SenseInfo('00421590-a', 0), SenseInfo('00255308-a', 0) ],
"_stumble_v_upon_rel" : [ SenseInfo('01901133-v', 11), SenseInfo('01900408-v', 9), SenseInfo('02206462-v', 2), SenseInfo('00618057-v', 0) ],
"_desk_n_1_rel" : [ SenseInfo('03179701-n', 24) ],
"_write_v_of_rel" : [ SenseInfo('01698271-v', 112), SenseInfo('00993014-v', 94), SenseInfo('01744611-v', 33), SenseInfo('01007027-v', 15), SenseInfo('01031966-v', 10), SenseInfo('01705494-v', 9), SenseInfo('01691057-v', 8), SenseInfo('00998886-v', 4), SenseInfo('01699896-v', 1), SenseInfo('01692834-v', 0), SenseInfo('01698271-v', 112), SenseInfo('00993014-v', 94), SenseInfo('01744611-v', 33), SenseInfo('01007027-v', 15), SenseInfo('01031966-v', 10), SenseInfo('01705494-v', 9), SenseInfo('01691057-v', 8), SenseInfo('00998886-v', 4), SenseInfo('01699896-v', 1), SenseInfo('01692834-v', 0) ],
"_burn_v_up_rel" : [ SenseInfo('00378664-v', 11), SenseInfo('02768874-v', 10), SenseInfo('00377002-v', 9), SenseInfo('02120451-v', 4), SenseInfo('02762468-v', 2), SenseInfo('01829292-v', 2), SenseInfo('00378042-v', 2), SenseInfo('02485322-v', 1), SenseInfo('02268881-v', 1), SenseInfo('02121048-v', 1), SenseInfo('00373766-v', 1), SenseInfo('00104299-v', 1), SenseInfo('01756277-v', 0), SenseInfo('01205000-v', 0), SenseInfo('00196364-v', 0), SenseInfo('00378664-v', 11), SenseInfo('02768874-v', 10), SenseInfo('00377002-v', 9), SenseInfo('02120451-v', 4), SenseInfo('02762468-v', 2), SenseInfo('01829292-v', 2), SenseInfo('00378042-v', 2), SenseInfo('02485322-v', 1), SenseInfo('02268881-v', 1), SenseInfo('02121048-v', 1), SenseInfo('00373766-v', 1), SenseInfo('00104299-v', 1), SenseInfo('01756277-v', 0), SenseInfo('01205000-v', 0), SenseInfo('00196364-v', 0) ],
"_leopard_n_1_rel" : [ SenseInfo('14765422-n', 0), SenseInfo('02128385-n', 0) ],
"_envy_v_1_rel" : [ SenseInfo('01827619-v', 9), SenseInfo('01827064-v', 0), SenseInfo('01827619-v', 9), SenseInfo('01827064-v', 0) ],
"_strained_a_1_rel" : [ SenseInfo('01141468-a', 3), SenseInfo('02407041-a', 2), SenseInfo('00073761-a', 0), SenseInfo('00073358-a', 0) ],
"_funereal_a_1_rel" : [ SenseInfo('01368464-a', 0) ],
"_sizeable_a_1_rel" : [ SenseInfo('01383394-a', 0), SenseInfo('00624576-a', 0) ],
"_well+off_a_1_rel" : [ SenseInfo('02022556-a', 0), SenseInfo('01049352-a', 0), SenseInfo('02022556-a', 0), SenseInfo('01049352-a', 0), SenseInfo('02022556-a', 0), SenseInfo('01049352-a', 0), SenseInfo('02022556-a', 0), SenseInfo('01049352-a', 0), SenseInfo('02022556-a', 0), SenseInfo('01049352-a', 0) ],
"_sediment_n_1_rel" : [ SenseInfo('09428967-n', 3) ],
"_ship_v_back_rel" : [ SenseInfo('01950798-v', 7), SenseInfo('02409838-v', 0), SenseInfo('01979462-v', 0), SenseInfo('01847582-v', 0), SenseInfo('01496978-v', 0) ],
"_refusal_n_of_rel" : [ SenseInfo('07205573-n', 4), SenseInfo('06634095-n', 1), SenseInfo('07205573-n', 4), SenseInfo('06634095-n', 1), SenseInfo('07205573-n', 4), SenseInfo('06634095-n', 1) ],
"_craft_n_1_rel" : [ SenseInfo('00606370-n', 3), SenseInfo('03125870-n', 1), SenseInfo('08436562-n', 0), SenseInfo('05638063-n', 0), SenseInfo('05621178-n', 0) ],
"_just+like_p_rel" : [  ],
"_hokey_a_1_rel" : [ SenseInfo('00854413-a', 0), SenseInfo('00073465-a', 0) ],
"_zing_n_1_rel" : [ SenseInfo('07400701-n', 0), SenseInfo('04635482-n', 0) ],
"_unreschedulable_a_1_rel" : [  ],
"_warm_v_over_rel" : [ SenseInfo('00373250-v', 2), SenseInfo('00372958-v', 1) ],
"_pica_n_1_rel" : [ SenseInfo('14055977-n', 0), SenseInfo('13712428-n', 0), SenseInfo('01582111-n', 0) ],
"_groupage_n_1_rel" : [  ],
"_drift_v_1_rel" : [ SenseInfo('01902783-v', 6), SenseInfo('01925694-v', 3), SenseInfo('01881180-v', 3), SenseInfo('02662821-v', 0), SenseInfo('02617338-v', 0), SenseInfo('01903218-v', 0), SenseInfo('01874875-v', 0), SenseInfo('01576779-v', 0), SenseInfo('00572502-v', 0), SenseInfo('00571390-v', 0) ],
"_nocturnal_a_1_rel" : [ SenseInfo('00678923-a', 1), SenseInfo('02931826-a', 0) ],
"_polymer_n_1_rel" : [ SenseInfo('14994328-n', 0) ],
"_unravel_v_1_rel" : [ SenseInfo('01520844-v', 1), SenseInfo('01521367-v', 0), SenseInfo('00332672-v', 0) ],
"_perhaps_a_1_rel" : [  ],
"_rafter_n_1_rel" : [ SenseInfo('04045644-n', 1), SenseInfo('10504545-n', 0) ],
"_inspiration_n_of_rel" : [ SenseInfo('05834567-n', 1), SenseInfo('03574004-n', 1), SenseInfo('05797473-n', 0), SenseInfo('05686690-n', 0), SenseInfo('01261845-n', 0), SenseInfo('00836788-n', 0) ],
"_fto_n_1_rel" : [ SenseInfo('08392137-n', 0) ],
"_archway_n_1_rel" : [ SenseInfo('02734217-n', 0) ],
"_appellation_n_1_rel" : [ SenseInfo('06338908-n', 0) ],
"_affect_n_1_rel" : [ SenseInfo('07479926-n', 1) ],
"_rumor_n_1_rel" : [ SenseInfo('07223450-n', 14), SenseInfo('07223450-n', 14), SenseInfo('07223450-n', 14), SenseInfo('07223450-n', 14) ],
"_sweat_v_out_rel" : [ SenseInfo('00067545-v', 5) ],
"_rule+of+thumb_n_1_rel" : [ SenseInfo('05848541-n', 0) ],
"_tweed_n_1_rel" : [ SenseInfo('04502502-n', 3), SenseInfo('03357081-n', 0) ],
"_gastronomic_a_1_rel" : [ SenseInfo('02975840-a', 0) ],
"_vomit_v_up_rel" : [ SenseInfo('00076400-v', 1) ],
"_churn_v_out_rel" : [ SenseInfo('01418389-v', 1), SenseInfo('01885430-v', 0) ],
"_wing_n_1_rel" : [ SenseInfo('02151625-n', 8), SenseInfo('04592741-n', 6), SenseInfo('04592962-n', 5), SenseInfo('08219493-n', 2), SenseInfo('08482113-n', 1), SenseInfo('10782135-n', 0), SenseInfo('08493825-n', 0), SenseInfo('08486306-n', 0), SenseInfo('07648549-n', 0), SenseInfo('03327841-n', 0), SenseInfo('02713594-n', 0), SenseInfo('02151625-n', 8), SenseInfo('04592741-n', 6), SenseInfo('04592962-n', 5), SenseInfo('08219493-n', 2), SenseInfo('08482113-n', 1), SenseInfo('10782135-n', 0), SenseInfo('08493825-n', 0), SenseInfo('08486306-n', 0), SenseInfo('07648549-n', 0), SenseInfo('03327841-n', 0), SenseInfo('02713594-n', 0) ],
"_do_v_up_rel" : [ SenseInfo('02560585-v', 526), SenseInfo('01712704-v', 173), SenseInfo('02561995-v', 134), SenseInfo('02617567-v', 58), SenseInfo('01645601-v', 35), SenseInfo('02568672-v', 20), SenseInfo('02669789-v', 11), SenseInfo('01619014-v', 9), SenseInfo('00010435-v', 3), SenseInfo('02709107-v', 2), SenseInfo('02523221-v', 2), SenseInfo('00038849-v', 2), SenseInfo('01841772-v', 1) ],
"_hiss_v_at_rel" : [ SenseInfo('01053771-v', 1), SenseInfo('02069014-v', 0), SenseInfo('01054186-v', 0), SenseInfo('00862225-v', 0) ],
"_empower_v_1_rel" : [ SenseInfo('02473981-v', 1), SenseInfo('02474239-v', 0), SenseInfo('02473981-v', 1), SenseInfo('02474239-v', 0), SenseInfo('02473981-v', 1), SenseInfo('02474239-v', 0), SenseInfo('02473981-v', 1), SenseInfo('02474239-v', 0), SenseInfo('02473981-v', 1), SenseInfo('02474239-v', 0), SenseInfo('02473981-v', 1), SenseInfo('02474239-v', 0) ],
"_alternate_v_between_rel" : [ SenseInfo('00121506-v', 3), SenseInfo('02393726-v', 0), SenseInfo('00604930-v', 0), SenseInfo('00121678-v', 0), SenseInfo('00121214-v', 0) ],
"_definition_n_of_rel" : [ SenseInfo('06744396-n', 11), SenseInfo('04702957-n', 10), SenseInfo('06744396-n', 11), SenseInfo('04702957-n', 10), SenseInfo('06744396-n', 11), SenseInfo('04702957-n', 10) ],
"_due+date_n_1_rel" : [ SenseInfo('15153225-n', 7) ],
"_conflicting_a_1_rel" : [ SenseInfo('00578234-a', 2), SenseInfo('01662912-a', 0) ],
"_carry_v_out_rel" : [ SenseInfo('01449974-v', 72), SenseInfo('02717102-v', 36), SenseInfo('02079933-v', 8), SenseInfo('01061017-v', 8), SenseInfo('01218084-v', 6), SenseInfo('01601234-v', 5), SenseInfo('02700867-v', 4), SenseInfo('02561168-v', 4), SenseInfo('00235110-v', 3), SenseInfo('02636325-v', 2), SenseInfo('01101416-v', 2), SenseInfo('00738951-v', 2), SenseInfo('02518161-v', 1), SenseInfo('02285392-v', 1), SenseInfo('01746359-v', 1), SenseInfo('01408760-v', 1), SenseInfo('01061320-v', 1), SenseInfo('02746735-v', 0), SenseInfo('02741357-v', 0), SenseInfo('02682954-v', 0), SenseInfo('02636516-v', 0), SenseInfo('02630734-v', 0), SenseInfo('02586121-v', 0), SenseInfo('02556537-v', 0), SenseInfo('02555684-v', 0), SenseInfo('02359228-v', 0), SenseInfo('02303878-v', 0), SenseInfo('02233195-v', 0), SenseInfo('02012725-v', 0), SenseInfo('02001699-v', 0), SenseInfo('01740320-v', 0), SenseInfo('01241881-v', 0), SenseInfo('01205153-v', 0), SenseInfo('01203074-v', 0), SenseInfo('01123609-v', 0), SenseInfo('01123415-v', 0), SenseInfo('01101571-v', 0), SenseInfo('01100672-v', 0), SenseInfo('01049606-v', 0), SenseInfo('00059019-v', 0) ],
"_pig_n_1_rel" : [ SenseInfo('02395406-n', 7), SenseInfo('10612210-n', 0), SenseInfo('10179649-n', 0), SenseInfo('09879144-n', 0), SenseInfo('03935116-n', 0), SenseInfo('03934998-n', 0) ],
"_chore_n_1_rel" : [ SenseInfo('00719705-n', 7), SenseInfo('00719705-n', 7), SenseInfo('00719705-n', 7) ],
"_defense_n_1_rel" : [ SenseInfo('00954311-n', 17), SenseInfo('00823750-n', 9), SenseInfo('08081403-n', 2), SenseInfo('06740644-n', 2), SenseInfo('13459322-n', 1), SenseInfo('08131530-n', 1), SenseInfo('08064523-n', 1), SenseInfo('07200813-n', 1), SenseInfo('08064130-n', 0), SenseInfo('03171356-n', 0), SenseInfo('01198750-n', 0), SenseInfo('00823532-n', 0), SenseInfo('00954311-n', 17), SenseInfo('00823750-n', 9), SenseInfo('08081403-n', 2), SenseInfo('06740644-n', 2), SenseInfo('13459322-n', 1), SenseInfo('08131530-n', 1), SenseInfo('08064523-n', 1), SenseInfo('07200813-n', 1), SenseInfo('08064130-n', 0), SenseInfo('03171356-n', 0), SenseInfo('01198750-n', 0), SenseInfo('00823532-n', 0) ],
"_grudge_n_1_rel" : [ SenseInfo('07549536-n', 3) ],
"_persian_a_1_rel" : [ SenseInfo('03075191-a', 0) ],
"_triband_n_1_rel" : [  ],
"_erysipelas_n_1_rel" : [ SenseInfo('14232299-n', 0) ],
"_temperamental_a_1_rel" : [ SenseInfo('02810552-a', 0), SenseInfo('00856325-a', 0), SenseInfo('00725227-a', 0) ],
"_roof_v_1_rel" : [ SenseInfo('01233993-v', 1) ],
"_hand-tighten_v_1_rel" : [  ],
"_passenger_n_1_rel" : [ SenseInfo('10403876-n', 4) ],
"_postmark_n_1_rel" : [ SenseInfo('07270718-n', 1) ],
"_laser_n_1_rel" : [ SenseInfo('03643253-n', 0) ],
"_zoom_v_1_rel" : [ SenseInfo('02055521-v', 2), SenseInfo('02056209-v', 0), SenseInfo('01943718-v', 0) ],
"_turret_n_1_rel" : [ SenseInfo('04501947-n', 0), SenseInfo('03469175-n', 0) ],
"_chemist_n_1_rel" : [ SenseInfo('09913824-n', 4), SenseInfo('10421470-n', 1) ],
"_unconsidered_a_1_rel" : [ SenseInfo('02420757-a', 0), SenseInfo('02420757-a', 0) ],
"_deformity_n_1_rel" : [ SenseInfo('14213512-n', 0), SenseInfo('04691178-n', 0) ],
"_toward_p_sel_rel" : [  ],
"_singular_n_1_rel" : [ SenseInfo('06299916-n', 0), SenseInfo('06299916-n', 0), SenseInfo('06299916-n', 0) ],
"_in-office_a_1_rel" : [  ],
"_double-cross_v_1_rel" : [ SenseInfo('02537812-v', 1), SenseInfo('02537812-v', 1) ],
"_novelty_n_1_rel" : [ SenseInfo('04800596-n', 3), SenseInfo('05635055-n', 1), SenseInfo('03623448-n', 0), SenseInfo('02787435-n', 0) ],
"_nut_n_1_rel" : [ SenseInfo('13136556-n', 2), SenseInfo('09512835-n', 1), SenseInfo('03836191-n', 1), SenseInfo('13712592-n', 0), SenseInfo('09974496-n', 0), SenseInfo('09769076-n', 0), SenseInfo('05524615-n', 0) ],
"_relegate_v_to_rel" : [ SenseInfo('02589013-v', 4), SenseInfo('02399331-v', 2), SenseInfo('02503803-v', 0), SenseInfo('00739662-v', 0) ],
"_exterior_n_1_rel" : [ SenseInfo('08613593-n', 1), SenseInfo('08613472-n', 1) ],
"_enticing_a_1_rel" : [ SenseInfo('02097480-a', 0) ],
"_plenteous_a_1_rel" : [ SenseInfo('00014490-a', 0) ],
"_board_n_of_rel" : [ SenseInfo('08322981-n', 28), SenseInfo('15101854-n', 18), SenseInfo('02856463-n', 4), SenseInfo('07565259-n', 0), SenseInfo('03211616-n', 0), SenseInfo('03201208-n', 0), SenseInfo('03098140-n', 0), SenseInfo('03033986-n', 0), SenseInfo('02857023-n', 0) ],
"_fling_v_back_rel" : [ SenseInfo('01512465-v', 13), SenseInfo('02094428-v', 1), SenseInfo('02269003-v', 0), SenseInfo('02222318-v', 0) ],
"_elite_n_1_rel" : [ SenseInfo('08386555-n', 6) ],
"_lower_a_1_rel" : [ SenseInfo('03693973-n', 0) ],
"_join_n_1_rel" : [ SenseInfo('13911151-n', 0), SenseInfo('07998712-n', 0) ],
"_chapter_n_1_rel" : [ SenseInfo('06396142-n', 38), SenseInfo('15252907-n', 2), SenseInfo('08228665-n', 2), SenseInfo('08228838-n', 0), SenseInfo('07307172-n', 0) ],
"_biography_n_1_rel" : [ SenseInfo('06515827-n', 3), SenseInfo('06515827-n', 3) ],
"_shilling_n_1_rel" : [ SenseInfo('13707346-n', 0), SenseInfo('13707106-n', 0), SenseInfo('13706864-n', 0), SenseInfo('13706628-n', 0), SenseInfo('13686877-n', 0), SenseInfo('13389763-n', 0), SenseInfo('13707346-n', 0), SenseInfo('13707106-n', 0), SenseInfo('13706864-n', 0), SenseInfo('13706628-n', 0), SenseInfo('13686877-n', 0), SenseInfo('13389763-n', 0) ],
"_pay_v_out_rel" : [ SenseInfo('02251743-v', 138), SenseInfo('01060494-v', 26), SenseInfo('02252931-v', 12), SenseInfo('02291708-v', 6), SenseInfo('02253456-v', 6), SenseInfo('00732224-v', 4), SenseInfo('02732292-v', 3), SenseInfo('02488056-v', 1), SenseInfo('00737884-v', 1), SenseInfo('02344243-v', 0), SenseInfo('02253154-v', 0) ],
"_degree_n_1_rel" : [ SenseInfo('05093890-n', 25), SenseInfo('13939892-n', 17), SenseInfo('06697331-n', 13), SenseInfo('13611207-n', 7), SenseInfo('05861317-n', 6), SenseInfo('13714184-n', 1), SenseInfo('05094565-n', 0), SenseInfo('05093890-n', 25), SenseInfo('13939892-n', 17), SenseInfo('06697331-n', 13), SenseInfo('13611207-n', 7), SenseInfo('05861317-n', 6), SenseInfo('13714184-n', 1), SenseInfo('05094565-n', 0) ],
"_eat_v_up_rel" : [ SenseInfo('01168468-v', 61), SenseInfo('01166351-v', 13), SenseInfo('01179865-v', 4), SenseInfo('01766273-v', 0), SenseInfo('01157517-v', 0), SenseInfo('00274283-v', 0) ],
"_trudge_v_1_rel" : [ SenseInfo('01921204-v', 6) ],
"_mkay_a_1_rel" : [  ],
"_dishwasher_n_1_rel" : [ SenseInfo('03207941-n', 1), SenseInfo('10017190-n', 0) ],
"_severance_n_1_rel" : [ SenseInfo('07313814-n', 0), SenseInfo('00359492-n', 0) ],
"_mackerel_n_1_rel" : [ SenseInfo('07781319-n', 0), SenseInfo('02624167-n', 0) ],
"_backside_n_1_rel" : [ SenseInfo('08629508-n', 0), SenseInfo('05559256-n', 0) ],
"_scrap_n_of_rel" : [ SenseInfo('09222051-n', 1), SenseInfo('14857497-n', 0), SenseInfo('04150668-n', 0), SenseInfo('01170962-n', 0) ],
"_in+case_x_rel" : [ SenseInfo('01486312-v', 0) ],
"_spectrogram_n_1_rel" : [ SenseInfo('04272638-n', 0) ],
"_scale_n_1_rel" : [ SenseInfo('13850304-n', 10), SenseInfo('13815342-n', 10), SenseInfo('13816862-n', 6), SenseInfo('13155759-n', 2), SenseInfo('09425607-n', 0), SenseInfo('06856568-n', 0), SenseInfo('04141975-n', 0), SenseInfo('04141838-n', 0), SenseInfo('03959701-n', 0), SenseInfo('01902877-n', 0) ],
"_rainclothes_n_1_rel" : [  ],
"_neighborhood_n_of_rel" : [ SenseInfo('08641113-n', 28), SenseInfo('08225090-n', 14), SenseInfo('13759146-n', 0), SenseInfo('08642331-n', 0), SenseInfo('08641113-n', 28), SenseInfo('08225090-n', 14), SenseInfo('13759146-n', 0), SenseInfo('08642331-n', 0) ],
"_put_v_through_rel" : [ SenseInfo('01494310-v', 138), SenseInfo('01493741-v', 98), SenseInfo('00981276-v', 28), SenseInfo('01160370-v', 6), SenseInfo('02271137-v', 3), SenseInfo('00673448-v', 2), SenseInfo('02111499-v', 0), SenseInfo('01706375-v', 0), SenseInfo('00735571-v', 0), SenseInfo('01494310-v', 138), SenseInfo('01493741-v', 98), SenseInfo('00981276-v', 28), SenseInfo('01160370-v', 6), SenseInfo('02271137-v', 3), SenseInfo('00673448-v', 2), SenseInfo('02111499-v', 0), SenseInfo('01706375-v', 0), SenseInfo('00735571-v', 0) ],
"_short_n_1_rel" : [ SenseInfo('04204619-n', 3), SenseInfo('04204755-n', 0), SenseInfo('00723984-n', 0) ],
"_unpolished_a_1_rel" : [ SenseInfo('01812846-a', 0), SenseInfo('00851329-a', 0), SenseInfo('01812846-a', 0), SenseInfo('00851329-a', 0) ],
"_indicative_n_1_rel" : [ SenseInfo('13801700-n', 0) ],
"_plum_a_1_rel" : [ SenseInfo('12638218-n', 0), SenseInfo('07751451-n', 0), SenseInfo('00596081-n', 0) ],
"_but_c_mod_rel" : [  ],
"_protocol_n_1_rel" : [ SenseInfo('06665108-n', 0), SenseInfo('06664981-n', 0), SenseInfo('05668915-n', 0) ],
"_jewish_a_1_rel" : [ SenseInfo('02922263-a', 52) ],
"_astonishing_a_for_rel" : [ SenseInfo('02359789-a', 4), SenseInfo('01283155-a', 0), SenseInfo('02359789-a', 4), SenseInfo('01283155-a', 0) ],
"_binder_n_1_rel" : [ SenseInfo('02840361-n', 1), SenseInfo('14704465-n', 0), SenseInfo('02840245-n', 0), SenseInfo('02840134-n', 0) ],
"_southeastward_a_2_rel" : [ SenseInfo('01603789-a', 0), SenseInfo('01603789-a', 0) ],
"_violet_n_1_rel" : [ SenseInfo('12387839-n', 1), SenseInfo('04970758-n', 1) ],
"_wildness_n_1_rel" : [ SenseInfo('07481223-n', 1), SenseInfo('05037813-n', 1), SenseInfo('04909887-n', 0), SenseInfo('04907826-n', 0) ],
"_urbanize_v_cause_rel" : [ SenseInfo('00499812-v', 1), SenseInfo('00500055-v', 0) ],
"_chancellor_n_of_rel" : [ SenseInfo('09907408-n', 0), SenseInfo('09906986-n', 0), SenseInfo('09906848-n', 0) ],
"_egoless_a_1_rel" : [  ],
"_shod_a_1_rel" : [ SenseInfo('02155936-a', 2), SenseInfo('02156934-a', 0) ],
"_glimpse_v_1_rel" : [ SenseInfo('02119470-v', 5) ],
"_stroll_v_along_rel" : [ SenseInfo('01917980-v', 1) ],
"_intermixture_n_1_rel" : [ SenseInfo('07882497-n', 0), SenseInfo('02681084-n', 0), SenseInfo('00380083-n', 0) ],
"_double-click_v_1_rel" : [  ],
"_pro_n_1_rel" : [ SenseInfo('10480583-n', 1), SenseInfo('06649223-n', 0) ],
"_designation_n_of_rel" : [ SenseInfo('06338908-n', 2), SenseInfo('00163779-n', 0), SenseInfo('00152018-n', 0) ],
"_penetrate_v_1_rel" : [ SenseInfo('01227675-v', 7), SenseInfo('00728954-v', 3), SenseInfo('00591755-v', 1), SenseInfo('02435634-v', 0), SenseInfo('01993031-v', 0), SenseInfo('01422003-v', 0), SenseInfo('01229071-v', 0), SenseInfo('01227675-v', 7), SenseInfo('00728954-v', 3), SenseInfo('00591755-v', 1), SenseInfo('02435634-v', 0), SenseInfo('01993031-v', 0), SenseInfo('01422003-v', 0), SenseInfo('01229071-v', 0) ],
"_query_v_1_rel" : [ SenseInfo('00785008-v', 3), SenseInfo('00785008-v', 3) ],
"_double+check_v_1_rel" : [ SenseInfo('00663549-v', 0) ],
"_wrong_a_1_rel" : [ SenseInfo('00632438-a', 15), SenseInfo('02035337-a', 12), SenseInfo('00136185-a', 9), SenseInfo('01092371-a', 5), SenseInfo('00633778-a', 0), SenseInfo('01881478-a', 0), SenseInfo('01694081-a', 0), SenseInfo('01662119-a', 0), SenseInfo('00023854-a', 0) ],
"_unfinished_a_1_rel" : [ SenseInfo('01005675-a', 0), SenseInfo('01004318-a', 0), SenseInfo('01714157-a', 0), SenseInfo('01005675-a', 0), SenseInfo('01004318-a', 0), SenseInfo('01714157-a', 0) ],
"_trek_n_1_rel" : [ SenseInfo('00310516-n', 0), SenseInfo('00310347-n', 0) ],
"_quoit_n_1_rel" : [ SenseInfo('04036155-n', 0) ],
"_see+also_v_1_rel" : [  ],
"_bring_v_along_rel" : [ SenseInfo('02077656-v', 122), SenseInfo('01438902-v', 55), SenseInfo('01629589-v', 31), SenseInfo('01433294-v', 19), SenseInfo('00135857-v', 9), SenseInfo('01434140-v', 4), SenseInfo('01618547-v', 3), SenseInfo('02324478-v', 2), SenseInfo('02247390-v', 1), SenseInfo('01808218-v', 0), SenseInfo('00767334-v', 0) ],
"_pedestrian_n_1_rel" : [ SenseInfo('10412055-n', 0) ],
"_slaughterhouse_n_1_rel" : [ SenseInfo('02666943-n', 0) ],
"_rat_v_on_rel" : [ SenseInfo('02584475-v', 0), SenseInfo('02413140-v', 0), SenseInfo('02412939-v', 0), SenseInfo('01527135-v', 0), SenseInfo('01480641-v', 0), SenseInfo('00841986-v', 0) ],
"_aluminum_n_1_rel" : [ SenseInfo('14627820-n', 5), SenseInfo('14627820-n', 5) ],
"_siphon_v_off_rel" : [ SenseInfo('01853542-v', 0), SenseInfo('01613391-v', 0) ],
"_prong_n_1_rel" : [ SenseInfo('04010927-n', 0) ],
"_cloudless_a_1_rel" : [ SenseInfo('00460946-a', 0) ],
"_forecourt_n_1_rel" : [ SenseInfo('03382292-n', 0) ],
"_denomination_n_1_rel" : [ SenseInfo('08146782-n', 10), SenseInfo('08006989-n', 0), SenseInfo('06338908-n', 0) ],
"_plentiful_a_1_rel" : [ SenseInfo('00015854-a', 2), SenseInfo('00014490-a', 2), SenseInfo('01080900-a', 0) ],
"_manipulation_n_of_rel" : [ SenseInfo('00158185-n', 1), SenseInfo('00140652-n', 0) ],
"_isolated_a_1_rel" : [ SenseInfo('00594267-a', 8), SenseInfo('02110447-a', 5), SenseInfo('02111095-a', 4), SenseInfo('02251576-a', 0), SenseInfo('01327205-a', 0), SenseInfo('00567860-a', 0) ],
"_backward_p_rel" : [ SenseInfo('00074407-r', 4), SenseInfo('00201354-a', 2), SenseInfo('00075966-r', 2), SenseInfo('00204077-a', 0), SenseInfo('00074201-r', 0), SenseInfo('01840673-a', 0), SenseInfo('00810636-a', 0) ],
"_trans+fat_n_1_rel" : [  ],
"_sequestration_n_of_rel" : [ SenseInfo('01202184-n', 1), SenseInfo('13554586-n', 0), SenseInfo('06555570-n', 0), SenseInfo('00087218-n', 0) ],
"_both_q_rel" : [  ],
"_huff_n_1_rel" : [ SenseInfo('14407070-n', 0) ],
"_wed_v_1_rel" : [ SenseInfo('02488834-v', 3), SenseInfo('02489456-v', 0) ],
"_stronghold_n_1_rel" : [ SenseInfo('04340935-n', 0) ],
"_seeming_a_1_rel" : [ SenseInfo('01873985-a', 6), SenseInfo('01873985-a', 6), SenseInfo('01873985-a', 6) ],
"_polyp_n_1_rel" : [ SenseInfo('14234436-n', 0), SenseInfo('01909906-n', 0) ],
"_pitfall_n_1_rel" : [ SenseInfo('05688990-n', 1), SenseInfo('03949663-n', 0) ],
"_ruggedness_n_1_rel" : [ SenseInfo('05031214-n', 0), SenseInfo('04772388-n', 0), SenseInfo('04710588-n', 0) ],
"_imaging_n_1_rel" : [ SenseInfo('05767733-n', 1), SenseInfo('00901083-n', 0) ],
"_stamp_v_on_rel" : [ SenseInfo('01925338-v', 3), SenseInfo('01273016-v', 3), SenseInfo('02144644-v', 1), SenseInfo('01273814-v', 1), SenseInfo('00656292-v', 1), SenseInfo('00478488-v', 1), SenseInfo('01624568-v', 0), SenseInfo('01594362-v', 0), SenseInfo('01531265-v', 0) ],
"_music_n_1_rel" : [ SenseInfo('07020895-n', 51), SenseInfo('05718556-n', 12), SenseInfo('00543233-n', 2), SenseInfo('05718935-n', 0), SenseInfo('01162529-n', 0) ],
"_call_v_out_rel" : [ SenseInfo('01028748-v', 91), SenseInfo('00971015-v', 51), SenseInfo('00789448-v', 38), SenseInfo('00913065-v', 25), SenseInfo('00792471-v', 25), SenseInfo('02487573-v', 9), SenseInfo('02429810-v', 9), SenseInfo('01067995-v', 1), SenseInfo('01062739-v', 1), SenseInfo('00975036-v', 1), SenseInfo('02643421-v', 0), SenseInfo('02601456-v', 0), SenseInfo('02487901-v', 0), SenseInfo('02359061-v', 0), SenseInfo('02300060-v', 0), SenseInfo('01899017-v', 0), SenseInfo('01068793-v', 0), SenseInfo('00917772-v', 0), SenseInfo('00874002-v', 0), SenseInfo('00869393-v', 0), SenseInfo('00822746-v', 0), SenseInfo('00783523-v', 0), SenseInfo('00754156-v', 0), SenseInfo('00753881-v', 0), SenseInfo('00738747-v', 0), SenseInfo('00738583-v', 0), SenseInfo('00691516-v', 0), SenseInfo('00107231-v', 0), SenseInfo('01028748-v', 91), SenseInfo('00971015-v', 51), SenseInfo('00789448-v', 38), SenseInfo('00913065-v', 25), SenseInfo('00792471-v', 25), SenseInfo('02487573-v', 9), SenseInfo('02429810-v', 9), SenseInfo('01067995-v', 1), SenseInfo('01062739-v', 1), SenseInfo('00975036-v', 1), SenseInfo('02643421-v', 0), SenseInfo('02601456-v', 0), SenseInfo('02487901-v', 0), SenseInfo('02359061-v', 0), SenseInfo('02300060-v', 0), SenseInfo('01899017-v', 0), SenseInfo('01068793-v', 0), SenseInfo('00917772-v', 0), SenseInfo('00874002-v', 0), SenseInfo('00869393-v', 0), SenseInfo('00822746-v', 0), SenseInfo('00783523-v', 0), SenseInfo('00754156-v', 0), SenseInfo('00753881-v', 0), SenseInfo('00738747-v', 0), SenseInfo('00738583-v', 0), SenseInfo('00691516-v', 0), SenseInfo('00107231-v', 0) ],
"_celtic_a_1_rel" : [ SenseInfo('02957823-a', 1) ],
"_lecture_v_1_rel" : [ SenseInfo('00830761-v', 4), SenseInfo('00824767-v', 1) ],
"_doze_v_1_rel" : [ SenseInfo('00015303-v', 4) ],
"_divide_n_1_rel" : [ SenseInfo('13982692-n', 0), SenseInfo('08679369-n', 0) ],
"_commandment_n_1_rel" : [ SenseInfo('07169848-n', 2), SenseInfo('06185955-n', 0), SenseInfo('07169848-n', 2), SenseInfo('06185955-n', 0), SenseInfo('07169848-n', 2), SenseInfo('06185955-n', 0), SenseInfo('07169848-n', 2), SenseInfo('06185955-n', 0) ],
"_vivacity_n_1_rel" : [ SenseInfo('04634299-n', 0) ],
"_accrue_v_cause_rel" : [ SenseInfo('00155869-v', 2), SenseInfo('02230056-v', 0) ],
"_jigsaw_n_1_rel" : [ SenseInfo('04121728-n', 0), SenseInfo('03598783-n', 0) ],
"_par_v_1_rel" : [ SenseInfo('01084331-v', 0) ],
"_governmental_a_1_rel" : [ SenseInfo('01814711-a', 0) ],
"_hap_n_1_rel" : [ SenseInfo('07314277-n', 0) ],
"_co-director_n_1_rel" : [  ],
"_likewise_a_1_rel" : [  ],
"_gratis_a_1_rel" : [ SenseInfo('01710260-a', 0) ],
"_supposed_a_1_rel" : [ SenseInfo('01617255-a', 4), SenseInfo('01414137-a', 2), SenseInfo('01916555-a', 0), SenseInfo('00861216-a', 0), SenseInfo('01617255-a', 4), SenseInfo('01414137-a', 2), SenseInfo('01916555-a', 0), SenseInfo('00861216-a', 0), SenseInfo('01617255-a', 4), SenseInfo('01414137-a', 2), SenseInfo('01916555-a', 0), SenseInfo('00861216-a', 0), SenseInfo('01617255-a', 4), SenseInfo('01414137-a', 2), SenseInfo('01916555-a', 0), SenseInfo('00861216-a', 0), SenseInfo('01617255-a', 4), SenseInfo('01414137-a', 2), SenseInfo('01916555-a', 0), SenseInfo('00861216-a', 0), SenseInfo('01617255-a', 4), SenseInfo('01414137-a', 2), SenseInfo('01916555-a', 0), SenseInfo('00861216-a', 0) ],
"_hide-and-go-seek_n_1_rel" : [ SenseInfo('00484910-n', 0), SenseInfo('00484910-n', 0) ],
"_comparability_n_1_rel" : [ SenseInfo('04746842-n', 0) ],
"_round+trip_n_1_rel" : [ SenseInfo('00308779-n', 0), SenseInfo('00308779-n', 0) ],
"_exclaim_v_to_rel" : [ SenseInfo('00912048-v', 8), SenseInfo('00977336-v', 5) ],
"_foreseeable_a_1_rel" : [ SenseInfo('01841699-a', 1) ],
"_stone_n_1_rel" : [ SenseInfo('09416076-n', 16), SenseInfo('04326084-n', 9), SenseInfo('14696793-n', 8), SenseInfo('14699752-n', 0), SenseInfo('13720600-n', 0), SenseInfo('11684739-n', 0), SenseInfo('11319810-n', 0), SenseInfo('11319704-n', 0), SenseInfo('11319570-n', 0), SenseInfo('11319413-n', 0), SenseInfo('11319244-n', 0), SenseInfo('11319134-n', 0), SenseInfo('04629958-n', 0) ],
"_gulp_v_down_rel" : [ SenseInfo('01202068-v', 5), SenseInfo('01067002-v', 1) ],
"_greasy_a_1_rel" : [ SenseInfo('00992432-a', 7), SenseInfo('00422168-a', 0), SenseInfo('00992432-a', 7), SenseInfo('00422168-a', 0), SenseInfo('00992432-a', 7), SenseInfo('00422168-a', 0) ],
"_starpoint_n_1_rel" : [  ],
"_abstract_a_1_rel" : [ SenseInfo('00011757-a', 5), SenseInfo('01980557-a', 1), SenseInfo('00862526-a', 0), SenseInfo('00011757-a', 5), SenseInfo('01980557-a', 1), SenseInfo('00862526-a', 0) ],
"_save_v_up_rel" : [ SenseInfo('02550868-v', 41), SenseInfo('02225492-v', 16), SenseInfo('02551832-v', 4), SenseInfo('02266920-v', 4), SenseInfo('02265979-v', 4), SenseInfo('00549552-v', 4), SenseInfo('02551602-v', 2), SenseInfo('02464583-v', 2), SenseInfo('02357228-v', 1), SenseInfo('02283716-v', 1), SenseInfo('00998886-v', 0), SenseInfo('02550868-v', 41), SenseInfo('02225492-v', 16), SenseInfo('02551832-v', 4), SenseInfo('02266920-v', 4), SenseInfo('02265979-v', 4), SenseInfo('00549552-v', 4), SenseInfo('02551602-v', 2), SenseInfo('02464583-v', 2), SenseInfo('02357228-v', 1), SenseInfo('02283716-v', 1), SenseInfo('00998886-v', 0) ],
"_start_v_cause_rel" : [ SenseInfo('00345761-v', 159), SenseInfo('00348746-v', 45), SenseInfo('02014165-v', 29), SenseInfo('02608347-v', 17), SenseInfo('01628449-v', 16), SenseInfo('01650610-v', 11), SenseInfo('01910373-v', 7), SenseInfo('01857717-v', 7), SenseInfo('01864230-v', 5), SenseInfo('02379528-v', 2), SenseInfo('01075164-v', 1), SenseInfo('02608823-v', 0), SenseInfo('02600948-v', 0), SenseInfo('02081946-v', 0) ],
"_quarry_v_1_rel" : [ SenseInfo('01163847-v', 0) ],
"comp_not+so_rel" : [  ],
"_mistaking_n_1_rel" : [ SenseInfo('07174433-n', 1) ],
"_soak_v_1_rel" : [ SenseInfo('01578513-v', 4), SenseInfo('02319050-v', 1), SenseInfo('00216216-v', 1), SenseInfo('02347220-v', 0), SenseInfo('01397870-v', 0), SenseInfo('01190494-v', 0), SenseInfo('01190277-v', 0), SenseInfo('00456151-v', 0), SenseInfo('00372157-v', 0) ],
"_tease_v_1_rel" : [ SenseInfo('01803380-v', 2), SenseInfo('00850501-v', 1), SenseInfo('01803641-v', 0), SenseInfo('01572386-v', 0), SenseInfo('01531635-v', 0), SenseInfo('01463792-v', 0), SenseInfo('01356256-v', 0), SenseInfo('00852506-v', 0), SenseInfo('00040188-v', 0) ],
"_incense_v_1_rel" : [ SenseInfo('02126686-v', 0), SenseInfo('01786906-v', 0) ],
"_stalwart_a_1_rel" : [ SenseInfo('02038994-a', 0), SenseInfo('01991586-a', 0), SenseInfo('00264262-a', 0) ],
"_predominate_v_1_rel" : [ SenseInfo('02644234-v', 2), SenseInfo('02696503-v', 0) ],
"_succulence_n_1_rel" : [ SenseInfo('04996215-n', 0) ],
"_early+on_a_1_rel" : [  ],
"_decrease_v_cause_rel" : [ SenseInfo('00151689-v', 13), SenseInfo('00441445-v', 3) ],
"_frank_a_1_rel" : [ SenseInfo('00764484-a', 3), SenseInfo('01619379-a', 0), SenseInfo('00764484-a', 3), SenseInfo('01619379-a', 0), SenseInfo('00764484-a', 3), SenseInfo('01619379-a', 0), SenseInfo('00764484-a', 3), SenseInfo('01619379-a', 0), SenseInfo('00764484-a', 3), SenseInfo('01619379-a', 0), SenseInfo('00764484-a', 3), SenseInfo('01619379-a', 0) ],
"_daypack_n_1_rel" : [  ],
"_jagged_a_1_rel" : [ SenseInfo('00912288-a', 3), SenseInfo('02246903-a', 0) ],
"_hem_a_1_rel" : [ SenseInfo('03513627-n', 3), SenseInfo('07126521-n', 0) ],
"_call_v_back_rel" : [ SenseInfo('01028748-v', 91), SenseInfo('00971015-v', 51), SenseInfo('00789448-v', 38), SenseInfo('00913065-v', 25), SenseInfo('00792471-v', 25), SenseInfo('02487573-v', 9), SenseInfo('02429810-v', 9), SenseInfo('01067995-v', 1), SenseInfo('01062739-v', 1), SenseInfo('00975036-v', 1), SenseInfo('02643421-v', 0), SenseInfo('02601456-v', 0), SenseInfo('02487901-v', 0), SenseInfo('02359061-v', 0), SenseInfo('02300060-v', 0), SenseInfo('01899017-v', 0), SenseInfo('01068793-v', 0), SenseInfo('00917772-v', 0), SenseInfo('00874002-v', 0), SenseInfo('00869393-v', 0), SenseInfo('00822746-v', 0), SenseInfo('00783523-v', 0), SenseInfo('00754156-v', 0), SenseInfo('00753881-v', 0), SenseInfo('00738747-v', 0), SenseInfo('00738583-v', 0), SenseInfo('00691516-v', 0), SenseInfo('00107231-v', 0), SenseInfo('01028748-v', 91), SenseInfo('00971015-v', 51), SenseInfo('00789448-v', 38), SenseInfo('00913065-v', 25), SenseInfo('00792471-v', 25), SenseInfo('02487573-v', 9), SenseInfo('02429810-v', 9), SenseInfo('01067995-v', 1), SenseInfo('01062739-v', 1), SenseInfo('00975036-v', 1), SenseInfo('02643421-v', 0), SenseInfo('02601456-v', 0), SenseInfo('02487901-v', 0), SenseInfo('02359061-v', 0), SenseInfo('02300060-v', 0), SenseInfo('01899017-v', 0), SenseInfo('01068793-v', 0), SenseInfo('00917772-v', 0), SenseInfo('00874002-v', 0), SenseInfo('00869393-v', 0), SenseInfo('00822746-v', 0), SenseInfo('00783523-v', 0), SenseInfo('00754156-v', 0), SenseInfo('00753881-v', 0), SenseInfo('00738747-v', 0), SenseInfo('00738583-v', 0), SenseInfo('00691516-v', 0), SenseInfo('00107231-v', 0) ],
"_palliate_a_1_rel" : [  ],
"_snowdrift_n_1_rel" : [ SenseInfo('09438940-n', 0) ],
"_diminish_v_cause_rel" : [ SenseInfo('00151689-v', 10), SenseInfo('00441881-v', 2) ],
"_indispensable_a_1_rel" : [ SenseInfo('00903668-a', 2), SenseInfo('01580306-a', 1), SenseInfo('00849108-a', 0), SenseInfo('00903668-a', 2), SenseInfo('01580306-a', 1), SenseInfo('00849108-a', 0) ],
"_weave_v_in_rel" : [ SenseInfo('01518924-v', 3), SenseInfo('01673891-v', 2), SenseInfo('01868258-v', 1), SenseInfo('01882814-v', 0) ],
"_iraqi_a_1_rel" : [ SenseInfo('03075470-a', 0) ],
"_satire_n_1_rel" : [ SenseInfo('06777164-n', 7) ],
"_preparation_n_for_rel" : [ SenseInfo('01143040-n', 14), SenseInfo('14873641-n', 5), SenseInfo('05794694-n', 2), SenseInfo('14031108-n', 0), SenseInfo('07027942-n', 0), SenseInfo('00893955-n', 0), SenseInfo('00729108-n', 0), SenseInfo('00243918-n', 0) ],
"_tremble_v_1_rel" : [ SenseInfo('01888511-v', 4) ],
"_cheat_n_1_rel" : [ SenseInfo('12125183-n', 0), SenseInfo('12111238-n', 0), SenseInfo('09998101-n', 0), SenseInfo('00780148-n', 0), SenseInfo('00754424-n', 0) ],
"_trappings_n_1_rel" : [ SenseInfo('02955540-n', 1), SenseInfo('02955540-n', 1) ],
"_cd_n_1_rel" : [ SenseInfo('14632444-n', 0), SenseInfo('13641534-n', 0), SenseInfo('13365137-n', 0), SenseInfo('03079230-n', 0) ],
"_render_n_1_rel" : [ SenseInfo('15060326-n', 0) ],
"_distraction_n_1_rel" : [ SenseInfo('05684440-n', 2), SenseInfo('05706547-n', 0), SenseInfo('00515414-n', 0), SenseInfo('00200041-n', 0) ],
"_yes/no_a_1_rel" : [  ],
"_fiberglass_n_1_rel" : [ SenseInfo('14866769-n', 1) ],
"_angle_n_1_rel" : [ SenseInfo('13887509-n', 10), SenseInfo('06211078-n', 2), SenseInfo('09702673-n', 0) ],
"_patrician_n_1_rel" : [ SenseInfo('10407105-n', 0), SenseInfo('09807754-n', 0) ],
"_clatter_n_1_rel" : [ SenseInfo('07380473-n', 4) ],
"_shoot_v_off_rel" : [ SenseInfo('01137138-v', 28), SenseInfo('02484570-v', 27), SenseInfo('01134781-v', 26), SenseInfo('01002740-v', 7), SenseInfo('02096047-v', 3), SenseInfo('02061495-v', 3), SenseInfo('02055267-v', 1), SenseInfo('01597286-v', 1), SenseInfo('01003249-v', 1), SenseInfo('02768259-v', 0), SenseInfo('02123175-v', 0), SenseInfo('01585523-v', 0), SenseInfo('01519184-v', 0), SenseInfo('01437144-v', 0), SenseInfo('01195804-v', 0), SenseInfo('01084466-v', 0), SenseInfo('00985219-v', 0), SenseInfo('00647508-v', 0), SenseInfo('00357332-v', 0), SenseInfo('00086320-v', 0) ],
"_tool_v_1_rel" : [ SenseInfo('02100341-v', 1), SenseInfo('01956708-v', 1), SenseInfo('02338003-v', 0), SenseInfo('01669547-v', 0) ],
"_chechen_a_1_rel" : [ SenseInfo('02691839-a', 0) ],
"_continue_v_2_rel" : [ SenseInfo('02684924-v', 146), SenseInfo('00781000-v', 39), SenseInfo('02679899-v', 22), SenseInfo('01995549-v', 5), SenseInfo('02410175-v', 2), SenseInfo('02747922-v', 1), SenseInfo('02747709-v', 0), SenseInfo('02727462-v', 0), SenseInfo('02687916-v', 0), SenseInfo('00118523-v', 0), SenseInfo('02684924-v', 146), SenseInfo('00781000-v', 39), SenseInfo('02679899-v', 22), SenseInfo('01995549-v', 5), SenseInfo('02410175-v', 2), SenseInfo('02747922-v', 1), SenseInfo('02747709-v', 0), SenseInfo('02727462-v', 0), SenseInfo('02687916-v', 0), SenseInfo('00118523-v', 0), SenseInfo('02684924-v', 146), SenseInfo('00781000-v', 39), SenseInfo('02679899-v', 22), SenseInfo('01995549-v', 5), SenseInfo('02410175-v', 2), SenseInfo('02747922-v', 1), SenseInfo('02747709-v', 0), SenseInfo('02727462-v', 0), SenseInfo('02687916-v', 0), SenseInfo('00118523-v', 0), SenseInfo('02684924-v', 146), SenseInfo('00781000-v', 39), SenseInfo('02679899-v', 22), SenseInfo('01995549-v', 5), SenseInfo('02410175-v', 2), SenseInfo('02747922-v', 1), SenseInfo('02747709-v', 0), SenseInfo('02727462-v', 0), SenseInfo('02687916-v', 0), SenseInfo('00118523-v', 0) ],
"_bill_v_for_rel" : [ SenseInfo('02320374-v', 2), SenseInfo('00977153-v', 1), SenseInfo('00991900-v', 0), SenseInfo('02320374-v', 2), SenseInfo('00977153-v', 1), SenseInfo('00991900-v', 0) ],
"_somewhat_a_1_rel" : [  ],
"_dead_n_1_rel" : [ SenseInfo('07945657-n', 9), SenseInfo('15123362-n', 1) ],
"_seriousness_n_1_rel" : [ SenseInfo('07512315-n', 2), SenseInfo('05037197-n', 1), SenseInfo('04646548-n', 0) ],
"_trace-elemental_a_1_rel" : [  ],
"_asparagus_n_1_rel" : [ SenseInfo('12441183-n', 0), SenseInfo('07719213-n', 0) ],
"_ninth_n_of_rel" : [ SenseInfo('13847715-n', 1), SenseInfo('13738235-n', 0), SenseInfo('13847715-n', 1), SenseInfo('13738235-n', 0), SenseInfo('13847715-n', 1), SenseInfo('13738235-n', 0) ],
"_swim_n_1_rel" : [ SenseInfo('00442115-n', 0) ],
"_wave_v_1_rel" : [ SenseInfo('01041415-v', 21), SenseInfo('01446901-v', 5), SenseInfo('01901783-v', 4), SenseInfo('01223616-v', 0), SenseInfo('00039488-v', 0) ],
"_print_v_cause_rel" : [ SenseInfo('01745722-v', 12), SenseInfo('01746715-v', 1), SenseInfo('01749184-v', 0), SenseInfo('01747945-v', 0) ],
"_ravage_v_1_rel" : [ SenseInfo('00389083-v', 0), SenseInfo('00388635-v', 0) ],
"_submarine_n_1_rel" : [ SenseInfo('04347754-n', 7), SenseInfo('07697825-n', 0) ],
"_deceiving_a_1_rel" : [  ],
"_double_v_as_rel" : [ SenseInfo('00246217-v', 12), SenseInfo('01409523-v', 2), SenseInfo('02063309-v', 1), SenseInfo('01525505-v', 1), SenseInfo('02300425-v', 0), SenseInfo('01734502-v', 0) ],
"_hippopotamus_n_1_rel" : [ SenseInfo('02398521-n', 0) ],
"_soup_n_1_rel" : [ SenseInfo('07583197-n', 2), SenseInfo('15048623-n', 0), SenseInfo('13927112-n', 0) ],
"_deviate_v_1_rel" : [ SenseInfo('02064887-v', 2), SenseInfo('02661252-v', 1), SenseInfo('02065085-v', 0) ],
"_environment_n_1_rel" : [ SenseInfo('13934596-n', 21), SenseInfo('08567235-n', 1) ],
"_wooded_a_1_rel" : [ SenseInfo('02572823-a', 1) ],
"_renovate_v_1_rel" : [ SenseInfo('00164201-v', 0), SenseInfo('00163441-v', 0), SenseInfo('00024279-v', 0) ],
"_hitch_v_up_rel" : [ SenseInfo('01327816-v', 2), SenseInfo('01917244-v', 1), SenseInfo('01884383-v', 1), SenseInfo('01956955-v', 0), SenseInfo('01614774-v', 0) ],
"_plateau_n_1_rel" : [ SenseInfo('09453008-n', 0) ],
"_strive_v_for_rel" : [ SenseInfo('02531199-v', 13), SenseInfo('01146051-v', 6) ],
"_strychnine_n_1_rel" : [ SenseInfo('14715008-n', 4) ],
"_safari_n_1_rel" : [ SenseInfo('00309906-n', 0), SenseInfo('00309906-n', 0) ],
"_flat_a_1_rel" : [ SenseInfo('00910101-a', 11), SenseInfo('00659259-a', 5), SenseInfo('01913931-a', 2), SenseInfo('01239040-a', 2), SenseInfo('01021794-a', 1), SenseInfo('01578152-a', 0), SenseInfo('02413037-a', 0), SenseInfo('02399595-a', 0), SenseInfo('02307563-a', 0), SenseInfo('02277078-a', 0), SenseInfo('01541828-a', 0), SenseInfo('01233020-a', 0), SenseInfo('00660551-a', 0), SenseInfo('00283972-a', 0), SenseInfo('00038119-a', 0), SenseInfo('00910101-a', 11), SenseInfo('00659259-a', 5), SenseInfo('01913931-a', 2), SenseInfo('01239040-a', 2), SenseInfo('01021794-a', 1), SenseInfo('01578152-a', 0), SenseInfo('02413037-a', 0), SenseInfo('02399595-a', 0), SenseInfo('02307563-a', 0), SenseInfo('02277078-a', 0), SenseInfo('01541828-a', 0), SenseInfo('01233020-a', 0), SenseInfo('00660551-a', 0), SenseInfo('00283972-a', 0), SenseInfo('00038119-a', 0), SenseInfo('00910101-a', 11), SenseInfo('00659259-a', 5), SenseInfo('01913931-a', 2), SenseInfo('01239040-a', 2), SenseInfo('01021794-a', 1), SenseInfo('01578152-a', 0), SenseInfo('02413037-a', 0), SenseInfo('02399595-a', 0), SenseInfo('02307563-a', 0), SenseInfo('02277078-a', 0), SenseInfo('01541828-a', 0), SenseInfo('01233020-a', 0), SenseInfo('00660551-a', 0), SenseInfo('00283972-a', 0), SenseInfo('00038119-a', 0), SenseInfo('00910101-a', 11), SenseInfo('00659259-a', 5), SenseInfo('01913931-a', 2), SenseInfo('01239040-a', 2), SenseInfo('01021794-a', 1), SenseInfo('01578152-a', 0), SenseInfo('02413037-a', 0), SenseInfo('02399595-a', 0), SenseInfo('02307563-a', 0), SenseInfo('02277078-a', 0), SenseInfo('01541828-a', 0), SenseInfo('01233020-a', 0), SenseInfo('00660551-a', 0), SenseInfo('00283972-a', 0), SenseInfo('00038119-a', 0) ],
"_fudge_v_1_rel" : [ SenseInfo('02576921-v', 0), SenseInfo('00809654-v', 0) ],
"_seater_n_1_rel" : [  ],
"_hollow_v_out_rel" : [ SenseInfo('01310660-v', 0), SenseInfo('01282545-v', 0) ],
"_fuzz_v_1_rel" : [  ],
"_gotta_v_modal_rel" : [  ],
"_clear_x_deg_rel" : [ SenseInfo('00428404-a', 55), SenseInfo('00181664-v', 16), SenseInfo('00435190-a', 8), SenseInfo('01622505-a', 6), SenseInfo('00195617-v', 5), SenseInfo('00431447-a', 4), SenseInfo('00285854-r', 3), SenseInfo('01062938-a', 3), SenseInfo('02771169-v', 2), SenseInfo('00803325-v', 2), SenseInfo('00195342-v', 2), SenseInfo('02459667-a', 1), SenseInfo('01906464-a', 1), SenseInfo('00869253-a', 1), SenseInfo('00780011-a', 1), SenseInfo('02523351-v', 1), SenseInfo('02289134-v', 1), SenseInfo('02156844-v', 1), SenseInfo('02081178-v', 1), SenseInfo('00621058-v', 1), SenseInfo('00697923-a', 0), SenseInfo('00460735-a', 0), SenseInfo('13990502-n', 0), SenseInfo('08632423-n', 0), SenseInfo('00285687-r', 0), SenseInfo('01914108-a', 0), SenseInfo('01750073-a', 0), SenseInfo('01582598-a', 0), SenseInfo('01405047-a', 0), SenseInfo('01320184-a', 0), SenseInfo('00771616-a', 0), SenseInfo('02422409-v', 0), SenseInfo('02350440-v', 0), SenseInfo('02291548-v', 0), SenseInfo('02291258-v', 0), SenseInfo('02289295-v', 0), SenseInfo('02208409-v', 0), SenseInfo('02053490-v', 0), SenseInfo('00904046-v', 0), SenseInfo('00761454-v', 0), SenseInfo('00549217-v', 0), SenseInfo('00450863-v', 0), SenseInfo('00450691-v', 0), SenseInfo('00450565-v', 0), SenseInfo('00178235-v', 0) ],
"_leave_v_i_rel" : [ SenseInfo('02009433-v', 146), SenseInfo('00613683-v', 63), SenseInfo('02729414-v', 56), SenseInfo('00136991-v', 27), SenseInfo('02015598-v', 20), SenseInfo('02721438-v', 19), SenseInfo('02635659-v', 16), SenseInfo('02383440-v', 14), SenseInfo('02356230-v', 8), SenseInfo('02229055-v', 7), SenseInfo('02730135-v', 5), SenseInfo('00360092-v', 5), SenseInfo('02296153-v', 3), SenseInfo('00613018-v', 3) ],
"_doubtful_a_1_rel" : [ SenseInfo('01916979-a', 10), SenseInfo('00338013-a', 2), SenseInfo('02130672-a', 0), SenseInfo('01916979-a', 10), SenseInfo('00338013-a', 2), SenseInfo('02130672-a', 0), SenseInfo('01916979-a', 10), SenseInfo('00338013-a', 2), SenseInfo('02130672-a', 0) ],
"_fossil_n_1_rel" : [ SenseInfo('10022908-n', 0), SenseInfo('09284589-n', 0) ],
"_canadian+dollar_n_1_rel" : [ SenseInfo('13672794-n', 0) ],
"_doughnut_n_1_rel" : [ SenseInfo('13875392-n', 0), SenseInfo('07639069-n', 0) ],
"_simulator_n_1_rel" : [ SenseInfo('04221823-n', 0) ],
"_spoiled_a_1_rel" : [ SenseInfo('01138902-a', 1), SenseInfo('01069283-a', 0) ],
"_equate_v_to_rel" : [ SenseInfo('00653620-v', 8), SenseInfo('02633534-v', 1), SenseInfo('00417001-v', 0), SenseInfo('00653620-v', 8), SenseInfo('02633534-v', 1), SenseInfo('00417001-v', 0) ],
"_reckon_v_1_rel" : [ SenseInfo('00631737-v', 5), SenseInfo('00712135-v', 3), SenseInfo('00690614-v', 1), SenseInfo('00637259-v', 1), SenseInfo('00712708-v', 0), SenseInfo('00712556-v', 0), SenseInfo('00631737-v', 5), SenseInfo('00712135-v', 3), SenseInfo('00690614-v', 1), SenseInfo('00637259-v', 1), SenseInfo('00712708-v', 0), SenseInfo('00712556-v', 0), SenseInfo('00631737-v', 5), SenseInfo('00712135-v', 3), SenseInfo('00690614-v', 1), SenseInfo('00637259-v', 1), SenseInfo('00712708-v', 0), SenseInfo('00712556-v', 0) ],
"_bland_a_1_rel" : [ SenseInfo('02399595-a', 1), SenseInfo('02307563-a', 0), SenseInfo('00758800-a', 0), SenseInfo('02399595-a', 1), SenseInfo('02307563-a', 0), SenseInfo('00758800-a', 0), SenseInfo('02399595-a', 1), SenseInfo('02307563-a', 0), SenseInfo('00758800-a', 0) ],
"_unpleasant_a_1_rel" : [ SenseInfo('01801600-a', 6), SenseInfo('01801600-a', 6), SenseInfo('01801600-a', 6) ],
"_hollow_v_1_rel" : [ SenseInfo('01310660-v', 0), SenseInfo('01282545-v', 0) ],
"_housewares_n_1_rel" : [  ],
"_throttle_n_1_rel" : [ SenseInfo('02670186-n', 4), SenseInfo('02670683-n', 0) ],
"_look_v_for_rel" : [ SenseInfo('02130524-v', 274), SenseInfo('02133435-v', 126), SenseInfo('00033599-v', 25), SenseInfo('02153709-v', 8), SenseInfo('02693319-v', 1), SenseInfo('02549581-v', 1), SenseInfo('00929362-v', 1), SenseInfo('00720063-v', 1), SenseInfo('02658447-v', 0), SenseInfo('00712708-v', 0) ],
"_thoroughgoing_a_1_rel" : [ SenseInfo('00522463-a', 2), SenseInfo('01520091-a', 0), SenseInfo('00522463-a', 2), SenseInfo('01520091-a', 0), SenseInfo('00522463-a', 2), SenseInfo('01520091-a', 0) ],
"_cuckoo_n_1_rel" : [ SenseInfo('10157744-n', 0), SenseInfo('01823013-n', 0) ],
"_northwestward_a_1_rel" : [ SenseInfo('01602250-a', 0), SenseInfo('01602250-a', 0) ],
"_rank_a_1_rel" : [ SenseInfo('01002256-a', 1), SenseInfo('01627049-a', 0), SenseInfo('00580039-a', 0), SenseInfo('00520892-a', 0), SenseInfo('00016135-a', 0) ],
"_convene_v_1_rel" : [ SenseInfo('02024508-v', 2), SenseInfo('00793037-v', 0) ],
"_wick_n_1_rel" : [ SenseInfo('04582044-n', 0), SenseInfo('04581829-n', 0) ],
"_demo_n_of_rel" : [ SenseInfo('06879180-n', 0) ],
"_mar_v_1_rel" : [ SenseInfo('00477941-v', 6), SenseInfo('00090708-v', 0) ],
"_right_x_deg_rel" : [ SenseInfo('05174653-n', 41), SenseInfo('08625073-n', 27), SenseInfo('02031986-a', 20), SenseInfo('00631391-a', 20), SenseInfo('00205052-r', 17), SenseInfo('01879261-a', 16), SenseInfo('00105162-r', 14), SenseInfo('00058033-r', 11), SenseInfo('02034828-a', 10), SenseInfo('04091839-n', 5), SenseInfo('08416652-n', 4), SenseInfo('00387828-r', 4), SenseInfo('00196203-r', 3), SenseInfo('00150351-r', 3), SenseInfo('00633410-a', 2), SenseInfo('05565337-n', 2), SenseInfo('00351000-n', 2), SenseInfo('00205125-r', 2), SenseInfo('00032299-r', 2), SenseInfo('04850341-n', 1), SenseInfo('00205226-r', 1), SenseInfo('00135455-a', 1), SenseInfo('02030080-a', 0), SenseInfo('13341756-n', 0), SenseInfo('00203922-r', 0), SenseInfo('02082081-a', 0), SenseInfo('02029047-a', 0), SenseInfo('01879464-a', 0), SenseInfo('01720930-a', 0), SenseInfo('01693585-a', 0), SenseInfo('01661289-a', 0), SenseInfo('00023278-a', 0), SenseInfo('02519991-v', 0), SenseInfo('01984734-v', 0), SenseInfo('01984574-v', 0), SenseInfo('00199659-v', 0) ],
"_tear_v_1_rel" : [ SenseInfo('01573515-v', 19), SenseInfo('01556346-v', 7), SenseInfo('02055267-v', 2), SenseInfo('01384275-v', 1), SenseInfo('00066977-v', 0) ],
"_wallpaper_n_1_rel" : [ SenseInfo('15093938-n', 3) ],
"_bandage_v_1_rel" : [ SenseInfo('01303547-v', 0), SenseInfo('00083124-v', 0) ],
"_rein_v_in_rel" : [ SenseInfo('02442737-v', 1), SenseInfo('01862090-v', 0), SenseInfo('01858362-v', 0), SenseInfo('00234857-v', 0), SenseInfo('02442737-v', 1), SenseInfo('01862090-v', 0), SenseInfo('01858362-v', 0), SenseInfo('00234857-v', 0) ],
"_belch_n_1_rel" : [ SenseInfo('00117578-n', 2) ],
"_plain-clothesman_n_1_rel" : [ SenseInfo('10437590-n', 2), SenseInfo('10437590-n', 2), SenseInfo('10437590-n', 2) ],
"_injure_v_1_rel" : [ SenseInfo('00069879-v', 12), SenseInfo('01793177-v', 0), SenseInfo('00260470-v', 0), SenseInfo('00069879-v', 12), SenseInfo('01793177-v', 0), SenseInfo('00260470-v', 0), SenseInfo('00069879-v', 12), SenseInfo('01793177-v', 0), SenseInfo('00260470-v', 0) ],
"_floodlight_n_1_rel" : [ SenseInfo('03365374-n', 0) ],
"_outbreak_n_of_rel" : [ SenseInfo('07435273-n', 1) ],
"_erect_v_1_rel" : [ SenseInfo('01661243-v', 17), SenseInfo('01982866-v', 0) ],
"_apprentice_v_to_rel" : [ SenseInfo('00602635-v', 1), SenseInfo('00602635-v', 1) ],
"_forth_p_rel" : [ SenseInfo('00232936-r', 3), SenseInfo('00103859-r', 1), SenseInfo('00103761-r', 1), SenseInfo('09284433-n', 0) ],
"_oscillator_n_1_rel" : [ SenseInfo('03857430-n', 1) ],
"_sighting_n_of_rel" : [ SenseInfo('00880269-n', 0) ],
"_superimpose_v_1_rel" : [ SenseInfo('01469263-v', 4), SenseInfo('01469263-v', 4) ],
"_soak_v_in_rel" : [ SenseInfo('01578513-v', 4), SenseInfo('02319050-v', 1), SenseInfo('00216216-v', 1), SenseInfo('02347220-v', 0), SenseInfo('01397870-v', 0), SenseInfo('01190494-v', 0), SenseInfo('01190277-v', 0), SenseInfo('00456151-v', 0), SenseInfo('00372157-v', 0), SenseInfo('01578513-v', 4), SenseInfo('02319050-v', 1), SenseInfo('00216216-v', 1), SenseInfo('02347220-v', 0), SenseInfo('01397870-v', 0), SenseInfo('01190494-v', 0), SenseInfo('01190277-v', 0), SenseInfo('00456151-v', 0), SenseInfo('00372157-v', 0) ],
"_happen_v_to_rel" : [ SenseInfo('00339934-v', 149), SenseInfo('00344643-v', 20), SenseInfo('02593912-v', 17), SenseInfo('00344174-v', 9), SenseInfo('02248465-v', 0), SenseInfo('00339934-v', 149), SenseInfo('00344643-v', 20), SenseInfo('02593912-v', 17), SenseInfo('00344174-v', 9), SenseInfo('02248465-v', 0) ],
"_blunt_v_1_rel" : [ SenseInfo('00228019-v', 1), SenseInfo('02115273-v', 0), SenseInfo('01246444-v', 0), SenseInfo('00227913-v', 0), SenseInfo('00192051-v', 0) ],
"_slither_v_1_rel" : [ SenseInfo('01886488-v', 0) ],
"_portal_n_1_rel" : [ SenseInfo('03985684-n', 5), SenseInfo('06359657-n', 0), SenseInfo('05377665-n', 0) ],
"_occurrence_n_1_rel" : [ SenseInfo('07283608-n', 29), SenseInfo('13959069-n', 3) ],
"_skull_n_1_rel" : [ SenseInfo('05540121-n', 5) ],
"_moan_v_1_rel" : [ SenseInfo('01045419-v', 3), SenseInfo('01045419-v', 3) ],
"_logic_n_1_rel" : [ SenseInfo('06163751-n', 2), SenseInfo('05615028-n', 2), SenseInfo('05871618-n', 1), SenseInfo('06133018-n', 0), SenseInfo('05664069-n', 0) ],
"_downward_a_2_rel" : [ SenseInfo('02486248-a', 3), SenseInfo('02492981-a', 1) ],
"_invest_v_in_rel" : [ SenseInfo('02271137-v', 7), SenseInfo('02474239-v', 2), SenseInfo('02386675-v', 0), SenseInfo('02386388-v', 0), SenseInfo('02384275-v', 0), SenseInfo('02271137-v', 7), SenseInfo('02474239-v', 2), SenseInfo('02386675-v', 0), SenseInfo('02386388-v', 0), SenseInfo('02384275-v', 0) ],
"_in+toward_p_rel" : [  ],
"_digest_v_1_rel" : [ SenseInfo('01197338-v', 1), SenseInfo('00590924-v', 1), SenseInfo('00668099-v', 0), SenseInfo('00481555-v', 0), SenseInfo('00481391-v', 0), SenseInfo('00397987-v', 0), SenseInfo('00244625-v', 0), SenseInfo('00209420-v', 0) ],
"_obstreperous_a_1_rel" : [ SenseInfo('00696207-a', 0), SenseInfo('00083876-a', 0) ],
"_smile_v_1_rel" : [ SenseInfo('00028565-v', 79), SenseInfo('01067512-v', 0), SenseInfo('00028565-v', 79), SenseInfo('01067512-v', 0) ],
"_demonstrator_n_1_rel" : [ SenseInfo('10003120-n', 1), SenseInfo('10002982-n', 0), SenseInfo('10002760-n', 0) ],
"_on+account+of_p_rel" : [  ],
"_atmosphere_n_1_rel" : [ SenseInfo('14524849-n', 18), SenseInfo('13711060-n', 7), SenseInfo('08499057-n', 7), SenseInfo('14520278-n', 5), SenseInfo('09210604-n', 4), SenseInfo('04727214-n', 0) ],
"_rector_n_1_rel" : [ SenseInfo('09983572-n', 0) ],
"_unimportant_a_1_rel" : [ SenseInfo('01279978-a', 2), SenseInfo('02164402-a', 0), SenseInfo('01279978-a', 2), SenseInfo('02164402-a', 0) ],
"_lay-off_n_1_rel" : [ SenseInfo('00229814-n', 2), SenseInfo('00229814-n', 2), SenseInfo('00229814-n', 2) ],
"_wonderment_n_1_rel" : [ SenseInfo('07509996-n', 0) ],
"_designate_v_1_rel" : [ SenseInfo('01030132-v', 12), SenseInfo('02391803-v', 1), SenseInfo('00923793-v', 0), SenseInfo('00746479-v', 0), SenseInfo('00709379-v', 0), SenseInfo('01030132-v', 12), SenseInfo('02391803-v', 1), SenseInfo('00923793-v', 0), SenseInfo('00746479-v', 0), SenseInfo('00709379-v', 0) ],
"_seminar_n_1_rel" : [ SenseInfo('08327816-n', 0), SenseInfo('00892145-n', 0) ],
"_ball_v_1_rel" : [ SenseInfo('01523270-v', 1) ],
"_space_v_out_rel" : [ SenseInfo('01988080-v', 3) ],
"_handcrafted_a_1_rel" : [  ],
"_narrow_v_down-to_rel" : [ SenseInfo('00305109-v', 2), SenseInfo('00715541-v', 1), SenseInfo('00437449-v', 1), SenseInfo('00304422-v', 1) ],
"_cloud_n_of_rel" : [ SenseInfo('11439690-n', 24), SenseInfo('09247410-n', 16), SenseInfo('13960357-n', 1), SenseInfo('14525108-n', 0), SenseInfo('13982999-n', 0), SenseInfo('07996149-n', 0) ],
"_bring_v_over_rel" : [ SenseInfo('02077656-v', 122), SenseInfo('01438902-v', 55), SenseInfo('01629589-v', 31), SenseInfo('01433294-v', 19), SenseInfo('00135857-v', 9), SenseInfo('01434140-v', 4), SenseInfo('01618547-v', 3), SenseInfo('02324478-v', 2), SenseInfo('02247390-v', 1), SenseInfo('01808218-v', 0), SenseInfo('00767334-v', 0) ],
"_fumed_a_1_rel" : [ SenseInfo('01954517-a', 0) ],
"_lick_v_1_rel" : [ SenseInfo('01412912-v', 12), SenseInfo('01432176-v', 7), SenseInfo('00634906-v', 1), SenseInfo('01170983-v', 0) ],
"_undercarriage_n_1_rel" : [ SenseInfo('04507453-n', 0) ],
"_mesa_n_1_rel" : [ SenseInfo('09351905-n', 0), SenseInfo('09058071-n', 0) ],
"_marker_n_1_rel" : [ SenseInfo('03721797-n', 1), SenseInfo('07270179-n', 0), SenseInfo('03722007-n', 0) ],
"_perplex_v_1_rel" : [ SenseInfo('00622384-v', 0), SenseInfo('00402539-v', 0), SenseInfo('00622384-v', 0), SenseInfo('00402539-v', 0), SenseInfo('00622384-v', 0), SenseInfo('00402539-v', 0) ],
"_receptive_a_1_rel" : [ SenseInfo('01773420-a', 1), SenseInfo('01985247-a', 0), SenseInfo('00333611-a', 0), SenseInfo('00007208-a', 0), SenseInfo('01773420-a', 1), SenseInfo('01985247-a', 0), SenseInfo('00333611-a', 0), SenseInfo('00007208-a', 0) ],
"_american_n_1_rel" : [ SenseInfo('09738708-n', 33), SenseInfo('06947479-n', 2), SenseInfo('09738400-n', 0) ],
"_interlock_v_1_rel" : [ SenseInfo('00405079-v', 1), SenseInfo('01606736-v', 0), SenseInfo('01606018-v', 0) ],
"_correlation_n_with_rel" : [ SenseInfo('13841651-n', 9), SenseInfo('06032246-n', 2), SenseInfo('06031248-n', 0) ],
"_sky_n_1_rel" : [ SenseInfo('09436708-n', 49) ],
"_spell_v_1_rel" : [ SenseInfo('00937879-v', 2), SenseInfo('00932636-v', 2), SenseInfo('01699896-v', 1), SenseInfo('02412366-v', 0), SenseInfo('01064560-v', 0), SenseInfo('00121387-v', 0), SenseInfo('00937879-v', 2), SenseInfo('00932636-v', 2), SenseInfo('01699896-v', 1), SenseInfo('02412366-v', 0), SenseInfo('01064560-v', 0), SenseInfo('00121387-v', 0) ],
"_gourmet_a_1_rel" : [ SenseInfo('10061656-n', 2) ],
"_symbol_n_of_rel" : [ SenseInfo('06806469-n', 18), SenseInfo('05765415-n', 2) ],
"_a_q_rel" : [  ],
"_upgradable_a_to_rel" : [  ],
"_christmassy_a_1_rel" : [  ],
"_subconscious_n_1_rel" : [ SenseInfo('05613478-n', 0) ],
"_triple_v_1_rel" : [ SenseInfo('00246746-v', 3), SenseInfo('01409642-v', 1) ],
"_project_v_1_rel" : [ SenseInfo('00743223-v', 7), SenseInfo('02713372-v', 6), SenseInfo('01436015-v', 5), SenseInfo('02138075-v', 2), SenseInfo('02180747-v', 1), SenseInfo('01690972-v', 1), SenseInfo('01638368-v', 1), SenseInfo('00706243-v', 1), SenseInfo('01635432-v', 0), SenseInfo('01632897-v', 0), SenseInfo('01515791-v', 0), SenseInfo('00729642-v', 0), SenseInfo('00743223-v', 7), SenseInfo('02713372-v', 6), SenseInfo('01436015-v', 5), SenseInfo('02138075-v', 2), SenseInfo('02180747-v', 1), SenseInfo('01690972-v', 1), SenseInfo('01638368-v', 1), SenseInfo('00706243-v', 1), SenseInfo('01635432-v', 0), SenseInfo('01632897-v', 0), SenseInfo('01515791-v', 0), SenseInfo('00729642-v', 0) ],
"_rod_n_1_rel" : [ SenseInfo('04100174-n', 1), SenseInfo('01377602-n', 1), SenseInfo('13650921-n', 0), SenseInfo('13614679-n', 0), SenseInfo('05456456-n', 0), SenseInfo('03427202-n', 0) ],
"_exploit_n_1_rel" : [ SenseInfo('00036762-n', 2) ],
"_mildness_n_1_rel" : [ SenseInfo('14522408-n', 0), SenseInfo('04910973-n', 0), SenseInfo('04829922-n', 0) ],
"_approach_n_to_rel" : [ SenseInfo('00941140-n', 29), SenseInfo('00280853-n', 9), SenseInfo('02671062-n', 2), SenseInfo('08493961-n', 0), SenseInfo('07310507-n', 0), SenseInfo('07164349-n', 0), SenseInfo('05046471-n', 0), SenseInfo('04746134-n', 0), SenseInfo('00573268-n', 0), SenseInfo('00941140-n', 29), SenseInfo('00280853-n', 9), SenseInfo('02671062-n', 2), SenseInfo('08493961-n', 0), SenseInfo('07310507-n', 0), SenseInfo('07164349-n', 0), SenseInfo('05046471-n', 0), SenseInfo('04746134-n', 0), SenseInfo('00573268-n', 0) ],
"_dilute_v_1_rel" : [ SenseInfo('00226071-v', 9), SenseInfo('00487748-v', 0) ],
"_recumbent_a_1_rel" : [ SenseInfo('01238201-a', 0) ],
"_implicit_a_1_rel" : [ SenseInfo('00941485-a', 3), SenseInfo('00005599-a', 0) ],
"_environmentalist_n_1_rel" : [ SenseInfo('10060621-n', 0) ],
"_threatening_a_1_rel" : [ SenseInfo('00194357-a', 2), SenseInfo('00462409-a', 0), SenseInfo('00194357-a', 2), SenseInfo('00462409-a', 0) ],
"_still_v_cause_rel" : [ SenseInfo('01764800-v', 1), SenseInfo('00461493-v', 1), SenseInfo('01815185-v', 0), SenseInfo('00583905-v', 0) ],
"_precautionary_a_1_rel" : [ SenseInfo('01764895-a', 0), SenseInfo('01764895-a', 0) ],
"_calm_n_1_rel" : [ SenseInfo('04903813-n', 3), SenseInfo('11431617-n', 0) ],
"_in+turn_a_1_rel" : [  ],
"_psychical_a_1_rel" : [ SenseInfo('01780740-a', 4), SenseInfo('01599898-a', 0) ],
"_duck_v_out_rel" : [ SenseInfo('01865203-v', 10), SenseInfo('01967792-v', 3), SenseInfo('01976220-v', 0), SenseInfo('00809654-v', 0) ],
"_coronation_n_of_rel" : [ SenseInfo('07453638-n', 0) ],
"_painter_n_1_rel" : [ SenseInfo('10391653-n', 15), SenseInfo('10393909-n', 0), SenseInfo('03876352-n', 0), SenseInfo('02125311-n', 0) ],
"_batwing_n_1_rel" : [ SenseInfo('02812505-n', 1) ],
"_premier_n_1_rel" : [ SenseInfo('09907196-n', 0), SenseInfo('09906986-n', 0) ],
"_butt_n_1_rel" : [ SenseInfo('02927296-n', 2), SenseInfo('13124855-n', 0), SenseInfo('09884666-n', 0), SenseInfo('05559256-n', 0), SenseInfo('04394261-n', 0), SenseInfo('03030663-n', 0), SenseInfo('02928413-n', 0), SenseInfo('02927608-n', 0), SenseInfo('02927399-n', 0) ],
"_unscrew_v_1_rel" : [ SenseInfo('01352528-v', 2), SenseInfo('01352680-v', 1), SenseInfo('01352528-v', 2), SenseInfo('01352680-v', 1) ],
"_intuitive_a_to_rel" : [ SenseInfo('02282843-a', 0), SenseInfo('01431471-a', 0), SenseInfo('02282843-a', 0), SenseInfo('01431471-a', 0) ],
"_vacancy_n_1_rel" : [ SenseInfo('14455966-n', 3), SenseInfo('13910116-n', 1) ],
"_webmaster_n_1_rel" : [ SenseInfo('10772289-n', 0) ],
"_sledge_n_1_rel" : [ SenseInfo('04235291-n', 0), SenseInfo('03731695-n', 0) ],
"_rental_n_of_rel" : [ SenseInfo('13248393-n', 0), SenseInfo('01111375-n', 0) ],
"_buoyancy_n_1_rel" : [ SenseInfo('07530723-n', 0), SenseInfo('05028963-n', 0), SenseInfo('04944412-n', 0), SenseInfo('04633959-n', 0) ],
"_cultivated_a_1_rel" : [ SenseInfo('01833643-a', 0), SenseInfo('02388596-a', 0), SenseInfo('01947741-a', 0) ],
"_annoyed_a_1_rel" : [ SenseInfo('01806106-a', 3), SenseInfo('02455845-a', 0) ],
"_tag_v_1_rel" : [ SenseInfo('01588493-v', 3), SenseInfo('01600600-v', 1), SenseInfo('01029760-v', 1), SenseInfo('02001858-v', 0), SenseInfo('01702033-v', 0), SenseInfo('01588493-v', 3), SenseInfo('01600600-v', 1), SenseInfo('01029760-v', 1), SenseInfo('02001858-v', 0), SenseInfo('01702033-v', 0) ],
"_jonquil_n_1_rel" : [ SenseInfo('12421917-n', 1), SenseInfo('12422129-n', 0) ],
"_take_n_1_rel" : [ SenseInfo('13260190-n', 0), SenseInfo('00908133-n', 0) ],
"_saudi_n_1_rel" : [ SenseInfo('09729387-n', 0) ],
"_syringa_n_1_rel" : [ SenseInfo('12791329-n', 1), SenseInfo('12310153-n', 0) ],
"_aspect_n_1_rel" : [ SenseInfo('05850624-n', 24), SenseInfo('04733118-n', 18), SenseInfo('05933246-n', 2), SenseInfo('13804669-n', 0), SenseInfo('04679738-n', 0) ],
"_screenwriters_a_1_rel" : [  ],
"_crest_n_1_rel" : [ SenseInfo('08547544-n', 8), SenseInfo('08617963-n', 3), SenseInfo('03138981-n', 0), SenseInfo('03131038-n', 0), SenseInfo('01326015-n', 0) ],
"_rat_n_1_rel" : [ SenseInfo('02331046-n', 5), SenseInfo('10554455-n', 0), SenseInfo('10539715-n', 0), SenseInfo('10206173-n', 0), SenseInfo('04055030-n', 0) ],
"_undetermined_a_1_rel" : [ SenseInfo('01610803-a', 0), SenseInfo('00740336-a', 0), SenseInfo('02130821-a', 0), SenseInfo('01610803-a', 0), SenseInfo('00740336-a', 0), SenseInfo('02130821-a', 0) ],
"_lean_a_1_rel" : [ SenseInfo('00988232-a', 5), SenseInfo('02027003-a', 0), SenseInfo('02337188-a', 0), SenseInfo('01872374-a', 0), SenseInfo('00988232-a', 5), SenseInfo('02027003-a', 0), SenseInfo('02337188-a', 0), SenseInfo('01872374-a', 0), SenseInfo('00988232-a', 5), SenseInfo('02027003-a', 0), SenseInfo('02337188-a', 0), SenseInfo('01872374-a', 0) ],
"_second_n_1_rel" : [ SenseInfo('15235126-n', 24), SenseInfo('15246853-n', 6), SenseInfo('00723783-n', 2), SenseInfo('15244650-n', 0), SenseInfo('13846546-n', 0), SenseInfo('13611395-n', 0), SenseInfo('10568083-n', 0), SenseInfo('07180372-n', 0), SenseInfo('04164529-n', 0), SenseInfo('03587050-n', 0), SenseInfo('15235126-n', 24), SenseInfo('15246853-n', 6), SenseInfo('00723783-n', 2), SenseInfo('15244650-n', 0), SenseInfo('13846546-n', 0), SenseInfo('13611395-n', 0), SenseInfo('10568083-n', 0), SenseInfo('07180372-n', 0), SenseInfo('04164529-n', 0), SenseInfo('03587050-n', 0), SenseInfo('15235126-n', 24), SenseInfo('15246853-n', 6), SenseInfo('00723783-n', 2), SenseInfo('15244650-n', 0), SenseInfo('13846546-n', 0), SenseInfo('13611395-n', 0), SenseInfo('10568083-n', 0), SenseInfo('07180372-n', 0), SenseInfo('04164529-n', 0), SenseInfo('03587050-n', 0), SenseInfo('15235126-n', 24), SenseInfo('15246853-n', 6), SenseInfo('00723783-n', 2), SenseInfo('15244650-n', 0), SenseInfo('13846546-n', 0), SenseInfo('13611395-n', 0), SenseInfo('10568083-n', 0), SenseInfo('07180372-n', 0), SenseInfo('04164529-n', 0), SenseInfo('03587050-n', 0), SenseInfo('15235126-n', 24), SenseInfo('15246853-n', 6), SenseInfo('00723783-n', 2), SenseInfo('15244650-n', 0), SenseInfo('13846546-n', 0), SenseInfo('13611395-n', 0), SenseInfo('10568083-n', 0), SenseInfo('07180372-n', 0), SenseInfo('04164529-n', 0), SenseInfo('03587050-n', 0), SenseInfo('15235126-n', 24), SenseInfo('15246853-n', 6), SenseInfo('00723783-n', 2), SenseInfo('15244650-n', 0), SenseInfo('13846546-n', 0), SenseInfo('13611395-n', 0), SenseInfo('10568083-n', 0), SenseInfo('07180372-n', 0), SenseInfo('04164529-n', 0), SenseInfo('03587050-n', 0) ],
"_stupid_a_1_rel" : [ SenseInfo('00439588-a', 10), SenseInfo('00436645-a', 1), SenseInfo('01336587-a', 0), SenseInfo('00439588-a', 10), SenseInfo('00436645-a', 1), SenseInfo('01336587-a', 0), SenseInfo('00439588-a', 10), SenseInfo('00436645-a', 1), SenseInfo('01336587-a', 0), SenseInfo('00439588-a', 10), SenseInfo('00436645-a', 1), SenseInfo('01336587-a', 0) ],
"_palm_n_1_rel" : [ SenseInfo('05565696-n', 4), SenseInfo('13656075-n', 0), SenseInfo('12582231-n', 0), SenseInfo('06706676-n', 0), SenseInfo('05565696-n', 4), SenseInfo('13656075-n', 0), SenseInfo('12582231-n', 0), SenseInfo('06706676-n', 0), SenseInfo('05565696-n', 4), SenseInfo('13656075-n', 0), SenseInfo('12582231-n', 0), SenseInfo('06706676-n', 0) ],
"_miserable_a_1_rel" : [ SenseInfo('01150205-a', 3), SenseInfo('01050890-a', 1), SenseInfo('00904745-a', 1), SenseInfo('02347086-a', 0), SenseInfo('00478872-a', 0), SenseInfo('00107384-a', 0) ],
"_notice_v_1_rel" : [ SenseInfo('02154508-v', 39), SenseInfo('02118476-v', 19), SenseInfo('01058574-v', 1), SenseInfo('01059123-v', 0), SenseInfo('02154508-v', 39), SenseInfo('02118476-v', 19), SenseInfo('01058574-v', 1), SenseInfo('01059123-v', 0), SenseInfo('02154508-v', 39), SenseInfo('02118476-v', 19), SenseInfo('01058574-v', 1), SenseInfo('01059123-v', 0), SenseInfo('02154508-v', 39), SenseInfo('02118476-v', 19), SenseInfo('01058574-v', 1), SenseInfo('01059123-v', 0) ],
"_stem_v_from_rel" : [ SenseInfo('02627753-v', 19), SenseInfo('02713065-v', 0), SenseInfo('00354452-v', 0), SenseInfo('00176137-v', 0) ],
"_handrail_n_1_rel" : [ SenseInfo('02788148-n', 0) ],
"_chew_v_off_rel" : [ SenseInfo('01201089-v', 10) ],
"_incoherent_a_1_rel" : [ SenseInfo('00464962-a', 1), SenseInfo('00328653-a', 0), SenseInfo('00152104-a', 0), SenseInfo('00464962-a', 1), SenseInfo('00328653-a', 0), SenseInfo('00152104-a', 0) ],
"_cabinet_n_1_rel" : [ SenseInfo('02933112-n', 4), SenseInfo('08381820-n', 0), SenseInfo('02933462-n', 0), SenseInfo('02933340-n', 0) ],
"_lay_v_on_rel" : [ SenseInfo('01494310-v', 24), SenseInfo('01544692-v', 11), SenseInfo('01651972-v', 5), SenseInfo('01545079-v', 4), SenseInfo('02307261-v', 1) ],
"_comforter_n_1_rel" : [ SenseInfo('10686313-n', 0), SenseInfo('10518349-n', 0), SenseInfo('04033995-n', 0), SenseInfo('03075768-n', 0) ],
"_antique_n_1_rel" : [ SenseInfo('10376890-n', 0), SenseInfo('02723754-n', 0) ],
"_blister_n_1_rel" : [ SenseInfo('14464512-n', 0), SenseInfo('13088858-n', 0), SenseInfo('05517837-n', 0) ],
"_linsey-woolsey_n_1_rel" : [ SenseInfo('03675445-n', 0) ],
"_executioner_n_1_rel" : [ SenseInfo('10069427-n', 2) ],
"_affianced_n_1_rel" : [  ],
"_rugged_a_1_rel" : [ SenseInfo('00707366-a', 9), SenseInfo('02243806-a', 0), SenseInfo('02239746-a', 0), SenseInfo('00748058-a', 0) ],
"_assess_v_as_rel" : [ SenseInfo('00681429-v', 14), SenseInfo('02308552-v', 0), SenseInfo('02308389-v', 0), SenseInfo('00682230-v', 0), SenseInfo('00681429-v', 14), SenseInfo('02308552-v', 0), SenseInfo('02308389-v', 0), SenseInfo('00682230-v', 0) ],
"_guarantee_n_of_rel" : [ SenseInfo('06685456-n', 2), SenseInfo('06686174-n', 1), SenseInfo('13353004-n', 0), SenseInfo('06685456-n', 2), SenseInfo('06686174-n', 1), SenseInfo('13353004-n', 0) ],
"_taswegian_a_1_rel" : [  ],
"_mention_v_to_rel" : [ SenseInfo('01024190-v', 62), SenseInfo('01020005-v', 14), SenseInfo('01023071-v', 6), SenseInfo('01024190-v', 62), SenseInfo('01020005-v', 14), SenseInfo('01023071-v', 6), SenseInfo('01024190-v', 62), SenseInfo('01020005-v', 14), SenseInfo('01023071-v', 6) ],
"_d2_n_1_rel" : [  ],
"_pliers_n_1_rel" : [ SenseInfo('03966976-n', 0) ],
"_semiconductor_n_1_rel" : [ SenseInfo('14821248-n', 0), SenseInfo('04171831-n', 0) ],
"_litigation_n_1_rel" : [ SenseInfo('01186810-n', 1) ],
"_hum_a_1_rel" : [ SenseInfo('14008050-n', 0), SenseInfo('08022972-n', 0), SenseInfo('07385803-n', 0) ],
"_psychology_n_1_rel" : [ SenseInfo('06136258-n', 5) ],
"_proverb_n_1_rel" : [ SenseInfo('07153838-n', 3) ],
"_interlude_n_1_rel" : [ SenseInfo('15272685-n', 4), SenseInfo('00520880-n', 0) ],
"_independent_n_1_rel" : [ SenseInfo('10337488-n', 0), SenseInfo('10110421-n', 0) ],
"_double_n_1_rel" : [ SenseInfo('00132756-n', 12), SenseInfo('10666846-n', 0), SenseInfo('10027246-n', 0), SenseInfo('05860200-n', 0), SenseInfo('00803394-n', 0) ],
"_impinge_v_on_rel" : [ SenseInfo('02569790-v', 1), SenseInfo('01993352-v', 0) ],
"_clash_n_1_rel" : [ SenseInfo('07380144-n', 2), SenseInfo('13981137-n', 1), SenseInfo('13981271-n', 0), SenseInfo('00959376-n', 0) ],
"_shop_v_1_rel" : [ SenseInfo('02325968-v', 7), SenseInfo('02466134-v', 1), SenseInfo('02326355-v', 0), SenseInfo('00841986-v', 0) ],
"_pinpoint_n_1_rel" : [ SenseInfo('15245382-n', 1), SenseInfo('04681230-n', 1), SenseInfo('03943544-n', 0) ],
"_oyster_n_1_rel" : [ SenseInfo('01960459-n', 1), SenseInfo('07786164-n', 0), SenseInfo('07649342-n', 0) ],
"_or_c_1_rel" : [  ],
"_fry_v_1_rel" : [ SenseInfo('02738241-v', 1), SenseInfo('00325328-v', 1), SenseInfo('02484957-v', 0) ],
"_doa_a_1_rel" : [  ],
"_destruction_n_of_rel" : [ SenseInfo('00217014-n', 8), SenseInfo('07334490-n', 6), SenseInfo('14562960-n', 0) ],
"_ramify_v_cause_rel" : [ SenseInfo('00401373-v', 0), SenseInfo('00329244-v', 0), SenseInfo('00328802-v', 0) ],
"_sleep_n_1_rel" : [ SenseInfo('14024882-n', 23), SenseInfo('14025993-n', 1), SenseInfo('15273626-n', 0), SenseInfo('13962765-n', 0) ],
"_jerky_n_1_rel" : [ SenseInfo('07664770-n', 0) ],
"_upset_v_1_rel" : [ SenseInfo('00521296-v', 4), SenseInfo('01790020-v', 2), SenseInfo('01770501-v', 2), SenseInfo('01909978-v', 0), SenseInfo('01256374-v', 0), SenseInfo('01109087-v', 0), SenseInfo('00521296-v', 4), SenseInfo('01790020-v', 2), SenseInfo('01770501-v', 2), SenseInfo('01909978-v', 0), SenseInfo('01256374-v', 0), SenseInfo('01109087-v', 0), SenseInfo('00521296-v', 4), SenseInfo('01790020-v', 2), SenseInfo('01770501-v', 2), SenseInfo('01909978-v', 0), SenseInfo('01256374-v', 0), SenseInfo('01109087-v', 0), SenseInfo('00521296-v', 4), SenseInfo('01790020-v', 2), SenseInfo('01770501-v', 2), SenseInfo('01909978-v', 0), SenseInfo('01256374-v', 0), SenseInfo('01109087-v', 0), SenseInfo('00521296-v', 4), SenseInfo('01790020-v', 2), SenseInfo('01770501-v', 2), SenseInfo('01909978-v', 0), SenseInfo('01256374-v', 0), SenseInfo('01109087-v', 0) ],
"_next+to_x_deg_rel" : [  ],
"_save_v_1_rel" : [ SenseInfo('02550868-v', 41), SenseInfo('02225492-v', 16), SenseInfo('02551832-v', 4), SenseInfo('02266920-v', 4), SenseInfo('02265979-v', 4), SenseInfo('00549552-v', 4), SenseInfo('02551602-v', 2), SenseInfo('02464583-v', 2), SenseInfo('02357228-v', 1), SenseInfo('02283716-v', 1), SenseInfo('00998886-v', 0), SenseInfo('02550868-v', 41), SenseInfo('02225492-v', 16), SenseInfo('02551832-v', 4), SenseInfo('02266920-v', 4), SenseInfo('02265979-v', 4), SenseInfo('00549552-v', 4), SenseInfo('02551602-v', 2), SenseInfo('02464583-v', 2), SenseInfo('02357228-v', 1), SenseInfo('02283716-v', 1), SenseInfo('00998886-v', 0) ],
"_fridge_n_1_rel" : [ SenseInfo('03273913-n', 0) ],
"_exasperation_n_1_rel" : [ SenseInfo('07518878-n', 6), SenseInfo('00425451-n', 0) ],
"_free-for-all_n_1_rel" : [ SenseInfo('01176431-n', 0), SenseInfo('01176431-n', 0) ],
"_pile_v_1_rel" : [ SenseInfo('01503404-v', 8), SenseInfo('02064131-v', 2), SenseInfo('01434822-v', 0), SenseInfo('01503404-v', 8), SenseInfo('02064131-v', 2), SenseInfo('01434822-v', 0) ],
"_overtone_n_1_rel" : [ SenseInfo('06606464-n', 1), SenseInfo('05720093-n', 0) ],
"_textbook_n_1_rel" : [ SenseInfo('06414372-n', 0) ],
"_crook_v_1_rel" : [ SenseInfo('02034671-v', 0) ],
"_glower_n_1_rel" : [ SenseInfo('00878797-n', 0) ],
"_hearty_a_1_rel" : [ SenseInfo('02531243-a', 1), SenseInfo('02558528-a', 0), SenseInfo('01171746-a', 0), SenseInfo('01171606-a', 0), SenseInfo('00523479-a', 0), SenseInfo('02531243-a', 1), SenseInfo('02558528-a', 0), SenseInfo('01171746-a', 0), SenseInfo('01171606-a', 0), SenseInfo('00523479-a', 0), SenseInfo('02531243-a', 1), SenseInfo('02558528-a', 0), SenseInfo('01171746-a', 0), SenseInfo('01171606-a', 0), SenseInfo('00523479-a', 0), SenseInfo('02531243-a', 1), SenseInfo('02558528-a', 0), SenseInfo('01171746-a', 0), SenseInfo('01171606-a', 0), SenseInfo('00523479-a', 0) ],
"_grasp_n_1_rel" : [ SenseInfo('05806623-n', 0), SenseInfo('05623628-n', 0), SenseInfo('05194874-n', 0), SenseInfo('00812526-n', 0) ],
"_fortnight_n_1_rel" : [ SenseInfo('15170331-n', 0) ],
"_cop_n_1_rel" : [ SenseInfo('09879144-n', 20) ],
"_symbolize_v_1_rel" : [ SenseInfo('00836236-v', 16), SenseInfo('00987597-v', 0), SenseInfo('00836236-v', 16), SenseInfo('00987597-v', 0) ],
"_competent_n_1_rel" : [ SenseInfo('00510050-a', 7), SenseInfo('00051571-a', 3), SenseInfo('00512130-a', 0) ],
"_approximate_a_1_rel" : [ SenseInfo('00915976-a', 3), SenseInfo('00451872-a', 0), SenseInfo('00448130-a', 0), SenseInfo('00915976-a', 3), SenseInfo('00451872-a', 0), SenseInfo('00448130-a', 0) ],
"_obligatory_a_1_rel" : [ SenseInfo('00848074-a', 0), SenseInfo('01580968-a', 0) ],
"_prime_n_1_rel" : [ SenseInfo('13594005-n', 2), SenseInfo('15295045-n', 0), SenseInfo('15229784-n', 0), SenseInfo('15152409-n', 0) ],
"_madeira_n_1_rel" : [ SenseInfo('09345127-n', 0), SenseInfo('08985559-n', 0), SenseInfo('07900616-n', 0) ],
"_insensibility_n_1_rel" : [ SenseInfo('05680982-n', 0), SenseInfo('04844625-n', 0) ],
"_kitten_n_1_rel" : [ SenseInfo('02122948-n', 7) ],
"_poverty_n_1_rel" : [ SenseInfo('14493145-n', 7) ],
"_shudder_n_1_rel" : [ SenseInfo('07520112-n', 0), SenseInfo('00348801-n', 0) ],
"_write-up_n_1_rel" : [ SenseInfo('06681551-n', 0), SenseInfo('06681551-n', 0) ],
"_heretofore_a_1_rel" : [  ],
"_more+than_a_1_rel" : [ SenseInfo('01555133-a', 0) ],
"_adherence_n_1_rel" : [ SenseInfo('01212882-n', 2), SenseInfo('04935528-n', 0) ],
"_lame_a_1_rel" : [ SenseInfo('02325304-a', 0), SenseInfo('01018788-a', 0), SenseInfo('02325304-a', 0), SenseInfo('01018788-a', 0), SenseInfo('02325304-a', 0), SenseInfo('01018788-a', 0) ],
"_surprised_a_at_rel" : [ SenseInfo('02357479-a', 15), SenseInfo('02357479-a', 15) ],
"_besides_p_rel" : [ SenseInfo('00029037-r', 10), SenseInfo('00047534-r', 1) ],
"_hosers_a_1_rel" : [  ],
"_ice_n_1_rel" : [ SenseInfo('14915184-n', 22), SenseInfo('09308398-n', 1), SenseInfo('13372123-n', 0), SenseInfo('07620822-n', 0), SenseInfo('07614198-n', 0), SenseInfo('03754295-n', 0), SenseInfo('03579982-n', 0), SenseInfo('03558176-n', 0) ],
"_flemish_n_1_rel" : [ SenseInfo('08483788-n', 0), SenseInfo('06952705-n', 0), SenseInfo('08483788-n', 0), SenseInfo('06952705-n', 0), SenseInfo('08483788-n', 0), SenseInfo('06952705-n', 0) ],
"_distress_v_1_rel" : [ SenseInfo('02603424-v', 0), SenseInfo('01798100-v', 0) ],
"_patriarch_n_1_rel" : [ SenseInfo('10406905-n', 0), SenseInfo('10406765-n', 0), SenseInfo('10406391-n', 0), SenseInfo('10406266-n', 0) ],
"_valve_n_1_rel" : [ SenseInfo('05395286-n', 2), SenseInfo('04519536-n', 1), SenseInfo('04519153-n', 0), SenseInfo('01904583-n', 0), SenseInfo('01904461-n', 0) ],
"_fairy_n_1_rel" : [ SenseInfo('09540430-n', 1), SenseInfo('10076033-n', 0) ],
"_anguish_n_1_rel" : [ SenseInfo('07496755-n', 4), SenseInfo('14449022-n', 2) ],
"_afflict_v_1_rel" : [ SenseInfo('01797730-v', 0), SenseInfo('00259927-v', 0) ],
"_patent_n_of_rel" : [ SenseInfo('06501141-n', 5), SenseInfo('06551627-n', 0) ],
"_devastation_n_1_rel" : [ SenseInfo('14562142-n', 0), SenseInfo('07509827-n', 0), SenseInfo('07335414-n', 0), SenseInfo('00967157-n', 0), SenseInfo('00217014-n', 0) ],
"_knothole_n_1_rel" : [ SenseInfo('15102894-n', 0) ],
"_oxide_n_1_rel" : [ SenseInfo('14971519-n', 0) ],
"_anyway_a_1_rel" : [  ],
"_nag_n_1_rel" : [ SenseInfo('10561861-n', 0), SenseInfo('02382204-n', 0) ],
"_go_v_off_rel" : [ SenseInfo('01835496-v', 343), SenseInfo('02372605-v', 95), SenseInfo('01848718-v', 49), SenseInfo('00149583-v', 29), SenseInfo('02653862-v', 14), SenseInfo('02721284-v', 10), SenseInfo('02685951-v', 10), SenseInfo('00341560-v', 10), SenseInfo('00359916-v', 9), SenseInfo('02618001-v', 7), SenseInfo('02176268-v', 3), SenseInfo('01525666-v', 3), SenseInfo('01192773-v', 3), SenseInfo('00539110-v', 3), SenseInfo('02618149-v', 2), SenseInfo('02617798-v', 2), SenseInfo('00358431-v', 2), SenseInfo('02737876-v', 1), SenseInfo('02729819-v', 1), SenseInfo('01864230-v', 1), SenseInfo('01076615-v', 1), SenseInfo('02700772-v', 0), SenseInfo('02700666-v', 0), SenseInfo('02700455-v', 0), SenseInfo('02686471-v', 0), SenseInfo('02659763-v', 0), SenseInfo('01318849-v', 0), SenseInfo('01192992-v', 0), SenseInfo('00676267-v', 0), SenseInfo('00434374-v', 0) ],
"_multiple_n_1_rel" : [ SenseInfo('05859991-n', 0) ],
"_pr_n_1_rel" : [ SenseInfo('14651212-n', 0), SenseInfo('08752974-n', 0), SenseInfo('07247925-n', 0) ],
"_scare_n_1_rel" : [ SenseInfo('14405931-n', 0), SenseInfo('07521437-n', 0) ],
"_runnable_a_1_rel" : [  ],
"_hurricane_n_1_rel" : [ SenseInfo('11467018-n', 2) ],
"_in+part_x_deg_rel" : [  ],
"_liberation_n_of_rel" : [ SenseInfo('00095502-n', 1), SenseInfo('00787832-n', 0), SenseInfo('00216174-n', 0) ],
"_undergarment_n_1_rel" : [ SenseInfo('04508163-n', 0) ],
"_bow_v_out_rel" : [ SenseInfo('00898691-v', 11), SenseInfo('00878348-v', 3), SenseInfo('02040273-v', 1), SenseInfo('02062632-v', 0), SenseInfo('01729295-v', 0), SenseInfo('00898691-v', 11), SenseInfo('00878348-v', 3), SenseInfo('02040273-v', 1), SenseInfo('02062632-v', 0), SenseInfo('01729295-v', 0) ],
"_bother_v_with_rel" : [ SenseInfo('02507464-v', 18), SenseInfo('01787955-v', 16), SenseInfo('02507736-v', 8), SenseInfo('02018858-v', 0), SenseInfo('01791535-v', 0), SenseInfo('01791408-v', 0) ],
"_may_v_modal_rel" : [ SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0) ],
"_threat_n_1_rel" : [ SenseInfo('14543231-n', 16), SenseInfo('07226015-n', 4), SenseInfo('06733476-n', 4), SenseInfo('10702615-n', 0), SenseInfo('14543231-n', 16), SenseInfo('07226015-n', 4), SenseInfo('06733476-n', 4), SenseInfo('10702615-n', 0), SenseInfo('14543231-n', 16), SenseInfo('07226015-n', 4), SenseInfo('06733476-n', 4), SenseInfo('10702615-n', 0) ],
"_lion_n_1_rel" : [ SenseInfo('02129165-n', 2), SenseInfo('10265070-n', 0), SenseInfo('09752795-n', 0), SenseInfo('08686821-n', 0) ],
"_budget_v_for_rel" : [ SenseInfo('00724029-v', 2), SenseInfo('00724029-v', 2) ],
"_sort+of_a_1_rel" : [  ],
"_disgusting_a_1_rel" : [ SenseInfo('01625893-a', 1) ],
"_dynabook_n_1_rel" : [  ],
"_sag_n_1_rel" : [ SenseInfo('13905572-n', 0) ],
"_elute_v_1_rel" : [ SenseInfo('01270463-v', 1) ],
"_consort_n_1_rel" : [ SenseInfo('09958724-n', 0), SenseInfo('08188814-n', 0) ],
"_innumerable_a_1_rel" : [ SenseInfo('00301951-a', 1) ],
"_sorry_a_1_rel" : [ SenseInfo('01150475-a', 1), SenseInfo('01126841-a', 1), SenseInfo('02502578-a', 0), SenseInfo('00364881-a', 0) ],
"_thread_v_1_rel" : [ SenseInfo('01882814-v', 3), SenseInfo('01521912-v', 3), SenseInfo('01359917-v', 0), SenseInfo('01359803-v', 0), SenseInfo('01359432-v', 0), SenseInfo('01882814-v', 3), SenseInfo('01521912-v', 3), SenseInfo('01359917-v', 0), SenseInfo('01359803-v', 0), SenseInfo('01359432-v', 0) ],
"_wheelchair_n_1_rel" : [ SenseInfo('04576002-n', 1) ],
"_cadmium_n_1_rel" : [ SenseInfo('14632444-n', 0) ],
"_unpopular_a_1_rel" : [ SenseInfo('01816956-a', 4), SenseInfo('01816956-a', 4) ],
"_monsieur_n_1_rel" : [ SenseInfo('10329675-n', 1) ],
"_pothole_n_1_rel" : [ SenseInfo('09398076-n', 2) ],
"_celebrate_v_1_rel" : [ SenseInfo('02578510-v', 11), SenseInfo('02490877-v', 6), SenseInfo('02398956-v', 2) ],
"_stamp_n_1_rel" : [ SenseInfo('13913566-n', 1), SenseInfo('07998573-n', 1), SenseInfo('06855207-n', 1), SenseInfo('06796119-n', 1), SenseInfo('13374008-n', 0), SenseInfo('06855817-n', 0), SenseInfo('04300080-n', 0), SenseInfo('04299963-n', 0), SenseInfo('04159058-n', 0) ],
"_tit-for-tat_a_1_rel" : [  ],
"_madman_n_1_rel" : [ SenseInfo('10276764-n', 3) ],
"_treaty_n_1_rel" : [ SenseInfo('06773434-n', 3) ],
"_in+full_p_1_rel" : [ SenseInfo('00504620-r', 3) ],
"_spark_v_1_rel" : [ SenseInfo('01643657-v', 5), SenseInfo('02766687-v', 1), SenseInfo('01643657-v', 5), SenseInfo('02766687-v', 1) ],
"_divide_v_1_rel" : [ SenseInfo('02467662-v', 20), SenseInfo('00642098-v', 11), SenseInfo('02621853-v', 4), SenseInfo('01557774-v', 2), SenseInfo('02031158-v', 1), SenseInfo('01556921-v', 1) ],
"_arbitrary_a_1_rel" : [ SenseInfo('00718924-a', 8), SenseInfo('00718924-a', 8) ],
"_monk_n_1_rel" : [ SenseInfo('10112129-n', 5), SenseInfo('11185500-n', 0) ],
"_ohm_n_1_rel" : [ SenseInfo('13646816-n', 0), SenseInfo('11213094-n', 0) ],
"_presentation_n_of_rel" : [ SenseInfo('01048697-n', 6), SenseInfo('00521562-n', 4), SenseInfo('06891022-n', 3), SenseInfo('07167415-n', 1), SenseInfo('03210940-n', 1), SenseInfo('07217349-n', 0), SenseInfo('05081434-n', 0) ],
"_bottom+line_n_1_rel" : [ SenseInfo('13423267-n', 0), SenseInfo('06606618-n', 0) ],
"_wiggle_v_1_rel" : [ SenseInfo('01898282-v', 5), SenseInfo('01898282-v', 5) ],
"_well-suited_a_1_rel" : [  ],
"_lunch_v_on_rel" : [ SenseInfo('01185304-v', 1), SenseInfo('01185475-v', 0) ],
"_parka_n_1_rel" : [ SenseInfo('03891051-n', 0) ],
"_resistance_n_to_rel" : [ SenseInfo('00202284-n', 6), SenseInfo('11503644-n', 4), SenseInfo('11503968-n', 2), SenseInfo('00955987-n', 1), SenseInfo('14527171-n', 0), SenseInfo('14526954-n', 0), SenseInfo('08360672-n', 0), SenseInfo('05213894-n', 0), SenseInfo('04646372-n', 0), SenseInfo('04079933-n', 0), SenseInfo('01169317-n', 0), SenseInfo('00202284-n', 6), SenseInfo('11503644-n', 4), SenseInfo('11503968-n', 2), SenseInfo('00955987-n', 1), SenseInfo('14527171-n', 0), SenseInfo('14526954-n', 0), SenseInfo('08360672-n', 0), SenseInfo('05213894-n', 0), SenseInfo('04646372-n', 0), SenseInfo('04079933-n', 0), SenseInfo('01169317-n', 0) ],
"_apathetic_a_1_rel" : [ SenseInfo('02281611-a', 0), SenseInfo('01342949-a', 0), SenseInfo('02281611-a', 0), SenseInfo('01342949-a', 0) ],
"_markka_n_1_rel" : [ SenseInfo('13688447-n', 0) ],
"_ball_n_i_rel" : [ SenseInfo('02778669-n', 35), SenseInfo('03802228-n', 5), SenseInfo('13899404-n', 3), SenseInfo('08253268-n', 2), SenseInfo('05524615-n', 1), SenseInfo('02779435-n', 1), SenseInfo('10832731-n', 0), SenseInfo('07961016-n', 0), SenseInfo('07448885-n', 0), SenseInfo('05576194-n', 0), SenseInfo('00474568-n', 0), SenseInfo('00107400-n', 0) ],
"_on+the+mend_a_1_rel" : [  ],
"_student_n_of_rel" : [ SenseInfo('10665698-n', 67), SenseInfo('10557854-n', 14) ],
"_fuzzy_a_1_rel" : [ SenseInfo('00214165-a', 2), SenseInfo('00781644-a', 1), SenseInfo('00465585-a', 0), SenseInfo('00214165-a', 2), SenseInfo('00781644-a', 1), SenseInfo('00465585-a', 0), SenseInfo('00214165-a', 2), SenseInfo('00781644-a', 1), SenseInfo('00465585-a', 0) ],
"_marvellous_a_1_rel" : [ SenseInfo('01676517-a', 0), SenseInfo('01576551-a', 0), SenseInfo('00646117-a', 0) ],
"_grandfather_v_1_rel" : [  ],
"_past_a_1_rel" : [ SenseInfo('01727926-a', 29), SenseInfo('01296091-a', 4) ],
"_shave_v_1_rel" : [ SenseInfo('00037298-v', 8), SenseInfo('01248782-v', 1), SenseInfo('02349597-v', 0), SenseInfo('01249490-v', 0), SenseInfo('01249147-v', 0), SenseInfo('01248597-v', 0) ],
"_engraver_n_1_rel" : [ SenseInfo('10058155-n', 1), SenseInfo('10058027-n', 0) ],
"_swell_a_1_rel" : [ SenseInfo('01123879-a', 1) ],
"_mock_v_1_rel" : [ SenseInfo('00849080-v', 4), SenseInfo('00849332-v', 0), SenseInfo('00849080-v', 4), SenseInfo('00849332-v', 0) ],
"_toboggan_v_1_rel" : [ SenseInfo('01940034-v', 0) ],
"_conquer_v_1_rel" : [ SenseInfo('00462092-v', 5), SenseInfo('02272549-v', 1), SenseInfo('01114303-v', 1) ],
"_affirmative_n_1_rel" : [ SenseInfo('07203696-n', 0) ],
"_set_v_i_rel" : [ SenseInfo('01494310-v', 30), SenseInfo('00699815-v', 29), SenseInfo('00947077-v', 12), SenseInfo('01062395-v', 10), SenseInfo('00298896-v', 9), SenseInfo('01607445-v', 6), SenseInfo('00406243-v', 5), SenseInfo('00298556-v', 5), SenseInfo('01711749-v', 3), SenseInfo('01970646-v', 2), SenseInfo('01706129-v', 2), SenseInfo('01567275-v', 2), SenseInfo('01628899-v', 1), SenseInfo('00442669-v', 1), SenseInfo('01744888-v', 0), SenseInfo('01613239-v', 0), SenseInfo('01530273-v', 0), SenseInfo('01247322-v', 0), SenseInfo('01115006-v', 0), SenseInfo('00673448-v', 0), SenseInfo('00408085-v', 0), SenseInfo('00407848-v', 0), SenseInfo('00296178-v', 0), SenseInfo('00056188-v', 0), SenseInfo('00038849-v', 0) ],
"_holiday_v_1_rel" : [ SenseInfo('02708707-v', 0) ],
"_poetic_a_1_rel" : [ SenseInfo('02857099-a', 1), SenseInfo('01420337-a', 1), SenseInfo('02857295-a', 0), SenseInfo('02018141-a', 0) ],
"_damn_v_to_rel" : [ SenseInfo('00865958-v', 7), SenseInfo('00865958-v', 7), SenseInfo('00865958-v', 7), SenseInfo('00865958-v', 7), SenseInfo('00865958-v', 7) ],
"_prepositional_a_1_rel" : [ SenseInfo('03102278-a', 3) ],
"_cache_n_1_rel" : [ SenseInfo('02934888-n', 1), SenseInfo('13366912-n', 0), SenseInfo('02935017-n', 0) ],
"_topping_n_1_rel" : [ SenseInfo('07621776-n', 0) ],
"_initiative_n_1_rel" : [ SenseInfo('04836074-n', 5), SenseInfo('00239230-n', 4), SenseInfo('04836074-n', 5), SenseInfo('00239230-n', 4), SenseInfo('04836074-n', 5), SenseInfo('00239230-n', 4), SenseInfo('04836074-n', 5), SenseInfo('00239230-n', 4) ],
"_preparative_a_1_rel" : [ SenseInfo('00126830-a', 1) ],
"_thousandth_n_of_rel" : [ SenseInfo('13849810-n', 0), SenseInfo('13739170-n', 0) ],
"_concern_n_1_rel" : [ SenseInfo('05670710-n', 21), SenseInfo('07524529-n', 12), SenseInfo('07504841-n', 4), SenseInfo('05832264-n', 4), SenseInfo('08061042-n', 2), SenseInfo('05670710-n', 21), SenseInfo('07524529-n', 12), SenseInfo('07504841-n', 4), SenseInfo('05832264-n', 4), SenseInfo('08061042-n', 2) ],
"_overnight_a_2_rel" : [ SenseInfo('01441530-a', 2), SenseInfo('01441530-a', 2) ],
"_bomb_n_1_rel" : [ SenseInfo('02866578-n', 8), SenseInfo('02867592-n', 1), SenseInfo('07365193-n', 0) ],
"_supermarket_n_1_rel" : [ SenseInfo('04358707-n', 1) ],
"_pool_n_of_rel" : [ SenseInfo('03982060-n', 13), SenseInfo('09397391-n', 2), SenseInfo('08481369-n', 2), SenseInfo('08236438-n', 2), SenseInfo('13369857-n', 1), SenseInfo('09397607-n', 1), SenseInfo('13369474-n', 0), SenseInfo('08665101-n', 0), SenseInfo('00501080-n', 0) ],
"_instead_p_rel" : [ SenseInfo('00063172-r', 36), SenseInfo('00098714-r', 21) ],
"_conveyance_n_1_rel" : [ SenseInfo('06546633-n', 0), SenseInfo('06252954-n', 0), SenseInfo('03100490-n', 0), SenseInfo('01108402-n', 0), SenseInfo('00315986-n', 0) ],
"_most_a_1_rel" : [ SenseInfo('01557120-a', 76), SenseInfo('01555732-a', 26), SenseInfo('01557120-a', 76), SenseInfo('01555732-a', 26), SenseInfo('01557120-a', 76), SenseInfo('01555732-a', 26) ],
"_crosstalk_n_1_rel" : [ SenseInfo('07431247-n', 0) ],
"_applause_n_1_rel" : [ SenseInfo('06691989-n', 9) ],
"_piss_n_1_rel" : [ SenseInfo('14855724-n', 0), SenseInfo('13533886-n', 0) ],
"_joyous_a_1_rel" : [ SenseInfo('01366718-a', 4) ],
"_halter_n_1_rel" : [ SenseInfo('03480719-n', 1), SenseInfo('03491724-n', 0), SenseInfo('03480579-n', 0), SenseInfo('02152212-n', 0) ],
"_call_n_1_rel" : [ SenseInfo('06272803-n', 9), SenseInfo('06198505-n', 4), SenseInfo('07120524-n', 3), SenseInfo('07192129-n', 2), SenseInfo('06796642-n', 1), SenseInfo('01055954-n', 1), SenseInfo('07192661-n', 0), SenseInfo('07192511-n', 0), SenseInfo('07190693-n', 0), SenseInfo('06582761-n', 0), SenseInfo('01055493-n', 0), SenseInfo('00164801-n', 0), SenseInfo('00080743-n', 0) ],
"_lest_x_rel" : [  ],
"_caveat_n_1_rel" : [ SenseInfo('07225167-n', 1), SenseInfo('06747907-n', 0), SenseInfo('07225167-n', 1), SenseInfo('06747907-n', 0) ],
"_onerous_a_1_rel" : [ SenseInfo('01189109-a', 0) ],
"_vocalize_v_1_rel" : [ SenseInfo('00952182-v', 1), SenseInfo('01704236-v', 0), SenseInfo('00983635-v', 0), SenseInfo('00978369-v', 0), SenseInfo('00745187-v', 0) ],
"_ride_n_1_rel" : [ SenseInfo('00307631-n', 6), SenseInfo('04088797-n', 0) ],
"_devote_v_to_rel" : [ SenseInfo('00887463-v', 30), SenseInfo('00732224-v', 5), SenseInfo('02214717-v', 0) ],
"_mens_a_1_rel" : [  ],
"_towel_v_off_rel" : [ SenseInfo('01394335-v', 0), SenseInfo('01394335-v', 0) ],
"_northbound_a_1_rel" : [ SenseInfo('01600713-a', 0) ],
"_sew_v_up_rel" : [ SenseInfo('01329239-v', 5), SenseInfo('01666327-v', 0) ],
"_kitty_n_1_rel" : [ SenseInfo('13369474-n', 0), SenseInfo('13343774-n', 0), SenseInfo('02122948-n', 0), SenseInfo('02122298-n', 0) ],
"_order_n_of_rel" : [ SenseInfo('07168623-n', 26), SenseInfo('05091316-n', 8), SenseInfo('13968547-n', 7), SenseInfo('08456993-n', 6), SenseInfo('14496710-n', 4), SenseInfo('06539770-n', 2), SenseInfo('06529219-n', 2), SenseInfo('08227214-n', 1), SenseInfo('06652878-n', 1), SenseInfo('13950812-n', 0), SenseInfo('08147794-n', 0), SenseInfo('08106934-n', 0), SenseInfo('07279687-n', 0), SenseInfo('04698656-n', 0), SenseInfo('01009871-n', 0), SenseInfo('07168623-n', 26), SenseInfo('05091316-n', 8), SenseInfo('13968547-n', 7), SenseInfo('08456993-n', 6), SenseInfo('14496710-n', 4), SenseInfo('06539770-n', 2), SenseInfo('06529219-n', 2), SenseInfo('08227214-n', 1), SenseInfo('06652878-n', 1), SenseInfo('13950812-n', 0), SenseInfo('08147794-n', 0), SenseInfo('08106934-n', 0), SenseInfo('07279687-n', 0), SenseInfo('04698656-n', 0), SenseInfo('01009871-n', 0), SenseInfo('07168623-n', 26), SenseInfo('05091316-n', 8), SenseInfo('13968547-n', 7), SenseInfo('08456993-n', 6), SenseInfo('14496710-n', 4), SenseInfo('06539770-n', 2), SenseInfo('06529219-n', 2), SenseInfo('08227214-n', 1), SenseInfo('06652878-n', 1), SenseInfo('13950812-n', 0), SenseInfo('08147794-n', 0), SenseInfo('08106934-n', 0), SenseInfo('07279687-n', 0), SenseInfo('04698656-n', 0), SenseInfo('01009871-n', 0), SenseInfo('07168623-n', 26), SenseInfo('05091316-n', 8), SenseInfo('13968547-n', 7), SenseInfo('08456993-n', 6), SenseInfo('14496710-n', 4), SenseInfo('06539770-n', 2), SenseInfo('06529219-n', 2), SenseInfo('08227214-n', 1), SenseInfo('06652878-n', 1), SenseInfo('13950812-n', 0), SenseInfo('08147794-n', 0), SenseInfo('08106934-n', 0), SenseInfo('07279687-n', 0), SenseInfo('04698656-n', 0), SenseInfo('01009871-n', 0), SenseInfo('07168623-n', 26), SenseInfo('05091316-n', 8), SenseInfo('13968547-n', 7), SenseInfo('08456993-n', 6), SenseInfo('14496710-n', 4), SenseInfo('06539770-n', 2), SenseInfo('06529219-n', 2), SenseInfo('08227214-n', 1), SenseInfo('06652878-n', 1), SenseInfo('13950812-n', 0), SenseInfo('08147794-n', 0), SenseInfo('08106934-n', 0), SenseInfo('07279687-n', 0), SenseInfo('04698656-n', 0), SenseInfo('01009871-n', 0), SenseInfo('07168623-n', 26), SenseInfo('05091316-n', 8), SenseInfo('13968547-n', 7), SenseInfo('08456993-n', 6), SenseInfo('14496710-n', 4), SenseInfo('06539770-n', 2), SenseInfo('06529219-n', 2), SenseInfo('08227214-n', 1), SenseInfo('06652878-n', 1), SenseInfo('13950812-n', 0), SenseInfo('08147794-n', 0), SenseInfo('08106934-n', 0), SenseInfo('07279687-n', 0), SenseInfo('04698656-n', 0), SenseInfo('01009871-n', 0), SenseInfo('07168623-n', 26), SenseInfo('05091316-n', 8), SenseInfo('13968547-n', 7), SenseInfo('08456993-n', 6), SenseInfo('14496710-n', 4), SenseInfo('06539770-n', 2), SenseInfo('06529219-n', 2), SenseInfo('08227214-n', 1), SenseInfo('06652878-n', 1), SenseInfo('13950812-n', 0), SenseInfo('08147794-n', 0), SenseInfo('08106934-n', 0), SenseInfo('07279687-n', 0), SenseInfo('04698656-n', 0), SenseInfo('01009871-n', 0), SenseInfo('07168623-n', 26), SenseInfo('05091316-n', 8), SenseInfo('13968547-n', 7), SenseInfo('08456993-n', 6), SenseInfo('14496710-n', 4), SenseInfo('06539770-n', 2), SenseInfo('06529219-n', 2), SenseInfo('08227214-n', 1), SenseInfo('06652878-n', 1), SenseInfo('13950812-n', 0), SenseInfo('08147794-n', 0), SenseInfo('08106934-n', 0), SenseInfo('07279687-n', 0), SenseInfo('04698656-n', 0), SenseInfo('01009871-n', 0), SenseInfo('07168623-n', 26), SenseInfo('05091316-n', 8), SenseInfo('13968547-n', 7), SenseInfo('08456993-n', 6), SenseInfo('14496710-n', 4), SenseInfo('06539770-n', 2), SenseInfo('06529219-n', 2), SenseInfo('08227214-n', 1), SenseInfo('06652878-n', 1), SenseInfo('13950812-n', 0), SenseInfo('08147794-n', 0), SenseInfo('08106934-n', 0), SenseInfo('07279687-n', 0), SenseInfo('04698656-n', 0), SenseInfo('01009871-n', 0), SenseInfo('07168623-n', 26), SenseInfo('05091316-n', 8), SenseInfo('13968547-n', 7), SenseInfo('08456993-n', 6), SenseInfo('14496710-n', 4), SenseInfo('06539770-n', 2), SenseInfo('06529219-n', 2), SenseInfo('08227214-n', 1), SenseInfo('06652878-n', 1), SenseInfo('13950812-n', 0), SenseInfo('08147794-n', 0), SenseInfo('08106934-n', 0), SenseInfo('07279687-n', 0), SenseInfo('04698656-n', 0), SenseInfo('01009871-n', 0), SenseInfo('07168623-n', 26), SenseInfo('05091316-n', 8), SenseInfo('13968547-n', 7), SenseInfo('08456993-n', 6), SenseInfo('14496710-n', 4), SenseInfo('06539770-n', 2), SenseInfo('06529219-n', 2), SenseInfo('08227214-n', 1), SenseInfo('06652878-n', 1), SenseInfo('13950812-n', 0), SenseInfo('08147794-n', 0), SenseInfo('08106934-n', 0), SenseInfo('07279687-n', 0), SenseInfo('04698656-n', 0), SenseInfo('01009871-n', 0) ],
"_hydrophobicity_n_1_rel" : [ SenseInfo('05196220-n', 0) ],
"_scoop_n_1_rel" : [ SenseInfo('13769317-n', 1), SenseInfo('13894306-n', 0), SenseInfo('06683183-n', 0), SenseInfo('04253751-n', 0), SenseInfo('04149208-n', 0), SenseInfo('04149083-n', 0) ],
"_trollop_n_1_rel" : [ SenseInfo('10609198-n', 0), SenseInfo('09772930-n', 0) ],
"_privacy_n_1_rel" : [ SenseInfo('04622932-n', 2), SenseInfo('14416089-n', 1) ],
"_marxism_n_1_rel" : [ SenseInfo('06215618-n', 0) ],
"_berth_v_1_rel" : [ SenseInfo('02336947-v', 0), SenseInfo('01305542-v', 0), SenseInfo('01305361-v', 0) ],
"_tall_a_1_rel" : [ SenseInfo('02385102-a', 73), SenseInfo('02017721-a', 0), SenseInfo('00748563-a', 0), SenseInfo('00646117-a', 0), SenseInfo('02385102-a', 73), SenseInfo('02017721-a', 0), SenseInfo('00748563-a', 0), SenseInfo('00646117-a', 0), SenseInfo('02385102-a', 73), SenseInfo('02017721-a', 0), SenseInfo('00748563-a', 0), SenseInfo('00646117-a', 0) ],
"_pull_v_across_rel" : [ SenseInfo('01448100-v', 44), SenseInfo('01505254-v', 8), SenseInfo('02057499-v', 6), SenseInfo('01609287-v', 3), SenseInfo('02582615-v', 2), SenseInfo('01995211-v', 2), SenseInfo('02057337-v', 1), SenseInfo('00071803-v', 1), SenseInfo('02103162-v', 0), SenseInfo('01947247-v', 0), SenseInfo('01858573-v', 0), SenseInfo('01573276-v', 0), SenseInfo('01407059-v', 0), SenseInfo('01384275-v', 0), SenseInfo('01351170-v', 0), SenseInfo('01148710-v', 0), SenseInfo('00571596-v', 0) ],
"_heck_n_1_rel" : [  ],
"_abolition_n_of_rel" : [ SenseInfo('00228283-n', 1) ],
"_spongy_a_1_rel" : [ SenseInfo('01154964-a', 2), SenseInfo('00007516-a', 0), SenseInfo('01154964-a', 2), SenseInfo('00007516-a', 0), SenseInfo('01154964-a', 2), SenseInfo('00007516-a', 0) ],
"_ship_v_cause_rel" : [ SenseInfo('01950798-v', 7), SenseInfo('02409838-v', 0), SenseInfo('01979462-v', 0), SenseInfo('01847582-v', 0), SenseInfo('01496978-v', 0), SenseInfo('01950798-v', 7), SenseInfo('02409838-v', 0), SenseInfo('01979462-v', 0), SenseInfo('01847582-v', 0), SenseInfo('01496978-v', 0) ],
"_content_v_with_rel" : [ SenseInfo('01194238-v', 3), SenseInfo('01816844-v', 2) ],
"_furrow_v_1_rel" : [ SenseInfo('01277431-v', 1), SenseInfo('01277784-v', 0), SenseInfo('01277649-v', 0) ],
"_echelon_n_of_rel" : [ SenseInfo('08272352-n', 0), SenseInfo('03263474-n', 0) ],
"_oppression_n_of_rel" : [ SenseInfo('00421047-n', 1), SenseInfo('13996719-n', 0), SenseInfo('07538674-n', 0) ],
"_imaginary_a_1_rel" : [ SenseInfo('01936528-a', 7) ],
"_entire_a_1_rel" : [ SenseInfo('00515380-a', 42), SenseInfo('00515870-a', 5), SenseInfo('02244890-a', 1), SenseInfo('02137394-a', 0), SenseInfo('00515380-a', 42), SenseInfo('00515870-a', 5), SenseInfo('02244890-a', 1), SenseInfo('02137394-a', 0) ],
"_escudo_n_1_rel" : [ SenseInfo('13676108-n', 0), SenseInfo('13675824-n', 0) ],
"_pounce_v_on_rel" : [ SenseInfo('02064358-v', 2), SenseInfo('02064358-v', 2) ],
"_obvious_n_1_rel" : [ SenseInfo('01618053-a', 26) ],
"_maniac_n_1_rel" : [ SenseInfo('10276764-n', 4), SenseInfo('10290541-n', 0) ],
"_auroral_a_1_rel" : [ SenseInfo('02649873-a', 0), SenseInfo('02649706-a', 0) ],
"_unintended_a_1_rel" : [ SenseInfo('01338730-a', 1), SenseInfo('01338730-a', 1) ],
"_unmolested_a_1_rel" : [ SenseInfo('02460404-a', 8), SenseInfo('02460404-a', 8) ],
"_majority_n_of_rel" : [ SenseInfo('05122557-n', 17), SenseInfo('13581067-n', 5), SenseInfo('15152062-n', 1), SenseInfo('05122557-n', 17), SenseInfo('13581067-n', 5), SenseInfo('15152062-n', 1) ],
"_home_v_in_rel" : [ SenseInfo('02459633-v', 0), SenseInfo('02005347-v', 0), SenseInfo('02459633-v', 0), SenseInfo('02005347-v', 0), SenseInfo('02459633-v', 0), SenseInfo('02005347-v', 0) ],
"_trendy_a_1_rel" : [ SenseInfo('00973677-a', 0), SenseInfo('00973677-a', 0), SenseInfo('00973677-a', 0) ],
"_bonfire_n_1_rel" : [ SenseInfo('07303335-n', 3) ],
"_lard_n_1_rel" : [ SenseInfo('07672421-n', 0) ],
"_just_x_deg_rel" : [ SenseInfo('00004722-r', 162), SenseInfo('00158309-r', 95), SenseInfo('00033308-r', 52), SenseInfo('00246296-r', 33), SenseInfo('00002621-r', 13), SenseInfo('01369663-a', 4), SenseInfo('00958151-a', 0), SenseInfo('00956131-a', 0), SenseInfo('00002950-r', 0), SenseInfo('02036934-a', 0), SenseInfo('00004722-r', 162), SenseInfo('00158309-r', 95), SenseInfo('00033308-r', 52), SenseInfo('00246296-r', 33), SenseInfo('00002621-r', 13), SenseInfo('01369663-a', 4), SenseInfo('00958151-a', 0), SenseInfo('00956131-a', 0), SenseInfo('00002950-r', 0), SenseInfo('02036934-a', 0) ],
"_propulsive_a_1_rel" : [ SenseInfo('03104040-a', 0), SenseInfo('00809790-a', 0) ],
"_stash_v_away_rel" : [ SenseInfo('02305856-v', 0) ],
"_chary_a_of_rel" : [ SenseInfo('00325619-a', 0) ],
"_close_v_1_rel" : [ SenseInfo('01345109-v', 32), SenseInfo('01346978-v', 20), SenseInfo('02426395-v', 18), SenseInfo('02425913-v', 13), SenseInfo('02610628-v', 2), SenseInfo('00763831-v', 1), SenseInfo('02754276-v', 0), SenseInfo('02375619-v', 0), SenseInfo('02140781-v', 0), SenseInfo('02104503-v', 0), SenseInfo('02054541-v', 0), SenseInfo('02054382-v', 0), SenseInfo('01607288-v', 0), SenseInfo('01478423-v', 0), SenseInfo('01423285-v', 0), SenseInfo('01291941-v', 0), SenseInfo('00352137-v', 0) ],
"_after_p_rel" : [ SenseInfo('00061203-r', 5), SenseInfo('00508070-r', 0), SenseInfo('01033542-a', 0), SenseInfo('00061203-r', 5), SenseInfo('00508070-r', 0), SenseInfo('01033542-a', 0), SenseInfo('00061203-r', 5), SenseInfo('00508070-r', 0), SenseInfo('01033542-a', 0) ],
"_capable_a_of_rel" : [ SenseInfo('00306314-a', 20), SenseInfo('02361540-a', 5), SenseInfo('00308015-a', 2), SenseInfo('00051373-a', 2), SenseInfo('00510348-a', 1) ],
"_adept_n_1_rel" : [ SenseInfo('09762509-n', 0) ],
"_reach_v_out_rel" : [ SenseInfo('02020590-v', 103), SenseInfo('02006834-v', 39), SenseInfo('01440139-v', 29), SenseInfo('00743344-v', 22), SenseInfo('02526085-v', 18), SenseInfo('02685665-v', 13), SenseInfo('02022162-v', 9), SenseInfo('02230772-v', 1), SenseInfo('01146051-v', 0) ],
"_attach_v_1_rel" : [ SenseInfo('01296462-v', 22), SenseInfo('01290255-v', 4), SenseInfo('01290422-v', 3), SenseInfo('02538086-v', 0), SenseInfo('02273293-v', 0), SenseInfo('01296462-v', 22), SenseInfo('01290255-v', 4), SenseInfo('01290422-v', 3), SenseInfo('02538086-v', 0), SenseInfo('02273293-v', 0) ],
"_province_n_1_rel" : [ SenseInfo('08654360-n', 4), SenseInfo('14515633-n', 1), SenseInfo('08654360-n', 4), SenseInfo('14515633-n', 1) ],
"_setting_n_of_rel" : [ SenseInfo('08568256-n', 7), SenseInfo('14513259-n', 2), SenseInfo('03773268-n', 1), SenseInfo('14512817-n', 0), SenseInfo('08623927-n', 0), SenseInfo('03953743-n', 0), SenseInfo('03792526-n', 0) ],
"_antenna_n_1_rel" : [ SenseInfo('02715229-n', 14), SenseInfo('04843270-n', 2), SenseInfo('02584915-n', 0) ],
"_pervade_v_1_rel" : [ SenseInfo('01229071-v', 3) ],
"_restoration_n_of_rel" : [ SenseInfo('15261868-n', 1), SenseInfo('00268557-n', 1), SenseInfo('00089351-n', 1), SenseInfo('14424517-n', 0), SenseInfo('04083468-n', 0), SenseInfo('04062989-n', 0), SenseInfo('01307606-n', 0) ],
"_compressible_a_1_rel" : [ SenseInfo('00514396-a', 0), SenseInfo('01153435-a', 0) ],
"_quite_x_rel" : [ SenseInfo('00018781-r', 57), SenseInfo('00018577-r', 47), SenseInfo('00018918-r', 6), SenseInfo('00019181-r', 0) ],
"_get_v_off_rel" : [ SenseInfo('02210855-v', 235), SenseInfo('00149583-v', 157), SenseInfo('00120796-v', 82), SenseInfo('00522751-v', 64), SenseInfo('02005948-v', 58), SenseInfo('01433294-v', 45), SenseInfo('02108026-v', 36), SenseInfo('01153947-v', 14), SenseInfo('02355596-v', 9), SenseInfo('00770437-v', 7), SenseInfo('01215421-v', 4), SenseInfo('00094460-v', 4), SenseInfo('00087736-v', 4), SenseInfo('01066036-v', 3), SenseInfo('00120316-v', 3), SenseInfo('01026975-v', 2), SenseInfo('00589904-v', 2), SenseInfo('01505958-v', 1), SenseInfo('01401115-v', 1), SenseInfo('00639849-v', 1), SenseInfo('02359340-v', 0), SenseInfo('02208265-v', 0), SenseInfo('02189398-v', 0), SenseInfo('02109645-v', 0), SenseInfo('02108654-v', 0), SenseInfo('02010864-v', 0), SenseInfo('02006573-v', 0), SenseInfo('01771194-v', 0), SenseInfo('01771039-v', 0), SenseInfo('01738107-v', 0), SenseInfo('01643297-v', 0), SenseInfo('01565211-v', 0), SenseInfo('00622384-v', 0), SenseInfo('00345761-v', 0), SenseInfo('00065639-v', 0), SenseInfo('00054628-v', 0) ],
"_deck_v_out_rel" : [ SenseInfo('02748927-v', 0), SenseInfo('01679980-v', 0), SenseInfo('01412346-v', 0) ],
"_junction_n_1_rel" : [ SenseInfo('03605722-n', 1), SenseInfo('14420954-n', 0), SenseInfo('13911151-n', 0), SenseInfo('03605915-n', 0), SenseInfo('00147454-n', 0) ],
"_spell_n_1_rel" : [ SenseInfo('14407536-n', 4), SenseInfo('15292069-n', 1), SenseInfo('15246353-n', 1), SenseInfo('07159791-n', 0) ],
"_footprint_n_1_rel" : [ SenseInfo('06645039-n', 1), SenseInfo('06646854-n', 0), SenseInfo('05129054-n', 0) ],
"_premonition_n_1_rel" : [ SenseInfo('07522128-n', 2), SenseInfo('07225450-n', 0) ],
"_rustle_v_1_rel" : [ SenseInfo('02182662-v', 7), SenseInfo('02277138-v', 3), SenseInfo('02270090-v', 0) ],
"_dampen_v_cause_rel" : [ SenseInfo('00390842-v', 3), SenseInfo('00217956-v', 2), SenseInfo('02191311-v', 0), SenseInfo('00391553-v', 0), SenseInfo('00390560-v', 0), SenseInfo('00390459-v', 0), SenseInfo('00390215-v', 0) ],
"_traditionally_x_deg_rel" : [ SenseInfo('00476807-r', 1) ],
"_con_n_1_rel" : [ SenseInfo('06649325-n', 1), SenseInfo('09962966-n', 0), SenseInfo('00779248-n', 0) ],
"_resign_v_1_rel" : [ SenseInfo('02367032-v', 9), SenseInfo('02382367-v', 0), SenseInfo('02316304-v', 0), SenseInfo('00732394-v', 0) ],
"_co-op_n_1_rel" : [ SenseInfo('01100877-n', 0), SenseInfo('01100877-n', 0) ],
"_population_n_1_rel" : [ SenseInfo('08179879-n', 27), SenseInfo('08178741-n', 4), SenseInfo('06026276-n', 3), SenseInfo('13779804-n', 1), SenseInfo('01257969-n', 0) ],
"_grotesque_a_1_rel" : [ SenseInfo('00221627-a', 4), SenseInfo('00967646-a', 3) ],
"_more_a_1_rel" : [ SenseInfo('01555133-a', 134), SenseInfo('01556355-a', 67), SenseInfo('01555133-a', 134), SenseInfo('01556355-a', 67) ],
"_recent_a_1_rel" : [ SenseInfo('01642477-a', 36), SenseInfo('01730444-a', 9), SenseInfo('01642477-a', 36), SenseInfo('01730444-a', 9), SenseInfo('01642477-a', 36), SenseInfo('01730444-a', 9), SenseInfo('01642477-a', 36), SenseInfo('01730444-a', 9), SenseInfo('01642477-a', 36), SenseInfo('01730444-a', 9) ],
"_aerobatics_n_1_rel" : [ SenseInfo('00302861-n', 0) ],
"_swing_v_up_rel" : [ SenseInfo('02087745-v', 35), SenseInfo('01877355-v', 15), SenseInfo('01877620-v', 6), SenseInfo('02537238-v', 4), SenseInfo('01593763-v', 4), SenseInfo('02717472-v', 2), SenseInfo('01152040-v', 2), SenseInfo('00557216-v', 2), SenseInfo('02615140-v', 1), SenseInfo('02752277-v', 0), SenseInfo('02389815-v', 0), SenseInfo('01725375-v', 0), SenseInfo('01427483-v', 0) ],
"_onrush_n_1_rel" : [ SenseInfo('00972621-n', 2), SenseInfo('07440617-n', 1) ],
"_presupposition_n_1_rel" : [ SenseInfo('05779923-n', 2), SenseInfo('05779923-n', 2) ],
"_downhill_a_1_rel" : [ SenseInfo('02485895-a', 1) ],
"_moran_n_1_rel" : [  ],
"_not+as+yet_a_1_rel" : [  ],
"_stimulate_v_1_rel" : [ SenseInfo('00503164-v', 6), SenseInfo('00770437-v', 5), SenseInfo('01761706-v', 3), SenseInfo('00022686-v', 3), SenseInfo('01644522-v', 2), SenseInfo('02116118-v', 1), SenseInfo('00794079-v', 0), SenseInfo('00503164-v', 6), SenseInfo('00770437-v', 5), SenseInfo('01761706-v', 3), SenseInfo('00022686-v', 3), SenseInfo('01644522-v', 2), SenseInfo('02116118-v', 1), SenseInfo('00794079-v', 0), SenseInfo('00503164-v', 6), SenseInfo('00770437-v', 5), SenseInfo('01761706-v', 3), SenseInfo('00022686-v', 3), SenseInfo('01644522-v', 2), SenseInfo('02116118-v', 1), SenseInfo('00794079-v', 0), SenseInfo('00503164-v', 6), SenseInfo('00770437-v', 5), SenseInfo('01761706-v', 3), SenseInfo('00022686-v', 3), SenseInfo('01644522-v', 2), SenseInfo('02116118-v', 1), SenseInfo('00794079-v', 0), SenseInfo('00503164-v', 6), SenseInfo('00770437-v', 5), SenseInfo('01761706-v', 3), SenseInfo('00022686-v', 3), SenseInfo('01644522-v', 2), SenseInfo('02116118-v', 1), SenseInfo('00794079-v', 0) ],
"_remembrance_n_1_rel" : [ SenseInfo('05761918-n', 3), SenseInfo('06688522-n', 0) ],
"_warranty_n_1_rel" : [ SenseInfo('06685456-n', 0) ],
"_fortify_v_1_rel" : [ SenseInfo('00220869-v', 4), SenseInfo('01606205-v', 0), SenseInfo('01087197-v', 0), SenseInfo('00222328-v', 0), SenseInfo('00222135-v', 0) ],
"_co-equal_a_to_rel" : [ SenseInfo('00890781-a', 0), SenseInfo('00890781-a', 0) ],
"_diffusion_n_of_rel" : [ SenseInfo('13465530-n', 6), SenseInfo('07331600-n', 1), SenseInfo('05088056-n', 1), SenseInfo('00368592-n', 0) ],
"_keep_v_1_rel" : [ SenseInfo('02681795-v', 206), SenseInfo('02684924-v', 39), SenseInfo('02202384-v', 32), SenseInfo('02450505-v', 22), SenseInfo('02578872-v', 10), SenseInfo('00732552-v', 9), SenseInfo('02202928-v', 8), SenseInfo('01065877-v', 4), SenseInfo('02651853-v', 3), SenseInfo('02410175-v', 3), SenseInfo('01184625-v', 3), SenseInfo('02734800-v', 2), SenseInfo('02578510-v', 2), SenseInfo('02422663-v', 2), SenseInfo('02733122-v', 1), SenseInfo('02652016-v', 0), SenseInfo('02283716-v', 0), SenseInfo('02204094-v', 0), SenseInfo('02203844-v', 0), SenseInfo('02203168-v', 0), SenseInfo('01302019-v', 0), SenseInfo('00212414-v', 0) ],
"_crunch_v_cause_rel" : [ SenseInfo('01058224-v', 1), SenseInfo('01594978-v', 0), SenseInfo('01201693-v', 0), SenseInfo('00331082-v', 0) ],
"_below_p_rel" : [ SenseInfo('00080039-r', 16), SenseInfo('00079866-r', 13), SenseInfo('00258282-r', 2), SenseInfo('00094396-r', 2), SenseInfo('00486067-r', 0), SenseInfo('00080039-r', 16), SenseInfo('00079866-r', 13), SenseInfo('00258282-r', 2), SenseInfo('00094396-r', 2), SenseInfo('00486067-r', 0), SenseInfo('00080039-r', 16), SenseInfo('00079866-r', 13), SenseInfo('00258282-r', 2), SenseInfo('00094396-r', 2), SenseInfo('00486067-r', 0) ],
"_rhythmic_a_1_rel" : [ SenseInfo('02019021-a', 3) ],
"_partisan_a_1_rel" : [ SenseInfo('00730731-a', 0) ],
"_shame_n_1_rel" : [ SenseInfo('07506569-n', 9), SenseInfo('14440137-n', 5), SenseInfo('07305098-n', 1), SenseInfo('07506569-n', 9), SenseInfo('14440137-n', 5), SenseInfo('07305098-n', 1) ],
"_manure_n_1_rel" : [ SenseInfo('14863521-n', 4) ],
"_fuse_v_cause_rel" : [ SenseInfo('00394813-v', 3), SenseInfo('00397192-v', 1), SenseInfo('01137829-v', 0), SenseInfo('00396997-v', 0) ],
"_corridor_n_1_rel" : [ SenseInfo('03112099-n', 9) ],
"_sheer_a_1_rel" : [ SenseInfo('00520892-a', 6), SenseInfo('01907103-a', 2), SenseInfo('01145422-a', 1), SenseInfo('02413390-a', 0), SenseInfo('00520892-a', 6), SenseInfo('01907103-a', 2), SenseInfo('01145422-a', 1), SenseInfo('02413390-a', 0), SenseInfo('00520892-a', 6), SenseInfo('01907103-a', 2), SenseInfo('01145422-a', 1), SenseInfo('02413390-a', 0) ],
"_inspection_n_of_rel" : [ SenseInfo('00879271-n', 1) ],
"_arianist_n_1_rel" : [ SenseInfo('09807609-n', 2) ],
"_carpenters_a_1_rel" : [  ],
"_question_v_about_rel" : [ SenseInfo('00867409-v', 17), SenseInfo('00788184-v', 14), SenseInfo('00785008-v', 5), SenseInfo('00808855-v', 3), SenseInfo('00925110-v', 2) ],
"_adolescent_a_1_rel" : [ SenseInfo('02602261-a', 1), SenseInfo('01647983-a', 0), SenseInfo('01492596-a', 0), SenseInfo('01490061-a', 0) ],
"_workman_n_1_rel" : [ SenseInfo('10791221-n', 3) ],
"_donut_n_1_rel" : [ SenseInfo('07639069-n', 0) ],
"_confession_n_of_rel" : [ SenseInfo('07216083-n', 4), SenseInfo('06472242-n', 1), SenseInfo('01039307-n', 1), SenseInfo('06727133-n', 0), SenseInfo('06472409-n', 0), SenseInfo('07216083-n', 4), SenseInfo('06472242-n', 1), SenseInfo('01039307-n', 1), SenseInfo('06727133-n', 0), SenseInfo('06472409-n', 0) ],
"_or_c_rel" : [  ],
"_dairying_n_1_rel" : [ SenseInfo('00918289-n', 0) ],
"_horoscope_n_1_rel" : [ SenseInfo('06749594-n', 1), SenseInfo('03537714-n', 0) ],
"_dilapidation_n_1_rel" : [ SenseInfo('14562541-n', 0), SenseInfo('13466312-n', 0) ],
"_aviation_n_1_rel" : [ SenseInfo('08433727-n', 1), SenseInfo('08067218-n', 0), SenseInfo('05635188-n', 0), SenseInfo('00300441-n', 0) ],
"_proliferate_v_cause_rel" : [ SenseInfo('00310635-v', 0), SenseInfo('00247830-v', 0) ],
"_innocence_n_1_rel" : [ SenseInfo('04880830-n', 5), SenseInfo('13990064-n', 0), SenseInfo('13989627-n', 0) ],
"_mechanical_a_1_rel" : [ SenseInfo('01499686-a', 10), SenseInfo('02891236-a', 2), SenseInfo('02890983-a', 1), SenseInfo('01499686-a', 10), SenseInfo('02891236-a', 2), SenseInfo('02890983-a', 1) ],
"_parade_v_1_rel" : [ SenseInfo('01924712-v', 2), SenseInfo('01924505-v', 1) ],
"_venezuelan_a_1_rel" : [ SenseInfo('02966656-a', 0) ],
"_highbrow_a_1_rel" : [ SenseInfo('01332907-a', 0) ],
"_identify_v_1_rel" : [ SenseInfo('00618878-v', 32), SenseInfo('01026095-v', 7), SenseInfo('00691944-v', 6), SenseInfo('00714531-v', 4), SenseInfo('00652346-v', 2), SenseInfo('00618451-v', 2), SenseInfo('00618878-v', 32), SenseInfo('01026095-v', 7), SenseInfo('00691944-v', 6), SenseInfo('00714531-v', 4), SenseInfo('00652346-v', 2), SenseInfo('00618451-v', 2) ],
"_free_a_of_rel" : [ SenseInfo('01061489-a', 38), SenseInfo('01058363-a', 4), SenseInfo('01710260-a', 3), SenseInfo('01624010-a', 3), SenseInfo('01060947-a', 1), SenseInfo('01065694-a', 0), SenseInfo('01624115-a', 0), SenseInfo('00927978-a', 0), SenseInfo('00916199-a', 0), SenseInfo('01061489-a', 38), SenseInfo('01058363-a', 4), SenseInfo('01710260-a', 3), SenseInfo('01624010-a', 3), SenseInfo('01060947-a', 1), SenseInfo('01065694-a', 0), SenseInfo('01624115-a', 0), SenseInfo('00927978-a', 0), SenseInfo('00916199-a', 0) ],
"_courtroom_n_1_rel" : [ SenseInfo('03120778-n', 0) ],
"_drawer_n_of_rel" : [ SenseInfo('03233905-n', 5), SenseInfo('10032524-n', 0), SenseInfo('10029068-n', 0) ],
"_modifier_n_1_rel" : [ SenseInfo('06320801-n', 5), SenseInfo('10326776-n', 0), SenseInfo('09609871-n', 0), SenseInfo('05439286-n', 0) ],
"_year_n_1_rel" : [ SenseInfo('15203791-n', 426), SenseInfo('15204297-n', 18), SenseInfo('15201505-n', 5), SenseInfo('08238660-n', 1), SenseInfo('15203791-n', 426), SenseInfo('15204297-n', 18), SenseInfo('15201505-n', 5), SenseInfo('08238660-n', 1), SenseInfo('15203791-n', 426), SenseInfo('15204297-n', 18), SenseInfo('15201505-n', 5), SenseInfo('08238660-n', 1), SenseInfo('15203791-n', 426), SenseInfo('15204297-n', 18), SenseInfo('15201505-n', 5), SenseInfo('08238660-n', 1) ],
"_hundredth_n_of_rel" : [ SenseInfo('13849710-n', 0), SenseInfo('13739051-n', 0) ],
"_rachis_n_1_rel" : [ SenseInfo('13128976-n', 0), SenseInfo('05588174-n', 0) ],
"_poodle_n_1_rel" : [ SenseInfo('02113335-n', 0) ],
"_propitious_a_1_rel" : [ SenseInfo('00177186-a', 1) ],
"_boulder_n_1_rel" : [ SenseInfo('09227839-n', 1), SenseInfo('09067721-n', 0) ],
"_off-camera_a_1_rel" : [  ],
"_juvenile_n_1_rel" : [ SenseInfo('09622049-n', 0) ],
"_attack_v_1_rel" : [ SenseInfo('01119169-v', 22), SenseInfo('00862683-v', 9), SenseInfo('01118449-v', 8), SenseInfo('01120069-v', 4), SenseInfo('00347610-v', 1), SenseInfo('00019792-v', 0) ],
"_beget_v_1_rel" : [ SenseInfo('00054628-v', 2) ],
"_fledge_v_1_rel" : [ SenseInfo('02540151-v', 0), SenseInfo('01669792-v', 0), SenseInfo('00094312-v', 0) ],
"_forceful_a_1_rel" : [ SenseInfo('00841403-a', 2), SenseInfo('00156575-a', 0), SenseInfo('00841403-a', 2), SenseInfo('00156575-a', 0) ],
"_top+dollar_n_1_rel" : [  ],
"_moonlit_a_1_rel" : [ SenseInfo('00278006-a', 1) ],
"_recount_v_to_rel" : [ SenseInfo('00953216-v', 10), SenseInfo('00801355-v', 0), SenseInfo('00953216-v', 10), SenseInfo('00801355-v', 0) ],
"_checkers_n_1_rel" : [ SenseInfo('09913110-n', 0), SenseInfo('09912995-n', 0), SenseInfo('03011355-n', 0) ],
"_walkie+talkie_n_1_rel" : [ SenseInfo('04545858-n', 0), SenseInfo('04545858-n', 0) ],
"_whalebone_n_1_rel" : [ SenseInfo('14758252-n', 0) ],
"_siamese_a_1_rel" : [ SenseInfo('03117012-a', 0), SenseInfo('03116809-a', 0), SenseInfo('03116651-a', 0) ],
"_finagle_v_1_rel" : [ SenseInfo('02527431-v', 0) ],
"_surmount_v_1_rel" : [ SenseInfo('01108627-v', 2), SenseInfo('02694548-v', 1), SenseInfo('01999082-v', 0), SenseInfo('01105639-v', 0) ],
"_picket_v_1_rel" : [ SenseInfo('02522153-v', 1), SenseInfo('01289026-v', 1) ],
"_communique_n_1_rel" : [ SenseInfo('06682794-n', 1) ],
"_hoe_v_1_rel" : [ SenseInfo('01742556-v', 0) ],
"_demean_v_1_rel" : [ SenseInfo('01800422-v', 1), SenseInfo('01800422-v', 1), SenseInfo('01800422-v', 1), SenseInfo('01800422-v', 1), SenseInfo('01800422-v', 1) ],
"_impress_v_1_rel" : [ SenseInfo('01767949-v', 9), SenseInfo('01769902-v', 8), SenseInfo('00728393-v', 5), SenseInfo('01531742-v', 1), SenseInfo('01747945-v', 0), SenseInfo('01471547-v', 0), SenseInfo('00283805-v', 0), SenseInfo('01767949-v', 9), SenseInfo('01769902-v', 8), SenseInfo('00728393-v', 5), SenseInfo('01531742-v', 1), SenseInfo('01747945-v', 0), SenseInfo('01471547-v', 0), SenseInfo('00283805-v', 0), SenseInfo('01767949-v', 9), SenseInfo('01769902-v', 8), SenseInfo('00728393-v', 5), SenseInfo('01531742-v', 1), SenseInfo('01747945-v', 0), SenseInfo('01471547-v', 0), SenseInfo('00283805-v', 0) ],
"_unsurpassed_a_1_rel" : [ SenseInfo('00229371-a', 0), SenseInfo('00229371-a', 0) ],
"_chant_n_1_rel" : [ SenseInfo('07034634-n', 0), SenseInfo('07034634-n', 0) ],
"_revolve_v_1_rel" : [ SenseInfo('02045043-v', 1), SenseInfo('02043982-v', 1), SenseInfo('01866610-v', 0) ],
"_filter_v_1_rel" : [ SenseInfo('01458664-v', 10), SenseInfo('01457954-v', 3), SenseInfo('02070874-v', 0) ],
"_drop_v_1_rel" : [ SenseInfo('01977701-v', 36), SenseInfo('01976841-v', 21), SenseInfo('00432683-v', 12), SenseInfo('01985923-v', 7), SenseInfo('02403920-v', 6), SenseInfo('00941446-v', 6), SenseInfo('00363110-v', 5), SenseInfo('01489465-v', 3), SenseInfo('01258302-v', 2), SenseInfo('01100008-v', 2), SenseInfo('02267060-v', 1), SenseInfo('00393534-v', 1), SenseInfo('02717472-v', 0), SenseInfo('02465939-v', 0), SenseInfo('01611516-v', 0), SenseInfo('01513430-v', 0), SenseInfo('01200661-v', 0), SenseInfo('00615615-v', 0), SenseInfo('00614999-v', 0), SenseInfo('00548616-v', 0), SenseInfo('00148341-v', 0), SenseInfo('00092293-v', 0), SenseInfo('00057764-v', 0) ],
"_okra_n_1_rel" : [ SenseInfo('12172364-n', 0), SenseInfo('12171966-n', 0), SenseInfo('07733394-n', 0) ],
"_assignment_n_of_rel" : [ SenseInfo('00730247-n', 7), SenseInfo('06545528-n', 3), SenseInfo('00164345-n', 2), SenseInfo('13254237-n', 0), SenseInfo('00796586-n', 0), SenseInfo('00163779-n', 0) ],
"_mistletoe_n_1_rel" : [ SenseInfo('12739801-n', 0), SenseInfo('12739332-n', 0), SenseInfo('12737898-n', 0) ],
"_count_v_on_rel" : [ SenseInfo('00948071-v', 23), SenseInfo('02645839-v', 7), SenseInfo('00950431-v', 4), SenseInfo('00947857-v', 3), SenseInfo('02731632-v', 2), SenseInfo('00685081-v', 2), SenseInfo('02747140-v', 0), SenseInfo('00712708-v', 0), SenseInfo('00712556-v', 0) ],
"_higher-up_n_1_rel" : [ SenseInfo('10676018-n', 0) ],
"_duplication_n_of_rel" : [ SenseInfo('03257343-n', 1), SenseInfo('01019703-n', 1) ],
"_note_n_1_rel" : [ SenseInfo('06504462-n', 14), SenseInfo('06626286-n', 13), SenseInfo('06865345-n', 4), SenseInfo('07082819-n', 3), SenseInfo('04727694-n', 2), SenseInfo('13393762-n', 1), SenseInfo('06763273-n', 1), SenseInfo('14435445-n', 0), SenseInfo('13398469-n', 0), SenseInfo('06504462-n', 14), SenseInfo('06626286-n', 13), SenseInfo('06865345-n', 4), SenseInfo('07082819-n', 3), SenseInfo('04727694-n', 2), SenseInfo('13393762-n', 1), SenseInfo('06763273-n', 1), SenseInfo('14435445-n', 0), SenseInfo('13398469-n', 0) ],
"_counter+narcotics_n_1_rel" : [  ],
"_each_q_rel" : [  ],
"_indistinct_a_1_rel" : [ SenseInfo('00781168-a', 1) ],
"_human_a_1_rel" : [ SenseInfo('02743261-a', 46), SenseInfo('02743391-a', 19), SenseInfo('01258617-a', 15) ],
"_sheet_n_of_rel" : [ SenseInfo('09432060-n', 12), SenseInfo('06255777-n', 11), SenseInfo('04188179-n', 3), SenseInfo('13861050-n', 0), SenseInfo('06267893-n', 0), SenseInfo('04188643-n', 0), SenseInfo('04188368-n', 0), SenseInfo('04127904-n', 0) ],
"_blatant_a_1_rel" : [ SenseInfo('02090567-a', 2), SenseInfo('01920367-a', 2) ],
"_poem_n_1_rel" : [ SenseInfo('06377442-n', 14) ],
"_dodge_n_1_rel" : [ SenseInfo('05905802-n', 1), SenseInfo('00059895-n', 1), SenseInfo('06756680-n', 0) ],
"_observable_n_1_rel" : [ SenseInfo('01287486-a', 1) ],
"_decrease_v_1_rel" : [ SenseInfo('00151689-v', 13), SenseInfo('00441445-v', 3) ],
"_overreach_v_1_rel" : [ SenseInfo('02525868-v', 3), SenseInfo('01104852-v', 1), SenseInfo('02525868-v', 3), SenseInfo('01104852-v', 1) ],
"_piglet_n_1_rel" : [ SenseInfo('02395694-n', 0) ],
"_empty_v_of_rel" : [ SenseInfo('00449692-v', 4), SenseInfo('00448680-v', 3), SenseInfo('02076676-v', 2), SenseInfo('01488313-v', 1), SenseInfo('00073343-v', 0), SenseInfo('00449692-v', 4), SenseInfo('00448680-v', 3), SenseInfo('02076676-v', 2), SenseInfo('01488313-v', 1), SenseInfo('00073343-v', 0), SenseInfo('00449692-v', 4), SenseInfo('00448680-v', 3), SenseInfo('02076676-v', 2), SenseInfo('01488313-v', 1), SenseInfo('00073343-v', 0), SenseInfo('00449692-v', 4), SenseInfo('00448680-v', 3), SenseInfo('02076676-v', 2), SenseInfo('01488313-v', 1), SenseInfo('00073343-v', 0) ],
"_object_n_1_rel" : [ SenseInfo('00002684-n', 51), SenseInfo('05981230-n', 3), SenseInfo('06310237-n', 2), SenseInfo('05810948-n', 1), SenseInfo('06132724-n', 0) ],
"_co_n_1_rel" : [ SenseInfo('14797641-n', 0), SenseInfo('14635290-n', 0), SenseInfo('09957013-n', 0), SenseInfo('09067277-n', 0), SenseInfo('14797641-n', 0), SenseInfo('14635290-n', 0), SenseInfo('09957013-n', 0), SenseInfo('09067277-n', 0) ],
"_define_v_as_rel" : [ SenseInfo('02611630-v', 20), SenseInfo('00957378-v', 13), SenseInfo('02698319-v', 9), SenseInfo('02736778-v', 2), SenseInfo('00947077-v', 0), SenseInfo('02611630-v', 20), SenseInfo('00957378-v', 13), SenseInfo('02698319-v', 9), SenseInfo('02736778-v', 2), SenseInfo('00947077-v', 0) ],
"_vulnerability_n_1_rel" : [ SenseInfo('14543931-n', 3), SenseInfo('05042871-n', 0) ],
"_latch_v_onto_rel" : [ SenseInfo('01286777-v', 2) ],
"_spar_n_1_rel" : [ SenseInfo('15049096-n', 0), SenseInfo('04267577-n', 0), SenseInfo('00446804-n', 0) ],
"_off-license_n_1_rel" : [  ],
"_fit_v_1_rel" : [ SenseInfo('02702830-v', 14), SenseInfo('02659763-v', 11), SenseInfo('02667900-v', 9), SenseInfo('00300537-v', 7), SenseInfo('00300113-v', 5), SenseInfo('02657219-v', 4), SenseInfo('02735753-v', 1), SenseInfo('02339413-v', 1), SenseInfo('00456740-v', 0), SenseInfo('02702830-v', 14), SenseInfo('02659763-v', 11), SenseInfo('02667900-v', 9), SenseInfo('00300537-v', 7), SenseInfo('00300113-v', 5), SenseInfo('02657219-v', 4), SenseInfo('02735753-v', 1), SenseInfo('02339413-v', 1), SenseInfo('00456740-v', 0) ],
"_joke_n_1_rel" : [ SenseInfo('06778102-n', 10), SenseInfo('00431005-n', 1), SenseInfo('00427580-n', 1), SenseInfo('05173443-n', 0), SenseInfo('06778102-n', 10), SenseInfo('00431005-n', 1), SenseInfo('00427580-n', 1), SenseInfo('05173443-n', 0) ],
"_helpful_a_1_rel" : [ SenseInfo('01195536-a', 9), SenseInfo('01195536-a', 9) ],
"_gin_v_1_rel" : [ SenseInfo('01557517-v', 0), SenseInfo('01481027-v', 0) ],
"_gripe_v_1_rel" : [ SenseInfo('00910973-v', 0), SenseInfo('00910973-v', 0) ],
"_seal_v_in_rel" : [ SenseInfo('01354006-v', 3), SenseInfo('01353405-v', 3), SenseInfo('00698732-v', 2), SenseInfo('01356582-v', 0), SenseInfo('01269008-v', 0), SenseInfo('01143498-v', 0) ],
"_norse_n_1_rel" : [ SenseInfo('09730204-n', 0), SenseInfo('09725402-n', 0), SenseInfo('06953731-n', 0), SenseInfo('09730204-n', 0), SenseInfo('09725402-n', 0), SenseInfo('06953731-n', 0) ],
"_unshaved_a_1_rel" : [ SenseInfo('02153817-a', 1), SenseInfo('02153817-a', 1) ],
"_aimless_a_1_rel" : [ SenseInfo('01910652-a', 3), SenseInfo('02127159-a', 0) ],
"_townsman_n_1_rel" : [ SenseInfo('10719692-n', 1), SenseInfo('10719267-n', 0) ],
"_afternoon_n_of_rel" : [ SenseInfo('15166191-n', 51), SenseInfo('06632807-n', 1), SenseInfo('15166191-n', 51), SenseInfo('06632807-n', 1), SenseInfo('15166191-n', 51), SenseInfo('06632807-n', 1), SenseInfo('15166191-n', 51), SenseInfo('06632807-n', 1), SenseInfo('15166191-n', 51), SenseInfo('06632807-n', 1) ],
"_passive_n_1_rel" : [ SenseInfo('13803431-n', 0) ],
"_ballast_v_1_rel" : [ SenseInfo('00271403-v', 0) ],
"_overshoe_n_1_rel" : [ SenseInfo('03865949-n', 1) ],
"_recorder_n_of_rel" : [ SenseInfo('04063373-n', 2), SenseInfo('10516874-n', 0), SenseInfo('10511960-n', 0), SenseInfo('03343354-n', 0) ],
"_pirate_v_1_rel" : [ SenseInfo('02277897-v', 0), SenseInfo('01471825-v', 0) ],
"_testament_n_1_rel" : [ SenseInfo('05800272-n', 2), SenseInfo('06544142-n', 1), SenseInfo('06648590-n', 0), SenseInfo('06453723-n', 0) ],
"_rat_v_1_rel" : [ SenseInfo('02584475-v', 0), SenseInfo('02413140-v', 0), SenseInfo('02412939-v', 0), SenseInfo('01527135-v', 0), SenseInfo('01480641-v', 0), SenseInfo('00841986-v', 0) ],
"_mark_n_of_rel" : [ SenseInfo('05737153-n', 5), SenseInfo('07270179-n', 4), SenseInfo('07262108-n', 3), SenseInfo('06798750-n', 2), SenseInfo('04676064-n', 2), SenseInfo('06794666-n', 1), SenseInfo('13688033-n', 0), SenseInfo('11156943-n', 0), SenseInfo('09921409-n', 0), SenseInfo('06817782-n', 0), SenseInfo('06646243-n', 0), SenseInfo('06441803-n', 0), SenseInfo('04693900-n', 0), SenseInfo('04681387-n', 0), SenseInfo('00064789-n', 0) ],
"_side-step_n_1_rel" : [ SenseInfo('00286360-n', 0), SenseInfo('00286360-n', 0), SenseInfo('00286360-n', 0) ],
"_imperative_n_1_rel" : [ SenseInfo('13802306-n', 0), SenseInfo('01131330-n', 0) ],
"_plover_n_1_rel" : [ SenseInfo('02023341-n', 0) ],
"_fuel_n_1_rel" : [ SenseInfo('14875077-n', 5) ],
"_own_v_1_rel" : [ SenseInfo('02204692-v', 47) ],
"_author_v_1_rel" : [ SenseInfo('01704452-v', 0) ],
"_dry_v_1_rel" : [ SenseInfo('00218475-v', 12), SenseInfo('00219403-v', 11) ],
"_until_x_h_rel" : [  ],
"_shoe_n_1_rel" : [ SenseInfo('04199027-n', 27), SenseInfo('04200000-n', 0), SenseInfo('03539433-n', 0), SenseInfo('02890940-n', 0) ],
"_sandwich_v_1_rel" : [ SenseInfo('01665081-v', 0), SenseInfo('01529906-v', 0) ],
"_meet_v_1_rel" : [ SenseInfo('02023107-v', 49), SenseInfo('02486932-v', 38), SenseInfo('02710402-v', 32), SenseInfo('01183573-v', 23), SenseInfo('02667900-v', 18), SenseInfo('02594674-v', 15), SenseInfo('02428924-v', 14), SenseInfo('02596113-v', 12), SenseInfo('02022804-v', 11), SenseInfo('01079480-v', 8), SenseInfo('02739480-v', 7), SenseInfo('02110082-v', 3), SenseInfo('01205696-v', 1) ],
"_maddening_a_1_rel" : [ SenseInfo('01809245-a', 2) ],
"_post+meeting_a_1_rel" : [  ],
"_shepherd_n_1_rel" : [ SenseInfo('10588965-n', 1), SenseInfo('10587605-n', 1) ],
"_assertion_n_of_rel" : [ SenseInfo('06729499-n', 2), SenseInfo('07203126-n', 1), SenseInfo('06729499-n', 2), SenseInfo('07203126-n', 1), SenseInfo('06729499-n', 2), SenseInfo('07203126-n', 1) ],
"_log_v_off_rel" : [ SenseInfo('01002481-v', 2), SenseInfo('01258828-v', 1), SenseInfo('01002481-v', 2), SenseInfo('01258828-v', 1) ],
"_capricious_a_1_rel" : [ SenseInfo('01842304-a', 0), SenseInfo('00719442-a', 0) ],
"_registrar_n_1_rel" : [ SenseInfo('10517137-n', 0), SenseInfo('10517032-n', 0), SenseInfo('10516874-n', 0) ],
"_use_v_up_rel" : [ SenseInfo('01158872-v', 603), SenseInfo('01165043-v', 12), SenseInfo('01158572-v', 8), SenseInfo('02600490-v', 0), SenseInfo('02561332-v', 0), SenseInfo('02370131-v', 0) ],
"_remainder_n_of_rel" : [ SenseInfo('13810818-n', 8), SenseInfo('13733663-n', 0), SenseInfo('13729236-n', 0), SenseInfo('03286383-n', 0), SenseInfo('13810818-n', 8), SenseInfo('13733663-n', 0), SenseInfo('13729236-n', 0), SenseInfo('03286383-n', 0) ],
"_term_n_of_rel" : [ SenseInfo('06303888-n', 37), SenseInfo('15224486-n', 8), SenseInfo('06770875-n', 6), SenseInfo('05855904-n', 3), SenseInfo('06751974-n', 1), SenseInfo('15226451-n', 0), SenseInfo('04413723-n', 0), SenseInfo('06303888-n', 37), SenseInfo('15224486-n', 8), SenseInfo('06770875-n', 6), SenseInfo('05855904-n', 3), SenseInfo('06751974-n', 1), SenseInfo('15226451-n', 0), SenseInfo('04413723-n', 0), SenseInfo('06303888-n', 37), SenseInfo('15224486-n', 8), SenseInfo('06770875-n', 6), SenseInfo('05855904-n', 3), SenseInfo('06751974-n', 1), SenseInfo('15226451-n', 0), SenseInfo('04413723-n', 0), SenseInfo('06303888-n', 37), SenseInfo('15224486-n', 8), SenseInfo('06770875-n', 6), SenseInfo('05855904-n', 3), SenseInfo('06751974-n', 1), SenseInfo('15226451-n', 0), SenseInfo('04413723-n', 0), SenseInfo('06303888-n', 37), SenseInfo('15224486-n', 8), SenseInfo('06770875-n', 6), SenseInfo('05855904-n', 3), SenseInfo('06751974-n', 1), SenseInfo('15226451-n', 0), SenseInfo('04413723-n', 0), SenseInfo('06303888-n', 37), SenseInfo('15224486-n', 8), SenseInfo('06770875-n', 6), SenseInfo('05855904-n', 3), SenseInfo('06751974-n', 1), SenseInfo('15226451-n', 0), SenseInfo('04413723-n', 0), SenseInfo('06303888-n', 37), SenseInfo('15224486-n', 8), SenseInfo('06770875-n', 6), SenseInfo('05855904-n', 3), SenseInfo('06751974-n', 1), SenseInfo('15226451-n', 0), SenseInfo('04413723-n', 0) ],
"_cram_v_in_rel" : [ SenseInfo('01524298-v', 1), SenseInfo('01612295-v', 0), SenseInfo('00605783-v', 0), SenseInfo('00407146-v', 0) ],
"_reform_n_1_rel" : [ SenseInfo('00260622-n', 3), SenseInfo('00800940-n', 1), SenseInfo('00261405-n', 0) ],
"_pattern_n_1_rel" : [ SenseInfo('05930736-n', 28), SenseInfo('00410247-n', 22), SenseInfo('03178782-n', 9), SenseInfo('05667613-n', 8), SenseInfo('05938795-n', 1), SenseInfo('05902327-n', 1), SenseInfo('08492747-n', 0), SenseInfo('07005270-n', 0) ],
"_whooping+cough_n_1_rel" : [ SenseInfo('14144626-n', 0) ],
"_slope_n_1_rel" : [ SenseInfo('09437454-n', 11), SenseInfo('05068461-n', 4) ],
"_carbonic_a_1_rel" : [ SenseInfo('02863724-a', 0) ],
"_tangle_n_1_rel" : [ SenseInfo('09454412-n', 2), SenseInfo('05685879-n', 1) ],
"_block_v_off_rel" : [ SenseInfo('01478002-v', 7), SenseInfo('02557199-v', 3), SenseInfo('02559752-v', 1), SenseInfo('01057034-v', 1), SenseInfo('02444297-v', 0), SenseInfo('02198423-v', 0), SenseInfo('02145543-v', 0), SenseInfo('01531492-v', 0), SenseInfo('01479333-v', 0), SenseInfo('01476483-v', 0), SenseInfo('01217924-v', 0), SenseInfo('01147060-v', 0), SenseInfo('00609100-v', 0), SenseInfo('00477528-v', 0), SenseInfo('00477382-v', 0), SenseInfo('00269423-v', 0) ],
"_wedge_v_in_rel" : [ SenseInfo('01528069-v', 1), SenseInfo('01527271-v', 0) ],
"_british_a_1_rel" : [ SenseInfo('03022177-a', 11), SenseInfo('03022177-a', 11), SenseInfo('03022177-a', 11) ],
"_wear_v_away_rel" : [ SenseInfo('00052374-v', 83), SenseInfo('00047745-v', 22), SenseInfo('02740034-v', 6), SenseInfo('00469382-v', 2), SenseInfo('00047610-v', 2), SenseInfo('02705132-v', 1), SenseInfo('01369346-v', 0), SenseInfo('00075021-v', 0), SenseInfo('00050652-v', 0), SenseInfo('00052374-v', 83), SenseInfo('00047745-v', 22), SenseInfo('02740034-v', 6), SenseInfo('00469382-v', 2), SenseInfo('00047610-v', 2), SenseInfo('02705132-v', 1), SenseInfo('01369346-v', 0), SenseInfo('00075021-v', 0), SenseInfo('00050652-v', 0) ],
"_intention_n_1_rel" : [ SenseInfo('05982152-n', 12), SenseInfo('05982720-n', 1), SenseInfo('00163233-n', 0), SenseInfo('05982152-n', 12), SenseInfo('05982720-n', 1), SenseInfo('00163233-n', 0) ],
"_value-add_v_1_rel" : [  ],
"_assistance_n_1_rel" : [ SenseInfo('01207609-n', 28), SenseInfo('05154908-n', 3) ],
"_spirited_a_1_rel" : [ SenseInfo('02278939-a', 3), SenseInfo('00805309-a', 0), SenseInfo('00263994-a', 0), SenseInfo('00118844-a', 0) ],
"_frown_v_on-upon_rel" : [ SenseInfo('00032981-v', 12), SenseInfo('00032981-v', 12) ],
"_offpeak_a_1_rel" : [  ],
"_adjective_n_1_rel" : [ SenseInfo('06321702-n', 3), SenseInfo('06319029-n', 2), SenseInfo('06321702-n', 3), SenseInfo('06319029-n', 2), SenseInfo('06321702-n', 3), SenseInfo('06319029-n', 2) ],
"_diminutive_a_1_rel" : [ SenseInfo('01392249-a', 2) ],
"_effect_n_1_rel" : [ SenseInfo('11410625-n', 101), SenseInfo('04675314-n', 11), SenseInfo('05917477-n', 9), SenseInfo('06604066-n', 2), SenseInfo('04809642-n', 1), SenseInfo('14311348-n', 0), SenseInfo('11410625-n', 101), SenseInfo('04675314-n', 11), SenseInfo('05917477-n', 9), SenseInfo('06604066-n', 2), SenseInfo('04809642-n', 1), SenseInfo('14311348-n', 0) ],
"_ancestral_a_1_rel" : [ SenseInfo('01314197-a', 5), SenseInfo('02604913-a', 0) ],
"_penguin_n_1_rel" : [ SenseInfo('02055803-n', 0) ],
"_taunt_n_1_rel" : [ SenseInfo('01222859-n', 3) ],
"_larva_n_1_rel" : [ SenseInfo('02311060-n', 6) ],
"_by-product_n_1_rel" : [ SenseInfo('11412592-n', 4), SenseInfo('02930492-n', 2), SenseInfo('11412592-n', 4), SenseInfo('02930492-n', 2) ],
"_rare_v_1_rel" : [  ],
"_wildcat_n_1_rel" : [ SenseInfo('04584639-n', 2), SenseInfo('09845589-n', 1), SenseInfo('02124623-n', 1) ],
"_lemming_n_1_rel" : [ SenseInfo('02344528-n', 0), SenseInfo('02344528-n', 0) ],
"_come_v_out_rel" : [ SenseInfo('01849221-v', 276), SenseInfo('02005948-v', 235), SenseInfo('00341917-v', 147), SenseInfo('00542120-v', 41), SenseInfo('02625339-v', 40), SenseInfo('00342812-v', 11), SenseInfo('02743921-v', 9), SenseInfo('02743214-v', 7), SenseInfo('02686805-v', 6), SenseInfo('02743565-v', 3), SenseInfo('01839690-v', 3), SenseInfo('02729963-v', 2), SenseInfo('00344886-v', 2), SenseInfo('02645007-v', 1), SenseInfo('02627363-v', 1), SenseInfo('02006709-v', 1), SenseInfo('00723349-v', 1), SenseInfo('02737187-v', 0), SenseInfo('02617567-v', 0), SenseInfo('02197360-v', 0), SenseInfo('00659984-v', 0), SenseInfo('01849221-v', 276), SenseInfo('02005948-v', 235), SenseInfo('00341917-v', 147), SenseInfo('00542120-v', 41), SenseInfo('02625339-v', 40), SenseInfo('00342812-v', 11), SenseInfo('02743921-v', 9), SenseInfo('02743214-v', 7), SenseInfo('02686805-v', 6), SenseInfo('02743565-v', 3), SenseInfo('01839690-v', 3), SenseInfo('02729963-v', 2), SenseInfo('00344886-v', 2), SenseInfo('02645007-v', 1), SenseInfo('02627363-v', 1), SenseInfo('02006709-v', 1), SenseInfo('00723349-v', 1), SenseInfo('02737187-v', 0), SenseInfo('02617567-v', 0), SenseInfo('02197360-v', 0), SenseInfo('00659984-v', 0) ],
"_clap_v_in_rel" : [ SenseInfo('01607590-v', 2), SenseInfo('02094299-v', 1), SenseInfo('00861929-v', 1), SenseInfo('00034115-v', 1), SenseInfo('02094172-v', 0), SenseInfo('01237599-v', 0), SenseInfo('01237398-v', 0) ],
"_resultant_a_1_rel" : [ SenseInfo('00122844-a', 5) ],
"_strap_v_1_rel" : [ SenseInfo('01289492-v', 1), SenseInfo('01411085-v', 0), SenseInfo('00392860-v', 0), SenseInfo('00083523-v', 0), SenseInfo('01289492-v', 1), SenseInfo('01411085-v', 0), SenseInfo('00392860-v', 0), SenseInfo('00083523-v', 0) ],
"_scene_n_of_rel" : [ SenseInfo('08645963-n', 18), SenseInfo('07360841-n', 17), SenseInfo('05933246-n', 13), SenseInfo('06614729-n', 8), SenseInfo('13937075-n', 7), SenseInfo('07009808-n', 7), SenseInfo('14406303-n', 1), SenseInfo('04144782-n', 1), SenseInfo('08568256-n', 0), SenseInfo('04145056-n', 0) ],
"_seedling_n_1_rel" : [ SenseInfo('11552594-n', 1) ],
"_traveler_n_1_rel" : [ SenseInfo('09629752-n', 3) ],
"_complementary_a_1_rel" : [ SenseInfo('02381963-a', 0), SenseInfo('00049016-a', 0) ],
"_recapitulate_v_1_rel" : [ SenseInfo('01008903-v', 1), SenseInfo('01735144-v', 0), SenseInfo('01727490-v', 0) ],
"_glow_v_1_rel" : [ SenseInfo('02160944-v', 5), SenseInfo('02161530-v', 4), SenseInfo('02768874-v', 2), SenseInfo('01830042-v', 1), SenseInfo('01829747-v', 0), SenseInfo('02160944-v', 5), SenseInfo('02161530-v', 4), SenseInfo('02768874-v', 2), SenseInfo('01830042-v', 1), SenseInfo('01829747-v', 0) ],
"_sour_v_1_rel" : [ SenseInfo('00458471-v', 2), SenseInfo('02196690-v', 1) ],
"_abort_n_1_rel" : [ SenseInfo('00034939-n', 0) ],
"_wham_a_1_rel" : [  ],
"_windgear_n_1_rel" : [  ],
"_mute_n_1_rel" : [ SenseInfo('10342367-n', 0), SenseInfo('03802973-n', 0) ],
"_man_v_1_rel" : [ SenseInfo('02420991-v', 2), SenseInfo('01088547-v', 0) ],
"_unremoved_a_1_rel" : [  ],
"_wayfarer_n_1_rel" : [ SenseInfo('10771539-n', 0), SenseInfo('10771392-n', 0) ],
"_upsurge_n_1_rel" : [ SenseInfo('07440240-n', 0), SenseInfo('00364787-n', 0) ],
"_trachea_n_1_rel" : [ SenseInfo('05531814-n', 2), SenseInfo('05532050-n', 0) ],
"_second+person_n_1_rel" : [ SenseInfo('06327870-n', 0), SenseInfo('06327870-n', 0) ],
"_sour_a_1_rel" : [ SenseInfo('01054922-a', 1), SenseInfo('02368787-a', 0), SenseInfo('02399014-a', 0), SenseInfo('02369869-a', 0), SenseInfo('01164420-a', 0), SenseInfo('01137378-a', 0), SenseInfo('01054922-a', 1), SenseInfo('02368787-a', 0), SenseInfo('02399014-a', 0), SenseInfo('02369869-a', 0), SenseInfo('01164420-a', 0), SenseInfo('01137378-a', 0), SenseInfo('01054922-a', 1), SenseInfo('02368787-a', 0), SenseInfo('02399014-a', 0), SenseInfo('02369869-a', 0), SenseInfo('01164420-a', 0), SenseInfo('01137378-a', 0), SenseInfo('01054922-a', 1), SenseInfo('02368787-a', 0), SenseInfo('02399014-a', 0), SenseInfo('02369869-a', 0), SenseInfo('01164420-a', 0), SenseInfo('01137378-a', 0) ],
"_splurge_v_1_rel" : [ SenseInfo('02269003-v', 0), SenseInfo('02142413-v', 0) ],
"_think_v_amt-of_rel" : [ SenseInfo('00689344-v', 274), SenseInfo('00631737-v', 188), SenseInfo('00628491-v', 111), SenseInfo('00607780-v', 8), SenseInfo('01637166-v', 4), SenseInfo('00723056-v', 3), SenseInfo('00708538-v', 2), SenseInfo('00739340-v', 0), SenseInfo('00739082-v', 0), SenseInfo('00689809-v', 0), SenseInfo('00629738-v', 0), SenseInfo('00608808-v', 0), SenseInfo('00561887-v', 0) ],
"_tuba_n_1_rel" : [ SenseInfo('02804252-n', 0) ],
"_mistress_n_1_rel" : [ SenseInfo('10323752-n', 4), SenseInfo('10559840-n', 0), SenseInfo('10323634-n', 0) ],
"_silversmith_n_1_rel" : [ SenseInfo('10598749-n', 0) ],
"_broadcast_v_to_rel" : [ SenseInfo('00973056-v', 2), SenseInfo('01501184-v', 0), SenseInfo('00968211-v', 0), SenseInfo('00973056-v', 2), SenseInfo('01501184-v', 0), SenseInfo('00968211-v', 0) ],
"_scoop_v_out_rel" : [ SenseInfo('01312371-v', 0), SenseInfo('01109259-v', 0) ],
"_deflection_n_of_rel" : [ SenseInfo('14504726-n', 1), SenseInfo('07410883-n', 0), SenseInfo('07310839-n', 0), SenseInfo('05011277-n', 0), SenseInfo('00350380-n', 0) ],
"_transient_n_1_rel" : [ SenseInfo('10725149-n', 0), SenseInfo('07347468-n', 0) ],
"_myth_n_of_rel" : [ SenseInfo('06372680-n', 14), SenseInfo('06372680-n', 14) ],
"_of+late_a_1_rel" : [  ],
"_fling_v_off_rel" : [ SenseInfo('01512465-v', 13), SenseInfo('02094428-v', 1), SenseInfo('02269003-v', 0), SenseInfo('02222318-v', 0) ],
"_hangover_n_1_rel" : [ SenseInfo('14447165-n', 1), SenseInfo('10180791-n', 0), SenseInfo('01022292-n', 0) ],
"_advise_v_as_rel" : [ SenseInfo('00872886-v', 11), SenseInfo('00873682-v', 10), SenseInfo('00875394-v', 4) ],
"_bengal_a_1_rel" : [ SenseInfo('08710535-n', 0) ],
"_con_v_into_rel" : [ SenseInfo('02572119-v', 1), SenseInfo('00604576-v', 0) ],
"_pleasure_n_of_rel" : [ SenseInfo('07490713-n', 21), SenseInfo('05829782-n', 4), SenseInfo('05790452-n', 0), SenseInfo('01071746-n', 0), SenseInfo('00846326-n', 0), SenseInfo('07490713-n', 21), SenseInfo('05829782-n', 4), SenseInfo('05790452-n', 0), SenseInfo('01071746-n', 0), SenseInfo('00846326-n', 0), SenseInfo('07490713-n', 21), SenseInfo('05829782-n', 4), SenseInfo('05790452-n', 0), SenseInfo('01071746-n', 0), SenseInfo('00846326-n', 0) ],
"_diarthrosis_n_1_rel" : [ SenseInfo('05543177-n', 0) ],
"_span_n_1_rel" : [ SenseInfo('15134340-n', 6), SenseInfo('05087061-n', 1), SenseInfo('13743605-n', 0), SenseInfo('13656204-n', 0), SenseInfo('02898711-n', 0), SenseInfo('00349213-n', 0) ],
"_catalogue_v_1_rel" : [ SenseInfo('00652622-v', 2), SenseInfo('01626844-v', 1) ],
"_occupant_n_1_rel" : [ SenseInfo('10523519-n', 6) ],
"_now_x_deg_rel" : [ SenseInfo('00049433-r', 283), SenseInfo('00048475-r', 182), SenseInfo('00049102-r', 29), SenseInfo('00049220-r', 15), SenseInfo('15119919-n', 10), SenseInfo('00048739-r', 9), SenseInfo('00049758-r', 0), SenseInfo('00049685-r', 0) ],
"_belly+up_a_1_rel" : [ SenseInfo('02026629-a', 0), SenseInfo('02026629-a', 0) ],
"_syriac_a_1_rel" : [  ],
"_collar_v_1_rel" : [ SenseInfo('01215137-v', 1), SenseInfo('01215851-v', 0), SenseInfo('01215694-v', 0) ],
"_way_x_deg_rel" : [ SenseInfo('04928903-n', 183), SenseInfo('00172710-n', 61), SenseInfo('08679972-n', 40), SenseInfo('13939604-n', 28), SenseInfo('00415676-n', 19), SenseInfo('04564698-n', 16), SenseInfo('00312691-n', 12), SenseInfo('13777764-n', 10), SenseInfo('05084733-n', 7), SenseInfo('00101752-r', 7), SenseInfo('05791764-n', 3), SenseInfo('05839910-n', 1), SenseInfo('13285973-n', 0) ],
"_temblor_n_1_rel" : [ SenseInfo('07428954-n', 0) ],
"_intercom_n_1_rel" : [ SenseInfo('03578055-n', 0) ],
"_paisley_n_1_rel" : [ SenseInfo('03877351-n', 0) ],
"_simulate_v_1_rel" : [ SenseInfo('01742886-v', 5), SenseInfo('01722980-v', 0), SenseInfo('01721754-v', 0) ],
"_junior_n_1_rel" : [ SenseInfo('10784281-n', 3), SenseInfo('10227393-n', 2), SenseInfo('10227266-n', 1), SenseInfo('10227490-n', 0), SenseInfo('10784281-n', 3), SenseInfo('10227393-n', 2), SenseInfo('10227266-n', 1), SenseInfo('10227490-n', 0), SenseInfo('10784281-n', 3), SenseInfo('10227393-n', 2), SenseInfo('10227266-n', 1), SenseInfo('10227490-n', 0), SenseInfo('10784281-n', 3), SenseInfo('10227393-n', 2), SenseInfo('10227266-n', 1), SenseInfo('10227490-n', 0), SenseInfo('10784281-n', 3), SenseInfo('10227393-n', 2), SenseInfo('10227266-n', 1), SenseInfo('10227490-n', 0) ],
"_bobsled_v_1_rel" : [ SenseInfo('01939811-v', 0) ],
"_as+well_a_1_rel" : [  ],
"_on_p_rel" : [ SenseInfo('00068368-r', 40), SenseInfo('01651196-a', 6), SenseInfo('00069346-r', 2), SenseInfo('00069472-r', 1), SenseInfo('01651741-a', 0), SenseInfo('00068368-r', 40), SenseInfo('01651196-a', 6), SenseInfo('00069346-r', 2), SenseInfo('00069472-r', 1), SenseInfo('01651741-a', 0), SenseInfo('00068368-r', 40), SenseInfo('01651196-a', 6), SenseInfo('00069346-r', 2), SenseInfo('00069472-r', 1), SenseInfo('01651741-a', 0), SenseInfo('00068368-r', 40), SenseInfo('01651196-a', 6), SenseInfo('00069346-r', 2), SenseInfo('00069472-r', 1), SenseInfo('01651741-a', 0) ],
"_perpetrate_v_1_rel" : [ SenseInfo('02582615-v', 2) ],
"_mouth_n_1_rel" : [ SenseInfo('05302499-n', 48), SenseInfo('05301908-n', 12), SenseInfo('09362469-n', 2), SenseInfo('09362316-n', 2), SenseInfo('10335679-n', 1), SenseInfo('10335801-n', 0), SenseInfo('06721949-n', 0), SenseInfo('03794392-n', 0) ],
"_janitor_n_1_rel" : [ SenseInfo('10219577-n', 3) ],
"_particulars_n_of_rel" : [ SenseInfo('05818182-n', 7), SenseInfo('13809920-n', 0), SenseInfo('06751142-n', 0) ],
"_interfere_v_in_rel" : [ SenseInfo('02451912-v', 11), SenseInfo('02538765-v', 3) ],
"_illogical_n_1_rel" : [ SenseInfo('01430847-a', 0), SenseInfo('00465221-a', 0) ],
"_reshuffle_n_1_rel" : [ SenseInfo('01084489-n', 0), SenseInfo('00340662-n', 0) ],
"_orphan_v_1_rel" : [ SenseInfo('02315277-v', 0) ],
"_interchange_n_1_rel" : [ SenseInfo('03577818-n', 5), SenseInfo('00040152-n', 1), SenseInfo('01166258-n', 0), SenseInfo('01093085-n', 0) ],
"_such+a_q_rel" : [  ],
"_affect_v_2_rel" : [ SenseInfo('00137313-v', 43), SenseInfo('00019448-v', 11), SenseInfo('02677097-v', 4), SenseInfo('00838043-v', 4), SenseInfo('01767949-v', 0) ],
"_unmalicious_a_1_rel" : [ SenseInfo('00226535-a', 1), SenseInfo('00226535-a', 1) ],
"_spearhead_v_1_rel" : [ SenseInfo('02440608-v', 1) ],
"_precipitation_n_of_rel" : [ SenseInfo('13772653-n', 0), SenseInfo('13540199-n', 0), SenseInfo('11494638-n', 0), SenseInfo('07434320-n', 0), SenseInfo('05061149-n', 0), SenseInfo('05060189-n', 0) ],
"_perimeter_n_1_rel" : [ SenseInfo('13903387-n', 0), SenseInfo('13871452-n', 0), SenseInfo('05101261-n', 0) ],
"_correct_a_1_rel" : [ SenseInfo('00631391-a', 5), SenseInfo('01879261-a', 5), SenseInfo('01879464-a', 2), SenseInfo('00633410-a', 0), SenseInfo('00631391-a', 5), SenseInfo('01879261-a', 5), SenseInfo('01879464-a', 2), SenseInfo('00633410-a', 0), SenseInfo('00631391-a', 5), SenseInfo('01879261-a', 5), SenseInfo('01879464-a', 2), SenseInfo('00633410-a', 0), SenseInfo('00631391-a', 5), SenseInfo('01879261-a', 5), SenseInfo('01879464-a', 2), SenseInfo('00633410-a', 0) ],
"_subordination_n_of_rel" : [ SenseInfo('14001852-n', 0), SenseInfo('13807853-n', 0), SenseInfo('13800675-n', 0), SenseInfo('04907153-n', 0), SenseInfo('01128655-n', 0) ],
"_pry_v_1_rel" : [ SenseInfo('01593254-v', 3), SenseInfo('00784874-v', 2), SenseInfo('02169119-v', 1), SenseInfo('01630903-v', 0) ],
"_luxurious_a_1_rel" : [ SenseInfo('01298239-a', 3), SenseInfo('02024928-a', 0), SenseInfo('01298239-a', 3), SenseInfo('02024928-a', 0) ],
"_bottommost_a_1_rel" : [ SenseInfo('02440881-a', 0), SenseInfo('02440881-a', 0), SenseInfo('02440881-a', 0) ],
"_heat_v_cause_rel" : [ SenseInfo('00371264-v', 11), SenseInfo('02333358-v', 0), SenseInfo('01761120-v', 0), SenseInfo('00372665-v', 0) ],
"_dangle_v_cause_rel" : [ SenseInfo('02717472-v', 3), SenseInfo('01482285-v', 2) ],
"_ship_n_of_rel" : [ SenseInfo('04194289-n', 49) ],
"_commencement_n_of_rel" : [ SenseInfo('15265518-n', 0), SenseInfo('07454758-n', 0), SenseInfo('00235435-n', 0) ],
"_yow_a_1_rel" : [  ],
"_bitterly_x_deg_rel" : [ SenseInfo('00052762-r', 3), SenseInfo('00052882-r', 1), SenseInfo('00422435-r', 0) ],
"_thoughtless_a_1_rel" : [ SenseInfo('02420530-a', 2), SenseInfo('00639594-a', 1) ],
"_rest_n_1_rel" : [ SenseInfo('13810818-n', 44), SenseInfo('01064148-n', 6), SenseInfo('15274074-n', 3), SenseInfo('14012501-n', 1), SenseInfo('13962765-n', 1), SenseInfo('04081044-n', 1), SenseInfo('06865177-n', 0) ],
"_bucket_n_1_rel" : [ SenseInfo('02909870-n', 2), SenseInfo('13765749-n', 0) ],
"_muppet_n_1_rel" : [  ],
"_institution_n_1_rel" : [ SenseInfo('08053576-n', 26), SenseInfo('03574555-n', 2), SenseInfo('05669350-n', 1), SenseInfo('00240184-n', 1), SenseInfo('03746574-n', 0) ],
"_donkey_n_1_rel" : [ SenseInfo('06881360-n', 0), SenseInfo('02389559-n', 0) ],
"_disguise_v_as_rel" : [ SenseInfo('02158587-v', 1), SenseInfo('02158587-v', 1) ],
"_gainsay_v_to_rel" : [ SenseInfo('00869126-v', 0), SenseInfo('00869126-v', 0) ],
"_uphill_a_1_rel" : [ SenseInfo('02484530-a', 0) ],
"_commit_n_1_rel" : [  ],
"_simplified_a_1_rel" : [ SenseInfo('00750843-a', 2) ],
"_never+before_a_1_rel" : [  ],
"_downstroke_n_1_rel" : [ SenseInfo('06799485-n', 0) ],
"_satisfactory_a_for_rel" : [ SenseInfo('02080577-a', 14), SenseInfo('01124768-a', 7), SenseInfo('02080577-a', 14), SenseInfo('01124768-a', 7), SenseInfo('02080577-a', 14), SenseInfo('01124768-a', 7), SenseInfo('02080577-a', 14), SenseInfo('01124768-a', 7) ],
"_yap_v_at_rel" : [ SenseInfo('01048171-v', 1) ],
"_anal_a_1_rel" : [ SenseInfo('02620436-a', 0), SenseInfo('00109966-a', 0) ],
"_feature_v_cause_rel" : [ SenseInfo('02630189-v', 16), SenseInfo('02631659-v', 3) ],
"_age_v_cause_rel" : [ SenseInfo('00248512-v', 1), SenseInfo('00248026-v', 1), SenseInfo('00249679-v', 0) ],
"_crank_v_out_rel" : [ SenseInfo('01991744-v', 0), SenseInfo('01858796-v', 0), SenseInfo('01595149-v', 0), SenseInfo('01341815-v', 0), SenseInfo('01280958-v', 0) ],
"_embroider_v_1_rel" : [ SenseInfo('01667607-v', 2), SenseInfo('00956405-v', 0) ],
"_care_v_about_rel" : [ SenseInfo('01822936-v', 64), SenseInfo('02550296-v', 9), SenseInfo('01824736-v', 7), SenseInfo('02436349-v', 4), SenseInfo('01766748-v', 1) ],
"_close_n_of-to_rel" : [ SenseInfo('15267536-n', 8), SenseInfo('06398401-n', 0), SenseInfo('00210797-n', 0), SenseInfo('15267536-n', 8), SenseInfo('06398401-n', 0), SenseInfo('00210797-n', 0) ],
"_ridiculously_x_deg_rel" : [ SenseInfo('00387017-r', 1) ],
"_chihuahua_n_1_rel" : [ SenseInfo('08742578-n', 0), SenseInfo('08742455-n', 0), SenseInfo('02085620-n', 0) ],
"_chimney_n_1_rel" : [ SenseInfo('03017428-n', 9), SenseInfo('03636891-n', 0) ],
"_pick_v_out_rel" : [ SenseInfo('00676450-v', 13), SenseInfo('01382083-v', 4), SenseInfo('00842772-v', 2), SenseInfo('01647131-v', 1), SenseInfo('00178102-v', 1), SenseInfo('00177714-v', 1), SenseInfo('02321648-v', 0), SenseInfo('02287209-v', 0), SenseInfo('01452546-v', 0), SenseInfo('01442578-v', 0), SenseInfo('01243474-v', 0), SenseInfo('01174294-v', 0) ],
"_arbitrator_n_1_rel" : [ SenseInfo('09803429-n', 0) ],
"_soluble_a_1_rel" : [ SenseInfo('02265015-a', 1), SenseInfo('02266145-a', 0) ],
"_lemonade_n_1_rel" : [ SenseInfo('07926250-n', 1) ],
"_spear_n_1_rel" : [ SenseInfo('04270891-n', 1), SenseInfo('04271148-n', 0) ],
"_punt_n_1_rel" : [ SenseInfo('13694657-n', 0), SenseInfo('04024983-n', 0), SenseInfo('00136984-n', 0), SenseInfo('13694657-n', 0), SenseInfo('04024983-n', 0), SenseInfo('00136984-n', 0) ],
"_ilm_n_1_rel" : [  ],
"_forcible_a_1_rel" : [ SenseInfo('00842324-a', 0), SenseInfo('00842324-a', 0) ],
"_dividend_n_1_rel" : [ SenseInfo('13408023-n', 5), SenseInfo('13732953-n', 0), SenseInfo('13273836-n', 0) ],
"_revert_v_to_rel" : [ SenseInfo('00387310-v', 3), SenseInfo('00120217-v', 0), SenseInfo('00387310-v', 3), SenseInfo('00120217-v', 0), SenseInfo('00387310-v', 3), SenseInfo('00120217-v', 0) ],
"_jersey_n_1_rel" : [ SenseInfo('09112282-n', 0), SenseInfo('08887238-n', 0), SenseInfo('03595614-n', 0), SenseInfo('03595523-n', 0), SenseInfo('02406749-n', 0) ],
"_at+the+most_x_deg_rel" : [ SenseInfo('00104528-r', 1) ],
"_minimalist_a_1_rel" : [ SenseInfo('02764549-a', 0), SenseInfo('01532760-a', 0) ],
"_sew_v_on_rel" : [ SenseInfo('01329239-v', 5), SenseInfo('01666327-v', 0) ],
"_brewer_n_1_rel" : [ SenseInfo('09874118-n', 0), SenseInfo('09874014-n', 0) ],
"_broaden_v_cause_rel" : [ SenseInfo('00317569-v', 9), SenseInfo('00540235-v', 1), SenseInfo('00436404-v', 1), SenseInfo('00317468-v', 1), SenseInfo('00317569-v', 9), SenseInfo('00540235-v', 1), SenseInfo('00436404-v', 1), SenseInfo('00317468-v', 1) ],
"_youngster_n_1_rel" : [ SenseInfo('09917593-n', 4) ],
"_sufficiently_x_deg_rel" : [ SenseInfo('00145571-r', 23) ],
"_norwegian_a_1_rel" : [ SenseInfo('02959912-a', 0) ],
"_float_n_1_rel" : [ SenseInfo('15294085-n', 0), SenseInfo('13336368-n', 0), SenseInfo('07923034-n', 0), SenseInfo('03364775-n', 0), SenseInfo('03364599-n', 0), SenseInfo('03364340-n', 0), SenseInfo('02467581-n', 0) ],
"_intersection_n_1_rel" : [ SenseInfo('05866653-n', 10), SenseInfo('03581125-n', 2), SenseInfo('13873213-n', 0), SenseInfo('07999068-n', 0), SenseInfo('05764365-n', 0), SenseInfo('00146111-n', 0) ],
"_eh_a_1_rel" : [  ],
"_ringgit_n_1_rel" : [ SenseInfo('13698076-n', 0), SenseInfo('13698076-n', 0), SenseInfo('13698076-n', 0), SenseInfo('13698076-n', 0) ],
"_string_v_1_rel" : [ SenseInfo('01359432-v', 2), SenseInfo('00190389-v', 1), SenseInfo('01993805-v', 0), SenseInfo('01360571-v', 0), SenseInfo('01360423-v', 0), SenseInfo('01360316-v', 0), SenseInfo('01359145-v', 0), SenseInfo('01359432-v', 2), SenseInfo('00190389-v', 1), SenseInfo('01993805-v', 0), SenseInfo('01360571-v', 0), SenseInfo('01360423-v', 0), SenseInfo('01360316-v', 0), SenseInfo('01359145-v', 0) ],
"_indebted_a_1_rel" : [ SenseInfo('01617004-a', 2), SenseInfo('01617144-a', 0) ],
"_shaker_n_1_rel" : [ SenseInfo('10585976-n', 0), SenseInfo('10585773-n', 0), SenseInfo('04183329-n', 0) ],
"_utmost_n_1_rel" : [ SenseInfo('05124928-n', 1), SenseInfo('05124928-n', 1) ],
"_round_v_up_rel" : [ SenseInfo('01858910-v', 3), SenseInfo('00145147-v', 1), SenseInfo('00980339-v', 0), SenseInfo('00862683-v', 0), SenseInfo('00473799-v', 0), SenseInfo('00145623-v', 0), SenseInfo('00046382-v', 0) ],
"_go_v_on_rel" : [ SenseInfo('01835496-v', 343), SenseInfo('02372605-v', 95), SenseInfo('01848718-v', 49), SenseInfo('00149583-v', 29), SenseInfo('02653862-v', 14), SenseInfo('02721284-v', 10), SenseInfo('02685951-v', 10), SenseInfo('00341560-v', 10), SenseInfo('00359916-v', 9), SenseInfo('02618001-v', 7), SenseInfo('02176268-v', 3), SenseInfo('01525666-v', 3), SenseInfo('01192773-v', 3), SenseInfo('00539110-v', 3), SenseInfo('02618149-v', 2), SenseInfo('02617798-v', 2), SenseInfo('00358431-v', 2), SenseInfo('02737876-v', 1), SenseInfo('02729819-v', 1), SenseInfo('01864230-v', 1), SenseInfo('01076615-v', 1), SenseInfo('02700772-v', 0), SenseInfo('02700666-v', 0), SenseInfo('02700455-v', 0), SenseInfo('02686471-v', 0), SenseInfo('02659763-v', 0), SenseInfo('01318849-v', 0), SenseInfo('01192992-v', 0), SenseInfo('00676267-v', 0), SenseInfo('00434374-v', 0), SenseInfo('01835496-v', 343), SenseInfo('02372605-v', 95), SenseInfo('01848718-v', 49), SenseInfo('00149583-v', 29), SenseInfo('02653862-v', 14), SenseInfo('02721284-v', 10), SenseInfo('02685951-v', 10), SenseInfo('00341560-v', 10), SenseInfo('00359916-v', 9), SenseInfo('02618001-v', 7), SenseInfo('02176268-v', 3), SenseInfo('01525666-v', 3), SenseInfo('01192773-v', 3), SenseInfo('00539110-v', 3), SenseInfo('02618149-v', 2), SenseInfo('02617798-v', 2), SenseInfo('00358431-v', 2), SenseInfo('02737876-v', 1), SenseInfo('02729819-v', 1), SenseInfo('01864230-v', 1), SenseInfo('01076615-v', 1), SenseInfo('02700772-v', 0), SenseInfo('02700666-v', 0), SenseInfo('02700455-v', 0), SenseInfo('02686471-v', 0), SenseInfo('02659763-v', 0), SenseInfo('01318849-v', 0), SenseInfo('01192992-v', 0), SenseInfo('00676267-v', 0), SenseInfo('00434374-v', 0) ],
"_fussy_a_1_rel" : [ SenseInfo('01136248-a', 1), SenseInfo('01795203-a', 0), SenseInfo('00984624-a', 0) ],
"_from_p_time_rel" : [  ],
"_inequality_n_1_rel" : [ SenseInfo('04752221-n', 1) ],
"_nitre_n_1_rel" : [ SenseInfo('14861355-n', 0) ],
"_fence_v_in_rel" : [ SenseInfo('01588134-v', 1), SenseInfo('02210754-v', 0), SenseInfo('01146918-v', 0), SenseInfo('01130607-v', 0), SenseInfo('00773432-v', 0) ],
"_unbranched_a_1_rel" : [ SenseInfo('00614868-a', 0), SenseInfo('00614868-a', 0) ],
"_if_x_rel" : [  ],
"_month+to+month_a_1_rel" : [  ],
"_rootstock_n_1_rel" : [ SenseInfo('13128582-n', 0), SenseInfo('13127303-n', 0) ],
"_cadaver_n_1_rel" : [ SenseInfo('05218119-n', 1) ],
"_practice_n_of_rel" : [ SenseInfo('00410247-n', 23), SenseInfo('00894552-n', 5), SenseInfo('00411048-n', 3), SenseInfo('00631378-n', 2), SenseInfo('05667196-n', 1), SenseInfo('00410247-n', 23), SenseInfo('00894552-n', 5), SenseInfo('00411048-n', 3), SenseInfo('00631378-n', 2), SenseInfo('05667196-n', 1) ],
"_shipment_n_of-to_rel" : [ SenseInfo('02964389-n', 3), SenseInfo('00061290-n', 3), SenseInfo('02964389-n', 3), SenseInfo('00061290-n', 3) ],
"_reverse_v_1_rel" : [ SenseInfo('00138508-v', 8), SenseInfo('00386715-v', 7), SenseInfo('00716130-v', 2), SenseInfo('00799798-v', 0), SenseInfo('00386965-v', 0) ],
"comp_too_rel" : [  ],
"_fibrous_a_1_rel" : [ SenseInfo('02446380-a', 0), SenseInfo('02446239-a', 0) ],
"_jet_v_off_rel" : [ SenseInfo('01516290-v', 1), SenseInfo('01942234-v', 0) ],
"_deteriorate_v_1_rel" : [ SenseInfo('00208497-v', 4), SenseInfo('00092293-v', 2) ],
"_sofa_n_1_rel" : [ SenseInfo('04256520-n', 5) ],
"_remarkably_x_deg_rel" : [ SenseInfo('00107230-r', 9), SenseInfo('00454512-r', 0) ],
"_dishonor_v_1_rel" : [ SenseInfo('02547225-v', 2), SenseInfo('02567519-v', 0), SenseInfo('02237943-v', 0), SenseInfo('02547225-v', 2), SenseInfo('02567519-v', 0), SenseInfo('02237943-v', 0) ],
"_mistrial_n_1_rel" : [ SenseInfo('01199252-n', 0) ],
"_fabricate_v_1_rel" : [ SenseInfo('01653442-v', 0), SenseInfo('01634424-v', 0) ],
"_conditional_n_1_rel" : [ SenseInfo('01913413-a', 1), SenseInfo('00555325-a', 0) ],
"_irritate_v_1_rel" : [ SenseInfo('01787955-v', 3), SenseInfo('00063291-v', 1), SenseInfo('00503715-v', 0), SenseInfo('01787955-v', 3), SenseInfo('00063291-v', 1), SenseInfo('00503715-v', 0), SenseInfo('01787955-v', 3), SenseInfo('00063291-v', 1), SenseInfo('00503715-v', 0), SenseInfo('01787955-v', 3), SenseInfo('00063291-v', 1), SenseInfo('00503715-v', 0), SenseInfo('01787955-v', 3), SenseInfo('00063291-v', 1), SenseInfo('00503715-v', 0) ],
"_heartbreaking_a_for_rel" : [ SenseInfo('01365544-a', 0), SenseInfo('01365544-a', 0), SenseInfo('01365544-a', 0) ],
"_tub_n_of_rel" : [ SenseInfo('02808440-n', 7), SenseInfo('04493381-n', 1), SenseInfo('13770926-n', 0) ],
"_whole_a_1_rel" : [ SenseInfo('00514884-a', 109), SenseInfo('00517916-a', 0), SenseInfo('01319712-a', 0), SenseInfo('01171396-a', 0), SenseInfo('00784215-a', 0), SenseInfo('00514884-a', 109), SenseInfo('00517916-a', 0), SenseInfo('01319712-a', 0), SenseInfo('01171396-a', 0), SenseInfo('00784215-a', 0) ],
"_recommendable_a_1_rel" : [  ],
"_volatile_n_1_rel" : [ SenseInfo('15093735-n', 0) ],
"_candour_n_1_rel" : [ SenseInfo('04871720-n', 1), SenseInfo('06203030-n', 0) ],
"_rainwater_n_1_rel" : [ SenseInfo('15008607-n', 0) ],
"_developer_n_of_rel" : [ SenseInfo('10010062-n', 4), SenseInfo('03182912-n', 0) ],
"_terminal_n_1_rel" : [ SenseInfo('04412901-n', 2), SenseInfo('04413151-n', 1), SenseInfo('08566028-n', 0), SenseInfo('04413419-n', 0) ],
"_adjacent+to_p_rel" : [  ],
"_sum_n_1_rel" : [ SenseInfo('13331198-n', 12), SenseInfo('05861067-n', 4), SenseInfo('07959016-n', 1), SenseInfo('05921123-n', 1), SenseInfo('04353803-n', 1), SenseInfo('07998712-n', 0) ],
"_zero_n_1_rel" : [ SenseInfo('13740168-n', 6), SenseInfo('13742358-n', 3), SenseInfo('05856217-n', 0), SenseInfo('04614505-n', 0) ],
"_fly_v_off_rel" : [ SenseInfo('01940403-v', 33), SenseInfo('01842068-v', 9), SenseInfo('01941093-v', 5), SenseInfo('01451842-v', 3), SenseInfo('01848058-v', 2), SenseInfo('01839404-v', 2), SenseInfo('00545292-v', 2), SenseInfo('02073065-v', 1), SenseInfo('01840238-v', 1), SenseInfo('02140965-v', 0), SenseInfo('02075462-v', 0), SenseInfo('01847845-v', 0), SenseInfo('01402765-v', 0), SenseInfo('00153061-v', 0) ],
"_founder_n_of_rel" : [ SenseInfo('14348895-n', 1), SenseInfo('10107303-n', 1), SenseInfo('10107778-n', 0), SenseInfo('14348895-n', 1), SenseInfo('10107303-n', 1), SenseInfo('10107778-n', 0) ],
"_shape_n_1_rel" : [ SenseInfo('05064037-n', 37), SenseInfo('00027807-n', 6), SenseInfo('05217168-n', 3), SenseInfo('05941210-n', 2), SenseInfo('04677514-n', 2), SenseInfo('14546227-n', 1), SenseInfo('08174167-n', 0), SenseInfo('05930736-n', 0) ],
"_rice_n_1_rel" : [ SenseInfo('07804323-n', 5), SenseInfo('12125890-n', 4), SenseInfo('11259777-n', 0), SenseInfo('11259635-n', 0) ],
"_minister_n_of_rel" : [ SenseInfo('09983572-n', 10), SenseInfo('10320863-n', 0), SenseInfo('10320695-n', 0), SenseInfo('00585810-n', 0) ],
"_make_v_over_rel" : [ SenseInfo('02560585-v', 508), SenseInfo('00120316-v', 459), SenseInfo('01617192-v', 243), SenseInfo('00770437-v', 85), SenseInfo('01645601-v', 78), SenseInfo('01621555-v', 52), SenseInfo('00730758-v', 33), SenseInfo('01646075-v', 17), SenseInfo('01640207-v', 16), SenseInfo('02289295-v', 14), SenseInfo('01619014-v', 14), SenseInfo('02621395-v', 12), SenseInfo('02022162-v', 12), SenseInfo('02674708-v', 10), SenseInfo('01653873-v', 9), SenseInfo('01755816-v', 8), SenseInfo('01654628-v', 5), SenseInfo('00556855-v', 5), SenseInfo('00012267-v', 5), SenseInfo('02396716-v', 4), SenseInfo('02355596-v', 4), SenseInfo('02020590-v', 4), SenseInfo('00665476-v', 4), SenseInfo('02582921-v', 3), SenseInfo('02598483-v', 2), SenseInfo('01733477-v', 2), SenseInfo('00276068-v', 2), SenseInfo('02075857-v', 1), SenseInfo('00074038-v', 1), SenseInfo('02748759-v', 0), SenseInfo('02748627-v', 0), SenseInfo('02745332-v', 0), SenseInfo('02665124-v', 0), SenseInfo('02621133-v', 0), SenseInfo('02134050-v', 0), SenseInfo('02051031-v', 0), SenseInfo('02021532-v', 0), SenseInfo('01755504-v', 0), SenseInfo('01664172-v', 0), SenseInfo('01428578-v', 0), SenseInfo('00891038-v', 0), SenseInfo('00838524-v', 0), SenseInfo('00698256-v', 0), SenseInfo('00698104-v', 0), SenseInfo('00562182-v', 0), SenseInfo('00562067-v', 0), SenseInfo('00545953-v', 0), SenseInfo('00107369-v', 0), SenseInfo('00072012-v', 0) ],
"_hyena_n_1_rel" : [ SenseInfo('02117135-n', 0) ],
"_barn_n_1_rel" : [ SenseInfo('02793495-n', 22), SenseInfo('13614256-n', 0) ],
"_initial_v_1_rel" : [ SenseInfo('00997307-v', 0) ],
"_mover_n_of_rel" : [ SenseInfo('10336234-n', 3), SenseInfo('10484526-n', 0), SenseInfo('10335931-n', 0), SenseInfo('08478482-n', 0) ],
"_loft_n_1_rel" : [ SenseInfo('03686470-n', 1), SenseInfo('03686130-n', 1), SenseInfo('05069447-n', 0), SenseInfo('03686363-n', 0) ],
"_suppressor_n_1_rel" : [ SenseInfo('10678472-n', 0), SenseInfo('05441468-n', 0), SenseInfo('04361641-n', 0) ],
"_notch_v_up_rel" : [ SenseInfo('01276970-v', 3), SenseInfo('01004550-v', 0) ],
"_red_a_1_rel" : [ SenseInfo('00381097-a', 43), SenseInfo('00248560-a', 8), SenseInfo('00395626-a', 7), SenseInfo('00381097-a', 43), SenseInfo('00248560-a', 8), SenseInfo('00395626-a', 7), SenseInfo('00381097-a', 43), SenseInfo('00248560-a', 8), SenseInfo('00395626-a', 7) ],
"_unrivaled_a_1_rel" : [ SenseInfo('00505410-a', 0), SenseInfo('00505410-a', 0) ],
"_litter_v_1_rel" : [ SenseInfo('02735142-v', 1), SenseInfo('01378421-v', 1), SenseInfo('00058401-v', 0) ],
"_pan_n_of_rel" : [ SenseInfo('03880531-n', 5), SenseInfo('09568241-n', 0), SenseInfo('03880323-n', 0), SenseInfo('02481629-n', 0) ],
"_reflector_n_1_rel" : [ SenseInfo('04069276-n', 6), SenseInfo('04068601-n', 1) ],
"_litter_n_1_rel" : [ SenseInfo('08400331-n', 4), SenseInfo('14858292-n', 2), SenseInfo('03678362-n', 0), SenseInfo('02820432-n', 0) ],
"_inhabitable_a_1_rel" : [ SenseInfo('01423851-a', 0) ],
"_teaching_n_1_rel" : [ SenseInfo('00887081-n', 9), SenseInfo('06185955-n', 3), SenseInfo('00883297-n', 1) ],
"_hope_n_of_rel" : [ SenseInfo('07511733-n', 18), SenseInfo('07541053-n', 17), SenseInfo('05950733-n', 14), SenseInfo('10184946-n', 2), SenseInfo('11059263-n', 0), SenseInfo('04848262-n', 0), SenseInfo('07511733-n', 18), SenseInfo('07541053-n', 17), SenseInfo('05950733-n', 14), SenseInfo('10184946-n', 2), SenseInfo('11059263-n', 0), SenseInfo('04848262-n', 0) ],
"_tangle_v_up_rel" : [ SenseInfo('02677797-v', 0), SenseInfo('01521124-v', 0), SenseInfo('01474034-v', 0), SenseInfo('01462928-v', 0) ],
"_criterion_n_1_rel" : [ SenseInfo('07260623-n', 3), SenseInfo('05924920-n', 2), SenseInfo('07260623-n', 3), SenseInfo('05924920-n', 2) ],
"_spider_n_1_rel" : [ SenseInfo('01772222-n', 1), SenseInfo('06579715-n', 0), SenseInfo('04275283-n', 0) ],
"_renal_a_1_rel" : [ SenseInfo('02883599-a', 0) ],
"_romantic_a_1_rel" : [ SenseInfo('02789151-a', 6), SenseInfo('01465214-a', 2), SenseInfo('01837182-a', 0), SenseInfo('02789151-a', 6), SenseInfo('01465214-a', 2), SenseInfo('01837182-a', 0) ],
"_mathematics_n_1_rel" : [ SenseInfo('06000644-n', 4) ],
"_vehicular_a_1_rel" : [ SenseInfo('03128327-a', 0) ],
"_norseman_n_1_rel" : [ SenseInfo('09725402-n', 0) ],
"_coordinate_a_1_rel" : [ SenseInfo('00890874-a', 1) ],
"_panel_n_of_rel" : [ SenseInfo('03882058-n', 1), SenseInfo('08414807-n', 0), SenseInfo('08414608-n', 0), SenseInfo('08414381-n', 0), SenseInfo('03882346-n', 0), SenseInfo('03448253-n', 0), SenseInfo('03187268-n', 0), SenseInfo('03098140-n', 0) ],
"_marsupial_n_1_rel" : [ SenseInfo('01874434-n', 0) ],
"_revolutionize_v_1_rel" : [ SenseInfo('00125633-v', 1), SenseInfo('02402695-v', 0), SenseInfo('00605310-v', 0), SenseInfo('00125633-v', 1), SenseInfo('02402695-v', 0), SenseInfo('00605310-v', 0) ],
"_workday_n_1_rel" : [ SenseInfo('15136923-n', 0), SenseInfo('15136723-n', 0) ],
"_sweat_n_1_rel" : [ SenseInfo('05405751-n', 11), SenseInfo('14403560-n', 0), SenseInfo('11446459-n', 0), SenseInfo('00621627-n', 0) ],
"_tally_n_1_rel" : [ SenseInfo('00189565-n', 4), SenseInfo('06517779-n', 0), SenseInfo('00634586-n', 0) ],
"_hull_n_1_rel" : [ SenseInfo('13139918-n', 0), SenseInfo('11691990-n', 0), SenseInfo('11065718-n', 0), SenseInfo('11065562-n', 0), SenseInfo('08877208-n', 0), SenseInfo('03548626-n', 0) ],
"_rudimentary_a_1_rel" : [ SenseInfo('01856419-a', 1), SenseInfo('00524965-a', 1), SenseInfo('00742714-a', 0) ],
"_individualist_n_1_rel" : [ SenseInfo('09619824-n', 3) ],
"_hunt_v_out_rel" : [ SenseInfo('01143838-v', 4), SenseInfo('02003601-v', 2), SenseInfo('02056691-v', 0), SenseInfo('02034147-v', 0), SenseInfo('01878376-v', 0), SenseInfo('01316401-v', 0), SenseInfo('01144657-v', 0) ],
"_overgraze_v_1_rel" : [  ],
"_spool_v_1_rel" : [ SenseInfo('02233533-v', 0), SenseInfo('01522878-v', 0) ],
"_transparent_a_1_rel" : [ SenseInfo('00431774-a', 5), SenseInfo('02413390-a', 2), SenseInfo('02318950-a', 0), SenseInfo('01619689-a', 0) ],
"_shampoo_v_1_rel" : [ SenseInfo('00042017-v', 0) ],
"_perpetuate_v_1_rel" : [ SenseInfo('02648253-v', 10) ],
"_incidental_a_1_rel" : [ SenseInfo('01856929-a', 1), SenseInfo('00903264-a', 0), SenseInfo('00122844-a', 0), SenseInfo('01856929-a', 1), SenseInfo('00903264-a', 0), SenseInfo('00122844-a', 0) ],
"_stall_v_1_rel" : [ SenseInfo('02642238-v', 2), SenseInfo('01862340-v', 1), SenseInfo('00460555-v', 1), SenseInfo('02460070-v', 0), SenseInfo('01862776-v', 0), SenseInfo('01862640-v', 0), SenseInfo('01862496-v', 0) ],
"_ball_n_of_rel" : [ SenseInfo('02778669-n', 35), SenseInfo('03802228-n', 5), SenseInfo('13899404-n', 3), SenseInfo('08253268-n', 2), SenseInfo('05524615-n', 1), SenseInfo('02779435-n', 1), SenseInfo('10832731-n', 0), SenseInfo('07961016-n', 0), SenseInfo('07448885-n', 0), SenseInfo('05576194-n', 0), SenseInfo('00474568-n', 0), SenseInfo('00107400-n', 0) ],
"_harvest_v_1_rel" : [ SenseInfo('01320009-v', 3), SenseInfo('00175804-v', 0) ],
"_nauseate_v_1_rel" : [ SenseInfo('02195191-v', 0), SenseInfo('01808374-v', 0) ],
"_banjo_n_1_rel" : [ SenseInfo('02787622-n', 1) ],
"_affiance_v_1_rel" : [ SenseInfo('00886602-v', 0) ],
"_boycott_n_1_rel" : [ SenseInfo('00206130-n', 0) ],
"_resist_n_1_rel" : [  ],
"_offing_n_1_rel" : [ SenseInfo('15263675-n', 0), SenseInfo('09377125-n', 0) ],
"_tow_n_1_rel" : [ SenseInfo('00115292-n', 1), SenseInfo('00115292-n', 1) ],
"_reboot_n_1_rel" : [  ],
"_process_n_of_rel" : [ SenseInfo('01023820-n', 63), SenseInfo('05701363-n', 3), SenseInfo('06556692-n', 0), SenseInfo('05701738-n', 0), SenseInfo('05470189-n', 0), SenseInfo('00029677-n', 0) ],
"_unimpaired_a_1_rel" : [ SenseInfo('01275395-a', 1), SenseInfo('01275395-a', 1) ],
"_bad_n_1_rel" : [ SenseInfo('05144079-n', 2) ],
"_most_q_rel" : [  ],
"_womanish_a_1_rel" : [ SenseInfo('01476516-a', 0) ],
"_document_v_1_rel" : [ SenseInfo('01002297-v', 3), SenseInfo('00666510-v', 1), SenseInfo('01002297-v', 3), SenseInfo('00666510-v', 1) ],
"_snort_v_1_rel" : [ SenseInfo('01045073-v', 3), SenseInfo('00006523-v', 3), SenseInfo('01200245-v', 1), SenseInfo('01199755-v', 0), SenseInfo('01045073-v', 3), SenseInfo('00006523-v', 3), SenseInfo('01200245-v', 1), SenseInfo('01199755-v', 0) ],
"_turgite_n_1_rel" : [  ],
"_orogeny_n_1_rel" : [ SenseInfo('13527817-n', 0) ],
"_swathing_n_1_rel" : [ SenseInfo('04369146-n', 1) ],
"_fourth_n_of_rel" : [ SenseInfo('13847124-n', 1), SenseInfo('13737480-n', 0), SenseInfo('06859674-n', 0), SenseInfo('13847124-n', 1), SenseInfo('13737480-n', 0), SenseInfo('06859674-n', 0), SenseInfo('13847124-n', 1), SenseInfo('13737480-n', 0), SenseInfo('06859674-n', 0), SenseInfo('13847124-n', 1), SenseInfo('13737480-n', 0), SenseInfo('06859674-n', 0) ],
"_cut_v_short_rel" : [ SenseInfo('01552519-v', 58), SenseInfo('00429060-v', 18), SenseInfo('02033295-v', 3), SenseInfo('01610834-v', 2), SenseInfo('02422283-v', 1), SenseInfo('01754915-v', 1), SenseInfo('01666717-v', 1), SenseInfo('01413917-v', 1), SenseInfo('01064799-v', 1), SenseInfo('00201722-v', 1), SenseInfo('02613860-v', 0), SenseInfo('02588280-v', 0), SenseInfo('02134232-v', 0), SenseInfo('02101649-v', 0), SenseInfo('01915865-v', 0), SenseInfo('01915730-v', 0), SenseInfo('01860107-v', 0), SenseInfo('01859995-v', 0), SenseInfo('01756563-v', 0), SenseInfo('01756416-v', 0), SenseInfo('01756277-v', 0), SenseInfo('01754737-v', 0), SenseInfo('01713491-v', 0), SenseInfo('01611123-v', 0), SenseInfo('01610990-v', 0), SenseInfo('01555437-v', 0), SenseInfo('01510576-v', 0), SenseInfo('01320424-v', 0), SenseInfo('01319738-v', 0), SenseInfo('01227088-v', 0), SenseInfo('01059564-v', 0), SenseInfo('00561090-v', 0), SenseInfo('00473322-v', 0), SenseInfo('00447654-v', 0), SenseInfo('00429968-v', 0), SenseInfo('00292507-v', 0), SenseInfo('00243900-v', 0), SenseInfo('00226071-v', 0), SenseInfo('00108475-v', 0), SenseInfo('00096136-v', 0), SenseInfo('00061219-v', 0) ],
"_hardy_a_1_rel" : [ SenseInfo('02038994-a', 1), SenseInfo('02039304-a', 0), SenseInfo('00250119-a', 0), SenseInfo('02038994-a', 1), SenseInfo('02039304-a', 0), SenseInfo('00250119-a', 0), SenseInfo('02038994-a', 1), SenseInfo('02039304-a', 0), SenseInfo('00250119-a', 0) ],
"_statute_n_1_rel" : [ SenseInfo('06564387-n', 5) ],
"_show_v_1_rel" : [ SenseInfo('02148788-v', 136), SenseInfo('00664788-v', 63), SenseInfo('01015244-v', 57), SenseInfo('02137132-v', 43), SenseInfo('01686956-v', 32), SenseInfo('00943837-v', 24), SenseInfo('00923793-v', 24), SenseInfo('02139544-v', 11), SenseInfo('00922867-v', 7), SenseInfo('00923307-v', 6), SenseInfo('02000547-v', 2), SenseInfo('01086549-v', 0), SenseInfo('02148788-v', 136), SenseInfo('00664788-v', 63), SenseInfo('01015244-v', 57), SenseInfo('02137132-v', 43), SenseInfo('01686956-v', 32), SenseInfo('00943837-v', 24), SenseInfo('00923793-v', 24), SenseInfo('02139544-v', 11), SenseInfo('00922867-v', 7), SenseInfo('00923307-v', 6), SenseInfo('02000547-v', 2), SenseInfo('01086549-v', 0), SenseInfo('02148788-v', 136), SenseInfo('00664788-v', 63), SenseInfo('01015244-v', 57), SenseInfo('02137132-v', 43), SenseInfo('01686956-v', 32), SenseInfo('00943837-v', 24), SenseInfo('00923793-v', 24), SenseInfo('02139544-v', 11), SenseInfo('00922867-v', 7), SenseInfo('00923307-v', 6), SenseInfo('02000547-v', 2), SenseInfo('01086549-v', 0), SenseInfo('02148788-v', 136), SenseInfo('00664788-v', 63), SenseInfo('01015244-v', 57), SenseInfo('02137132-v', 43), SenseInfo('01686956-v', 32), SenseInfo('00943837-v', 24), SenseInfo('00923793-v', 24), SenseInfo('02139544-v', 11), SenseInfo('00922867-v', 7), SenseInfo('00923307-v', 6), SenseInfo('02000547-v', 2), SenseInfo('01086549-v', 0), SenseInfo('02148788-v', 136), SenseInfo('00664788-v', 63), SenseInfo('01015244-v', 57), SenseInfo('02137132-v', 43), SenseInfo('01686956-v', 32), SenseInfo('00943837-v', 24), SenseInfo('00923793-v', 24), SenseInfo('02139544-v', 11), SenseInfo('00922867-v', 7), SenseInfo('00923307-v', 6), SenseInfo('02000547-v', 2), SenseInfo('01086549-v', 0), SenseInfo('02148788-v', 136), SenseInfo('00664788-v', 63), SenseInfo('01015244-v', 57), SenseInfo('02137132-v', 43), SenseInfo('01686956-v', 32), SenseInfo('00943837-v', 24), SenseInfo('00923793-v', 24), SenseInfo('02139544-v', 11), SenseInfo('00922867-v', 7), SenseInfo('00923307-v', 6), SenseInfo('02000547-v', 2), SenseInfo('01086549-v', 0), SenseInfo('02148788-v', 136), SenseInfo('00664788-v', 63), SenseInfo('01015244-v', 57), SenseInfo('02137132-v', 43), SenseInfo('01686956-v', 32), SenseInfo('00943837-v', 24), SenseInfo('00923793-v', 24), SenseInfo('02139544-v', 11), SenseInfo('00922867-v', 7), SenseInfo('00923307-v', 6), SenseInfo('02000547-v', 2), SenseInfo('01086549-v', 0), SenseInfo('02148788-v', 136), SenseInfo('00664788-v', 63), SenseInfo('01015244-v', 57), SenseInfo('02137132-v', 43), SenseInfo('01686956-v', 32), SenseInfo('00943837-v', 24), SenseInfo('00923793-v', 24), SenseInfo('02139544-v', 11), SenseInfo('00922867-v', 7), SenseInfo('00923307-v', 6), SenseInfo('02000547-v', 2), SenseInfo('01086549-v', 0), SenseInfo('02148788-v', 136), SenseInfo('00664788-v', 63), SenseInfo('01015244-v', 57), SenseInfo('02137132-v', 43), SenseInfo('01686956-v', 32), SenseInfo('00943837-v', 24), SenseInfo('00923793-v', 24), SenseInfo('02139544-v', 11), SenseInfo('00922867-v', 7), SenseInfo('00923307-v', 6), SenseInfo('02000547-v', 2), SenseInfo('01086549-v', 0) ],
"_edge_n_of_rel" : [ SenseInfo('08565701-n', 28), SenseInfo('13903079-n', 5), SenseInfo('03264136-n', 5), SenseInfo('05171978-n', 2), SenseInfo('05158857-n', 2), SenseInfo('03264542-n', 1), SenseInfo('08565701-n', 28), SenseInfo('13903079-n', 5), SenseInfo('03264136-n', 5), SenseInfo('05171978-n', 2), SenseInfo('05158857-n', 2), SenseInfo('03264542-n', 1), SenseInfo('08565701-n', 28), SenseInfo('13903079-n', 5), SenseInfo('03264136-n', 5), SenseInfo('05171978-n', 2), SenseInfo('05158857-n', 2), SenseInfo('03264542-n', 1) ],
"_top-notch_a_1_rel" : [ SenseInfo('02341864-a', 1), SenseInfo('02341864-a', 1) ],
"_symbolist_n_1_rel" : [ SenseInfo('10685685-n', 1), SenseInfo('10685853-n', 0) ],
"_briton_n_1_rel" : [ SenseInfo('09700964-n', 0), SenseInfo('09688366-n', 0) ],
"_decomposition_n_of_rel" : [ SenseInfo('06013471-n', 8), SenseInfo('14561327-n', 3), SenseInfo('13458268-n', 0), SenseInfo('13458019-n', 0), SenseInfo('11444643-n', 0) ],
"_perforation_n_of_rel" : [ SenseInfo('03915900-n', 1), SenseInfo('09389867-n', 0), SenseInfo('00944633-n', 0) ],
"_by+no+means_a_1_rel" : [  ],
"_birthday_n_1_rel" : [ SenseInfo('15250178-n', 8), SenseInfo('15252422-n', 1) ],
"_suite_n_1_rel" : [ SenseInfo('07047011-n', 2), SenseInfo('04351550-n', 2), SenseInfo('08429167-n', 1), SenseInfo('08007534-n', 0) ],
"_like_v_back_rel" : [ SenseInfo('01824736-v', 76), SenseInfo('01777210-v', 73), SenseInfo('01776952-v', 19), SenseInfo('00691665-v', 2), SenseInfo('01825962-v', 1) ],
"_hinduism_n_1_rel" : [ SenseInfo('08096624-n', 0), SenseInfo('06236802-n', 0) ],
"_ignite_v_cause_rel" : [ SenseInfo('02759614-v', 2), SenseInfo('02760622-v', 1), SenseInfo('01761120-v', 1) ],
"_westerly_a_1_rel" : [ SenseInfo('00824753-a', 0), SenseInfo('00824509-a', 0), SenseInfo('00824753-a', 0), SenseInfo('00824509-a', 0) ],
"_pop-out_n_1_rel" : [  ],
"_pig-drunk_a_1_rel" : [  ],
"_overhaste_n_1_rel" : [  ],
"_deploy_v_as_rel" : [ SenseInfo('01149327-v', 2), SenseInfo('01379600-v', 0) ],
"_parliament_n_1_rel" : [ SenseInfo('08319198-n', 2), SenseInfo('00492497-n', 0) ],
"_forecast_v_1_rel" : [ SenseInfo('00926472-v', 5), SenseInfo('00712135-v', 2), SenseInfo('00871942-v', 1), SenseInfo('00926472-v', 5), SenseInfo('00712135-v', 2), SenseInfo('00871942-v', 1) ],
"_softball_n_1_rel" : [ SenseInfo('04256891-n', 0), SenseInfo('00475787-n', 0) ],
"_forage_v_1_rel" : [ SenseInfo('02269894-v', 0), SenseInfo('01177699-v', 0) ],
"_lie_n_1_rel" : [ SenseInfo('06756831-n', 13), SenseInfo('11131808-n', 0), SenseInfo('08624196-n', 0) ],
"_develop_v_into_rel" : [ SenseInfo('01738774-v', 44), SenseInfo('01738597-v', 44), SenseInfo('00545557-v', 41), SenseInfo('00094460-v', 19), SenseInfo('02624263-v', 15), SenseInfo('00171852-v', 12), SenseInfo('00925873-v', 6), SenseInfo('00603298-v', 5), SenseInfo('00342980-v', 4), SenseInfo('00252019-v', 4), SenseInfo('00411020-v', 3), SenseInfo('00253761-v', 3), SenseInfo('01627947-v', 1), SenseInfo('00543410-v', 1), SenseInfo('02138766-v', 0), SenseInfo('01469623-v', 0), SenseInfo('01074701-v', 0), SenseInfo('01074509-v', 0), SenseInfo('00402130-v', 0), SenseInfo('00339464-v', 0), SenseInfo('00234057-v', 0) ],
"_limousine_n_1_rel" : [ SenseInfo('03670208-n', 0) ],
"_service_n_1_rel" : [ SenseInfo('00577525-n', 24), SenseInfo('01209576-n', 8), SenseInfo('01032040-n', 5), SenseInfo('08186047-n', 4), SenseInfo('00584891-n', 3), SenseInfo('08198137-n', 2), SenseInfo('11293636-n', 0), SenseInfo('05149832-n', 0), SenseInfo('04175380-n', 0), SenseInfo('00853649-n', 0), SenseInfo('00579564-n', 0), SenseInfo('00568430-n', 0), SenseInfo('00318391-n', 0), SenseInfo('00268112-n', 0), SenseInfo('00098625-n', 0), SenseInfo('00577525-n', 24), SenseInfo('01209576-n', 8), SenseInfo('01032040-n', 5), SenseInfo('08186047-n', 4), SenseInfo('00584891-n', 3), SenseInfo('08198137-n', 2), SenseInfo('11293636-n', 0), SenseInfo('05149832-n', 0), SenseInfo('04175380-n', 0), SenseInfo('00853649-n', 0), SenseInfo('00579564-n', 0), SenseInfo('00568430-n', 0), SenseInfo('00318391-n', 0), SenseInfo('00268112-n', 0), SenseInfo('00098625-n', 0), SenseInfo('00577525-n', 24), SenseInfo('01209576-n', 8), SenseInfo('01032040-n', 5), SenseInfo('08186047-n', 4), SenseInfo('00584891-n', 3), SenseInfo('08198137-n', 2), SenseInfo('11293636-n', 0), SenseInfo('05149832-n', 0), SenseInfo('04175380-n', 0), SenseInfo('00853649-n', 0), SenseInfo('00579564-n', 0), SenseInfo('00568430-n', 0), SenseInfo('00318391-n', 0), SenseInfo('00268112-n', 0), SenseInfo('00098625-n', 0) ],
"_youth_n_1_rel" : [ SenseInfo('10804406-n', 323), SenseInfo('07944050-n', 10), SenseInfo('15147713-n', 5), SenseInfo('14425853-n', 2), SenseInfo('15266034-n', 1), SenseInfo('04928585-n', 1) ],
"_fiancee_n_1_rel" : [ SenseInfo('10085970-n', 0) ],
"_innate_a_1_rel" : [ SenseInfo('01637184-a', 0), SenseInfo('01335708-a', 0), SenseInfo('01315844-a', 0) ],
"_sixteenth_n_of_rel" : [ SenseInfo('13848466-n', 0), SenseInfo('13738585-n', 0), SenseInfo('13848466-n', 0), SenseInfo('13738585-n', 0), SenseInfo('13848466-n', 0), SenseInfo('13738585-n', 0) ],
"_close_v_cause_rel" : [ SenseInfo('01345109-v', 32), SenseInfo('01346978-v', 20), SenseInfo('02426395-v', 18), SenseInfo('02425913-v', 13), SenseInfo('02610628-v', 2), SenseInfo('00763831-v', 1), SenseInfo('02754276-v', 0), SenseInfo('02375619-v', 0), SenseInfo('02140781-v', 0), SenseInfo('02104503-v', 0), SenseInfo('02054541-v', 0), SenseInfo('02054382-v', 0), SenseInfo('01607288-v', 0), SenseInfo('01478423-v', 0), SenseInfo('01423285-v', 0), SenseInfo('01291941-v', 0), SenseInfo('00352137-v', 0) ],
"_off-Broadway_a_1_rel" : [  ],
"_base_v_1_rel" : [ SenseInfo('00636888-v', 75), SenseInfo('02756196-v', 0), SenseInfo('01200068-v', 0), SenseInfo('00636888-v', 75), SenseInfo('02756196-v', 0), SenseInfo('01200068-v', 0), SenseInfo('00636888-v', 75), SenseInfo('02756196-v', 0), SenseInfo('01200068-v', 0), SenseInfo('00636888-v', 75), SenseInfo('02756196-v', 0), SenseInfo('01200068-v', 0) ],
"_kiosk_n_1_rel" : [ SenseInfo('02873839-n', 0) ],
"_zoo_n_1_rel" : [ SenseInfo('03745146-n', 2) ],
"_bean_n_1_rel" : [ SenseInfo('07724943-n', 2), SenseInfo('13136316-n', 0), SenseInfo('12556307-n', 0), SenseInfo('05539454-n', 0) ],
"_temperature_n_of_rel" : [ SenseInfo('05011790-n', 91), SenseInfo('05725378-n', 1), SenseInfo('05011790-n', 91), SenseInfo('05725378-n', 1) ],
"_construction_n_of_rel" : [ SenseInfo('00911048-n', 25), SenseInfo('06313651-n', 5), SenseInfo('05771836-n', 2), SenseInfo('04341686-n', 1), SenseInfo('00873381-n', 1), SenseInfo('07173959-n', 0), SenseInfo('01104637-n', 0) ],
"_send_v_for_rel" : [ SenseInfo('01951480-v', 79), SenseInfo('01437254-v', 20), SenseInfo('01031256-v', 20), SenseInfo('01950798-v', 14), SenseInfo('01088923-v', 5), SenseInfo('01062555-v', 5), SenseInfo('02348568-v', 3), SenseInfo('00973056-v', 2) ],
"_go-cart_n_1_rel" : [ SenseInfo('04545305-n', 0), SenseInfo('03484083-n', 0), SenseInfo('02766534-n', 0), SenseInfo('04545305-n', 0), SenseInfo('03484083-n', 0), SenseInfo('02766534-n', 0) ],
"_grope_v_for_rel" : [ SenseInfo('01314738-v', 6), SenseInfo('02530936-v', 1), SenseInfo('01211263-v', 0) ],
"_obscure_v_1_rel" : [ SenseInfo('02157731-v', 3), SenseInfo('00620673-v', 2), SenseInfo('00313712-v', 2), SenseInfo('00587390-v', 0), SenseInfo('00313987-v', 0) ],
"_accuracy_n_1_rel" : [ SenseInfo('04802907-n', 7), SenseInfo('04803209-n', 2) ],
"_fall_v_in_rel" : [ SenseInfo('01972298-v', 43), SenseInfo('01970826-v', 21), SenseInfo('00147815-v', 16), SenseInfo('02729963-v', 6), SenseInfo('02756821-v', 4), SenseInfo('02528985-v', 4), SenseInfo('02620213-v', 3), SenseInfo('02611976-v', 3), SenseInfo('02304507-v', 3), SenseInfo('00342443-v', 3), SenseInfo('00151689-v', 3), SenseInfo('02565911-v', 2), SenseInfo('02385153-v', 2), SenseInfo('02358655-v', 2), SenseInfo('02099413-v', 1), SenseInfo('02661015-v', 0), SenseInfo('02566092-v', 0), SenseInfo('02358922-v', 0), SenseInfo('02230056-v', 0), SenseInfo('02229828-v', 0), SenseInfo('02229550-v', 0), SenseInfo('02037839-v', 0), SenseInfo('01984317-v', 0), SenseInfo('01984119-v', 0), SenseInfo('01542668-v', 0), SenseInfo('00561375-v', 0), SenseInfo('00561266-v', 0), SenseInfo('00530177-v', 0), SenseInfo('00360678-v', 0), SenseInfo('00346839-v', 0), SenseInfo('00342314-v', 0), SenseInfo('00342164-v', 0) ],
"_operate_v_1_rel" : [ SenseInfo('02443849-v', 34), SenseInfo('01525666-v', 29), SenseInfo('01224744-v', 14), SenseInfo('01109863-v', 3), SenseInfo('00341285-v', 2), SenseInfo('01510827-v', 0), SenseInfo('00083809-v', 0) ],
"_riches_n_1_rel" : [ SenseInfo('13353280-n', 0), SenseInfo('13353280-n', 0) ],
"_wipe_n_1_rel" : [ SenseInfo('00125126-n', 0) ],
"_fess_v_up_rel" : [  ],
"_account_v_for_rel" : [ SenseInfo('02607432-v', 0), SenseInfo('02265231-v', 0), SenseInfo('00965035-v', 0), SenseInfo('00867644-v', 0) ],
"_by_p_rel" : [ SenseInfo('00417787-r', 2), SenseInfo('00233687-r', 0), SenseInfo('00417787-r', 2), SenseInfo('00233687-r', 0), SenseInfo('00417787-r', 2), SenseInfo('00233687-r', 0) ],
"_corpse_n_1_rel" : [ SenseInfo('05218119-n', 22) ],
"_putt_n_1_rel" : [ SenseInfo('00572838-n', 0) ],
"_cairn_n_1_rel" : [ SenseInfo('07273802-n', 0), SenseInfo('02096177-n', 0) ],
"_inconsistent_a_1_rel" : [ SenseInfo('00577920-a', 1), SenseInfo('01987207-a', 1), SenseInfo('00562803-a', 0) ],
"_winnow_v_out_rel" : [ SenseInfo('01460937-v', 1), SenseInfo('01885708-v', 0), SenseInfo('00677203-v', 0), SenseInfo('00177984-v', 0) ],
"_overt_a_1_rel" : [ SenseInfo('01704761-a', 1), SenseInfo('01704761-a', 1) ],
"_powder_v_1_rel" : [ SenseInfo('00332154-v', 0), SenseInfo('00042173-v', 0) ],
"_canoe_n_1_rel" : [ SenseInfo('02951358-n', 0) ],
"_so_a_also_rel" : [ SenseInfo('06868844-n', 0) ],
"_detour_n_1_rel" : [ SenseInfo('03182506-n', 0) ],
"_flatten_v_cause_rel" : [ SenseInfo('00463778-v', 6), SenseInfo('00463469-v', 1), SenseInfo('00393534-v', 0) ],
"_premature_a_1_rel" : [ SenseInfo('01495535-a', 0), SenseInfo('00815227-a', 0), SenseInfo('00815000-a', 0) ],
"_wake-up_n_1_rel" : [  ],
"_upwards_a_1_rel" : [  ],
"_libel_n_1_rel" : [ SenseInfo('06720371-n', 0), SenseInfo('06562436-n', 0) ],
"_tackle_n_1_rel" : [ SenseInfo('10688070-n', 1), SenseInfo('04091693-n', 0), SenseInfo('03351434-n', 0), SenseInfo('00727901-n', 0), SenseInfo('00561985-n', 0) ],
"_deliverance_n_1_rel" : [ SenseInfo('00093483-n', 1) ],
"_liberal_a_1_rel" : [ SenseInfo('00286837-a', 6), SenseInfo('02031473-a', 4), SenseInfo('00575230-a', 3), SenseInfo('01111418-a', 3), SenseInfo('00916199-a', 0), SenseInfo('00286837-a', 6), SenseInfo('02031473-a', 4), SenseInfo('00575230-a', 3), SenseInfo('01111418-a', 3), SenseInfo('00916199-a', 0) ],
"_recycle_v_1_rel" : [ SenseInfo('02052877-v', 0), SenseInfo('01162425-v', 0) ],
"_present-day_a_1_rel" : [ SenseInfo('00667079-a', 8), SenseInfo('00667079-a', 8) ],
"_corinthian_n_1_rel" : [ SenseInfo('10439727-n', 0), SenseInfo('09711320-n', 0) ],
"_outgrowth_n_1_rel" : [ SenseInfo('11415721-n', 0), SenseInfo('07324673-n', 0), SenseInfo('05470189-n', 0) ],
"_quiet_v_1_rel" : [ SenseInfo('02190188-v', 1), SenseInfo('01764800-v', 1) ],
"_dampness_n_1_rel" : [ SenseInfo('14535905-n', 0) ],
"_upraised_a_1_rel" : [ SenseInfo('01208221-a', 2) ],
"_for+sure_a_1_rel" : [ SenseInfo('01918660-a', 1), SenseInfo('01918660-a', 1), SenseInfo('01918660-a', 1), SenseInfo('01918660-a', 1) ],
"_squirt_n_1_rel" : [ SenseInfo('10435251-n', 0), SenseInfo('07436100-n', 0) ],
"_queue_n_1_rel" : [ SenseInfo('08432345-n', 0), SenseInfo('06494816-n', 0), SenseInfo('05259823-n', 0) ],
"_glare_v_at_rel" : [ SenseInfo('00033203-v', 9), SenseInfo('02765090-v', 0), SenseInfo('02162672-v', 0) ],
"_abet_v_1_rel" : [ SenseInfo('02549211-v', 3) ],
"_appoint_v_as_rel" : [ SenseInfo('02396205-v', 13), SenseInfo('02475922-v', 8), SenseInfo('02341370-v', 0) ],
"_amusement_n_1_rel" : [ SenseInfo('07491476-n', 3), SenseInfo('00429048-n', 1) ],
"_ooh_a_1_rel" : [  ],
"_nap_v_1_rel" : [ SenseInfo('00015498-v', 0) ],
"_digs_n_1_rel" : [ SenseInfo('08550076-n', 0), SenseInfo('06767922-n', 0), SenseInfo('04693557-n', 0), SenseInfo('00941974-n', 0), SenseInfo('00135311-n', 0), SenseInfo('08550076-n', 0), SenseInfo('06767922-n', 0), SenseInfo('04693557-n', 0), SenseInfo('00941974-n', 0), SenseInfo('00135311-n', 0) ],
"_gun_v_1_rel" : [ SenseInfo('01136614-v', 0) ],
"_automatic_n_1_rel" : [ SenseInfo('02760855-n', 0), SenseInfo('02760658-n', 0) ],
"_eminently_x_deg_rel" : [ SenseInfo('00328378-r', 1) ],
"_elitist_a_1_rel" : [ SenseInfo('10050558-n', 0) ],
"_upstanding_a_1_rel" : [ SenseInfo('01993693-a', 0) ],
"_khaki_a_1_rel" : [ SenseInfo('00376821-a', 1) ],
"_testamentary_a_1_rel" : [ SenseInfo('02812838-a', 0) ],
"_spread_v_1_rel" : [ SenseInfo('01378556-v', 24), SenseInfo('01380122-v', 6), SenseInfo('02689299-v', 5), SenseInfo('01579813-v', 5), SenseInfo('00968211-v', 5), SenseInfo('00969873-v', 4), SenseInfo('02082690-v', 3), SenseInfo('02060141-v', 3), SenseInfo('01611901-v', 0), SenseInfo('01611746-v', 0), SenseInfo('01378556-v', 24), SenseInfo('01380122-v', 6), SenseInfo('02689299-v', 5), SenseInfo('01579813-v', 5), SenseInfo('00968211-v', 5), SenseInfo('00969873-v', 4), SenseInfo('02082690-v', 3), SenseInfo('02060141-v', 3), SenseInfo('01611901-v', 0), SenseInfo('01611746-v', 0) ],
"_wicked_a_1_rel" : [ SenseInfo('02513740-a', 2), SenseInfo('02037531-a', 1), SenseInfo('01513050-a', 1), SenseInfo('02122715-a', 0), SenseInfo('01625893-a', 0) ],
"_amalgamate_v_1_rel" : [ SenseInfo('01462005-v', 0) ],
"_condense_v_cause_rel" : [ SenseInfo('00364868-v', 2), SenseInfo('00244625-v', 1), SenseInfo('00366547-v', 0), SenseInfo('00366275-v', 0), SenseInfo('00365647-v', 0), SenseInfo('00365446-v', 0), SenseInfo('00365188-v', 0) ],
"_employed_n_1_rel" : [ SenseInfo('00863946-a', 1), SenseInfo('00942806-a', 0) ],
"_book_v_into_rel" : [ SenseInfo('00678777-v', 3), SenseInfo('02498320-v', 1), SenseInfo('02498136-v', 1), SenseInfo('02599754-v', 0) ],
"_involved_a_1_rel" : [ SenseInfo('01514827-a', 23), SenseInfo('00868603-a', 3), SenseInfo('00158332-a', 1), SenseInfo('02176841-a', 0), SenseInfo('01658386-a', 0) ],
"_snapshot_n_1_rel" : [ SenseInfo('04248607-n', 1) ],
"_balm_n_1_rel" : [ SenseInfo('14896923-n', 0), SenseInfo('03845550-n', 0) ],
"_timber_n_1_rel" : [ SenseInfo('14943580-n', 3), SenseInfo('04436185-n', 2), SenseInfo('04436329-n', 1), SenseInfo('09284015-n', 0), SenseInfo('04987620-n', 0) ],
"_sender_n_of_rel" : [ SenseInfo('10578762-n', 0), SenseInfo('04472726-n', 0) ],
"_pari-mutuel_a_1_rel" : [  ],
"_override_n_1_rel" : [ SenseInfo('03865820-n', 0), SenseInfo('00231567-n', 0) ],
"_abide_v_by_rel" : [ SenseInfo('02637202-v', 2), SenseInfo('00668099-v', 1) ],
"_fake_v_out_rel" : [ SenseInfo('01654271-v', 1), SenseInfo('02576921-v', 0), SenseInfo('00839526-v', 0) ],
"_rock+hop_v_1_rel" : [  ],
"_inter_v_1_rel" : [ SenseInfo('02456493-v', 1) ],
"_sapling_n_1_rel" : [ SenseInfo('13108481-n', 1) ],
"_unflattering_a_for_rel" : [ SenseInfo('00908315-a', 0), SenseInfo('00908315-a', 0), SenseInfo('00908315-a', 0), SenseInfo('00908315-a', 0), SenseInfo('00908315-a', 0), SenseInfo('00908315-a', 0) ],
"_sunbath_n_1_rel" : [  ],
"_inconvenience_v_1_rel" : [ SenseInfo('02507736-v', 0) ],
"_emanation_n_1_rel" : [ SenseInfo('15109745-n', 1), SenseInfo('01253060-n', 1), SenseInfo('07327288-n', 0) ],
"_twinge_n_1_rel" : [ SenseInfo('07494972-n', 2), SenseInfo('05725269-n', 0) ],
"_fresh_a_1_rel" : [ SenseInfo('01067694-a', 16), SenseInfo('01641648-a', 5), SenseInfo('01357027-a', 4), SenseInfo('01687167-a', 3), SenseInfo('01071198-a', 2), SenseInfo('01073707-a', 0), SenseInfo('02554420-a', 0), SenseInfo('02434797-a', 0), SenseInfo('02370083-a', 0), SenseInfo('01906320-a', 0), SenseInfo('00418198-a', 0), SenseInfo('00205295-a', 0), SenseInfo('01067694-a', 16), SenseInfo('01641648-a', 5), SenseInfo('01357027-a', 4), SenseInfo('01687167-a', 3), SenseInfo('01071198-a', 2), SenseInfo('01073707-a', 0), SenseInfo('02554420-a', 0), SenseInfo('02434797-a', 0), SenseInfo('02370083-a', 0), SenseInfo('01906320-a', 0), SenseInfo('00418198-a', 0), SenseInfo('00205295-a', 0), SenseInfo('01067694-a', 16), SenseInfo('01641648-a', 5), SenseInfo('01357027-a', 4), SenseInfo('01687167-a', 3), SenseInfo('01071198-a', 2), SenseInfo('01073707-a', 0), SenseInfo('02554420-a', 0), SenseInfo('02434797-a', 0), SenseInfo('02370083-a', 0), SenseInfo('01906320-a', 0), SenseInfo('00418198-a', 0), SenseInfo('00205295-a', 0), SenseInfo('01067694-a', 16), SenseInfo('01641648-a', 5), SenseInfo('01357027-a', 4), SenseInfo('01687167-a', 3), SenseInfo('01071198-a', 2), SenseInfo('01073707-a', 0), SenseInfo('02554420-a', 0), SenseInfo('02434797-a', 0), SenseInfo('02370083-a', 0), SenseInfo('01906320-a', 0), SenseInfo('00418198-a', 0), SenseInfo('00205295-a', 0) ],
"_exceptionally_x_deg_rel" : [ SenseInfo('00178793-r', 2) ],
"_!=_v_1_rel" : [  ],
"_stand_v_up_rel" : [ SenseInfo('01546111-v', 169), SenseInfo('02611373-v', 53), SenseInfo('02734488-v', 38), SenseInfo('02702120-v', 18), SenseInfo('00668099-v', 9), SenseInfo('00670991-v', 8), SenseInfo('02707125-v', 5), SenseInfo('02703018-v', 3), SenseInfo('02702368-v', 2), SenseInfo('01546768-v', 1), SenseInfo('01115916-v', 1), SenseInfo('01428203-v', 0), SenseInfo('01546111-v', 169), SenseInfo('02611373-v', 53), SenseInfo('02734488-v', 38), SenseInfo('02702120-v', 18), SenseInfo('00668099-v', 9), SenseInfo('00670991-v', 8), SenseInfo('02707125-v', 5), SenseInfo('02703018-v', 3), SenseInfo('02702368-v', 2), SenseInfo('01546768-v', 1), SenseInfo('01115916-v', 1), SenseInfo('01428203-v', 0) ],
"_clamp_n_1_rel" : [ SenseInfo('03036866-n', 0) ],
"_proclaim_v_as_rel" : [ SenseInfo('00978173-v', 13), SenseInfo('00977336-v', 10), SenseInfo('01017001-v', 3), SenseInfo('00860620-v', 1), SenseInfo('00978173-v', 13), SenseInfo('00977336-v', 10), SenseInfo('01017001-v', 3), SenseInfo('00860620-v', 1), SenseInfo('00978173-v', 13), SenseInfo('00977336-v', 10), SenseInfo('01017001-v', 3), SenseInfo('00860620-v', 1), SenseInfo('00978173-v', 13), SenseInfo('00977336-v', 10), SenseInfo('01017001-v', 3), SenseInfo('00860620-v', 1) ],
"_deepen_v_1_rel" : [ SenseInfo('00227165-v', 1), SenseInfo('00226566-v', 1), SenseInfo('00570524-v', 0), SenseInfo('00551210-v', 0) ],
"_stitch_n_1_rel" : [ SenseInfo('04321238-n', 1), SenseInfo('14332339-n', 0) ],
"_theoretical_a_1_rel" : [ SenseInfo('00860611-a', 8), SenseInfo('00862327-a', 0), SenseInfo('00860611-a', 8), SenseInfo('00862327-a', 0) ],
"_ticket_v_1_rel" : [ SenseInfo('02498716-v', 0), SenseInfo('02329413-v', 0) ],
"_swoop_v_up_rel" : [ SenseInfo('02064358-v', 8), SenseInfo('02064759-v', 0), SenseInfo('01440010-v', 0) ],
"_misnomer_n_1_rel" : [ SenseInfo('06338485-n', 1) ],
"_steam_n_1_rel" : [ SenseInfo('15055181-n', 0) ],
"_tackle_v_1_rel" : [ SenseInfo('02569630-v', 3), SenseInfo('01491697-v', 0), SenseInfo('01150164-v', 0) ],
"_firm_v_cause_rel" : [ SenseInfo('00420549-v', 0), SenseInfo('00420434-v', 0) ],
"_liver_n_1_rel" : [ SenseInfo('05385534-n', 11), SenseInfo('07652052-n', 1), SenseInfo('10268299-n', 0), SenseInfo('10268180-n', 0) ],
"_ranger_n_1_rel" : [ SenseInfo('10704712-n', 0), SenseInfo('10092098-n', 0), SenseInfo('09942275-n', 0) ],
"_shirtwaist_n_1_rel" : [ SenseInfo('04198562-n', 0) ],
"_disadvantage_v_1_rel" : [ SenseInfo('02513460-v', 0) ],
"_dwarf_v_1_rel" : [ SenseInfo('02696306-v', 3), SenseInfo('02452614-v', 0) ],
"_until_p_1_rel" : [  ],
"_recruitment_n_of_rel" : [ SenseInfo('01263711-n', 6) ],
"_obeisance_n_1_rel" : [ SenseInfo('07274425-n', 0), SenseInfo('01167146-n', 0) ],
"_keep_v_from_rel" : [ SenseInfo('02681795-v', 206), SenseInfo('02684924-v', 39), SenseInfo('02202384-v', 32), SenseInfo('02450505-v', 22), SenseInfo('02578872-v', 10), SenseInfo('00732552-v', 9), SenseInfo('02202928-v', 8), SenseInfo('01065877-v', 4), SenseInfo('02651853-v', 3), SenseInfo('02410175-v', 3), SenseInfo('01184625-v', 3), SenseInfo('02734800-v', 2), SenseInfo('02578510-v', 2), SenseInfo('02422663-v', 2), SenseInfo('02733122-v', 1), SenseInfo('02652016-v', 0), SenseInfo('02283716-v', 0), SenseInfo('02204094-v', 0), SenseInfo('02203844-v', 0), SenseInfo('02203168-v', 0), SenseInfo('01302019-v', 0), SenseInfo('00212414-v', 0) ],
"_prolong_v_1_rel" : [ SenseInfo('00317888-v', 3), SenseInfo('02679530-v', 0) ],
"_maybe_x_deg_rel" : [ SenseInfo('00300247-r', 57) ],
"_applesauce_n_1_rel" : [ SenseInfo('07825850-n', 0), SenseInfo('06611998-n', 0) ],
"_degree_n_of_rel" : [ SenseInfo('05093890-n', 25), SenseInfo('13939892-n', 17), SenseInfo('06697331-n', 13), SenseInfo('13611207-n', 7), SenseInfo('05861317-n', 6), SenseInfo('13714184-n', 1), SenseInfo('05094565-n', 0), SenseInfo('05093890-n', 25), SenseInfo('13939892-n', 17), SenseInfo('06697331-n', 13), SenseInfo('13611207-n', 7), SenseInfo('05861317-n', 6), SenseInfo('13714184-n', 1), SenseInfo('05094565-n', 0), SenseInfo('05093890-n', 25), SenseInfo('13939892-n', 17), SenseInfo('06697331-n', 13), SenseInfo('13611207-n', 7), SenseInfo('05861317-n', 6), SenseInfo('13714184-n', 1), SenseInfo('05094565-n', 0), SenseInfo('05093890-n', 25), SenseInfo('13939892-n', 17), SenseInfo('06697331-n', 13), SenseInfo('13611207-n', 7), SenseInfo('05861317-n', 6), SenseInfo('13714184-n', 1), SenseInfo('05094565-n', 0) ],
"_climb_v_1_rel" : [ SenseInfo('01921964-v', 36), SenseInfo('01923909-v', 2), SenseInfo('00433232-v', 2), SenseInfo('02037989-v', 0), SenseInfo('00249017-v', 0), SenseInfo('00155143-v', 0), SenseInfo('01921964-v', 36), SenseInfo('01923909-v', 2), SenseInfo('00433232-v', 2), SenseInfo('02037989-v', 0), SenseInfo('00249017-v', 0), SenseInfo('00155143-v', 0) ],
"_hit_v_up_rel" : [ SenseInfo('01405044-v', 25), SenseInfo('01236164-v', 21), SenseInfo('01400044-v', 18), SenseInfo('02020590-v', 9), SenseInfo('01209135-v', 8), SenseInfo('01137138-v', 8), SenseInfo('02206462-v', 3), SenseInfo('01111816-v', 3), SenseInfo('02108791-v', 2), SenseInfo('01123887-v', 2), SenseInfo('02482425-v', 0), SenseInfo('02104161-v', 0), SenseInfo('02006834-v', 0), SenseInfo('01209426-v', 0), SenseInfo('01157421-v', 0), SenseInfo('01152396-v', 0), SenseInfo('00781903-v', 0) ],
"_pesky_a_1_rel" : [ SenseInfo('00089550-a', 0) ],
"_false_a_1_rel" : [ SenseInfo('02461723-a', 9), SenseInfo('00633235-a', 1), SenseInfo('02500379-a', 0), SenseInfo('02182088-a', 0), SenseInfo('01942507-a', 0), SenseInfo('01573238-a', 0), SenseInfo('01224650-a', 0), SenseInfo('01164420-a', 0), SenseInfo('01116857-a', 0), SenseInfo('00584403-a', 0) ],
"_pop_v_out_rel" : [ SenseInfo('02081946-v', 3), SenseInfo('01404913-v', 3), SenseInfo('02185988-v', 1), SenseInfo('01134071-v', 1), SenseInfo('02186192-v', 0), SenseInfo('02157519-v', 0), SenseInfo('01499510-v', 0), SenseInfo('01474980-v', 0), SenseInfo('01401005-v', 0), SenseInfo('01202374-v', 0), SenseInfo('01199487-v', 0), SenseInfo('00309792-v', 0), SenseInfo('00309582-v', 0), SenseInfo('02081946-v', 3), SenseInfo('01404913-v', 3), SenseInfo('02185988-v', 1), SenseInfo('01134071-v', 1), SenseInfo('02186192-v', 0), SenseInfo('02157519-v', 0), SenseInfo('01499510-v', 0), SenseInfo('01474980-v', 0), SenseInfo('01401005-v', 0), SenseInfo('01202374-v', 0), SenseInfo('01199487-v', 0), SenseInfo('00309792-v', 0), SenseInfo('00309582-v', 0) ],
"_acknowledge_v_as_rel" : [ SenseInfo('00817311-v', 5), SenseInfo('00892698-v', 3), SenseInfo('01059123-v', 2), SenseInfo('00892467-v', 1), SenseInfo('00740449-v', 0), SenseInfo('00592883-v', 0), SenseInfo('00817311-v', 5), SenseInfo('00892698-v', 3), SenseInfo('01059123-v', 2), SenseInfo('00892467-v', 1), SenseInfo('00740449-v', 0), SenseInfo('00592883-v', 0) ],
"_adaptation_n_of_rel" : [ SenseInfo('06408779-n', 1), SenseInfo('13427078-n', 0), SenseInfo('00193406-n', 0) ],
"_merrymaking_n_1_rel" : [ SenseInfo('00509846-n', 1) ],
"_inside_n_of_rel" : [ SenseInfo('08588294-n', 4), SenseInfo('08588152-n', 4) ],
"_self-reference_n_1_rel" : [  ],
"_reward_n_1_rel" : [ SenseInfo('07295629-n', 4), SenseInfo('13283764-n', 2), SenseInfo('01219551-n', 2), SenseInfo('07166281-n', 1), SenseInfo('05142863-n', 0) ],
"_suburb_n_1_rel" : [ SenseInfo('08554440-n', 16) ],
"_prayer_n_1_rel" : [ SenseInfo('01041968-n', 5), SenseInfo('07189130-n', 4), SenseInfo('07186828-n', 2), SenseInfo('06455990-n', 1), SenseInfo('10464052-n', 0), SenseInfo('01041968-n', 5), SenseInfo('07189130-n', 4), SenseInfo('07186828-n', 2), SenseInfo('06455990-n', 1), SenseInfo('10464052-n', 0) ],
"_dive_n_1_rel" : [ SenseInfo('03530803-n', 4), SenseInfo('00442981-n', 1), SenseInfo('00326677-n', 0) ],
"_voluntary_a_1_rel" : [ SenseInfo('02520219-a', 1), SenseInfo('02522267-a', 0), SenseInfo('02520219-a', 1), SenseInfo('02522267-a', 0) ],
"_cry_n_1_rel" : [ SenseInfo('07120524-n', 13), SenseInfo('07121157-n', 10), SenseInfo('07152752-n', 1), SenseInfo('07014752-n', 1), SenseInfo('07382572-n', 0) ],
"_countenance_v_1_rel" : [ SenseInfo('00802318-v', 0) ],
"_snack_v_1_rel" : [ SenseInfo('01173405-v', 0) ],
"_satisfaction_n_of_rel" : [ SenseInfo('07531255-n', 10), SenseInfo('13986679-n', 4), SenseInfo('13292787-n', 1), SenseInfo('13349997-n', 0), SenseInfo('01072565-n', 0) ],
"_snicker_n_1_rel" : [ SenseInfo('07128060-n', 0) ],
"_narrowness_n_1_rel" : [ SenseInfo('05136788-n', 1), SenseInfo('06205411-n', 0), SenseInfo('05846626-n', 0), SenseInfo('05121095-n', 0) ],
"_uncompromising_a_1_rel" : [ SenseInfo('01025913-a', 1), SenseInfo('01025913-a', 1) ],
"_ach_a_1_rel" : [  ],
"_lumberjack_n_1_rel" : [ SenseInfo('10276045-n', 0), SenseInfo('03696909-n', 0) ],
"_buttress_v_1_rel" : [ SenseInfo('00222861-v', 0), SenseInfo('00222728-v', 0) ],
"_thumbs+up_n_1_rel" : [  ],
"_set_v_off_rel" : [ SenseInfo('01494310-v', 30), SenseInfo('00699815-v', 29), SenseInfo('00947077-v', 12), SenseInfo('01062395-v', 10), SenseInfo('00298896-v', 9), SenseInfo('01607445-v', 6), SenseInfo('00406243-v', 5), SenseInfo('00298556-v', 5), SenseInfo('01711749-v', 3), SenseInfo('01970646-v', 2), SenseInfo('01706129-v', 2), SenseInfo('01567275-v', 2), SenseInfo('01628899-v', 1), SenseInfo('00442669-v', 1), SenseInfo('01744888-v', 0), SenseInfo('01613239-v', 0), SenseInfo('01530273-v', 0), SenseInfo('01247322-v', 0), SenseInfo('01115006-v', 0), SenseInfo('00673448-v', 0), SenseInfo('00408085-v', 0), SenseInfo('00407848-v', 0), SenseInfo('00296178-v', 0), SenseInfo('00056188-v', 0), SenseInfo('00038849-v', 0), SenseInfo('01494310-v', 30), SenseInfo('00699815-v', 29), SenseInfo('00947077-v', 12), SenseInfo('01062395-v', 10), SenseInfo('00298896-v', 9), SenseInfo('01607445-v', 6), SenseInfo('00406243-v', 5), SenseInfo('00298556-v', 5), SenseInfo('01711749-v', 3), SenseInfo('01970646-v', 2), SenseInfo('01706129-v', 2), SenseInfo('01567275-v', 2), SenseInfo('01628899-v', 1), SenseInfo('00442669-v', 1), SenseInfo('01744888-v', 0), SenseInfo('01613239-v', 0), SenseInfo('01530273-v', 0), SenseInfo('01247322-v', 0), SenseInfo('01115006-v', 0), SenseInfo('00673448-v', 0), SenseInfo('00408085-v', 0), SenseInfo('00407848-v', 0), SenseInfo('00296178-v', 0), SenseInfo('00056188-v', 0), SenseInfo('00038849-v', 0) ],
"_bootlegging_n_1_rel" : [ SenseInfo('00092663-n', 1), SenseInfo('00092847-n', 0) ],
"_subscribe_v_1_rel" : [ SenseInfo('02299110-v', 2), SenseInfo('00996485-v', 1), SenseInfo('00806314-v', 1), SenseInfo('02299269-v', 0), SenseInfo('02209745-v', 0) ],
"_mesial_a_1_rel" : [ SenseInfo('00778958-a', 0) ],
"_eternity_n_1_rel" : [ SenseInfo('15243976-n', 3), SenseInfo('13956905-n', 2), SenseInfo('15273406-n', 1) ],
"_occasion_v_1_rel" : [ SenseInfo('01646528-v', 3) ],
"comp_less_rel" : [  ],
"_refrain_v_from_rel" : [ SenseInfo('02725714-v', 1), SenseInfo('01196037-v', 0), SenseInfo('02725714-v', 1), SenseInfo('01196037-v', 0), SenseInfo('02725714-v', 1), SenseInfo('01196037-v', 0) ],
"_beloved_a_1_rel" : [ SenseInfo('01462324-a', 7) ],
"_so+as+to_x_rel" : [  ],
"_throw_v_down_rel" : [ SenseInfo('01508368-v', 53), SenseInfo('02097204-v', 9), SenseInfo('01513430-v', 7), SenseInfo('01499265-v', 7), SenseInfo('01060317-v', 6), SenseInfo('01510173-v', 5), SenseInfo('01632897-v', 4), SenseInfo('02097341-v', 2), SenseInfo('01791232-v', 2), SenseInfo('01067664-v', 2), SenseInfo('01733477-v', 1), SenseInfo('01663443-v', 0), SenseInfo('01527754-v', 0), SenseInfo('01437011-v', 0), SenseInfo('00621734-v', 0) ],
"_frau_n_1_rel" : [ SenseInfo('06340707-n', 0) ],
"_cancelled_a_1_rel" : [ SenseInfo('01651896-a', 0) ],
"_hutment_n_1_rel" : [ SenseInfo('03550420-n', 2) ],
"_dreadful_a_to_rel" : [ SenseInfo('00193799-a', 6), SenseInfo('01126291-a', 1), SenseInfo('01803247-a', 0), SenseInfo('00193799-a', 6), SenseInfo('01126291-a', 1), SenseInfo('01803247-a', 0), SenseInfo('00193799-a', 6), SenseInfo('01126291-a', 1), SenseInfo('01803247-a', 0) ],
"_transplant_v_1_rel" : [ SenseInfo('01855155-v', 3), SenseInfo('02753255-v', 0), SenseInfo('01530431-v', 0), SenseInfo('00555240-v', 0), SenseInfo('01855155-v', 3), SenseInfo('02753255-v', 0), SenseInfo('01530431-v', 0), SenseInfo('00555240-v', 0) ],
"_angler_n_1_rel" : [ SenseInfo('09794081-n', 0), SenseInfo('09793946-n', 0), SenseInfo('02548247-n', 0) ],
"_stabilize_v_cause_rel" : [ SenseInfo('00270826-v', 2), SenseInfo('01219993-v', 0), SenseInfo('00271946-v', 0), SenseInfo('00270826-v', 2), SenseInfo('01219993-v', 0), SenseInfo('00271946-v', 0), SenseInfo('00270826-v', 2), SenseInfo('01219993-v', 0), SenseInfo('00271946-v', 0) ],
"_menagerie_n_1_rel" : [ SenseInfo('08456888-n', 0), SenseInfo('03745146-n', 0) ],
"_catch_n_1_rel" : [ SenseInfo('05164673-n', 1), SenseInfo('13755822-n', 0), SenseInfo('09900981-n', 0), SenseInfo('09238143-n', 0), SenseInfo('07067760-n', 0), SenseInfo('02982790-n', 0), SenseInfo('02982599-n', 0), SenseInfo('00458641-n', 0), SenseInfo('00138956-n', 0), SenseInfo('00088725-n', 0) ],
"_lop_v_off_rel" : [ SenseInfo('01560731-v', 0), SenseInfo('01321002-v', 0) ],
"_iraqi_n_1_rel" : [ SenseInfo('09714694-n', 0) ],
"_hopeless_a_1_rel" : [ SenseInfo('01229020-a', 3), SenseInfo('02229812-a', 0), SenseInfo('01823475-a', 0), SenseInfo('01127440-a', 0), SenseInfo('01229020-a', 3), SenseInfo('02229812-a', 0), SenseInfo('01823475-a', 0), SenseInfo('01127440-a', 0) ],
"_mock_a_1_rel" : [ SenseInfo('01117823-a', 2) ],
"_rape_n_1_rel" : [ SenseInfo('11879722-n', 0), SenseInfo('00966384-n', 0), SenseInfo('00773402-n', 0) ],
"_break_v_1_rel" : [ SenseInfo('00364064-v', 15), SenseInfo('00334186-v', 13), SenseInfo('00258665-v', 9), SenseInfo('01369758-v', 8), SenseInfo('00334996-v', 8), SenseInfo('02566528-v', 5), SenseInfo('02073233-v', 4), SenseInfo('02029369-v', 4), SenseInfo('01785395-v', 4), SenseInfo('00362348-v', 4), SenseInfo('02570684-v', 3), SenseInfo('00202569-v', 3), SenseInfo('02668523-v', 2), SenseInfo('01106864-v', 2), SenseInfo('00933821-v', 2), SenseInfo('00558536-v', 2), SenseInfo('00434374-v', 2), SenseInfo('02535716-v', 1), SenseInfo('02030764-v', 1), SenseInfo('01972976-v', 1), SenseInfo('00390215-v', 1), SenseInfo('00202784-v', 1), SenseInfo('02746617-v', 0), SenseInfo('02746449-v', 0), SenseInfo('02681639-v', 0), SenseInfo('02681524-v', 0), SenseInfo('02625187-v', 0), SenseInfo('02600082-v', 0), SenseInfo('02559395-v', 0), SenseInfo('02478469-v', 0), SenseInfo('02431320-v', 0), SenseInfo('02399331-v', 0), SenseInfo('02318165-v', 0), SenseInfo('02101373-v', 0), SenseInfo('01991347-v', 0), SenseInfo('01989053-v', 0), SenseInfo('01896484-v', 0), SenseInfo('01610666-v', 0), SenseInfo('01610463-v', 0), SenseInfo('01597995-v', 0), SenseInfo('01557646-v', 0), SenseInfo('01369346-v', 0), SenseInfo('01298931-v', 0), SenseInfo('01228524-v', 0), SenseInfo('01228396-v', 0), SenseInfo('00935987-v', 0), SenseInfo('00779061-v', 0), SenseInfo('00778745-v', 0), SenseInfo('00744439-v', 0), SenseInfo('00738440-v', 0), SenseInfo('00738314-v', 0), SenseInfo('00551412-v', 0), SenseInfo('00339464-v', 0), SenseInfo('00336260-v', 0), SenseInfo('00258366-v', 0), SenseInfo('00155046-v', 0), SenseInfo('00107739-v', 0), SenseInfo('00107604-v', 0), SenseInfo('00030463-v', 0), SenseInfo('00364064-v', 15), SenseInfo('00334186-v', 13), SenseInfo('00258665-v', 9), SenseInfo('01369758-v', 8), SenseInfo('00334996-v', 8), SenseInfo('02566528-v', 5), SenseInfo('02073233-v', 4), SenseInfo('02029369-v', 4), SenseInfo('01785395-v', 4), SenseInfo('00362348-v', 4), SenseInfo('02570684-v', 3), SenseInfo('00202569-v', 3), SenseInfo('02668523-v', 2), SenseInfo('01106864-v', 2), SenseInfo('00933821-v', 2), SenseInfo('00558536-v', 2), SenseInfo('00434374-v', 2), SenseInfo('02535716-v', 1), SenseInfo('02030764-v', 1), SenseInfo('01972976-v', 1), SenseInfo('00390215-v', 1), SenseInfo('00202784-v', 1), SenseInfo('02746617-v', 0), SenseInfo('02746449-v', 0), SenseInfo('02681639-v', 0), SenseInfo('02681524-v', 0), SenseInfo('02625187-v', 0), SenseInfo('02600082-v', 0), SenseInfo('02559395-v', 0), SenseInfo('02478469-v', 0), SenseInfo('02431320-v', 0), SenseInfo('02399331-v', 0), SenseInfo('02318165-v', 0), SenseInfo('02101373-v', 0), SenseInfo('01991347-v', 0), SenseInfo('01989053-v', 0), SenseInfo('01896484-v', 0), SenseInfo('01610666-v', 0), SenseInfo('01610463-v', 0), SenseInfo('01597995-v', 0), SenseInfo('01557646-v', 0), SenseInfo('01369346-v', 0), SenseInfo('01298931-v', 0), SenseInfo('01228524-v', 0), SenseInfo('01228396-v', 0), SenseInfo('00935987-v', 0), SenseInfo('00779061-v', 0), SenseInfo('00778745-v', 0), SenseInfo('00744439-v', 0), SenseInfo('00738440-v', 0), SenseInfo('00738314-v', 0), SenseInfo('00551412-v', 0), SenseInfo('00339464-v', 0), SenseInfo('00336260-v', 0), SenseInfo('00258366-v', 0), SenseInfo('00155046-v', 0), SenseInfo('00107739-v', 0), SenseInfo('00107604-v', 0), SenseInfo('00030463-v', 0) ],
"_symphonic_a_1_rel" : [ SenseInfo('03002040-a', 5), SenseInfo('01163941-a', 0) ],
"_preliminary_n_1_rel" : [ SenseInfo('07457599-n', 0), SenseInfo('07327013-n', 0) ],
"_buckskin_n_1_rel" : [ SenseInfo('02381004-n', 8), SenseInfo('14760555-n', 0) ],
"_insofar+as_x_subord_rel" : [  ],
"_retinoblastoma_n_1_rel" : [ SenseInfo('14250850-n', 0) ],
"_solitary_n_1_rel" : [ SenseInfo('13999941-n', 0), SenseInfo('10172448-n', 0) ],
"_phase_v_in_rel" : [ SenseInfo('01648894-v', 0), SenseInfo('00394381-v', 0), SenseInfo('01648894-v', 0), SenseInfo('00394381-v', 0) ],
"_dynasty_n_1_rel" : [ SenseInfo('07971582-n', 1), SenseInfo('07971582-n', 1) ],
"_terrier_n_1_rel" : [ SenseInfo('02092468-n', 2) ],
"_splash_v_1_rel" : [ SenseInfo('01374767-v', 2), SenseInfo('01921591-v', 1), SenseInfo('01374020-v', 1), SenseInfo('01336864-v', 1), SenseInfo('02186868-v', 0), SenseInfo('01534609-v', 0), SenseInfo('01375295-v', 0) ],
"_play_n_1_rel" : [ SenseInfo('07007945-n', 32), SenseInfo('07018931-n', 10), SenseInfo('00557588-n', 8), SenseInfo('00556313-n', 6), SenseInfo('14009763-n', 2), SenseInfo('00947596-n', 1), SenseInfo('00786887-n', 1), SenseInfo('00431893-n', 1), SenseInfo('15256915-n', 0), SenseInfo('13993842-n', 0), SenseInfo('07411851-n', 0), SenseInfo('06780882-n', 0), SenseInfo('04774511-n', 0), SenseInfo('00511817-n', 0), SenseInfo('00457382-n', 0), SenseInfo('00430140-n', 0), SenseInfo('00041468-n', 0) ],
"_feverish_a_1_rel" : [ SenseInfo('00086210-a', 4), SenseInfo('02726715-a', 0), SenseInfo('02544892-a', 0), SenseInfo('00086210-a', 4), SenseInfo('02726715-a', 0), SenseInfo('02544892-a', 0) ],
"_trunk_n_1_rel" : [ SenseInfo('13165815-n', 3), SenseInfo('04491769-n', 3), SenseInfo('05549830-n', 0), SenseInfo('03696065-n', 0), SenseInfo('02452967-n', 0) ],
"_percept_n_1_rel" : [ SenseInfo('05930136-n', 0) ],
"_shrug_v_1_rel" : [ SenseInfo('00033955-v', 10), SenseInfo('00033955-v', 10) ],
"_thicken_v_1_rel" : [ SenseInfo('00431327-v', 2), SenseInfo('00431117-v', 2), SenseInfo('00431610-v', 0) ],
"_affluent_a_1_rel" : [ SenseInfo('02022167-a', 0) ],
"_schottische_n_1_rel" : [ SenseInfo('07057095-n', 0), SenseInfo('00538266-n', 0) ],
"_feather_n_1_rel" : [ SenseInfo('01896031-n', 6), SenseInfo('00342565-n', 0) ],
"_cheap_n_i_rel" : [ SenseInfo('00934199-a', 9), SenseInfo('02393791-a', 1), SenseInfo('02346013-a', 1), SenseInfo('01113114-a', 0) ],
"_nationwide_a_2_rel" : [ SenseInfo('00526984-a', 0) ],
"_than_p_ind_rel" : [  ],
"_third_n_of_rel" : [ SenseInfo('13737190-n', 6), SenseInfo('00724168-n', 4), SenseInfo('13846900-n', 3), SenseInfo('06859504-n', 0), SenseInfo('04425977-n', 0), SenseInfo('04425804-n', 0), SenseInfo('13737190-n', 6), SenseInfo('00724168-n', 4), SenseInfo('13846900-n', 3), SenseInfo('06859504-n', 0), SenseInfo('04425977-n', 0), SenseInfo('04425804-n', 0), SenseInfo('13737190-n', 6), SenseInfo('00724168-n', 4), SenseInfo('13846900-n', 3), SenseInfo('06859504-n', 0), SenseInfo('04425977-n', 0), SenseInfo('04425804-n', 0), SenseInfo('13737190-n', 6), SenseInfo('00724168-n', 4), SenseInfo('13846900-n', 3), SenseInfo('06859504-n', 0), SenseInfo('04425977-n', 0), SenseInfo('04425804-n', 0) ],
"_counter+move_n_1_rel" : [ SenseInfo('00978173-n', 0), SenseInfo('00978173-n', 0), SenseInfo('00978173-n', 0), SenseInfo('00978173-n', 0), SenseInfo('00978173-n', 0), SenseInfo('00978173-n', 0), SenseInfo('00978173-n', 0), SenseInfo('00978173-n', 0) ],
"_milk_n_1_rel" : [ SenseInfo('07844042-n', 20), SenseInfo('05399034-n', 1), SenseInfo('09354780-n', 0), SenseInfo('07844604-n', 0) ],
"_renovation_n_of_rel" : [ SenseInfo('00265119-n', 1), SenseInfo('14424517-n', 0) ],
"_windy_a_1_rel" : [ SenseInfo('00305225-a', 2), SenseInfo('02498213-a', 0), SenseInfo('00980385-a', 0), SenseInfo('00549236-a', 0), SenseInfo('00305225-a', 2), SenseInfo('02498213-a', 0), SenseInfo('00980385-a', 0), SenseInfo('00549236-a', 0), SenseInfo('00305225-a', 2), SenseInfo('02498213-a', 0), SenseInfo('00980385-a', 0), SenseInfo('00549236-a', 0), SenseInfo('00305225-a', 2), SenseInfo('02498213-a', 0), SenseInfo('00980385-a', 0), SenseInfo('00549236-a', 0), SenseInfo('00305225-a', 2), SenseInfo('02498213-a', 0), SenseInfo('00980385-a', 0), SenseInfo('00549236-a', 0), SenseInfo('00305225-a', 2), SenseInfo('02498213-a', 0), SenseInfo('00980385-a', 0), SenseInfo('00549236-a', 0) ],
"_unsullied_a_1_rel" : [ SenseInfo('00419058-a', 0), SenseInfo('00247247-a', 0), SenseInfo('00419058-a', 0), SenseInfo('00247247-a', 0) ],
"_function_n_1_rel" : [ SenseInfo('13783816-n', 43), SenseInfo('05149325-n', 24), SenseInfo('00720565-n', 7), SenseInfo('13781164-n', 0), SenseInfo('08252467-n', 0), SenseInfo('07447261-n', 0), SenseInfo('06582403-n', 0) ],
"_batch_n_of_rel" : [ SenseInfo('08400772-n', 1), SenseInfo('13774404-n', 0), SenseInfo('08400452-n', 0), SenseInfo('08400772-n', 1), SenseInfo('13774404-n', 0), SenseInfo('08400452-n', 0) ],
"_plan_n_1_rel" : [ SenseInfo('05898568-n', 63), SenseInfo('05728678-n', 10), SenseInfo('03954199-n', 6), SenseInfo('05898568-n', 63), SenseInfo('05728678-n', 10), SenseInfo('03954199-n', 6), SenseInfo('05898568-n', 63), SenseInfo('05728678-n', 10), SenseInfo('03954199-n', 6) ],
"_postmaster_n_1_rel" : [ SenseInfo('10459575-n', 0) ],
"_penal_a_1_rel" : [ SenseInfo('02779420-a', 0), SenseInfo('01902866-a', 0), SenseInfo('01404370-a', 0) ],
"_humane_a_1_rel" : [ SenseInfo('02743547-a', 1), SenseInfo('01261867-a', 0), SenseInfo('00412460-a', 0) ],
"_fixation_n_1_rel" : [ SenseInfo('14503354-n', 0), SenseInfo('05700401-n', 0), SenseInfo('01260182-n', 0), SenseInfo('00276342-n', 0), SenseInfo('14503354-n', 0), SenseInfo('05700401-n', 0), SenseInfo('01260182-n', 0), SenseInfo('00276342-n', 0) ],
"_ant_n_1_rel" : [ SenseInfo('02219486-n', 6) ],
"_survey_n_1_rel" : [ SenseInfo('00644503-n', 5), SenseInfo('06469694-n', 4), SenseInfo('00881649-n', 1) ],
"_about_p_sel_rel" : [ SenseInfo('00007015-r', 55), SenseInfo('00071840-r', 10), SenseInfo('00071165-r', 5), SenseInfo('00072329-r', 3), SenseInfo('00072201-r', 3), SenseInfo('00358114-r', 2), SenseInfo('00073033-r', 1), SenseInfo('00032358-a', 0) ],
"_folder_n_of_rel" : [ SenseInfo('06413889-n', 0), SenseInfo('03376279-n', 0) ],
"_squeeze_n_1_rel" : [ SenseInfo('00357023-n', 1), SenseInfo('14488912-n', 0), SenseInfo('13327503-n', 0), SenseInfo('10643584-n', 0), SenseInfo('07351031-n', 0), SenseInfo('00788097-n', 0), SenseInfo('00417859-n', 0), SenseInfo('00226319-n', 0) ],
"_insectivora_n_1_rel" : [ SenseInfo('01888520-n', 0) ],
"_shareware_n_1_rel" : [ SenseInfo('06587596-n', 0) ],
"_falter_v_1_rel" : [ SenseInfo('02740204-v', 3), SenseInfo('01901289-v', 2), SenseInfo('01901133-v', 1), SenseInfo('00981544-v', 1) ],
"_forward_n_1_rel" : [ SenseInfo('10105733-n', 0), SenseInfo('00725383-n', 0) ],
"_carnitas_n_1_rel" : [  ],
"_assortment_n_1_rel" : [ SenseInfo('08398773-n', 1), SenseInfo('01012712-n', 0) ],
"_heed_n_1_rel" : [ SenseInfo('05702726-n', 1) ],
"_airflow_n_1_rel" : [ SenseInfo('07406601-n', 1) ],
"_unwire_v_1_rel" : [ SenseInfo('01599225-v', 2), SenseInfo('01599225-v', 2) ],
"_harmonic_n_1_rel" : [ SenseInfo('05719804-n', 0), SenseInfo('04988078-n', 0) ],
"_grace_v_1_rel" : [ SenseInfo('01675963-v', 1), SenseInfo('02748927-v', 0) ],
"_dragon_n_1_rel" : [ SenseInfo('09494388-n', 6), SenseInfo('10029729-n', 0), SenseInfo('09269717-n', 0), SenseInfo('01688589-n', 0) ],
"_nonwoven_a_1_rel" : [  ],
"_unenclosed_a_1_rel" : [ SenseInfo('01658814-a', 0), SenseInfo('01658814-a', 0) ],
"_cleanliness_n_1_rel" : [ SenseInfo('14496451-n', 0), SenseInfo('04896161-n', 0) ],
"_swell_v_1_rel" : [ SenseInfo('00555084-v', 5), SenseInfo('02596908-v', 4), SenseInfo('00256507-v', 4), SenseInfo('02626405-v', 1), SenseInfo('01991204-v', 1), SenseInfo('00257650-v', 0) ],
"_diagnosis_n_of_rel" : [ SenseInfo('00152727-n', 4), SenseInfo('00152727-n', 4) ],
"_sieve_n_1_rel" : [ SenseInfo('04216634-n', 1) ],
"_bust_v_cause_rel" : [ SenseInfo('01369758-v', 1), SenseInfo('02494850-v', 0), SenseInfo('01573515-v', 0), SenseInfo('01369346-v', 0), SenseInfo('00333594-v', 0) ],
"_workers_a_1_rel" : [  ],
"_sidewalk_n_1_rel" : [ SenseInfo('04215402-n', 16) ],
"_bend_v_1_rel" : [ SenseInfo('02035919-v', 23), SenseInfo('02033137-v', 11), SenseInfo('01280014-v', 5), SenseInfo('02062632-v', 3), SenseInfo('02034300-v', 1), SenseInfo('01280488-v', 0) ],
"_degenerate_n_1_rel" : [ SenseInfo('10419047-n', 0) ],
"_lorry_n_1_rel" : [ SenseInfo('03690600-n', 0), SenseInfo('03690473-n', 0) ],
"_whether_x_rel" : [  ],
"_reins_n_1_rel" : [ SenseInfo('04072551-n', 5), SenseInfo('05197574-n', 0), SenseInfo('04072551-n', 5), SenseInfo('05197574-n', 0) ],
"_draw_n_1_rel" : [ SenseInfo('09269882-n', 5), SenseInfo('10032676-n', 0), SenseInfo('07353716-n', 0), SenseInfo('03233423-n', 0), SenseInfo('03233246-n', 0), SenseInfo('00572285-n', 0), SenseInfo('00559329-n', 0), SenseInfo('00497536-n', 0), SenseInfo('00115036-n', 0) ],
"_resurrection_n_of_rel" : [ SenseInfo('07312018-n', 0), SenseInfo('01048059-n', 0) ],
"_electrolyte_n_1_rel" : [ SenseInfo('14847929-n', 0) ],
"_optical_a_1_rel" : [ SenseInfo('02861859-a', 2), SenseInfo('02869563-a', 1), SenseInfo('02869823-a', 0) ],
"_lawn_n_1_rel" : [ SenseInfo('08591592-n', 14) ],
"_shoo_v_in_rel" : [ SenseInfo('02003480-v', 0) ],
"_of+course_p_rel" : [ SenseInfo('00038625-r', 123) ],
"_cartographic_a_1_rel" : [ SenseInfo('02681881-a', 0) ],
"_ferryboat_n_1_rel" : [ SenseInfo('03329663-n', 0) ],
"_conjugate_n_1_rel" : [ SenseInfo('14820425-n', 22) ],
"_siege_n_1_rel" : [ SenseInfo('01075117-n', 2) ],
"_printable_a_1_rel" : [ SenseInfo('01964933-a', 1) ],
"_congregation_n_of_rel" : [ SenseInfo('07991364-n', 32), SenseInfo('07976181-n', 2), SenseInfo('01231686-n', 0), SenseInfo('07991364-n', 32), SenseInfo('07976181-n', 2), SenseInfo('01231686-n', 0) ],
"_at+least_x_deg_rel" : [ SenseInfo('00104661-r', 60), SenseInfo('00104345-r', 57) ],
"_back_v_up_rel" : [ SenseInfo('02453889-v', 7), SenseInfo('01997119-v', 6), SenseInfo('02556817-v', 4), SenseInfo('01997512-v', 4), SenseInfo('02217695-v', 2), SenseInfo('02693965-v', 0), SenseInfo('01139104-v', 0), SenseInfo('00560628-v', 0), SenseInfo('00223109-v', 0), SenseInfo('00185857-v', 0), SenseInfo('02453889-v', 7), SenseInfo('01997119-v', 6), SenseInfo('02556817-v', 4), SenseInfo('01997512-v', 4), SenseInfo('02217695-v', 2), SenseInfo('02693965-v', 0), SenseInfo('01139104-v', 0), SenseInfo('00560628-v', 0), SenseInfo('00223109-v', 0), SenseInfo('00185857-v', 0), SenseInfo('02453889-v', 7), SenseInfo('01997119-v', 6), SenseInfo('02556817-v', 4), SenseInfo('01997512-v', 4), SenseInfo('02217695-v', 2), SenseInfo('02693965-v', 0), SenseInfo('01139104-v', 0), SenseInfo('00560628-v', 0), SenseInfo('00223109-v', 0), SenseInfo('00185857-v', 0) ],
"_goddammit_a_1_rel" : [  ],
"_perforate_v_1_rel" : [ SenseInfo('01442779-v', 0), SenseInfo('01227675-v', 0) ],
"_tap_v_off_rel" : [ SenseInfo('01403314-v', 6), SenseInfo('02312318-v', 3), SenseInfo('01247804-v', 3), SenseInfo('01164273-v', 3), SenseInfo('02188848-v', 1), SenseInfo('02360274-v', 0), SenseInfo('02185373-v', 0), SenseInfo('01901021-v', 0), SenseInfo('01895757-v', 0), SenseInfo('01854519-v', 0), SenseInfo('01613732-v', 0), SenseInfo('00782057-v', 0) ],
"_miscommunication_n_1_rel" : [  ],
"_claw_v_1_rel" : [ SenseInfo('01914297-v', 1), SenseInfo('01213504-v', 1), SenseInfo('01306654-v', 0), SenseInfo('00845765-v', 0), SenseInfo('01914297-v', 1), SenseInfo('01213504-v', 1), SenseInfo('01306654-v', 0), SenseInfo('00845765-v', 0) ],
"_flare_n_1_rel" : [ SenseInfo('13862644-n', 1), SenseInfo('13481883-n', 1), SenseInfo('06874930-n', 1), SenseInfo('14227357-n', 0), SenseInfo('14081789-n', 0), SenseInfo('11510223-n', 0), SenseInfo('11454310-n', 0), SenseInfo('07014997-n', 0), SenseInfo('03357893-n', 0), SenseInfo('00561376-n', 0), SenseInfo('00150097-n', 0) ],
"_in+vivo_a_1_rel" : [ SenseInfo('01359424-a', 0) ],
"_wasp_n_1_rel" : [ SenseInfo('09641578-n', 0), SenseInfo('02212062-n', 0) ],
"_fresh-made_a_1_rel" : [  ],
"_plow_v_1_rel" : [ SenseInfo('01741864-v', 6), SenseInfo('01033527-v', 2), SenseInfo('02096853-v', 1) ],
"_farewell_n_1_rel" : [ SenseInfo('06629392-n', 4), SenseInfo('00053097-n', 0) ],
"_biologist_n_1_rel" : [ SenseInfo('09855630-n', 1) ],
"_father+in+law_n_1_rel" : [ SenseInfo('10082043-n', 0), SenseInfo('10082043-n', 0) ],
"_big_a_1_rel" : [ SenseInfo('01382086-a', 107), SenseInfo('01276872-a', 7), SenseInfo('01510444-a', 2), SenseInfo('01453084-a', 2), SenseInfo('00579622-a', 2), SenseInfo('02402439-a', 0), SenseInfo('01890752-a', 0), SenseInfo('01890187-a', 0), SenseInfo('01488616-a', 0), SenseInfo('01191780-a', 0), SenseInfo('01114658-a', 0), SenseInfo('01111418-a', 0), SenseInfo('00173391-a', 0), SenseInfo('01382086-a', 107), SenseInfo('01276872-a', 7), SenseInfo('01510444-a', 2), SenseInfo('01453084-a', 2), SenseInfo('00579622-a', 2), SenseInfo('02402439-a', 0), SenseInfo('01890752-a', 0), SenseInfo('01890187-a', 0), SenseInfo('01488616-a', 0), SenseInfo('01191780-a', 0), SenseInfo('01114658-a', 0), SenseInfo('01111418-a', 0), SenseInfo('00173391-a', 0), SenseInfo('01382086-a', 107), SenseInfo('01276872-a', 7), SenseInfo('01510444-a', 2), SenseInfo('01453084-a', 2), SenseInfo('00579622-a', 2), SenseInfo('02402439-a', 0), SenseInfo('01890752-a', 0), SenseInfo('01890187-a', 0), SenseInfo('01488616-a', 0), SenseInfo('01191780-a', 0), SenseInfo('01114658-a', 0), SenseInfo('01111418-a', 0), SenseInfo('00173391-a', 0) ],
"_platform_n_1_rel" : [ SenseInfo('03961939-n', 5), SenseInfo('06501311-n', 2), SenseInfo('03962685-n', 0), SenseInfo('03962525-n', 0), SenseInfo('03025250-n', 0) ],
"_intense_a_1_rel" : [ SenseInfo('01509527-a', 20), SenseInfo('00803275-a', 0), SenseInfo('00393683-a', 0), SenseInfo('01509527-a', 20), SenseInfo('00803275-a', 0), SenseInfo('00393683-a', 0) ],
"_disdain_n_for_rel" : [ SenseInfo('07502980-n', 2), SenseInfo('06719404-n', 0) ],
"_fed+ex_v_1_rel" : [  ],
"_mortify_v_1_rel" : [ SenseInfo('01802070-v', 0), SenseInfo('01801847-v', 0), SenseInfo('01799794-v', 0), SenseInfo('00097394-v', 0) ],
"_give_v_out_rel" : [ SenseInfo('02316868-v', 179), SenseInfo('02339171-v', 160), SenseInfo('02199590-v', 96), SenseInfo('02235842-v', 78), SenseInfo('01060494-v', 32), SenseInfo('01733477-v', 29), SenseInfo('01060317-v', 24), SenseInfo('02200686-v', 20), SenseInfo('01629403-v', 18), SenseInfo('00732224-v', 18), SenseInfo('01629000-v', 16), SenseInfo('02296153-v', 14), SenseInfo('01647672-v', 14), SenseInfo('02200498-v', 12), SenseInfo('02562901-v', 10), SenseInfo('02343595-v', 10), SenseInfo('02230772-v', 10), SenseInfo('00887463-v', 8), SenseInfo('02309374-v', 5), SenseInfo('02309165-v', 5), SenseInfo('01060746-v', 5), SenseInfo('02317094-v', 4), SenseInfo('01848465-v', 4), SenseInfo('01178565-v', 4), SenseInfo('02308741-v', 3), SenseInfo('01989053-v', 1), SenseInfo('00673571-v', 1), SenseInfo('02564052-v', 0), SenseInfo('02359553-v', 0), SenseInfo('02358034-v', 0), SenseInfo('01716283-v', 0), SenseInfo('01716112-v', 0), SenseInfo('01449796-v', 0), SenseInfo('01175810-v', 0), SenseInfo('01069638-v', 0), SenseInfo('00944247-v', 0), SenseInfo('00888009-v', 0), SenseInfo('00878876-v', 0), SenseInfo('00771806-v', 0), SenseInfo('00748972-v', 0), SenseInfo('00748616-v', 0), SenseInfo('00341184-v', 0), SenseInfo('00108747-v', 0), SenseInfo('00108604-v', 0) ],
"_yank_n_1_rel" : [ SenseInfo('10802283-n', 7), SenseInfo('09746819-n', 0) ],
"_tram_n_1_rel" : [ SenseInfo('04469813-n', 0), SenseInfo('04468847-n', 0), SenseInfo('04335435-n', 0) ],
"_flute_n_1_rel" : [ SenseInfo('03372029-n', 1), SenseInfo('03372549-n', 0), SenseInfo('03372355-n', 0) ],
"_extensile_a_1_rel" : [ SenseInfo('00944449-a', 0) ],
"_vital_a_for_rel" : [ SenseInfo('00903894-a', 6), SenseInfo('00902347-a', 0), SenseInfo('00119006-a', 0), SenseInfo('00095094-a', 0), SenseInfo('00903894-a', 6), SenseInfo('00902347-a', 0), SenseInfo('00119006-a', 0), SenseInfo('00095094-a', 0), SenseInfo('00903894-a', 6), SenseInfo('00902347-a', 0), SenseInfo('00119006-a', 0), SenseInfo('00095094-a', 0), SenseInfo('00903894-a', 6), SenseInfo('00902347-a', 0), SenseInfo('00119006-a', 0), SenseInfo('00095094-a', 0) ],
"_panic_n_1_rel" : [ SenseInfo('07520612-n', 7), SenseInfo('14405931-n', 2) ],
"_loader_n_1_rel" : [ SenseInfo('10655169-n', 0), SenseInfo('10268505-n', 0) ],
"_gender_n_1_rel" : [ SenseInfo('06328643-n', 3), SenseInfo('05006898-n', 0) ],
"_wheel_v_1_rel" : [ SenseInfo('02046075-v', 7), SenseInfo('02046441-v', 3), SenseInfo('01887020-v', 3), SenseInfo('01935476-v', 0), SenseInfo('02046075-v', 7), SenseInfo('02046441-v', 3), SenseInfo('01887020-v', 3), SenseInfo('01935476-v', 0) ],
"_top-heavy_a_1_rel" : [ SenseInfo('02293497-a', 0) ],
"_galling_a_1_rel" : [ SenseInfo('00089550-a', 1), SenseInfo('00089550-a', 1), SenseInfo('00089550-a', 1) ],
"_laxative_a_1_rel" : [ SenseInfo('00637857-a', 0) ],
"_documentary_n_1_rel" : [ SenseInfo('06616806-n', 5) ],
"_ownership_n_of_rel" : [ SenseInfo('13240514-n', 4), SenseInfo('00809465-n', 2), SenseInfo('14479488-n', 0) ],
"_emit_v_1_rel" : [ SenseInfo('00105333-v', 2), SenseInfo('02767308-v', 1), SenseInfo('00983824-v', 0) ],
"_one+after+the+other_a_1_rel" : [  ],
"_appetizer_n_1_rel" : [ SenseInfo('07581346-n', 0) ],
"_trove_n_1_rel" : [ SenseInfo('13371355-n', 0) ],
"_apartment_n_1_rel" : [ SenseInfo('02726305-n', 32), SenseInfo('02726305-n', 32), SenseInfo('02726305-n', 32), SenseInfo('02726305-n', 32), SenseInfo('02726305-n', 32) ],
"_cartridge_n_1_rel" : [ SenseInfo('02971691-n', 7), SenseInfo('03704376-n', 0), SenseInfo('02972182-n', 0), SenseInfo('02971940-n', 0) ],
"_bricklayer_n_1_rel" : [ SenseInfo('09874518-n', 1) ],
"_lifelong_a_1_rel" : [ SenseInfo('01440159-a', 1), SenseInfo('01440159-a', 1) ],
"_meeting_n_of_rel" : [ SenseInfo('08307589-n', 30), SenseInfo('08310389-n', 4), SenseInfo('07414922-n', 2), SenseInfo('01230965-n', 2), SenseInfo('00146856-n', 1), SenseInfo('08542634-n', 0) ],
"_muddy_a_1_rel" : [ SenseInfo('02548066-a', 7), SenseInfo('00422620-a', 1), SenseInfo('01909077-a', 0), SenseInfo('00433529-a', 0), SenseInfo('02548066-a', 7), SenseInfo('00422620-a', 1), SenseInfo('01909077-a', 0), SenseInfo('00433529-a', 0), SenseInfo('02548066-a', 7), SenseInfo('00422620-a', 1), SenseInfo('01909077-a', 0), SenseInfo('00433529-a', 0) ],
"_necktie_n_1_rel" : [ SenseInfo('03815615-n', 2) ],
"_squirmy_a_1_rel" : [  ],
"_under-perform_v_1_rel" : [ SenseInfo('02562585-v', 0), SenseInfo('01715357-v', 0), SenseInfo('02562585-v', 0), SenseInfo('01715357-v', 0) ],
"_eye_v_1_rel" : [ SenseInfo('02167052-v', 11) ],
"_seek_v_1_rel" : [ SenseInfo('02240481-v', 44), SenseInfo('01315613-v', 41), SenseInfo('02530167-v', 32), SenseInfo('01839170-v', 0), SenseInfo('01069989-v', 0), SenseInfo('02240481-v', 44), SenseInfo('01315613-v', 41), SenseInfo('02530167-v', 32), SenseInfo('01839170-v', 0), SenseInfo('01069989-v', 0) ],
"_weakness_n_1_rel" : [ SenseInfo('14462946-n', 24), SenseInfo('05204982-n', 2), SenseInfo('05040275-n', 2), SenseInfo('14474718-n', 0), SenseInfo('07498614-n', 0) ],
"_uniform_a_1_rel" : [ SenseInfo('01966488-a', 4), SenseInfo('01200095-a', 2), SenseInfo('00744506-a', 0), SenseInfo('01960310-a', 0), SenseInfo('01966488-a', 4), SenseInfo('01200095-a', 2), SenseInfo('00744506-a', 0), SenseInfo('01960310-a', 0) ],
"_after+hours_a_1_rel" : [ SenseInfo('00817004-a', 1), SenseInfo('00817004-a', 1) ],
"_bond_v_1_rel" : [ SenseInfo('01356750-v', 1), SenseInfo('02538086-v', 0), SenseInfo('02351925-v', 0), SenseInfo('01607072-v', 0) ],
"_combination_n_of_rel" : [ SenseInfo('07963711-n', 18), SenseInfo('08373723-n', 0), SenseInfo('08373544-n', 0), SenseInfo('08272961-n', 0), SenseInfo('07964495-n', 0), SenseInfo('00870453-n', 0), SenseInfo('00378985-n', 0) ],
"_unskillful_a_1_rel" : [ SenseInfo('02229000-a', 0), SenseInfo('02229000-a', 0) ],
"_relation_n_1_rel" : [ SenseInfo('00031921-n', 23), SenseInfo('00845523-n', 2), SenseInfo('10235549-n', 0), SenseInfo('07222823-n', 0), SenseInfo('05957428-n', 0), SenseInfo('00040962-n', 0), SenseInfo('00031921-n', 23), SenseInfo('00845523-n', 2), SenseInfo('10235549-n', 0), SenseInfo('07222823-n', 0), SenseInfo('05957428-n', 0), SenseInfo('00040962-n', 0) ],
"_acquainted_a_1_rel" : [ SenseInfo('00965894-a', 1) ],
"_aperient_n_1_rel" : [ SenseInfo('04025748-n', 0) ],
"_attendant_n_1_rel" : [ SenseInfo('09821831-n', 3), SenseInfo('09608002-n', 0), SenseInfo('07284554-n', 0) ],
"_absorber_n_1_rel" : [ SenseInfo('14598079-n', 0) ],
"_mmm_a_1_rel" : [  ],
"_scrape_v_off_rel" : [ SenseInfo('01308160-v', 4), SenseInfo('01750156-v', 1), SenseInfo('01309143-v', 1), SenseInfo('02040709-v', 0), SenseInfo('01384752-v', 0), SenseInfo('01309478-v', 0) ],
"_name_v_1_rel" : [ SenseInfo('01028748-v', 31), SenseInfo('01026095-v', 6), SenseInfo('02396716-v', 5), SenseInfo('02396205-v', 4), SenseInfo('00947439-v', 4), SenseInfo('01024190-v', 2), SenseInfo('00652346-v', 1), SenseInfo('00945853-v', 0), SenseInfo('00645552-v', 0), SenseInfo('01028748-v', 31), SenseInfo('01026095-v', 6), SenseInfo('02396716-v', 5), SenseInfo('02396205-v', 4), SenseInfo('00947439-v', 4), SenseInfo('01024190-v', 2), SenseInfo('00652346-v', 1), SenseInfo('00945853-v', 0), SenseInfo('00645552-v', 0), SenseInfo('01028748-v', 31), SenseInfo('01026095-v', 6), SenseInfo('02396716-v', 5), SenseInfo('02396205-v', 4), SenseInfo('00947439-v', 4), SenseInfo('01024190-v', 2), SenseInfo('00652346-v', 1), SenseInfo('00945853-v', 0), SenseInfo('00645552-v', 0), SenseInfo('01028748-v', 31), SenseInfo('01026095-v', 6), SenseInfo('02396716-v', 5), SenseInfo('02396205-v', 4), SenseInfo('00947439-v', 4), SenseInfo('01024190-v', 2), SenseInfo('00652346-v', 1), SenseInfo('00945853-v', 0), SenseInfo('00645552-v', 0) ],
"_worth_a_1_rel" : [ SenseInfo('02586206-a', 13), SenseInfo('02502016-a', 8), SenseInfo('02586206-a', 13), SenseInfo('02502016-a', 8), SenseInfo('02586206-a', 13), SenseInfo('02502016-a', 8), SenseInfo('02586206-a', 13), SenseInfo('02502016-a', 8) ],
"_coarse_a_1_rel" : [ SenseInfo('02230990-a', 1), SenseInfo('01950198-a', 1), SenseInfo('02346557-a', 0), SenseInfo('02230990-a', 1), SenseInfo('01950198-a', 1), SenseInfo('02346557-a', 0), SenseInfo('02230990-a', 1), SenseInfo('01950198-a', 1), SenseInfo('02346557-a', 0) ],
"_all+too_x_comp_rel" : [ SenseInfo('00250258-r', 8) ],
"_last+of+all_a_1_rel" : [  ],
"_moonlight_n_1_rel" : [ SenseInfo('11484975-n', 5) ],
"_conduce_v_1_rel" : [ SenseInfo('02555908-v', 0) ],
"_airless_n_1_rel" : [ SenseInfo('02509484-a', 1) ],
"_suave_a_1_rel" : [ SenseInfo('01948231-a', 1), SenseInfo('00758800-a', 1) ],
"_garb_v_1_rel" : [ SenseInfo('00047945-v', 0) ],
"_occupation_n_of_rel" : [ SenseInfo('00582388-n', 7), SenseInfo('01133106-n', 1), SenseInfo('00582868-n', 1), SenseInfo('00086809-n', 1), SenseInfo('15141486-n', 0) ],
"_attic_a_1_rel" : [ SenseInfo('03017286-a', 1) ],
"_all+in+all_a_1_rel" : [  ],
"_gifted_n_1_rel" : [ SenseInfo('01119192-a', 0) ],
"_hotel_n_1_rel" : [ SenseInfo('03542333-n', 39), SenseInfo('03542333-n', 39), SenseInfo('03542333-n', 39), SenseInfo('03542333-n', 39) ],
"_cluster_n_of_rel" : [ SenseInfo('07959943-n', 11), SenseInfo('07959943-n', 11) ],
"_pipe_v_1_rel" : [ SenseInfo('00914420-v', 1), SenseInfo('01950295-v', 0), SenseInfo('01727684-v', 0), SenseInfo('01670645-v', 0) ],
"_hasty_a_1_rel" : [ SenseInfo('01270704-a', 1), SenseInfo('01270868-a', 0), SenseInfo('01270704-a', 1), SenseInfo('01270868-a', 0), SenseInfo('01270704-a', 1), SenseInfo('01270868-a', 0), SenseInfo('01270704-a', 1), SenseInfo('01270868-a', 0) ],
"_brother_n_of_rel" : [ SenseInfo('09876454-n', 36), SenseInfo('09876892-n', 6), SenseInfo('09877951-n', 0), SenseInfo('09877124-n', 0), SenseInfo('09876701-n', 0) ],
"_abbreviate_v_1_rel" : [ SenseInfo('00243900-v', 0), SenseInfo('00243749-v', 0), SenseInfo('00243900-v', 0), SenseInfo('00243749-v', 0) ],
"_contemplate_v_1_rel" : [ SenseInfo('02164825-v', 8), SenseInfo('00703875-v', 7), SenseInfo('00704388-v', 5), SenseInfo('00630380-v', 1), SenseInfo('02164825-v', 8), SenseInfo('00703875-v', 7), SenseInfo('00704388-v', 5), SenseInfo('00630380-v', 1), SenseInfo('02164825-v', 8), SenseInfo('00703875-v', 7), SenseInfo('00704388-v', 5), SenseInfo('00630380-v', 1) ],
"_reign_v_1_rel" : [ SenseInfo('02587375-v', 3), SenseInfo('02644234-v', 1) ],
"_financial_a_1_rel" : [ SenseInfo('02847894-a', 22), SenseInfo('02847894-a', 22) ],
"_antiquity_n_1_rel" : [ SenseInfo('15253139-n', 1), SenseInfo('04925756-n', 0), SenseInfo('02724026-n', 0), SenseInfo('15253139-n', 1), SenseInfo('04925756-n', 0), SenseInfo('02724026-n', 0), SenseInfo('15253139-n', 1), SenseInfo('04925756-n', 0), SenseInfo('02724026-n', 0) ],
"_metropolitan_a_1_rel" : [ SenseInfo('02865172-a', 15) ],
"_idiom_n_1_rel" : [ SenseInfo('07081177-n', 2), SenseInfo('07155661-n', 1), SenseInfo('04929422-n', 1), SenseInfo('07154330-n', 0) ],
"_jealous_a_of_rel" : [ SenseInfo('00888765-a', 3), SenseInfo('02464105-a', 2) ],
"_load_v_up_rel" : [ SenseInfo('01489989-v', 8), SenseInfo('01490336-v', 3), SenseInfo('02231910-v', 0), SenseInfo('01612084-v', 0), SenseInfo('00487748-v', 0) ],
"_synch_n_1_rel" : [  ],
"_feudalism_n_1_rel" : [ SenseInfo('07972425-n', 0) ],
"_covered+up_a_1_rel" : [  ],
"_abode_n_1_rel" : [ SenseInfo('08558963-n', 1), SenseInfo('03259505-n', 1) ],
"_hinder_v_1_rel" : [ SenseInfo('02451370-v', 3), SenseInfo('02557199-v', 1), SenseInfo('01085474-v', 1) ],
"_extensive_a_1_rel" : [ SenseInfo('01386234-a', 13), SenseInfo('00526062-a', 3), SenseInfo('01514598-a', 0), SenseInfo('01386234-a', 13), SenseInfo('00526062-a', 3), SenseInfo('01514598-a', 0) ],
"_commend_v_for_rel" : [ SenseInfo('00882395-v', 10), SenseInfo('01689169-v', 1), SenseInfo('00883112-v', 1), SenseInfo('00882948-v', 0), SenseInfo('00882523-v', 0) ],
"_savor_n_1_rel" : [ SenseInfo('05715864-n', 0), SenseInfo('05715864-n', 0), SenseInfo('05715864-n', 0) ],
"_infectious_a_1_rel" : [ SenseInfo('02114746-a', 7), SenseInfo('01302811-a', 4), SenseInfo('02833070-a', 0) ],
"_packer_n_1_rel" : [ SenseInfo('10390427-n', 0), SenseInfo('10304505-n', 0), SenseInfo('09830629-n', 0) ],
"_fuck_n_1_rel" : [ SenseInfo('00846021-n', 0) ],
"_cleave_v_1_rel" : [ SenseInfo('01556572-v', 1), SenseInfo('01558681-v', 0), SenseInfo('01220885-v', 0) ],
"_sunflower_n_1_rel" : [ SenseInfo('11978233-n', 0) ],
"_sociological_a_1_rel" : [ SenseInfo('02906206-a', 2) ],
"_billet_v_1_rel" : [ SenseInfo('02653159-v', 0) ],
"_wring_v_1_rel" : [ SenseInfo('01350699-v', 1), SenseInfo('01349130-v', 1), SenseInfo('02241107-v', 0), SenseInfo('01350971-v', 0) ],
"_income_n_1_rel" : [ SenseInfo('13255145-n', 45) ],
"_court_n_of_rel" : [ SenseInfo('08329453-n', 42), SenseInfo('03120778-n', 5), SenseInfo('08051946-n', 3), SenseInfo('03120491-n', 2), SenseInfo('10913355-n', 0), SenseInfo('08329322-n', 0), SenseInfo('03790755-n', 0), SenseInfo('03649459-n', 0), SenseInfo('03121040-n', 0), SenseInfo('03120198-n', 0), SenseInfo('01229223-n', 0) ],
"_semibreve_n_1_rel" : [ SenseInfo('06870576-n', 0) ],
"_prolonged_a_1_rel" : [ SenseInfo('01439155-a', 5), SenseInfo('01434218-a', 0) ],
"_unobstructed_a_1_rel" : [ SenseInfo('01622302-a', 0), SenseInfo('01622302-a', 0) ],
"_harder_a_1_rel" : [  ],
"_national_a_1_rel" : [ SenseInfo('02988060-a', 46), SenseInfo('01567862-a', 17), SenseInfo('01105840-a', 6), SenseInfo('01861776-a', 5), SenseInfo('01038332-a', 5), SenseInfo('02988402-a', 1), SenseInfo('02988281-a', 0), SenseInfo('02988060-a', 46), SenseInfo('01567862-a', 17), SenseInfo('01105840-a', 6), SenseInfo('01861776-a', 5), SenseInfo('01038332-a', 5), SenseInfo('02988402-a', 1), SenseInfo('02988281-a', 0) ],
"_giggle_n_1_rel" : [ SenseInfo('07127693-n', 1) ],
"_forth_p_sel_rel" : [ SenseInfo('00232936-r', 3), SenseInfo('00103859-r', 1), SenseInfo('00103761-r', 1), SenseInfo('09284433-n', 0) ],
"_ingenuity_n_1_rel" : [ SenseInfo('05633672-n', 0), SenseInfo('04730367-n', 0) ],
"_ghoul_n_1_rel" : [ SenseInfo('10144571-n', 3), SenseInfo('09543673-n', 1) ],
"_deadlock_n_1_rel" : [ SenseInfo('14015361-n', 2) ],
"_inborn_a_1_rel" : [ SenseInfo('01315844-a', 0), SenseInfo('01034153-a', 0) ],
"_platelet_n_1_rel" : [ SenseInfo('15023959-n', 0) ],
"_sycamore_n_1_rel" : [ SenseInfo('12807082-n', 0), SenseInfo('12806732-n', 0), SenseInfo('12754981-n', 0), SenseInfo('12403513-n', 0) ],
"_pensioner_n_1_rel" : [ SenseInfo('10414612-n', 1) ],
"_hindmost_a_1_rel" : [ SenseInfo('00197773-a', 0) ],
"_heater_n_1_rel" : [ SenseInfo('03508101-n', 1), SenseInfo('00108181-n', 0) ],
"_seasonable_a_1_rel" : [ SenseInfo('01494586-a', 0), SenseInfo('01661529-a', 0), SenseInfo('01494586-a', 0), SenseInfo('01661529-a', 0) ],
"_49er_n_1_rel" : [  ],
"_extract_v_from_rel" : [ SenseInfo('01351170-v', 8), SenseInfo('02239098-v', 1), SenseInfo('01630532-v', 1), SenseInfo('00229280-v', 1), SenseInfo('01459392-v', 0), SenseInfo('01351754-v', 0), SenseInfo('00677021-v', 0), SenseInfo('00638723-v', 0), SenseInfo('01351170-v', 8), SenseInfo('02239098-v', 1), SenseInfo('01630532-v', 1), SenseInfo('00229280-v', 1), SenseInfo('01459392-v', 0), SenseInfo('01351754-v', 0), SenseInfo('00677021-v', 0), SenseInfo('00638723-v', 0) ],
"_darned_x_deg_rel" : [ SenseInfo('00669942-a', 6) ],
"_existent_a_1_rel" : [ SenseInfo('00927017-a', 1), SenseInfo('01932973-a', 0), SenseInfo('00043765-a', 0) ],
"_before_x_h_rel" : [ SenseInfo('00060939-r', 68), SenseInfo('00066781-r', 0) ],
"_indigenous_a_to_rel" : [ SenseInfo('01036383-a', 0) ],
"_bespectacled_a_1_rel" : [ SenseInfo('00056943-a', 2) ],
"_offence_n_1_rel" : [ SenseInfo('00980038-n', 1), SenseInfo('08081244-n', 0), SenseInfo('07517550-n', 0), SenseInfo('01224031-n', 0), SenseInfo('00766234-n', 0) ],
"_mirror_n_1_rel" : [ SenseInfo('03773035-n', 8), SenseInfo('05767245-n', 1) ],
"_glue_v_1_rel" : [ SenseInfo('01332205-v', 15), SenseInfo('00486850-v', 2), SenseInfo('01332205-v', 15), SenseInfo('00486850-v', 2) ],
"_despairing_a_1_rel" : [ SenseInfo('01229826-a', 3), SenseInfo('01229826-a', 3) ],
"_valiant_a_1_rel" : [ SenseInfo('00264570-a', 3) ],
"_honeymoon_n_1_rel" : [ SenseInfo('15138903-n', 2), SenseInfo('15293788-n', 0) ],
"_comanche_n_1_rel" : [ SenseInfo('09653438-n', 0), SenseInfo('06914930-n', 0) ],
"_have_v_cause_rel" : [ SenseInfo('02203362-v', 1202), SenseInfo('02630189-v', 377), SenseInfo('02108026-v', 220), SenseInfo('02204692-v', 143), SenseInfo('00120796-v', 64), SenseInfo('01156834-v', 42), SenseInfo('02378453-v', 31), SenseInfo('01733477-v', 30), SenseInfo('02205098-v', 28), SenseInfo('02740745-v', 25), SenseInfo('00121046-v', 25), SenseInfo('00065370-v', 11), SenseInfo('00770437-v', 8), SenseInfo('02236124-v', 7), SenseInfo('02210119-v', 7), SenseInfo('00065639-v', 5), SenseInfo('02355596-v', 3), SenseInfo('00056930-v', 3), SenseInfo('01427127-v', 2) ],
"_malady_n_1_rel" : [ SenseInfo('14563928-n', 1), SenseInfo('14061805-n', 1) ],
"_tenrec_n_1_rel" : [ SenseInfo('01894207-n', 0) ],
"_illiteracy_n_1_rel" : [ SenseInfo('05989386-n', 0), SenseInfo('05649256-n', 0) ],
"_requisite_a_1_rel" : [ SenseInfo('01580775-a', 0) ],
"_signal_n_1_rel" : [ SenseInfo('06791372-n', 16), SenseInfo('09185280-n', 1), SenseInfo('11447319-n', 0), SenseInfo('06791372-n', 16), SenseInfo('09185280-n', 1), SenseInfo('11447319-n', 0) ],
"_seal_v_up_rel" : [ SenseInfo('01354006-v', 3), SenseInfo('01353405-v', 3), SenseInfo('00698732-v', 2), SenseInfo('01356582-v', 0), SenseInfo('01269008-v', 0), SenseInfo('01143498-v', 0) ],
"_superior_a_1_rel" : [ SenseInfo('02341266-a', 16), SenseInfo('02338615-a', 4), SenseInfo('00792769-a', 1), SenseInfo('02349685-a', 0), SenseInfo('02348482-a', 0), SenseInfo('02100566-a', 0), SenseInfo('00072436-a', 0) ],
"_heave_n_1_rel" : [ SenseInfo('07370968-n', 0), SenseInfo('07350069-n', 0), SenseInfo('00324834-n', 0), SenseInfo('00226951-n', 0), SenseInfo('00116376-n', 0), SenseInfo('00105271-n', 0) ],
"_fly_v_on_rel" : [ SenseInfo('01940403-v', 33), SenseInfo('01842068-v', 9), SenseInfo('01941093-v', 5), SenseInfo('01451842-v', 3), SenseInfo('01848058-v', 2), SenseInfo('01839404-v', 2), SenseInfo('00545292-v', 2), SenseInfo('02073065-v', 1), SenseInfo('01840238-v', 1), SenseInfo('02140965-v', 0), SenseInfo('02075462-v', 0), SenseInfo('01847845-v', 0), SenseInfo('01402765-v', 0), SenseInfo('00153061-v', 0) ],
"_trample_v_1_rel" : [ SenseInfo('01929467-v', 5), SenseInfo('00070439-v', 1), SenseInfo('01867504-v', 0) ],
"_signpost_n_1_rel" : [ SenseInfo('06794374-n', 1) ],
"_elegant_a_1_rel" : [ SenseInfo('00849357-a', 2), SenseInfo('01142069-a', 0), SenseInfo('01139613-a', 0), SenseInfo('00849357-a', 2), SenseInfo('01142069-a', 0), SenseInfo('01139613-a', 0) ],
"_gee_a_1_rel" : [ SenseInfo('13648596-n', 2), SenseInfo('13648596-n', 2) ],
"_glow_v_with_rel" : [ SenseInfo('02160944-v', 5), SenseInfo('02161530-v', 4), SenseInfo('02768874-v', 2), SenseInfo('01830042-v', 1), SenseInfo('01829747-v', 0) ],
"_feed_v_2_rel" : [ SenseInfo('01182021-v', 47), SenseInfo('01178565-v', 15), SenseInfo('01181166-v', 5), SenseInfo('00189511-v', 4), SenseInfo('02555787-v', 3), SenseInfo('01179865-v', 3), SenseInfo('01180206-v', 1), SenseInfo('02066939-v', 0), SenseInfo('01203715-v', 0), SenseInfo('01182152-v', 0), SenseInfo('00502757-v', 0) ],
"_wince_n_1_rel" : [ SenseInfo('06879056-n', 0), SenseInfo('00865471-n', 0) ],
"_except_p_rel" : [ SenseInfo('00807941-v', 1), SenseInfo('00615774-v', 1), SenseInfo('00807941-v', 1), SenseInfo('00615774-v', 1) ],
"_cramp_n_1_rel" : [ SenseInfo('14360459-n', 1), SenseInfo('03126251-n', 0), SenseInfo('03126090-n', 0) ],
"_eccentric_a_1_rel" : [ SenseInfo('00608791-a', 4), SenseInfo('00543200-a', 1) ],
"_force_v_open_rel" : [ SenseInfo('02504562-v', 48), SenseInfo('01650425-v', 17), SenseInfo('01871979-v', 13), SenseInfo('00747418-v', 8), SenseInfo('01527271-v', 3), SenseInfo('01516534-v', 2), SenseInfo('01448100-v', 1), SenseInfo('01350449-v', 1), SenseInfo('01586600-v', 0) ],
"_coordinate_v_1_rel" : [ SenseInfo('00404642-v', 9), SenseInfo('02437905-v', 4), SenseInfo('02438228-v', 1), SenseInfo('00466053-v', 1), SenseInfo('00404642-v', 9), SenseInfo('02437905-v', 4), SenseInfo('02438228-v', 1), SenseInfo('00466053-v', 1), SenseInfo('00404642-v', 9), SenseInfo('02437905-v', 4), SenseInfo('02438228-v', 1), SenseInfo('00466053-v', 1), SenseInfo('00404642-v', 9), SenseInfo('02437905-v', 4), SenseInfo('02438228-v', 1), SenseInfo('00466053-v', 1), SenseInfo('00404642-v', 9), SenseInfo('02437905-v', 4), SenseInfo('02438228-v', 1), SenseInfo('00466053-v', 1), SenseInfo('00404642-v', 9), SenseInfo('02437905-v', 4), SenseInfo('02438228-v', 1), SenseInfo('00466053-v', 1) ],
"_hectic_a_1_rel" : [ SenseInfo('00086210-a', 1), SenseInfo('00086210-a', 1) ],
"_aperitif_n_1_rel" : [ SenseInfo('07886463-n', 0) ],
"_pronoun_n_1_rel" : [ SenseInfo('06325370-n', 5), SenseInfo('06325370-n', 5) ],
"_tissue_n_1_rel" : [ SenseInfo('05267345-n', 37), SenseInfo('15074962-n', 4) ],
"_at+the+earliest_a_1_rel" : [  ],
"_grin_v_at_rel" : [ SenseInfo('00029025-v', 18), SenseInfo('00029025-v', 18) ],
"_blue_a_1_rel" : [ SenseInfo('00370869-a', 48), SenseInfo('01606058-a', 13), SenseInfo('00703615-a', 1), SenseInfo('00425002-a', 1), SenseInfo('02132224-a', 0), SenseInfo('01590484-a', 0), SenseInfo('01300370-a', 0), SenseInfo('00364881-a', 0), SenseInfo('00370869-a', 48), SenseInfo('01606058-a', 13), SenseInfo('00703615-a', 1), SenseInfo('00425002-a', 1), SenseInfo('02132224-a', 0), SenseInfo('01590484-a', 0), SenseInfo('01300370-a', 0), SenseInfo('00364881-a', 0), SenseInfo('00370869-a', 48), SenseInfo('01606058-a', 13), SenseInfo('00703615-a', 1), SenseInfo('00425002-a', 1), SenseInfo('02132224-a', 0), SenseInfo('01590484-a', 0), SenseInfo('01300370-a', 0), SenseInfo('00364881-a', 0) ],
"_sensible_a_for_rel" : [ SenseInfo('01943406-a', 3), SenseInfo('02102484-a', 0), SenseInfo('01748152-a', 0), SenseInfo('00191265-a', 0), SenseInfo('01943406-a', 3), SenseInfo('02102484-a', 0), SenseInfo('01748152-a', 0), SenseInfo('00191265-a', 0), SenseInfo('01943406-a', 3), SenseInfo('02102484-a', 0), SenseInfo('01748152-a', 0), SenseInfo('00191265-a', 0) ],
"_skepticism_n_1_rel" : [ SenseInfo('05698982-n', 1), SenseInfo('05980051-n', 0), SenseInfo('05698982-n', 1), SenseInfo('05980051-n', 0) ],
"_curve_v_cause_rel" : [ SenseInfo('02033295-v', 2), SenseInfo('02738701-v', 1), SenseInfo('02034986-v', 1), SenseInfo('02034671-v', 0), SenseInfo('00362128-v', 0) ],
"_radar_n_1_rel" : [ SenseInfo('04039848-n', 11) ],
"_soul_n_1_rel" : [ SenseInfo('10627082-n', 20), SenseInfo('00007846-n', 6), SenseInfo('07480790-n', 3), SenseInfo('00933154-n', 1), SenseInfo('07061968-n', 0) ],
"_chance_v_1_rel" : [ SenseInfo('02594102-v', 2), SenseInfo('02544348-v', 1), SenseInfo('02248465-v', 0), SenseInfo('02594102-v', 2), SenseInfo('02544348-v', 1), SenseInfo('02248465-v', 0) ],
"_dull_v_cause_rel" : [ SenseInfo('01246321-v', 1), SenseInfo('00391971-v', 1), SenseInfo('02191311-v', 0), SenseInfo('02115273-v', 0), SenseInfo('01246444-v', 0), SenseInfo('00538199-v', 0), SenseInfo('00391672-v', 0) ],
"_floppy_n_1_rel" : [ SenseInfo('03209910-n', 0) ],
"_remit_n_1_rel" : [ SenseInfo('05815890-n', 0), SenseInfo('00122106-n', 0) ],
"_singer_n_1_rel" : [ SenseInfo('10599806-n', 3), SenseInfo('11302772-n', 0), SenseInfo('11302615-n', 0) ],
"_muffin_n_1_rel" : [ SenseInfo('07690273-n', 0) ],
"_ghostlike_a_1_rel" : [ SenseInfo('01574925-a', 1) ],
"_lunch_n_1_rel" : [ SenseInfo('07575076-n', 12), SenseInfo('07575076-n', 12) ],
"_lull_v_into_rel" : [ SenseInfo('01763643-v', 2), SenseInfo('00558061-v', 1), SenseInfo('01764800-v', 0), SenseInfo('01763643-v', 2), SenseInfo('00558061-v', 1), SenseInfo('01764800-v', 0) ],
"_arch_n_1_rel" : [ SenseInfo('13886133-n', 1), SenseInfo('05576573-n', 1), SenseInfo('02734217-n', 0), SenseInfo('02733524-n', 0) ],
"_babylonian_n_1_rel" : [ SenseInfo('09640220-n', 1), SenseInfo('06352446-n', 0) ],
"_crackle_n_1_rel" : [ SenseInfo('07381678-n', 2), SenseInfo('03125588-n', 0) ],
"_unstaffed_a_1_rel" : [  ],
"_nihilistic_a_1_rel" : [ SenseInfo('02911757-a', 1) ],
"_internet_n_1_rel" : [ SenseInfo('03580615-n', 0) ],
"_detach_v_cause_rel" : [ SenseInfo('01298668-v', 3), SenseInfo('02031622-v', 1), SenseInfo('01299758-v', 0), SenseInfo('01298668-v', 3), SenseInfo('02031622-v', 1), SenseInfo('01299758-v', 0) ],
"_cutting-edge_a_1_rel" : [ SenseInfo('00972642-a', 0), SenseInfo('00972642-a', 0) ],
"_sticky_a_1_rel" : [ SenseInfo('00053691-a', 4), SenseInfo('02550704-a', 2), SenseInfo('02549691-a', 0), SenseInfo('00746047-a', 0), SenseInfo('00054804-a', 0), SenseInfo('00053691-a', 4), SenseInfo('02550704-a', 2), SenseInfo('02549691-a', 0), SenseInfo('00746047-a', 0), SenseInfo('00054804-a', 0), SenseInfo('00053691-a', 4), SenseInfo('02550704-a', 2), SenseInfo('02549691-a', 0), SenseInfo('00746047-a', 0), SenseInfo('00054804-a', 0) ],
"_appropriation_n_1_rel" : [ SenseInfo('13289845-n', 3), SenseInfo('00373418-n', 0), SenseInfo('00083975-n', 0), SenseInfo('13289845-n', 3), SenseInfo('00373418-n', 0), SenseInfo('00083975-n', 0) ],
"_drive_v_around_rel" : [ SenseInfo('01930874-v', 56), SenseInfo('01930117-v', 24), SenseInfo('02056971-v', 13), SenseInfo('01516534-v', 13), SenseInfo('02505358-v', 6), SenseInfo('01506157-v', 5), SenseInfo('01646300-v', 4), SenseInfo('01512259-v', 2), SenseInfo('01509584-v', 2), SenseInfo('02406916-v', 1), SenseInfo('01026975-v', 1), SenseInfo('02742232-v', 0), SenseInfo('02408281-v', 0), SenseInfo('02057656-v', 0), SenseInfo('01939553-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01407904-v', 0), SenseInfo('01407722-v', 0), SenseInfo('01310964-v', 0), SenseInfo('01181741-v', 0), SenseInfo('01142636-v', 0), SenseInfo('01142490-v', 0), SenseInfo('01930874-v', 56), SenseInfo('01930117-v', 24), SenseInfo('02056971-v', 13), SenseInfo('01516534-v', 13), SenseInfo('02505358-v', 6), SenseInfo('01506157-v', 5), SenseInfo('01646300-v', 4), SenseInfo('01512259-v', 2), SenseInfo('01509584-v', 2), SenseInfo('02406916-v', 1), SenseInfo('01026975-v', 1), SenseInfo('02742232-v', 0), SenseInfo('02408281-v', 0), SenseInfo('02057656-v', 0), SenseInfo('01939553-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01407904-v', 0), SenseInfo('01407722-v', 0), SenseInfo('01310964-v', 0), SenseInfo('01181741-v', 0), SenseInfo('01142636-v', 0), SenseInfo('01142490-v', 0) ],
"_spin_n_1_rel" : [ SenseInfo('07442288-n', 0), SenseInfo('00343249-n', 0), SenseInfo('00309540-n', 0), SenseInfo('00306210-n', 0), SenseInfo('00101003-n', 0) ],
"_staircase_n_1_rel" : [ SenseInfo('04298308-n', 3) ],
"_vote_v_for_rel" : [ SenseInfo('02461314-v', 30), SenseInfo('02462580-v', 10), SenseInfo('02462386-v', 1), SenseInfo('02473890-v', 0), SenseInfo('02462201-v', 0) ],
"_chloride_n_1_rel" : [ SenseInfo('15017604-n', 2), SenseInfo('15016852-n', 0) ],
"_medical_n_1_rel" : [ SenseInfo('00142361-n', 0) ],
"_subversive_n_1_rel" : [ SenseInfo('10527334-n', 0) ],
"_cleanse_v_1_rel" : [ SenseInfo('00035758-v', 1), SenseInfo('00501896-v', 0) ],
"_animal_n_1_rel" : [ SenseInfo('00015388-n', 67) ],
"_horror_n_1_rel" : [ SenseInfo('07520411-n', 10), SenseInfo('03537866-n', 6), SenseInfo('07503987-n', 3) ],
"_near_p_rel" : [ SenseInfo('00444519-a', 44), SenseInfo('00409709-r', 19), SenseInfo('02053941-v', 11), SenseInfo('00073033-r', 1), SenseInfo('02033556-a', 0), SenseInfo('01573762-a', 0), SenseInfo('01113225-a', 0), SenseInfo('00452883-a', 0), SenseInfo('00451872-a', 0), SenseInfo('00444519-a', 44), SenseInfo('00409709-r', 19), SenseInfo('02053941-v', 11), SenseInfo('00073033-r', 1), SenseInfo('02033556-a', 0), SenseInfo('01573762-a', 0), SenseInfo('01113225-a', 0), SenseInfo('00452883-a', 0), SenseInfo('00451872-a', 0) ],
"_sink_v_cause_rel" : [ SenseInfo('01985923-v', 8), SenseInfo('01986869-v', 5), SenseInfo('01972131-v', 4), SenseInfo('01989873-v', 3), SenseInfo('01971929-v', 3), SenseInfo('02039679-v', 2), SenseInfo('00432839-v', 2), SenseInfo('01988886-v', 1), SenseInfo('01530098-v', 1) ],
"_functional_a_1_rel" : [ SenseInfo('01090308-a', 3), SenseInfo('01092989-a', 1), SenseInfo('02976260-a', 0), SenseInfo('02124253-a', 0), SenseInfo('01835023-a', 0), SenseInfo('01091728-a', 0), SenseInfo('01090308-a', 3), SenseInfo('01092989-a', 1), SenseInfo('02976260-a', 0), SenseInfo('02124253-a', 0), SenseInfo('01835023-a', 0), SenseInfo('01091728-a', 0) ],
"_fix_v_to_rel" : [ SenseInfo('00260648-v', 9), SenseInfo('01340439-v', 7), SenseInfo('00947077-v', 6), SenseInfo('01664172-v', 5), SenseInfo('01153947-v', 3), SenseInfo('01647543-v', 2), SenseInfo('00407458-v', 2), SenseInfo('00486998-v', 1), SenseInfo('00061595-v', 1), SenseInfo('02603299-v', 0), SenseInfo('01575675-v', 0), SenseInfo('00406243-v', 0) ],
"_wanderer_n_1_rel" : [ SenseInfo('10765679-n', 1), SenseInfo('06579715-n', 0) ],
"_centre_n_1_rel" : [ SenseInfo('08941426-n', 0), SenseInfo('08523483-n', 0), SenseInfo('08521816-n', 0), SenseInfo('08514034-n', 0), SenseInfo('07602650-n', 0), SenseInfo('05921123-n', 0), SenseInfo('05812038-n', 0), SenseInfo('05463533-n', 0), SenseInfo('02993546-n', 0) ],
"_egg_n_1_rel" : [ SenseInfo('01460457-n', 19), SenseInfo('07840804-n', 1), SenseInfo('05524615-n', 0) ],
"_job_n_of_rel" : [ SenseInfo('00582388-n', 76), SenseInfo('00719705-n', 36), SenseInfo('03599628-n', 4), SenseInfo('03599761-n', 2), SenseInfo('00584769-n', 2), SenseInfo('00576877-n', 2), SenseInfo('00576717-n', 1), SenseInfo('14410605-n', 0), SenseInfo('11085402-n', 0), SenseInfo('10222949-n', 0), SenseInfo('06572482-n', 0), SenseInfo('06436939-n', 0), SenseInfo('00782792-n', 0), SenseInfo('00582388-n', 76), SenseInfo('00719705-n', 36), SenseInfo('03599628-n', 4), SenseInfo('03599761-n', 2), SenseInfo('00584769-n', 2), SenseInfo('00576877-n', 2), SenseInfo('00576717-n', 1), SenseInfo('14410605-n', 0), SenseInfo('11085402-n', 0), SenseInfo('10222949-n', 0), SenseInfo('06572482-n', 0), SenseInfo('06436939-n', 0), SenseInfo('00782792-n', 0) ],
"_inferior_n_1_rel" : [ SenseInfo('10205231-n', 0), SenseInfo('06820212-n', 0) ],
"_millimeter_n_1_rel" : [ SenseInfo('13658657-n', 1), SenseInfo('13658657-n', 1), SenseInfo('13658657-n', 1) ],
"_monarchial_a_1_rel" : [  ],
"_meantime_n_1_rel" : [ SenseInfo('15272887-n', 0) ],
"_Da_n_meas_rel" : [ SenseInfo('10019072-n', 0) ],
"_bowl_v_1_rel" : [ SenseInfo('01887324-v', 0), SenseInfo('01616738-v', 0), SenseInfo('01146507-v', 0) ],
"_nicaraguan_n_1_rel" : [ SenseInfo('09724656-n', 0) ],
"_deliberate_a_1_rel" : [ SenseInfo('01337939-a', 2), SenseInfo('01271961-a', 2), SenseInfo('01337939-a', 2), SenseInfo('01271961-a', 2) ],
"_paraguayan_n_1_rel" : [ SenseInfo('09726246-n', 0) ],
"_cell_n_1_rel" : [ SenseInfo('02991711-n', 71), SenseInfo('00006484-n', 44), SenseInfo('02991048-n', 1), SenseInfo('08358594-n', 0), SenseInfo('02992529-n', 0), SenseInfo('02991555-n', 0), SenseInfo('02991302-n', 0), SenseInfo('02991711-n', 71), SenseInfo('00006484-n', 44), SenseInfo('02991048-n', 1), SenseInfo('08358594-n', 0), SenseInfo('02992529-n', 0), SenseInfo('02991555-n', 0), SenseInfo('02991302-n', 0) ],
"_cautious_a_of_rel" : [ SenseInfo('00325281-a', 2), SenseInfo('01532149-a', 0), SenseInfo('00325281-a', 2), SenseInfo('01532149-a', 0) ],
"_in_p_temp_rel" : [ SenseInfo('00501990-r', 19), SenseInfo('13649791-n', 3), SenseInfo('14641223-n', 0), SenseInfo('09084750-n', 0), SenseInfo('02332204-a', 0), SenseInfo('01295143-a', 0), SenseInfo('00972501-a', 0) ],
"_down-size_v_1_rel" : [ SenseInfo('02403773-v', 0), SenseInfo('00586816-v', 0), SenseInfo('00586682-v', 0) ],
"_grin_v_1_rel" : [ SenseInfo('00029025-v', 18) ],
"_ballad_n_1_rel" : [ SenseInfo('07049713-n', 3), SenseInfo('06378298-n', 2) ],
"_bellow_v_1_rel" : [ SenseInfo('01048569-v', 10), SenseInfo('01048718-v', 0), SenseInfo('01048569-v', 10), SenseInfo('01048718-v', 0) ],
"_ingredient_n_1_rel" : [ SenseInfo('03570709-n', 3), SenseInfo('05868954-n', 1), SenseInfo('07809096-n', 0) ],
"_conference_n_of_rel" : [ SenseInfo('08308497-n', 12), SenseInfo('08231184-n', 2), SenseInfo('07142566-n', 2) ],
"_parachute_n_1_rel" : [ SenseInfo('03888257-n', 2) ],
"_evensong_n_1_rel" : [ SenseInfo('15230180-n', 1), SenseInfo('06456759-n', 0) ],
"_hilt_n_1_rel" : [ SenseInfo('03520654-n', 1) ],
"_downstairs_n_1_rel" : [ SenseInfo('02494092-a', 0) ],
"_goings-on_n_1_rel" : [  ],
"_know-how_n_1_rel" : [ SenseInfo('05616786-n', 1), SenseInfo('05616786-n', 1) ],
"_blemish_v_1_rel" : [ SenseInfo('01549905-v', 0), SenseInfo('01538161-v', 0), SenseInfo('00263044-v', 0) ],
"_begone_v_1_rel" : [  ],
"_sentinel_n_1_rel" : [ SenseInfo('10271216-n', 1) ],
"_planet_n_1_rel" : [ SenseInfo('09394007-n', 21), SenseInfo('10552639-n', 1), SenseInfo('09394646-n', 0) ],
"_grocery_n_1_rel" : [ SenseInfo('03461385-n', 1), SenseInfo('03461119-n', 0) ],
"_complain_v_of_rel" : [ SenseInfo('00907147-v', 29), SenseInfo('00844298-v', 0) ],
"_hitch_n_1_rel" : [ SenseInfo('15293590-n', 1), SenseInfo('14010927-n', 0), SenseInfo('05691144-n', 0), SenseInfo('03522863-n', 0), SenseInfo('03522634-n', 0), SenseInfo('03520811-n', 0), SenseInfo('00286756-n', 0) ],
"_coup_n_1_rel" : [ SenseInfo('01145015-n', 1), SenseInfo('00065336-n', 1) ],
"_dull_a_1_rel" : [ SenseInfo('00806512-a', 5), SenseInfo('00283703-a', 5), SenseInfo('01454985-a', 2), SenseInfo('01345307-a', 2), SenseInfo('00393992-a', 2), SenseInfo('00803971-a', 1), SenseInfo('00440579-a', 1), SenseInfo('00036998-a', 1), SenseInfo('00800248-a', 0), SenseInfo('02107634-a', 0), SenseInfo('02011622-a', 0), SenseInfo('00462249-a', 0), SenseInfo('00806512-a', 5), SenseInfo('00283703-a', 5), SenseInfo('01454985-a', 2), SenseInfo('01345307-a', 2), SenseInfo('00393992-a', 2), SenseInfo('00803971-a', 1), SenseInfo('00440579-a', 1), SenseInfo('00036998-a', 1), SenseInfo('00800248-a', 0), SenseInfo('02107634-a', 0), SenseInfo('02011622-a', 0), SenseInfo('00462249-a', 0), SenseInfo('00806512-a', 5), SenseInfo('00283703-a', 5), SenseInfo('01454985-a', 2), SenseInfo('01345307-a', 2), SenseInfo('00393992-a', 2), SenseInfo('00803971-a', 1), SenseInfo('00440579-a', 1), SenseInfo('00036998-a', 1), SenseInfo('00800248-a', 0), SenseInfo('02107634-a', 0), SenseInfo('02011622-a', 0), SenseInfo('00462249-a', 0) ],
"_pie-in-the-sky_a_1_rel" : [  ],
"_get_v_from-to_rel" : [ SenseInfo('02210855-v', 235), SenseInfo('00149583-v', 157), SenseInfo('00120796-v', 82), SenseInfo('00522751-v', 64), SenseInfo('02005948-v', 58), SenseInfo('01433294-v', 45), SenseInfo('02108026-v', 36), SenseInfo('01153947-v', 14), SenseInfo('02355596-v', 9), SenseInfo('00770437-v', 7), SenseInfo('01215421-v', 4), SenseInfo('00094460-v', 4), SenseInfo('00087736-v', 4), SenseInfo('01066036-v', 3), SenseInfo('00120316-v', 3), SenseInfo('01026975-v', 2), SenseInfo('00589904-v', 2), SenseInfo('01505958-v', 1), SenseInfo('01401115-v', 1), SenseInfo('00639849-v', 1), SenseInfo('02359340-v', 0), SenseInfo('02208265-v', 0), SenseInfo('02189398-v', 0), SenseInfo('02109645-v', 0), SenseInfo('02108654-v', 0), SenseInfo('02010864-v', 0), SenseInfo('02006573-v', 0), SenseInfo('01771194-v', 0), SenseInfo('01771039-v', 0), SenseInfo('01738107-v', 0), SenseInfo('01643297-v', 0), SenseInfo('01565211-v', 0), SenseInfo('00622384-v', 0), SenseInfo('00345761-v', 0), SenseInfo('00065639-v', 0), SenseInfo('00054628-v', 0) ],
"_halo_n_1_rel" : [ SenseInfo('04951716-n', 4), SenseInfo('13875392-n', 0), SenseInfo('11487424-n', 0) ],
"_tiptoe_v_1_rel" : [ SenseInfo('01924023-v', 1) ],
"_outfit_v_1_rel" : [ SenseInfo('02339413-v', 0) ],
"_awaken_v_1_rel" : [ SenseInfo('00018813-v', 8), SenseInfo('00018526-v', 8), SenseInfo('00736095-v', 1) ],
"_whip_v_1_rel" : [ SenseInfo('01411085-v', 8), SenseInfo('01102997-v', 4), SenseInfo('01891092-v', 3), SenseInfo('01398032-v', 3), SenseInfo('01417868-v', 0), SenseInfo('00863906-v', 0), SenseInfo('01411085-v', 8), SenseInfo('01102997-v', 4), SenseInfo('01891092-v', 3), SenseInfo('01398032-v', 3), SenseInfo('01417868-v', 0), SenseInfo('00863906-v', 0) ],
"_second_v_to_rel" : [ SenseInfo('02556817-v', 0), SenseInfo('02393304-v', 0) ],
"_arrow_n_1_rel" : [ SenseInfo('06818121-n', 17), SenseInfo('02742753-n', 3) ],
"_opt_v_for_rel" : [ SenseInfo('00679389-v', 0) ],
"_tear_v_up_rel" : [ SenseInfo('01573515-v', 19), SenseInfo('01556346-v', 7), SenseInfo('02055267-v', 2), SenseInfo('01384275-v', 1), SenseInfo('00066977-v', 0), SenseInfo('01573515-v', 19), SenseInfo('01556346-v', 7), SenseInfo('02055267-v', 2), SenseInfo('01384275-v', 1), SenseInfo('00066977-v', 0) ],
"_roast_v_cause_rel" : [ SenseInfo('00324560-v', 4), SenseInfo('00851933-v', 0) ],
"_exposition_n_of_rel" : [ SenseInfo('06742426-n', 2), SenseInfo('08407619-n', 0), SenseInfo('06742173-n', 0), SenseInfo('06741993-n', 0) ],
"_wheel_v_in_rel" : [ SenseInfo('02046075-v', 7), SenseInfo('02046441-v', 3), SenseInfo('01887020-v', 3), SenseInfo('01935476-v', 0), SenseInfo('02046075-v', 7), SenseInfo('02046441-v', 3), SenseInfo('01887020-v', 3), SenseInfo('01935476-v', 0) ],
"_herders_a_1_rel" : [  ],
"_tail_n_1_rel" : [ SenseInfo('02157557-n', 6), SenseInfo('15268367-n', 2), SenseInfo('13918274-n', 1), SenseInfo('05559256-n', 1), SenseInfo('10689104-n', 0), SenseInfo('04384199-n', 0), SenseInfo('04384016-n', 0), SenseInfo('04316646-n', 0) ],
"_blink_v_1_rel" : [ SenseInfo('00007739-v', 11), SenseInfo('00008435-v', 2), SenseInfo('02159890-v', 0) ],
"_intermediate_a_1_rel" : [ SenseInfo('01014251-a', 11), SenseInfo('01531957-a', 1) ],
"_pizzeria_n_1_rel" : [ SenseInfo('03952576-n', 0) ],
"_preview_v_1_rel" : [ SenseInfo('02151816-v', 0) ],
"_sundry_a_1_rel" : [ SenseInfo('01199083-a', 4) ],
"_prey_n_1_rel" : [ SenseInfo('10470460-n', 3), SenseInfo('02152881-n', 2), SenseInfo('10470460-n', 3), SenseInfo('02152881-n', 2) ],
"_heavenly_a_1_rel" : [ SenseInfo('02684971-a', 1), SenseInfo('02685153-a', 0), SenseInfo('01178974-a', 0) ],
"_double-cross_n_1_rel" : [ SenseInfo('00749991-n', 0), SenseInfo('00749991-n', 0) ],
"_store_v_1_rel" : [ SenseInfo('02281093-v', 16), SenseInfo('02282506-v', 11) ],
"_energy_n_1_rel" : [ SenseInfo('11452218-n', 31), SenseInfo('05035961-n', 8), SenseInfo('04836683-n', 6), SenseInfo('04633197-n', 2), SenseInfo('14050143-n', 0), SenseInfo('11452079-n', 0), SenseInfo('08132955-n', 0) ],
"_mistrust_n_of_rel" : [ SenseInfo('05698791-n', 0), SenseInfo('04895773-n', 0) ],
"_leave_v_over_rel" : [ SenseInfo('02009433-v', 146), SenseInfo('00613683-v', 63), SenseInfo('02729414-v', 56), SenseInfo('00136991-v', 27), SenseInfo('02015598-v', 20), SenseInfo('02721438-v', 19), SenseInfo('02635659-v', 16), SenseInfo('02383440-v', 14), SenseInfo('02356230-v', 8), SenseInfo('02229055-v', 7), SenseInfo('02730135-v', 5), SenseInfo('00360092-v', 5), SenseInfo('02296153-v', 3), SenseInfo('00613018-v', 3) ],
"_paperback_n_1_rel" : [ SenseInfo('03886432-n', 1) ],
"_unclimbable_a_1_rel" : [ SenseInfo('02083516-a', 0), SenseInfo('01725422-a', 0), SenseInfo('02083516-a', 0), SenseInfo('01725422-a', 0) ],
"_own_n_1_rel" : [ SenseInfo('01768724-a', 259) ],
"_bestride_v_1_rel" : [ SenseInfo('01923414-v', 0) ],
"_syndicate_v_1_rel" : [ SenseInfo('02449183-v', 0), SenseInfo('02449011-v', 0), SenseInfo('02243758-v', 0) ],
"_aside_n_1_rel" : [ SenseInfo('07011075-n', 0), SenseInfo('06600684-n', 0) ],
"_auxiliary_a_1_rel" : [ SenseInfo('01854129-a', 1), SenseInfo('02354897-a', 0) ],
"_way_n_i_rel" : [ SenseInfo('04928903-n', 183), SenseInfo('00172710-n', 61), SenseInfo('08679972-n', 40), SenseInfo('13939604-n', 28), SenseInfo('00415676-n', 19), SenseInfo('04564698-n', 16), SenseInfo('00312691-n', 12), SenseInfo('13777764-n', 10), SenseInfo('05084733-n', 7), SenseInfo('05791764-n', 3), SenseInfo('05839910-n', 1), SenseInfo('13285973-n', 0) ],
"_feline_n_1_rel" : [ SenseInfo('02120997-n', 0) ],
"_lion+tamer_n_1_rel" : [  ],
"_what+with_p_rel" : [  ],
"_ptarmigan_n_1_rel" : [ SenseInfo('01796340-n', 0) ],
"_woe_n_1_rel" : [ SenseInfo('14448910-n', 3), SenseInfo('07533877-n', 0) ],
"_fierce_a_1_rel" : [ SenseInfo('02511528-a', 8), SenseInfo('01511854-a', 5), SenseInfo('01507808-a', 1), SenseInfo('00304949-a', 0), SenseInfo('02511528-a', 8), SenseInfo('01511854-a', 5), SenseInfo('01507808-a', 1), SenseInfo('00304949-a', 0), SenseInfo('02511528-a', 8), SenseInfo('01511854-a', 5), SenseInfo('01507808-a', 1), SenseInfo('00304949-a', 0), SenseInfo('02511528-a', 8), SenseInfo('01511854-a', 5), SenseInfo('01507808-a', 1), SenseInfo('00304949-a', 0) ],
"_humid_a_1_rel" : [ SenseInfo('02549393-a', 0) ],
"_disperse_v_1_rel" : [ SenseInfo('01376245-v', 2), SenseInfo('02030424-v', 1), SenseInfo('00330565-v', 1), SenseInfo('02028994-v', 0), SenseInfo('01616608-v', 0), SenseInfo('00968211-v', 0) ],
"_solitary_a_1_rel" : [ SenseInfo('02250430-a', 3), SenseInfo('02253205-a', 1), SenseInfo('02251212-a', 0), SenseInfo('02214736-a', 0), SenseInfo('01313649-a', 0) ],
"_force+majeure_n_1_rel" : [ SenseInfo('07315350-n', 0) ],
"_bather_n_1_rel" : [ SenseInfo('10683126-n', 1), SenseInfo('09843602-n', 0) ],
"_subminimum_n_1_rel" : [  ],
"_hurry_v_up_rel" : [ SenseInfo('02055649-v', 30), SenseInfo('00459498-v', 8), SenseInfo('00459296-v', 1), SenseInfo('02055649-v', 30), SenseInfo('00459498-v', 8), SenseInfo('00459296-v', 1) ],
"_scoff_v_at_rel" : [ SenseInfo('00850192-v', 4), SenseInfo('00801782-v', 0), SenseInfo('00850192-v', 4), SenseInfo('00801782-v', 0) ],
"_adjunct_a_1_rel" : [ SenseInfo('02354897-a', 0), SenseInfo('00793250-a', 0) ],
"_shaft_v_1_rel" : [ SenseInfo('02362601-v', 0), SenseInfo('01104624-v', 0) ],
"_costly_a_1_rel" : [ SenseInfo('00933941-a', 2), SenseInfo('00933599-a', 2), SenseInfo('00933941-a', 2), SenseInfo('00933599-a', 2), SenseInfo('00933941-a', 2), SenseInfo('00933599-a', 2) ],
"_pursuit_n_of_rel" : [ SenseInfo('00319939-n', 4), SenseInfo('05770391-n', 2), SenseInfo('00432689-n', 0), SenseInfo('00431552-n', 0) ],
"_prof_n_1_rel" : [ SenseInfo('10480730-n', 0) ],
"_meager_a_1_rel" : [ SenseInfo('00106456-a', 4), SenseInfo('00106456-a', 4) ],
"_lessee_n_1_rel" : [ SenseInfo('10252075-n', 0) ],
"_airline_n_1_rel" : [ SenseInfo('02690270-n', 0), SenseInfo('02690081-n', 0) ],
"_horrendous_a_to_rel" : [ SenseInfo('00193799-a', 0), SenseInfo('00193799-a', 0), SenseInfo('00193799-a', 0) ],
"_sort_v_1_rel" : [ SenseInfo('02400378-v', 0), SenseInfo('00654625-v', 0) ],
"_symposium_n_1_rel" : [ SenseInfo('08327616-n', 2) ],
"_grill_n_1_rel" : [ SenseInfo('03459914-n', 2), SenseInfo('03459591-n', 0) ],
"_if_x_then_rel" : [  ],
"_crowded_a_1_rel" : [ SenseInfo('00559690-a', 12) ],
"_resuscitation_n_of_rel" : [ SenseInfo('01048210-n', 0) ],
"_rag_v_2_rel" : [ SenseInfo('01803003-v', 0), SenseInfo('01787955-v', 0), SenseInfo('01725886-v', 0), SenseInfo('00850501-v', 0), SenseInfo('00824767-v', 0), SenseInfo('00338736-v', 0) ],
"_debark_v_1_rel" : [ SenseInfo('01979241-v', 0) ],
"_call_v_forth_rel" : [ SenseInfo('01028748-v', 91), SenseInfo('00971015-v', 51), SenseInfo('00789448-v', 38), SenseInfo('00913065-v', 25), SenseInfo('00792471-v', 25), SenseInfo('02487573-v', 9), SenseInfo('02429810-v', 9), SenseInfo('01067995-v', 1), SenseInfo('01062739-v', 1), SenseInfo('00975036-v', 1), SenseInfo('02643421-v', 0), SenseInfo('02601456-v', 0), SenseInfo('02487901-v', 0), SenseInfo('02359061-v', 0), SenseInfo('02300060-v', 0), SenseInfo('01899017-v', 0), SenseInfo('01068793-v', 0), SenseInfo('00917772-v', 0), SenseInfo('00874002-v', 0), SenseInfo('00869393-v', 0), SenseInfo('00822746-v', 0), SenseInfo('00783523-v', 0), SenseInfo('00754156-v', 0), SenseInfo('00753881-v', 0), SenseInfo('00738747-v', 0), SenseInfo('00738583-v', 0), SenseInfo('00691516-v', 0), SenseInfo('00107231-v', 0) ],
"_blower_n_1_rel" : [ SenseInfo('02855089-n', 3), SenseInfo('03271574-n', 0), SenseInfo('02062430-n', 0) ],
"_tread_n_1_rel" : [ SenseInfo('00285889-n', 2), SenseInfo('04477091-n', 0), SenseInfo('04476972-n', 0), SenseInfo('04476831-n', 0) ],
"_attain_v_1_rel" : [ SenseInfo('02526085-v', 16), SenseInfo('02006834-v', 6), SenseInfo('02286687-v', 0), SenseInfo('02020590-v', 0) ],
"_freak_n_1_rel" : [ SenseInfo('10109443-n', 4), SenseInfo('09769076-n', 0) ],
"_huddle_n_1_rel" : [ SenseInfo('07144416-n', 2), SenseInfo('08184439-n', 0) ],
"_tsar_n_1_rel" : [ SenseInfo('09987239-n', 0) ],
"_adventure_n_1_rel" : [ SenseInfo('00796315-n', 12) ],
"_fast_v_1_rel" : [ SenseInfo('01189604-v', 0), SenseInfo('01189427-v', 0) ],
"_parley_v_1_rel" : [ SenseInfo('00763009-v', 0) ],
"_hail_v_from_rel" : [ SenseInfo('00861725-v', 4), SenseInfo('02743214-v', 1), SenseInfo('00900499-v', 1), SenseInfo('00900376-v', 1), SenseInfo('02759115-v', 0) ],
"_indicative_a_of_rel" : [ SenseInfo('03094520-a', 0), SenseInfo('02091300-a', 0) ],
"_localize_v_cause_rel" : [ SenseInfo('02695895-v', 0), SenseInfo('02692335-v', 0), SenseInfo('02509919-v', 0), SenseInfo('01711749-v', 0), SenseInfo('02695895-v', 0), SenseInfo('02692335-v', 0), SenseInfo('02509919-v', 0), SenseInfo('01711749-v', 0) ],
"_shoe-horn_v_1_rel" : [ SenseInfo('00301544-v', 0), SenseInfo('00301544-v', 0), SenseInfo('00301544-v', 0) ],
"_show+and+tell_n_1_rel" : [  ],
"_domestic_a_1_rel" : [ SenseInfo('01038102-a', 19), SenseInfo('02919594-a', 8), SenseInfo('01038808-a', 3), SenseInfo('02388921-a', 0), SenseInfo('01036754-a', 0), SenseInfo('01038102-a', 19), SenseInfo('02919594-a', 8), SenseInfo('01038808-a', 3), SenseInfo('02388921-a', 0), SenseInfo('01036754-a', 0) ],
"_gentile_n_1_rel" : [ SenseInfo('10166394-n', 0), SenseInfo('09679170-n', 0), SenseInfo('09679028-n', 0), SenseInfo('09678917-n', 0) ],
"_sleeveless_a_1_rel" : [ SenseInfo('02257038-a', 0), SenseInfo('01866812-a', 0) ],
"_virtually_x_deg_rel" : [ SenseInfo('00111451-r', 4), SenseInfo('00073033-r', 4), SenseInfo('00111451-r', 4), SenseInfo('00073033-r', 4) ],
"_flatulent_a_1_rel" : [ SenseInfo('01182974-a', 0), SenseInfo('01175741-a', 0) ],
"_crush_n_1_rel" : [ SenseInfo('14762366-n', 1), SenseInfo('08183398-n', 0), SenseInfo('07544351-n', 0), SenseInfo('00358089-n', 0) ],
"_cultivate_v_1_rel" : [ SenseInfo('01742726-v', 3), SenseInfo('01741446-v', 1), SenseInfo('02388403-v', 0), SenseInfo('00302464-v', 0) ],
"_vend_v_1_rel" : [ SenseInfo('02302817-v', 0) ],
"_resignation_n_1_rel" : [ SenseInfo('07542433-n', 1), SenseInfo('07254267-n', 1), SenseInfo('06511560-n', 1) ],
"_tableland_n_1_rel" : [ SenseInfo('09453008-n', 0) ],
"_unemployed_a_1_rel" : [ SenseInfo('00864693-a', 2), SenseInfo('00864693-a', 2) ],
"_correspond_v_to_rel" : [ SenseInfo('02657219-v', 9), SenseInfo('02633534-v', 6), SenseInfo('01006810-v', 3), SenseInfo('02699497-v', 0), SenseInfo('02657219-v', 9), SenseInfo('02633534-v', 6), SenseInfo('01006810-v', 3), SenseInfo('02699497-v', 0), SenseInfo('02657219-v', 9), SenseInfo('02633534-v', 6), SenseInfo('01006810-v', 3), SenseInfo('02699497-v', 0) ],
"_civilian_n_1_rel" : [ SenseInfo('09924742-n', 2) ],
"_filigree_n_1_rel" : [ SenseInfo('03337822-n', 0) ],
"_apart_a_sel_rel" : [ SenseInfo('00567860-a', 1), SenseInfo('02110161-a', 0) ],
"_gothic_a_1_rel" : [ SenseInfo('03069797-a', 0), SenseInfo('03069643-a', 0), SenseInfo('03069542-a', 0), SenseInfo('01537448-a', 0), SenseInfo('00969103-a', 0) ],
"_metalloid_a_1_rel" : [ SenseInfo('01529479-a', 0) ],
"_radiate_a_1_rel" : [ SenseInfo('02373055-a', 0), SenseInfo('02174188-a', 0) ],
"_flux_n_1_rel" : [ SenseInfo('15278132-n', 18), SenseInfo('07407970-n', 5), SenseInfo('14860102-n', 0), SenseInfo('14044592-n', 0), SenseInfo('14033917-n', 0), SenseInfo('11477384-n', 0), SenseInfo('05089199-n', 0), SenseInfo('00195938-n', 0) ],
"_discuss_v_1_rel" : [ SenseInfo('01034312-v', 54), SenseInfo('00813978-v', 30), SenseInfo('01034312-v', 54), SenseInfo('00813978-v', 30) ],
"_sunset_n_1_rel" : [ SenseInfo('15169248-n', 0), SenseInfo('11517776-n', 0), SenseInfo('07344015-n', 0) ],
"_pessimistic_a_1_rel" : [ SenseInfo('01664581-a', 1), SenseInfo('01664581-a', 1) ],
"_vast_a_1_rel" : [ SenseInfo('01387319-a', 30), SenseInfo('01387319-a', 30), SenseInfo('01387319-a', 30), SenseInfo('01387319-a', 30) ],
"_performance_n_1_rel" : [ SenseInfo('06891493-n', 27), SenseInfo('00550771-n', 19), SenseInfo('00097504-n', 13), SenseInfo('00047106-n', 2), SenseInfo('13525549-n', 0) ],
"_petulant_a_1_rel" : [ SenseInfo('01136541-a', 0) ],
"_out-of-touch_a_1_rel" : [  ],
"_diplomat_n_1_rel" : [ SenseInfo('10013927-n', 4), SenseInfo('10014658-n', 0) ],
"_byronism_n_1_rel" : [  ],
"_theatrical_a_1_rel" : [ SenseInfo('02813315-a', 1), SenseInfo('00796047-a', 1) ],
"_petition_n_1_rel" : [ SenseInfo('06513366-n', 6), SenseInfo('07189130-n', 0) ],
"_force_v_1_rel" : [ SenseInfo('02504562-v', 48), SenseInfo('01650425-v', 17), SenseInfo('01871979-v', 13), SenseInfo('00747418-v', 8), SenseInfo('01527271-v', 3), SenseInfo('01516534-v', 2), SenseInfo('01448100-v', 1), SenseInfo('01350449-v', 1), SenseInfo('01586600-v', 0), SenseInfo('02504562-v', 48), SenseInfo('01650425-v', 17), SenseInfo('01871979-v', 13), SenseInfo('00747418-v', 8), SenseInfo('01527271-v', 3), SenseInfo('01516534-v', 2), SenseInfo('01448100-v', 1), SenseInfo('01350449-v', 1), SenseInfo('01586600-v', 0), SenseInfo('02504562-v', 48), SenseInfo('01650425-v', 17), SenseInfo('01871979-v', 13), SenseInfo('00747418-v', 8), SenseInfo('01527271-v', 3), SenseInfo('01516534-v', 2), SenseInfo('01448100-v', 1), SenseInfo('01350449-v', 1), SenseInfo('01586600-v', 0) ],
"_award_v_1_rel" : [ SenseInfo('02261888-v', 6), SenseInfo('02262278-v', 2), SenseInfo('02261888-v', 6), SenseInfo('02262278-v', 2) ],
"_valuables_n_1_rel" : [ SenseInfo('13371030-n', 0), SenseInfo('13371030-n', 0) ],
"_vice_n_1_rel" : [ SenseInfo('04853873-n', 3), SenseInfo('00747029-n', 0), SenseInfo('04853873-n', 3), SenseInfo('00747029-n', 0) ],
"_try_v_1_rel" : [ SenseInfo('02530167-v', 342), SenseInfo('02531625-v', 16), SenseInfo('02501278-v', 4), SenseInfo('01195299-v', 2), SenseInfo('02500902-v', 0), SenseInfo('01798782-v', 0), SenseInfo('01798452-v', 0), SenseInfo('00444975-v', 0), SenseInfo('00047317-v', 0), SenseInfo('02530167-v', 342), SenseInfo('02531625-v', 16), SenseInfo('02501278-v', 4), SenseInfo('01195299-v', 2), SenseInfo('02500902-v', 0), SenseInfo('01798782-v', 0), SenseInfo('01798452-v', 0), SenseInfo('00444975-v', 0), SenseInfo('00047317-v', 0), SenseInfo('02530167-v', 342), SenseInfo('02531625-v', 16), SenseInfo('02501278-v', 4), SenseInfo('01195299-v', 2), SenseInfo('02500902-v', 0), SenseInfo('01798782-v', 0), SenseInfo('01798452-v', 0), SenseInfo('00444975-v', 0), SenseInfo('00047317-v', 0), SenseInfo('02530167-v', 342), SenseInfo('02531625-v', 16), SenseInfo('02501278-v', 4), SenseInfo('01195299-v', 2), SenseInfo('02500902-v', 0), SenseInfo('01798782-v', 0), SenseInfo('01798452-v', 0), SenseInfo('00444975-v', 0), SenseInfo('00047317-v', 0), SenseInfo('02530167-v', 342), SenseInfo('02531625-v', 16), SenseInfo('02501278-v', 4), SenseInfo('01195299-v', 2), SenseInfo('02500902-v', 0), SenseInfo('01798782-v', 0), SenseInfo('01798452-v', 0), SenseInfo('00444975-v', 0), SenseInfo('00047317-v', 0) ],
"_marshall_v_1_rel" : [  ],
"_procedure_n_1_rel" : [ SenseInfo('01023820-n', 41), SenseInfo('00577068-n', 15), SenseInfo('06582403-n', 0), SenseInfo('01023636-n', 0), SenseInfo('01023820-n', 41), SenseInfo('00577068-n', 15), SenseInfo('06582403-n', 0), SenseInfo('01023636-n', 0), SenseInfo('01023820-n', 41), SenseInfo('00577068-n', 15), SenseInfo('06582403-n', 0), SenseInfo('01023636-n', 0) ],
"_rob_v_of_rel" : [ SenseInfo('02321391-v', 5), SenseInfo('02319050-v', 5), SenseInfo('02321391-v', 5), SenseInfo('02319050-v', 5) ],
"_lock_v_away_rel" : [ SenseInfo('01348174-v', 8), SenseInfo('01510827-v', 7), SenseInfo('00219775-v', 4), SenseInfo('01606736-v', 2), SenseInfo('01606018-v', 2), SenseInfo('01810320-v', 1), SenseInfo('01347678-v', 1), SenseInfo('02050865-v', 0), SenseInfo('01655347-v', 0) ],
"_pirogue_n_1_rel" : [ SenseInfo('03254374-n', 1) ],
"_chop_v_up_rel" : [ SenseInfo('01258091-v', 2), SenseInfo('01871471-v', 0), SenseInfo('01758410-v', 0), SenseInfo('01415454-v', 0), SenseInfo('01257173-v', 0), SenseInfo('01124535-v', 0) ],
"_respectful_a_of_rel" : [ SenseInfo('01993940-a', 3), SenseInfo('02012333-a', 0) ],
"_present_v_with_rel" : [ SenseInfo('02148788-v', 40), SenseInfo('00772967-v', 28), SenseInfo('01711445-v', 14), SenseInfo('02262752-v', 13), SenseInfo('02722663-v', 7), SenseInfo('02261888-v', 3), SenseInfo('02200686-v', 3), SenseInfo('00989602-v', 3), SenseInfo('00901103-v', 2), SenseInfo('01688771-v', 1), SenseInfo('01066433-v', 0), SenseInfo('00901651-v', 0), SenseInfo('00899956-v', 0) ],
"_celebration_n_of_rel" : [ SenseInfo('07450651-n', 5), SenseInfo('00428000-n', 1), SenseInfo('00516086-n', 0) ],
"_wholesale_a_1_rel" : [ SenseInfo('00774182-a', 0) ],
"_capitalism_n_1_rel" : [ SenseInfo('08364143-n', 9) ],
"_rack_v_1_rel" : [ SenseInfo('01960491-v', 2), SenseInfo('01798678-v', 1), SenseInfo('02408722-v', 0), SenseInfo('02241107-v', 0), SenseInfo('01946138-v', 0), SenseInfo('01940782-v', 0), SenseInfo('01855058-v', 0), SenseInfo('01802689-v', 0), SenseInfo('01669419-v', 0), SenseInfo('01213348-v', 0), SenseInfo('00071547-v', 0) ],
"_chockstone_n_1_rel" : [  ],
"_idiomatic_a_1_rel" : [ SenseInfo('03004358-a', 1) ],
"_once+and+for+all_a_1_rel" : [  ],
"_still_a_sel_rel" : [ SenseInfo('01564315-a', 16), SenseInfo('01919428-a', 9), SenseInfo('00302951-a', 3), SenseInfo('01565751-a', 2), SenseInfo('02277485-a', 0), SenseInfo('01241600-a', 0) ],
"_promote_v_1_rel" : [ SenseInfo('02554922-v', 31), SenseInfo('02397637-v', 5), SenseInfo('00976653-v', 2), SenseInfo('01080523-v', 0), SenseInfo('01080235-v', 0) ],
"_sternum_n_1_rel" : [ SenseInfo('05281189-n', 1) ],
"_curl_v_1_rel" : [ SenseInfo('00362128-v', 3), SenseInfo('02098458-v', 2), SenseInfo('01523986-v', 2), SenseInfo('01223616-v', 1), SenseInfo('01074074-v', 0) ],
"_disambiguate_v_1_rel" : [ SenseInfo('00957178-v', 0) ],
"_raise_v_cause_rel" : [ SenseInfo('00158503-v', 33), SenseInfo('01974062-v', 26), SenseInfo('00941166-v', 21), SenseInfo('02306281-v', 14), SenseInfo('01739814-v', 10), SenseInfo('02539788-v', 7), SenseInfo('01629958-v', 7), SenseInfo('01973759-v', 4), SenseInfo('01661243-v', 2), SenseInfo('01759326-v', 1), SenseInfo('01755651-v', 1), SenseInfo('00544549-v', 1), SenseInfo('00229605-v', 1), SenseInfo('02397637-v', 0), SenseInfo('01975587-v', 0), SenseInfo('01156406-v', 0), SenseInfo('01156291-v', 0), SenseInfo('01098452-v', 0), SenseInfo('01025246-v', 0), SenseInfo('00950782-v', 0), SenseInfo('00851625-v', 0), SenseInfo('00744070-v', 0), SenseInfo('00641929-v', 0), SenseInfo('00557537-v', 0), SenseInfo('00549982-v', 0), SenseInfo('00354195-v', 0), SenseInfo('00098517-v', 0) ],
"_quirt_n_1_rel" : [ SenseInfo('04035748-n', 7) ],
"_editor+in+chief_n_1_rel" : [ SenseInfo('10044879-n', 0), SenseInfo('10044879-n', 0), SenseInfo('10044879-n', 0), SenseInfo('10044879-n', 0) ],
"_exponent_n_1_rel" : [ SenseInfo('09774783-n', 0), SenseInfo('09618760-n', 0), SenseInfo('06812417-n', 0) ],
"_close_v_out_rel" : [ SenseInfo('01345109-v', 32), SenseInfo('01346978-v', 20), SenseInfo('02426395-v', 18), SenseInfo('02425913-v', 13), SenseInfo('02610628-v', 2), SenseInfo('00763831-v', 1), SenseInfo('02754276-v', 0), SenseInfo('02375619-v', 0), SenseInfo('02140781-v', 0), SenseInfo('02104503-v', 0), SenseInfo('02054541-v', 0), SenseInfo('02054382-v', 0), SenseInfo('01607288-v', 0), SenseInfo('01478423-v', 0), SenseInfo('01423285-v', 0), SenseInfo('01291941-v', 0), SenseInfo('00352137-v', 0), SenseInfo('01345109-v', 32), SenseInfo('01346978-v', 20), SenseInfo('02426395-v', 18), SenseInfo('02425913-v', 13), SenseInfo('02610628-v', 2), SenseInfo('00763831-v', 1), SenseInfo('02754276-v', 0), SenseInfo('02375619-v', 0), SenseInfo('02140781-v', 0), SenseInfo('02104503-v', 0), SenseInfo('02054541-v', 0), SenseInfo('02054382-v', 0), SenseInfo('01607288-v', 0), SenseInfo('01478423-v', 0), SenseInfo('01423285-v', 0), SenseInfo('01291941-v', 0), SenseInfo('00352137-v', 0) ],
"_mop_n_1_rel" : [ SenseInfo('04367480-n', 0) ],
"_involvement_n_in_rel" : [ SenseInfo('01239064-n', 4), SenseInfo('13793504-n', 1), SenseInfo('05682950-n', 1), SenseInfo('13931889-n', 0), SenseInfo('13924659-n', 0) ],
"_awfulness_n_1_rel" : [ SenseInfo('04782116-n', 1), SenseInfo('04782116-n', 1) ],
"_makings_n_1_rel" : [ SenseInfo('00923995-n', 7), SenseInfo('04717139-n', 0), SenseInfo('03714899-n', 0), SenseInfo('00923995-n', 7), SenseInfo('04717139-n', 0), SenseInfo('03714899-n', 0) ],
"_bowsprit_n_1_rel" : [ SenseInfo('02883004-n', 0) ],
"_bilberry_n_1_rel" : [ SenseInfo('12248574-n', 0), SenseInfo('12248359-n', 0), SenseInfo('07743224-n', 0) ],
"_suitcase_n_of_rel" : [ SenseInfo('02773838-n', 11) ],
"_distort_v_cause_rel" : [ SenseInfo('00835903-v', 5), SenseInfo('01223182-v', 1), SenseInfo('01350699-v', 0), SenseInfo('00836926-v', 0), SenseInfo('00476744-v', 0) ],
"_story_n_1_rel" : [ SenseInfo('07221094-n', 36), SenseInfo('06369829-n', 14), SenseInfo('03365991-n', 7), SenseInfo('06514093-n', 3), SenseInfo('06681551-n', 2), SenseInfo('06757057-n', 1) ],
"_so+long+as_x_rel" : [  ],
"_visually+impaired_n_1_rel" : [  ],
"_waste_n_of_rel" : [ SenseInfo('14856263-n', 5), SenseInfo('00742645-n', 4), SenseInfo('04894964-n', 1), SenseInfo('08504594-n', 0), SenseInfo('01252124-n', 0) ],
"_quieten_v_1_rel" : [ SenseInfo('02190188-v', 0), SenseInfo('01764800-v', 0), SenseInfo('00461493-v', 0) ],
"_all+week+long_a_1_rel" : [  ],
"_decency_n_1_rel" : [ SenseInfo('04900739-n', 2), SenseInfo('04871259-n', 2) ],
"_surf_v_1_rel" : [ SenseInfo('01948077-v', 0), SenseInfo('01315333-v', 0), SenseInfo('00551611-v', 0), SenseInfo('01948077-v', 0), SenseInfo('01315333-v', 0), SenseInfo('00551611-v', 0) ],
"_incumbency_n_1_rel" : [ SenseInfo('15291498-n', 0), SenseInfo('01131425-n', 0), SenseInfo('00593512-n', 0) ],
"_bark_n_1_rel" : [ SenseInfo('13162297-n', 4), SenseInfo('07376731-n', 1), SenseInfo('02793199-n', 1), SenseInfo('07376621-n', 0) ],
"_cognizance_n_1_rel" : [ SenseInfo('05675905-n', 1), SenseInfo('05805157-n', 0), SenseInfo('05710481-n', 0) ],
"_milk_v_1_rel" : [ SenseInfo('00194170-v', 3), SenseInfo('01164906-v', 1), SenseInfo('00194373-v', 0) ],
"_illegitimate_a_1_rel" : [ SenseInfo('01403760-a', 1), SenseInfo('01407465-a', 0) ],
"_brake_v_1_rel" : [ SenseInfo('01863817-v', 0), SenseInfo('01863593-v', 0) ],
"_embower_v_1_rel" : [ SenseInfo('01390210-v', 0) ],
"_imperceptible_a_1_rel" : [ SenseInfo('01748318-a', 0), SenseInfo('01748318-a', 0) ],
"_tabby_n_1_rel" : [ SenseInfo('02123045-n', 0), SenseInfo('02122878-n', 0) ],
"_set_v_about_rel" : [ SenseInfo('01494310-v', 30), SenseInfo('00699815-v', 29), SenseInfo('00947077-v', 12), SenseInfo('01062395-v', 10), SenseInfo('00298896-v', 9), SenseInfo('01607445-v', 6), SenseInfo('00406243-v', 5), SenseInfo('00298556-v', 5), SenseInfo('01711749-v', 3), SenseInfo('01970646-v', 2), SenseInfo('01706129-v', 2), SenseInfo('01567275-v', 2), SenseInfo('01628899-v', 1), SenseInfo('00442669-v', 1), SenseInfo('01744888-v', 0), SenseInfo('01613239-v', 0), SenseInfo('01530273-v', 0), SenseInfo('01247322-v', 0), SenseInfo('01115006-v', 0), SenseInfo('00673448-v', 0), SenseInfo('00408085-v', 0), SenseInfo('00407848-v', 0), SenseInfo('00296178-v', 0), SenseInfo('00056188-v', 0), SenseInfo('00038849-v', 0), SenseInfo('01494310-v', 30), SenseInfo('00699815-v', 29), SenseInfo('00947077-v', 12), SenseInfo('01062395-v', 10), SenseInfo('00298896-v', 9), SenseInfo('01607445-v', 6), SenseInfo('00406243-v', 5), SenseInfo('00298556-v', 5), SenseInfo('01711749-v', 3), SenseInfo('01970646-v', 2), SenseInfo('01706129-v', 2), SenseInfo('01567275-v', 2), SenseInfo('01628899-v', 1), SenseInfo('00442669-v', 1), SenseInfo('01744888-v', 0), SenseInfo('01613239-v', 0), SenseInfo('01530273-v', 0), SenseInfo('01247322-v', 0), SenseInfo('01115006-v', 0), SenseInfo('00673448-v', 0), SenseInfo('00408085-v', 0), SenseInfo('00407848-v', 0), SenseInfo('00296178-v', 0), SenseInfo('00056188-v', 0), SenseInfo('00038849-v', 0) ],
"_athlete_n_1_rel" : [ SenseInfo('09820263-n', 7) ],
"_teenager_n_1_rel" : [ SenseInfo('09772029-n', 12), SenseInfo('09772029-n', 12) ],
"_read_v_in_rel" : [ SenseInfo('00625119-v', 115), SenseInfo('02730813-v', 17), SenseInfo('00626428-v', 15), SenseInfo('00627520-v', 5), SenseInfo('00627091-v', 5), SenseInfo('00624476-v', 5), SenseInfo('00599992-v', 4), SenseInfo('00922867-v', 3), SenseInfo('01718755-v', 0), SenseInfo('00620239-v', 0), SenseInfo('00593852-v', 0) ],
"_typhoid_n_1_rel" : [ SenseInfo('14144416-n', 1) ],
"_wave_n_of_rel" : [ SenseInfo('07352190-n', 40), SenseInfo('00346095-n', 9), SenseInfo('07345593-n', 7), SenseInfo('07352835-n', 2), SenseInfo('07274027-n', 1), SenseInfo('05259240-n', 1), SenseInfo('13868944-n', 0), SenseInfo('11524451-n', 0), SenseInfo('10771066-n', 0) ],
"_free_a_1_rel" : [ SenseInfo('01061489-a', 38), SenseInfo('01058363-a', 4), SenseInfo('01710260-a', 3), SenseInfo('01624010-a', 3), SenseInfo('01060947-a', 1), SenseInfo('01065694-a', 0), SenseInfo('01624115-a', 0), SenseInfo('00927978-a', 0), SenseInfo('00916199-a', 0), SenseInfo('01061489-a', 38), SenseInfo('01058363-a', 4), SenseInfo('01710260-a', 3), SenseInfo('01624010-a', 3), SenseInfo('01060947-a', 1), SenseInfo('01065694-a', 0), SenseInfo('01624115-a', 0), SenseInfo('00927978-a', 0), SenseInfo('00916199-a', 0), SenseInfo('01061489-a', 38), SenseInfo('01058363-a', 4), SenseInfo('01710260-a', 3), SenseInfo('01624010-a', 3), SenseInfo('01060947-a', 1), SenseInfo('01065694-a', 0), SenseInfo('01624115-a', 0), SenseInfo('00927978-a', 0), SenseInfo('00916199-a', 0), SenseInfo('01061489-a', 38), SenseInfo('01058363-a', 4), SenseInfo('01710260-a', 3), SenseInfo('01624010-a', 3), SenseInfo('01060947-a', 1), SenseInfo('01065694-a', 0), SenseInfo('01624115-a', 0), SenseInfo('00927978-a', 0), SenseInfo('00916199-a', 0), SenseInfo('01061489-a', 38), SenseInfo('01058363-a', 4), SenseInfo('01710260-a', 3), SenseInfo('01624010-a', 3), SenseInfo('01060947-a', 1), SenseInfo('01065694-a', 0), SenseInfo('01624115-a', 0), SenseInfo('00927978-a', 0), SenseInfo('00916199-a', 0), SenseInfo('01061489-a', 38), SenseInfo('01058363-a', 4), SenseInfo('01710260-a', 3), SenseInfo('01624010-a', 3), SenseInfo('01060947-a', 1), SenseInfo('01065694-a', 0), SenseInfo('01624115-a', 0), SenseInfo('00927978-a', 0), SenseInfo('00916199-a', 0) ],
"_fence_v_1_rel" : [ SenseInfo('01588134-v', 1), SenseInfo('02210754-v', 0), SenseInfo('01146918-v', 0), SenseInfo('01130607-v', 0), SenseInfo('00773432-v', 0) ],
"_mandella_n_1_rel" : [  ],
"_broadcloth_n_1_rel" : [ SenseInfo('02903852-n', 0), SenseInfo('02903727-n', 0) ],
"_pity_v_1_rel" : [ SenseInfo('01821996-v', 4) ],
"_ache_v_1_rel" : [ SenseInfo('02121511-v', 3), SenseInfo('01805684-v', 3), SenseInfo('02122164-v', 2), SenseInfo('02121511-v', 3), SenseInfo('01805684-v', 3), SenseInfo('02122164-v', 2) ],
"_post+trip_a_1_rel" : [  ],
"_immortal_a_1_rel" : [ SenseInfo('01557903-a', 5) ],
"_cue_v_1_rel" : [ SenseInfo('00877848-v', 0) ],
"_horrid_a_1_rel" : [ SenseInfo('01127661-a', 1), SenseInfo('01626562-a', 0) ],
"_bullet_n_1_rel" : [ SenseInfo('02916350-n', 35), SenseInfo('02917067-n', 0), SenseInfo('00108181-n', 0) ],
"_hacked+up_a_1_rel" : [  ],
"_manganese_n_1_rel" : [ SenseInfo('14644654-n', 0) ],
"_barrier_n_to_rel" : [ SenseInfo('02796623-n', 4), SenseInfo('05690916-n', 3), SenseInfo('09214581-n', 2) ],
"_pickaxe_n_1_rel" : [ SenseInfo('03929202-n', 0) ],
"_breath_n_1_rel" : [ SenseInfo('00835032-n', 15), SenseInfo('14841770-n', 14), SenseInfo('15274695-n', 1), SenseInfo('07163988-n', 1), SenseInfo('11432262-n', 0) ],
"_counterfeit_n_1_rel" : [ SenseInfo('03562262-n', 0), SenseInfo('03562262-n', 0) ],
"_beard_v_1_rel" : [ SenseInfo('02687730-v', 1) ],
"_acquirement_n_1_rel" : [ SenseInfo('05637558-n', 0) ],
"_unsophisticated_a_1_rel" : [ SenseInfo('02273088-a', 0), SenseInfo('02175980-a', 0), SenseInfo('00636891-a', 0), SenseInfo('02273088-a', 0), SenseInfo('02175980-a', 0), SenseInfo('00636891-a', 0) ],
"_elastic_a_1_rel" : [ SenseInfo('00843146-a', 5), SenseInfo('01028163-a', 1) ],
"_chip_n_1_rel" : [ SenseInfo('09222051-n', 1), SenseInfo('03020563-n', 1), SenseInfo('09243906-n', 0), SenseInfo('07712559-n', 0), SenseInfo('04692908-n', 0), SenseInfo('03020416-n', 0), SenseInfo('03020034-n', 0), SenseInfo('00573530-n', 0), SenseInfo('00377169-n', 0) ],
"_map_v_out_rel" : [ SenseInfo('01687876-v', 3), SenseInfo('00710606-v', 1), SenseInfo('02695709-v', 0), SenseInfo('01756149-v', 0), SenseInfo('01688114-v', 0), SenseInfo('00380698-v', 0) ],
"_fresh-baked_a_1_rel" : [  ],
"_catch_v_on_rel" : [ SenseInfo('00725748-v', 19), SenseInfo('02117955-v', 14), SenseInfo('01401115-v', 10), SenseInfo('01439190-v', 8), SenseInfo('01215421-v', 8), SenseInfo('01327816-v', 7), SenseInfo('01505958-v', 6), SenseInfo('01480149-v', 4), SenseInfo('02018372-v', 3), SenseInfo('02248299-v', 2), SenseInfo('01155090-v', 2), SenseInfo('00543016-v', 2), SenseInfo('02510905-v', 1), SenseInfo('02189168-v', 1), SenseInfo('02150948-v', 1), SenseInfo('01328012-v', 1), SenseInfo('00599835-v', 1), SenseInfo('00589904-v', 1), SenseInfo('00087988-v', 1), SenseInfo('02761134-v', 0), SenseInfo('02189398-v', 0), SenseInfo('02109645-v', 0), SenseInfo('01806505-v', 0), SenseInfo('01738107-v', 0), SenseInfo('01480469-v', 0), SenseInfo('01380366-v', 0), SenseInfo('01082454-v', 0), SenseInfo('00726009-v', 0), SenseInfo('00460357-v', 0), SenseInfo('00725748-v', 19), SenseInfo('02117955-v', 14), SenseInfo('01401115-v', 10), SenseInfo('01439190-v', 8), SenseInfo('01215421-v', 8), SenseInfo('01327816-v', 7), SenseInfo('01505958-v', 6), SenseInfo('01480149-v', 4), SenseInfo('02018372-v', 3), SenseInfo('02248299-v', 2), SenseInfo('01155090-v', 2), SenseInfo('00543016-v', 2), SenseInfo('02510905-v', 1), SenseInfo('02189168-v', 1), SenseInfo('02150948-v', 1), SenseInfo('01328012-v', 1), SenseInfo('00599835-v', 1), SenseInfo('00589904-v', 1), SenseInfo('00087988-v', 1), SenseInfo('02761134-v', 0), SenseInfo('02189398-v', 0), SenseInfo('02109645-v', 0), SenseInfo('01806505-v', 0), SenseInfo('01738107-v', 0), SenseInfo('01480469-v', 0), SenseInfo('01380366-v', 0), SenseInfo('01082454-v', 0), SenseInfo('00726009-v', 0), SenseInfo('00460357-v', 0) ],
"_believe_v_sel_rel" : [ SenseInfo('00683280-v', 118), SenseInfo('00689344-v', 72), SenseInfo('00721098-v', 37), SenseInfo('00684273-v', 10), SenseInfo('00684068-v', 2) ],
"_sinewy_a_1_rel" : [ SenseInfo('02446239-a', 2), SenseInfo('02811265-a', 0), SenseInfo('02321809-a', 0) ],
"_predisposition_n_1_rel" : [ SenseInfo('14531772-n', 0), SenseInfo('06200178-n', 0), SenseInfo('04943464-n', 0) ],
"_confinement_n_1_rel" : [ SenseInfo('14048441-n', 1), SenseInfo('01146576-n', 1), SenseInfo('13998576-n', 0), SenseInfo('01148614-n', 0) ],
"_handycam_n_1_rel" : [  ],
"_blurry_a_1_rel" : [ SenseInfo('00781644-a', 0), SenseInfo('00781644-a', 0), SenseInfo('00781644-a', 0) ],
"_low-life_n_1_rel" : [ SenseInfo('10539715-n', 0), SenseInfo('10539715-n', 0) ],
"_propane_n_1_rel" : [ SenseInfo('14691686-n', 0) ],
"_billboard_n_1_rel" : [ SenseInfo('02839110-n', 0) ],
"_tolerable_a_1_rel" : [ SenseInfo('02435026-a', 0), SenseInfo('02080937-a', 0), SenseInfo('02435026-a', 0), SenseInfo('02080937-a', 0) ],
"_nicaraguan_a_1_rel" : [ SenseInfo('03090939-a', 0) ],
"_funicular_n_1_rel" : [ SenseInfo('02934641-n', 0) ],
"_all+along_a_1_rel" : [  ],
"_hopeful_n_1_rel" : [ SenseInfo('09801533-n', 0) ],
"_elector_n_1_rel" : [ SenseInfo('10760340-n', 1), SenseInfo('10473273-n', 0) ],
"_scud_v_1_rel" : [ SenseInfo('02061495-v', 1), SenseInfo('01946138-v', 0) ],
"_count_v_as_rel" : [ SenseInfo('00948071-v', 23), SenseInfo('02645839-v', 7), SenseInfo('00950431-v', 4), SenseInfo('00947857-v', 3), SenseInfo('02731632-v', 2), SenseInfo('00685081-v', 2), SenseInfo('02747140-v', 0), SenseInfo('00712708-v', 0), SenseInfo('00712556-v', 0), SenseInfo('00948071-v', 23), SenseInfo('02645839-v', 7), SenseInfo('00950431-v', 4), SenseInfo('00947857-v', 3), SenseInfo('02731632-v', 2), SenseInfo('00685081-v', 2), SenseInfo('02747140-v', 0), SenseInfo('00712708-v', 0), SenseInfo('00712556-v', 0) ],
"_usurp_v_1_rel" : [ SenseInfo('02274482-v', 2), SenseInfo('02406287-v', 0) ],
"_inclusive_a_1_rel" : [ SenseInfo('01863680-a', 2), SenseInfo('01863680-a', 2) ],
"_mess_n_1_rel" : [ SenseInfo('14500047-n', 12), SenseInfo('14409489-n', 1), SenseInfo('07650792-n', 1), SenseInfo('07565608-n', 1), SenseInfo('03751065-n', 1), SenseInfo('13774404-n', 0) ],
"_outerwear_n_1_rel" : [ SenseInfo('03859495-n', 0) ],
"_musical_n_1_rel" : [ SenseInfo('07019172-n', 2) ],
"_cater_v_for_rel" : [ SenseInfo('01182709-v', 4), SenseInfo('01180844-v', 0) ],
"_due_a_1_rel" : [ SenseInfo('00136354-a', 6), SenseInfo('00929916-a', 1), SenseInfo('00137725-a', 0), SenseInfo('00171872-a', 0), SenseInfo('00136354-a', 6), SenseInfo('00929916-a', 1), SenseInfo('00137725-a', 0), SenseInfo('00171872-a', 0), SenseInfo('00136354-a', 6), SenseInfo('00929916-a', 1), SenseInfo('00137725-a', 0), SenseInfo('00171872-a', 0), SenseInfo('00136354-a', 6), SenseInfo('00929916-a', 1), SenseInfo('00137725-a', 0), SenseInfo('00171872-a', 0), SenseInfo('00136354-a', 6), SenseInfo('00929916-a', 1), SenseInfo('00137725-a', 0), SenseInfo('00171872-a', 0) ],
"_outdated_a_1_rel" : [ SenseInfo('00669138-a', 1) ],
"_prolongation_n_of_rel" : [ SenseInfo('01018366-n', 1), SenseInfo('05133535-n', 0), SenseInfo('05051896-n', 0) ],
"_shake_v_by_rel" : [ SenseInfo('01889610-v', 42), SenseInfo('00014034-v', 14), SenseInfo('01891638-v', 8), SenseInfo('01875295-v', 6), SenseInfo('00167385-v', 6), SenseInfo('01761706-v', 2), SenseInfo('02073545-v', 1), SenseInfo('00559556-v', 1), SenseInfo('00992518-v', 0) ],
"_columnist_n_1_rel" : [ SenseInfo('09939154-n', 1) ],
"_amok_a_1_rel" : [ SenseInfo('02074673-a', 0) ],
"_eyeball_n_1_rel" : [ SenseInfo('05316025-n', 1) ],
"_slosh_v_1_rel" : [ SenseInfo('02186868-v', 0), SenseInfo('01921591-v', 0), SenseInfo('01374587-v', 0) ],
"_backdrop_n_1_rel" : [ SenseInfo('02768864-n', 1) ],
"_per-capita_a_1_rel" : [ SenseInfo('00482452-a', 14), SenseInfo('00482452-a', 14) ],
"_food_n_1_rel" : [ SenseInfo('00021265-n', 29), SenseInfo('07555863-n', 0), SenseInfo('05811214-n', 0), SenseInfo('00021265-n', 29), SenseInfo('07555863-n', 0), SenseInfo('05811214-n', 0), SenseInfo('00021265-n', 29), SenseInfo('07555863-n', 0), SenseInfo('05811214-n', 0) ],
"_chemistry_n_1_rel" : [ SenseInfo('06084469-n', 5), SenseInfo('14580752-n', 0), SenseInfo('13840958-n', 0) ],
"_cognate_a_with_rel" : [ SenseInfo('01973969-a', 1), SenseInfo('01973823-a', 0), SenseInfo('01971846-a', 0) ],
"_alert_v_to_rel" : [ SenseInfo('00872414-v', 9) ],
"_adore_v_1_rel" : [ SenseInfo('01777817-v', 1) ],
"_idler_n_1_rel" : [ SenseInfo('10197967-n', 2) ],
"_pitchfork_n_1_rel" : [ SenseInfo('03950359-n', 2) ],
"_rock_n_1_rel" : [ SenseInfo('09416076-n', 14), SenseInfo('14696793-n', 6), SenseInfo('11266920-n', 0), SenseInfo('10535366-n', 0), SenseInfo('07609083-n', 0), SenseInfo('07064715-n', 0), SenseInfo('00348008-n', 0) ],
"_kayak_v_dir_rel" : [ SenseInfo('01947735-v', 0) ],
"_belt_v_1_rel" : [ SenseInfo('01704030-v', 1), SenseInfo('01415162-v', 1), SenseInfo('01366061-v', 0) ],
"_micro_a_1_rel" : [ SenseInfo('01393976-a', 0), SenseInfo('01393976-a', 0) ],
"_sub+notebook_n_1_rel" : [  ],
"_ache_n_1_rel" : [ SenseInfo('14323683-n', 2) ],
"_gourmet_n_1_rel" : [ SenseInfo('10061656-n', 2) ],
"_cf_v_1_rel" : [  ],
"_goodness_n_1_rel" : [ SenseInfo('05142180-n', 7), SenseInfo('04849241-n', 0) ],
"_up-regulate_v_1_rel" : [  ],
"_claustrophobia_n_1_rel" : [ SenseInfo('14383252-n', 1) ],
"_raid_n_1_rel" : [ SenseInfo('00976953-n', 3), SenseInfo('00777324-n', 0) ],
"_transfer_n_of_rel" : [ SenseInfo('00315986-n', 20), SenseInfo('10724372-n', 1), SenseInfo('00201671-n', 1), SenseInfo('06519480-n', 0), SenseInfo('05756203-n', 0), SenseInfo('01107932-n', 0) ],
"_foodstuff_n_1_rel" : [ SenseInfo('03461119-n', 1), SenseInfo('07566340-n', 0) ],
"_applet_n_1_rel" : [ SenseInfo('06570647-n', 0) ],
"_bruise_v_1_rel" : [ SenseInfo('01492725-v', 2), SenseInfo('01793177-v', 0), SenseInfo('00339268-v', 0), SenseInfo('00259560-v', 0) ],
"_cast_v_down_rel" : [ SenseInfo('01632897-v', 15), SenseInfo('02236023-v', 3), SenseInfo('01710481-v', 2), SenseInfo('01507143-v', 1), SenseInfo('02385813-v', 0), SenseInfo('01881180-v', 0), SenseInfo('01662771-v', 0), SenseInfo('01513430-v', 0), SenseInfo('01078050-v', 0), SenseInfo('00981276-v', 0), SenseInfo('00076400-v', 0) ],
"_amidst_p_rel" : [  ],
"_keyboard_n_1_rel" : [ SenseInfo('03614007-n', 2), SenseInfo('03613873-n', 0) ],
"_mire_v_1_rel" : [ SenseInfo('02678287-v', 0), SenseInfo('01835103-v', 0), SenseInfo('01834896-v', 0), SenseInfo('01534745-v', 0) ],
"_outgoing_a_1_rel" : [ SenseInfo('01295443-a', 2), SenseInfo('01294185-a', 0), SenseInfo('02258249-a', 0) ],
"_audacious_a_1_rel" : [ SenseInfo('00250119-a', 1), SenseInfo('00155144-a', 0), SenseInfo('00066146-a', 0) ],
"_frightful_a_1_rel" : [ SenseInfo('00193480-a', 4), SenseInfo('01677200-a', 1), SenseInfo('01127147-a', 0) ],
"_csr_n_1_rel" : [  ],
"_unwashed_a_1_rel" : [ SenseInfo('01593079-a', 0), SenseInfo('00423874-a', 0), SenseInfo('01593079-a', 0), SenseInfo('00423874-a', 0) ],
"_old+age_n_1_rel" : [ SenseInfo('15153787-n', 1) ],
"_parisian_n_1_rel" : [ SenseInfo('09708750-n', 0) ],
"_workplace_n_1_rel" : [ SenseInfo('04602044-n', 0) ],
"_nourishment_n_1_rel" : [ SenseInfo('07570720-n', 1), SenseInfo('00664849-n', 0) ],
"_spindle_v_1_rel" : [  ],
"_torque_n_1_rel" : [ SenseInfo('11519702-n', 0) ],
"_author_n_of_rel" : [ SenseInfo('10794014-n', 38), SenseInfo('10126177-n', 6) ],
"_cozy_a_1_rel" : [ SenseInfo('00477284-a', 2), SenseInfo('01076145-a', 0), SenseInfo('00452773-a', 0), SenseInfo('00477284-a', 2), SenseInfo('01076145-a', 0), SenseInfo('00452773-a', 0), SenseInfo('00477284-a', 2), SenseInfo('01076145-a', 0), SenseInfo('00452773-a', 0), SenseInfo('00477284-a', 2), SenseInfo('01076145-a', 0), SenseInfo('00452773-a', 0) ],
"_in+behalf+of_p_rel" : [  ],
"_ash_n_1_rel" : [ SenseInfo('14769160-n', 2), SenseInfo('12303462-n', 1), SenseInfo('12303921-n', 0) ],
"_all+around_p_rel" : [ SenseInfo('00526541-a', 0), SenseInfo('00526541-a', 0) ],
"_horseshoe_n_1_rel" : [ SenseInfo('03539546-n', 0), SenseInfo('03539433-n', 0) ],
"_people_n_of_rel" : [ SenseInfo('07942152-n', 257), SenseInfo('08160276-n', 28), SenseInfo('07971141-n', 3), SenseInfo('08180190-n', 1) ],
"_signature_n_1_rel" : [ SenseInfo('06404582-n', 1), SenseInfo('04931428-n', 1), SenseInfo('07029088-n', 0), SenseInfo('06863618-n', 0), SenseInfo('06256041-n', 0) ],
"_pulpit_n_1_rel" : [ SenseInfo('03159640-n', 2) ],
"_red-flag_v_1_rel" : [  ],
"_airway_n_1_rel" : [ SenseInfo('02690941-n', 4), SenseInfo('08492546-n', 0), SenseInfo('05510173-n', 0), SenseInfo('02690081-n', 0) ],
"_grower_n_1_rel" : [ SenseInfo('09779790-n', 1) ],
"_gloss_n_1_rel" : [ SenseInfo('06744000-n', 0), SenseInfo('06420781-n', 0), SenseInfo('04955160-n', 0), SenseInfo('04677952-n', 0) ],
"_dead-center_v_1_rel" : [  ],
"_relieved_a_1_rel" : [ SenseInfo('01519465-a', 5), SenseInfo('01353982-a', 0), SenseInfo('01519465-a', 5), SenseInfo('01353982-a', 0), SenseInfo('01519465-a', 5), SenseInfo('01353982-a', 0) ],
"_ink_n_1_rel" : [ SenseInfo('14917635-n', 2), SenseInfo('05404598-n', 0) ],
"_welfare_n_1_rel" : [ SenseInfo('01086945-n', 3), SenseInfo('05142641-n', 1), SenseInfo('14447525-n', 0) ],
"_terrestrial_a_1_rel" : [ SenseInfo('02810102-a', 1), SenseInfo('02780093-a', 1), SenseInfo('00124918-a', 0), SenseInfo('02578035-a', 0), SenseInfo('01181661-a', 0) ],
"_slur_n_1_rel" : [ SenseInfo('06865953-n', 0), SenseInfo('06718543-n', 0), SenseInfo('04694441-n', 0) ],
"_belay_n_1_rel" : [ SenseInfo('09218494-n', 0) ],
"_ionization_n_of_rel" : [ SenseInfo('14577469-n', 0), SenseInfo('13502909-n', 0) ],
"_brigadier_n_1_rel" : [ SenseInfo('09875540-n', 4) ],
"_injunction_n_1_rel" : [ SenseInfo('07170467-n', 0), SenseInfo('06542830-n', 0), SenseInfo('07170467-n', 0), SenseInfo('06542830-n', 0) ],
"_available_a_1_rel" : [ SenseInfo('00183053-a', 91), SenseInfo('01062631-a', 0), SenseInfo('00777650-a', 0), SenseInfo('00183053-a', 91), SenseInfo('01062631-a', 0), SenseInfo('00777650-a', 0) ],
"_conscious_a_1_rel" : [ SenseInfo('01337767-a', 7), SenseInfo('00570590-a', 6), SenseInfo('00190960-a', 6) ],
"_dizzy_v_1_rel" : [ SenseInfo('00532328-v', 0), SenseInfo('00532328-v', 0), SenseInfo('00532328-v', 0) ],
"_ephoto_n_1_rel" : [  ],
"_noncompetitive_a_1_rel" : [ SenseInfo('00513165-a', 1) ],
"_riddle_v_1_rel" : [ SenseInfo('01275301-v', 2), SenseInfo('00623006-v', 1), SenseInfo('01460785-v', 0), SenseInfo('01229071-v', 0), SenseInfo('00742051-v', 0), SenseInfo('00635714-v', 0) ],
"_integral_a_1_rel" : [ SenseInfo('01348528-a', 3), SenseInfo('00515870-a', 1), SenseInfo('02685703-a', 0) ],
"_ekg_n_1_rel" : [ SenseInfo('07004057-n', 0) ],
"_lamb_n_1_rel" : [ SenseInfo('02412440-n', 5), SenseInfo('11115029-n', 0), SenseInfo('10243988-n', 0), SenseInfo('10243872-n', 0), SenseInfo('07667151-n', 0) ],
"_smash_v_in_rel" : [ SenseInfo('01401772-v', 6), SenseInfo('00335923-v', 5), SenseInfo('02318165-v', 0), SenseInfo('02104373-v', 0), SenseInfo('01800195-v', 0), SenseInfo('01566705-v', 0), SenseInfo('01561583-v', 0), SenseInfo('01561408-v', 0), SenseInfo('01083576-v', 0), SenseInfo('00334649-v', 0) ],
"_homicide_n_1_rel" : [ SenseInfo('00220023-n', 1) ],
"_prohibition_n_of_rel" : [ SenseInfo('06541820-n', 3), SenseInfo('06542047-n', 2), SenseInfo('15294382-n', 1), SenseInfo('07255174-n', 0), SenseInfo('00201923-n', 0) ],
"_eventuate_v_1_rel" : [ SenseInfo('02611002-v', 1) ],
"_candidacy_n_1_rel" : [ SenseInfo('00799537-n', 1) ],
"_afraid_a_of_rel" : [ SenseInfo('00077645-a', 29), SenseInfo('00543993-a', 3), SenseInfo('00544231-a', 1), SenseInfo('01293396-a', 0), SenseInfo('00077645-a', 29), SenseInfo('00543993-a', 3), SenseInfo('00544231-a', 1), SenseInfo('01293396-a', 0), SenseInfo('00077645-a', 29), SenseInfo('00543993-a', 3), SenseInfo('00544231-a', 1), SenseInfo('01293396-a', 0) ],
"_deliver_v_1_rel" : [ SenseInfo('00989602-v', 21), SenseInfo('01438304-v', 15), SenseInfo('02293321-v', 6), SenseInfo('02551144-v', 3), SenseInfo('02503365-v', 2), SenseInfo('01062253-v', 1), SenseInfo('00989869-v', 1), SenseInfo('02551602-v', 0), SenseInfo('02358327-v', 0), SenseInfo('02235229-v', 0), SenseInfo('01509079-v', 0), SenseInfo('00056930-v', 0) ],
"_ante-bellum_a_1_rel" : [ SenseInfo('01537144-a', 1), SenseInfo('01537144-a', 1), SenseInfo('01537144-a', 1) ],
"_carve_v_1_rel" : [ SenseInfo('01256157-v', 9), SenseInfo('01256600-v', 3), SenseInfo('01255967-v', 0), SenseInfo('01256157-v', 9), SenseInfo('01256600-v', 3), SenseInfo('01255967-v', 0), SenseInfo('01256157-v', 9), SenseInfo('01256600-v', 3), SenseInfo('01255967-v', 0) ],
"_yellow_v_cause_rel" : [ SenseInfo('00289840-v', 2) ],
"_new-found_a_1_rel" : [ SenseInfo('01642081-a', 0) ],
"_popular_a_for_rel" : [ SenseInfo('01815838-a', 14), SenseInfo('00716370-a', 9), SenseInfo('00486539-a', 5), SenseInfo('00414518-a', 1), SenseInfo('01815838-a', 14), SenseInfo('00716370-a', 9), SenseInfo('00486539-a', 5), SenseInfo('00414518-a', 1) ],
"_propose_v_to_rel" : [ SenseInfo('00875394-v', 23), SenseInfo('00706243-v', 21), SenseInfo('00708980-v', 6), SenseInfo('02401523-v', 1), SenseInfo('00879764-v', 1), SenseInfo('00875394-v', 23), SenseInfo('00706243-v', 21), SenseInfo('00708980-v', 6), SenseInfo('02401523-v', 1), SenseInfo('00879764-v', 1), SenseInfo('00875394-v', 23), SenseInfo('00706243-v', 21), SenseInfo('00708980-v', 6), SenseInfo('02401523-v', 1), SenseInfo('00879764-v', 1), SenseInfo('00875394-v', 23), SenseInfo('00706243-v', 21), SenseInfo('00708980-v', 6), SenseInfo('02401523-v', 1), SenseInfo('00879764-v', 1), SenseInfo('00875394-v', 23), SenseInfo('00706243-v', 21), SenseInfo('00708980-v', 6), SenseInfo('02401523-v', 1), SenseInfo('00879764-v', 1) ],
"_hose_v_down_rel" : [ SenseInfo('00228521-v', 0) ],
"_as+usual_a_1_rel" : [  ],
"_feel_v_seem_rel" : [ SenseInfo('01771535-v', 181), SenseInfo('00715239-v', 150), SenseInfo('02106006-v', 66), SenseInfo('00105958-v', 39), SenseInfo('00690305-v', 37), SenseInfo('02110552-v', 34), SenseInfo('02730471-v', 14), SenseInfo('02127613-v', 5), SenseInfo('01209678-v', 4), SenseInfo('01210352-v', 3), SenseInfo('02286027-v', 1), SenseInfo('02134350-v', 0), SenseInfo('01210152-v', 0) ],
"_spine_n_1_rel" : [ SenseInfo('05588174-n', 3), SenseInfo('13912839-n', 0), SenseInfo('13089631-n', 0), SenseInfo('04277980-n', 0), SenseInfo('01900488-n', 0) ],
"_in+the+way+of_p_rel" : [  ],
"_curtain_n_1_rel" : [ SenseInfo('03151077-n', 6), SenseInfo('09262233-n', 2) ],
"_brainstorm_v_1_rel" : [ SenseInfo('00630223-v', 0) ],
"_newborn_n_1_rel" : [ SenseInfo('10353016-n', 0), SenseInfo('10353016-n', 0), SenseInfo('10353016-n', 0) ],
"_winnings_n_1_rel" : [ SenseInfo('00064018-n', 1), SenseInfo('00064018-n', 1) ],
"_talon_n_1_rel" : [ SenseInfo('02156413-n', 0) ],
"_kilometer_n_1_rel" : [ SenseInfo('13659760-n', 1), SenseInfo('13659760-n', 1), SenseInfo('13659760-n', 1), SenseInfo('13659760-n', 1) ],
"_ex+girlfriend_n_1_rel" : [  ],
"_trace_n_of_rel" : [ SenseInfo('13773361-n', 5), SenseInfo('06646628-n', 2), SenseInfo('07164163-n', 1), SenseInfo('04463273-n', 1), SenseInfo('04462407-n', 1), SenseInfo('06647036-n', 0) ],
"_unsuitable_a_1_rel" : [ SenseInfo('01021607-a', 1), SenseInfo('01976851-a', 0), SenseInfo('01129823-a', 0), SenseInfo('00853473-a', 0), SenseInfo('01021607-a', 1), SenseInfo('01976851-a', 0), SenseInfo('01129823-a', 0), SenseInfo('00853473-a', 0), SenseInfo('01021607-a', 1), SenseInfo('01976851-a', 0), SenseInfo('01129823-a', 0), SenseInfo('00853473-a', 0) ],
"_proficiency_n_1_rel" : [ SenseInfo('05154114-n', 1), SenseInfo('05643190-n', 0) ],
"_terrified_a_of_rel" : [ SenseInfo('00080357-a', 4), SenseInfo('00080357-a', 4) ],
"_blend_v_cause_rel" : [ SenseInfo('01462468-v', 7), SenseInfo('02700455-v', 1), SenseInfo('00394813-v', 0) ],
"_rightarrow_p_rel" : [  ],
"_lag_v_behind_rel" : [ SenseInfo('01997862-v', 7), SenseInfo('02494356-v', 0), SenseInfo('01513045-v', 0), SenseInfo('01339050-v', 0) ],
"_nerve_n_1_rel" : [ SenseInfo('05474346-n', 6), SenseInfo('04857490-n', 5), SenseInfo('04838210-n', 0), SenseInfo('05474346-n', 6), SenseInfo('04857490-n', 5), SenseInfo('04838210-n', 0) ],
"_cog_n_1_rel" : [ SenseInfo('09934337-n', 0), SenseInfo('03064935-n', 0) ],
"_top+to+bottom_p_1_rel" : [  ],
"_hatred_n_of_rel" : [ SenseInfo('07546465-n', 18) ],
"_cuisine_n_1_rel" : [ SenseInfo('07571324-n', 0) ],
"_cold_a_1_rel" : [ SenseInfo('01251128-a', 35), SenseInfo('01257612-a', 13), SenseInfo('01069454-a', 1), SenseInfo('02532398-a', 0), SenseInfo('01750256-a', 0), SenseInfo('01689580-a', 0), SenseInfo('01510914-a', 0), SenseInfo('01466775-a', 0), SenseInfo('01263971-a', 0), SenseInfo('00887317-a', 0), SenseInfo('00572060-a', 0), SenseInfo('00442827-a', 0), SenseInfo('00096815-a', 0), SenseInfo('01251128-a', 35), SenseInfo('01257612-a', 13), SenseInfo('01069454-a', 1), SenseInfo('02532398-a', 0), SenseInfo('01750256-a', 0), SenseInfo('01689580-a', 0), SenseInfo('01510914-a', 0), SenseInfo('01466775-a', 0), SenseInfo('01263971-a', 0), SenseInfo('00887317-a', 0), SenseInfo('00572060-a', 0), SenseInfo('00442827-a', 0), SenseInfo('00096815-a', 0), SenseInfo('01251128-a', 35), SenseInfo('01257612-a', 13), SenseInfo('01069454-a', 1), SenseInfo('02532398-a', 0), SenseInfo('01750256-a', 0), SenseInfo('01689580-a', 0), SenseInfo('01510914-a', 0), SenseInfo('01466775-a', 0), SenseInfo('01263971-a', 0), SenseInfo('00887317-a', 0), SenseInfo('00572060-a', 0), SenseInfo('00442827-a', 0), SenseInfo('00096815-a', 0), SenseInfo('01251128-a', 35), SenseInfo('01257612-a', 13), SenseInfo('01069454-a', 1), SenseInfo('02532398-a', 0), SenseInfo('01750256-a', 0), SenseInfo('01689580-a', 0), SenseInfo('01510914-a', 0), SenseInfo('01466775-a', 0), SenseInfo('01263971-a', 0), SenseInfo('00887317-a', 0), SenseInfo('00572060-a', 0), SenseInfo('00442827-a', 0), SenseInfo('00096815-a', 0), SenseInfo('01251128-a', 35), SenseInfo('01257612-a', 13), SenseInfo('01069454-a', 1), SenseInfo('02532398-a', 0), SenseInfo('01750256-a', 0), SenseInfo('01689580-a', 0), SenseInfo('01510914-a', 0), SenseInfo('01466775-a', 0), SenseInfo('01263971-a', 0), SenseInfo('00887317-a', 0), SenseInfo('00572060-a', 0), SenseInfo('00442827-a', 0), SenseInfo('00096815-a', 0), SenseInfo('01251128-a', 35), SenseInfo('01257612-a', 13), SenseInfo('01069454-a', 1), SenseInfo('02532398-a', 0), SenseInfo('01750256-a', 0), SenseInfo('01689580-a', 0), SenseInfo('01510914-a', 0), SenseInfo('01466775-a', 0), SenseInfo('01263971-a', 0), SenseInfo('00887317-a', 0), SenseInfo('00572060-a', 0), SenseInfo('00442827-a', 0), SenseInfo('00096815-a', 0), SenseInfo('01251128-a', 35), SenseInfo('01257612-a', 13), SenseInfo('01069454-a', 1), SenseInfo('02532398-a', 0), SenseInfo('01750256-a', 0), SenseInfo('01689580-a', 0), SenseInfo('01510914-a', 0), SenseInfo('01466775-a', 0), SenseInfo('01263971-a', 0), SenseInfo('00887317-a', 0), SenseInfo('00572060-a', 0), SenseInfo('00442827-a', 0), SenseInfo('00096815-a', 0) ],
"_architecture_n_1_rel" : [ SenseInfo('02734725-n', 3), SenseInfo('06123363-n', 1), SenseInfo('00610738-n', 1), SenseInfo('04932278-n', 0) ],
"_flashlight_n_1_rel" : [ SenseInfo('03359137-n', 3) ],
"_urielite_n_1_rel" : [  ],
"_level_v_with_rel" : [ SenseInfo('01152896-v', 4), SenseInfo('01661804-v', 1), SenseInfo('01307142-v', 1), SenseInfo('01152214-v', 0), SenseInfo('00964237-v', 0), SenseInfo('00356649-v', 0) ],
"_onwards_a_1_rel" : [  ],
"_marijuana_n_1_rel" : [ SenseInfo('12397210-n', 0), SenseInfo('02949691-n', 0) ],
"_exhibit_v_1_rel" : [ SenseInfo('02631856-v', 13), SenseInfo('02140033-v', 11), SenseInfo('02148788-v', 4), SenseInfo('01924712-v', 0), SenseInfo('02631856-v', 13), SenseInfo('02140033-v', 11), SenseInfo('02148788-v', 4), SenseInfo('01924712-v', 0) ],
"_spring_n_1_rel" : [ SenseInfo('15237044-n', 25), SenseInfo('04288272-n', 4), SenseInfo('09443453-n', 3), SenseInfo('08508361-n', 1), SenseInfo('05021151-n', 1), SenseInfo('00120202-n', 1) ],
"_friction_n_1_rel" : [ SenseInfo('13981137-n', 2), SenseInfo('11459538-n', 0), SenseInfo('00712031-n', 0) ],
"_camouflage_v_1_rel" : [ SenseInfo('02158896-v', 1) ],
"_conversation_n_1_rel" : [ SenseInfo('07133701-n', 20) ],
"_regard_n_1_rel" : [ SenseInfo('05820170-n', 4), SenseInfo('05702726-n', 2), SenseInfo('06630627-n', 1), SenseInfo('00878648-n', 1), SenseInfo('14437552-n', 0), SenseInfo('07545415-n', 0), SenseInfo('06206800-n', 0) ],
"_constant_n_1_rel" : [ SenseInfo('05858936-n', 4), SenseInfo('13585429-n', 0) ],
"_idle_v_1_rel" : [ SenseInfo('01526483-v', 2), SenseInfo('02417504-v', 1) ],
"_hint_n_of_rel" : [ SenseInfo('07163988-n', 1), SenseInfo('06802785-n', 1), SenseInfo('13774115-n', 0), SenseInfo('13773361-n', 0), SenseInfo('06651577-n', 0), SenseInfo('07163988-n', 1), SenseInfo('06802785-n', 1), SenseInfo('13774115-n', 0), SenseInfo('13773361-n', 0), SenseInfo('06651577-n', 0) ],
"_boxer_n_1_rel" : [ SenseInfo('09870208-n', 1), SenseInfo('10390427-n', 0), SenseInfo('09870746-n', 0), SenseInfo('02108089-n', 0) ],
"_cow_v_1_rel" : [ SenseInfo('01779803-v', 0) ],
"_turquoise_a_1_rel" : [ SenseInfo('15082198-n', 0), SenseInfo('04969798-n', 0) ],
"_roar_n_1_rel" : [ SenseInfo('07377682-n', 13), SenseInfo('07121361-n', 2), SenseInfo('07392280-n', 0) ],
"_fosterite_n_1_rel" : [  ],
"_refund_n_of_rel" : [ SenseInfo('13282161-n', 7), SenseInfo('01121690-n', 1) ],
"_diatonic_a_1_rel" : [ SenseInfo('00409889-a', 0), SenseInfo('02437534-a', 0) ],
"_hms_n_1_rel" : [ SenseInfo('13659604-n', 0), SenseInfo('13659604-n', 0) ],
"_vector_v_1_rel" : [  ],
"_fifth_n_of_rel" : [ SenseInfo('13619475-n', 1), SenseInfo('13847240-n', 0), SenseInfo('13737830-n', 0), SenseInfo('06859800-n', 0), SenseInfo('13619475-n', 1), SenseInfo('13847240-n', 0), SenseInfo('13737830-n', 0), SenseInfo('06859800-n', 0), SenseInfo('13619475-n', 1), SenseInfo('13847240-n', 0), SenseInfo('13737830-n', 0), SenseInfo('06859800-n', 0), SenseInfo('13619475-n', 1), SenseInfo('13847240-n', 0), SenseInfo('13737830-n', 0), SenseInfo('06859800-n', 0) ],
"_drat_a_1_rel" : [  ],
"_origin_n_1_rel" : [ SenseInfo('08507558-n', 11), SenseInfo('04923743-n', 3), SenseInfo('07323922-n', 1), SenseInfo('06009086-n', 1), SenseInfo('13559177-n', 0), SenseInfo('08101937-n', 0) ],
"_confident_a_of-about_rel" : [ SenseInfo('00338817-a', 7), SenseInfo('00337172-a', 0), SenseInfo('00306909-a', 0), SenseInfo('00338817-a', 7), SenseInfo('00337172-a', 0), SenseInfo('00306909-a', 0), SenseInfo('00338817-a', 7), SenseInfo('00337172-a', 0), SenseInfo('00306909-a', 0) ],
"_unease_n_1_rel" : [ SenseInfo('14447019-n', 0), SenseInfo('04904851-n', 0) ],
"_step_v_on_rel" : [ SenseInfo('01928838-v', 23), SenseInfo('02091410-v', 7), SenseInfo('02563616-v', 0), SenseInfo('02516594-v', 0), SenseInfo('02330247-v', 0), SenseInfo('02091885-v', 0), SenseInfo('02091689-v', 0), SenseInfo('01256487-v', 0), SenseInfo('00490722-v', 0), SenseInfo('00124659-v', 0) ],
"_thrash_v_1_rel" : [ SenseInfo('01416193-v', 2), SenseInfo('01890792-v', 1), SenseInfo('01897885-v', 0), SenseInfo('01880390-v', 0), SenseInfo('01838860-v', 0), SenseInfo('01416364-v', 0), SenseInfo('01412912-v', 0) ],
"_twine_v_1_rel" : [ SenseInfo('01517662-v', 5), SenseInfo('01522276-v', 0), SenseInfo('01518047-v', 0), SenseInfo('01223182-v', 0), SenseInfo('01517662-v', 5), SenseInfo('01522276-v', 0), SenseInfo('01518047-v', 0), SenseInfo('01223182-v', 0) ],
"_track_n_i_rel" : [ SenseInfo('09387222-n', 6), SenseInfo('05826914-n', 1), SenseInfo('04463983-n', 1), SenseInfo('04037625-n', 1), SenseInfo('06612865-n', 0), SenseInfo('04464418-n', 0), SenseInfo('04464211-n', 0), SenseInfo('04464125-n', 0), SenseInfo('04463679-n', 0), SenseInfo('04463510-n', 0), SenseInfo('00440039-n', 0) ],
"_blister_v_1_rel" : [ SenseInfo('00379774-v', 2), SenseInfo('00863906-v', 0), SenseInfo('00379996-v', 0) ],
"_spawn_v_1_rel" : [ SenseInfo('01649024-v', 0), SenseInfo('00056683-v', 0) ],
"_ape_n_1_rel" : [ SenseInfo('02470325-n', 1), SenseInfo('09964411-n', 0), SenseInfo('09796185-n', 0) ],
"_lie_v_mental_rel" : [ SenseInfo('02690708-v', 88), SenseInfo('01547001-v', 58), SenseInfo('02653381-v', 15), SenseInfo('02734338-v', 14), SenseInfo('00834259-v', 9), SenseInfo('02731390-v', 4), SenseInfo('01985029-v', 4) ],
"_lc_n_1_rel" : [  ],
"_embankment_n_1_rel" : [ SenseInfo('03282060-n', 5) ],
"_glance_n_1_rel" : [ SenseInfo('00877625-n', 31), SenseInfo('00877625-n', 31) ],
"_nurture_v_1_rel" : [ SenseInfo('00908351-v', 1), SenseInfo('02539788-v', 0), SenseInfo('01202728-v', 0), SenseInfo('00908351-v', 1), SenseInfo('02539788-v', 0), SenseInfo('01202728-v', 0), SenseInfo('00908351-v', 1), SenseInfo('02539788-v', 0), SenseInfo('01202728-v', 0) ],
"_metamorphose_n_1_rel" : [  ],
"_portage_n_1_rel" : [ SenseInfo('13306346-n', 0), SenseInfo('03985588-n', 0), SenseInfo('00319717-n', 0) ],
"_tidbit_n_1_rel" : [ SenseInfo('07594737-n', 1) ],
"_linewidth_n_1_rel" : [  ],
"_allege_v_1_rel" : [ SenseInfo('01016002-v', 5), SenseInfo('01016002-v', 5), SenseInfo('01016002-v', 5) ],
"_seize_v_1_rel" : [ SenseInfo('01212572-v', 13), SenseInfo('01213614-v', 5), SenseInfo('02272549-v', 4), SenseInfo('02273293-v', 3), SenseInfo('02274482-v', 0), SenseInfo('01365839-v', 0), SenseInfo('00737656-v', 0), SenseInfo('00737476-v', 0) ],
"_fingerlike_a_1_rel" : [ SenseInfo('00946281-a', 0) ],
"_capital_n_1_rel" : [ SenseInfo('13354420-n', 15), SenseInfo('13353607-n', 3), SenseInfo('08518505-n', 3), SenseInfo('06824227-n', 1), SenseInfo('08518747-n', 0), SenseInfo('08357129-n', 0), SenseInfo('07282929-n', 0), SenseInfo('02956247-n', 0) ],
"_given+that_x_subord_rel" : [  ],
"_duel_n_1_rel" : [ SenseInfo('01172784-n', 1), SenseInfo('00789237-n', 1) ],
"_enforce_v_1_rel" : [ SenseInfo('02560164-v', 17), SenseInfo('02560424-v', 7) ],
"_sporting_n_1_rel" : [ SenseInfo('00956733-a', 5), SenseInfo('02801839-a', 3), SenseInfo('00066565-a', 1), SenseInfo('01297946-a', 0) ],
"_news_n_of_rel" : [ SenseInfo('06642138-n', 21), SenseInfo('06681177-n', 17), SenseInfo('06619850-n', 3), SenseInfo('06642356-n', 0), SenseInfo('05192897-n', 0), SenseInfo('06642138-n', 21), SenseInfo('06681177-n', 17), SenseInfo('06619850-n', 3), SenseInfo('06642356-n', 0), SenseInfo('05192897-n', 0), SenseInfo('06642138-n', 21), SenseInfo('06681177-n', 17), SenseInfo('06619850-n', 3), SenseInfo('06642356-n', 0), SenseInfo('05192897-n', 0) ],
"_eat_v_in_rel" : [ SenseInfo('01168468-v', 61), SenseInfo('01166351-v', 13), SenseInfo('01179865-v', 4), SenseInfo('01766273-v', 0), SenseInfo('01157517-v', 0), SenseInfo('00274283-v', 0) ],
"_divan_n_1_rel" : [ SenseInfo('03214966-n', 5), SenseInfo('08311848-n', 0), SenseInfo('06592576-n', 0), SenseInfo('03215076-n', 0) ],
"_knock_v_1_rel" : [ SenseInfo('01238640-v', 7), SenseInfo('01414467-v', 6), SenseInfo('01239619-v', 4), SenseInfo('02185373-v', 0), SenseInfo('02178866-v', 0), SenseInfo('00826509-v', 0), SenseInfo('01238640-v', 7), SenseInfo('01414467-v', 6), SenseInfo('01239619-v', 4), SenseInfo('02185373-v', 0), SenseInfo('02178866-v', 0), SenseInfo('00826509-v', 0) ],
"_sheath_v_1_rel" : [  ],
"_decay_n_1_rel" : [ SenseInfo('13456715-n', 2), SenseInfo('13456567-n', 2), SenseInfo('11444643-n', 1), SenseInfo('14560612-n', 0), SenseInfo('13456899-n', 0) ],
"_unproblematic_a_1_rel" : [ SenseInfo('00750296-a', 1), SenseInfo('00750296-a', 1) ],
"_electronics_n_1_rel" : [ SenseInfo('06099269-n', 10), SenseInfo('06099269-n', 10), SenseInfo('06099269-n', 10), SenseInfo('06099269-n', 10) ],
"_textual_a_1_rel" : [ SenseInfo('02925879-a', 0) ],
"_self-service+lodge_n_1_rel" : [  ],
"_refreshing_a_1_rel" : [ SenseInfo('01357027-a', 2), SenseInfo('01642245-a', 0) ],
"_porter_n_1_rel" : [ SenseInfo('10455447-n', 1), SenseInfo('10026553-n', 1), SenseInfo('11243424-n', 0), SenseInfo('11243268-n', 0), SenseInfo('11243102-n', 0), SenseInfo('10455305-n', 0), SenseInfo('07890226-n', 0) ],
"_moor_v_1_rel" : [ SenseInfo('01305542-v', 0), SenseInfo('01305361-v', 0), SenseInfo('01305099-v', 0) ],
"_reef_n_1_rel" : [ SenseInfo('09406793-n', 1), SenseInfo('09001881-n', 0), SenseInfo('03458961-n', 0) ],
"_lightness_n_1_rel" : [ SenseInfo('07527656-n', 0), SenseInfo('05028700-n', 0), SenseInfo('05003850-n', 0), SenseInfo('04979758-n', 0), SenseInfo('04951373-n', 0), SenseInfo('04648596-n', 0) ],
"_fringe_v_1_rel" : [ SenseInfo('01751021-v', 0), SenseInfo('01467751-v', 0) ],
"_twice_a_1_rel" : [  ],
"_unsubdued_a_1_rel" : [ SenseInfo('02391342-a', 0), SenseInfo('02391342-a', 0) ],
"_robe+de+chambre_n_1_rel" : [ SenseInfo('03237992-n', 0), SenseInfo('03237992-n', 0), SenseInfo('03237992-n', 0) ],
"_providing_x_rel" : [  ],
"_camera_n_1_rel" : [ SenseInfo('02942699-n', 18), SenseInfo('04404997-n', 4) ],
"_fester_v_1_rel" : [ SenseInfo('00096766-v', 0) ],
"_criticism_n_1_rel" : [ SenseInfo('06710546-n', 6), SenseInfo('05734018-n', 3), SenseInfo('06374587-n', 2), SenseInfo('06710546-n', 6), SenseInfo('05734018-n', 3), SenseInfo('06374587-n', 2) ],
"_fingerprint_n_1_rel" : [ SenseInfo('06644393-n', 5), SenseInfo('06886488-n', 0), SenseInfo('04694980-n', 0) ],
"_curb_n_1_rel" : [ SenseInfo('03148920-n', 5), SenseInfo('03149135-n', 0), SenseInfo('02701871-n', 0), SenseInfo('01146039-n', 0) ],
"_nonpareil_a_1_rel" : [ SenseInfo('00505410-a', 0) ],
"_block_v_out_rel" : [ SenseInfo('01478002-v', 7), SenseInfo('02557199-v', 3), SenseInfo('02559752-v', 1), SenseInfo('01057034-v', 1), SenseInfo('02444297-v', 0), SenseInfo('02198423-v', 0), SenseInfo('02145543-v', 0), SenseInfo('01531492-v', 0), SenseInfo('01479333-v', 0), SenseInfo('01476483-v', 0), SenseInfo('01217924-v', 0), SenseInfo('01147060-v', 0), SenseInfo('00609100-v', 0), SenseInfo('00477528-v', 0), SenseInfo('00477382-v', 0), SenseInfo('00269423-v', 0) ],
"_drain_v_cause_rel" : [ SenseInfo('02071457-v', 2), SenseInfo('01158022-v', 1), SenseInfo('00451648-v', 1), SenseInfo('00389638-v', 0), SenseInfo('02071457-v', 2), SenseInfo('01158022-v', 1), SenseInfo('00451648-v', 1), SenseInfo('00389638-v', 0), SenseInfo('02071457-v', 2), SenseInfo('01158022-v', 1), SenseInfo('00451648-v', 1), SenseInfo('00389638-v', 0), SenseInfo('02071457-v', 2), SenseInfo('01158022-v', 1), SenseInfo('00451648-v', 1), SenseInfo('00389638-v', 0), SenseInfo('02071457-v', 2), SenseInfo('01158022-v', 1), SenseInfo('00451648-v', 1), SenseInfo('00389638-v', 0) ],
"_wardrobe_n_1_rel" : [ SenseInfo('04550184-n', 3), SenseInfo('04550426-n', 1), SenseInfo('04550546-n', 0) ],
"_untimely_a_1_rel" : [ SenseInfo('01662119-a', 0), SenseInfo('00815000-a', 0), SenseInfo('01662119-a', 0), SenseInfo('00815000-a', 0), SenseInfo('01662119-a', 0), SenseInfo('00815000-a', 0) ],
"_mis_v_order_rel" : [  ],
"_gneiss_n_1_rel" : [ SenseInfo('14889271-n', 0) ],
"_citizenship_n_1_rel" : [ SenseInfo('13953467-n', 0), SenseInfo('04898208-n', 0) ],
"_stipulation_n_of_rel" : [ SenseInfo('07216761-n', 0), SenseInfo('06755568-n', 0), SenseInfo('01149303-n', 0), SenseInfo('07216761-n', 0), SenseInfo('06755568-n', 0), SenseInfo('01149303-n', 0) ],
"_weed_n_1_rel" : [ SenseInfo('13085113-n', 3), SenseInfo('04570680-n', 0), SenseInfo('03990834-n', 0) ],
"_lacrymal_a_1_rel" : [  ],
"_french_n_1_rel" : [ SenseInfo('06964901-n', 6), SenseInfo('09732903-n', 3), SenseInfo('10981750-n', 0), SenseInfo('06964901-n', 6), SenseInfo('09732903-n', 3), SenseInfo('10981750-n', 0), SenseInfo('06964901-n', 6), SenseInfo('09732903-n', 3), SenseInfo('10981750-n', 0) ],
"_colonic_a_1_rel" : [ SenseInfo('02700317-a', 0) ],
"_large_n_1_rel" : [ SenseInfo('05096191-n', 0) ],
"_whip_v_up_rel" : [ SenseInfo('01411085-v', 8), SenseInfo('01102997-v', 4), SenseInfo('01891092-v', 3), SenseInfo('01398032-v', 3), SenseInfo('01417868-v', 0), SenseInfo('00863906-v', 0) ],
"_compendium_n_1_rel" : [ SenseInfo('06591442-n', 0), SenseInfo('06467996-n', 0) ],
"_magnifier_n_1_rel" : [ SenseInfo('03709206-n', 0) ],
"_brick_n_1_rel" : [ SenseInfo('02897820-n', 7), SenseInfo('09874428-n', 1) ],
"_mistype_v_1_rel" : [  ],
"_quiz_n_1_rel" : [ SenseInfo('07199191-n', 2) ],
"_fool_v_around_rel" : [ SenseInfo('02576349-v', 6), SenseInfo('01195804-v', 0), SenseInfo('00854904-v', 0), SenseInfo('00854150-v', 0), SenseInfo('02576349-v', 6), SenseInfo('01195804-v', 0), SenseInfo('00854904-v', 0), SenseInfo('00854150-v', 0), SenseInfo('02576349-v', 6), SenseInfo('01195804-v', 0), SenseInfo('00854904-v', 0), SenseInfo('00854150-v', 0) ],
"_predominantly_x_deg_rel" : [ SenseInfo('00161018-r', 2) ],
"_soapstone_n_1_rel" : [ SenseInfo('15044327-n', 0) ],
"_cancel_v_1_rel" : [ SenseInfo('02477755-v', 9), SenseInfo('02717831-v', 0), SenseInfo('02477334-v', 0), SenseInfo('01549187-v', 0), SenseInfo('00800460-v', 0) ],
"_epic_a_1_rel" : [ SenseInfo('01386010-a', 2), SenseInfo('03015589-a', 1) ],
"_postal_a_1_rel" : [ SenseInfo('02885934-a', 0) ],
"_crawl_v_dir_rel" : [ SenseInfo('01885845-v', 32), SenseInfo('02730682-v', 1), SenseInfo('02716048-v', 0), SenseInfo('02063771-v', 0), SenseInfo('01961974-v', 0) ],
"_cure-all_n_1_rel" : [ SenseInfo('03880770-n', 3), SenseInfo('03880770-n', 3) ],
"_slobber_n_1_rel" : [ SenseInfo('05416678-n', 0) ],
"_impracticable_a_1_rel" : [ SenseInfo('01823574-a', 0) ],
"_pay_v_down_rel" : [ SenseInfo('02251743-v', 138), SenseInfo('01060494-v', 26), SenseInfo('02252931-v', 12), SenseInfo('02291708-v', 6), SenseInfo('02253456-v', 6), SenseInfo('00732224-v', 4), SenseInfo('02732292-v', 3), SenseInfo('02488056-v', 1), SenseInfo('00737884-v', 1), SenseInfo('02344243-v', 0), SenseInfo('02253154-v', 0) ],
"_up_p_rel" : [ SenseInfo('00096333-r', 79), SenseInfo('02490170-a', 8), SenseInfo('00186925-a', 5), SenseInfo('00154966-v', 2), SenseInfo('02487108-a', 1), SenseInfo('02485488-a', 1), SenseInfo('00097011-r', 0), SenseInfo('00096921-r', 0), SenseInfo('00096760-r', 0), SenseInfo('00096636-r', 0), SenseInfo('01845002-a', 0), SenseInfo('01208146-a', 0), SenseInfo('01091995-a', 0), SenseInfo('01004245-a', 0), SenseInfo('00096333-r', 79), SenseInfo('02490170-a', 8), SenseInfo('00186925-a', 5), SenseInfo('00154966-v', 2), SenseInfo('02487108-a', 1), SenseInfo('02485488-a', 1), SenseInfo('00097011-r', 0), SenseInfo('00096921-r', 0), SenseInfo('00096760-r', 0), SenseInfo('00096636-r', 0), SenseInfo('01845002-a', 0), SenseInfo('01208146-a', 0), SenseInfo('01091995-a', 0), SenseInfo('01004245-a', 0), SenseInfo('00096333-r', 79), SenseInfo('02490170-a', 8), SenseInfo('00186925-a', 5), SenseInfo('00154966-v', 2), SenseInfo('02487108-a', 1), SenseInfo('02485488-a', 1), SenseInfo('00097011-r', 0), SenseInfo('00096921-r', 0), SenseInfo('00096760-r', 0), SenseInfo('00096636-r', 0), SenseInfo('01845002-a', 0), SenseInfo('01208146-a', 0), SenseInfo('01091995-a', 0), SenseInfo('01004245-a', 0) ],
"_millisecond_n_1_rel" : [ SenseInfo('15236338-n', 0) ],
"_conveyor_n_1_rel" : [ SenseInfo('09962789-n', 1), SenseInfo('03100897-n', 1) ],
"_marmelade_n_1_rel" : [  ],
"_pulsation_n_1_rel" : [ SenseInfo('07420991-n', 1), SenseInfo('11529295-n', 0), SenseInfo('07400906-n', 0) ],
"_mat_v_cause_rel" : [ SenseInfo('01462928-v', 0), SenseInfo('00565592-v', 0) ],
"_english_a_1_rel" : [ SenseInfo('03003344-a', 33), SenseInfo('03003616-a', 0) ],
"_stone_v_1_rel" : [ SenseInfo('01323518-v', 1), SenseInfo('00179567-v', 0) ],
"_dictate_v_to_rel" : [ SenseInfo('00747135-v', 8), SenseInfo('00626890-v', 1), SenseInfo('02587084-v', 0), SenseInfo('00747135-v', 8), SenseInfo('00626890-v', 1), SenseInfo('02587084-v', 0), SenseInfo('00747135-v', 8), SenseInfo('00626890-v', 1), SenseInfo('02587084-v', 0), SenseInfo('00747135-v', 8), SenseInfo('00626890-v', 1), SenseInfo('02587084-v', 0), SenseInfo('00747135-v', 8), SenseInfo('00626890-v', 1), SenseInfo('02587084-v', 0) ],
"_lounge_v_1_rel" : [ SenseInfo('01528339-v', 2), SenseInfo('02639075-v', 0) ],
"_antler_n_1_rel" : [ SenseInfo('01325658-n', 0) ],
"_expanse_n_1_rel" : [ SenseInfo('05127959-n', 2), SenseInfo('05128519-n', 1), SenseInfo('09277538-n', 0) ],
"_ritual_n_1_rel" : [ SenseInfo('01027859-n', 6), SenseInfo('01030820-n', 4), SenseInfo('00414790-n', 0) ],
"_loose_v_1_rel" : [ SenseInfo('02421374-v', 1), SenseInfo('01475536-v', 1), SenseInfo('00419375-v', 0), SenseInfo('00419137-v', 0) ],
"_scam_v_1_rel" : [ SenseInfo('02572119-v', 0) ],
"_game_v_1_rel" : [ SenseInfo('01139104-v', 0) ],
"_fledgling_n_1_rel" : [ SenseInfo('10355449-n', 1), SenseInfo('01504179-n', 0) ],
"_boil_v_cause_rel" : [ SenseInfo('00375021-v', 4), SenseInfo('00328128-v', 4), SenseInfo('00374668-v', 3), SenseInfo('01885430-v', 0), SenseInfo('01767612-v', 0) ],
"_DNA_n_1_rel" : [ SenseInfo('14830364-n', 0) ],
"_home_n_of-n_rel" : [ SenseInfo('08559508-n', 55), SenseInfo('03259505-n', 48), SenseInfo('08490199-n', 10), SenseInfo('03528901-n', 3), SenseInfo('08490402-n', 2), SenseInfo('08585158-n', 1), SenseInfo('14513694-n', 0), SenseInfo('08078020-n', 0), SenseInfo('03528100-n', 0), SenseInfo('08559508-n', 55), SenseInfo('03259505-n', 48), SenseInfo('08490199-n', 10), SenseInfo('03528901-n', 3), SenseInfo('08490402-n', 2), SenseInfo('08585158-n', 1), SenseInfo('14513694-n', 0), SenseInfo('08078020-n', 0), SenseInfo('03528100-n', 0) ],
"_anatomical_n_1_rel" : [ SenseInfo('07151892-n', 2) ],
"_moderate_v_1_rel" : [ SenseInfo('00813790-v', 1), SenseInfo('00198710-v', 1), SenseInfo('02510337-v', 0), SenseInfo('01058036-v', 0), SenseInfo('00933566-v', 0), SenseInfo('00202934-v', 0) ],
"_deflect_v_1_rel" : [ SenseInfo('02453321-v', 0), SenseInfo('02034300-v', 0), SenseInfo('02033805-v', 0), SenseInfo('01791756-v', 0), SenseInfo('01147060-v', 0) ],
"_diversify_v_1_rel" : [ SenseInfo('00437125-v', 0), SenseInfo('00436668-v', 0), SenseInfo('00436404-v', 0) ],
"_cheer_v_up_rel" : [ SenseInfo('01817938-v', 1), SenseInfo('00858568-v', 1), SenseInfo('00859325-v', 0), SenseInfo('00859153-v', 0), SenseInfo('00858781-v', 0), SenseInfo('01817938-v', 1), SenseInfo('00858568-v', 1), SenseInfo('00859325-v', 0), SenseInfo('00859153-v', 0), SenseInfo('00858781-v', 0) ],
"_mannered_a_1_rel" : [ SenseInfo('00074094-a', 0) ],
"_impossibly_x_deg_rel" : [ SenseInfo('00300682-r', 0) ],
"_promissory_a_1_rel" : [ SenseInfo('02997740-a', 0) ],
"_throb_v_1_rel" : [ SenseInfo('02122665-v', 2), SenseInfo('01879251-v', 2), SenseInfo('01888946-v', 0) ],
"_pre+approved_a_1_rel" : [  ],
"_escape_v_from_rel" : [ SenseInfo('02074677-v', 22), SenseInfo('00810557-v', 8), SenseInfo('00810729-v', 7), SenseInfo('02723232-v', 2), SenseInfo('02599004-v', 0), SenseInfo('02075049-v', 0), SenseInfo('00530017-v', 0) ],
"_calender_v_1_rel" : [ SenseInfo('01391095-v', 0) ],
"_markkaa_n_1_rel" : [ SenseInfo('13688447-n', 0) ],
"_cough_v_1_rel" : [ SenseInfo('00005815-v', 6) ],
"_tell_v_about_rel" : [ SenseInfo('01009240-v', 196), SenseInfo('00952524-v', 189), SenseInfo('00953216-v', 75), SenseInfo('00746718-v', 60), SenseInfo('00720961-v', 27), SenseInfo('01019643-v', 6), SenseInfo('00954422-v', 4), SenseInfo('00650353-v', 3) ],
"_at-market_a_1_rel" : [  ],
"_follow_v_around_rel" : [ SenseInfo('01998432-v', 74), SenseInfo('02712772-v', 50), SenseInfo('02720149-v', 26), SenseInfo('01991931-v', 20), SenseInfo('02542280-v', 18), SenseInfo('02720354-v', 17), SenseInfo('00150776-v', 13), SenseInfo('02720544-v', 12), SenseInfo('02346895-v', 9), SenseInfo('02720697-v', 8), SenseInfo('01744450-v', 8), SenseInfo('00729109-v', 4), SenseInfo('02455407-v', 3), SenseInfo('02406585-v', 2), SenseInfo('01728355-v', 1), SenseInfo('00118764-v', 1), SenseInfo('02625339-v', 0), SenseInfo('02600255-v', 0), SenseInfo('02561697-v', 0), SenseInfo('02445925-v', 0), SenseInfo('02198602-v', 0), SenseInfo('02000868-v', 0), SenseInfo('00589738-v', 0), SenseInfo('00351406-v', 0) ],
"_speciality_n_1_rel" : [ SenseInfo('05159225-n', 0), SenseInfo('04763925-n', 0), SenseInfo('00583461-n', 0) ],
"_inactivity_n_1_rel" : [ SenseInfo('14010148-n', 0), SenseInfo('04635631-n', 0), SenseInfo('01062583-n', 0) ],
"_owl_n_1_rel" : [ SenseInfo('01621127-n', 3) ],
"_rectify_v_1_rel" : [ SenseInfo('00919829-v', 0), SenseInfo('00474492-v', 0), SenseInfo('00384620-v', 0), SenseInfo('00199912-v', 0), SenseInfo('00199659-v', 0), SenseInfo('00161731-v', 0) ],
"_bushy_a_1_rel" : [ SenseInfo('02428610-a', 1), SenseInfo('00613975-a', 0), SenseInfo('02428610-a', 1), SenseInfo('00613975-a', 0), SenseInfo('02428610-a', 1), SenseInfo('00613975-a', 0) ],
"_style_v_1_rel" : [ SenseInfo('01028466-v', 1), SenseInfo('01666894-v', 0), SenseInfo('00993608-v', 0) ],
"_female_n_1_rel" : [ SenseInfo('01320872-n', 18), SenseInfo('09619168-n', 4) ],
"_superstition_n_1_rel" : [ SenseInfo('05952678-n', 9) ],
"_cultural_a_1_rel" : [ SenseInfo('02898922-a', 9), SenseInfo('02248693-a', 8), SenseInfo('02872501-a', 3), SenseInfo('02872362-a', 0), SenseInfo('02898922-a', 9), SenseInfo('02248693-a', 8), SenseInfo('02872501-a', 3), SenseInfo('02872362-a', 0) ],
"_tone_v_1_rel" : [ SenseInfo('01066775-v', 0), SenseInfo('00982293-v', 0), SenseInfo('00290132-v', 0), SenseInfo('00289974-v', 0), SenseInfo('00101277-v', 0) ],
"_snowboard_n_1_rel" : [ SenseInfo('04251791-n', 0) ],
"_graze_v_cause_rel" : [ SenseInfo('01576165-v', 3), SenseInfo('01608508-v', 2), SenseInfo('01576478-v', 0), SenseInfo('01240514-v', 0), SenseInfo('01174742-v', 0) ],
"_gallop_n_1_rel" : [ SenseInfo('00288671-n', 2) ],
"_shareholder_n_1_rel" : [ SenseInfo('10657969-n', 0), SenseInfo('10657969-n', 0), SenseInfo('10657969-n', 0) ],
"_urbanite_n_1_rel" : [  ],
"_nephew_n_of_rel" : [ SenseInfo('10353355-n', 8) ],
"_die_n_1_rel" : [ SenseInfo('03191029-n', 6), SenseInfo('03192790-n', 1), SenseInfo('03192907-n', 0) ],
"_declarative_a_1_rel" : [ SenseInfo('00686890-a', 1), SenseInfo('03094520-a', 0) ],
"_grand_a_1_rel" : [ SenseInfo('01284544-a', 6), SenseInfo('01591050-a', 1), SenseInfo('02024928-a', 0), SenseInfo('01676517-a', 0), SenseInfo('01588619-a', 0), SenseInfo('01387149-a', 0), SenseInfo('01278251-a', 0), SenseInfo('00752110-a', 0), SenseInfo('01284544-a', 6), SenseInfo('01591050-a', 1), SenseInfo('02024928-a', 0), SenseInfo('01676517-a', 0), SenseInfo('01588619-a', 0), SenseInfo('01387149-a', 0), SenseInfo('01278251-a', 0), SenseInfo('00752110-a', 0), SenseInfo('01284544-a', 6), SenseInfo('01591050-a', 1), SenseInfo('02024928-a', 0), SenseInfo('01676517-a', 0), SenseInfo('01588619-a', 0), SenseInfo('01387149-a', 0), SenseInfo('01278251-a', 0), SenseInfo('00752110-a', 0) ],
"_normally_x_deg_rel" : [ SenseInfo('00106921-r', 20), SenseInfo('00106921-r', 20) ],
"_immobility_n_1_rel" : [ SenseInfo('14006490-n', 1), SenseInfo('04776299-n', 0) ],
"_immobilization_n_of_rel" : [ SenseInfo('01260309-n', 0), SenseInfo('01146288-n', 0), SenseInfo('01260309-n', 0), SenseInfo('01146288-n', 0) ],
"_knotty_a_1_rel" : [ SenseInfo('00746451-a', 1), SenseInfo('02313235-a', 0), SenseInfo('02176841-a', 0), SenseInfo('00255720-a', 0), SenseInfo('00746451-a', 1), SenseInfo('02313235-a', 0), SenseInfo('02176841-a', 0), SenseInfo('00255720-a', 0), SenseInfo('00746451-a', 1), SenseInfo('02313235-a', 0), SenseInfo('02176841-a', 0), SenseInfo('00255720-a', 0) ],
"_visceral_a_1_rel" : [ SenseInfo('02862964-a', 1), SenseInfo('01431471-a', 0) ],
"_interfere_v_with_rel" : [ SenseInfo('02451912-v', 11), SenseInfo('02538765-v', 3) ],
"_whiteboard_n_1_rel" : [  ],
"_copepod_n_1_rel" : [ SenseInfo('01996585-n', 0) ],
"_comic_a_1_rel" : [ SenseInfo('01265308-a', 3), SenseInfo('02973392-a', 2) ],
"_commemorative_a_1_rel" : [ SenseInfo('03055809-a', 0) ],
"_crafty_a_1_rel" : [ SenseInfo('00148078-a', 1), SenseInfo('00148078-a', 1), SenseInfo('00148078-a', 1) ],
"_frequency_n_1_rel" : [ SenseInfo('15278281-n', 12), SenseInfo('13821570-n', 11), SenseInfo('13598237-n', 2) ],
"_off+route_a_1_rel" : [  ],
"_colony_n_1_rel" : [ SenseInfo('08374049-n', 7), SenseInfo('07995856-n', 2), SenseInfo('09048460-n', 0), SenseInfo('08514233-n', 0), SenseInfo('08499840-n', 0), SenseInfo('07996010-n', 0) ],
"_pelt_v_1_rel" : [ SenseInfo('01507914-v', 1), SenseInfo('01121320-v', 1), SenseInfo('02758033-v', 0) ],
"_wish_v_for_rel" : [ SenseInfo('01824339-v', 48), SenseInfo('01824736-v', 31), SenseInfo('00903212-v', 12), SenseInfo('01824532-v', 5), SenseInfo('00903098-v', 2), SenseInfo('00902932-v', 2) ],
"_weave_n_1_rel" : [ SenseInfo('04568298-n', 2) ],
"_unpredictable_a_1_rel" : [ SenseInfo('01842001-a', 2), SenseInfo('00739789-a', 0), SenseInfo('00594146-a', 0), SenseInfo('01842001-a', 2), SenseInfo('00739789-a', 0), SenseInfo('00594146-a', 0) ],
"_terrible_a_for_rel" : [ SenseInfo('00193799-a', 11), SenseInfo('01126291-a', 2), SenseInfo('01513050-a', 1), SenseInfo('01677200-a', 0), SenseInfo('00193799-a', 11), SenseInfo('01126291-a', 2), SenseInfo('01513050-a', 1), SenseInfo('01677200-a', 0), SenseInfo('00193799-a', 11), SenseInfo('01126291-a', 2), SenseInfo('01513050-a', 1), SenseInfo('01677200-a', 0) ],
"_nice_a_of-for_rel" : [ SenseInfo('01586342-a', 23), SenseInfo('01993408-a', 5), SenseInfo('01838916-a', 1), SenseInfo('00984333-a', 0), SenseInfo('00641460-a', 0), SenseInfo('01586342-a', 23), SenseInfo('01993408-a', 5), SenseInfo('01838916-a', 1), SenseInfo('00984333-a', 0), SenseInfo('00641460-a', 0), SenseInfo('01586342-a', 23), SenseInfo('01993408-a', 5), SenseInfo('01838916-a', 1), SenseInfo('00984333-a', 0), SenseInfo('00641460-a', 0), SenseInfo('01586342-a', 23), SenseInfo('01993408-a', 5), SenseInfo('01838916-a', 1), SenseInfo('00984333-a', 0), SenseInfo('00641460-a', 0), SenseInfo('01586342-a', 23), SenseInfo('01993408-a', 5), SenseInfo('01838916-a', 1), SenseInfo('00984333-a', 0), SenseInfo('00641460-a', 0), SenseInfo('01586342-a', 23), SenseInfo('01993408-a', 5), SenseInfo('01838916-a', 1), SenseInfo('00984333-a', 0), SenseInfo('00641460-a', 0), SenseInfo('01586342-a', 23), SenseInfo('01993408-a', 5), SenseInfo('01838916-a', 1), SenseInfo('00984333-a', 0), SenseInfo('00641460-a', 0), SenseInfo('01586342-a', 23), SenseInfo('01993408-a', 5), SenseInfo('01838916-a', 1), SenseInfo('00984333-a', 0), SenseInfo('00641460-a', 0) ],
"_plural_a_1_rel" : [ SenseInfo('02183512-a', 0), SenseInfo('02182979-a', 0) ],
"_hang_v_about_rel" : [ SenseInfo('01482075-v', 35), SenseInfo('01481360-v', 12), SenseInfo('02485451-v', 11), SenseInfo('01977962-v', 6), SenseInfo('01542668-v', 5), SenseInfo('02734952-v', 2), SenseInfo('02170427-v', 1), SenseInfo('01481957-v', 1), SenseInfo('01216331-v', 1), SenseInfo('02741003-v', 0), SenseInfo('02557790-v', 0), SenseInfo('01677716-v', 0), SenseInfo('01481819-v', 0), SenseInfo('01481647-v', 0), SenseInfo('00210110-v', 0) ],
"_curtail_v_1_rel" : [ SenseInfo('00236592-v', 5), SenseInfo('00292877-v', 0) ],
"_cricket_n_1_rel" : [ SenseInfo('02229544-n', 1), SenseInfo('00476389-n', 0) ],
"_basically_x_deg_rel" : [ SenseInfo('00003483-r', 7) ],
"_clump_v_1_rel" : [ SenseInfo('02184965-v', 0), SenseInfo('02025009-v', 0), SenseInfo('01930033-v', 0), SenseInfo('01484392-v', 0) ],
"_precede_v_1_rel" : [ SenseInfo('02712443-v', 9), SenseInfo('02692686-v', 6), SenseInfo('02407766-v', 3), SenseInfo('01999218-v', 1), SenseInfo('00901799-v', 0) ],
"_orbital_a_1_rel" : [ SenseInfo('02979285-a', 2), SenseInfo('02870178-a', 0) ],
"_swallow_v_1_rel" : [ SenseInfo('01201856-v', 12), SenseInfo('01083769-v', 4), SenseInfo('01582409-v', 2), SenseInfo('00941037-v', 0), SenseInfo('00799076-v', 0), SenseInfo('00737352-v', 0), SenseInfo('00668805-v', 0), SenseInfo('00601659-v', 0) ],
"_botanical_a_1_rel" : [ SenseInfo('02668258-a', 0), SenseInfo('02668258-a', 0) ],
"_hardship_n_1_rel" : [ SenseInfo('14475661-n', 1), SenseInfo('04710127-n', 1), SenseInfo('07336763-n', 0) ],
"_comfortable_a_1_rel" : [ SenseInfo('00476819-a', 17), SenseInfo('00479330-a', 2), SenseInfo('02563194-a', 0), SenseInfo('02336338-a', 0), SenseInfo('02022556-a', 0), SenseInfo('00476819-a', 17), SenseInfo('00479330-a', 2), SenseInfo('02563194-a', 0), SenseInfo('02336338-a', 0), SenseInfo('02022556-a', 0) ],
"_legion_n_1_rel" : [ SenseInfo('08183802-n', 1), SenseInfo('08272248-n', 0), SenseInfo('08271801-n', 0), SenseInfo('08182962-n', 0) ],
"_affair_n_1_rel" : [ SenseInfo('05671325-n', 23), SenseInfo('13931889-n', 5), SenseInfo('07447261-n', 4), SenseInfo('05671325-n', 23), SenseInfo('13931889-n', 5), SenseInfo('07447261-n', 4), SenseInfo('05671325-n', 23), SenseInfo('13931889-n', 5), SenseInfo('07447261-n', 4) ],
"_relevant_a_1_rel" : [ SenseInfo('01975138-a', 11) ],
"_a+lot_x_deg_rel" : [ SenseInfo('00059171-r', 17) ],
"_standardize_v_1_rel" : [ SenseInfo('00467717-v', 1), SenseInfo('00682436-v', 0), SenseInfo('00467717-v', 1), SenseInfo('00682436-v', 0) ],
"_inland_a_2_rel" : [ SenseInfo('00463784-a', 0) ],
"_flip_v_off_rel" : [ SenseInfo('01893079-v', 3), SenseInfo('01510173-v', 1), SenseInfo('02153023-v', 0), SenseInfo('01893601-v', 0), SenseInfo('01893465-v', 0), SenseInfo('01512625-v', 0), SenseInfo('01241614-v', 0), SenseInfo('01222958-v', 0), SenseInfo('00717921-v', 0), SenseInfo('00584810-v', 0), SenseInfo('00121678-v', 0) ],
"_spurt_v_1_rel" : [ SenseInfo('02068413-v', 0), SenseInfo('01884126-v', 0) ],
"_tip_v_over_rel" : [ SenseInfo('02039544-v', 5), SenseInfo('00511178-v', 1), SenseInfo('02202133-v', 0), SenseInfo('02097047-v', 0), SenseInfo('02038357-v', 0), SenseInfo('01924023-v', 0), SenseInfo('01247804-v', 0), SenseInfo('00873469-v', 0), SenseInfo('00176021-v', 0), SenseInfo('02039544-v', 5), SenseInfo('00511178-v', 1), SenseInfo('02202133-v', 0), SenseInfo('02097047-v', 0), SenseInfo('02038357-v', 0), SenseInfo('01924023-v', 0), SenseInfo('01247804-v', 0), SenseInfo('00873469-v', 0), SenseInfo('00176021-v', 0) ],
"_encirclement_n_1_rel" : [ SenseInfo('00954086-n', 0) ],
"_beam_v_to_rel" : [ SenseInfo('00029214-v', 5), SenseInfo('02763740-v', 1), SenseInfo('01067380-v', 1), SenseInfo('00973056-v', 1), SenseInfo('02161530-v', 0), SenseInfo('01829747-v', 0), SenseInfo('00029214-v', 5), SenseInfo('02763740-v', 1), SenseInfo('01067380-v', 1), SenseInfo('00973056-v', 1), SenseInfo('02161530-v', 0), SenseInfo('01829747-v', 0), SenseInfo('00029214-v', 5), SenseInfo('02763740-v', 1), SenseInfo('01067380-v', 1), SenseInfo('00973056-v', 1), SenseInfo('02161530-v', 0), SenseInfo('01829747-v', 0) ],
"_erratic_a_1_rel" : [ SenseInfo('00345189-a', 1), SenseInfo('02127509-a', 0), SenseInfo('00725227-a', 0) ],
"_wax_v_1_rel" : [ SenseInfo('01268726-v', 2), SenseInfo('00433232-v', 1), SenseInfo('00433525-v', 0) ],
"_sudsy_a_1_rel" : [ SenseInfo('02754839-a', 0) ],
"_moulin_n_1_rel" : [  ],
"_inconvenience_n_1_rel" : [ SenseInfo('14446878-n', 1), SenseInfo('04711435-n', 1), SenseInfo('04722715-n', 0) ],
"_oxidation_n_1_rel" : [ SenseInfo('13530408-n', 20) ],
"_peak_v_1_rel" : [ SenseInfo('02008066-v', 1) ],
"_get_v_around_rel" : [ SenseInfo('02210855-v', 235), SenseInfo('00149583-v', 157), SenseInfo('00120796-v', 82), SenseInfo('00522751-v', 64), SenseInfo('02005948-v', 58), SenseInfo('01433294-v', 45), SenseInfo('02108026-v', 36), SenseInfo('01153947-v', 14), SenseInfo('02355596-v', 9), SenseInfo('00770437-v', 7), SenseInfo('01215421-v', 4), SenseInfo('00094460-v', 4), SenseInfo('00087736-v', 4), SenseInfo('01066036-v', 3), SenseInfo('00120316-v', 3), SenseInfo('01026975-v', 2), SenseInfo('00589904-v', 2), SenseInfo('01505958-v', 1), SenseInfo('01401115-v', 1), SenseInfo('00639849-v', 1), SenseInfo('02359340-v', 0), SenseInfo('02208265-v', 0), SenseInfo('02189398-v', 0), SenseInfo('02109645-v', 0), SenseInfo('02108654-v', 0), SenseInfo('02010864-v', 0), SenseInfo('02006573-v', 0), SenseInfo('01771194-v', 0), SenseInfo('01771039-v', 0), SenseInfo('01738107-v', 0), SenseInfo('01643297-v', 0), SenseInfo('01565211-v', 0), SenseInfo('00622384-v', 0), SenseInfo('00345761-v', 0), SenseInfo('00065639-v', 0), SenseInfo('00054628-v', 0), SenseInfo('02210855-v', 235), SenseInfo('00149583-v', 157), SenseInfo('00120796-v', 82), SenseInfo('00522751-v', 64), SenseInfo('02005948-v', 58), SenseInfo('01433294-v', 45), SenseInfo('02108026-v', 36), SenseInfo('01153947-v', 14), SenseInfo('02355596-v', 9), SenseInfo('00770437-v', 7), SenseInfo('01215421-v', 4), SenseInfo('00094460-v', 4), SenseInfo('00087736-v', 4), SenseInfo('01066036-v', 3), SenseInfo('00120316-v', 3), SenseInfo('01026975-v', 2), SenseInfo('00589904-v', 2), SenseInfo('01505958-v', 1), SenseInfo('01401115-v', 1), SenseInfo('00639849-v', 1), SenseInfo('02359340-v', 0), SenseInfo('02208265-v', 0), SenseInfo('02189398-v', 0), SenseInfo('02109645-v', 0), SenseInfo('02108654-v', 0), SenseInfo('02010864-v', 0), SenseInfo('02006573-v', 0), SenseInfo('01771194-v', 0), SenseInfo('01771039-v', 0), SenseInfo('01738107-v', 0), SenseInfo('01643297-v', 0), SenseInfo('01565211-v', 0), SenseInfo('00622384-v', 0), SenseInfo('00345761-v', 0), SenseInfo('00065639-v', 0), SenseInfo('00054628-v', 0) ],
"_negotiate_v_1_rel" : [ SenseInfo('00761713-v', 17), SenseInfo('02050688-v', 0) ],
"_self-activation_n_1_rel" : [  ],
"_aware_a_of_rel" : [ SenseInfo('00190115-a', 40), SenseInfo('01977155-a', 0), SenseInfo('00190115-a', 40), SenseInfo('01977155-a', 0) ],
"_staple_n_1_rel" : [ SenseInfo('02800793-n', 1), SenseInfo('15018688-n', 0), SenseInfo('14596700-n', 0), SenseInfo('04303258-n', 0), SenseInfo('04303095-n', 0) ],
"_transitional_a_1_rel" : [ SenseInfo('02944694-a', 3) ],
"_republican_a_1_rel" : [ SenseInfo('02788378-a', 6), SenseInfo('00716892-a', 0) ],
"_not+surprising_a_1_rel" : [ SenseInfo('02359464-a', 11), SenseInfo('02359464-a', 11) ],
"_afternoonish_a_1_rel" : [  ],
"_thalassemia_n_1_rel" : [ SenseInfo('14195715-n', 0) ],
"_southward_a_1_rel" : [ SenseInfo('01602683-a', 0) ],
"_vote_v_against_rel" : [ SenseInfo('02461314-v', 30), SenseInfo('02462580-v', 10), SenseInfo('02462386-v', 1), SenseInfo('02473890-v', 0), SenseInfo('02462201-v', 0) ],
"_emigrant_n_1_rel" : [ SenseInfo('10051975-n', 0) ],
"_uptown_a_2_rel" : [ SenseInfo('02494594-a', 0) ],
"_glint_n_1_rel" : [ SenseInfo('07412310-n', 1), SenseInfo('04953296-n', 0) ],
"_railing_n_1_rel" : [ SenseInfo('04047401-n', 3), SenseInfo('04047733-n', 0) ],
"_terra-firma_n_1_rel" : [ SenseInfo('09334396-n', 1), SenseInfo('09334396-n', 1) ],
"_peruvian_a_1_rel" : [ SenseInfo('02966154-a', 0) ],
"_in+order+to_x_rel" : [  ],
"_caucasian_n_1_rel" : [ SenseInfo('09638875-n', 0), SenseInfo('06978180-n', 0) ],
"_beguiling_a_1_rel" : [ SenseInfo('02097480-a', 1), SenseInfo('01223781-a', 0), SenseInfo('02097480-a', 1), SenseInfo('01223781-a', 0) ],
"_weigh_v_down_rel" : [ SenseInfo('02704818-v', 17), SenseInfo('00950431-v', 4), SenseInfo('02704617-v', 2), SenseInfo('02645839-v', 1), SenseInfo('02646064-v', 0) ],
"_fissure_v_1_rel" : [ SenseInfo('00336922-v', 0) ],
"_caution_n_1_rel" : [ SenseInfo('04664058-n', 3), SenseInfo('07225167-n', 2), SenseInfo('05615869-n', 2), SenseInfo('04891184-n', 0), SenseInfo('04664058-n', 3), SenseInfo('07225167-n', 2), SenseInfo('05615869-n', 2), SenseInfo('04891184-n', 0) ],
"_speaker_n_1_rel" : [ SenseInfo('10630188-n', 9), SenseInfo('03691459-n', 2), SenseInfo('10631309-n', 1) ],
"_masculine_n_1_rel" : [ SenseInfo('06329165-n', 0) ],
"_s+p+a_n_1_rel" : [ SenseInfo('08678615-n', 0), SenseInfo('04080705-n', 0), SenseInfo('03506370-n', 0), SenseInfo('08678615-n', 0), SenseInfo('04080705-n', 0), SenseInfo('03506370-n', 0), SenseInfo('08678615-n', 0), SenseInfo('04080705-n', 0), SenseInfo('03506370-n', 0), SenseInfo('08678615-n', 0), SenseInfo('04080705-n', 0), SenseInfo('03506370-n', 0), SenseInfo('08678615-n', 0), SenseInfo('04080705-n', 0), SenseInfo('03506370-n', 0), SenseInfo('08678615-n', 0), SenseInfo('04080705-n', 0), SenseInfo('03506370-n', 0), SenseInfo('08678615-n', 0), SenseInfo('04080705-n', 0), SenseInfo('03506370-n', 0), SenseInfo('08678615-n', 0), SenseInfo('04080705-n', 0), SenseInfo('03506370-n', 0), SenseInfo('08678615-n', 0), SenseInfo('04080705-n', 0), SenseInfo('03506370-n', 0) ],
"_bluster_v_1_rel" : [ SenseInfo('02770362-v', 1), SenseInfo('00883226-v', 1), SenseInfo('00012434-v', 0) ],
"_orchard_n_1_rel" : [ SenseInfo('03463832-n', 2) ],
"_button_v_cause_rel" : [ SenseInfo('01368126-v', 0), SenseInfo('01367862-v', 0) ],
"_checker_n_1_rel" : [ SenseInfo('09913110-n', 0), SenseInfo('09912995-n', 0), SenseInfo('03011355-n', 0) ],
"_musket_n_1_rel" : [ SenseInfo('03802007-n', 9) ],
"_beat_n_1_rel" : [ SenseInfo('08507381-n', 1), SenseInfo('07400906-n', 1), SenseInfo('07086518-n', 1), SenseInfo('11477710-n', 0), SenseInfo('09845849-n', 0), SenseInfo('07376937-n', 0), SenseInfo('07094093-n', 0), SenseInfo('05058893-n', 0), SenseInfo('00547616-n', 0), SenseInfo('00314094-n', 0) ],
"_overflow_v_1_rel" : [ SenseInfo('02072159-v', 2), SenseInfo('01763101-v', 0) ],
"_taco_n_1_rel" : [ SenseInfo('09722898-n', 0), SenseInfo('07880751-n', 0) ],
"_date_n_of_rel" : [ SenseInfo('15159583-n', 23), SenseInfo('09992538-n', 3), SenseInfo('08385009-n', 3), SenseInfo('15179888-n', 1), SenseInfo('15120223-n', 1), SenseInfo('15160579-n', 0), SenseInfo('15159819-n', 0), SenseInfo('07765073-n', 0) ],
"_best_a_1_rel" : [ SenseInfo('00227507-a', 94), SenseInfo('00067379-a', 0), SenseInfo('00227507-a', 94), SenseInfo('00067379-a', 0), SenseInfo('00227507-a', 94), SenseInfo('00067379-a', 0), SenseInfo('00227507-a', 94), SenseInfo('00067379-a', 0) ],
"_particular_a_1_rel" : [ SenseInfo('01104026-a', 24), SenseInfo('01104460-a', 13), SenseInfo('00488187-a', 6), SenseInfo('01853228-a', 0), SenseInfo('00984624-a', 0), SenseInfo('00311044-a', 0), SenseInfo('01104026-a', 24), SenseInfo('01104460-a', 13), SenseInfo('00488187-a', 6), SenseInfo('01853228-a', 0), SenseInfo('00984624-a', 0), SenseInfo('00311044-a', 0) ],
"_continental_a_1_rel" : [ SenseInfo('02886263-a', 3), SenseInfo('02886406-a', 0), SenseInfo('02886090-a', 0), SenseInfo('01566916-a', 0) ],
"_romance_v_1_rel" : [ SenseInfo('02534492-v', 0), SenseInfo('01775782-v', 0), SenseInfo('01037910-v', 0), SenseInfo('00834557-v', 0) ],
"_pudding_n_1_rel" : [ SenseInfo('07617188-n', 0), SenseInfo('07612996-n', 0), SenseInfo('07612632-n', 0), SenseInfo('07617188-n', 0), SenseInfo('07612996-n', 0), SenseInfo('07612632-n', 0) ],
"_consider_v_as_rel" : [ SenseInfo('00690614-v', 107), SenseInfo('02166460-v', 51), SenseInfo('00734054-v', 37), SenseInfo('00950431-v', 27), SenseInfo('00813044-v', 15), SenseInfo('00689344-v', 2), SenseInfo('02133185-v', 0), SenseInfo('02130300-v', 0), SenseInfo('00691312-v', 0) ],
"_wine_n_1_rel" : [ SenseInfo('07891726-n', 9), SenseInfo('04964162-n', 2) ],
"_so_a_sel_rel" : [ SenseInfo('06868844-n', 0) ],
"_authentic_a_1_rel" : [ SenseInfo('02465115-a', 6), SenseInfo('01115635-a', 6), SenseInfo('02465115-a', 6), SenseInfo('01115635-a', 6) ],
"_sedimentary_a_1_rel" : [ SenseInfo('02952109-a', 0), SenseInfo('01355089-a', 0) ],
"_reading_n_of_rel" : [ SenseInfo('05808794-n', 22), SenseInfo('07173766-n', 4), SenseInfo('05816790-n', 3), SenseInfo('06598030-n', 2), SenseInfo('05928513-n', 1), SenseInfo('08880223-n', 0), SenseInfo('07234881-n', 0), SenseInfo('01004582-n', 0) ],
"_would-be_a_1_rel" : [ SenseInfo('00104825-a', 0), SenseInfo('00104825-a', 0) ],
"_renewal_n_of_rel" : [ SenseInfo('00269018-n', 2), SenseInfo('01248852-n', 1), SenseInfo('13547925-n', 0) ],
"_frustration_n_1_rel" : [ SenseInfo('07540866-n', 4), SenseInfo('00067990-n', 1), SenseInfo('07518663-n', 0), SenseInfo('07540866-n', 4), SenseInfo('00067990-n', 1), SenseInfo('07518663-n', 0) ],
"_move_v_cause_rel" : [ SenseInfo('01835496-v', 110), SenseInfo('01850315-v', 57), SenseInfo('01831531-v', 52), SenseInfo('01855606-v', 20), SenseInfo('02372605-v', 15), SenseInfo('00014549-v', 7), SenseInfo('00124442-v', 6), SenseInfo('02367363-v', 3), SenseInfo('01767949-v', 3), SenseInfo('01649999-v', 3), SenseInfo('01771390-v', 2), SenseInfo('02355959-v', 1), SenseInfo('00539110-v', 1), SenseInfo('02598863-v', 0), SenseInfo('01076615-v', 0), SenseInfo('00879356-v', 0), SenseInfo('01835496-v', 110), SenseInfo('01850315-v', 57), SenseInfo('01831531-v', 52), SenseInfo('01855606-v', 20), SenseInfo('02372605-v', 15), SenseInfo('00014549-v', 7), SenseInfo('00124442-v', 6), SenseInfo('02367363-v', 3), SenseInfo('01767949-v', 3), SenseInfo('01649999-v', 3), SenseInfo('01771390-v', 2), SenseInfo('02355959-v', 1), SenseInfo('00539110-v', 1), SenseInfo('02598863-v', 0), SenseInfo('01076615-v', 0), SenseInfo('00879356-v', 0), SenseInfo('01835496-v', 110), SenseInfo('01850315-v', 57), SenseInfo('01831531-v', 52), SenseInfo('01855606-v', 20), SenseInfo('02372605-v', 15), SenseInfo('00014549-v', 7), SenseInfo('00124442-v', 6), SenseInfo('02367363-v', 3), SenseInfo('01767949-v', 3), SenseInfo('01649999-v', 3), SenseInfo('01771390-v', 2), SenseInfo('02355959-v', 1), SenseInfo('00539110-v', 1), SenseInfo('02598863-v', 0), SenseInfo('01076615-v', 0), SenseInfo('00879356-v', 0) ],
"_predominant_a_1_rel" : [ SenseInfo('01066787-a', 0), SenseInfo('00792202-a', 0), SenseInfo('01066787-a', 0), SenseInfo('00792202-a', 0), SenseInfo('01066787-a', 0), SenseInfo('00792202-a', 0) ],
"_ignition_n_1_rel" : [ SenseInfo('13495873-n', 0), SenseInfo('03560567-n', 0), SenseInfo('00378479-n', 0) ],
"_thunder_v_1_rel" : [ SenseInfo('02088792-v', 2), SenseInfo('00915605-v', 1), SenseInfo('02770535-v', 0), SenseInfo('01046587-v', 0), SenseInfo('02088792-v', 2), SenseInfo('00915605-v', 1), SenseInfo('02770535-v', 0), SenseInfo('01046587-v', 0) ],
"_dispatch_v_1_rel" : [ SenseInfo('01955127-v', 5), SenseInfo('02563724-v', 1), SenseInfo('02482425-v', 0), SenseInfo('02369633-v', 0), SenseInfo('01325128-v', 0), SenseInfo('01955127-v', 5), SenseInfo('02563724-v', 1), SenseInfo('02482425-v', 0), SenseInfo('02369633-v', 0), SenseInfo('01325128-v', 0) ],
"_eatery_n_1_rel" : [ SenseInfo('04081281-n', 0) ],
"_dubious_a_1_rel" : [ SenseInfo('00338013-a', 2), SenseInfo('01916979-a', 1), SenseInfo('00338669-a', 0), SenseInfo('00338013-a', 2), SenseInfo('01916979-a', 1), SenseInfo('00338669-a', 0) ],
"_nickel_n_1_rel" : [ SenseInfo('14646610-n', 4), SenseInfo('13390139-n', 1), SenseInfo('13395652-n', 0) ],
"_spirit_n_1_rel" : [ SenseInfo('10636598-n', 45), SenseInfo('14526182-n', 37), SenseInfo('04620558-n', 13), SenseInfo('09545324-n', 7), SenseInfo('13985818-n', 6), SenseInfo('06605897-n', 3), SenseInfo('04632157-n', 3), SenseInfo('04624826-n', 2), SenseInfo('10636598-n', 45), SenseInfo('14526182-n', 37), SenseInfo('04620558-n', 13), SenseInfo('09545324-n', 7), SenseInfo('13985818-n', 6), SenseInfo('06605897-n', 3), SenseInfo('04632157-n', 3), SenseInfo('04624826-n', 2), SenseInfo('10636598-n', 45), SenseInfo('14526182-n', 37), SenseInfo('04620558-n', 13), SenseInfo('09545324-n', 7), SenseInfo('13985818-n', 6), SenseInfo('06605897-n', 3), SenseInfo('04632157-n', 3), SenseInfo('04624826-n', 2) ],
"_impromptu_a_1_rel" : [ SenseInfo('01845451-a', 1) ],
"_deputy_n_1_rel" : [ SenseInfo('10005548-n', 9), SenseInfo('10005280-n', 1), SenseInfo('10005934-n', 0), SenseInfo('10005721-n', 0) ],
"_depressing_a_1_rel" : [ SenseInfo('00364479-a', 0) ],
"_city_n_1_rel" : [ SenseInfo('08524735-n', 103), SenseInfo('08540903-n', 13), SenseInfo('08226335-n', 1), SenseInfo('08524735-n', 103), SenseInfo('08540903-n', 13), SenseInfo('08226335-n', 1) ],
"_jeopardize_v_1_rel" : [ SenseInfo('02697120-v', 2), SenseInfo('02545272-v', 2) ],
"_cyst_n_1_rel" : [ SenseInfo('14202996-n', 3), SenseInfo('05517578-n', 0) ],
"_delectable_a_1_rel" : [ SenseInfo('02396720-a', 0), SenseInfo('00733406-a', 0) ],
"_nutriment_n_1_rel" : [ SenseInfo('07570720-n', 0) ],
"_n-tuple_n_1_rel" : [  ],
"_overconfident_a_1_rel" : [ SenseInfo('00339288-a', 1) ],
"_arch_v_cause_rel" : [ SenseInfo('02034986-v', 3), SenseInfo('02034986-v', 3) ],
"_junk_v_1_rel" : [ SenseInfo('02223238-v', 1) ],
"_brook_n_1_rel" : [ SenseInfo('09229409-n', 3), SenseInfo('09229409-n', 3) ],
"_botanize_v_1_rel" : [ SenseInfo('00645415-v', 0) ],
"_vivid_a_1_rel" : [ SenseInfo('01941026-a', 10), SenseInfo('00430041-a', 4), SenseInfo('00402855-a', 0), SenseInfo('00393683-a', 0), SenseInfo('01941026-a', 10), SenseInfo('00430041-a', 4), SenseInfo('00402855-a', 0), SenseInfo('00393683-a', 0), SenseInfo('01941026-a', 10), SenseInfo('00430041-a', 4), SenseInfo('00402855-a', 0), SenseInfo('00393683-a', 0), SenseInfo('01941026-a', 10), SenseInfo('00430041-a', 4), SenseInfo('00402855-a', 0), SenseInfo('00393683-a', 0) ],
"_explosive_a_1_rel" : [ SenseInfo('00474620-a', 3), SenseInfo('02292573-a', 3), SenseInfo('01144009-a', 0), SenseInfo('00474620-a', 3), SenseInfo('02292573-a', 3), SenseInfo('01144009-a', 0) ],
"_deuce_n_1_rel" : [ SenseInfo('13947272-n', 0), SenseInfo('13743269-n', 0), SenseInfo('07125786-n', 0), SenseInfo('03182795-n', 0) ],
"_drift_n_1_rel" : [ SenseInfo('11447851-n', 3), SenseInfo('13469674-n', 1), SenseInfo('13469893-n', 0), SenseInfo('09270233-n', 0), SenseInfo('06197664-n', 0), SenseInfo('05922651-n', 0), SenseInfo('03239399-n', 0) ],
"_dandy_n_1_rel" : [ SenseInfo('09991026-n', 0), SenseInfo('04612373-n', 0) ],
"_coming-of-age_a_1_rel" : [  ],
"_c+_n_1_rel" : [ SenseInfo('13714491-n', 21), SenseInfo('15284285-n', 0), SenseInfo('15093298-n', 0), SenseInfo('14829765-n', 0), SenseInfo('14828511-n', 0), SenseInfo('14633206-n', 0), SenseInfo('13750415-n', 0), SenseInfo('13636648-n', 0), SenseInfo('06902696-n', 0), SenseInfo('06866332-n', 0), SenseInfo('06831391-n', 0), SenseInfo('03066743-n', 0) ],
"_acknowledgement_n_of_rel" : [ SenseInfo('14411981-n', 0), SenseInfo('06628861-n', 0), SenseInfo('14411981-n', 0), SenseInfo('06628861-n', 0) ],
"_chew_v_out_rel" : [ SenseInfo('01201089-v', 10) ],
"_calcareous_a_1_rel" : [ SenseInfo('02673969-a', 0) ],
"_ruthless_a_1_rel" : [ SenseInfo('01508086-a', 1) ],
"_squeeze_v_in_rel" : [ SenseInfo('01593937-v', 9), SenseInfo('01447868-v', 6), SenseInfo('01527271-v', 4), SenseInfo('02504562-v', 0), SenseInfo('02241107-v', 0), SenseInfo('02094569-v', 0), SenseInfo('01456771-v', 0), SenseInfo('01424456-v', 0), SenseInfo('01387786-v', 0), SenseInfo('01593937-v', 9), SenseInfo('01447868-v', 6), SenseInfo('01527271-v', 4), SenseInfo('02504562-v', 0), SenseInfo('02241107-v', 0), SenseInfo('02094569-v', 0), SenseInfo('01456771-v', 0), SenseInfo('01424456-v', 0), SenseInfo('01387786-v', 0) ],
"_shop_n_i_rel" : [ SenseInfo('04202417-n', 9), SenseInfo('04603081-n', 1), SenseInfo('00892254-n', 0) ],
"_into_p_sel_rel" : [  ],
"_poison_v_1_rel" : [ SenseInfo('02580678-v', 3), SenseInfo('01323338-v', 1), SenseInfo('00532429-v', 1), SenseInfo('01323793-v', 0), SenseInfo('00088339-v', 0) ],
"_pained_a_1_rel" : [ SenseInfo('01807075-a', 0) ],
"_infallible_a_1_rel" : [ SenseInfo('00964906-a', 1) ],
"_foil_v_1_rel" : [ SenseInfo('02739688-v', 1), SenseInfo('02558172-v', 1), SenseInfo('01335075-v', 0) ],
"_camp_v_out_rel" : [ SenseInfo('02653996-v', 7), SenseInfo('01514248-v', 0), SenseInfo('00525805-v', 0) ],
"_confusion_n_1_rel" : [ SenseInfo('13975752-n', 14), SenseInfo('05683582-n', 7), SenseInfo('07507912-n', 0), SenseInfo('00379754-n', 0), SenseInfo('00072473-n', 0) ],
"_hermit_n_1_rel" : [ SenseInfo('10519126-n', 0), SenseInfo('10172448-n', 0) ],
"_tester_n_1_rel" : [ SenseInfo('10068234-n', 0), SenseInfo('04415354-n', 0) ],
"_alphabetic_a_1_rel" : [ SenseInfo('02614194-a', 0), SenseInfo('00100634-a', 0) ],
"_searchable_a_1_rel" : [  ],
"_north+german_a_1_rel" : [  ],
"_export_n_of_rel" : [ SenseInfo('03306207-n', 1) ],
"_choose_v_from_rel" : [ SenseInfo('00674607-v', 80), SenseInfo('00679389-v', 19), SenseInfo('00679937-v', 11), SenseInfo('00674607-v', 80), SenseInfo('00679389-v', 19), SenseInfo('00679937-v', 11), SenseInfo('00674607-v', 80), SenseInfo('00679389-v', 19), SenseInfo('00679937-v', 11), SenseInfo('00674607-v', 80), SenseInfo('00679389-v', 19), SenseInfo('00679937-v', 11), SenseInfo('00674607-v', 80), SenseInfo('00679389-v', 19), SenseInfo('00679937-v', 11) ],
"_wartime_n_1_rel" : [ SenseInfo('15293328-n', 0) ],
"_extra_n_1_rel" : [ SenseInfo('10676569-n', 0), SenseInfo('06597349-n', 0), SenseInfo('03307981-n', 0) ],
"_unfold_v_cause_rel" : [ SenseInfo('00293760-v', 5), SenseInfo('02144101-v', 1), SenseInfo('02054989-v', 1), SenseInfo('01579813-v', 0) ],
"_entitle_v_1_rel" : [ SenseInfo('02447370-v', 17), SenseInfo('01029500-v', 6), SenseInfo('02398463-v', 0) ],
"_cram_v_with_rel" : [ SenseInfo('01524298-v', 1), SenseInfo('01612295-v', 0), SenseInfo('00605783-v', 0), SenseInfo('00407146-v', 0) ],
"_careen_v_1_rel" : [ SenseInfo('01924882-v', 1), SenseInfo('01884974-v', 0) ],
"_splatter_v_cause_rel" : [ SenseInfo('01542207-v', 0), SenseInfo('01374020-v', 0) ],
"_meat_n_1_rel" : [ SenseInfo('07649854-n', 4), SenseInfo('13137010-n', 0), SenseInfo('05921123-n', 0) ],
"_arched_a_1_rel" : [ SenseInfo('02639064-a', 1), SenseInfo('02315461-a', 1) ],
"_allegiance_n_1_rel" : [ SenseInfo('01206153-n', 1), SenseInfo('04877938-n', 0) ],
"_blood_n_1_rel" : [ SenseInfo('05399847-n', 61), SenseInfo('04628747-n', 2), SenseInfo('10505942-n', 1), SenseInfo('08101937-n', 1), SenseInfo('07944618-n', 0) ],
"_induce_v_1_rel" : [ SenseInfo('01644050-v', 11), SenseInfo('00770437-v', 6), SenseInfo('01644522-v', 5), SenseInfo('00636441-v', 2), SenseInfo('01737417-v', 0), SenseInfo('01644050-v', 11), SenseInfo('00770437-v', 6), SenseInfo('01644522-v', 5), SenseInfo('00636441-v', 2), SenseInfo('01737417-v', 0) ],
"_armpit_n_1_rel" : [ SenseInfo('05549576-n', 2) ],
"_hardest_a_1_rel" : [  ],
"_jew_n_1_rel" : [ SenseInfo('09681351-n', 55) ],
"_powerless_a_1_rel" : [ SenseInfo('01827535-a', 1) ],
"_glider_n_1_rel" : [ SenseInfo('03439814-n', 0) ],
"_fourth_a_1_rel" : [ SenseInfo('02202443-a', 33), SenseInfo('02202443-a', 33), SenseInfo('02202443-a', 33) ],
"_knuckle_v_down_rel" : [ SenseInfo('01605291-v', 0), SenseInfo('01605169-v', 0) ],
"_conjunction_n_1_rel" : [ SenseInfo('05048301-n', 3), SenseInfo('14420954-n', 1), SenseInfo('06325826-n', 1), SenseInfo('13799392-n', 0), SenseInfo('07415167-n', 0), SenseInfo('03605915-n', 0) ],
"_ungainly_a_1_rel" : [ SenseInfo('01140896-a', 4), SenseInfo('02564023-a', 0) ],
"_hysteria_n_1_rel" : [ SenseInfo('14391876-n', 1), SenseInfo('07520507-n', 1), SenseInfo('14393438-n', 0) ],
"_amplifier_n_of_rel" : [ SenseInfo('02705944-n', 1) ],
"_into_p_rel" : [  ],
"_gauzy_a_1_rel" : [ SenseInfo('02413390-a', 0) ],
"_sever_v_1_rel" : [ SenseInfo('01560984-v', 5), SenseInfo('01560731-v', 3) ],
"_transport_n_1_rel" : [ SenseInfo('03100490-n', 3), SenseInfo('13570236-n', 1), SenseInfo('01105259-n', 1), SenseInfo('13986372-n', 0), SenseInfo('04392764-n', 0), SenseInfo('00315986-n', 0) ],
"_fluoride_n_1_rel" : [ SenseInfo('14871601-n', 2) ],
"_intergovernmental_a_1_rel" : [  ],
"_adventurous_n_1_rel" : [ SenseInfo('00065791-a', 1) ],
"_unpublished_a_1_rel" : [ SenseInfo('00471072-a', 1), SenseInfo('00471072-a', 1) ],
"_port_v_1_rel" : [ SenseInfo('02090854-v', 0), SenseInfo('02087472-v', 0), SenseInfo('01979085-v', 0), SenseInfo('01908204-v', 0), SenseInfo('01450792-v', 0), SenseInfo('01239202-v', 0), SenseInfo('01171661-v', 0), SenseInfo('00587268-v', 0) ],
"_do_v_over_rel" : [ SenseInfo('02560585-v', 526), SenseInfo('01712704-v', 173), SenseInfo('02561995-v', 134), SenseInfo('02617567-v', 58), SenseInfo('01645601-v', 35), SenseInfo('02568672-v', 20), SenseInfo('02669789-v', 11), SenseInfo('01619014-v', 9), SenseInfo('00010435-v', 3), SenseInfo('02709107-v', 2), SenseInfo('02523221-v', 2), SenseInfo('00038849-v', 2), SenseInfo('01841772-v', 1) ],
"_dryshod_a_1_rel" : [  ],
"_hyper_x_deg_rel" : [  ],
"_say_n_1_rel" : [ SenseInfo('14485526-n', 0) ],
"_executory_a_1_rel" : [  ],
"_north+korean_a_1_rel" : [ SenseInfo('02967990-a', 2) ],
"_negation_n_of_rel" : [ SenseInfo('07280941-n', 0), SenseInfo('07206461-n', 0), SenseInfo('06751572-n', 0) ],
"_small-town_a_1_rel" : [  ],
"_impressive_a_1_rel" : [ SenseInfo('01282014-a', 16), SenseInfo('00835292-a', 0), SenseInfo('01282014-a', 16), SenseInfo('00835292-a', 0) ],
"_unrest_n_1_rel" : [ SenseInfo('13979503-n', 1), SenseInfo('07513711-n', 0) ],
"_gathering_n_of_rel" : [ SenseInfo('07975026-n', 3), SenseInfo('01229938-n', 3), SenseInfo('01014990-n', 1), SenseInfo('03428805-n', 0) ],
"_earnings_n_1_rel" : [ SenseInfo('13258362-n', 4), SenseInfo('13279262-n', 2) ],
"_hilltop_n_1_rel" : [ SenseInfo('08584787-n', 0) ],
"_circulation_n_of_rel" : [ SenseInfo('06253371-n', 4), SenseInfo('11439031-n', 1), SenseInfo('13592598-n', 0), SenseInfo('13592384-n', 0), SenseInfo('07312221-n', 0), SenseInfo('00368302-n', 0) ],
"_scribble_v_down_rel" : [ SenseInfo('01006239-v', 1), SenseInfo('01747203-v', 0) ],
"_concealment_n_1_rel" : [ SenseInfo('14416089-n', 0), SenseInfo('04151940-n', 0), SenseInfo('01048912-n', 0) ],
"_suffrage_n_1_rel" : [ SenseInfo('05186306-n', 1) ],
"_uncertain_a_of_rel" : [ SenseInfo('00337404-a', 6), SenseInfo('00336168-a', 3), SenseInfo('02087450-a', 0), SenseInfo('00341405-a', 0), SenseInfo('02504558-a', 0), SenseInfo('00725522-a', 0), SenseInfo('00103567-a', 0), SenseInfo('00337404-a', 6), SenseInfo('00336168-a', 3), SenseInfo('02087450-a', 0), SenseInfo('00341405-a', 0), SenseInfo('02504558-a', 0), SenseInfo('00725522-a', 0), SenseInfo('00103567-a', 0), SenseInfo('00337404-a', 6), SenseInfo('00336168-a', 3), SenseInfo('02087450-a', 0), SenseInfo('00341405-a', 0), SenseInfo('02504558-a', 0), SenseInfo('00725522-a', 0), SenseInfo('00103567-a', 0), SenseInfo('00337404-a', 6), SenseInfo('00336168-a', 3), SenseInfo('02087450-a', 0), SenseInfo('00341405-a', 0), SenseInfo('02504558-a', 0), SenseInfo('00725522-a', 0), SenseInfo('00103567-a', 0) ],
"_tramp_v_1_rel" : [ SenseInfo('01920698-v', 7), SenseInfo('01921204-v', 0), SenseInfo('01881957-v', 0), SenseInfo('01881180-v', 0) ],
"_gulp_n_1_rel" : [ SenseInfo('00840189-n', 2), SenseInfo('00840363-n', 0) ],
"_stray_a_1_rel" : [ SenseInfo('00594267-a', 2), SenseInfo('01450443-a', 0) ],
"_hype_n_1_rel" : [ SenseInfo('07248507-n', 0) ],
"_donor_n_1_rel" : [ SenseInfo('10025730-n', 7), SenseInfo('10026058-n', 0) ],
"_oath_n_1_rel" : [ SenseInfo('07125096-n', 15), SenseInfo('06684572-n', 2), SenseInfo('07226841-n', 0) ],
"_erect_a_1_rel" : [ SenseInfo('01235859-a', 10), SenseInfo('01151592-a', 0) ],
"_reaction_n_1_rel" : [ SenseInfo('13447361-n', 38), SenseInfo('05917328-n', 10), SenseInfo('00859001-n', 7), SenseInfo('11498461-n', 0), SenseInfo('11417129-n', 0), SenseInfo('06216634-n', 0), SenseInfo('00202816-n', 0) ],
"_care+of_p_rel" : [  ],
"_sinner_n_1_rel" : [ SenseInfo('10601078-n', 4) ],
"_mimic_v_1_rel" : [ SenseInfo('01743531-v', 0) ],
"_underpants_n_1_rel" : [ SenseInfo('04508489-n', 0), SenseInfo('04508489-n', 0) ],
"_comrade_n_1_rel" : [ SenseInfo('09945905-n', 55), SenseInfo('09951524-n', 0), SenseInfo('09877124-n', 0) ],
"_enough_a_1_rel" : [ SenseInfo('02336109-a', 50) ],
"_pull_v_through_rel" : [ SenseInfo('01448100-v', 44), SenseInfo('01505254-v', 8), SenseInfo('02057499-v', 6), SenseInfo('01609287-v', 3), SenseInfo('02582615-v', 2), SenseInfo('01995211-v', 2), SenseInfo('02057337-v', 1), SenseInfo('00071803-v', 1), SenseInfo('02103162-v', 0), SenseInfo('01947247-v', 0), SenseInfo('01858573-v', 0), SenseInfo('01573276-v', 0), SenseInfo('01407059-v', 0), SenseInfo('01384275-v', 0), SenseInfo('01351170-v', 0), SenseInfo('01148710-v', 0), SenseInfo('00571596-v', 0) ],
"_controller_n_of_rel" : [ SenseInfo('09761403-n', 2), SenseInfo('10525134-n', 0), SenseInfo('03096960-n', 0) ],
"_seaward_a_1_rel" : [ SenseInfo('00464399-a', 0), SenseInfo('00464195-a', 0), SenseInfo('00463580-a', 0) ],
"_depreciatory_a_1_rel" : [ SenseInfo('02536911-a', 0), SenseInfo('00906655-a', 0) ],
"_nymph_n_1_rel" : [ SenseInfo('09548632-n', 1), SenseInfo('02311617-n', 1), SenseInfo('10368528-n', 0) ],
"_greedy_a_1_rel" : [ SenseInfo('00029933-a', 1), SenseInfo('00888477-a', 0), SenseInfo('00011160-a', 0), SenseInfo('00029933-a', 1), SenseInfo('00888477-a', 0), SenseInfo('00011160-a', 0), SenseInfo('00029933-a', 1), SenseInfo('00888477-a', 0), SenseInfo('00011160-a', 0) ],
"_onion_n_1_rel" : [ SenseInfo('12433081-n', 0), SenseInfo('12432808-n', 0), SenseInfo('07722217-n', 0) ],
"_as+always_a_1_rel" : [  ],
"_aftershock_n_1_rel" : [ SenseInfo('07429637-n', 0) ],
"_intensely_x_deg_rel" : [ SenseInfo('00190959-r', 3) ],
"_many+such_a_rel" : [  ],
"_turmoil_n_1_rel" : [ SenseInfo('13977732-n', 5), SenseInfo('07514520-n', 1), SenseInfo('00554300-n', 0) ],
"_through_a_1_rel" : [ SenseInfo('01003536-a', 4), SenseInfo('00762168-a', 0), SenseInfo('01003536-a', 4), SenseInfo('00762168-a', 0) ],
"_blot_n_1_rel" : [ SenseInfo('04694441-n', 7), SenseInfo('00072261-n', 0) ],
"_crouch_n_1_rel" : [ SenseInfo('00405766-n', 2) ],
"_novel_a_1_rel" : [ SenseInfo('01687167-a', 6), SenseInfo('01642245-a', 0) ],
"_relationship_n_of_rel" : [ SenseInfo('13780719-n', 25), SenseInfo('13928388-n', 9), SenseInfo('13928668-n', 8), SenseInfo('13812607-n', 0) ],
"_intent_a_on_rel" : [ SenseInfo('00163948-a', 4) ],
"_dread_v_1_rel" : [ SenseInfo('01780202-v', 4), SenseInfo('01780202-v', 4), SenseInfo('01780202-v', 4), SenseInfo('01780202-v', 4) ],
"_ratification_n_of_rel" : [ SenseInfo('07179943-n', 0) ],
"_windscreen_n_1_rel" : [ SenseInfo('04590553-n', 0) ],
"_far-reaching_a_1_rel" : [  ],
"_get_v_along_rel" : [ SenseInfo('02210855-v', 235), SenseInfo('00149583-v', 157), SenseInfo('00120796-v', 82), SenseInfo('00522751-v', 64), SenseInfo('02005948-v', 58), SenseInfo('01433294-v', 45), SenseInfo('02108026-v', 36), SenseInfo('01153947-v', 14), SenseInfo('02355596-v', 9), SenseInfo('00770437-v', 7), SenseInfo('01215421-v', 4), SenseInfo('00094460-v', 4), SenseInfo('00087736-v', 4), SenseInfo('01066036-v', 3), SenseInfo('00120316-v', 3), SenseInfo('01026975-v', 2), SenseInfo('00589904-v', 2), SenseInfo('01505958-v', 1), SenseInfo('01401115-v', 1), SenseInfo('00639849-v', 1), SenseInfo('02359340-v', 0), SenseInfo('02208265-v', 0), SenseInfo('02189398-v', 0), SenseInfo('02109645-v', 0), SenseInfo('02108654-v', 0), SenseInfo('02010864-v', 0), SenseInfo('02006573-v', 0), SenseInfo('01771194-v', 0), SenseInfo('01771039-v', 0), SenseInfo('01738107-v', 0), SenseInfo('01643297-v', 0), SenseInfo('01565211-v', 0), SenseInfo('00622384-v', 0), SenseInfo('00345761-v', 0), SenseInfo('00065639-v', 0), SenseInfo('00054628-v', 0) ],
"_unsung_a_1_rel" : [ SenseInfo('01122595-a', 1), SenseInfo('00028867-a', 0), SenseInfo('01122595-a', 1), SenseInfo('00028867-a', 0) ],
"_shroud_n_1_rel" : [ SenseInfo('04210723-n', 0), SenseInfo('04188368-n', 0), SenseInfo('03879116-n', 0) ],
"_acceptable_a_for_rel" : [ SenseInfo('00017782-a', 2), SenseInfo('02297966-a', 0), SenseInfo('01124768-a', 0), SenseInfo('01020709-a', 0), SenseInfo('00017782-a', 2), SenseInfo('02297966-a', 0), SenseInfo('01124768-a', 0), SenseInfo('01020709-a', 0), SenseInfo('00017782-a', 2), SenseInfo('02297966-a', 0), SenseInfo('01124768-a', 0), SenseInfo('01020709-a', 0), SenseInfo('00017782-a', 2), SenseInfo('02297966-a', 0), SenseInfo('01124768-a', 0), SenseInfo('01020709-a', 0) ],
"_emotion_n_1_rel" : [ SenseInfo('07480068-n', 50) ],
"_expansion_n_1_rel" : [ SenseInfo('00365709-n', 10), SenseInfo('13784366-n', 0), SenseInfo('07172756-n', 0), SenseInfo('00371314-n', 0) ],
"_duchess_n_1_rel" : [ SenseInfo('10038409-n', 0) ],
"_idol_n_1_rel" : [ SenseInfo('03560161-n', 2), SenseInfo('10198437-n', 1), SenseInfo('05924519-n', 0) ],
"_not-too-large_a_1_rel" : [  ],
"_articulation_n_of_rel" : [ SenseInfo('07131854-n', 1), SenseInfo('13911151-n', 0), SenseInfo('07073208-n', 0), SenseInfo('05595083-n', 0), SenseInfo('00147314-n', 0) ],
"_experience_n_with_rel" : [ SenseInfo('05758059-n', 52), SenseInfo('05984584-n', 48), SenseInfo('07285403-n', 28), SenseInfo('05758059-n', 52), SenseInfo('05984584-n', 48), SenseInfo('07285403-n', 28), SenseInfo('05758059-n', 52), SenseInfo('05984584-n', 48), SenseInfo('07285403-n', 28) ],
"_auction_n_of_rel" : [ SenseInfo('00491161-n', 0), SenseInfo('00092366-n', 0) ],
"_furtive_a_1_rel" : [ SenseInfo('02088974-a', 1), SenseInfo('01706111-a', 0) ],
"_mark_n_cur_rel" : [ SenseInfo('05737153-n', 5), SenseInfo('07270179-n', 4), SenseInfo('07262108-n', 3), SenseInfo('06798750-n', 2), SenseInfo('04676064-n', 2), SenseInfo('06794666-n', 1), SenseInfo('13688033-n', 0), SenseInfo('11156943-n', 0), SenseInfo('09921409-n', 0), SenseInfo('06817782-n', 0), SenseInfo('06646243-n', 0), SenseInfo('06441803-n', 0), SenseInfo('04693900-n', 0), SenseInfo('04681387-n', 0), SenseInfo('00064789-n', 0) ],
"_pelvic+style_a_1_rel" : [  ],
"_in-line_a_1_rel" : [ SenseInfo('00128137-a', 1), SenseInfo('00852576-a', 0), SenseInfo('00128137-a', 1), SenseInfo('00852576-a', 0) ],
"_bar_v_from_rel" : [ SenseInfo('00796588-v', 9), SenseInfo('01478002-v', 5), SenseInfo('02503803-v', 1), SenseInfo('01342910-v', 1), SenseInfo('00796588-v', 9), SenseInfo('01478002-v', 5), SenseInfo('02503803-v', 1), SenseInfo('01342910-v', 1) ],
"_livelihood_n_1_rel" : [ SenseInfo('13365286-n', 1) ],
"_bluff_v_1_rel" : [ SenseInfo('01076953-v', 0), SenseInfo('00837872-v', 0) ],
"_onshore_a_1_rel" : [ SenseInfo('00464195-a', 1), SenseInfo('00125068-a', 0), SenseInfo('00464195-a', 1), SenseInfo('00125068-a', 0) ],
"_revenue_n_1_rel" : [ SenseInfo('13256691-n', 5), SenseInfo('13261916-n', 0) ],
"_end_n_of_rel" : [ SenseInfo('08566028-n', 35), SenseInfo('15266911-n', 31), SenseInfo('07291794-n', 23), SenseInfo('05980875-n', 22), SenseInfo('05868477-n', 13), SenseInfo('14562960-n', 6), SenseInfo('08566707-n', 5), SenseInfo('10056398-n', 3), SenseInfo('08565894-n', 2), SenseInfo('08566884-n', 1), SenseInfo('00787727-n', 1), SenseInfo('06398401-n', 0), SenseInfo('03286383-n', 0), SenseInfo('00728065-n', 0), SenseInfo('08566028-n', 35), SenseInfo('15266911-n', 31), SenseInfo('07291794-n', 23), SenseInfo('05980875-n', 22), SenseInfo('05868477-n', 13), SenseInfo('14562960-n', 6), SenseInfo('08566707-n', 5), SenseInfo('10056398-n', 3), SenseInfo('08565894-n', 2), SenseInfo('08566884-n', 1), SenseInfo('00787727-n', 1), SenseInfo('06398401-n', 0), SenseInfo('03286383-n', 0), SenseInfo('00728065-n', 0), SenseInfo('08566028-n', 35), SenseInfo('15266911-n', 31), SenseInfo('07291794-n', 23), SenseInfo('05980875-n', 22), SenseInfo('05868477-n', 13), SenseInfo('14562960-n', 6), SenseInfo('08566707-n', 5), SenseInfo('10056398-n', 3), SenseInfo('08565894-n', 2), SenseInfo('08566884-n', 1), SenseInfo('00787727-n', 1), SenseInfo('06398401-n', 0), SenseInfo('03286383-n', 0), SenseInfo('00728065-n', 0) ],
"_booking_n_1_rel" : [ SenseInfo('00270919-n', 6), SenseInfo('01218327-n', 1) ],
"_feature_v_as_rel" : [ SenseInfo('02630189-v', 16), SenseInfo('02631659-v', 3), SenseInfo('02630189-v', 16), SenseInfo('02631659-v', 3) ],
"_wrinkle_n_1_rel" : [ SenseInfo('13905792-n', 4), SenseInfo('06251424-n', 0), SenseInfo('06251295-n', 0) ],
"_version_n_of_rel" : [ SenseInfo('07173585-n', 7), SenseInfo('05840650-n', 7), SenseInfo('06408779-n', 1), SenseInfo('06536389-n', 0), SenseInfo('05928513-n', 0), SenseInfo('01267901-n', 0) ],
"_following_a_1_rel" : [ SenseInfo('00127815-a', 30), SenseInfo('00127948-a', 20), SenseInfo('00199569-a', 3), SenseInfo('00995365-a', 0) ],
"_fist_n_1_rel" : [ SenseInfo('05565064-n', 20) ],
"_counsellor_n_1_rel" : [ SenseInfo('09969062-n', 0), SenseInfo('09968845-n', 0), SenseInfo('09775663-n', 0) ],
"_stick_n_1_rel" : [ SenseInfo('04317420-n', 7), SenseInfo('13165646-n', 6), SenseInfo('04317976-n', 5), SenseInfo('07848645-n', 0), SenseInfo('05561707-n', 0), SenseInfo('04318131-n', 0), SenseInfo('04317833-n', 0), SenseInfo('03600806-n', 0), SenseInfo('01162928-n', 0) ],
"_ultra-high_a_1_rel" : [  ],
"_hold_n_of_rel" : [ SenseInfo('00812526-n', 5), SenseInfo('05806623-n', 2), SenseInfo('05197232-n', 2), SenseInfo('15272029-n', 0), SenseInfo('13999663-n', 0), SenseInfo('03525372-n', 0), SenseInfo('03525252-n', 0), SenseInfo('03485997-n', 0), SenseInfo('02964634-n', 0) ],
"_reconnoiter_v_1_rel" : [ SenseInfo('02167571-v', 1) ],
"_bombard_v_1_rel" : [ SenseInfo('01507914-v', 0), SenseInfo('01131902-v', 0), SenseInfo('00863579-v', 0), SenseInfo('00291624-v', 0) ],
"_highlight_v_1_rel" : [ SenseInfo('00514069-v', 2), SenseInfo('00041206-v', 0), SenseInfo('00514069-v', 2), SenseInfo('00041206-v', 0) ],
"_ecu_n_1_rel" : [  ],
"_sprinkle_v_with_rel" : [ SenseInfo('01376245-v', 5), SenseInfo('01374767-v', 1), SenseInfo('02757828-v', 0), SenseInfo('00228655-v', 0) ],
"_hose_v_1_rel" : [ SenseInfo('00228521-v', 0) ],
"_philharmonic_n_1_rel" : [ SenseInfo('08248856-n', 0) ],
"_involve_v_1_rel" : [ SenseInfo('02677097-v', 56), SenseInfo('02677567-v', 23), SenseInfo('02636132-v', 17), SenseInfo('02627934-v', 12), SenseInfo('02633218-v', 6), SenseInfo('00600724-v', 0), SenseInfo('00401538-v', 0) ],
"_inflection_n_1_rel" : [ SenseInfo('13803782-n', 1), SenseInfo('07083732-n', 1), SenseInfo('07366971-n', 0), SenseInfo('07083958-n', 0) ],
"_confound_v_1_rel" : [ SenseInfo('00621734-v', 2), SenseInfo('00619610-v', 0) ],
"_dart_n_1_rel" : [ SenseInfo('03162818-n', 0), SenseInfo('03162714-n', 0), SenseInfo('00334356-n', 0) ],
"_interchangeable_a_1_rel" : [ SenseInfo('02372697-a', 0), SenseInfo('01978532-a', 0), SenseInfo('02372697-a', 0), SenseInfo('01978532-a', 0) ],
"_madden_v_1_rel" : [ SenseInfo('01787822-v', 0), SenseInfo('01787709-v', 0), SenseInfo('01787600-v', 0), SenseInfo('01787822-v', 0), SenseInfo('01787709-v', 0), SenseInfo('01787600-v', 0), SenseInfo('01787822-v', 0), SenseInfo('01787709-v', 0), SenseInfo('01787600-v', 0) ],
"_inheritance_n_of_rel" : [ SenseInfo('00083585-n', 2), SenseInfo('13262913-n', 0), SenseInfo('04922338-n', 0), SenseInfo('04921011-n', 0) ],
"_camphor_n_1_rel" : [ SenseInfo('14790979-n', 0) ],
"_circular_n_1_rel" : [ SenseInfo('07250339-n', 0), SenseInfo('07250339-n', 0) ],
"_composed_a_of_rel" : [ SenseInfo('00529266-a', 2) ],
"_staff_n_of_rel" : [ SenseInfo('08439955-n', 17), SenseInfo('04296261-n', 2), SenseInfo('08287586-n', 1), SenseInfo('15050320-n', 0), SenseInfo('07267160-n', 0), SenseInfo('06861860-n', 0) ],
"_blind_v_to_rel" : [ SenseInfo('02168555-v', 2), SenseInfo('02168194-v', 2), SenseInfo('00312278-v', 0) ],
"_experiment_v_on_rel" : [ SenseInfo('02532595-v', 17), SenseInfo('02532886-v', 0) ],
"_environs_n_1_rel" : [ SenseInfo('08567235-n', 1), SenseInfo('08539457-n', 0), SenseInfo('08567235-n', 1), SenseInfo('08539457-n', 0) ],
"_make_v_cause_rel" : [ SenseInfo('02560585-v', 508), SenseInfo('00120316-v', 459), SenseInfo('01617192-v', 243), SenseInfo('00770437-v', 85), SenseInfo('01645601-v', 78), SenseInfo('01621555-v', 52), SenseInfo('00730758-v', 33), SenseInfo('01646075-v', 17), SenseInfo('01640207-v', 16), SenseInfo('02289295-v', 14), SenseInfo('01619014-v', 14), SenseInfo('02621395-v', 12), SenseInfo('02022162-v', 12), SenseInfo('02674708-v', 10), SenseInfo('01653873-v', 9), SenseInfo('01755816-v', 8), SenseInfo('01654628-v', 5), SenseInfo('00556855-v', 5), SenseInfo('00012267-v', 5), SenseInfo('02396716-v', 4), SenseInfo('02355596-v', 4), SenseInfo('02020590-v', 4), SenseInfo('00665476-v', 4), SenseInfo('02582921-v', 3), SenseInfo('02598483-v', 2), SenseInfo('01733477-v', 2), SenseInfo('00276068-v', 2), SenseInfo('02075857-v', 1), SenseInfo('00074038-v', 1), SenseInfo('02748759-v', 0), SenseInfo('02748627-v', 0), SenseInfo('02745332-v', 0), SenseInfo('02665124-v', 0), SenseInfo('02621133-v', 0), SenseInfo('02134050-v', 0), SenseInfo('02051031-v', 0), SenseInfo('02021532-v', 0), SenseInfo('01755504-v', 0), SenseInfo('01664172-v', 0), SenseInfo('01428578-v', 0), SenseInfo('00891038-v', 0), SenseInfo('00838524-v', 0), SenseInfo('00698256-v', 0), SenseInfo('00698104-v', 0), SenseInfo('00562182-v', 0), SenseInfo('00562067-v', 0), SenseInfo('00545953-v', 0), SenseInfo('00107369-v', 0), SenseInfo('00072012-v', 0), SenseInfo('02560585-v', 508), SenseInfo('00120316-v', 459), SenseInfo('01617192-v', 243), SenseInfo('00770437-v', 85), SenseInfo('01645601-v', 78), SenseInfo('01621555-v', 52), SenseInfo('00730758-v', 33), SenseInfo('01646075-v', 17), SenseInfo('01640207-v', 16), SenseInfo('02289295-v', 14), SenseInfo('01619014-v', 14), SenseInfo('02621395-v', 12), SenseInfo('02022162-v', 12), SenseInfo('02674708-v', 10), SenseInfo('01653873-v', 9), SenseInfo('01755816-v', 8), SenseInfo('01654628-v', 5), SenseInfo('00556855-v', 5), SenseInfo('00012267-v', 5), SenseInfo('02396716-v', 4), SenseInfo('02355596-v', 4), SenseInfo('02020590-v', 4), SenseInfo('00665476-v', 4), SenseInfo('02582921-v', 3), SenseInfo('02598483-v', 2), SenseInfo('01733477-v', 2), SenseInfo('00276068-v', 2), SenseInfo('02075857-v', 1), SenseInfo('00074038-v', 1), SenseInfo('02748759-v', 0), SenseInfo('02748627-v', 0), SenseInfo('02745332-v', 0), SenseInfo('02665124-v', 0), SenseInfo('02621133-v', 0), SenseInfo('02134050-v', 0), SenseInfo('02051031-v', 0), SenseInfo('02021532-v', 0), SenseInfo('01755504-v', 0), SenseInfo('01664172-v', 0), SenseInfo('01428578-v', 0), SenseInfo('00891038-v', 0), SenseInfo('00838524-v', 0), SenseInfo('00698256-v', 0), SenseInfo('00698104-v', 0), SenseInfo('00562182-v', 0), SenseInfo('00562067-v', 0), SenseInfo('00545953-v', 0), SenseInfo('00107369-v', 0), SenseInfo('00072012-v', 0), SenseInfo('02560585-v', 508), SenseInfo('00120316-v', 459), SenseInfo('01617192-v', 243), SenseInfo('00770437-v', 85), SenseInfo('01645601-v', 78), SenseInfo('01621555-v', 52), SenseInfo('00730758-v', 33), SenseInfo('01646075-v', 17), SenseInfo('01640207-v', 16), SenseInfo('02289295-v', 14), SenseInfo('01619014-v', 14), SenseInfo('02621395-v', 12), SenseInfo('02022162-v', 12), SenseInfo('02674708-v', 10), SenseInfo('01653873-v', 9), SenseInfo('01755816-v', 8), SenseInfo('01654628-v', 5), SenseInfo('00556855-v', 5), SenseInfo('00012267-v', 5), SenseInfo('02396716-v', 4), SenseInfo('02355596-v', 4), SenseInfo('02020590-v', 4), SenseInfo('00665476-v', 4), SenseInfo('02582921-v', 3), SenseInfo('02598483-v', 2), SenseInfo('01733477-v', 2), SenseInfo('00276068-v', 2), SenseInfo('02075857-v', 1), SenseInfo('00074038-v', 1), SenseInfo('02748759-v', 0), SenseInfo('02748627-v', 0), SenseInfo('02745332-v', 0), SenseInfo('02665124-v', 0), SenseInfo('02621133-v', 0), SenseInfo('02134050-v', 0), SenseInfo('02051031-v', 0), SenseInfo('02021532-v', 0), SenseInfo('01755504-v', 0), SenseInfo('01664172-v', 0), SenseInfo('01428578-v', 0), SenseInfo('00891038-v', 0), SenseInfo('00838524-v', 0), SenseInfo('00698256-v', 0), SenseInfo('00698104-v', 0), SenseInfo('00562182-v', 0), SenseInfo('00562067-v', 0), SenseInfo('00545953-v', 0), SenseInfo('00107369-v', 0), SenseInfo('00072012-v', 0) ],
"_basic_x_rel" : [ SenseInfo('01855764-a', 45), SenseInfo('02295298-a', 17), SenseInfo('06902909-n', 0), SenseInfo('02800793-n', 0), SenseInfo('01011753-a', 0), SenseInfo('00026168-a', 0) ],
"_inflect_v_cause_rel" : [ SenseInfo('00982514-v', 1), SenseInfo('00982293-v', 0) ],
"_laborious_a_1_rel" : [ SenseInfo('00836544-a', 0), SenseInfo('00836544-a', 0) ],
"_originate_v_from_rel" : [ SenseInfo('02624263-v', 12), SenseInfo('01628449-v', 4), SenseInfo('02743343-v', 0) ],
"_ringbone_n_1_rel" : [  ],
"_twitch_v_1_rel" : [ SenseInfo('00009631-v', 4), SenseInfo('01891817-v', 2), SenseInfo('01893601-v', 0), SenseInfo('01456771-v', 0), SenseInfo('01448778-v', 0) ],
"_shower_v_2_rel" : [ SenseInfo('02264601-v', 2), SenseInfo('01372994-v', 2), SenseInfo('00035259-v', 2), SenseInfo('02757651-v', 0), SenseInfo('01184333-v', 0) ],
"_recommend_v_to_rel" : [ SenseInfo('00875141-v', 50), SenseInfo('00882948-v', 6), SenseInfo('00578733-v', 0), SenseInfo('00875141-v', 50), SenseInfo('00882948-v', 6), SenseInfo('00578733-v', 0) ],
"_holder_n_of_rel" : [ SenseInfo('03525454-n', 23), SenseInfo('10180178-n', 0), SenseInfo('10179911-n', 0) ],
"_raisin_n_1_rel" : [ SenseInfo('07752664-n', 0) ],
"_solicitor_n_of_rel" : [ SenseInfo('10623354-n', 0), SenseInfo('10623175-n', 0) ],
"_back+order_n_1_rel" : [  ],
"_exciting_a_1_rel" : [ SenseInfo('00921014-a', 12), SenseInfo('02306763-a', 3), SenseInfo('00921014-a', 12), SenseInfo('02306763-a', 3) ],
"_around_x_deg_rel" : [ SenseInfo('00071165-r', 26), SenseInfo('00071601-r', 13), SenseInfo('00072329-r', 12), SenseInfo('00071741-r', 6), SenseInfo('00007015-r', 2), SenseInfo('00072201-r', 1), SenseInfo('00072043-r', 1), SenseInfo('00071840-r', 1), SenseInfo('00071050-r', 1), SenseInfo('00071456-r', 0), SenseInfo('00071165-r', 26), SenseInfo('00071601-r', 13), SenseInfo('00072329-r', 12), SenseInfo('00071741-r', 6), SenseInfo('00007015-r', 2), SenseInfo('00072201-r', 1), SenseInfo('00072043-r', 1), SenseInfo('00071840-r', 1), SenseInfo('00071050-r', 1), SenseInfo('00071456-r', 0) ],
"_consistency_n_1_rel" : [ SenseInfo('04934546-n', 2), SenseInfo('04745932-n', 2), SenseInfo('14420780-n', 0), SenseInfo('04785195-n', 0) ],
"_wire_n_1_rel" : [ SenseInfo('04594218-n', 15), SenseInfo('04594489-n', 5), SenseInfo('08684107-n', 1), SenseInfo('06622709-n', 1) ],
"_no-service_a_1_rel" : [  ],
"_inadvisable_a_1_rel" : [ SenseInfo('00067767-a', 1), SenseInfo('00932565-a', 0), SenseInfo('00067767-a', 1), SenseInfo('00932565-a', 0) ],
"_doubt_v_1_rel" : [ SenseInfo('00687295-v', 16), SenseInfo('00687523-v', 1), SenseInfo('00687295-v', 16), SenseInfo('00687523-v', 1) ],
"_old-timer_n_1_rel" : [ SenseInfo('10749123-n', 0), SenseInfo('10376890-n', 0), SenseInfo('10749123-n', 0), SenseInfo('10376890-n', 0) ],
"_over_n_1_rel" : [ SenseInfo('15258694-n', 0) ],
"_gp_n_1_rel" : [ SenseInfo('10126009-n', 0) ],
"_not+the+least_x_deg_rel" : [  ],
"_nowhere_near_x_deg_rel" : [  ],
"_grandson_n_of_rel" : [ SenseInfo('10143299-n', 0) ],
"_hand-edit_v_1_rel" : [  ],
"_awning_n_1_rel" : [ SenseInfo('02763901-n', 0) ],
"_non+service_n_1_rel" : [  ],
"_buoy_n_1_rel" : [ SenseInfo('07266178-n', 0) ],
"_windowpane_n_1_rel" : [ SenseInfo('04589745-n', 2), SenseInfo('02662825-n', 0) ],
"_offense_n_1_rel" : [ SenseInfo('01224031-n', 2), SenseInfo('07517550-n', 1), SenseInfo('00766234-n', 1), SenseInfo('08081244-n', 0), SenseInfo('00980038-n', 0) ],
"_mailman_n_1_rel" : [ SenseInfo('10283037-n', 1) ],
"_agency_n_1_rel" : [ SenseInfo('08337324-n', 20), SenseInfo('08057206-n', 6), SenseInfo('14007546-n', 1), SenseInfo('14000403-n', 0), SenseInfo('00172710-n', 0) ],
"_ankle_n_1_rel" : [ SenseInfo('05578442-n', 7) ],
"_barracks_n_1_rel" : [ SenseInfo('02794779-n', 1) ],
"_undeclared_a_1_rel" : [ SenseInfo('00688581-a', 1), SenseInfo('00688581-a', 1) ],
"_spinner_n_1_rel" : [ SenseInfo('10636340-n', 0), SenseInfo('04278751-n', 0), SenseInfo('04278605-n', 0) ],
"_no+wonder_a_1_rel" : [  ],
"_sense_n_of_rel" : [ SenseInfo('05677504-n', 37), SenseInfo('06602472-n', 23), SenseInfo('05651971-n', 16), SenseInfo('05614657-n', 8), SenseInfo('05807012-n', 1), SenseInfo('05677504-n', 37), SenseInfo('06602472-n', 23), SenseInfo('05651971-n', 16), SenseInfo('05614657-n', 8), SenseInfo('05807012-n', 1), SenseInfo('05677504-n', 37), SenseInfo('06602472-n', 23), SenseInfo('05651971-n', 16), SenseInfo('05614657-n', 8), SenseInfo('05807012-n', 1) ],
"_honey_n_1_rel" : [ SenseInfo('07858978-n', 9), SenseInfo('09849598-n', 4) ],
"_linger_v_1_rel" : [ SenseInfo('02731242-v', 3), SenseInfo('02639075-v', 2), SenseInfo('02011560-v', 2), SenseInfo('02058590-v', 1), SenseInfo('02640906-v', 0) ],
"_chuckle_v_1_rel" : [ SenseInfo('00031663-v', 8), SenseInfo('00031663-v', 8) ],
"_preserve_v_1_rel" : [ SenseInfo('02679899-v', 21), SenseInfo('02280132-v', 9), SenseInfo('02225492-v', 9), SenseInfo('00212414-v', 1), SenseInfo('02733122-v', 0), SenseInfo('02682773-v', 0) ],
"_hawaiian_a_1_rel" : [ SenseInfo('02738760-a', 0) ],
"_whoop_n_1_rel" : [ SenseInfo('07123288-n', 0) ],
"_pop_v_cause_rel" : [ SenseInfo('02081946-v', 3), SenseInfo('01404913-v', 3), SenseInfo('02185988-v', 1), SenseInfo('01134071-v', 1), SenseInfo('02186192-v', 0), SenseInfo('02157519-v', 0), SenseInfo('01499510-v', 0), SenseInfo('01474980-v', 0), SenseInfo('01401005-v', 0), SenseInfo('01202374-v', 0), SenseInfo('01199487-v', 0), SenseInfo('00309792-v', 0), SenseInfo('00309582-v', 0) ],
"_thick_a_1_rel" : [ SenseInfo('02410393-a', 25), SenseInfo('00539009-a', 7), SenseInfo('02415390-a', 6), SenseInfo('01337314-a', 2), SenseInfo('02387413-a', 0), SenseInfo('01771839-a', 0), SenseInfo('01513776-a', 0), SenseInfo('00452114-a', 0), SenseInfo('00440292-a', 0), SenseInfo('00015480-a', 0), SenseInfo('02410393-a', 25), SenseInfo('00539009-a', 7), SenseInfo('02415390-a', 6), SenseInfo('01337314-a', 2), SenseInfo('02387413-a', 0), SenseInfo('01771839-a', 0), SenseInfo('01513776-a', 0), SenseInfo('00452114-a', 0), SenseInfo('00440292-a', 0), SenseInfo('00015480-a', 0), SenseInfo('02410393-a', 25), SenseInfo('00539009-a', 7), SenseInfo('02415390-a', 6), SenseInfo('01337314-a', 2), SenseInfo('02387413-a', 0), SenseInfo('01771839-a', 0), SenseInfo('01513776-a', 0), SenseInfo('00452114-a', 0), SenseInfo('00440292-a', 0), SenseInfo('00015480-a', 0), SenseInfo('02410393-a', 25), SenseInfo('00539009-a', 7), SenseInfo('02415390-a', 6), SenseInfo('01337314-a', 2), SenseInfo('02387413-a', 0), SenseInfo('01771839-a', 0), SenseInfo('01513776-a', 0), SenseInfo('00452114-a', 0), SenseInfo('00440292-a', 0), SenseInfo('00015480-a', 0) ],
"_unusual_a_about_rel" : [ SenseInfo('00490035-a', 24), SenseInfo('00967129-a', 1), SenseInfo('00488857-a', 1), SenseInfo('00490035-a', 24), SenseInfo('00967129-a', 1), SenseInfo('00488857-a', 1) ],
"_peacock_n_1_rel" : [ SenseInfo('02279257-n', 2), SenseInfo('01806143-n', 2) ],
"_acute_a_1_rel" : [ SenseInfo('00044760-a', 2), SenseInfo('00803275-a', 2), SenseInfo('01744515-a', 1), SenseInfo('01811820-a', 0), SenseInfo('01810189-a', 0), SenseInfo('00650900-a', 0), SenseInfo('00044760-a', 2), SenseInfo('00803275-a', 2), SenseInfo('01744515-a', 1), SenseInfo('01811820-a', 0), SenseInfo('01810189-a', 0), SenseInfo('00650900-a', 0) ],
"_subsist_v_1_rel" : [ SenseInfo('02616713-v', 1) ],
"_thornbush_n_1_rel" : [  ],
"_off+chance_n_1_rel" : [  ],
"_fuck_v_around_rel" : [ SenseInfo('01426397-v', 0) ],
"_pedigree_n_1_rel" : [ SenseInfo('08101937-n', 2), SenseInfo('08101846-n', 0), SenseInfo('04923907-n', 0) ],
"_stern_n_1_rel" : [ SenseInfo('04316646-n', 2), SenseInfo('11316828-n', 0), SenseInfo('05559256-n', 0) ],
"_unthinkable_n_1_rel" : [ SenseInfo('02418538-a', 0) ],
"_motocross_n_1_rel" : [  ],
"_pharmaceuticals_n_1_rel" : [ SenseInfo('03920989-n', 0), SenseInfo('03920989-n', 0), SenseInfo('03920989-n', 0) ],
"_ham_n_1_rel" : [ SenseInfo('07669891-n', 1), SenseInfo('10158222-n', 0), SenseInfo('10158139-n', 0), SenseInfo('10158010-n', 0) ],
"_rival_v_1_rel" : [ SenseInfo('02672187-v', 4), SenseInfo('01122194-v', 0) ],
"_dog_n_1_rel" : [ SenseInfo('02084071-n', 42), SenseInfo('10114209-n', 0), SenseInfo('10023039-n', 0), SenseInfo('09886220-n', 0), SenseInfo('07676602-n', 0), SenseInfo('03901548-n', 0), SenseInfo('02710044-n', 0) ],
"_scream_v_1_rel" : [ SenseInfo('00913065-v', 25), SenseInfo('00912833-v', 2), SenseInfo('02173336-v', 1), SenseInfo('00913065-v', 25), SenseInfo('00912833-v', 2), SenseInfo('02173336-v', 1), SenseInfo('00913065-v', 25), SenseInfo('00912833-v', 2), SenseInfo('02173336-v', 1) ],
"_theme_n_of_rel" : [ SenseInfo('06599788-n', 9), SenseInfo('05920272-n', 5), SenseInfo('07029247-n', 0), SenseInfo('06409752-n', 0), SenseInfo('06300193-n', 0) ],
"_countable_a_1_rel" : [ SenseInfo('00301589-a', 0) ],
"_viral_a_1_rel" : [ SenseInfo('02880201-a', 0) ],
"_southerly_a_1_rel" : [ SenseInfo('01603179-a', 0), SenseInfo('01602966-a', 0) ],
"_onlooker_n_1_rel" : [ SenseInfo('10378026-n', 3) ],
"_befit_v_1_rel" : [ SenseInfo('02699941-v', 2) ],
"_heredity_n_1_rel" : [ SenseInfo('13493399-n', 1), SenseInfo('04920867-n', 0) ],
"_annex_n_1_rel" : [ SenseInfo('02713594-n', 0) ],
"_throw_v_open_rel" : [ SenseInfo('01508368-v', 53), SenseInfo('02097204-v', 9), SenseInfo('01513430-v', 7), SenseInfo('01499265-v', 7), SenseInfo('01060317-v', 6), SenseInfo('01510173-v', 5), SenseInfo('01632897-v', 4), SenseInfo('02097341-v', 2), SenseInfo('01791232-v', 2), SenseInfo('01067664-v', 2), SenseInfo('01733477-v', 1), SenseInfo('01663443-v', 0), SenseInfo('01527754-v', 0), SenseInfo('01437011-v', 0), SenseInfo('00621734-v', 0) ],
"_sideways_p_rel" : [ SenseInfo('00454344-r', 0), SenseInfo('00454210-r', 0), SenseInfo('00454031-r', 0), SenseInfo('00453580-r', 0), SenseInfo('01719779-a', 0) ],
"_fatal_a_1_rel" : [ SenseInfo('00993529-a', 6), SenseInfo('00685113-a', 4), SenseInfo('01050088-a', 0), SenseInfo('00343226-a', 0) ],
"_authorship_n_1_rel" : [ SenseInfo('00929718-n', 1), SenseInfo('00240754-n', 0) ],
"_cool_v_off-cause_rel" : [ SenseInfo('00370412-v', 15), SenseInfo('00369864-v', 1), SenseInfo('00370126-v', 0) ],
"_pointillistic_a_1_rel" : [ SenseInfo('01789734-a', 0) ],
"_bite_n_of_rel" : [ SenseInfo('14287408-n', 1), SenseInfo('07579076-n', 1), SenseInfo('14297870-n', 0), SenseInfo('07577374-n', 0), SenseInfo('07477413-n', 0), SenseInfo('06776986-n', 0), SenseInfo('04992834-n', 0), SenseInfo('00838816-n', 0), SenseInfo('00361041-n', 0) ],
"_callous_a_1_rel" : [ SenseInfo('02107162-a', 3), SenseInfo('02447569-a', 0), SenseInfo('02107162-a', 3), SenseInfo('02447569-a', 0) ],
"_groan_n_1_rel" : [ SenseInfo('07126383-n', 2) ],
"_chief_a_1_rel" : [ SenseInfo('01277426-a', 16) ],
"_close+by_a_1_rel" : [  ],
"_backyard_n_1_rel" : [ SenseInfo('02772197-n', 4), SenseInfo('02772197-n', 4) ],
"_terrible_a_1_rel" : [ SenseInfo('00193799-a', 11), SenseInfo('01126291-a', 2), SenseInfo('01513050-a', 1), SenseInfo('01677200-a', 0) ],
"_wear_v_out_rel" : [ SenseInfo('00052374-v', 83), SenseInfo('00047745-v', 22), SenseInfo('02740034-v', 6), SenseInfo('00469382-v', 2), SenseInfo('00047610-v', 2), SenseInfo('02705132-v', 1), SenseInfo('01369346-v', 0), SenseInfo('00075021-v', 0), SenseInfo('00050652-v', 0), SenseInfo('00052374-v', 83), SenseInfo('00047745-v', 22), SenseInfo('02740034-v', 6), SenseInfo('00469382-v', 2), SenseInfo('00047610-v', 2), SenseInfo('02705132-v', 1), SenseInfo('01369346-v', 0), SenseInfo('00075021-v', 0), SenseInfo('00050652-v', 0) ],
"_included_a_1_rel" : [ SenseInfo('01658269-a', 0) ],
"_sioux_a_1_rel" : [ SenseInfo('09669125-n', 3) ],
"_encoding_n_1_rel" : [ SenseInfo('00615887-n', 0) ],
"_up+to+par_a_1_rel" : [  ],
"_stricture_n_1_rel" : [ SenseInfo('14107374-n', 0), SenseInfo('06712761-n', 0) ],
"_expedient_a_for_rel" : [ SenseInfo('00931555-a', 1), SenseInfo('01813733-a', 0), SenseInfo('00931555-a', 1), SenseInfo('01813733-a', 0) ],
"_as+though_x_rel" : [  ],
"_immemorial_a_1_rel" : [ SenseInfo('01639973-a', 0), SenseInfo('01639973-a', 0) ],
"_glassware_n_1_rel" : [ SenseInfo('03439064-n', 0) ],
"_concentrate_v_1_rel" : [ SenseInfo('00237511-v', 8), SenseInfo('00722232-v', 4), SenseInfo('00405236-v', 4), SenseInfo('00244625-v', 2), SenseInfo('02032934-v', 1), SenseInfo('00365188-v', 0), SenseInfo('00237259-v', 0), SenseInfo('00236999-v', 0) ],
"_stumble_n_1_rel" : [ SenseInfo('00289388-n', 0), SenseInfo('00076563-n', 0) ],
"_retinue_n_1_rel" : [ SenseInfo('08429167-n', 0) ],
"_fricative_n_1_rel" : [ SenseInfo('07118554-n', 0) ],
"_unrelenting_a_1_rel" : [ SenseInfo('01785341-a', 0), SenseInfo('01510798-a', 0), SenseInfo('00593071-a', 0), SenseInfo('01785341-a', 0), SenseInfo('01510798-a', 0), SenseInfo('00593071-a', 0) ],
"_only+child_n_1_rel" : [  ],
"_option_n_1_rel" : [ SenseInfo('13241600-n', 0), SenseInfo('05790944-n', 0), SenseInfo('00161243-n', 0), SenseInfo('13241600-n', 0), SenseInfo('05790944-n', 0), SenseInfo('00161243-n', 0), SenseInfo('13241600-n', 0), SenseInfo('05790944-n', 0), SenseInfo('00161243-n', 0), SenseInfo('13241600-n', 0), SenseInfo('05790944-n', 0), SenseInfo('00161243-n', 0), SenseInfo('13241600-n', 0), SenseInfo('05790944-n', 0), SenseInfo('00161243-n', 0) ],
"_derring-do_n_1_rel" : [ SenseInfo('00043116-n', 0), SenseInfo('00043116-n', 0) ],
"_S$_n_1_rel" : [  ],
"_untrammeled_a_1_rel" : [ SenseInfo('01416255-a', 1) ],
"_sleighride_v_1_rel" : [  ],
"_educe_v_1_rel" : [ SenseInfo('01630532-v', 0), SenseInfo('00251615-v', 0), SenseInfo('01630532-v', 0), SenseInfo('00251615-v', 0) ],
"_contract_v_1_rel" : [ SenseInfo('00888786-v', 8), SenseInfo('02409941-v', 3), SenseInfo('01387786-v', 2), SenseInfo('00087736-v', 2), SenseInfo('00240571-v', 1), SenseInfo('01279474-v', 0), SenseInfo('00365188-v', 0), SenseInfo('00305109-v', 0), SenseInfo('00243900-v', 0), SenseInfo('00888786-v', 8), SenseInfo('02409941-v', 3), SenseInfo('01387786-v', 2), SenseInfo('00087736-v', 2), SenseInfo('00240571-v', 1), SenseInfo('01279474-v', 0), SenseInfo('00365188-v', 0), SenseInfo('00305109-v', 0), SenseInfo('00243900-v', 0), SenseInfo('00888786-v', 8), SenseInfo('02409941-v', 3), SenseInfo('01387786-v', 2), SenseInfo('00087736-v', 2), SenseInfo('00240571-v', 1), SenseInfo('01279474-v', 0), SenseInfo('00365188-v', 0), SenseInfo('00305109-v', 0), SenseInfo('00243900-v', 0) ],
"_brave_a_1_rel" : [ SenseInfo('00262792-a', 10), SenseInfo('00250119-a', 1), SenseInfo('00407151-a', 0), SenseInfo('00262792-a', 10), SenseInfo('00250119-a', 1), SenseInfo('00407151-a', 0), SenseInfo('00262792-a', 10), SenseInfo('00250119-a', 1), SenseInfo('00407151-a', 0), SenseInfo('00262792-a', 10), SenseInfo('00250119-a', 1), SenseInfo('00407151-a', 0) ],
"_to_x_subord_rel" : [  ],
"_cheers_v_1_rel" : [ SenseInfo('01817938-v', 1), SenseInfo('00858568-v', 1), SenseInfo('00859325-v', 0), SenseInfo('00859153-v', 0), SenseInfo('00858781-v', 0) ],
"_cause_v_1_rel" : [ SenseInfo('01645601-v', 110), SenseInfo('00770437-v', 45), SenseInfo('01645601-v', 110), SenseInfo('00770437-v', 45), SenseInfo('01645601-v', 110), SenseInfo('00770437-v', 45) ],
"_stairway_n_1_rel" : [ SenseInfo('04298308-n', 3) ],
"_bronze_n_1_rel" : [ SenseInfo('14717275-n', 2), SenseInfo('02906175-n', 0) ],
"_provided_x_rel" : [  ],
"_to+and+fro_a_1_rel" : [  ],
"_agree_v_on_rel" : [ SenseInfo('00805376-v', 62), SenseInfo('00764222-v', 25), SenseInfo('02657219-v', 4), SenseInfo('02700104-v', 1), SenseInfo('02741793-v', 0), SenseInfo('02291135-v', 0), SenseInfo('01035530-v', 0), SenseInfo('00805376-v', 62), SenseInfo('00764222-v', 25), SenseInfo('02657219-v', 4), SenseInfo('02700104-v', 1), SenseInfo('02741793-v', 0), SenseInfo('02291135-v', 0), SenseInfo('01035530-v', 0) ],
"_super_x_deg_rel" : [ SenseInfo('02341864-a', 3), SenseInfo('00046299-r', 2), SenseInfo('00528761-a', 1), SenseInfo('10675721-n', 0), SenseInfo('01390588-a', 0) ],
"_stop_v_up_rel" : [ SenseInfo('01860795-v', 57), SenseInfo('02680814-v', 56), SenseInfo('02559752-v', 25), SenseInfo('01862918-v', 7), SenseInfo('01859221-v', 7), SenseInfo('00362348-v', 4), SenseInfo('01131473-v', 3), SenseInfo('01440378-v', 2), SenseInfo('02609764-v', 1), SenseInfo('01478002-v', 0), SenseInfo('00362610-v', 0) ],
"_churn_v_1_rel" : [ SenseInfo('01418389-v', 1), SenseInfo('01885430-v', 0) ],
"_run_v_prd_rel" : [ SenseInfo('01926311-v', 106), SenseInfo('02075049-v', 38), SenseInfo('02685951-v', 21), SenseInfo('02443849-v', 20), SenseInfo('02721284-v', 10), SenseInfo('02066939-v', 9), SenseInfo('01525666-v', 8), SenseInfo('02727039-v', 7), SenseInfo('01094086-v', 7), SenseInfo('01717169-v', 5), SenseInfo('02099829-v', 4), SenseInfo('02719399-v', 3), SenseInfo('01526290-v', 3), SenseInfo('00549063-v', 3), SenseInfo('00517529-v', 3), SenseInfo('02720904-v', 2), SenseInfo('02647497-v', 2), SenseInfo('02612234-v', 2), SenseInfo('02563327-v', 2), SenseInfo('01746359-v', 2), SenseInfo('01641545-v', 2), SenseInfo('01212230-v', 2), SenseInfo('02686625-v', 1), SenseInfo('02525312-v', 1), SenseInfo('02242256-v', 1), SenseInfo('02092309-v', 1), SenseInfo('02060792-v', 1), SenseInfo('01927903-v', 1), SenseInfo('01914947-v', 1), SenseInfo('02648110-v', 0), SenseInfo('02421921-v', 0), SenseInfo('01927747-v', 0), SenseInfo('01927447-v', 0), SenseInfo('01926984-v', 0), SenseInfo('01864038-v', 0), SenseInfo('01143838-v', 0), SenseInfo('01086103-v', 0), SenseInfo('00539110-v', 0), SenseInfo('00444629-v', 0), SenseInfo('00334803-v', 0), SenseInfo('00332672-v', 0) ],
"_movement_n_of_rel" : [ SenseInfo('00331950-n', 24), SenseInfo('00279835-n', 16), SenseInfo('07309781-n', 14), SenseInfo('08464601-n', 4), SenseInfo('07046339-n', 4), SenseInfo('00798245-n', 4), SenseInfo('11425088-n', 3), SenseInfo('13441387-n', 0), SenseInfo('06197664-n', 0), SenseInfo('03795758-n', 0), SenseInfo('00280586-n', 0), SenseInfo('00331950-n', 24), SenseInfo('00279835-n', 16), SenseInfo('07309781-n', 14), SenseInfo('08464601-n', 4), SenseInfo('07046339-n', 4), SenseInfo('00798245-n', 4), SenseInfo('11425088-n', 3), SenseInfo('13441387-n', 0), SenseInfo('06197664-n', 0), SenseInfo('03795758-n', 0), SenseInfo('00280586-n', 0) ],
"_perch_v_cause_rel" : [ SenseInfo('01543731-v', 6), SenseInfo('01978700-v', 0), SenseInfo('01611240-v', 0) ],
"_worse_a_1_rel" : [ SenseInfo('00231252-a', 15), SenseInfo('00232068-a', 0) ],
"_intermediate_n_1_rel" : [ SenseInfo('14921272-n', 2) ],
"_craft_v_1_rel" : [ SenseInfo('01658762-v', 0) ],
"_tolerance_n_for_rel" : [ SenseInfo('05033410-n', 1), SenseInfo('04637923-n', 1), SenseInfo('01071090-n', 1), SenseInfo('06204406-n', 0), SenseInfo('04749991-n', 0) ],
"_implementation_n_of_rel" : [ SenseInfo('01127379-n', 2), SenseInfo('00044150-n', 1) ],
"_median_n_1_rel" : [ SenseInfo('06023821-n', 0) ],
"_mare_n_1_rel" : [ SenseInfo('02377480-n', 2), SenseInfo('09346613-n', 0) ],
"_impatient_a_1_rel" : [ SenseInfo('01737241-a', 5), SenseInfo('00811536-a', 2) ],
"_trust_n_1_rel" : [ SenseInfo('13360498-n', 4), SenseInfo('05697976-n', 3), SenseInfo('04895246-n', 3), SenseInfo('08236621-n', 1), SenseInfo('05943066-n', 1), SenseInfo('13929852-n', 0) ],
"_suck_v_1_rel" : [ SenseInfo('01169704-v', 4), SenseInfo('01854888-v', 2), SenseInfo('02765692-v', 0), SenseInfo('02674340-v', 0), SenseInfo('02117170-v', 0), SenseInfo('01539063-v', 0), SenseInfo('01186428-v', 0) ],
"_watt_n_1_rel" : [ SenseInfo('13644522-n', 2), SenseInfo('11376742-n', 0) ],
"_definable_a_1_rel" : [ SenseInfo('00739022-a', 1) ],
"_cross_a_with-at_rel" : [ SenseInfo('01445917-a', 4), SenseInfo('01136248-a', 1) ],
"_company_n_1_rel" : [ SenseInfo('08058098-n', 60), SenseInfo('08214272-n', 28), SenseInfo('13929588-n', 6), SenseInfo('08187033-n', 5), SenseInfo('09887850-n', 3), SenseInfo('08184861-n', 3), SenseInfo('08264897-n', 0), SenseInfo('08219059-n', 0), SenseInfo('08077711-n', 0), SenseInfo('08058098-n', 60), SenseInfo('08214272-n', 28), SenseInfo('13929588-n', 6), SenseInfo('08187033-n', 5), SenseInfo('09887850-n', 3), SenseInfo('08184861-n', 3), SenseInfo('08264897-n', 0), SenseInfo('08219059-n', 0), SenseInfo('08077711-n', 0), SenseInfo('08058098-n', 60), SenseInfo('08214272-n', 28), SenseInfo('13929588-n', 6), SenseInfo('08187033-n', 5), SenseInfo('09887850-n', 3), SenseInfo('08184861-n', 3), SenseInfo('08264897-n', 0), SenseInfo('08219059-n', 0), SenseInfo('08077711-n', 0), SenseInfo('08058098-n', 60), SenseInfo('08214272-n', 28), SenseInfo('13929588-n', 6), SenseInfo('08187033-n', 5), SenseInfo('09887850-n', 3), SenseInfo('08184861-n', 3), SenseInfo('08264897-n', 0), SenseInfo('08219059-n', 0), SenseInfo('08077711-n', 0), SenseInfo('08058098-n', 60), SenseInfo('08214272-n', 28), SenseInfo('13929588-n', 6), SenseInfo('08187033-n', 5), SenseInfo('09887850-n', 3), SenseInfo('08184861-n', 3), SenseInfo('08264897-n', 0), SenseInfo('08219059-n', 0), SenseInfo('08077711-n', 0), SenseInfo('08058098-n', 60), SenseInfo('08214272-n', 28), SenseInfo('13929588-n', 6), SenseInfo('08187033-n', 5), SenseInfo('09887850-n', 3), SenseInfo('08184861-n', 3), SenseInfo('08264897-n', 0), SenseInfo('08219059-n', 0), SenseInfo('08077711-n', 0) ],
"_my+god_a_1_rel" : [  ],
"_no+longer_a_1_rel" : [  ],
"_all_n_1_rel" : [ SenseInfo('02269286-a', 247), SenseInfo('00521584-a', 3) ],
"_sob_v_1_rel" : [ SenseInfo('00067129-v', 2) ],
"_crust_n_1_rel" : [ SenseInfo('09260010-n', 1), SenseInfo('09260218-n', 0), SenseInfo('04915866-n', 0) ],
"_grow_v_up_rel" : [ SenseInfo('00125841-v', 70), SenseInfo('00230746-v', 62), SenseInfo('00231557-v', 32), SenseInfo('00245457-v', 12), SenseInfo('00250181-v', 8), SenseInfo('02624263-v', 7), SenseInfo('01739814-v', 3), SenseInfo('00094460-v', 3), SenseInfo('00543410-v', 2), SenseInfo('00250539-v', 0) ],
"_bard_n_1_rel" : [ SenseInfo('09839022-n', 0), SenseInfo('02792305-n', 0) ],
"_dumb_a_1_rel" : [ SenseInfo('00440579-a', 9), SenseInfo('00152629-a', 0), SenseInfo('00152004-a', 0), SenseInfo('00151855-a', 0), SenseInfo('00440579-a', 9), SenseInfo('00152629-a', 0), SenseInfo('00152004-a', 0), SenseInfo('00151855-a', 0), SenseInfo('00440579-a', 9), SenseInfo('00152629-a', 0), SenseInfo('00152004-a', 0), SenseInfo('00151855-a', 0) ],
"_jack_n_of_rel" : [ SenseInfo('13773047-n', 0), SenseInfo('10294602-n', 0), SenseInfo('10241300-n', 0), SenseInfo('07754684-n', 0), SenseInfo('03589672-n', 0), SenseInfo('03589513-n', 0), SenseInfo('03589313-n', 0), SenseInfo('03589220-n', 0), SenseInfo('03589093-n', 0), SenseInfo('03588951-n', 0), SenseInfo('02576575-n', 0), SenseInfo('02389943-n', 0) ],
"_stare_v_1_rel" : [ SenseInfo('02132745-v', 82), SenseInfo('00033406-v', 4), SenseInfo('02132745-v', 82), SenseInfo('00033406-v', 4) ],
"_alight_v_1_rel" : [ SenseInfo('01978700-v', 1), SenseInfo('01978576-v', 0) ],
"_spelling_n_1_rel" : [ SenseInfo('06353445-n', 2) ],
"_dive_v_1_rel" : [ SenseInfo('01967373-v', 4), SenseInfo('01962865-v', 1), SenseInfo('01962671-v', 0) ],
"_reverse-engineer_v_1_rel" : [  ],
"_crowbar_n_1_rel" : [ SenseInfo('03138344-n', 0) ],
"_shove_v_out_rel" : [ SenseInfo('01871680-v', 6), SenseInfo('01584701-v', 5), SenseInfo('02094569-v', 0) ],
"_unsubstantial_a_1_rel" : [ SenseInfo('00625774-a', 0), SenseInfo('00625774-a', 0) ],
"_sauerkraut_n_1_rel" : [ SenseInfo('07876189-n', 0) ],
"_uncertain_a_1_rel" : [ SenseInfo('00337404-a', 6), SenseInfo('00336168-a', 3), SenseInfo('02087450-a', 0), SenseInfo('00341405-a', 0), SenseInfo('02504558-a', 0), SenseInfo('00725522-a', 0), SenseInfo('00103567-a', 0), SenseInfo('00337404-a', 6), SenseInfo('00336168-a', 3), SenseInfo('02087450-a', 0), SenseInfo('00341405-a', 0), SenseInfo('02504558-a', 0), SenseInfo('00725522-a', 0), SenseInfo('00103567-a', 0) ],
"_blond_a_1_rel" : [ SenseInfo('00243606-a', 2), SenseInfo('00243606-a', 2), SenseInfo('00243606-a', 2) ],
"_slot_v_1_rel" : [ SenseInfo('00679112-v', 1) ],
"_accept_v_as_rel" : [ SenseInfo('00686447-v', 34), SenseInfo('02236124-v', 33), SenseInfo('00797697-v', 17), SenseInfo('00719231-v', 12), SenseInfo('02236624-v', 8), SenseInfo('02301825-v', 7), SenseInfo('00668805-v', 2), SenseInfo('02741546-v', 0), SenseInfo('02210622-v', 0), SenseInfo('02209936-v', 0), SenseInfo('00718489-v', 0), SenseInfo('00686447-v', 34), SenseInfo('02236124-v', 33), SenseInfo('00797697-v', 17), SenseInfo('00719231-v', 12), SenseInfo('02236624-v', 8), SenseInfo('02301825-v', 7), SenseInfo('00668805-v', 2), SenseInfo('02741546-v', 0), SenseInfo('02210622-v', 0), SenseInfo('02209936-v', 0), SenseInfo('00718489-v', 0) ],
"_benefit_v_1_rel" : [ SenseInfo('02290461-v', 15), SenseInfo('02290956-v', 7) ],
"_unwanted_a_1_rel" : [ SenseInfo('02527734-a', 2), SenseInfo('00733905-a', 0), SenseInfo('02527734-a', 2), SenseInfo('00733905-a', 0) ],
"_adrenaline_n_1_rel" : [ SenseInfo('05408388-n', 0) ],
"_bream_n_1_rel" : [ SenseInfo('07777358-n', 0), SenseInfo('07777189-n', 0), SenseInfo('02590702-n', 0), SenseInfo('02563182-n', 0) ],
"_iron-shod_a_1_rel" : [ SenseInfo('02156177-a', 1) ],
"_centralize_v_1_rel" : [ SenseInfo('00405236-v', 2), SenseInfo('00405236-v', 2) ],
"_conveyancing_n_1_rel" : [ SenseInfo('01108402-n', 0) ],
"_tote_n_1_rel" : [ SenseInfo('02970408-n', 0) ],
"_brow_n_1_rel" : [ SenseInfo('05602548-n', 9), SenseInfo('05313535-n', 3), SenseInfo('08584787-n', 2) ],
"_steward_n_1_rel" : [ SenseInfo('10655442-n', 1), SenseInfo('10655730-n', 0), SenseInfo('10655594-n', 0), SenseInfo('10592811-n', 0), SenseInfo('09984298-n', 0) ],
"_corrosion_n_1_rel" : [ SenseInfo('14561995-n', 0), SenseInfo('13453428-n', 0) ],
"_jam_n_1_rel" : [ SenseInfo('07642933-n', 3), SenseInfo('14409489-n', 0), SenseInfo('08183398-n', 0), SenseInfo('01253379-n', 0) ],
"_homelessness_n_1_rel" : [ SenseInfo('13943053-n', 0) ],
"_seat_n_1_rel" : [ SenseInfo('08647616-n', 9), SenseInfo('05559256-n', 4), SenseInfo('04161981-n', 2), SenseInfo('04161358-n', 2), SenseInfo('08647945-n', 1), SenseInfo('08490039-n', 0), SenseInfo('05189946-n', 0), SenseInfo('04162599-n', 0), SenseInfo('04162433-n', 0) ],
"_smirk_n_1_rel" : [ SenseInfo('06878580-n', 0) ],
"_hurl_v_1_rel" : [ SenseInfo('01507143-v', 9), SenseInfo('02062212-v', 3), SenseInfo('01067664-v', 0), SenseInfo('01507143-v', 9), SenseInfo('02062212-v', 3), SenseInfo('01067664-v', 0) ],
"_disappointed_a_1_rel" : [ SenseInfo('02333976-a', 4) ],
"_interpret_v_as_rel" : [ SenseInfo('00623151-v', 17), SenseInfo('00938247-v', 10), SenseInfo('01732172-v', 2), SenseInfo('01686132-v', 2), SenseInfo('00959827-v', 1), SenseInfo('00593852-v', 1), SenseInfo('00623151-v', 17), SenseInfo('00938247-v', 10), SenseInfo('01732172-v', 2), SenseInfo('01686132-v', 2), SenseInfo('00959827-v', 1), SenseInfo('00593852-v', 1) ],
"_trait_n_1_rel" : [ SenseInfo('04616059-n', 3) ],
"_front_v_on_rel" : [ SenseInfo('02693319-v', 2), SenseInfo('01079172-v', 2) ],
"_thematic_a_1_rel" : [ SenseInfo('02813680-a', 1), SenseInfo('02813978-a', 0) ],
"_vowel_n_1_rel" : [ SenseInfo('07112550-n', 3), SenseInfo('07114712-n', 0) ],
"_railway_n_1_rel" : [ SenseInfo('04048568-n', 1), SenseInfo('04048075-n', 1) ],
"_legendary_a_1_rel" : [ SenseInfo('01376355-a', 3), SenseInfo('01935744-a', 0) ],
"_old_a_1_rel" : [ SenseInfo('01643620-a', 108), SenseInfo('01638438-a', 95), SenseInfo('00966357-a', 5), SenseInfo('00936297-a', 1), SenseInfo('01729566-a', 0), SenseInfo('01116118-a', 0), SenseInfo('00820219-a', 0), SenseInfo('00127137-a', 0), SenseInfo('01643620-a', 108), SenseInfo('01638438-a', 95), SenseInfo('00966357-a', 5), SenseInfo('00936297-a', 1), SenseInfo('01729566-a', 0), SenseInfo('01116118-a', 0), SenseInfo('00820219-a', 0), SenseInfo('00127137-a', 0), SenseInfo('01643620-a', 108), SenseInfo('01638438-a', 95), SenseInfo('00966357-a', 5), SenseInfo('00936297-a', 1), SenseInfo('01729566-a', 0), SenseInfo('01116118-a', 0), SenseInfo('00820219-a', 0), SenseInfo('00127137-a', 0), SenseInfo('01643620-a', 108), SenseInfo('01638438-a', 95), SenseInfo('00966357-a', 5), SenseInfo('00936297-a', 1), SenseInfo('01729566-a', 0), SenseInfo('01116118-a', 0), SenseInfo('00820219-a', 0), SenseInfo('00127137-a', 0) ],
"_arithmetical_a_1_rel" : [ SenseInfo('03044869-a', 0) ],
"_tenacious_a_1_rel" : [ SenseInfo('02005756-a', 0), SenseInfo('02327569-a', 0), SenseInfo('00053384-a', 0), SenseInfo('02005756-a', 0), SenseInfo('02327569-a', 0), SenseInfo('00053384-a', 0) ],
"_rambunctious_a_1_rel" : [ SenseInfo('01666489-a', 0) ],
"_lap_v_1_rel" : [ SenseInfo('02692197-v', 3), SenseInfo('01432176-v', 1), SenseInfo('02188198-v', 0), SenseInfo('01170983-v', 0), SenseInfo('00217576-v', 0) ],
"_slant_v_1_rel" : [ SenseInfo('02692558-v', 1), SenseInfo('00680485-v', 1), SenseInfo('02038357-v', 0), SenseInfo('01884577-v', 0) ],
"_machinery_n_1_rel" : [ SenseInfo('03701640-n', 15), SenseInfo('08434029-n', 3) ],
"_sugar_n_1_rel" : [ SenseInfo('07859284-n', 5), SenseInfo('14792703-n', 0), SenseInfo('13385216-n', 0) ],
"_statue_n_1_rel" : [ SenseInfo('04306847-n', 5) ],
"_orphan_n_1_rel" : [ SenseInfo('10384392-n', 1), SenseInfo('10384496-n', 0), SenseInfo('07013269-n', 0), SenseInfo('01321770-n', 0) ],
"_stuffed_a_1_rel" : [ SenseInfo('01086118-a', 1), SenseInfo('01086213-a', 0) ],
"_clamor_n_1_rel" : [ SenseInfo('07377473-n', 5), SenseInfo('07122118-n', 0), SenseInfo('07377473-n', 5), SenseInfo('07122118-n', 0) ],
"_unventilated_a_1_rel" : [ SenseInfo('02509292-a', 1), SenseInfo('02509292-a', 1) ],
"_swift_a_1_rel" : [ SenseInfo('00978199-a', 15), SenseInfo('00978199-a', 15), SenseInfo('00978199-a', 15), SenseInfo('00978199-a', 15) ],
"_inventive_a_1_rel" : [ SenseInfo('00643863-a', 1) ],
"_compartment_n_1_rel" : [ SenseInfo('03080309-n', 4), SenseInfo('03079741-n', 1) ],
"_brief_a_1_rel" : [ SenseInfo('01442826-a', 12), SenseInfo('00547166-a', 6), SenseInfo('01436432-a', 1), SenseInfo('01442826-a', 12), SenseInfo('00547166-a', 6), SenseInfo('01436432-a', 1), SenseInfo('01442826-a', 12), SenseInfo('00547166-a', 6), SenseInfo('01436432-a', 1), SenseInfo('01442826-a', 12), SenseInfo('00547166-a', 6), SenseInfo('01436432-a', 1) ],
"_shred_v_cause_rel" : [ SenseInfo('01573891-v', 1) ],
"_gammarid_n_1_rel" : [  ],
"_postcard_n_1_rel" : [ SenseInfo('06627938-n', 0) ],
"_turf_n_1_rel" : [ SenseInfo('09463919-n', 1), SenseInfo('08689771-n', 0), SenseInfo('08590719-n', 0) ],
"_jingle_v_cause_rel" : [ SenseInfo('02172683-v', 1) ],
"_dew-sodden_a_1_rel" : [  ],
"_benefactor_n_1_rel" : [ SenseInfo('09608709-n', 0) ],
"_indoor_a_1_rel" : [ SenseInfo('01692786-a', 2), SenseInfo('00953127-a', 0) ],
"_sundial_n_1_rel" : [ SenseInfo('04355338-n', 1) ],
"_put_v_on_rel" : [ SenseInfo('01494310-v', 138), SenseInfo('01493741-v', 98), SenseInfo('00981276-v', 28), SenseInfo('01160370-v', 6), SenseInfo('02271137-v', 3), SenseInfo('00673448-v', 2), SenseInfo('02111499-v', 0), SenseInfo('01706375-v', 0), SenseInfo('00735571-v', 0) ],
"_hand_v_down_rel" : [ SenseInfo('02230772-v', 25), SenseInfo('02000133-v', 0) ],
"_bathe_v_1_rel" : [ SenseInfo('00035603-v', 5), SenseInfo('01582070-v', 2), SenseInfo('00037919-v', 0) ],
"_mist_n_1_rel" : [ SenseInfo('11482706-n', 10) ],
"_sophisticated_a_1_rel" : [ SenseInfo('02270342-a', 9), SenseInfo('01208738-a', 1), SenseInfo('01333609-a', 0) ],
"_forwards_p_rel" : [ SenseInfo('00074641-r', 53), SenseInfo('00203237-a', 8), SenseInfo('00103859-r', 5), SenseInfo('00075442-r', 3), SenseInfo('00067265-r', 3), SenseInfo('01955508-v', 3), SenseInfo('00204491-a', 0), SenseInfo('00203774-a', 0), SenseInfo('10105733-n', 0), SenseInfo('00725383-n', 0), SenseInfo('00275694-r', 0), SenseInfo('01876555-a', 0) ],
"_emmie_n_1_rel" : [  ],
"_stack_n_1_rel" : [ SenseInfo('07963087-n', 2), SenseInfo('13774404-n', 0), SenseInfo('06494646-n', 0), SenseInfo('04247175-n', 0), SenseInfo('04027504-n', 0) ],
"_second+of+all_a_1_rel" : [  ],
"_pour_v_down_rel" : [ SenseInfo('02069551-v', 12), SenseInfo('02028366-v', 7), SenseInfo('02070296-v', 6), SenseInfo('02069248-v', 4), SenseInfo('02355806-v', 1), SenseInfo('02758033-v', 0) ],
"_abhor_v_1_rel" : [ SenseInfo('01774426-v', 1) ],
"_helix_n_1_rel" : [ SenseInfo('13876561-n', 0), SenseInfo('03065424-n', 0), SenseInfo('01944617-n', 0) ],
"_rabbit_n_1_rel" : [ SenseInfo('02324045-n', 9), SenseInfo('14765324-n', 0), SenseInfo('07666521-n', 0) ],
"_proximity_n_to_rel" : [ SenseInfo('05085867-n', 1), SenseInfo('08642517-n', 0), SenseInfo('06250771-n', 0) ],
"_wicker_n_1_rel" : [ SenseInfo('15097849-n', 2), SenseInfo('04582205-n', 0) ],
"_patrol_n_of_rel" : [ SenseInfo('08216176-n', 10), SenseInfo('00824808-n', 1), SenseInfo('08329113-n', 0) ],
"_charity_n_1_rel" : [ SenseInfo('08406619-n', 2), SenseInfo('04840405-n', 1), SenseInfo('01089635-n', 1), SenseInfo('12809626-n', 0), SenseInfo('08055824-n', 0), SenseInfo('08406619-n', 2), SenseInfo('04840405-n', 1), SenseInfo('01089635-n', 1), SenseInfo('12809626-n', 0), SenseInfo('08055824-n', 0), SenseInfo('08406619-n', 2), SenseInfo('04840405-n', 1), SenseInfo('01089635-n', 1), SenseInfo('12809626-n', 0), SenseInfo('08055824-n', 0) ],
"_hobby_n_1_rel" : [ SenseInfo('00432689-n', 2), SenseInfo('03523633-n', 0), SenseInfo('01612476-n', 0) ],
"_bruise_v_cause_rel" : [ SenseInfo('01492725-v', 2), SenseInfo('01793177-v', 0), SenseInfo('00339268-v', 0), SenseInfo('00259560-v', 0) ],
"_in+excess+of_x_deg_rel" : [  ],
"_good+show_a_1_rel" : [  ],
"_dose_v_1_rel" : [ SenseInfo('00516584-v', 1), SenseInfo('00084738-v', 0), SenseInfo('00516584-v', 1), SenseInfo('00084738-v', 0) ],
"_port_n_of_rel" : [ SenseInfo('08633957-n', 5), SenseInfo('07900825-n', 1), SenseInfo('03984908-n', 1), SenseInfo('03642928-n', 1), SenseInfo('03578656-n', 0) ],
"_lingenberry_n_1_rel" : [ SenseInfo('12249542-n', 0) ],
"_burn_v_out_rel" : [ SenseInfo('00378664-v', 11), SenseInfo('02768874-v', 10), SenseInfo('00377002-v', 9), SenseInfo('02120451-v', 4), SenseInfo('02762468-v', 2), SenseInfo('01829292-v', 2), SenseInfo('00378042-v', 2), SenseInfo('02485322-v', 1), SenseInfo('02268881-v', 1), SenseInfo('02121048-v', 1), SenseInfo('00373766-v', 1), SenseInfo('00104299-v', 1), SenseInfo('01756277-v', 0), SenseInfo('01205000-v', 0), SenseInfo('00196364-v', 0), SenseInfo('00378664-v', 11), SenseInfo('02768874-v', 10), SenseInfo('00377002-v', 9), SenseInfo('02120451-v', 4), SenseInfo('02762468-v', 2), SenseInfo('01829292-v', 2), SenseInfo('00378042-v', 2), SenseInfo('02485322-v', 1), SenseInfo('02268881-v', 1), SenseInfo('02121048-v', 1), SenseInfo('00373766-v', 1), SenseInfo('00104299-v', 1), SenseInfo('01756277-v', 0), SenseInfo('01205000-v', 0), SenseInfo('00196364-v', 0) ],
"_shoot_v_down_rel" : [ SenseInfo('01137138-v', 28), SenseInfo('02484570-v', 27), SenseInfo('01134781-v', 26), SenseInfo('01002740-v', 7), SenseInfo('02096047-v', 3), SenseInfo('02061495-v', 3), SenseInfo('02055267-v', 1), SenseInfo('01597286-v', 1), SenseInfo('01003249-v', 1), SenseInfo('02768259-v', 0), SenseInfo('02123175-v', 0), SenseInfo('01585523-v', 0), SenseInfo('01519184-v', 0), SenseInfo('01437144-v', 0), SenseInfo('01195804-v', 0), SenseInfo('01084466-v', 0), SenseInfo('00985219-v', 0), SenseInfo('00647508-v', 0), SenseInfo('00357332-v', 0), SenseInfo('00086320-v', 0) ],
"_cloak_n_1_rel" : [ SenseInfo('03045698-n', 1), SenseInfo('03045337-n', 0) ],
"_mullet_n_1_rel" : [ SenseInfo('07784367-n', 0), SenseInfo('02601344-n', 0), SenseInfo('02599958-n', 0) ],
"_will_v_1_rel" : [ SenseInfo('00746366-v', 3), SenseInfo('00698398-v', 2), SenseInfo('02229055-v', 0), SenseInfo('00746366-v', 3), SenseInfo('00698398-v', 2), SenseInfo('02229055-v', 0) ],
"_adduce_v_1_rel" : [ SenseInfo('01015866-v', 0) ],
"_unbelievable_a_1_rel" : [ SenseInfo('00645493-a', 1), SenseInfo('01800169-a', 0), SenseInfo('00645493-a', 1), SenseInfo('01800169-a', 0), SenseInfo('00645493-a', 1), SenseInfo('01800169-a', 0), SenseInfo('00645493-a', 1), SenseInfo('01800169-a', 0), SenseInfo('00645493-a', 1), SenseInfo('01800169-a', 0) ],
"_interplay_n_1_rel" : [ SenseInfo('00039211-n', 2) ],
"_depression_n_1_rel" : [ SenseInfo('14404160-n', 4), SenseInfo('14489113-n', 3), SenseInfo('09366017-n', 3), SenseInfo('07537485-n', 1), SenseInfo('15294211-n', 0), SenseInfo('14520829-n', 0), SenseInfo('14389240-n', 0), SenseInfo('13896369-n', 0), SenseInfo('13836715-n', 0), SenseInfo('00112674-n', 0) ],
"_pronunciation_n_of_rel" : [ SenseInfo('07128946-n', 0), SenseInfo('07128692-n', 0) ],
"_estrangement_n_1_rel" : [ SenseInfo('14415773-n', 1), SenseInfo('07502387-n', 0) ],
"_endoscopy_n_1_rel" : [ SenseInfo('00642045-n', 0) ],
"_unification_n_of_rel" : [ SenseInfo('07373602-n', 1), SenseInfo('14418395-n', 0), SenseInfo('00381680-n', 0), SenseInfo('07373602-n', 1), SenseInfo('14418395-n', 0), SenseInfo('00381680-n', 0) ],
"_look_n_at_rel" : [ SenseInfo('04679738-n', 24), SenseInfo('00877127-n', 16), SenseInfo('04674715-n', 9), SenseInfo('14526182-n', 0), SenseInfo('04679738-n', 24), SenseInfo('00877127-n', 16), SenseInfo('04674715-n', 9), SenseInfo('14526182-n', 0) ],
"_scornful_a_of_rel" : [ SenseInfo('01995288-a', 2) ],
"_unprepared_a_1_rel" : [ SenseInfo('01845160-a', 2), SenseInfo('01845160-a', 2), SenseInfo('01845160-a', 2), SenseInfo('01845160-a', 2) ],
"_full+grown_a_1_rel" : [ SenseInfo('01488616-a', 2), SenseInfo('01488616-a', 2) ],
"_dental_n_1_rel" : [ SenseInfo('07115493-n', 0) ],
"_a_a_parens_rel" : [ SenseInfo('13658027-n', 6), SenseInfo('15089803-n', 0), SenseInfo('14829565-n', 0), SenseInfo('14706889-n', 0), SenseInfo('13637376-n', 0), SenseInfo('06831177-n', 0), SenseInfo('05400860-n', 0), SenseInfo('13658027-n', 6), SenseInfo('15089803-n', 0), SenseInfo('14829565-n', 0), SenseInfo('14706889-n', 0), SenseInfo('13637376-n', 0), SenseInfo('06831177-n', 0), SenseInfo('05400860-n', 0) ],
"_vintage_a_1_rel" : [ SenseInfo('07892418-n', 1), SenseInfo('04926217-n', 0) ],
"_cheapen_v_1_rel" : [ SenseInfo('00207728-v', 0) ],
"_watch_n_1_rel" : [ SenseInfo('04555897-n', 9), SenseInfo('15292336-n', 3), SenseInfo('00880662-n', 3), SenseInfo('15292502-n', 2), SenseInfo('10271216-n', 0), SenseInfo('01029671-n', 0) ],
"_crossword_n_1_rel" : [ SenseInfo('06785654-n', 0) ],
"_joyful_a_1_rel" : [ SenseInfo('01363613-a', 0), SenseInfo('01367211-a', 0), SenseInfo('01363613-a', 0), SenseInfo('01367211-a', 0) ],
"_cardiac_a_1_rel" : [ SenseInfo('02843717-a', 0) ],
"_stupendous_a_1_rel" : [ SenseInfo('01384730-a', 2), SenseInfo('01384730-a', 2), SenseInfo('01384730-a', 2) ],
"_rejection_n_of_rel" : [ SenseInfo('00203342-n', 5), SenseInfo('13937554-n', 1), SenseInfo('11505318-n', 0), SenseInfo('07207273-n', 0) ],
"_impatient_a_for_rel" : [ SenseInfo('01737241-a', 5), SenseInfo('00811536-a', 2) ],
"_bunt_v_1_rel" : [ SenseInfo('01408297-v', 0), SenseInfo('01235769-v', 0) ],
"_cation_n_1_rel" : [ SenseInfo('09238294-n', 0) ],
"_act_v_1_rel" : [ SenseInfo('02367363-v', 35), SenseInfo('00010435-v', 22), SenseInfo('01719302-v', 7), SenseInfo('01095899-v', 4), SenseInfo('00013615-v', 1), SenseInfo('02744977-v', 0), SenseInfo('02525447-v', 0), SenseInfo('02419073-v', 0), SenseInfo('01721556-v', 0), SenseInfo('01719921-v', 0), SenseInfo('02367363-v', 35), SenseInfo('00010435-v', 22), SenseInfo('01719302-v', 7), SenseInfo('01095899-v', 4), SenseInfo('00013615-v', 1), SenseInfo('02744977-v', 0), SenseInfo('02525447-v', 0), SenseInfo('02419073-v', 0), SenseInfo('01721556-v', 0), SenseInfo('01719921-v', 0), SenseInfo('02367363-v', 35), SenseInfo('00010435-v', 22), SenseInfo('01719302-v', 7), SenseInfo('01095899-v', 4), SenseInfo('00013615-v', 1), SenseInfo('02744977-v', 0), SenseInfo('02525447-v', 0), SenseInfo('02419073-v', 0), SenseInfo('01721556-v', 0), SenseInfo('01719921-v', 0) ],
"_scapular_n_1_rel" : [ SenseInfo('02469248-n', 1), SenseInfo('04143492-n', 0) ],
"_psychological_a_1_rel" : [ SenseInfo('01781076-a', 6), SenseInfo('02905794-a', 2) ],
"_combat_n_1_rel" : [ SenseInfo('00964343-n', 14), SenseInfo('01170962-n', 1) ],
"_no+less+than_x_deg_rel" : [  ],
"_deviant_n_1_rel" : [ SenseInfo('10419047-n', 0) ],
"_pencil_n_1_rel" : [ SenseInfo('03908204-n', 7), SenseInfo('14796748-n', 0), SenseInfo('13863020-n', 0), SenseInfo('03908456-n', 0) ],
"_crossways_p_rel" : [ SenseInfo('00272844-r', 0) ],
"_vote_v_down_rel" : [ SenseInfo('02461314-v', 30), SenseInfo('02462580-v', 10), SenseInfo('02462386-v', 1), SenseInfo('02473890-v', 0), SenseInfo('02462201-v', 0) ],
"_flint_n_1_rel" : [ SenseInfo('14871078-n', 1), SenseInfo('09281545-n', 0), SenseInfo('09100690-n', 0) ],
"_joint_a_1_rel" : [ SenseInfo('02111684-a', 4), SenseInfo('02152716-a', 1), SenseInfo('00238189-a', 0), SenseInfo('02111684-a', 4), SenseInfo('02152716-a', 1), SenseInfo('00238189-a', 0) ],
"_opponent_n_1_rel" : [ SenseInfo('10379620-n', 2), SenseInfo('09773245-n', 2) ],
"_against_p_rel" : [  ],
"_latent_a_1_rel" : [ SenseInfo('00044608-a', 6), SenseInfo('00038462-a', 1) ],
"_defy_v_1_rel" : [ SenseInfo('02706816-v', 9), SenseInfo('02707800-v', 2), SenseInfo('00868097-v', 1), SenseInfo('02706816-v', 9), SenseInfo('02707800-v', 2), SenseInfo('00868097-v', 1) ],
"_gleeful_a_1_rel" : [ SenseInfo('01367211-a', 3) ],
"_axletree_n_1_rel" : [ SenseInfo('02765028-n', 0) ],
"_wares_n_1_rel" : [ SenseInfo('04550840-n', 0), SenseInfo('03748886-n', 0), SenseInfo('04550840-n', 0), SenseInfo('03748886-n', 0) ],
"_chop_v_1_rel" : [ SenseInfo('01258091-v', 2), SenseInfo('01871471-v', 0), SenseInfo('01758410-v', 0), SenseInfo('01415454-v', 0), SenseInfo('01257173-v', 0), SenseInfo('01124535-v', 0) ],
"_hip_n_1_rel" : [ SenseInfo('05556325-n', 5), SenseInfo('05596651-n', 1), SenseInfo('05596004-n', 1), SenseInfo('13890679-n', 0), SenseInfo('12620546-n', 0) ],
"_go_v_away_rel" : [ SenseInfo('01835496-v', 343), SenseInfo('02372605-v', 95), SenseInfo('01848718-v', 49), SenseInfo('00149583-v', 29), SenseInfo('02653862-v', 14), SenseInfo('02721284-v', 10), SenseInfo('02685951-v', 10), SenseInfo('00341560-v', 10), SenseInfo('00359916-v', 9), SenseInfo('02618001-v', 7), SenseInfo('02176268-v', 3), SenseInfo('01525666-v', 3), SenseInfo('01192773-v', 3), SenseInfo('00539110-v', 3), SenseInfo('02618149-v', 2), SenseInfo('02617798-v', 2), SenseInfo('00358431-v', 2), SenseInfo('02737876-v', 1), SenseInfo('02729819-v', 1), SenseInfo('01864230-v', 1), SenseInfo('01076615-v', 1), SenseInfo('02700772-v', 0), SenseInfo('02700666-v', 0), SenseInfo('02700455-v', 0), SenseInfo('02686471-v', 0), SenseInfo('02659763-v', 0), SenseInfo('01318849-v', 0), SenseInfo('01192992-v', 0), SenseInfo('00676267-v', 0), SenseInfo('00434374-v', 0) ],
"_johnny-come-lately_n_1_rel" : [  ],
"_millhouse_n_1_rel" : [  ],
"_meritocracy_n_1_rel" : [ SenseInfo('07973088-n', 0), SenseInfo('06218824-n', 0) ],
"_birthcontrol_n_1_rel" : [  ],
"_bone_v_1_rel" : [ SenseInfo('00605783-v', 0), SenseInfo('00197423-v', 0) ],
"_elemental_a_1_rel" : [ SenseInfo('02719395-a', 1), SenseInfo('02719503-a', 0), SenseInfo('01856238-a', 0) ],
"_high+school_n_1_rel" : [ SenseInfo('08409617-n', 1), SenseInfo('08409617-n', 1), SenseInfo('08409617-n', 1) ],
"_general_n_1_rel" : [ SenseInfo('10123844-n', 40), SenseInfo('10125561-n', 0), SenseInfo('05818388-n', 0), SenseInfo('10123844-n', 40), SenseInfo('10125561-n', 0), SenseInfo('05818388-n', 0) ],
"_access_n_to_rel" : [ SenseInfo('05176188-n', 2), SenseInfo('05175467-n', 2), SenseInfo('02671062-n', 2), SenseInfo('06354204-n', 0), SenseInfo('02671224-n', 0), SenseInfo('00281132-n', 0) ],
"_experiment_v_1_rel" : [ SenseInfo('02532595-v', 17), SenseInfo('02532886-v', 0) ],
"_voice_v_1_rel" : [ SenseInfo('00933403-v', 4), SenseInfo('00952182-v', 0) ],
"_missionary_n_1_rel" : [ SenseInfo('10322957-n', 3), SenseInfo('10323182-n', 0) ],
"_pop_v_up_rel" : [ SenseInfo('02081946-v', 3), SenseInfo('01404913-v', 3), SenseInfo('02185988-v', 1), SenseInfo('01134071-v', 1), SenseInfo('02186192-v', 0), SenseInfo('02157519-v', 0), SenseInfo('01499510-v', 0), SenseInfo('01474980-v', 0), SenseInfo('01401005-v', 0), SenseInfo('01202374-v', 0), SenseInfo('01199487-v', 0), SenseInfo('00309792-v', 0), SenseInfo('00309582-v', 0), SenseInfo('02081946-v', 3), SenseInfo('01404913-v', 3), SenseInfo('02185988-v', 1), SenseInfo('01134071-v', 1), SenseInfo('02186192-v', 0), SenseInfo('02157519-v', 0), SenseInfo('01499510-v', 0), SenseInfo('01474980-v', 0), SenseInfo('01401005-v', 0), SenseInfo('01202374-v', 0), SenseInfo('01199487-v', 0), SenseInfo('00309792-v', 0), SenseInfo('00309582-v', 0) ],
"_houseowner_n_1_rel" : [  ],
"_synthroid_n_1_rel" : [  ],
"_thaw_v_cause_rel" : [ SenseInfo('00376106-v', 5) ],
"_swamp_v_1_rel" : [ SenseInfo('02771564-v', 1), SenseInfo('01524523-v', 1) ],
"_curd_n_1_rel" : [ SenseInfo('07850083-n', 0), SenseInfo('07849912-n', 0) ],
"_explosive_n_1_rel" : [ SenseInfo('03304730-n', 0), SenseInfo('03304730-n', 0) ],
"_rank_v_1_rel" : [ SenseInfo('00660102-v', 2), SenseInfo('00658052-v', 1), SenseInfo('02673844-v', 0), SenseInfo('00660102-v', 2), SenseInfo('00658052-v', 1), SenseInfo('02673844-v', 0) ],
"_cooler_n_1_rel" : [ SenseInfo('03102654-n', 1), SenseInfo('07914006-n', 0), SenseInfo('03102771-n', 0) ],
"_by+way+of_p_rel" : [  ],
"_miss_n_1_rel" : [ SenseInfo('10129825-n', 3), SenseInfo('07319774-n', 1), SenseInfo('06341249-n', 0) ],
"_outskirts_n_1_rel" : [ SenseInfo('08690792-n', 1), SenseInfo('08690792-n', 1) ],
"_production_n_of_rel" : [ SenseInfo('00912960-n', 36), SenseInfo('07006951-n', 12), SenseInfo('04007894-n', 6), SenseInfo('00522736-n', 2), SenseInfo('13758745-n', 0), SenseInfo('07213989-n', 0), SenseInfo('00913705-n', 0), SenseInfo('00913585-n', 0) ],
"_antacid_n_1_rel" : [ SenseInfo('14778019-n', 0) ],
"_elevate_v_1_rel" : [ SenseInfo('02397637-v', 3), SenseInfo('01974062-v', 2), SenseInfo('00544549-v', 2) ],
"_labor_v_1_rel" : [ SenseInfo('02406916-v', 5), SenseInfo('02419773-v', 1), SenseInfo('00057506-v', 0), SenseInfo('02406916-v', 5), SenseInfo('02419773-v', 1), SenseInfo('00057506-v', 0), SenseInfo('02406916-v', 5), SenseInfo('02419773-v', 1), SenseInfo('00057506-v', 0), SenseInfo('02406916-v', 5), SenseInfo('02419773-v', 1), SenseInfo('00057506-v', 0) ],
"_sketch_n_1_rel" : [ SenseInfo('04227144-n', 15), SenseInfo('07203016-n', 6), SenseInfo('06469694-n', 2), SenseInfo('06780678-n', 0) ],
"_satyr_n_1_rel" : [ SenseInfo('10552980-n', 0), SenseInfo('09548111-n', 0) ],
"_focal_a_1_rel" : [ SenseInfo('00330904-a', 3), SenseInfo('02881438-a', 0) ],
"_wavelike_a_1_rel" : [ SenseInfo('00911762-a', 0) ],
"_own_a_1_rel" : [ SenseInfo('01768724-a', 259) ],
"_clear_v_off_rel" : [ SenseInfo('00181664-v', 16), SenseInfo('00195617-v', 5), SenseInfo('02771169-v', 2), SenseInfo('00803325-v', 2), SenseInfo('00195342-v', 2), SenseInfo('02523351-v', 1), SenseInfo('02289134-v', 1), SenseInfo('02156844-v', 1), SenseInfo('02081178-v', 1), SenseInfo('00621058-v', 1), SenseInfo('02422409-v', 0), SenseInfo('02350440-v', 0), SenseInfo('02291548-v', 0), SenseInfo('02291258-v', 0), SenseInfo('02289295-v', 0), SenseInfo('02208409-v', 0), SenseInfo('02053490-v', 0), SenseInfo('00904046-v', 0), SenseInfo('00761454-v', 0), SenseInfo('00549217-v', 0), SenseInfo('00450863-v', 0), SenseInfo('00450691-v', 0), SenseInfo('00450565-v', 0), SenseInfo('00178235-v', 0), SenseInfo('00181664-v', 16), SenseInfo('00195617-v', 5), SenseInfo('02771169-v', 2), SenseInfo('00803325-v', 2), SenseInfo('00195342-v', 2), SenseInfo('02523351-v', 1), SenseInfo('02289134-v', 1), SenseInfo('02156844-v', 1), SenseInfo('02081178-v', 1), SenseInfo('00621058-v', 1), SenseInfo('02422409-v', 0), SenseInfo('02350440-v', 0), SenseInfo('02291548-v', 0), SenseInfo('02291258-v', 0), SenseInfo('02289295-v', 0), SenseInfo('02208409-v', 0), SenseInfo('02053490-v', 0), SenseInfo('00904046-v', 0), SenseInfo('00761454-v', 0), SenseInfo('00549217-v', 0), SenseInfo('00450863-v', 0), SenseInfo('00450691-v', 0), SenseInfo('00450565-v', 0), SenseInfo('00178235-v', 0) ],
"_aisle_n_of_rel" : [ SenseInfo('02694182-n', 2), SenseInfo('02693860-n', 2), SenseInfo('02694045-n', 0) ],
"_aggregate_v_1_rel" : [ SenseInfo('02627555-v', 0), SenseInfo('01385170-v', 0) ],
"_recall_v_to_rel" : [ SenseInfo('00607780-v', 47), SenseInfo('00959524-v', 4), SenseInfo('02675458-v', 1), SenseInfo('00791506-v', 1), SenseInfo('00722848-v', 1), SenseInfo('02480216-v', 0), SenseInfo('02312478-v', 0) ],
"_beating_n_1_rel" : [ SenseInfo('01176219-n', 1), SenseInfo('01160729-n', 0) ],
"_bon+viveur_n_1_rel" : [  ],
"_contemplative_a_1_rel" : [ SenseInfo('02419434-a', 1), SenseInfo('02419434-a', 1) ],
"_total_a_1_rel" : [ SenseInfo('00515380-a', 31), SenseInfo('00522885-a', 2), SenseInfo('00515380-a', 31), SenseInfo('00522885-a', 2) ],
"_psyched_a_1_rel" : [  ],
"_barrage_v_1_rel" : [ SenseInfo('00863579-v', 0) ],
"_native_n_of_rel" : [ SenseInfo('09620794-n', 3), SenseInfo('09621232-n', 0), SenseInfo('00019046-n', 0) ],
"_liken_v_to_rel" : [ SenseInfo('00653620-v', 0) ],
"_brush_v_off_rel" : [ SenseInfo('01243809-v', 11), SenseInfo('01240720-v', 10), SenseInfo('01243982-v', 5), SenseInfo('01870043-v', 2), SenseInfo('00555780-v', 1), SenseInfo('01373718-v', 0) ],
"_occupier_n_of_rel" : [ SenseInfo('10523519-n', 0), SenseInfo('10369955-n', 0) ],
"_have_v_back_rel" : [ SenseInfo('02203362-v', 1202), SenseInfo('02630189-v', 377), SenseInfo('02108026-v', 220), SenseInfo('02204692-v', 143), SenseInfo('00120796-v', 64), SenseInfo('01156834-v', 42), SenseInfo('02378453-v', 31), SenseInfo('01733477-v', 30), SenseInfo('02205098-v', 28), SenseInfo('02740745-v', 25), SenseInfo('00121046-v', 25), SenseInfo('00065370-v', 11), SenseInfo('00770437-v', 8), SenseInfo('02236124-v', 7), SenseInfo('02210119-v', 7), SenseInfo('00065639-v', 5), SenseInfo('02355596-v', 3), SenseInfo('00056930-v', 3), SenseInfo('01427127-v', 2) ],
"_again_a_1_rel" : [  ],
"_substantially_x_deg_rel" : [ SenseInfo('00014285-r', 9), SenseInfo('00379432-r', 1) ],
"_bad_a_for_rel" : [ SenseInfo('01125429-a', 51), SenseInfo('01510444-a', 3), SenseInfo('00478311-a', 3), SenseInfo('01069283-a', 1), SenseInfo('01150475-a', 0), SenseInfo('02500050-a', 0), SenseInfo('02345713-a', 0), SenseInfo('02298642-a', 0), SenseInfo('02274537-a', 0), SenseInfo('01174222-a', 0), SenseInfo('01160775-a', 0), SenseInfo('01131803-a', 0), SenseInfo('01117226-a', 0), SenseInfo('01092572-a', 0), SenseInfo('01125429-a', 51), SenseInfo('01510444-a', 3), SenseInfo('00478311-a', 3), SenseInfo('01069283-a', 1), SenseInfo('01150475-a', 0), SenseInfo('02500050-a', 0), SenseInfo('02345713-a', 0), SenseInfo('02298642-a', 0), SenseInfo('02274537-a', 0), SenseInfo('01174222-a', 0), SenseInfo('01160775-a', 0), SenseInfo('01131803-a', 0), SenseInfo('01117226-a', 0), SenseInfo('01092572-a', 0) ],
"_touch_v_down_rel" : [ SenseInfo('01206218-v', 33), SenseInfo('02127358-v', 5), SenseInfo('01770802-v', 4), SenseInfo('02676054-v', 3), SenseInfo('01205696-v', 3), SenseInfo('00137313-v', 3), SenseInfo('02599325-v', 2), SenseInfo('01206849-v', 2), SenseInfo('02685665-v', 1), SenseInfo('02672187-v', 1), SenseInfo('01207527-v', 1), SenseInfo('01026728-v', 1), SenseInfo('00590642-v', 1), SenseInfo('01172701-v', 0), SenseInfo('00286928-v', 0) ],
"_powerful_a_1_rel" : [ SenseInfo('01825671-a', 18), SenseInfo('02323072-a', 2), SenseInfo('01830599-a', 2), SenseInfo('02321809-a', 1), SenseInfo('01261363-a', 0), SenseInfo('01825671-a', 18), SenseInfo('02323072-a', 2), SenseInfo('01830599-a', 2), SenseInfo('02321809-a', 1), SenseInfo('01261363-a', 0) ],
"_hold_v_onto_rel" : [ SenseInfo('02681795-v', 79), SenseInfo('01216670-v', 65), SenseInfo('01733477-v', 62), SenseInfo('02203362-v', 26), SenseInfo('00693780-v', 20), SenseInfo('01773130-v', 17), SenseInfo('01301410-v', 17), SenseInfo('02283324-v', 14), SenseInfo('02302220-v', 9), SenseInfo('01217043-v', 9), SenseInfo('02700867-v', 7), SenseInfo('02732798-v', 3), SenseInfo('02683489-v', 3), SenseInfo('01601234-v', 3), SenseInfo('02648502-v', 2), SenseInfo('00683771-v', 2), SenseInfo('02746275-v', 1), SenseInfo('02701210-v', 1), SenseInfo('02498320-v', 1), SenseInfo('01129876-v', 1), SenseInfo('00885217-v', 1), SenseInfo('00736586-v', 1), SenseInfo('00607000-v', 1), SenseInfo('02706816-v', 0), SenseInfo('02676789-v', 0), SenseInfo('02643574-v', 0), SenseInfo('02510337-v', 0), SenseInfo('02450989-v', 0), SenseInfo('02441897-v', 0), SenseInfo('01859586-v', 0), SenseInfo('01334744-v', 0), SenseInfo('01205153-v', 0), SenseInfo('01151753-v', 0), SenseInfo('00822367-v', 0), SenseInfo('00805376-v', 0), SenseInfo('00004492-v', 0), SenseInfo('02681795-v', 79), SenseInfo('01216670-v', 65), SenseInfo('01733477-v', 62), SenseInfo('02203362-v', 26), SenseInfo('00693780-v', 20), SenseInfo('01773130-v', 17), SenseInfo('01301410-v', 17), SenseInfo('02283324-v', 14), SenseInfo('02302220-v', 9), SenseInfo('01217043-v', 9), SenseInfo('02700867-v', 7), SenseInfo('02732798-v', 3), SenseInfo('02683489-v', 3), SenseInfo('01601234-v', 3), SenseInfo('02648502-v', 2), SenseInfo('00683771-v', 2), SenseInfo('02746275-v', 1), SenseInfo('02701210-v', 1), SenseInfo('02498320-v', 1), SenseInfo('01129876-v', 1), SenseInfo('00885217-v', 1), SenseInfo('00736586-v', 1), SenseInfo('00607000-v', 1), SenseInfo('02706816-v', 0), SenseInfo('02676789-v', 0), SenseInfo('02643574-v', 0), SenseInfo('02510337-v', 0), SenseInfo('02450989-v', 0), SenseInfo('02441897-v', 0), SenseInfo('01859586-v', 0), SenseInfo('01334744-v', 0), SenseInfo('01205153-v', 0), SenseInfo('01151753-v', 0), SenseInfo('00822367-v', 0), SenseInfo('00805376-v', 0), SenseInfo('00004492-v', 0) ],
"_bump_v_1_rel" : [ SenseInfo('01239619-v', 2), SenseInfo('02248465-v', 1), SenseInfo('01895383-v', 1), SenseInfo('02399331-v', 0), SenseInfo('01527508-v', 0), SenseInfo('01239619-v', 2), SenseInfo('02248465-v', 1), SenseInfo('01895383-v', 1), SenseInfo('02399331-v', 0), SenseInfo('01527508-v', 0) ],
"_world‘s+fair_n_1_rel" : [  ],
"_genetics_n_1_rel" : [ SenseInfo('06075527-n', 0) ],
"_choral_n_1_rel" : [ SenseInfo('07036328-n', 0) ],
"_casual_n_1_rel" : [ SenseInfo('00545746-a', 3), SenseInfo('01798484-a', 2), SenseInfo('01044557-a', 2), SenseInfo('01798162-a', 1), SenseInfo('00312234-a', 1), SenseInfo('01961205-a', 0), SenseInfo('01190484-a', 0), SenseInfo('01044730-a', 0), SenseInfo('00749749-a', 0) ],
"_earmark_n_1_rel" : [ SenseInfo('06795438-n', 0), SenseInfo('04732543-n', 0) ],
"_get-well_a_1_rel" : [  ],
"_folk_a_1_rel" : [ SenseInfo('07947255-n', 14), SenseInfo('08372411-n', 1), SenseInfo('07970721-n', 1), SenseInfo('07060167-n', 0) ],
"_wi-fi_n_1_rel" : [ SenseInfo('04595028-n', 0), SenseInfo('04595028-n', 0) ],
"_read-only_a_1_rel" : [  ],
"_salmon_n_1_rel" : [ SenseInfo('02534734-n', 1), SenseInfo('09420423-n', 0), SenseInfo('07795751-n', 0), SenseInfo('04965371-n', 0) ],
"_outer_a_1_rel" : [ SenseInfo('00949548-a', 6), SenseInfo('00951163-a', 1), SenseInfo('00948384-a', 0), SenseInfo('00949548-a', 6), SenseInfo('00951163-a', 1), SenseInfo('00948384-a', 0) ],
"_glorify_v_1_rel" : [ SenseInfo('00860620-v', 4), SenseInfo('00489299-v', 1), SenseInfo('00580512-v', 0), SenseInfo('00489496-v', 0) ],
"_swap_n_of_rel" : [ SenseInfo('01109687-n', 0), SenseInfo('01109687-n', 0), SenseInfo('01109687-n', 0) ],
"_dole_v_out_rel" : [  ],
"_death_n_1_rel" : [ SenseInfo('07355491-n', 45), SenseInfo('11444117-n', 39), SenseInfo('13962498-n', 24), SenseInfo('15143477-n', 14), SenseInfo('15143276-n', 4), SenseInfo('09488259-n', 3), SenseInfo('14562960-n', 1), SenseInfo('00219575-n', 0) ],
"_croatoan_n_1_rel" : [  ],
"_distract_v_from_rel" : [ SenseInfo('01791756-v', 3), SenseInfo('01764171-v', 0), SenseInfo('01791756-v', 3), SenseInfo('01764171-v', 0), SenseInfo('01791756-v', 3), SenseInfo('01764171-v', 0), SenseInfo('01791756-v', 3), SenseInfo('01764171-v', 0), SenseInfo('01791756-v', 3), SenseInfo('01764171-v', 0), SenseInfo('01791756-v', 3), SenseInfo('01764171-v', 0) ],
"_busy_a_1_rel" : [ SenseInfo('00292937-a', 30), SenseInfo('01795203-a', 1), SenseInfo('01352561-a', 1), SenseInfo('00035978-a', 1), SenseInfo('01623360-a', 0), SenseInfo('00292937-a', 30), SenseInfo('01795203-a', 1), SenseInfo('01352561-a', 1), SenseInfo('00035978-a', 1), SenseInfo('01623360-a', 0), SenseInfo('00292937-a', 30), SenseInfo('01795203-a', 1), SenseInfo('01352561-a', 1), SenseInfo('00035978-a', 1), SenseInfo('01623360-a', 0), SenseInfo('00292937-a', 30), SenseInfo('01795203-a', 1), SenseInfo('01352561-a', 1), SenseInfo('00035978-a', 1), SenseInfo('01623360-a', 0), SenseInfo('00292937-a', 30), SenseInfo('01795203-a', 1), SenseInfo('01352561-a', 1), SenseInfo('00035978-a', 1), SenseInfo('01623360-a', 0) ],
"_bottle_v_up_rel" : [ SenseInfo('02283080-v', 0), SenseInfo('01502279-v', 0) ],
"_convention+hall_n_1_rel" : [  ],
"_homestead_v_1_rel" : [ SenseInfo('00415231-v', 0) ],
"_byway_n_1_rel" : [ SenseInfo('02930645-n', 0) ],
"_wait_v_i_rel" : [ SenseInfo('02637938-v', 100), SenseInfo('02641463-v', 49), SenseInfo('00720063-v', 33), SenseInfo('02413290-v', 2) ],
"_boil_v_down-to_rel" : [ SenseInfo('00375021-v', 4), SenseInfo('00328128-v', 4), SenseInfo('00374668-v', 3), SenseInfo('01885430-v', 0), SenseInfo('01767612-v', 0) ],
"_smooth_a_1_rel" : [ SenseInfo('02236842-a', 11), SenseInfo('00758800-a', 3), SenseInfo('02244619-a', 1), SenseInfo('01139832-a', 1), SenseInfo('02294263-a', 0), SenseInfo('02243411-a', 0), SenseInfo('00750926-a', 0), SenseInfo('00302951-a', 0), SenseInfo('02236842-a', 11), SenseInfo('00758800-a', 3), SenseInfo('02244619-a', 1), SenseInfo('01139832-a', 1), SenseInfo('02294263-a', 0), SenseInfo('02243411-a', 0), SenseInfo('00750926-a', 0), SenseInfo('00302951-a', 0), SenseInfo('02236842-a', 11), SenseInfo('00758800-a', 3), SenseInfo('02244619-a', 1), SenseInfo('01139832-a', 1), SenseInfo('02294263-a', 0), SenseInfo('02243411-a', 0), SenseInfo('00750926-a', 0), SenseInfo('00302951-a', 0), SenseInfo('02236842-a', 11), SenseInfo('00758800-a', 3), SenseInfo('02244619-a', 1), SenseInfo('01139832-a', 1), SenseInfo('02294263-a', 0), SenseInfo('02243411-a', 0), SenseInfo('00750926-a', 0), SenseInfo('00302951-a', 0) ],
"_northeastward_a_2_rel" : [ SenseInfo('01601901-a', 0), SenseInfo('01601901-a', 0) ],
"_ms_n_1_rel" : [ SenseInfo('14094068-n', 0), SenseInfo('09103943-n', 0), SenseInfo('06702139-n', 0), SenseInfo('06406979-n', 0), SenseInfo('06341525-n', 0), SenseInfo('14094068-n', 0), SenseInfo('09103943-n', 0), SenseInfo('06702139-n', 0), SenseInfo('06406979-n', 0), SenseInfo('06341525-n', 0), SenseInfo('14094068-n', 0), SenseInfo('09103943-n', 0), SenseInfo('06702139-n', 0), SenseInfo('06406979-n', 0), SenseInfo('06341525-n', 0), SenseInfo('14094068-n', 0), SenseInfo('09103943-n', 0), SenseInfo('06702139-n', 0), SenseInfo('06406979-n', 0), SenseInfo('06341525-n', 0), SenseInfo('14094068-n', 0), SenseInfo('09103943-n', 0), SenseInfo('06702139-n', 0), SenseInfo('06406979-n', 0), SenseInfo('06341525-n', 0), SenseInfo('14094068-n', 0), SenseInfo('09103943-n', 0), SenseInfo('06702139-n', 0), SenseInfo('06406979-n', 0), SenseInfo('06341525-n', 0) ],
"_understand_v_by_rel" : [ SenseInfo('00588888-v', 110), SenseInfo('00591115-v', 29), SenseInfo('00593852-v', 9), SenseInfo('00593522-v', 4), SenseInfo('00594058-v', 1), SenseInfo('00588888-v', 110), SenseInfo('00591115-v', 29), SenseInfo('00593852-v', 9), SenseInfo('00593522-v', 4), SenseInfo('00594058-v', 1), SenseInfo('00588888-v', 110), SenseInfo('00591115-v', 29), SenseInfo('00593852-v', 9), SenseInfo('00593522-v', 4), SenseInfo('00594058-v', 1), SenseInfo('00588888-v', 110), SenseInfo('00591115-v', 29), SenseInfo('00593852-v', 9), SenseInfo('00593522-v', 4), SenseInfo('00594058-v', 1), SenseInfo('00588888-v', 110), SenseInfo('00591115-v', 29), SenseInfo('00593852-v', 9), SenseInfo('00593522-v', 4), SenseInfo('00594058-v', 1) ],
"_facing_p_rel" : [ SenseInfo('03315805-n', 2), SenseInfo('03315990-n', 0), SenseInfo('03315644-n', 0), SenseInfo('00827379-n', 0), SenseInfo('03315805-n', 2), SenseInfo('03315990-n', 0), SenseInfo('03315644-n', 0), SenseInfo('00827379-n', 0) ],
"_unnecessary_a_for_rel" : [ SenseInfo('01581115-a', 5), SenseInfo('01581115-a', 5), SenseInfo('01581115-a', 5), SenseInfo('01581115-a', 5), SenseInfo('01581115-a', 5), SenseInfo('01581115-a', 5), SenseInfo('01581115-a', 5), SenseInfo('01581115-a', 5), SenseInfo('01581115-a', 5) ],
"_overseas_a_1_rel" : [ SenseInfo('01037763-a', 1), SenseInfo('01381473-a', 0) ],
"_weatherbreaker_n_1_rel" : [  ],
"_put_v_forth_rel" : [ SenseInfo('01494310-v', 138), SenseInfo('01493741-v', 98), SenseInfo('00981276-v', 28), SenseInfo('01160370-v', 6), SenseInfo('02271137-v', 3), SenseInfo('00673448-v', 2), SenseInfo('02111499-v', 0), SenseInfo('01706375-v', 0), SenseInfo('00735571-v', 0) ],
"_cannibal_n_1_rel" : [ SenseInfo('09891079-n', 0) ],
"_laxative_n_1_rel" : [ SenseInfo('03650084-n', 0) ],
"_sunbathe_v_1_rel" : [ SenseInfo('00104147-v', 0) ],
"_species_n_of-n_rel" : [ SenseInfo('08110373-n', 27), SenseInfo('05844881-n', 5), SenseInfo('08110373-n', 27), SenseInfo('05844881-n', 5) ],
"_plaid_n_1_rel" : [ SenseInfo('04395106-n', 0) ],
"_uplands_n_1_rel" : [ SenseInfo('09302616-n', 0) ],
"_remission_n_1_rel" : [ SenseInfo('07419960-n', 1), SenseInfo('13299453-n', 0), SenseInfo('00122106-n', 0), SenseInfo('00094240-n', 0) ],
"_fawn_v_over_rel" : [ SenseInfo('02063771-v', 0), SenseInfo('00880978-v', 0), SenseInfo('00058794-v', 0) ],
"_girder_n_1_rel" : [ SenseInfo('03437941-n', 0) ],
"_brew_n_1_rel" : [ SenseInfo('07886572-n', 0) ],
"_outweigh_v_1_rel" : [ SenseInfo('01107544-v', 3), SenseInfo('02645597-v', 2) ],
"_pastor_n_1_rel" : [ SenseInfo('09983572-n', 9), SenseInfo('01577265-n', 0) ],
"_then_a_former_rel" : [ SenseInfo('01731108-a', 1) ],
"_protracted_a_1_rel" : [ SenseInfo('01439155-a', 0) ],
"_commune_v_1_rel" : [ SenseInfo('00760187-v', 2), SenseInfo('00760402-v', 0) ],
"_selector_n_1_rel" : [ SenseInfo('10431625-n', 0), SenseInfo('04169437-n', 0) ],
"_introduction_n_to_rel" : [ SenseInfo('00238022-n', 3), SenseInfo('06396930-n', 2), SenseInfo('07217349-n', 1), SenseInfo('06414849-n', 1), SenseInfo('07162975-n', 0), SenseInfo('00320852-n', 0), SenseInfo('00240184-n', 0) ],
"_inspector_n_1_rel" : [ SenseInfo('10208847-n', 4), SenseInfo('10067968-n', 0) ],
"_unsatisfied_a_1_rel" : [ SenseInfo('02078788-a', 0), SenseInfo('00590271-a', 0), SenseInfo('02078788-a', 0), SenseInfo('00590271-a', 0) ],
"_first+and+foremost_a_1_rel" : [  ],
"_ooze_v_1_rel" : [ SenseInfo('02071974-v', 0), SenseInfo('00067999-v', 0) ],
"_notably_x_deg_rel" : [ SenseInfo('00139266-r', 5) ],
"_truth_n_1_rel" : [ SenseInfo('05819453-n', 17), SenseInfo('13956488-n', 7), SenseInfo('06724066-n', 6), SenseInfo('04802907-n', 3), SenseInfo('11350705-n', 0), SenseInfo('05819453-n', 17), SenseInfo('13956488-n', 7), SenseInfo('06724066-n', 6), SenseInfo('04802907-n', 3), SenseInfo('11350705-n', 0) ],
"_termination_n_of_rel" : [ SenseInfo('15268682-n', 3), SenseInfo('08566554-n', 0), SenseInfo('07292694-n', 0), SenseInfo('06308765-n', 0), SenseInfo('00209943-n', 0) ],
"_odd_n_meas_rel" : [ SenseInfo('00913454-a', 7), SenseInfo('00490845-a', 6), SenseInfo('00916383-a', 3), SenseInfo('00968010-a', 1), SenseInfo('01487496-a', 0), SenseInfo('00926505-a', 0) ],
"_hard+hit_a_1_rel" : [  ],
"_cry_v_out-i_rel" : [ SenseInfo('00913065-v', 17), SenseInfo('00066191-v', 12), SenseInfo('00912048-v', 11), SenseInfo('00974786-v', 2), SenseInfo('01188987-v', 0), SenseInfo('00985464-v', 0), SenseInfo('00066685-v', 0) ],
"_brackish_a_1_rel" : [ SenseInfo('01716845-a', 0), SenseInfo('01074062-a', 0) ],
"_barefoot_a_1_rel" : [ SenseInfo('02156686-a', 2) ],
"_colloquial_a_1_rel" : [ SenseInfo('01045963-a', 1) ],
"_drive-in_n_1_rel" : [ SenseInfo('03243501-n', 0), SenseInfo('03243501-n', 0) ],
"_compromise_v_1_rel" : [ SenseInfo('01035803-v', 3), SenseInfo('01035380-v', 2), SenseInfo('01036592-v', 0), SenseInfo('01035803-v', 3), SenseInfo('01035380-v', 2), SenseInfo('01036592-v', 0) ],
"_sunlight_n_1_rel" : [ SenseInfo('11485367-n', 8) ],
"_turn-of-the-century_a_1_rel" : [  ],
"_dingy_n_1_rel" : [ SenseInfo('00420650-a', 4), SenseInfo('01909077-a', 0), SenseInfo('00364881-a', 0) ],
"_comply_v_with_rel" : [ SenseInfo('02542280-v', 9), SenseInfo('02542280-v', 9) ],
"_deal_v_with_rel" : [ SenseInfo('01033527-v', 34), SenseInfo('00734054-v', 15), SenseInfo('02370987-v', 14), SenseInfo('02587532-v', 9), SenseInfo('02294436-v', 5), SenseInfo('02244956-v', 4), SenseInfo('02436349-v', 3), SenseInfo('02377764-v', 3), SenseInfo('02246456-v', 2), SenseInfo('02445509-v', 0), SenseInfo('02294179-v', 0), SenseInfo('02246686-v', 0), SenseInfo('02245993-v', 0) ],
"_rout_v_1_rel" : [ SenseInfo('01108951-v', 1), SenseInfo('01282413-v', 0), SenseInfo('01281782-v', 0), SenseInfo('01104248-v', 0) ],
"_hand_n_1_rel" : [ SenseInfo('05564590-n', 215), SenseInfo('10176679-n', 5), SenseInfo('06403393-n', 4), SenseInfo('05637965-n', 3), SenseInfo('08650157-n', 2), SenseInfo('07956887-n', 1), SenseInfo('05852973-n', 1), SenseInfo('03482523-n', 1), SenseInfo('13654093-n', 0), SenseInfo('10158506-n', 0), SenseInfo('09875353-n', 0), SenseInfo('06692238-n', 0), SenseInfo('02440250-n', 0), SenseInfo('01208460-n', 0), SenseInfo('05564590-n', 215), SenseInfo('10176679-n', 5), SenseInfo('06403393-n', 4), SenseInfo('05637965-n', 3), SenseInfo('08650157-n', 2), SenseInfo('07956887-n', 1), SenseInfo('05852973-n', 1), SenseInfo('03482523-n', 1), SenseInfo('13654093-n', 0), SenseInfo('10158506-n', 0), SenseInfo('09875353-n', 0), SenseInfo('06692238-n', 0), SenseInfo('02440250-n', 0), SenseInfo('01208460-n', 0) ],
"_skylight_n_1_rel" : [ SenseInfo('04232800-n', 3) ],
"_rower_n_1_rel" : [ SenseInfo('10368920-n', 0) ],
"_unlimited_a_1_rel" : [ SenseInfo('01415605-a', 3), SenseInfo('01914407-a', 0), SenseInfo('01008289-a', 0), SenseInfo('01415605-a', 3), SenseInfo('01914407-a', 0), SenseInfo('01008289-a', 0) ],
"_thermostat_n_1_rel" : [ SenseInfo('04422875-n', 1) ],
"_lagoon_n_1_rel" : [ SenseInfo('09328746-n', 12) ],
"_layer_n_of_rel" : [ SenseInfo('03650173-n', 8), SenseInfo('08591680-n', 1), SenseInfo('06246896-n', 0), SenseInfo('01793159-n', 0), SenseInfo('01463259-n', 0) ],
"_saracen_n_1_rel" : [ SenseInfo('10552019-n', 1), SenseInfo('10552203-n', 0), SenseInfo('10551898-n', 0) ],
"_dig_v_up_rel" : [ SenseInfo('01309701-v', 9), SenseInfo('01311103-v', 5), SenseInfo('02419773-v', 0), SenseInfo('02143756-v', 0), SenseInfo('01899557-v', 0), SenseInfo('01310660-v', 0), SenseInfo('01229976-v', 0), SenseInfo('00588221-v', 0) ],
"_armed_a_1_rel" : [ SenseInfo('00142407-a', 10), SenseInfo('00146210-a', 0), SenseInfo('00144877-a', 0) ],
"_autograph_v_1_rel" : [ SenseInfo('00997133-v', 0) ],
"_abbatial_a_1_rel" : [ SenseInfo('02598768-a', 0) ],
"_rubber_n_1_rel" : [ SenseInfo('15006258-n', 4), SenseInfo('15006789-n', 0), SenseInfo('04116512-n', 0), SenseInfo('03088164-n', 0), SenseInfo('02735538-n', 0) ],
"_tarn_n_1_rel" : [ SenseInfo('09454642-n', 0), SenseInfo('09454642-n', 0) ],
"_largely_x_deg_rel" : [ SenseInfo('00006105-r', 24), SenseInfo('00065359-r', 0) ],
"_cephalon_n_1_rel" : [  ],
"_keep_v_out_rel" : [ SenseInfo('02681795-v', 206), SenseInfo('02684924-v', 39), SenseInfo('02202384-v', 32), SenseInfo('02450505-v', 22), SenseInfo('02578872-v', 10), SenseInfo('00732552-v', 9), SenseInfo('02202928-v', 8), SenseInfo('01065877-v', 4), SenseInfo('02651853-v', 3), SenseInfo('02410175-v', 3), SenseInfo('01184625-v', 3), SenseInfo('02734800-v', 2), SenseInfo('02578510-v', 2), SenseInfo('02422663-v', 2), SenseInfo('02733122-v', 1), SenseInfo('02652016-v', 0), SenseInfo('02283716-v', 0), SenseInfo('02204094-v', 0), SenseInfo('02203844-v', 0), SenseInfo('02203168-v', 0), SenseInfo('01302019-v', 0), SenseInfo('00212414-v', 0) ],
"_nautical_a_1_rel" : [ SenseInfo('02889746-a', 1) ],
"_dampen_v_1_rel" : [ SenseInfo('00390842-v', 3), SenseInfo('00217956-v', 2), SenseInfo('02191311-v', 0), SenseInfo('00391553-v', 0), SenseInfo('00390560-v', 0), SenseInfo('00390459-v', 0), SenseInfo('00390215-v', 0) ],
"_quill_n_1_rel" : [ SenseInfo('04033901-n', 1), SenseInfo('01900837-n', 1), SenseInfo('02468864-n', 0), SenseInfo('02468617-n', 0) ],
"_pronominal_n_1_rel" : [ SenseInfo('06317351-n', 0) ],
"_brush_v_1_rel" : [ SenseInfo('01243809-v', 11), SenseInfo('01240720-v', 10), SenseInfo('01243982-v', 5), SenseInfo('01870043-v', 2), SenseInfo('00555780-v', 1), SenseInfo('01373718-v', 0), SenseInfo('01243809-v', 11), SenseInfo('01240720-v', 10), SenseInfo('01243982-v', 5), SenseInfo('01870043-v', 2), SenseInfo('00555780-v', 1), SenseInfo('01373718-v', 0) ],
"_realistic_a_1_rel" : [ SenseInfo('01939984-a', 10), SenseInfo('01979985-a', 1), SenseInfo('02787290-a', 0), SenseInfo('01939984-a', 10), SenseInfo('01979985-a', 1), SenseInfo('02787290-a', 0) ],
"_flummox_v_1_rel" : [ SenseInfo('00622384-v', 0), SenseInfo('00622384-v', 0) ],
"_senator_n_1_rel" : [ SenseInfo('10578471-n', 6), SenseInfo('10578471-n', 6) ],
"_synthesize_v_1_rel" : [ SenseInfo('00644066-v', 3), SenseInfo('00644430-v', 0), SenseInfo('00644066-v', 3), SenseInfo('00644430-v', 0) ],
"_condition_n_1_rel" : [ SenseInfo('13920835-n', 72), SenseInfo('06755568-n', 12), SenseInfo('13920429-n', 2), SenseInfo('05822746-n', 1), SenseInfo('14546227-n', 0), SenseInfo('13923440-n', 0), SenseInfo('06770875-n', 0), SenseInfo('05798863-n', 0), SenseInfo('13920835-n', 72), SenseInfo('06755568-n', 12), SenseInfo('13920429-n', 2), SenseInfo('05822746-n', 1), SenseInfo('14546227-n', 0), SenseInfo('13923440-n', 0), SenseInfo('06770875-n', 0), SenseInfo('05798863-n', 0), SenseInfo('13920835-n', 72), SenseInfo('06755568-n', 12), SenseInfo('13920429-n', 2), SenseInfo('05822746-n', 1), SenseInfo('14546227-n', 0), SenseInfo('13923440-n', 0), SenseInfo('06770875-n', 0), SenseInfo('05798863-n', 0) ],
"_microscopic_a_1_rel" : [ SenseInfo('02918844-a', 4), SenseInfo('02516570-a', 0), SenseInfo('01838772-a', 0), SenseInfo('01393822-a', 0) ],
"_ablaze_a_1_rel" : [ SenseInfo('01726021-a', 1), SenseInfo('00475308-a', 0), SenseInfo('00402731-a', 0), SenseInfo('00270496-a', 0) ],
"_bequeath_v_1_rel" : [ SenseInfo('02229055-v', 0), SenseInfo('02229055-v', 0) ],
"_truly_x_deg_rel" : [ SenseInfo('00037226-r', 20), SenseInfo('00223000-r', 1), SenseInfo('00378365-r', 0), SenseInfo('00038013-r', 0) ],
"_coronary_n_1_rel" : [ SenseInfo('14102831-n', 0) ],
"_variable_n_1_rel" : [ SenseInfo('09468959-n', 4), SenseInfo('05857459-n', 2), SenseInfo('09469152-n', 0), SenseInfo('07271280-n', 0) ],
"_smelly_a_1_rel" : [ SenseInfo('01053634-a', 0) ],
"_jab_v_1_rel" : [ SenseInfo('01229976-v', 2), SenseInfo('01230555-v', 1), SenseInfo('01230350-v', 0), SenseInfo('01229976-v', 2), SenseInfo('01230555-v', 1), SenseInfo('01230350-v', 0) ],
"_blackness_n_1_rel" : [ SenseInfo('04960277-n', 4), SenseInfo('13983807-n', 2) ],
"_acquaint_v_with_rel" : [ SenseInfo('00901103-v', 1), SenseInfo('00874175-v', 1), SenseInfo('00832778-v', 0) ],
"_express_v_to_rel" : [ SenseInfo('00943837-v', 59), SenseInfo('00940384-v', 32), SenseInfo('01061017-v', 17), SenseInfo('01061481-v', 2), SenseInfo('02144460-v', 0), SenseInfo('01351754-v', 0), SenseInfo('01031756-v', 0) ],
"_dinnertime_n_1_rel" : [ SenseInfo('15166070-n', 2) ],
"_redundancy_n_1_rel" : [ SenseInfo('07090938-n', 1), SenseInfo('05120310-n', 1), SenseInfo('05730163-n', 0), SenseInfo('01019248-n', 0) ],
"_underestimate_v_1_rel" : [ SenseInfo('00695761-v', 1), SenseInfo('00673766-v', 1), SenseInfo('00671335-v', 1), SenseInfo('00695761-v', 1), SenseInfo('00673766-v', 1), SenseInfo('00671335-v', 1) ],
"_for_x_cause_rel" : [  ],
"_admit_v_of_rel" : [ SenseInfo('00817311-v', 64), SenseInfo('02502536-v', 11), SenseInfo('02449847-v', 1), SenseInfo('02236624-v', 1), SenseInfo('02745486-v', 0), SenseInfo('02741682-v', 0), SenseInfo('02732798-v', 0), SenseInfo('02671279-v', 0) ],
"_hyphenated_a_1_rel" : [  ],
"_tart_n_1_rel" : [ SenseInfo('10485440-n', 0), SenseInfo('07623933-n', 0), SenseInfo('07623664-n', 0) ],
"_off-target_a_1_rel" : [  ],
"_work_v_through_rel" : [ SenseInfo('02413480-v', 74), SenseInfo('02410855-v', 62), SenseInfo('02525447-v', 32), SenseInfo('01525666-v', 20), SenseInfo('01668603-v', 9), SenseInfo('00100551-v', 9), SenseInfo('02051031-v', 5), SenseInfo('02594979-v', 4), SenseInfo('02373015-v', 3), SenseInfo('01852468-v', 3), SenseInfo('01629589-v', 3), SenseInfo('02407987-v', 2), SenseInfo('01741446-v', 2), SenseInfo('02751271-v', 0), SenseInfo('02536557-v', 0), SenseInfo('02444159-v', 0), SenseInfo('02436963-v', 0), SenseInfo('02116980-v', 0), SenseInfo('01817574-v', 0), SenseInfo('01659248-v', 0), SenseInfo('01541231-v', 0), SenseInfo('01235355-v', 0), SenseInfo('01162754-v', 0), SenseInfo('00634906-v', 0), SenseInfo('00458754-v', 0), SenseInfo('00458471-v', 0), SenseInfo('00150096-v', 0) ],
"_drawl_n_1_rel" : [ SenseInfo('07131741-n', 1) ],
"_crisp_a_1_rel" : [ SenseInfo('00780352-a', 3), SenseInfo('02446931-a', 0), SenseInfo('01252714-a', 0), SenseInfo('01068104-a', 0), SenseInfo('01030372-a', 0), SenseInfo('00547641-a', 0), SenseInfo('00780352-a', 3), SenseInfo('02446931-a', 0), SenseInfo('01252714-a', 0), SenseInfo('01068104-a', 0), SenseInfo('01030372-a', 0), SenseInfo('00547641-a', 0), SenseInfo('00780352-a', 3), SenseInfo('02446931-a', 0), SenseInfo('01252714-a', 0), SenseInfo('01068104-a', 0), SenseInfo('01030372-a', 0), SenseInfo('00547641-a', 0) ],
"_close-up_a_1_rel" : [  ],
"_ungulate_a_1_rel" : [ SenseInfo('02489485-a', 0) ],
"_inside_a_1_rel" : [ SenseInfo('01693799-a', 2), SenseInfo('00953213-a', 1), SenseInfo('01863066-a', 0), SenseInfo('00950592-a', 0) ],
"_olive_n_1_rel" : [ SenseInfo('12301445-n', 0), SenseInfo('12301180-n', 0), SenseInfo('12301038-n', 0), SenseInfo('07767344-n', 0), SenseInfo('04974340-n', 0) ],
"_ferment_v_cause_rel" : [ SenseInfo('01763303-v', 0), SenseInfo('01761533-v', 0), SenseInfo('00458754-v', 0), SenseInfo('00458471-v', 0) ],
"_innocent_a_1_rel" : [ SenseInfo('01319874-a', 11), SenseInfo('01159907-a', 2), SenseInfo('02513614-a', 1), SenseInfo('02272670-a', 1), SenseInfo('01309220-a', 0), SenseInfo('00927978-a', 0), SenseInfo('00572392-a', 0) ],
"_monitor_n_1_rel" : [ SenseInfo('10478960-n', 0), SenseInfo('09771855-n', 0), SenseInfo('03782430-n', 0), SenseInfo('03782190-n', 0), SenseInfo('03782006-n', 0), SenseInfo('03781787-n', 0), SenseInfo('01694709-n', 0) ],
"_bygone_a_1_rel" : [ SenseInfo('01728919-a', 1) ],
"_empties_n_1_rel" : [ SenseInfo('03284308-n', 0), SenseInfo('03284308-n', 0) ],
"_retro_a_1_rel" : [ SenseInfo('01884744-a', 0) ],
"_ahead_p_sel_rel" : [ SenseInfo('00066781-r', 21), SenseInfo('00075442-r', 5), SenseInfo('00067265-r', 5), SenseInfo('00067045-r', 1), SenseInfo('02490631-a', 1), SenseInfo('00068070-r', 0), SenseInfo('00067823-r', 0), SenseInfo('00067513-r', 0) ],
"_delve_v_1_rel" : [ SenseInfo('01309701-v', 1) ],
"_adult_a_1_rel" : [ SenseInfo('01488616-a', 1), SenseInfo('02134397-a', 0) ],
"_reprisal_n_1_rel" : [ SenseInfo('01235946-n', 2) ],
"_man+to+man_a_1_rel" : [ SenseInfo('00765410-a', 0), SenseInfo('00494198-a', 0), SenseInfo('00765410-a', 0), SenseInfo('00494198-a', 0), SenseInfo('00765410-a', 0), SenseInfo('00494198-a', 0), SenseInfo('00765410-a', 0), SenseInfo('00494198-a', 0), SenseInfo('00765410-a', 0), SenseInfo('00494198-a', 0), SenseInfo('00765410-a', 0), SenseInfo('00494198-a', 0), SenseInfo('00765410-a', 0), SenseInfo('00494198-a', 0), SenseInfo('00765410-a', 0), SenseInfo('00494198-a', 0), SenseInfo('00765410-a', 0), SenseInfo('00494198-a', 0) ],
"_put_n_1_rel" : [ SenseInfo('00080968-n', 0) ],
"_boil_v_1_rel" : [ SenseInfo('00375021-v', 4), SenseInfo('00328128-v', 4), SenseInfo('00374668-v', 3), SenseInfo('01885430-v', 0), SenseInfo('01767612-v', 0) ],
"_access_n_1_rel" : [ SenseInfo('05176188-n', 2), SenseInfo('05175467-n', 2), SenseInfo('02671062-n', 2), SenseInfo('06354204-n', 0), SenseInfo('02671224-n', 0), SenseInfo('00281132-n', 0) ],
"_lenient_a_1_rel" : [ SenseInfo('01763159-a', 0), SenseInfo('00711831-a', 0), SenseInfo('00437744-a', 0), SenseInfo('01763159-a', 0), SenseInfo('00711831-a', 0), SenseInfo('00437744-a', 0) ],
"_lay_v_1_rel" : [ SenseInfo('01494310-v', 24), SenseInfo('01544692-v', 11), SenseInfo('01651972-v', 5), SenseInfo('01545079-v', 4), SenseInfo('02307261-v', 1), SenseInfo('01494310-v', 24), SenseInfo('01544692-v', 11), SenseInfo('01651972-v', 5), SenseInfo('01545079-v', 4), SenseInfo('02307261-v', 1) ],
"_anaconda_n_1_rel" : [ SenseInfo('01743086-n', 18) ],
"_left_n_of_rel" : [ SenseInfo('08625462-n', 19), SenseInfo('08416328-n', 2), SenseInfo('05565548-n', 2), SenseInfo('03654374-n', 2), SenseInfo('00351168-n', 0) ],
"_grip_n_1_rel" : [ SenseInfo('00812526-n', 7), SenseInfo('03485997-n', 1), SenseInfo('02773838-n', 1), SenseInfo('11460281-n', 0), SenseInfo('10147488-n', 0), SenseInfo('05194874-n', 0), SenseInfo('02860640-n', 0) ],
"_occupied_a_1_rel" : [ SenseInfo('01623187-a', 3), SenseInfo('01624267-a', 0), SenseInfo('01311814-a', 0), SenseInfo('00293611-a', 0) ],
"_underway_a_1_rel" : [ SenseInfo('00666784-a', 9) ],
"_climber_n_of_rel" : [ SenseInfo('13102409-n', 0), SenseInfo('10618685-n', 0), SenseInfo('10334957-n', 0), SenseInfo('09929298-n', 0), SenseInfo('03126385-n', 0) ],
"_under_x_deg_rel" : [ SenseInfo('00486509-r', 2), SenseInfo('01207546-a', 2), SenseInfo('00793682-a', 1), SenseInfo('00486694-r', 0), SenseInfo('00486605-r', 0), SenseInfo('00486384-r', 0), SenseInfo('00486296-r', 0), SenseInfo('00486223-r', 0), SenseInfo('00486157-r', 0), SenseInfo('00486067-r', 0) ],
"_settler_n_1_rel" : [ SenseInfo('10583387-n', 10), SenseInfo('10583916-n', 0), SenseInfo('10583790-n', 0) ],
"_buckle_n_1_rel" : [ SenseInfo('02910353-n', 2), SenseInfo('13885700-n', 0) ],
"_takeoff_n_1_rel" : [ SenseInfo('00306102-n', 1), SenseInfo('07375635-n', 0), SenseInfo('06780309-n', 0), SenseInfo('00549610-n', 0), SenseInfo('00306102-n', 1), SenseInfo('07375635-n', 0), SenseInfo('06780309-n', 0), SenseInfo('00549610-n', 0), SenseInfo('00306102-n', 1), SenseInfo('07375635-n', 0), SenseInfo('06780309-n', 0), SenseInfo('00549610-n', 0) ],
"_gradient_n_of_rel" : [ SenseInfo('13859512-n', 15), SenseInfo('05068461-n', 0), SenseInfo('13859512-n', 15), SenseInfo('05068461-n', 0), SenseInfo('13859512-n', 15), SenseInfo('05068461-n', 0) ],
"_instigator_n_1_rel" : [ SenseInfo('10209246-n', 0), SenseInfo('10209082-n', 0) ],
"_couple_v_with_rel" : [ SenseInfo('01292885-v', 5), SenseInfo('01297624-v', 2), SenseInfo('02490430-v', 1), SenseInfo('01428853-v', 0), SenseInfo('01292885-v', 5), SenseInfo('01297624-v', 2), SenseInfo('02490430-v', 1), SenseInfo('01428853-v', 0) ],
"_vex_v_1_rel" : [ SenseInfo('01787955-v', 1), SenseInfo('01765908-v', 0), SenseInfo('01419473-v', 0), SenseInfo('00812882-v', 0), SenseInfo('00622384-v', 0) ],
"_folklore_n_1_rel" : [ SenseInfo('05985602-n', 27) ],
"_ignite_v_1_rel" : [ SenseInfo('02759614-v', 2), SenseInfo('02760622-v', 1), SenseInfo('01761120-v', 1) ],
"_phonetics_n_1_rel" : [ SenseInfo('06177033-n', 1) ],
"_glory_n_1_rel" : [ SenseInfo('14437134-n', 9), SenseInfo('04684358-n', 6), SenseInfo('04951716-n', 0) ],
"_antsy_a_about_rel" : [ SenseInfo('02406166-a', 0) ],
"_congressional_a_1_rel" : [ SenseInfo('02981648-a', 2) ],
"_decompose_v_cause_rel" : [ SenseInfo('00209174-v', 3), SenseInfo('00399074-v', 0), SenseInfo('00209837-v', 0) ],
"_beggar_n_1_rel" : [ SenseInfo('09847010-n', 1) ],
"_orphanage_n_1_rel" : [ SenseInfo('14571181-n', 0), SenseInfo('03856012-n', 0) ],
"_persistent_a_1_rel" : [ SenseInfo('00593071-a', 10), SenseInfo('01040544-a', 1), SenseInfo('01758339-a', 0), SenseInfo('02327569-a', 0) ],
"_fairyland_n_1_rel" : [ SenseInfo('05633044-n', 1), SenseInfo('05627682-n', 0) ],
"_codename_v_1_rel" : [  ],
"_lower_v_cause_rel" : [ SenseInfo('01973125-v', 15), SenseInfo('00531489-v', 6), SenseInfo('00267855-v', 1), SenseInfo('01574923-v', 0), SenseInfo('00032981-v', 0) ],
"_now+that_x_rel" : [  ],
"_switch_v_1_rel" : [ SenseInfo('00140751-v', 5), SenseInfo('02259005-v', 3), SenseInfo('00550117-v', 2), SenseInfo('00380159-v', 1), SenseInfo('01510173-v', 0), SenseInfo('01411630-v', 0), SenseInfo('00121678-v', 0) ],
"_nearest_p_rel" : [ SenseInfo('00408021-r', 0), SenseInfo('00408021-r', 0) ],
"_light_a_1_rel" : [ SenseInfo('01186408-a', 14), SenseInfo('00408660-a', 9), SenseInfo('01193046-a', 4), SenseInfo('01190993-a', 3), SenseInfo('01190316-a', 3), SenseInfo('00269989-a', 3), SenseInfo('02320442-a', 2), SenseInfo('01182414-a', 2), SenseInfo('00503527-a', 2), SenseInfo('01906464-a', 1), SenseInfo('01192393-a', 1), SenseInfo('00712186-a', 1), SenseInfo('01191876-a', 0), SenseInfo('01191448-a', 0), SenseInfo('02544525-a', 0), SenseInfo('02414188-a', 0), SenseInfo('02401863-a', 0), SenseInfo('02337329-a', 0), SenseInfo('02165318-a', 0), SenseInfo('02121572-a', 0), SenseInfo('02121424-a', 0), SenseInfo('01188186-a', 0), SenseInfo('00993117-a', 0), SenseInfo('00693570-a', 0), SenseInfo('00361837-a', 0), SenseInfo('01186408-a', 14), SenseInfo('00408660-a', 9), SenseInfo('01193046-a', 4), SenseInfo('01190993-a', 3), SenseInfo('01190316-a', 3), SenseInfo('00269989-a', 3), SenseInfo('02320442-a', 2), SenseInfo('01182414-a', 2), SenseInfo('00503527-a', 2), SenseInfo('01906464-a', 1), SenseInfo('01192393-a', 1), SenseInfo('00712186-a', 1), SenseInfo('01191876-a', 0), SenseInfo('01191448-a', 0), SenseInfo('02544525-a', 0), SenseInfo('02414188-a', 0), SenseInfo('02401863-a', 0), SenseInfo('02337329-a', 0), SenseInfo('02165318-a', 0), SenseInfo('02121572-a', 0), SenseInfo('02121424-a', 0), SenseInfo('01188186-a', 0), SenseInfo('00993117-a', 0), SenseInfo('00693570-a', 0), SenseInfo('00361837-a', 0), SenseInfo('01186408-a', 14), SenseInfo('00408660-a', 9), SenseInfo('01193046-a', 4), SenseInfo('01190993-a', 3), SenseInfo('01190316-a', 3), SenseInfo('00269989-a', 3), SenseInfo('02320442-a', 2), SenseInfo('01182414-a', 2), SenseInfo('00503527-a', 2), SenseInfo('01906464-a', 1), SenseInfo('01192393-a', 1), SenseInfo('00712186-a', 1), SenseInfo('01191876-a', 0), SenseInfo('01191448-a', 0), SenseInfo('02544525-a', 0), SenseInfo('02414188-a', 0), SenseInfo('02401863-a', 0), SenseInfo('02337329-a', 0), SenseInfo('02165318-a', 0), SenseInfo('02121572-a', 0), SenseInfo('02121424-a', 0), SenseInfo('01188186-a', 0), SenseInfo('00993117-a', 0), SenseInfo('00693570-a', 0), SenseInfo('00361837-a', 0) ],
"_hazardous_a_1_rel" : [ SenseInfo('02059811-a', 0), SenseInfo('02059811-a', 0) ],
"_delight_v_in_rel" : [ SenseInfo('01815628-v', 5), SenseInfo('01190948-v', 3), SenseInfo('01817314-v', 0) ],
"_seep_v_1_rel" : [ SenseInfo('02071974-v', 4) ],
"_started_a_1_rel" : [  ],
"_greediness_n_1_rel" : [ SenseInfo('04886235-n', 0), SenseInfo('04834817-n', 0) ],
"_to_p_nbar_rel" : [  ],
"_mobile_a_1_rel" : [ SenseInfo('02128084-a', 2), SenseInfo('01522376-a', 0), SenseInfo('01563494-a', 0), SenseInfo('00346103-a', 0), SenseInfo('00345694-a', 0) ],
"_provisioning_n_1_rel" : [  ],
"_acetic_a_1_rel" : [ SenseInfo('03039907-a', 0) ],
"_rather_x_rel" : [ SenseInfo('00098714-r', 59), SenseInfo('00018302-r', 53), SenseInfo('00115554-r', 6), SenseInfo('00018781-r', 0) ],
"_microeconomics_n_1_rel" : [ SenseInfo('06151108-n', 0) ],
"_batter_n_1_rel" : [ SenseInfo('09843956-n', 2), SenseInfo('07860805-n', 0) ],
"_quarter_v_1_rel" : [ SenseInfo('02653159-v', 0), SenseInfo('02483564-v', 0), SenseInfo('01563575-v', 0), SenseInfo('00642498-v', 0) ],
"_mantic_a_1_rel" : [ SenseInfo('01882754-a', 1) ],
"_individuality_n_1_rel" : [ SenseInfo('04763293-n', 1), SenseInfo('04618070-n', 0) ],
"_medium+range_a_1_rel" : [  ],
"_tranquil_a_1_rel" : [ SenseInfo('00302951-a', 1), SenseInfo('00529657-a', 0) ],
"_vain_a_1_rel" : [ SenseInfo('01891773-a', 3), SenseInfo('01866812-a', 2), SenseInfo('01891773-a', 3), SenseInfo('01866812-a', 2), SenseInfo('01891773-a', 3), SenseInfo('01866812-a', 2), SenseInfo('01891773-a', 3), SenseInfo('01866812-a', 2) ],
"_carillon_n_1_rel" : [ SenseInfo('02965529-n', 0), SenseInfo('00544441-n', 0) ],
"_delicate_a_1_rel" : [ SenseInfo('00705891-a', 6), SenseInfo('02227344-a', 3), SenseInfo('00709215-a', 3), SenseInfo('02448324-a', 1), SenseInfo('01948389-a', 1), SenseInfo('00746994-a', 1), SenseInfo('02103982-a', 0) ],
"_by+far_x_deg_rel" : [ SenseInfo('00047056-r', 2) ],
"_decide_v_1_rel" : [ SenseInfo('00697589-v', 123), SenseInfo('00698855-v', 6), SenseInfo('00699485-v', 4), SenseInfo('00701877-v', 0), SenseInfo('00697589-v', 123), SenseInfo('00698855-v', 6), SenseInfo('00699485-v', 4), SenseInfo('00701877-v', 0), SenseInfo('00697589-v', 123), SenseInfo('00698855-v', 6), SenseInfo('00699485-v', 4), SenseInfo('00701877-v', 0), SenseInfo('00697589-v', 123), SenseInfo('00698855-v', 6), SenseInfo('00699485-v', 4), SenseInfo('00701877-v', 0) ],
"_compute_v_1_rel" : [ SenseInfo('00637259-v', 35) ],
"_baiter_n_1_rel" : [  ],
"_parody_v_1_rel" : [ SenseInfo('01723963-v', 1), SenseInfo('00849939-v', 0) ],
"_smiley+emoticon_a_1_rel" : [  ],
"_consider_v_1_rel" : [ SenseInfo('00690614-v', 107), SenseInfo('02166460-v', 51), SenseInfo('00734054-v', 37), SenseInfo('00950431-v', 27), SenseInfo('00813044-v', 15), SenseInfo('00689344-v', 2), SenseInfo('02133185-v', 0), SenseInfo('02130300-v', 0), SenseInfo('00691312-v', 0), SenseInfo('00690614-v', 107), SenseInfo('02166460-v', 51), SenseInfo('00734054-v', 37), SenseInfo('00950431-v', 27), SenseInfo('00813044-v', 15), SenseInfo('00689344-v', 2), SenseInfo('02133185-v', 0), SenseInfo('02130300-v', 0), SenseInfo('00691312-v', 0), SenseInfo('00690614-v', 107), SenseInfo('02166460-v', 51), SenseInfo('00734054-v', 37), SenseInfo('00950431-v', 27), SenseInfo('00813044-v', 15), SenseInfo('00689344-v', 2), SenseInfo('02133185-v', 0), SenseInfo('02130300-v', 0), SenseInfo('00691312-v', 0), SenseInfo('00690614-v', 107), SenseInfo('02166460-v', 51), SenseInfo('00734054-v', 37), SenseInfo('00950431-v', 27), SenseInfo('00813044-v', 15), SenseInfo('00689344-v', 2), SenseInfo('02133185-v', 0), SenseInfo('02130300-v', 0), SenseInfo('00691312-v', 0), SenseInfo('00690614-v', 107), SenseInfo('02166460-v', 51), SenseInfo('00734054-v', 37), SenseInfo('00950431-v', 27), SenseInfo('00813044-v', 15), SenseInfo('00689344-v', 2), SenseInfo('02133185-v', 0), SenseInfo('02130300-v', 0), SenseInfo('00691312-v', 0), SenseInfo('00690614-v', 107), SenseInfo('02166460-v', 51), SenseInfo('00734054-v', 37), SenseInfo('00950431-v', 27), SenseInfo('00813044-v', 15), SenseInfo('00689344-v', 2), SenseInfo('02133185-v', 0), SenseInfo('02130300-v', 0), SenseInfo('00691312-v', 0) ],
"_chromophore_n_1_rel" : [ SenseInfo('14808147-n', 0) ],
"_seafood_n_1_rel" : [ SenseInfo('07776866-n', 0) ],
"_guardhouse_n_1_rel" : [ SenseInfo('03464757-n', 0) ],
"_caffeinated_a_1_rel" : [  ],
"_potable_a_1_rel" : [ SenseInfo('00797113-a', 0) ],
"_teen_n_1_rel" : [ SenseInfo('09772029-n', 0) ],
"_take_v_home_rel" : [ SenseInfo('02599636-v', 92), SenseInfo('02267989-v', 74), SenseInfo('01999798-v', 73), SenseInfo('01214265-v', 50), SenseInfo('00524682-v', 38), SenseInfo('00624476-v', 36), SenseInfo('02077656-v', 32), SenseInfo('02205272-v', 28), SenseInfo('01842690-v', 26), SenseInfo('00674607-v', 26), SenseInfo('02236124-v', 25), SenseInfo('02394183-v', 22), SenseInfo('00734054-v', 22), SenseInfo('02627934-v', 21), SenseInfo('02109045-v', 21), SenseInfo('01002740-v', 16), SenseInfo('00173338-v', 16), SenseInfo('01156834-v', 15), SenseInfo('00669762-v', 15), SenseInfo('02209936-v', 14), SenseInfo('02206619-v', 13), SenseInfo('01982395-v', 10), SenseInfo('02236624-v', 8), SenseInfo('00523095-v', 7), SenseInfo('00599992-v', 6), SenseInfo('00756076-v', 5), SenseInfo('02075857-v', 4), SenseInfo('01151110-v', 4), SenseInfo('00557404-v', 4), SenseInfo('02717102-v', 2), SenseInfo('02208537-v', 2), SenseInfo('02209745-v', 1), SenseInfo('02208118-v', 1), SenseInfo('02201138-v', 1), SenseInfo('01427127-v', 1), SenseInfo('00758333-v', 1), SenseInfo('02741546-v', 0), SenseInfo('02701210-v', 0), SenseInfo('02590253-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01100830-v', 0), SenseInfo('00087736-v', 0) ],
"_systematic_a_1_rel" : [ SenseInfo('02382934-a', 2), SenseInfo('03018498-a', 0) ],
"_left+to+right_p_rel" : [  ],
"_stellar_a_1_rel" : [ SenseInfo('01472790-a', 1), SenseInfo('02802976-a', 0) ],
"_outbuilding_n_1_rel" : [ SenseInfo('03859280-n', 0) ],
"_wear_n_1_rel" : [ SenseInfo('14562683-n', 0), SenseInfo('03051540-n', 0), SenseInfo('00830257-n', 0) ],
"_pertaining_a_to_rel" : [  ],
"_bleed_v_of_rel" : [ SenseInfo('00074834-v', 10), SenseInfo('00086077-v', 2), SenseInfo('02360003-v', 0), SenseInfo('02060792-v', 0), SenseInfo('00449153-v', 0) ],
"_pseudo_a_1_rel" : [ SenseInfo('01118232-a', 9) ],
"_sally_n_1_rel" : [ SenseInfo('06767777-n', 1), SenseInfo('00971309-n', 0), SenseInfo('00801966-n', 0) ],
"_confucianism_n_1_rel" : [ SenseInfo('05969758-n', 0) ],
"_primeval_a_1_rel" : [ SenseInfo('00813589-a', 3) ],
"_nail_v_1_rel" : [ SenseInfo('01357831-v', 8), SenseInfo('01215137-v', 2), SenseInfo('01401772-v', 1), SenseInfo('02524897-v', 0), SenseInfo('02522581-v', 0), SenseInfo('02287380-v', 0), SenseInfo('01117484-v', 0) ],
"_appetite_n_1_rel" : [ SenseInfo('07485626-n', 5) ],
"_map_v_1_rel" : [ SenseInfo('01687876-v', 3), SenseInfo('00710606-v', 1), SenseInfo('02695709-v', 0), SenseInfo('01756149-v', 0), SenseInfo('01688114-v', 0), SenseInfo('00380698-v', 0), SenseInfo('01687876-v', 3), SenseInfo('00710606-v', 1), SenseInfo('02695709-v', 0), SenseInfo('01756149-v', 0), SenseInfo('01688114-v', 0), SenseInfo('00380698-v', 0) ],
"_scared_a_of_rel" : [ SenseInfo('00079629-a', 9), SenseInfo('00079629-a', 9) ],
"_outward_a_1_rel" : [ SenseInfo('00950706-a', 3), SenseInfo('01295660-a', 0), SenseInfo('00950706-a', 3), SenseInfo('01295660-a', 0) ],
"_consequently_x_deg_rel" : [ SenseInfo('00062857-r', 7), SenseInfo('00294459-r', 1) ],
"_meter_n_1_rel" : [ SenseInfo('13659162-n', 6), SenseInfo('03753077-n', 1), SenseInfo('07094093-n', 0), SenseInfo('04991738-n', 0), SenseInfo('13659162-n', 6), SenseInfo('03753077-n', 1), SenseInfo('07094093-n', 0), SenseInfo('04991738-n', 0), SenseInfo('13659162-n', 6), SenseInfo('03753077-n', 1), SenseInfo('07094093-n', 0), SenseInfo('04991738-n', 0), SenseInfo('13659162-n', 6), SenseInfo('03753077-n', 1), SenseInfo('07094093-n', 0), SenseInfo('04991738-n', 0), SenseInfo('13659162-n', 6), SenseInfo('03753077-n', 1), SenseInfo('07094093-n', 0), SenseInfo('04991738-n', 0) ],
"_butt_v_in_rel" : [ SenseInfo('01466978-v', 3), SenseInfo('01235769-v', 2), SenseInfo('01498713-v', 1) ],
"_economy_n_1_rel" : [ SenseInfo('08366753-n', 20), SenseInfo('05644727-n', 1), SenseInfo('04893787-n', 1), SenseInfo('00192613-n', 1) ],
"_nordic_a_1_rel" : [ SenseInfo('03092661-a', 0), SenseInfo('03092527-a', 0), SenseInfo('00244324-a', 0) ],
"_discredited_a_1_rel" : [ SenseInfo('01984252-a', 0), SenseInfo('00154163-a', 0) ],
"_pallid_a_1_rel" : [ SenseInfo('00405879-a', 2), SenseInfo('02325984-a', 1), SenseInfo('00408445-a', 0) ],
"_chancel_n_1_rel" : [ SenseInfo('03004824-n', 1) ],
"_hairline_n_1_rel" : [ SenseInfo('06802258-n', 0), SenseInfo('05256220-n', 0) ],
"_snap_v_1_rel" : [ SenseInfo('00916274-v', 7), SenseInfo('01573515-v', 3), SenseInfo('00337065-v', 3), SenseInfo('01893771-v', 2), SenseInfo('00355670-v', 2), SenseInfo('02182851-v', 1), SenseInfo('02088949-v', 1), SenseInfo('01439745-v', 1), SenseInfo('01402872-v', 1), SenseInfo('01242208-v', 1), SenseInfo('01784295-v', 0), SenseInfo('01446301-v', 0), SenseInfo('01003249-v', 0), SenseInfo('00916274-v', 7), SenseInfo('01573515-v', 3), SenseInfo('00337065-v', 3), SenseInfo('01893771-v', 2), SenseInfo('00355670-v', 2), SenseInfo('02182851-v', 1), SenseInfo('02088949-v', 1), SenseInfo('01439745-v', 1), SenseInfo('01402872-v', 1), SenseInfo('01242208-v', 1), SenseInfo('01784295-v', 0), SenseInfo('01446301-v', 0), SenseInfo('01003249-v', 0) ],
"_amicable_a_1_rel" : [ SenseInfo('01246579-a', 1) ],
"_fallacy_n_1_rel" : [ SenseInfo('05893916-n', 0) ],
"_hallway_n_1_rel" : [ SenseInfo('03479952-n', 5) ],
"_god_n_1_rel" : [ SenseInfo('09536058-n', 90), SenseInfo('09505418-n', 26), SenseInfo('10133307-n', 0), SenseInfo('03560161-n', 0) ],
"_credit_n_1_rel" : [ SenseInfo('06688274-n', 7), SenseInfo('13378518-n', 5), SenseInfo('13405646-n', 4), SenseInfo('00037200-n', 3), SenseInfo('13374281-n', 2), SenseInfo('00065855-n', 1), SenseInfo('06763681-n', 0), SenseInfo('06346681-n', 0), SenseInfo('05803747-n', 0) ],
"_dissolve_v_cause_rel" : [ SenseInfo('00447771-v', 4), SenseInfo('00447309-v', 3), SenseInfo('00355803-v', 2), SenseInfo('02029944-v', 1), SenseInfo('01784799-v', 0), SenseInfo('01784592-v', 0), SenseInfo('00447950-v', 0), SenseInfo('00446329-v', 0), SenseInfo('00376106-v', 0), SenseInfo('00355955-v', 0), SenseInfo('00338559-v', 0) ],
"_dun_v_1_rel" : [ SenseInfo('01803003-v', 0), SenseInfo('00845144-v', 0), SenseInfo('00528115-v', 0), SenseInfo('00312165-v', 0) ],
"_chicken_n_1_rel" : [ SenseInfo('07644967-n', 16), SenseInfo('01791625-n', 10), SenseInfo('10781817-n', 0), SenseInfo('07457936-n', 0) ],
"_commute_n_1_rel" : [ SenseInfo('00307455-n', 0) ],
"_over_x_deg_rel" : [ SenseInfo('00226550-r', 23), SenseInfo('01003277-a', 21), SenseInfo('00226677-r', 2), SenseInfo('00226458-r', 1), SenseInfo('15258694-n', 0), SenseInfo('00226758-r', 0), SenseInfo('00198039-r', 0) ],
"_head+to+head_a_1_rel" : [ SenseInfo('01860890-a', 0), SenseInfo('00551416-a', 0), SenseInfo('01860890-a', 0), SenseInfo('00551416-a', 0), SenseInfo('01860890-a', 0), SenseInfo('00551416-a', 0), SenseInfo('01860890-a', 0), SenseInfo('00551416-a', 0), SenseInfo('01860890-a', 0), SenseInfo('00551416-a', 0), SenseInfo('01860890-a', 0), SenseInfo('00551416-a', 0) ],
"_danish_n_1_rel" : [ SenseInfo('06954048-n', 2), SenseInfo('07693590-n', 0), SenseInfo('06954048-n', 2), SenseInfo('07693590-n', 0), SenseInfo('06954048-n', 2), SenseInfo('07693590-n', 0) ],
"_overstep_v_1_rel" : [ SenseInfo('02019574-v', 1), SenseInfo('02669081-v', 0), SenseInfo('02019574-v', 1), SenseInfo('02669081-v', 0), SenseInfo('02019574-v', 1), SenseInfo('02669081-v', 0) ],
"_flip_v_down_rel" : [ SenseInfo('01893079-v', 3), SenseInfo('01510173-v', 1), SenseInfo('02153023-v', 0), SenseInfo('01893601-v', 0), SenseInfo('01893465-v', 0), SenseInfo('01512625-v', 0), SenseInfo('01241614-v', 0), SenseInfo('01222958-v', 0), SenseInfo('00717921-v', 0), SenseInfo('00584810-v', 0), SenseInfo('00121678-v', 0) ],
"_concern_v_with_rel" : [ SenseInfo('02676054-v', 56), SenseInfo('02678438-v', 22) ],
"_big+league_a_1_rel" : [  ],
"_worldwide_a_rel" : [ SenseInfo('01567694-a', 1), SenseInfo('01568684-a', 0), SenseInfo('00527188-a', 0) ],
"_broadsword_n_1_rel" : [ SenseInfo('02904640-n', 0) ],
"_estimate_v_at_rel" : [ SenseInfo('00672433-v', 34), SenseInfo('00712135-v', 9), SenseInfo('00672433-v', 34), SenseInfo('00712135-v', 9), SenseInfo('00672433-v', 34), SenseInfo('00712135-v', 9), SenseInfo('00672433-v', 34), SenseInfo('00712135-v', 9) ],
"_long-lived_a_1_rel" : [ SenseInfo('01439496-a', 1) ],
"_circle_n_of_rel" : [ SenseInfo('13873502-n', 15), SenseInfo('08240169-n', 10), SenseInfo('13873917-n', 4), SenseInfo('00295172-n', 2), SenseInfo('04465933-n', 0), SenseInfo('04036494-n', 0), SenseInfo('03033019-n', 0), SenseInfo('03032811-n', 0) ],
"_respond_v_to_rel" : [ SenseInfo('00717358-v', 33), SenseInfo('00815686-v', 7), SenseInfo('00718737-v', 1), SenseInfo('00717358-v', 33), SenseInfo('00815686-v', 7), SenseInfo('00718737-v', 1), SenseInfo('00717358-v', 33), SenseInfo('00815686-v', 7), SenseInfo('00718737-v', 1) ],
"_hibernate_v_1_rel" : [ SenseInfo('00015946-v', 2), SenseInfo('02596004-v', 0) ],
"_fidelity_n_1_rel" : [ SenseInfo('04804306-n', 1), SenseInfo('04876985-n', 0) ],
"_tribunal_n_1_rel" : [ SenseInfo('08329453-n', 1) ],
"_mountainscape_n_1_rel" : [  ],
"_painful_a_to_rel" : [ SenseInfo('01711071-a', 10), SenseInfo('01804175-a', 1), SenseInfo('01126291-a', 0), SenseInfo('00478685-a', 0), SenseInfo('01711071-a', 10), SenseInfo('01804175-a', 1), SenseInfo('01126291-a', 0), SenseInfo('00478685-a', 0) ],
"_volumetric_a_1_rel" : [ SenseInfo('02985474-a', 1) ],
"_exhausting_a_1_rel" : [ SenseInfo('01358231-a', 1), SenseInfo('00837249-a', 0) ],
"_bare_v_1_rel" : [ SenseInfo('01340028-v', 1), SenseInfo('00954608-v', 0), SenseInfo('00194912-v', 0) ],
"_whinny_n_1_rel" : [ SenseInfo('07387316-n', 0) ],
"_but_x_rel" : [ SenseInfo('00004722-r', 2) ],
"_effectiveness_n_1_rel" : [ SenseInfo('05199286-n', 11), SenseInfo('05034225-n', 3) ],
"_concern_v_1_rel" : [ SenseInfo('02676054-v', 56), SenseInfo('02678438-v', 22), SenseInfo('02676054-v', 56), SenseInfo('02678438-v', 22), SenseInfo('02676054-v', 56), SenseInfo('02678438-v', 22) ],
"_funeral_n_1_rel" : [ SenseInfo('07451463-n', 8) ],
"_if+required_a_1_rel" : [  ],
"_optimize_v_1_rel" : [ SenseInfo('00172505-v', 0), SenseInfo('00124226-v', 0), SenseInfo('00011852-v', 0) ],
"_soup_v_up_rel" : [ SenseInfo('00085246-v', 0) ],
"_charitable_a_1_rel" : [ SenseInfo('02691390-a', 2), SenseInfo('00359459-a', 1), SenseInfo('01372948-a', 0) ],
"_knäckebrød_n_1_rel" : [  ],
"_rope_n_1_rel" : [ SenseInfo('04108268-n', 5), SenseInfo('04036494-n', 0), SenseInfo('04108268-n', 5), SenseInfo('04036494-n', 0), SenseInfo('04108268-n', 5), SenseInfo('04036494-n', 0) ],
"_rocket_v_up_rel" : [ SenseInfo('01944086-v', 0), SenseInfo('01241753-v', 0) ],
"_girlfriend_n_1_rel" : [ SenseInfo('10130877-n', 1), SenseInfo('10130686-n', 1) ],
"_solace_n_1_rel" : [ SenseInfo('07492655-n', 2), SenseInfo('14446161-n', 0), SenseInfo('01211667-n', 0) ],
"_touch_v_1_rel" : [ SenseInfo('01206218-v', 33), SenseInfo('02127358-v', 5), SenseInfo('01770802-v', 4), SenseInfo('02676054-v', 3), SenseInfo('01205696-v', 3), SenseInfo('00137313-v', 3), SenseInfo('02599325-v', 2), SenseInfo('01206849-v', 2), SenseInfo('02685665-v', 1), SenseInfo('02672187-v', 1), SenseInfo('01207527-v', 1), SenseInfo('01026728-v', 1), SenseInfo('00590642-v', 1), SenseInfo('01172701-v', 0), SenseInfo('00286928-v', 0) ],
"_marginal_a_1_rel" : [ SenseInfo('00331889-a', 4), SenseInfo('01496311-a', 3), SenseInfo('02563466-a', 0), SenseInfo('01872486-a', 0) ],
"_drop+in_n_1_rel" : [  ],
"_embody_v_1_rel" : [ SenseInfo('02698443-v', 3), SenseInfo('02697725-v', 3), SenseInfo('02740352-v', 1) ],
"_feed_v_in_rel" : [ SenseInfo('01182021-v', 47), SenseInfo('01178565-v', 15), SenseInfo('01181166-v', 5), SenseInfo('00189511-v', 4), SenseInfo('02555787-v', 3), SenseInfo('01179865-v', 3), SenseInfo('01180206-v', 1), SenseInfo('02066939-v', 0), SenseInfo('01203715-v', 0), SenseInfo('01182152-v', 0), SenseInfo('00502757-v', 0) ],
"_overnight_v_1_rel" : [  ],
"_pervasive_a_1_rel" : [ SenseInfo('00468795-a', 0) ],
"_play_v_out_rel" : [ SenseInfo('01072949-v', 70), SenseInfo('02370650-v', 37), SenseInfo('01725051-v', 29), SenseInfo('01719302-v', 27), SenseInfo('02418686-v', 23), SenseInfo('01724459-v', 14), SenseInfo('01726172-v', 8), SenseInfo('00013615-v', 6), SenseInfo('01903385-v', 5), SenseInfo('01138911-v', 5), SenseInfo('02418421-v', 4), SenseInfo('01722077-v', 4), SenseInfo('01717436-v', 3), SenseInfo('01716619-v', 2), SenseInfo('01149470-v', 2), SenseInfo('00013328-v', 2), SenseInfo('02597601-v', 1), SenseInfo('01717169-v', 1), SenseInfo('01586278-v', 1), SenseInfo('01163355-v', 1), SenseInfo('00711932-v', 1), SenseInfo('02722449-v', 0), SenseInfo('02437465-v', 0), SenseInfo('01903562-v', 0), SenseInfo('01719921-v', 0), SenseInfo('01716882-v', 0), SenseInfo('01629589-v', 0), SenseInfo('01377239-v', 0), SenseInfo('01156115-v', 0), SenseInfo('01155687-v', 0), SenseInfo('01080691-v', 0), SenseInfo('01080064-v', 0), SenseInfo('01079873-v', 0), SenseInfo('01079480-v', 0), SenseInfo('00075875-v', 0) ],
"_mini+camcorder_n_1_rel" : [  ],
"_black_n_1_rel" : [ SenseInfo('04960277-n', 4), SenseInfo('13983807-n', 0), SenseInfo('10852130-n', 0), SenseInfo('10851987-n', 0), SenseInfo('09636339-n', 0), SenseInfo('02846260-n', 0), SenseInfo('02846141-n', 0), SenseInfo('04960277-n', 4), SenseInfo('13983807-n', 0), SenseInfo('10852130-n', 0), SenseInfo('10851987-n', 0), SenseInfo('09636339-n', 0), SenseInfo('02846260-n', 0), SenseInfo('02846141-n', 0) ],
"_crunch_n_1_rel" : [ SenseInfo('07382414-n', 1), SenseInfo('13934070-n', 0), SenseInfo('00358089-n', 0) ],
"_basil_n_1_rel" : [ SenseInfo('12860365-n', 0), SenseInfo('10837918-n', 0), SenseInfo('07816164-n', 0) ],
"_extensiveness_n_1_rel" : [ SenseInfo('05106317-n', 0) ],
"_aggregation_n_of_rel" : [ SenseInfo('07951464-n', 1), SenseInfo('01014066-n', 0) ],
"_dead_a_1_rel" : [ SenseInfo('00095280-a', 72), SenseInfo('00099874-a', 4), SenseInfo('02432154-a', 2), SenseInfo('01838151-a', 1), SenseInfo('00041202-a', 1), SenseInfo('02107386-a', 0), SenseInfo('02105603-a', 0), SenseInfo('02011445-a', 0), SenseInfo('01872265-a', 0), SenseInfo('01241248-a', 0), SenseInfo('00929443-a', 0), SenseInfo('00845737-a', 0), SenseInfo('00833878-a', 0), SenseInfo('00668919-a', 0), SenseInfo('00522349-a', 0), SenseInfo('00359260-a', 0), SenseInfo('00036879-a', 0), SenseInfo('00095280-a', 72), SenseInfo('00099874-a', 4), SenseInfo('02432154-a', 2), SenseInfo('01838151-a', 1), SenseInfo('00041202-a', 1), SenseInfo('02107386-a', 0), SenseInfo('02105603-a', 0), SenseInfo('02011445-a', 0), SenseInfo('01872265-a', 0), SenseInfo('01241248-a', 0), SenseInfo('00929443-a', 0), SenseInfo('00845737-a', 0), SenseInfo('00833878-a', 0), SenseInfo('00668919-a', 0), SenseInfo('00522349-a', 0), SenseInfo('00359260-a', 0), SenseInfo('00036879-a', 0), SenseInfo('00095280-a', 72), SenseInfo('00099874-a', 4), SenseInfo('02432154-a', 2), SenseInfo('01838151-a', 1), SenseInfo('00041202-a', 1), SenseInfo('02107386-a', 0), SenseInfo('02105603-a', 0), SenseInfo('02011445-a', 0), SenseInfo('01872265-a', 0), SenseInfo('01241248-a', 0), SenseInfo('00929443-a', 0), SenseInfo('00845737-a', 0), SenseInfo('00833878-a', 0), SenseInfo('00668919-a', 0), SenseInfo('00522349-a', 0), SenseInfo('00359260-a', 0), SenseInfo('00036879-a', 0) ],
"_develop_v_1_rel" : [ SenseInfo('01738774-v', 44), SenseInfo('01738597-v', 44), SenseInfo('00545557-v', 41), SenseInfo('00094460-v', 19), SenseInfo('02624263-v', 15), SenseInfo('00171852-v', 12), SenseInfo('00925873-v', 6), SenseInfo('00603298-v', 5), SenseInfo('00342980-v', 4), SenseInfo('00252019-v', 4), SenseInfo('00411020-v', 3), SenseInfo('00253761-v', 3), SenseInfo('01627947-v', 1), SenseInfo('00543410-v', 1), SenseInfo('02138766-v', 0), SenseInfo('01469623-v', 0), SenseInfo('01074701-v', 0), SenseInfo('01074509-v', 0), SenseInfo('00402130-v', 0), SenseInfo('00339464-v', 0), SenseInfo('00234057-v', 0), SenseInfo('01738774-v', 44), SenseInfo('01738597-v', 44), SenseInfo('00545557-v', 41), SenseInfo('00094460-v', 19), SenseInfo('02624263-v', 15), SenseInfo('00171852-v', 12), SenseInfo('00925873-v', 6), SenseInfo('00603298-v', 5), SenseInfo('00342980-v', 4), SenseInfo('00252019-v', 4), SenseInfo('00411020-v', 3), SenseInfo('00253761-v', 3), SenseInfo('01627947-v', 1), SenseInfo('00543410-v', 1), SenseInfo('02138766-v', 0), SenseInfo('01469623-v', 0), SenseInfo('01074701-v', 0), SenseInfo('01074509-v', 0), SenseInfo('00402130-v', 0), SenseInfo('00339464-v', 0), SenseInfo('00234057-v', 0) ],
"_lance_n_1_rel" : [ SenseInfo('04270891-n', 2), SenseInfo('04271148-n', 0), SenseInfo('03637618-n', 0) ],
"_visit_v_1_rel" : [ SenseInfo('02493030-v', 29), SenseInfo('01843689-v', 24), SenseInfo('02487573-v', 15), SenseInfo('01844048-v', 6), SenseInfo('00748282-v', 3), SenseInfo('01038666-v', 1), SenseInfo('02619424-v', 0), SenseInfo('00260142-v', 0) ],
"_semicircular_a_1_rel" : [ SenseInfo('02316718-a', 0) ],
"_hoard_v_1_rel" : [ SenseInfo('02305856-v', 0), SenseInfo('02304982-v', 0) ],
"_forge_v_1_rel" : [ SenseInfo('01675245-v', 1), SenseInfo('01654271-v', 1), SenseInfo('01632411-v', 1), SenseInfo('01884266-v', 0), SenseInfo('01884126-v', 0), SenseInfo('01659248-v', 0), SenseInfo('01658188-v', 0) ],
"_generally_x_deg_rel" : [ SenseInfo('00155621-r', 37), SenseInfo('00041954-r', 11), SenseInfo('00221583-r', 2), SenseInfo('00155621-r', 37), SenseInfo('00041954-r', 11), SenseInfo('00221583-r', 2) ],
"_quart_n_1_rel" : [ SenseInfo('13619592-n', 3), SenseInfo('13622035-n', 0), SenseInfo('13620549-n', 0), SenseInfo('13619592-n', 3), SenseInfo('13622035-n', 0), SenseInfo('13620549-n', 0), SenseInfo('13619592-n', 3), SenseInfo('13622035-n', 0), SenseInfo('13620549-n', 0) ],
"_charm_n_1_rel" : [ SenseInfo('04687333-n', 6), SenseInfo('07159791-n', 1), SenseInfo('03009633-n', 1), SenseInfo('05844433-n', 0) ],
"_above-mentioned_a_1_rel" : [ SenseInfo('00126116-a', 1), SenseInfo('00126116-a', 1) ],
"_whist_n_1_rel" : [ SenseInfo('00496167-n', 0) ],
"_roar_v_1_rel" : [ SenseInfo('01046059-v', 15), SenseInfo('00915605-v', 7), SenseInfo('01046932-v', 6), SenseInfo('01996188-v', 1), SenseInfo('01048718-v', 1), SenseInfo('00029836-v', 0), SenseInfo('01046059-v', 15), SenseInfo('00915605-v', 7), SenseInfo('01046932-v', 6), SenseInfo('01996188-v', 1), SenseInfo('01048718-v', 1), SenseInfo('00029836-v', 0) ],
"_question_n_about_rel" : [ SenseInfo('07193596-n', 81), SenseInfo('06783768-n', 50), SenseInfo('07196682-n', 9), SenseInfo('04757522-n', 8), SenseInfo('07163593-n', 0), SenseInfo('07162059-n', 0), SenseInfo('07193596-n', 81), SenseInfo('06783768-n', 50), SenseInfo('07196682-n', 9), SenseInfo('04757522-n', 8), SenseInfo('07163593-n', 0), SenseInfo('07162059-n', 0), SenseInfo('07193596-n', 81), SenseInfo('06783768-n', 50), SenseInfo('07196682-n', 9), SenseInfo('04757522-n', 8), SenseInfo('07163593-n', 0), SenseInfo('07162059-n', 0) ],
"_abstention_n_1_rel" : [ SenseInfo('04882622-n', 1) ],
"_at-risk_a_1_rel" : [  ],
"_fluctuate_v_1_rel" : [ SenseInfo('01877204-v', 0), SenseInfo('01876907-v', 0), SenseInfo('00270699-v', 0) ],
"_raingear_n_1_rel" : [  ],
"_grasp_v_1_rel" : [ SenseInfo('01216004-v', 15), SenseInfo('00588221-v', 8), SenseInfo('01216004-v', 15), SenseInfo('00588221-v', 8) ],
"_copyright_n_1_rel" : [ SenseInfo('06473168-n', 0), SenseInfo('06473168-n', 0) ],
"_barrel_n_1_rel" : [ SenseInfo('02795528-n', 8), SenseInfo('02795169-n', 5), SenseInfo('13901211-n', 2), SenseInfo('13764764-n', 0), SenseInfo('13619920-n', 0) ],
"_golden_a_1_rel" : [ SenseInfo('00369941-a', 6), SenseInfo('01149195-a', 2), SenseInfo('01528730-a', 1), SenseInfo('00670938-a', 0), SenseInfo('00300943-a', 0), SenseInfo('00177547-a', 0) ],
"_more_x_comp_rel" : [ SenseInfo('00099341-r', 374), SenseInfo('01555133-a', 134), SenseInfo('01556355-a', 67), SenseInfo('00099712-r', 34), SenseInfo('11190183-n', 0), SenseInfo('00099341-r', 374), SenseInfo('01555133-a', 134), SenseInfo('01556355-a', 67), SenseInfo('00099712-r', 34), SenseInfo('11190183-n', 0) ],
"_wilds_n_1_rel" : [ SenseInfo('13939353-n', 0), SenseInfo('08683548-n', 0), SenseInfo('13939353-n', 0), SenseInfo('08683548-n', 0) ],
"_wrong_v_1_rel" : [ SenseInfo('02513989-v', 1) ],
"_distiller_n_1_rel" : [ SenseInfo('10018653-n', 0) ],
"_upholster_v_1_rel" : [ SenseInfo('02341816-v', 1) ],
"_breather_n_1_rel" : [ SenseInfo('15274695-n', 0), SenseInfo('04250850-n', 0) ],
"_damp_v_1_rel" : [ SenseInfo('02191311-v', 0), SenseInfo('00573085-v', 0), SenseInfo('00390560-v', 0), SenseInfo('00390215-v', 0) ],
"_dirge_n_1_rel" : [ SenseInfo('07050619-n', 2) ],
"_reversion_n_of_rel" : [ SenseInfo('13341350-n', 0), SenseInfo('07426573-n', 0), SenseInfo('07343574-n', 0), SenseInfo('00346693-n', 0), SenseInfo('00235208-n', 0), SenseInfo('00068333-n', 0) ],
"_magnify_v_1_rel" : [ SenseInfo('00434077-v', 4), SenseInfo('00839834-v', 1), SenseInfo('00240293-v', 1) ],
"_lately_a_rel" : [  ],
"_intersect_v_1_rel" : [ SenseInfo('02023396-v', 7) ],
"_bring_v_1_rel" : [ SenseInfo('02077656-v', 122), SenseInfo('01438902-v', 55), SenseInfo('01629589-v', 31), SenseInfo('01433294-v', 19), SenseInfo('00135857-v', 9), SenseInfo('01434140-v', 4), SenseInfo('01618547-v', 3), SenseInfo('02324478-v', 2), SenseInfo('02247390-v', 1), SenseInfo('01808218-v', 0), SenseInfo('00767334-v', 0), SenseInfo('02077656-v', 122), SenseInfo('01438902-v', 55), SenseInfo('01629589-v', 31), SenseInfo('01433294-v', 19), SenseInfo('00135857-v', 9), SenseInfo('01434140-v', 4), SenseInfo('01618547-v', 3), SenseInfo('02324478-v', 2), SenseInfo('02247390-v', 1), SenseInfo('01808218-v', 0), SenseInfo('00767334-v', 0), SenseInfo('02077656-v', 122), SenseInfo('01438902-v', 55), SenseInfo('01629589-v', 31), SenseInfo('01433294-v', 19), SenseInfo('00135857-v', 9), SenseInfo('01434140-v', 4), SenseInfo('01618547-v', 3), SenseInfo('02324478-v', 2), SenseInfo('02247390-v', 1), SenseInfo('01808218-v', 0), SenseInfo('00767334-v', 0), SenseInfo('02077656-v', 122), SenseInfo('01438902-v', 55), SenseInfo('01629589-v', 31), SenseInfo('01433294-v', 19), SenseInfo('00135857-v', 9), SenseInfo('01434140-v', 4), SenseInfo('01618547-v', 3), SenseInfo('02324478-v', 2), SenseInfo('02247390-v', 1), SenseInfo('01808218-v', 0), SenseInfo('00767334-v', 0), SenseInfo('02077656-v', 122), SenseInfo('01438902-v', 55), SenseInfo('01629589-v', 31), SenseInfo('01433294-v', 19), SenseInfo('00135857-v', 9), SenseInfo('01434140-v', 4), SenseInfo('01618547-v', 3), SenseInfo('02324478-v', 2), SenseInfo('02247390-v', 1), SenseInfo('01808218-v', 0), SenseInfo('00767334-v', 0) ],
"_hostile_a_1_rel" : [ SenseInfo('01244410-a', 5), SenseInfo('01077829-a', 3), SenseInfo('01987093-a', 0), SenseInfo('01243373-a', 0), SenseInfo('00083478-a', 0) ],
"_need_v_1_rel" : [ SenseInfo('02627934-v', 110), SenseInfo('01188725-v', 98), SenseInfo('01189113-v', 1), SenseInfo('02627934-v', 110), SenseInfo('01188725-v', 98), SenseInfo('01189113-v', 1), SenseInfo('02627934-v', 110), SenseInfo('01188725-v', 98), SenseInfo('01189113-v', 1), SenseInfo('02627934-v', 110), SenseInfo('01188725-v', 98), SenseInfo('01189113-v', 1), SenseInfo('02627934-v', 110), SenseInfo('01188725-v', 98), SenseInfo('01189113-v', 1), SenseInfo('02627934-v', 110), SenseInfo('01188725-v', 98), SenseInfo('01189113-v', 1), SenseInfo('02627934-v', 110), SenseInfo('01188725-v', 98), SenseInfo('01189113-v', 1), SenseInfo('02627934-v', 110), SenseInfo('01188725-v', 98), SenseInfo('01189113-v', 1), SenseInfo('02627934-v', 110), SenseInfo('01188725-v', 98), SenseInfo('01189113-v', 1), SenseInfo('02627934-v', 110), SenseInfo('01188725-v', 98), SenseInfo('01189113-v', 1) ],
"_despite_p_rel" : [ SenseInfo('07502980-n', 0), SenseInfo('00418787-n', 0) ],
"_flu_n_1_rel" : [ SenseInfo('14122497-n', 2) ],
"_leaded_a_1_rel" : [ SenseInfo('01060304-a', 1), SenseInfo('01396800-a', 0), SenseInfo('01656129-a', 0) ],
"_chap_v_1_rel" : [ SenseInfo('00337428-v', 0) ],
"_first_n_of_rel" : [ SenseInfo('13846199-n', 9), SenseInfo('13597444-n', 5), SenseInfo('15265518-n', 1), SenseInfo('00723547-n', 1), SenseInfo('06700169-n', 0), SenseInfo('03350011-n', 0), SenseInfo('13846199-n', 9), SenseInfo('13597444-n', 5), SenseInfo('15265518-n', 1), SenseInfo('00723547-n', 1), SenseInfo('06700169-n', 0), SenseInfo('03350011-n', 0) ],
"_coalescence_n_1_rel" : [ SenseInfo('00382109-n', 1) ],
"_charge_v_to_rel" : [ SenseInfo('01121719-v', 16), SenseInfo('00843468-v', 10), SenseInfo('02320374-v', 7), SenseInfo('02055267-v', 6), SenseInfo('02475922-v', 4), SenseInfo('00869931-v', 3), SenseInfo('00843959-v', 3), SenseInfo('01488956-v', 2), SenseInfo('02321046-v', 1), SenseInfo('02348568-v', 0), SenseInfo('02347637-v', 0), SenseInfo('02317289-v', 0), SenseInfo('01985424-v', 0), SenseInfo('01762528-v', 0), SenseInfo('01685960-v', 0), SenseInfo('01490336-v', 0), SenseInfo('01152214-v', 0), SenseInfo('00750532-v', 0), SenseInfo('00750345-v', 0), SenseInfo('00750172-v', 0), SenseInfo('00727991-v', 0), SenseInfo('00700517-v', 0), SenseInfo('00518115-v', 0), SenseInfo('00517847-v', 0), SenseInfo('00498016-v', 0), SenseInfo('01121719-v', 16), SenseInfo('00843468-v', 10), SenseInfo('02320374-v', 7), SenseInfo('02055267-v', 6), SenseInfo('02475922-v', 4), SenseInfo('00869931-v', 3), SenseInfo('00843959-v', 3), SenseInfo('01488956-v', 2), SenseInfo('02321046-v', 1), SenseInfo('02348568-v', 0), SenseInfo('02347637-v', 0), SenseInfo('02317289-v', 0), SenseInfo('01985424-v', 0), SenseInfo('01762528-v', 0), SenseInfo('01685960-v', 0), SenseInfo('01490336-v', 0), SenseInfo('01152214-v', 0), SenseInfo('00750532-v', 0), SenseInfo('00750345-v', 0), SenseInfo('00750172-v', 0), SenseInfo('00727991-v', 0), SenseInfo('00700517-v', 0), SenseInfo('00518115-v', 0), SenseInfo('00517847-v', 0), SenseInfo('00498016-v', 0) ],
"_wear_v_thin_rel" : [ SenseInfo('00052374-v', 83), SenseInfo('00047745-v', 22), SenseInfo('02740034-v', 6), SenseInfo('00469382-v', 2), SenseInfo('00047610-v', 2), SenseInfo('02705132-v', 1), SenseInfo('01369346-v', 0), SenseInfo('00075021-v', 0), SenseInfo('00050652-v', 0) ],
"_egoistic_a_1_rel" : [ SenseInfo('00101800-a', 0) ],
"_foot_n_1_rel" : [ SenseInfo('05563266-n', 89), SenseInfo('13650045-n', 81), SenseInfo('08511570-n', 8), SenseInfo('02153445-n', 4), SenseInfo('03387016-n', 2), SenseInfo('02322213-n', 2), SenseInfo('00284665-n', 1), SenseInfo('10101078-n', 0), SenseInfo('08390157-n', 0), SenseInfo('07094843-n', 0), SenseInfo('03378442-n', 0), SenseInfo('05563266-n', 89), SenseInfo('13650045-n', 81), SenseInfo('08511570-n', 8), SenseInfo('02153445-n', 4), SenseInfo('03387016-n', 2), SenseInfo('02322213-n', 2), SenseInfo('00284665-n', 1), SenseInfo('10101078-n', 0), SenseInfo('08390157-n', 0), SenseInfo('07094843-n', 0), SenseInfo('03378442-n', 0), SenseInfo('05563266-n', 89), SenseInfo('13650045-n', 81), SenseInfo('08511570-n', 8), SenseInfo('02153445-n', 4), SenseInfo('03387016-n', 2), SenseInfo('02322213-n', 2), SenseInfo('00284665-n', 1), SenseInfo('10101078-n', 0), SenseInfo('08390157-n', 0), SenseInfo('07094843-n', 0), SenseInfo('03378442-n', 0), SenseInfo('05563266-n', 89), SenseInfo('13650045-n', 81), SenseInfo('08511570-n', 8), SenseInfo('02153445-n', 4), SenseInfo('03387016-n', 2), SenseInfo('02322213-n', 2), SenseInfo('00284665-n', 1), SenseInfo('10101078-n', 0), SenseInfo('08390157-n', 0), SenseInfo('07094843-n', 0), SenseInfo('03378442-n', 0), SenseInfo('05563266-n', 89), SenseInfo('13650045-n', 81), SenseInfo('08511570-n', 8), SenseInfo('02153445-n', 4), SenseInfo('03387016-n', 2), SenseInfo('02322213-n', 2), SenseInfo('00284665-n', 1), SenseInfo('10101078-n', 0), SenseInfo('08390157-n', 0), SenseInfo('07094843-n', 0), SenseInfo('03378442-n', 0), SenseInfo('05563266-n', 89), SenseInfo('13650045-n', 81), SenseInfo('08511570-n', 8), SenseInfo('02153445-n', 4), SenseInfo('03387016-n', 2), SenseInfo('02322213-n', 2), SenseInfo('00284665-n', 1), SenseInfo('10101078-n', 0), SenseInfo('08390157-n', 0), SenseInfo('07094843-n', 0), SenseInfo('03378442-n', 0), SenseInfo('05563266-n', 89), SenseInfo('13650045-n', 81), SenseInfo('08511570-n', 8), SenseInfo('02153445-n', 4), SenseInfo('03387016-n', 2), SenseInfo('02322213-n', 2), SenseInfo('00284665-n', 1), SenseInfo('10101078-n', 0), SenseInfo('08390157-n', 0), SenseInfo('07094843-n', 0), SenseInfo('03378442-n', 0) ],
"_accessibility_n_1_rel" : [ SenseInfo('04718999-n', 0), SenseInfo('04655649-n', 0) ],
"_curdle_v_cause_rel" : [ SenseInfo('00457770-v', 0), SenseInfo('00443000-v', 0), SenseInfo('00442847-v', 0) ],
"_gluteal_a_1_rel" : [ SenseInfo('02736276-a', 0) ],
"_asian_n_1_rel" : [ SenseInfo('09641757-n', 0) ],
"_umpteen_q_rel" : [  ],
"_smuggle_v_out_rel" : [ SenseInfo('02345856-v', 3) ],
"_herbaceous_a_1_rel" : [ SenseInfo('02576795-a', 0) ],
"_take_v_back_rel" : [ SenseInfo('02599636-v', 92), SenseInfo('02267989-v', 74), SenseInfo('01999798-v', 73), SenseInfo('01214265-v', 50), SenseInfo('00524682-v', 38), SenseInfo('00624476-v', 36), SenseInfo('02077656-v', 32), SenseInfo('02205272-v', 28), SenseInfo('01842690-v', 26), SenseInfo('00674607-v', 26), SenseInfo('02236124-v', 25), SenseInfo('02394183-v', 22), SenseInfo('00734054-v', 22), SenseInfo('02627934-v', 21), SenseInfo('02109045-v', 21), SenseInfo('01002740-v', 16), SenseInfo('00173338-v', 16), SenseInfo('01156834-v', 15), SenseInfo('00669762-v', 15), SenseInfo('02209936-v', 14), SenseInfo('02206619-v', 13), SenseInfo('01982395-v', 10), SenseInfo('02236624-v', 8), SenseInfo('00523095-v', 7), SenseInfo('00599992-v', 6), SenseInfo('00756076-v', 5), SenseInfo('02075857-v', 4), SenseInfo('01151110-v', 4), SenseInfo('00557404-v', 4), SenseInfo('02717102-v', 2), SenseInfo('02208537-v', 2), SenseInfo('02209745-v', 1), SenseInfo('02208118-v', 1), SenseInfo('02201138-v', 1), SenseInfo('01427127-v', 1), SenseInfo('00758333-v', 1), SenseInfo('02741546-v', 0), SenseInfo('02701210-v', 0), SenseInfo('02590253-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01100830-v', 0), SenseInfo('00087736-v', 0) ],
"_asleep_a_1_rel" : [ SenseInfo('00187736-a', 9), SenseInfo('02103333-a', 0), SenseInfo('00095873-a', 0) ],
"_astronomical_a_1_rel" : [ SenseInfo('02646605-a', 1), SenseInfo('01383582-a', 1), SenseInfo('02646605-a', 1), SenseInfo('01383582-a', 1) ],
"_clerk_n_1_rel" : [ SenseInfo('09928451-n', 7), SenseInfo('10548227-n', 2) ],
"_certain_a_of_rel" : [ SenseInfo('00700884-a', 131), SenseInfo('00336831-a', 16), SenseInfo('00335421-a', 8), SenseInfo('00340239-a', 4), SenseInfo('02087342-a', 0), SenseInfo('00724397-a', 0), SenseInfo('00309740-a', 0), SenseInfo('00700884-a', 131), SenseInfo('00336831-a', 16), SenseInfo('00335421-a', 8), SenseInfo('00340239-a', 4), SenseInfo('02087342-a', 0), SenseInfo('00724397-a', 0), SenseInfo('00309740-a', 0), SenseInfo('00700884-a', 131), SenseInfo('00336831-a', 16), SenseInfo('00335421-a', 8), SenseInfo('00340239-a', 4), SenseInfo('02087342-a', 0), SenseInfo('00724397-a', 0), SenseInfo('00309740-a', 0), SenseInfo('00700884-a', 131), SenseInfo('00336831-a', 16), SenseInfo('00335421-a', 8), SenseInfo('00340239-a', 4), SenseInfo('02087342-a', 0), SenseInfo('00724397-a', 0), SenseInfo('00309740-a', 0) ],
"_original_a_1_rel" : [ SenseInfo('01012503-a', 17), SenseInfo('01853039-a', 8), SenseInfo('01686439-a', 5), SenseInfo('00699207-a', 0), SenseInfo('01012503-a', 17), SenseInfo('01853039-a', 8), SenseInfo('01686439-a', 5), SenseInfo('00699207-a', 0), SenseInfo('01012503-a', 17), SenseInfo('01853039-a', 8), SenseInfo('01686439-a', 5), SenseInfo('00699207-a', 0), SenseInfo('01012503-a', 17), SenseInfo('01853039-a', 8), SenseInfo('01686439-a', 5), SenseInfo('00699207-a', 0), SenseInfo('01012503-a', 17), SenseInfo('01853039-a', 8), SenseInfo('01686439-a', 5), SenseInfo('00699207-a', 0) ],
"_all_q_rel" : [  ],
"_antimicrobial_a_1_rel" : [ SenseInfo('01165474-a', 0) ],
"_d+_n_1_rel" : [ SenseInfo('15092227-n', 0), SenseInfo('13750712-n', 0), SenseInfo('06831498-n', 0) ],
"_statistics_n_1_rel" : [ SenseInfo('06018465-n', 0) ],
"_anabaptist_a_1_rel" : [ SenseInfo('09677427-n', 2) ],
"_tack_v_up_rel" : [ SenseInfo('01357429-v', 3), SenseInfo('01946408-v', 1), SenseInfo('01656788-v', 0), SenseInfo('01331348-v', 0), SenseInfo('01328513-v', 0), SenseInfo('00121678-v', 0) ],
"_sulk_n_1_rel" : [ SenseInfo('07551498-n', 0) ],
"_lighter-than-air_a_1_rel" : [ SenseInfo('01187322-a', 0), SenseInfo('01187322-a', 0), SenseInfo('01187322-a', 0) ],
"_overshadow_v_1_rel" : [ SenseInfo('02744280-v', 1), SenseInfo('02696306-v', 0), SenseInfo('02158196-v', 0), SenseInfo('02744280-v', 1), SenseInfo('02696306-v', 0), SenseInfo('02158196-v', 0) ],
"_immense_a_1_rel" : [ SenseInfo('01387319-a', 5), SenseInfo('01387319-a', 5) ],
"_cite_v_as_rel" : [ SenseInfo('01024190-v', 13), SenseInfo('01023071-v', 4), SenseInfo('01705257-v', 3), SenseInfo('01023259-v', 2), SenseInfo('01023574-v', 0), SenseInfo('01015866-v', 0), SenseInfo('00791134-v', 0), SenseInfo('01024190-v', 13), SenseInfo('01023071-v', 4), SenseInfo('01705257-v', 3), SenseInfo('01023259-v', 2), SenseInfo('01023574-v', 0), SenseInfo('01015866-v', 0), SenseInfo('00791134-v', 0) ],
"_HK$_n_1_rel" : [  ],
"_cyberspace_n_1_rel" : [ SenseInfo('03580615-n', 0) ],
"_ornament_n_1_rel" : [ SenseInfo('03169390-n', 1) ],
"_smack_x_deg_rel" : [ SenseInfo('01414916-v', 2), SenseInfo('02194723-v', 1), SenseInfo('07410745-n', 0), SenseInfo('05715864-n', 0), SenseInfo('04244847-n', 0), SenseInfo('02837416-n', 0), SenseInfo('00138599-n', 0), SenseInfo('00133668-n', 0), SenseInfo('00277585-r', 0), SenseInfo('02194495-v', 0), SenseInfo('01431879-v', 0), SenseInfo('01197208-v', 0) ],
"_progress_n_1_rel" : [ SenseInfo('00249501-n', 24), SenseInfo('00282050-n', 6), SenseInfo('07445265-n', 5) ],
"_fungicide_n_1_rel" : [ SenseInfo('02720201-n', 0) ],
"_infirmary_n_1_rel" : [ SenseInfo('03540595-n', 1) ],
"_salesman_n_1_rel" : [ SenseInfo('10548537-n', 20) ],
"_petroleum_n_1_rel" : [ SenseInfo('14980579-n', 0) ],
"_balcony_n_1_rel" : [ SenseInfo('02777927-n', 0), SenseInfo('02777734-n', 0) ],
"_over+with_a_1_rel" : [  ],
"_take_v_away_rel" : [ SenseInfo('02599636-v', 92), SenseInfo('02267989-v', 74), SenseInfo('01999798-v', 73), SenseInfo('01214265-v', 50), SenseInfo('00524682-v', 38), SenseInfo('00624476-v', 36), SenseInfo('02077656-v', 32), SenseInfo('02205272-v', 28), SenseInfo('01842690-v', 26), SenseInfo('00674607-v', 26), SenseInfo('02236124-v', 25), SenseInfo('02394183-v', 22), SenseInfo('00734054-v', 22), SenseInfo('02627934-v', 21), SenseInfo('02109045-v', 21), SenseInfo('01002740-v', 16), SenseInfo('00173338-v', 16), SenseInfo('01156834-v', 15), SenseInfo('00669762-v', 15), SenseInfo('02209936-v', 14), SenseInfo('02206619-v', 13), SenseInfo('01982395-v', 10), SenseInfo('02236624-v', 8), SenseInfo('00523095-v', 7), SenseInfo('00599992-v', 6), SenseInfo('00756076-v', 5), SenseInfo('02075857-v', 4), SenseInfo('01151110-v', 4), SenseInfo('00557404-v', 4), SenseInfo('02717102-v', 2), SenseInfo('02208537-v', 2), SenseInfo('02209745-v', 1), SenseInfo('02208118-v', 1), SenseInfo('02201138-v', 1), SenseInfo('01427127-v', 1), SenseInfo('00758333-v', 1), SenseInfo('02741546-v', 0), SenseInfo('02701210-v', 0), SenseInfo('02590253-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01100830-v', 0), SenseInfo('00087736-v', 0) ],
"_unseen_a_1_rel" : [ SenseInfo('01610261-a', 2), SenseInfo('01610261-a', 2) ],
"_sheriff_n_1_rel" : [ SenseInfo('10589140-n', 7) ],
"_troubling_a_for_rel" : [ SenseInfo('01189386-a', 0), SenseInfo('01189386-a', 0), SenseInfo('01189386-a', 0) ],
"_assemble_v_cause_rel" : [ SenseInfo('01656788-v', 15), SenseInfo('02428924-v', 13), SenseInfo('02598143-v', 1) ],
"_bear_n_1_rel" : [ SenseInfo('02131653-n', 1), SenseInfo('09845191-n', 0), SenseInfo('02131653-n', 1), SenseInfo('09845191-n', 0) ],
"_constituent_a_1_rel" : [ SenseInfo('00901345-a', 0) ],
"_key_v_1_rel" : [ SenseInfo('00652346-v', 1), SenseInfo('02338227-v', 0), SenseInfo('01520655-v', 0), SenseInfo('00483656-v', 0), SenseInfo('00482749-v', 0) ],
"_agree_v_with_rel" : [ SenseInfo('00805376-v', 62), SenseInfo('00764222-v', 25), SenseInfo('02657219-v', 4), SenseInfo('02700104-v', 1), SenseInfo('02741793-v', 0), SenseInfo('02291135-v', 0), SenseInfo('01035530-v', 0) ],
"_stare_v_at_rel" : [ SenseInfo('02132745-v', 82), SenseInfo('00033406-v', 4) ],
"_drop_v_in_rel" : [ SenseInfo('01977701-v', 36), SenseInfo('01976841-v', 21), SenseInfo('00432683-v', 12), SenseInfo('01985923-v', 7), SenseInfo('02403920-v', 6), SenseInfo('00941446-v', 6), SenseInfo('00363110-v', 5), SenseInfo('01489465-v', 3), SenseInfo('01258302-v', 2), SenseInfo('01100008-v', 2), SenseInfo('02267060-v', 1), SenseInfo('00393534-v', 1), SenseInfo('02717472-v', 0), SenseInfo('02465939-v', 0), SenseInfo('01611516-v', 0), SenseInfo('01513430-v', 0), SenseInfo('01200661-v', 0), SenseInfo('00615615-v', 0), SenseInfo('00614999-v', 0), SenseInfo('00548616-v', 0), SenseInfo('00148341-v', 0), SenseInfo('00092293-v', 0), SenseInfo('00057764-v', 0), SenseInfo('01977701-v', 36), SenseInfo('01976841-v', 21), SenseInfo('00432683-v', 12), SenseInfo('01985923-v', 7), SenseInfo('02403920-v', 6), SenseInfo('00941446-v', 6), SenseInfo('00363110-v', 5), SenseInfo('01489465-v', 3), SenseInfo('01258302-v', 2), SenseInfo('01100008-v', 2), SenseInfo('02267060-v', 1), SenseInfo('00393534-v', 1), SenseInfo('02717472-v', 0), SenseInfo('02465939-v', 0), SenseInfo('01611516-v', 0), SenseInfo('01513430-v', 0), SenseInfo('01200661-v', 0), SenseInfo('00615615-v', 0), SenseInfo('00614999-v', 0), SenseInfo('00548616-v', 0), SenseInfo('00148341-v', 0), SenseInfo('00092293-v', 0), SenseInfo('00057764-v', 0) ],
"_non-com_n_1_rel" : [ SenseInfo('10360747-n', 1) ],
"_igneous_a_1_rel" : [ SenseInfo('02852265-a', 0), SenseInfo('01354925-a', 0), SenseInfo('01248958-a', 0) ],
"_slant_v_cause_rel" : [ SenseInfo('02692558-v', 1), SenseInfo('00680485-v', 1), SenseInfo('02038357-v', 0), SenseInfo('01884577-v', 0) ],
"_fatten_v_cause_rel" : [ SenseInfo('01194938-v', 1), SenseInfo('01194938-v', 1) ],
"_decease_v_1_rel" : [ SenseInfo('00358431-v', 0) ],
"_miller_n_1_rel" : [ SenseInfo('11180209-n', 0), SenseInfo('11180029-n', 0), SenseInfo('11179923-n', 0), SenseInfo('10318087-n', 0), SenseInfo('03766044-n', 0), SenseInfo('02283617-n', 0) ],
"_do_v_suffice_rel" : [ SenseInfo('02560585-v', 526), SenseInfo('01712704-v', 173), SenseInfo('02561995-v', 134), SenseInfo('02617567-v', 58), SenseInfo('01645601-v', 35), SenseInfo('02568672-v', 20), SenseInfo('02669789-v', 11), SenseInfo('01619014-v', 9), SenseInfo('00010435-v', 3), SenseInfo('02709107-v', 2), SenseInfo('02523221-v', 2), SenseInfo('00038849-v', 2), SenseInfo('01841772-v', 1) ],
"_earth_n_1_rel" : [ SenseInfo('09270894-n', 51), SenseInfo('14842992-n', 20), SenseInfo('09334396-n', 20), SenseInfo('08562067-n', 3), SenseInfo('14844414-n', 0), SenseInfo('05670972-n', 0), SenseInfo('03462747-n', 0) ],
"_concomitant_n_1_rel" : [ SenseInfo('07284554-n', 0) ],
"_wait_n_1_rel" : [ SenseInfo('15272029-n', 2), SenseInfo('01063939-n', 2) ],
"_employ_v_as_rel" : [ SenseInfo('01158872-v', 42), SenseInfo('02409412-v', 14) ],
"_whilst_p_1_rel" : [  ],
"_bowel_n_1_rel" : [ SenseInfo('05534333-n', 0) ],
"_coinage_n_1_rel" : [ SenseInfo('13387877-n', 0), SenseInfo('06294441-n', 0), SenseInfo('00940560-n', 0) ],
"_cellar_n_1_rel" : [ SenseInfo('02800497-n', 9), SenseInfo('04108137-n', 0), SenseInfo('02991847-n', 0) ],
"_treat_v_to_rel" : [ SenseInfo('02514187-v', 30), SenseInfo('00515154-v', 23), SenseInfo('00078760-v', 17), SenseInfo('01033527-v', 10), SenseInfo('02261642-v', 3), SenseInfo('01176232-v', 0), SenseInfo('00762720-v', 0), SenseInfo('00651145-v', 0) ],
"_cubic_a_1_rel" : [ SenseInfo('00657198-a', 0) ],
"_matrix_n_1_rel" : [ SenseInfo('08267640-n', 1), SenseInfo('14949227-n', 0), SenseInfo('09349055-n', 0), SenseInfo('05582305-n', 0), SenseInfo('05582191-n', 0), SenseInfo('03730655-n', 0) ],
"_vitriol_n_1_rel" : [ SenseInfo('15093482-n', 0), SenseInfo('06721604-n', 0) ],
"_exploit_v_1_rel" : [ SenseInfo('01162754-v', 8), SenseInfo('01164273-v', 3), SenseInfo('02409148-v', 0) ],
"_eraser_n_1_rel" : [ SenseInfo('03294833-n', 0) ],
"_grateful_a_1_rel" : [ SenseInfo('01146493-a', 10), SenseInfo('01801327-a', 0), SenseInfo('01146493-a', 10), SenseInfo('01801327-a', 0), SenseInfo('01146493-a', 10), SenseInfo('01801327-a', 0), SenseInfo('01146493-a', 10), SenseInfo('01801327-a', 0) ],
"_veteran_n_of_rel" : [ SenseInfo('10749528-n', 7), SenseInfo('10749353-n', 5), SenseInfo('10749123-n', 5), SenseInfo('10749528-n', 7), SenseInfo('10749353-n', 5), SenseInfo('10749123-n', 5), SenseInfo('10749528-n', 7), SenseInfo('10749353-n', 5), SenseInfo('10749123-n', 5) ],
"_moveable_a_1_rel" : [ SenseInfo('01523724-a', 0) ],
"_challenge_v_to_rel" : [ SenseInfo('00869126-v', 12), SenseInfo('00868591-v', 7), SenseInfo('00808343-v', 1), SenseInfo('00808162-v', 1) ],
"_conservative_n_1_rel" : [ SenseInfo('09957156-n', 3), SenseInfo('09957523-n', 0) ],
"_rhythmical_a_1_rel" : [ SenseInfo('02019021-a', 1), SenseInfo('02019021-a', 1) ],
"_chockful_a_1_rel" : [ SenseInfo('01084297-a', 1) ],
"_disappointed_a_at-by-in_rel" : [ SenseInfo('02333976-a', 4), SenseInfo('02333976-a', 4), SenseInfo('02333976-a', 4) ],
"_admit_n_1_rel" : [  ],
"_knock_v_over_rel" : [ SenseInfo('01238640-v', 7), SenseInfo('01414467-v', 6), SenseInfo('01239619-v', 4), SenseInfo('02185373-v', 0), SenseInfo('02178866-v', 0), SenseInfo('00826509-v', 0) ],
"_grown+up_a_1_rel" : [ SenseInfo('01488616-a', 0) ],
"_bummer_n_1_rel" : [ SenseInfo('14406900-n', 0), SenseInfo('14311709-n', 0) ],
"_brilliance_n_1_rel" : [ SenseInfo('04952570-n', 1), SenseInfo('04814238-n', 1), SenseInfo('05619743-n', 0) ],
"_sulphuric_a_1_rel" : [ SenseInfo('03121394-a', 0) ],
"_just+about_x_deg_rel" : [ SenseInfo('00007015-r', 2) ],
"_repellent_n_1_rel" : [ SenseInfo('14920586-n', 0), SenseInfo('14920388-n', 0), SenseInfo('05196054-n', 0) ],
"_quite_x_deg_rel" : [ SenseInfo('00018781-r', 57), SenseInfo('00018577-r', 47), SenseInfo('00018918-r', 6), SenseInfo('00019181-r', 0) ],
"_IMHO_a_1_rel" : [  ],
"_farmhouse_n_1_rel" : [ SenseInfo('03322836-n', 3) ],
"_postulate_v_1_rel" : [ SenseInfo('00756898-v', 3), SenseInfo('00716758-v', 1), SenseInfo('02627934-v', 0), SenseInfo('00756898-v', 3), SenseInfo('00716758-v', 1), SenseInfo('02627934-v', 0) ],
"_appall_v_1_rel" : [ SenseInfo('01810447-v', 0), SenseInfo('01782650-v', 0), SenseInfo('01810447-v', 0), SenseInfo('01782650-v', 0), SenseInfo('01810447-v', 0), SenseInfo('01782650-v', 0), SenseInfo('01810447-v', 0), SenseInfo('01782650-v', 0) ],
"_apparent_a_to_rel" : [ SenseInfo('01618376-a', 19), SenseInfo('01873985-a', 8), SenseInfo('01618376-a', 19), SenseInfo('01873985-a', 8) ],
"_approximately_x_deg_rel" : [ SenseInfo('00007015-r', 26), SenseInfo('00007015-r', 26), SenseInfo('00007015-r', 26), SenseInfo('00007015-r', 26), SenseInfo('00007015-r', 26) ],
"_by+and+large_a_1_rel" : [  ],
"_soaking+wet_a_1_rel" : [  ],
"_hog_n_1_rel" : [ SenseInfo('10179649-n', 0), SenseInfo('02412787-n', 0), SenseInfo('02395406-n', 0) ],
"_civics_n_1_rel" : [ SenseInfo('06143454-n', 0) ],
"_kinship_n_1_rel" : [ SenseInfo('13811410-n', 2), SenseInfo('13812607-n', 1) ],
"_conjecture_n_1_rel" : [ SenseInfo('05891783-n', 1), SenseInfo('06782680-n', 0), SenseInfo('05773923-n', 0), SenseInfo('05891783-n', 1), SenseInfo('06782680-n', 0), SenseInfo('05773923-n', 0) ],
"_ifs_n_1_rel" : [  ],
"_see_n_1_rel" : [ SenseInfo('08586825-n', 0) ],
"_sensitivity_n_1_rel" : [ SenseInfo('05652926-n', 8), SenseInfo('05019661-n', 4), SenseInfo('07512465-n', 3), SenseInfo('14531772-n', 0), SenseInfo('04842993-n', 0) ],
"_punctuality_n_1_rel" : [ SenseInfo('05047778-n', 1) ],
"_mask_v_out_rel" : [ SenseInfo('02147603-v', 1), SenseInfo('01358328-v', 1), SenseInfo('02158587-v', 0), SenseInfo('01358855-v', 0), SenseInfo('01358737-v', 0) ],
"_bahn+card_n_1_rel" : [  ],
"_deforestation_n_of_rel" : [ SenseInfo('14519097-n', 0), SenseInfo('01262441-n', 0) ],
"_crown_n_1_rel" : [ SenseInfo('06884097-n', 1), SenseInfo('05308141-n', 1), SenseInfo('03138856-n', 1), SenseInfo('03138669-n', 1), SenseInfo('03138534-n', 1), SenseInfo('13389864-n', 0), SenseInfo('13128003-n', 0), SenseInfo('08617963-n', 0), SenseInfo('06705891-n', 0), SenseInfo('05539595-n', 0), SenseInfo('03139089-n', 0), SenseInfo('03138981-n', 0) ],
"_telescopic_a_1_rel" : [ SenseInfo('02517002-a', 0), SenseInfo('02157936-a', 0), SenseInfo('00466077-a', 0) ],
"_orienteerer_n_1_rel" : [  ],
"_joy_n_1_rel" : [ SenseInfo('07527352-n', 19), SenseInfo('05829782-n', 5) ],
"_spoils_n_1_rel" : [ SenseInfo('13262462-n', 0), SenseInfo('01263018-n', 0), SenseInfo('00966869-n', 0), SenseInfo('13262462-n', 0), SenseInfo('01263018-n', 0), SenseInfo('00966869-n', 0) ],
"_vitally_x_rel" : [ SenseInfo('00090551-r', 5) ],
"_sizzle_n_1_rel" : [ SenseInfo('07393919-n', 0) ],
"_guess_v_1_rel" : [ SenseInfo('00631737-v', 42), SenseInfo('00916909-v', 10), SenseInfo('00672433-v', 6), SenseInfo('00636061-v', 6), SenseInfo('00631737-v', 42), SenseInfo('00916909-v', 10), SenseInfo('00672433-v', 6), SenseInfo('00636061-v', 6), SenseInfo('00631737-v', 42), SenseInfo('00916909-v', 10), SenseInfo('00672433-v', 6), SenseInfo('00636061-v', 6) ],
"_conform_v_cause_rel" : [ SenseInfo('02662979-v', 1), SenseInfo('00150287-v', 1) ],
"_gunman_n_1_rel" : [ SenseInfo('10152083-n', 3), SenseInfo('10593392-n', 0) ],
"_heart_n_i_rel" : [ SenseInfo('05919263-n', 42), SenseInfo('05388805-n', 25), SenseInfo('04857490-n', 9), SenseInfo('08523483-n', 5), SenseInfo('05921123-n', 2), SenseInfo('04624826-n', 1), SenseInfo('13865904-n', 0), SenseInfo('07651905-n', 0), SenseInfo('07544647-n', 0), SenseInfo('03507048-n', 0) ],
"_entertainment_n_1_rel" : [ SenseInfo('00429048-n', 6) ],
"_break_v_in_rel" : [ SenseInfo('00364064-v', 15), SenseInfo('00334186-v', 13), SenseInfo('00258665-v', 9), SenseInfo('01369758-v', 8), SenseInfo('00334996-v', 8), SenseInfo('02566528-v', 5), SenseInfo('02073233-v', 4), SenseInfo('02029369-v', 4), SenseInfo('01785395-v', 4), SenseInfo('00362348-v', 4), SenseInfo('02570684-v', 3), SenseInfo('00202569-v', 3), SenseInfo('02668523-v', 2), SenseInfo('01106864-v', 2), SenseInfo('00933821-v', 2), SenseInfo('00558536-v', 2), SenseInfo('00434374-v', 2), SenseInfo('02535716-v', 1), SenseInfo('02030764-v', 1), SenseInfo('01972976-v', 1), SenseInfo('00390215-v', 1), SenseInfo('00202784-v', 1), SenseInfo('02746617-v', 0), SenseInfo('02746449-v', 0), SenseInfo('02681639-v', 0), SenseInfo('02681524-v', 0), SenseInfo('02625187-v', 0), SenseInfo('02600082-v', 0), SenseInfo('02559395-v', 0), SenseInfo('02478469-v', 0), SenseInfo('02431320-v', 0), SenseInfo('02399331-v', 0), SenseInfo('02318165-v', 0), SenseInfo('02101373-v', 0), SenseInfo('01991347-v', 0), SenseInfo('01989053-v', 0), SenseInfo('01896484-v', 0), SenseInfo('01610666-v', 0), SenseInfo('01610463-v', 0), SenseInfo('01597995-v', 0), SenseInfo('01557646-v', 0), SenseInfo('01369346-v', 0), SenseInfo('01298931-v', 0), SenseInfo('01228524-v', 0), SenseInfo('01228396-v', 0), SenseInfo('00935987-v', 0), SenseInfo('00779061-v', 0), SenseInfo('00778745-v', 0), SenseInfo('00744439-v', 0), SenseInfo('00738440-v', 0), SenseInfo('00738314-v', 0), SenseInfo('00551412-v', 0), SenseInfo('00339464-v', 0), SenseInfo('00336260-v', 0), SenseInfo('00258366-v', 0), SenseInfo('00155046-v', 0), SenseInfo('00107739-v', 0), SenseInfo('00107604-v', 0), SenseInfo('00030463-v', 0), SenseInfo('00364064-v', 15), SenseInfo('00334186-v', 13), SenseInfo('00258665-v', 9), SenseInfo('01369758-v', 8), SenseInfo('00334996-v', 8), SenseInfo('02566528-v', 5), SenseInfo('02073233-v', 4), SenseInfo('02029369-v', 4), SenseInfo('01785395-v', 4), SenseInfo('00362348-v', 4), SenseInfo('02570684-v', 3), SenseInfo('00202569-v', 3), SenseInfo('02668523-v', 2), SenseInfo('01106864-v', 2), SenseInfo('00933821-v', 2), SenseInfo('00558536-v', 2), SenseInfo('00434374-v', 2), SenseInfo('02535716-v', 1), SenseInfo('02030764-v', 1), SenseInfo('01972976-v', 1), SenseInfo('00390215-v', 1), SenseInfo('00202784-v', 1), SenseInfo('02746617-v', 0), SenseInfo('02746449-v', 0), SenseInfo('02681639-v', 0), SenseInfo('02681524-v', 0), SenseInfo('02625187-v', 0), SenseInfo('02600082-v', 0), SenseInfo('02559395-v', 0), SenseInfo('02478469-v', 0), SenseInfo('02431320-v', 0), SenseInfo('02399331-v', 0), SenseInfo('02318165-v', 0), SenseInfo('02101373-v', 0), SenseInfo('01991347-v', 0), SenseInfo('01989053-v', 0), SenseInfo('01896484-v', 0), SenseInfo('01610666-v', 0), SenseInfo('01610463-v', 0), SenseInfo('01597995-v', 0), SenseInfo('01557646-v', 0), SenseInfo('01369346-v', 0), SenseInfo('01298931-v', 0), SenseInfo('01228524-v', 0), SenseInfo('01228396-v', 0), SenseInfo('00935987-v', 0), SenseInfo('00779061-v', 0), SenseInfo('00778745-v', 0), SenseInfo('00744439-v', 0), SenseInfo('00738440-v', 0), SenseInfo('00738314-v', 0), SenseInfo('00551412-v', 0), SenseInfo('00339464-v', 0), SenseInfo('00336260-v', 0), SenseInfo('00258366-v', 0), SenseInfo('00155046-v', 0), SenseInfo('00107739-v', 0), SenseInfo('00107604-v', 0), SenseInfo('00030463-v', 0) ],
"_brush_n_1_rel" : [ SenseInfo('08437515-n', 11), SenseInfo('02908217-n', 8), SenseInfo('07413714-n', 1), SenseInfo('02908605-n', 0), SenseInfo('02157954-n', 0), SenseInfo('00959376-n', 0), SenseInfo('00656386-n', 0), SenseInfo('00256620-n', 0), SenseInfo('00039545-n', 0) ],
"_disguise_n_1_rel" : [ SenseInfo('04679074-n', 2), SenseInfo('03206718-n', 0), SenseInfo('01049266-n', 0) ],
"_restless_a_1_rel" : [ SenseInfo('00590271-a', 2), SenseInfo('01563578-a', 1), SenseInfo('01922562-a', 0), SenseInfo('00590271-a', 2), SenseInfo('01563578-a', 1), SenseInfo('01922562-a', 0) ],
"_leader_n_of_rel" : [ SenseInfo('09623038-n', 23), SenseInfo('03234795-n', 0) ],
"_fulfill_v_1_rel" : [ SenseInfo('01640855-v', 10), SenseInfo('02671880-v', 3), SenseInfo('01183573-v', 3), SenseInfo('01640855-v', 10), SenseInfo('02671880-v', 3), SenseInfo('01183573-v', 3), SenseInfo('01640855-v', 10), SenseInfo('02671880-v', 3), SenseInfo('01183573-v', 3), SenseInfo('01640855-v', 10), SenseInfo('02671880-v', 3), SenseInfo('01183573-v', 3) ],
"_dropping_n_1_rel" : [ SenseInfo('02486628-a', 0) ],
"_bedding_n_1_rel" : [ SenseInfo('02820210-n', 3), SenseInfo('02820432-n', 0) ],
"_delimit_v_1_rel" : [ SenseInfo('02611630-v', 1), SenseInfo('02693842-v', 0), SenseInfo('00730301-v', 0) ],
"_beetle_n_1_rel" : [ SenseInfo('02164464-n', 1), SenseInfo('03715386-n', 0) ],
"_past_p_rel" : [ SenseInfo('15120823-n', 42), SenseInfo('01727926-a', 29), SenseInfo('00417787-r', 15), SenseInfo('15141693-n', 5), SenseInfo('01296091-a', 4), SenseInfo('06330262-n', 1), SenseInfo('15120823-n', 42), SenseInfo('01727926-a', 29), SenseInfo('00417787-r', 15), SenseInfo('15141693-n', 5), SenseInfo('01296091-a', 4), SenseInfo('06330262-n', 1) ],
"_desertification_n_of_rel" : [ SenseInfo('13462989-n', 0) ],
"_regulatory_a_1_rel" : [ SenseInfo('02004685-a', 1) ],
"_institute_v_1_rel" : [ SenseInfo('01647229-v', 9), SenseInfo('01618547-v', 5) ],
"_exactly_x_rel" : [ SenseInfo('00158309-r', 37), SenseInfo('00368663-r', 2), SenseInfo('00368287-r', 0) ],
"_egret_n_1_rel" : [ SenseInfo('02008796-n', 0) ],
"_audition_n_1_rel" : [ SenseInfo('05657718-n', 0), SenseInfo('00794614-n', 0) ],
"_fragment_v_1_rel" : [ SenseInfo('00338071-v', 0) ],
"_amphitheater_n_1_rel" : [ SenseInfo('02705201-n', 0), SenseInfo('02704949-n', 0) ],
"_latin+american_a_1_rel" : [ SenseInfo('02754995-a', 3) ],
"_contract_v_out_rel" : [ SenseInfo('00888786-v', 8), SenseInfo('02409941-v', 3), SenseInfo('01387786-v', 2), SenseInfo('00087736-v', 2), SenseInfo('00240571-v', 1), SenseInfo('01279474-v', 0), SenseInfo('00365188-v', 0), SenseInfo('00305109-v', 0), SenseInfo('00243900-v', 0), SenseInfo('00888786-v', 8), SenseInfo('02409941-v', 3), SenseInfo('01387786-v', 2), SenseInfo('00087736-v', 2), SenseInfo('00240571-v', 1), SenseInfo('01279474-v', 0), SenseInfo('00365188-v', 0), SenseInfo('00305109-v', 0), SenseInfo('00243900-v', 0) ],
"_plenty_n_of_rel" : [ SenseInfo('05115568-n', 13), SenseInfo('13774404-n', 2), SenseInfo('05115568-n', 13), SenseInfo('13774404-n', 2) ],
"_swoop_v_1_rel" : [ SenseInfo('02064358-v', 8), SenseInfo('02064759-v', 0), SenseInfo('01440010-v', 0) ],
"_worthwhile_a_1_rel" : [ SenseInfo('02587936-a', 3), SenseInfo('02587936-a', 3), SenseInfo('02587936-a', 3), SenseInfo('02587936-a', 3) ],
"_phone_n_1_rel" : [ SenseInfo('04401088-n', 13), SenseInfo('07111047-n', 0), SenseInfo('03261776-n', 0) ],
"_firefighter_n_1_rel" : [ SenseInfo('10091651-n', 0) ],
"_strapwork_n_1_rel" : [  ],
"_sputter_v_1_rel" : [ SenseInfo('02186360-v', 1), SenseInfo('00556001-v', 1), SenseInfo('01921772-v', 0), SenseInfo('00986897-v', 0), SenseInfo('00102303-v', 0), SenseInfo('02186360-v', 1), SenseInfo('00556001-v', 1), SenseInfo('01921772-v', 0), SenseInfo('00986897-v', 0), SenseInfo('00102303-v', 0) ],
"_arabian_n_1_rel" : [ SenseInfo('09729530-n', 0), SenseInfo('02379908-n', 0) ],
"_pile_v_up_rel" : [ SenseInfo('01503404-v', 8), SenseInfo('02064131-v', 2), SenseInfo('01434822-v', 0), SenseInfo('01503404-v', 8), SenseInfo('02064131-v', 2), SenseInfo('01434822-v', 0) ],
"_workmanship_n_1_rel" : [ SenseInfo('05638063-n', 0) ],
"_engrossed_a_in_rel" : [ SenseInfo('00163948-a', 4), SenseInfo('02285147-a', 1) ],
"_sensibility_n_1_rel" : [ SenseInfo('05678148-n', 4), SenseInfo('07512848-n', 2), SenseInfo('05652926-n', 0) ],
"_tease_v_apart_rel" : [ SenseInfo('01803380-v', 2), SenseInfo('00850501-v', 1), SenseInfo('01803641-v', 0), SenseInfo('01572386-v', 0), SenseInfo('01531635-v', 0), SenseInfo('01463792-v', 0), SenseInfo('01356256-v', 0), SenseInfo('00852506-v', 0), SenseInfo('00040188-v', 0) ],
"_professional_a_1_rel" : [ SenseInfo('01868724-a', 12), SenseInfo('02839695-a', 11), SenseInfo('01870100-a', 6), SenseInfo('02839505-a', 4), SenseInfo('02556402-a', 1), SenseInfo('01868724-a', 12), SenseInfo('02839695-a', 11), SenseInfo('01870100-a', 6), SenseInfo('02839505-a', 4), SenseInfo('02556402-a', 1) ],
"_delayed_a_1_rel" : [ SenseInfo('01841295-a', 0) ],
"_erratum_n_1_rel" : [ SenseInfo('06769670-n', 0) ],
"_grade_v_1_rel" : [ SenseInfo('00658052-v', 1), SenseInfo('01307609-v', 0), SenseInfo('00657728-v', 0), SenseInfo('00657550-v', 0) ],
"_epistolatory_a_1_rel" : [ SenseInfo('01046553-a', 1) ],
"_sculpture_n_1_rel" : [ SenseInfo('04157320-n', 9), SenseInfo('00937656-n', 3) ],
"_including_p_rel" : [  ],
"_other_n_1_rel" : [ SenseInfo('02069355-a', 483), SenseInfo('01730820-a', 8), SenseInfo('01729384-a', 0), SenseInfo('00969333-a', 0) ],
"_needless_a_1_rel" : [ SenseInfo('01582049-a', 2) ],
"_shiver_n_1_rel" : [ SenseInfo('00867983-n', 1), SenseInfo('07520112-n', 0) ],
"_ensure_v_1_rel" : [ SenseInfo('00890590-v', 6), SenseInfo('00662589-v', 2), SenseInfo('00890590-v', 6), SenseInfo('00662589-v', 2), SenseInfo('00890590-v', 6), SenseInfo('00662589-v', 2), SenseInfo('00890590-v', 6), SenseInfo('00662589-v', 2) ],
"_dry_v_cause_rel" : [ SenseInfo('00218475-v', 12), SenseInfo('00219403-v', 11) ],
"_freehold_n_1_rel" : [ SenseInfo('13243261-n', 0), SenseInfo('13243134-n', 0) ],
"_dislodge_v_cause_rel" : [ SenseInfo('01528522-v', 2), SenseInfo('01883344-v', 0), SenseInfo('01527508-v', 0) ],
"_cheek-to-jowl_a_1_rel" : [  ],
"_congressman_n_1_rel" : [ SenseInfo('09955781-n', 3) ],
"_jam_v_1_rel" : [ SenseInfo('02064131-v', 1), SenseInfo('01993668-v', 1), SenseInfo('01492944-v', 1), SenseInfo('01057034-v', 1), SenseInfo('01525177-v', 0), SenseInfo('01524298-v', 0), SenseInfo('01476483-v', 0), SenseInfo('02064131-v', 1), SenseInfo('01993668-v', 1), SenseInfo('01492944-v', 1), SenseInfo('01057034-v', 1), SenseInfo('01525177-v', 0), SenseInfo('01524298-v', 0), SenseInfo('01476483-v', 0), SenseInfo('02064131-v', 1), SenseInfo('01993668-v', 1), SenseInfo('01492944-v', 1), SenseInfo('01057034-v', 1), SenseInfo('01525177-v', 0), SenseInfo('01524298-v', 0), SenseInfo('01476483-v', 0) ],
"_breezy_a_1_rel" : [ SenseInfo('00805566-a', 0), SenseInfo('00305225-a', 0), SenseInfo('00805566-a', 0), SenseInfo('00305225-a', 0), SenseInfo('00805566-a', 0), SenseInfo('00305225-a', 0), SenseInfo('00805566-a', 0), SenseInfo('00305225-a', 0), SenseInfo('00805566-a', 0), SenseInfo('00305225-a', 0), SenseInfo('00805566-a', 0), SenseInfo('00305225-a', 0), SenseInfo('00805566-a', 0), SenseInfo('00305225-a', 0) ],
"_tint_n_of_rel" : [ SenseInfo('04959230-n', 1) ],
"_footrope_n_1_rel" : [  ],
"_tractable_a_1_rel" : [ SenseInfo('02451113-a', 0), SenseInfo('02362499-a', 0) ],
"_diaphragm_n_1_rel" : [ SenseInfo('03189083-n', 5), SenseInfo('05318606-n', 2), SenseInfo('03189461-n', 0), SenseInfo('03189311-n', 0) ],
"_mystify_v_1_rel" : [ SenseInfo('00622384-v', 1), SenseInfo('00518653-v', 0), SenseInfo('00622384-v', 1), SenseInfo('00518653-v', 0), SenseInfo('00622384-v', 1), SenseInfo('00518653-v', 0) ],
"_gyration_n_1_rel" : [ SenseInfo('07440979-n', 1), SenseInfo('00342755-n', 0), SenseInfo('07440979-n', 1), SenseInfo('00342755-n', 0) ],
"_pepper_n_1_rel" : [ SenseInfo('13149506-n', 0), SenseInfo('12900462-n', 0), SenseInfo('07815588-n', 0), SenseInfo('07720442-n', 0) ],
"_bang_n_1_rel" : [ SenseInfo('07410207-n', 2), SenseInfo('07376257-n', 2), SenseInfo('05258985-n', 1), SenseInfo('07528470-n', 0), SenseInfo('00064504-n', 0) ],
"_frost_n_1_rel" : [ SenseInfo('14915622-n', 1), SenseInfo('11440521-n', 1), SenseInfo('13485270-n', 0), SenseInfo('10983931-n', 0) ],
"_mainframe_n_1_rel" : [ SenseInfo('03711711-n', 0), SenseInfo('02995345-n', 0) ],
"_lone_a_1_rel" : [ SenseInfo('02251212-a', 1), SenseInfo('02250430-a', 1), SenseInfo('02214736-a', 0) ],
"_dribble_n_1_rel" : [ SenseInfo('07432559-n', 0), SenseInfo('05416678-n', 0), SenseInfo('00478647-n', 0) ],
"_undersea_a_1_rel" : [ SenseInfo('02472137-a', 1) ],
"_run-down_a_1_rel" : [ SenseInfo('02581530-a', 1), SenseInfo('01092889-a', 1), SenseInfo('02581530-a', 1), SenseInfo('01092889-a', 1) ],
"_hummingbird_n_1_rel" : [ SenseInfo('01833805-n', 0) ],
"_unaccustomed_a_1_rel" : [ SenseInfo('00024834-a', 0), SenseInfo('00491320-a', 0), SenseInfo('00024834-a', 0), SenseInfo('00491320-a', 0) ],
"_wet_v_1_rel" : [ SenseInfo('00214951-v', 4), SenseInfo('00072730-v', 0) ],
"_function_v_1_rel" : [ SenseInfo('01525666-v', 9), SenseInfo('02670890-v', 3), SenseInfo('01096497-v', 1) ],
"_kimchi_n_1_rel" : [  ],
"_latinate_a_1_rel" : [ SenseInfo('02904691-a', 0) ],
"_saddle_v_1_rel" : [ SenseInfo('01492422-v', 1), SenseInfo('01490814-v', 1), SenseInfo('00750532-v', 1) ],
"_wire_v_1_rel" : [ SenseInfo('02354536-v', 3), SenseInfo('01007222-v', 2), SenseInfo('01599052-v', 1), SenseInfo('01599325-v', 0), SenseInfo('00505802-v', 0), SenseInfo('02354536-v', 3), SenseInfo('01007222-v', 2), SenseInfo('01599052-v', 1), SenseInfo('01599325-v', 0), SenseInfo('00505802-v', 0) ],
"_hut+to+hut_a_1_rel" : [  ],
"_jackdaw_n_1_rel" : [ SenseInfo('01579578-n', 1) ],
"_battle_v_1_rel" : [ SenseInfo('01092366-v', 6) ],
"_peace+and+quiet_n_1_rel" : [  ],
"_discourteous_a_1_rel" : [ SenseInfo('00640283-a', 1), SenseInfo('00642152-a', 0) ],
"_time+and+again_a_1_rel" : [  ],
"_material_a_1_rel" : [ SenseInfo('02577734-a', 5), SenseInfo('00626800-a', 3), SenseInfo('01487627-a', 1), SenseInfo('01779193-a', 1), SenseInfo('00629997-a', 0), SenseInfo('00625393-a', 0), SenseInfo('02577734-a', 5), SenseInfo('00626800-a', 3), SenseInfo('01487627-a', 1), SenseInfo('01779193-a', 1), SenseInfo('00629997-a', 0), SenseInfo('00625393-a', 0) ],
"_enumeration_n_of_rel" : [ SenseInfo('06490887-n', 0), SenseInfo('00634586-n', 0) ],
"_deform_v_1_rel" : [ SenseInfo('01584875-v', 0), SenseInfo('01350699-v', 0), SenseInfo('01280014-v', 0), SenseInfo('00477665-v', 0), SenseInfo('00476744-v', 0), SenseInfo('00140967-v', 0) ],
"_twirling_a_1_rel" : [  ],
"_mother+in+law_n_1_rel" : [ SenseInfo('10333317-n', 0), SenseInfo('10333317-n', 0) ],
"_nag_v_1_rel" : [ SenseInfo('00844941-v', 2), SenseInfo('01766638-v', 1), SenseInfo('00610928-v', 0), SenseInfo('00844941-v', 2), SenseInfo('01766638-v', 1), SenseInfo('00610928-v', 0) ],
"_gotcha_a_1_rel" : [  ],
"_susceptibility_n_1_rel" : [ SenseInfo('14530061-n', 2) ],
"_found_v_1_rel" : [ SenseInfo('02427103-v', 9), SenseInfo('01647229-v', 4), SenseInfo('00636888-v', 0) ],
"_bony_a_1_rel" : [ SenseInfo('00988988-a', 2), SenseInfo('03138224-a', 0), SenseInfo('00295657-a', 0), SenseInfo('00988988-a', 2), SenseInfo('03138224-a', 0), SenseInfo('00295657-a', 0), SenseInfo('00988988-a', 2), SenseInfo('03138224-a', 0), SenseInfo('00295657-a', 0) ],
"_deflate_v_1_rel" : [ SenseInfo('01436865-v', 0), SenseInfo('01436721-v', 0), SenseInfo('00856234-v', 0), SenseInfo('00562720-v', 0), SenseInfo('00562303-v', 0), SenseInfo('00264705-v', 0) ],
"_jerky_a_1_rel" : [ SenseInfo('02303575-a', 0), SenseInfo('01143750-a', 0), SenseInfo('00439905-a', 0) ],
"_cherish_v_1_rel" : [ SenseInfo('01776214-v', 13) ],
"_coherent_a_1_rel" : [ SenseInfo('00464513-a', 3), SenseInfo('01925708-a', 2), SenseInfo('00328528-a', 0), SenseInfo('00053384-a', 0), SenseInfo('00464513-a', 3), SenseInfo('01925708-a', 2), SenseInfo('00328528-a', 0), SenseInfo('00053384-a', 0) ],
"_escape_n_1_rel" : [ SenseInfo('00058743-n', 6), SenseInfo('00429440-n', 2), SenseInfo('00740712-n', 1), SenseInfo('00204199-n', 1), SenseInfo('00173283-n', 1), SenseInfo('11553419-n', 0), SenseInfo('07436661-n', 0), SenseInfo('04127633-n', 0) ],
"_air_v_cause_rel" : [ SenseInfo('02112891-v', 1), SenseInfo('00973728-v', 0), SenseInfo('00973056-v', 0), SenseInfo('00954608-v', 0), SenseInfo('00489029-v', 0), SenseInfo('00488770-v', 0) ],
"_orange_a_1_rel" : [ SenseInfo('00378892-a', 7) ],
"_vocalization_n_of_rel" : [ SenseInfo('07110615-n', 0), SenseInfo('07109847-n', 0) ],
"_flip_v_1_rel" : [ SenseInfo('01893079-v', 3), SenseInfo('01510173-v', 1), SenseInfo('02153023-v', 0), SenseInfo('01893601-v', 0), SenseInfo('01893465-v', 0), SenseInfo('01512625-v', 0), SenseInfo('01241614-v', 0), SenseInfo('01222958-v', 0), SenseInfo('00717921-v', 0), SenseInfo('00584810-v', 0), SenseInfo('00121678-v', 0) ],
"_heroin_n_1_rel" : [ SenseInfo('03516011-n', 0) ],
"_consultative_a_1_rel" : [ SenseInfo('01304802-a', 0) ],
"_work-around_n_1_rel" : [  ],
"_classify_v_1_rel" : [ SenseInfo('00654625-v', 14), SenseInfo('02508803-v', 0), SenseInfo('00739662-v', 0) ],
"_exertion_n_1_rel" : [ SenseInfo('00621627-n', 6) ],
"_homogeneous_a_1_rel" : [ SenseInfo('01199751-a', 7) ],
"_match_v_up-2_rel" : [ SenseInfo('02657219-v', 16), SenseInfo('02332627-v', 12), SenseInfo('01292885-v', 6), SenseInfo('02672187-v', 5), SenseInfo('00456740-v', 3), SenseInfo('02594674-v', 0), SenseInfo('01293389-v', 0), SenseInfo('01081152-v', 0), SenseInfo('00456596-v', 0), SenseInfo('00417001-v', 0) ],
"_singaporian_n_1_rel" : [  ],
"_through_p_rel" : [ SenseInfo('00478821-r', 5), SenseInfo('01003536-a', 4), SenseInfo('00478634-r', 2), SenseInfo('00478904-r', 1), SenseInfo('00478730-r', 0), SenseInfo('00057626-r', 0), SenseInfo('00762168-a', 0), SenseInfo('00478821-r', 5), SenseInfo('01003536-a', 4), SenseInfo('00478634-r', 2), SenseInfo('00478904-r', 1), SenseInfo('00478730-r', 0), SenseInfo('00057626-r', 0), SenseInfo('00762168-a', 0), SenseInfo('00478821-r', 5), SenseInfo('01003536-a', 4), SenseInfo('00478634-r', 2), SenseInfo('00478904-r', 1), SenseInfo('00478730-r', 0), SenseInfo('00057626-r', 0), SenseInfo('00762168-a', 0) ],
"_let_v_go-of_rel" : [ SenseInfo('02423183-v', 219), SenseInfo('00771490-v', 15), SenseInfo('00802318-v', 2), SenseInfo('00120796-v', 2), SenseInfo('00496673-v', 1), SenseInfo('02208903-v', 0), SenseInfo('02423183-v', 219), SenseInfo('00771490-v', 15), SenseInfo('00802318-v', 2), SenseInfo('00120796-v', 2), SenseInfo('00496673-v', 1), SenseInfo('02208903-v', 0) ],
"_free_v_of_rel" : [ SenseInfo('02421374-v', 6), SenseInfo('02350175-v', 3), SenseInfo('01528522-v', 3), SenseInfo('02564146-v', 1), SenseInfo('02494047-v', 1), SenseInfo('02422026-v', 1), SenseInfo('01475953-v', 1), SenseInfo('00902424-v', 1), SenseInfo('02316304-v', 0), SenseInfo('01757994-v', 0), SenseInfo('00269682-v', 0), SenseInfo('02421374-v', 6), SenseInfo('02350175-v', 3), SenseInfo('01528522-v', 3), SenseInfo('02564146-v', 1), SenseInfo('02494047-v', 1), SenseInfo('02422026-v', 1), SenseInfo('01475953-v', 1), SenseInfo('00902424-v', 1), SenseInfo('02316304-v', 0), SenseInfo('01757994-v', 0), SenseInfo('00269682-v', 0), SenseInfo('02421374-v', 6), SenseInfo('02350175-v', 3), SenseInfo('01528522-v', 3), SenseInfo('02564146-v', 1), SenseInfo('02494047-v', 1), SenseInfo('02422026-v', 1), SenseInfo('01475953-v', 1), SenseInfo('00902424-v', 1), SenseInfo('02316304-v', 0), SenseInfo('01757994-v', 0), SenseInfo('00269682-v', 0), SenseInfo('02421374-v', 6), SenseInfo('02350175-v', 3), SenseInfo('01528522-v', 3), SenseInfo('02564146-v', 1), SenseInfo('02494047-v', 1), SenseInfo('02422026-v', 1), SenseInfo('01475953-v', 1), SenseInfo('00902424-v', 1), SenseInfo('02316304-v', 0), SenseInfo('01757994-v', 0), SenseInfo('00269682-v', 0), SenseInfo('02421374-v', 6), SenseInfo('02350175-v', 3), SenseInfo('01528522-v', 3), SenseInfo('02564146-v', 1), SenseInfo('02494047-v', 1), SenseInfo('02422026-v', 1), SenseInfo('01475953-v', 1), SenseInfo('00902424-v', 1), SenseInfo('02316304-v', 0), SenseInfo('01757994-v', 0), SenseInfo('00269682-v', 0), SenseInfo('02421374-v', 6), SenseInfo('02350175-v', 3), SenseInfo('01528522-v', 3), SenseInfo('02564146-v', 1), SenseInfo('02494047-v', 1), SenseInfo('02422026-v', 1), SenseInfo('01475953-v', 1), SenseInfo('00902424-v', 1), SenseInfo('02316304-v', 0), SenseInfo('01757994-v', 0), SenseInfo('00269682-v', 0) ],
"_dumpster_n_1_rel" : [ SenseInfo('03256032-n', 0) ],
"_unrestrained_a_1_rel" : [ SenseInfo('02000680-a', 0), SenseInfo('02390724-a', 0), SenseInfo('02000680-a', 0), SenseInfo('02390724-a', 0), SenseInfo('02000680-a', 0), SenseInfo('02390724-a', 0) ],
"_morphological_a_1_rel" : [ SenseInfo('02949931-a', 0), SenseInfo('02949511-a', 0), SenseInfo('02949275-a', 0) ],
"_participial_n_1_rel" : [ SenseInfo('06330528-n', 0) ],
"_entitle_v_to_rel" : [ SenseInfo('02447370-v', 17), SenseInfo('01029500-v', 6), SenseInfo('02398463-v', 0), SenseInfo('02447370-v', 17), SenseInfo('01029500-v', 6), SenseInfo('02398463-v', 0) ],
"_p.e._n_1_rel" : [ SenseInfo('11494472-n', 0), SenseInfo('11494472-n', 0), SenseInfo('11494472-n', 0), SenseInfo('11494472-n', 0) ],
"_summary_n_of_rel" : [ SenseInfo('06467007-n', 5) ],
"_transformer_n_1_rel" : [ SenseInfo('04471315-n', 1) ],
"_solve_v_1_rel" : [ SenseInfo('00634906-v', 30), SenseInfo('00733044-v', 5), SenseInfo('00761454-v', 0) ],
"_authority_n_1_rel" : [ SenseInfo('05196582-n', 18), SenseInfo('09824609-n', 5), SenseInfo('09824361-n', 3), SenseInfo('05697363-n', 2), SenseInfo('08337324-n', 1), SenseInfo('05176607-n', 1), SenseInfo('06411592-n', 0), SenseInfo('05196582-n', 18), SenseInfo('09824609-n', 5), SenseInfo('09824361-n', 3), SenseInfo('05697363-n', 2), SenseInfo('08337324-n', 1), SenseInfo('05176607-n', 1), SenseInfo('06411592-n', 0) ],
"_elm_n_1_rel" : [ SenseInfo('12405714-n', 1), SenseInfo('12406155-n', 0) ],
"_atop_p_rel" : [ SenseInfo('00276225-r', 1), SenseInfo('00276225-r', 1) ],
"_spice_v_1_rel" : [ SenseInfo('00559919-v', 1), SenseInfo('02192570-v', 0) ],
"_speech_n_1_rel" : [ SenseInfo('07238694-n', 16), SenseInfo('07109196-n', 7), SenseInfo('07130050-n', 4), SenseInfo('07110457-n', 1), SenseInfo('07071483-n', 1), SenseInfo('06713930-n', 1), SenseInfo('07010821-n', 0), SenseInfo('05650820-n', 0) ],
"_incise_v_1_rel" : [ SenseInfo('01555742-v', 1) ],
"_cellulose_n_1_rel" : [ SenseInfo('14793921-n', 5) ],
"_strip_v_1_rel" : [ SenseInfo('02314275-v', 7), SenseInfo('00049900-v', 2), SenseInfo('01263479-v', 1), SenseInfo('00488617-v', 1), SenseInfo('00194912-v', 1), SenseInfo('02344568-v', 0), SenseInfo('01608706-v', 0), SenseInfo('01263659-v', 0), SenseInfo('00194812-v', 0), SenseInfo('00194696-v', 0), SenseInfo('00194534-v', 0), SenseInfo('00194079-v', 0), SenseInfo('00177243-v', 0) ],
"_articulate_v_1_rel" : [ SenseInfo('02354287-v', 1), SenseInfo('00980453-v', 1), SenseInfo('00978549-v', 1), SenseInfo('02622637-v', 0), SenseInfo('00978369-v', 0), SenseInfo('02354287-v', 1), SenseInfo('00980453-v', 1), SenseInfo('00978549-v', 1), SenseInfo('02622637-v', 0), SenseInfo('00978369-v', 0) ],
"_gate_n_1_rel" : [ SenseInfo('03427296-n', 18), SenseInfo('03427656-n', 1), SenseInfo('13258269-n', 0), SenseInfo('03427909-n', 0) ],
"_bin_n_1_rel" : [ SenseInfo('02839910-n', 2), SenseInfo('13765306-n', 0), SenseInfo('06425534-n', 0) ],
"_anatomy_n_1_rel" : [ SenseInfo('06057539-n', 4), SenseInfo('05217168-n', 2), SenseInfo('00646187-n', 1), SenseInfo('06057539-n', 4), SenseInfo('05217168-n', 2), SenseInfo('00646187-n', 1), SenseInfo('06057539-n', 4), SenseInfo('05217168-n', 2), SenseInfo('00646187-n', 1) ],
"_texture_n_1_rel" : [ SenseInfo('04946877-n', 13), SenseInfo('05849667-n', 3), SenseInfo('04984007-n', 1), SenseInfo('04950537-n', 0), SenseInfo('04934220-n', 0) ],
"_connote_v_1_rel" : [ SenseInfo('00929839-v', 2), SenseInfo('00931232-v', 0) ],
"_yearly_a_1_rel" : [ SenseInfo('01969150-a', 0), SenseInfo('01969150-a', 0) ],
"_duffer_n_1_rel" : [ SenseInfo('10039271-n', 3) ],
"_toughest_a_for_rel" : [  ],
"_presenter_n_1_rel" : [ SenseInfo('10466387-n', 0), SenseInfo('10466198-n', 0), SenseInfo('10025730-n', 0) ],
"_chatterbot_n_1_rel" : [  ],
"_ever+since_x_subord_rel" : [  ],
"_uplifting_a_1_rel" : [ SenseInfo('07376008-n', 2), SenseInfo('07376008-n', 2), SenseInfo('07376008-n', 2) ],
"_commercial_a_1_rel" : [ SenseInfo('00483146-a', 22), SenseInfo('03137558-a', 2), SenseInfo('02346878-a', 0), SenseInfo('00483146-a', 22), SenseInfo('03137558-a', 2), SenseInfo('02346878-a', 0) ],
"_froth_n_1_rel" : [ SenseInfo('09282724-n', 1) ],
"_hand_v_off_rel" : [ SenseInfo('02230772-v', 25), SenseInfo('02000133-v', 0) ],
"_endorse_v_as_rel" : [ SenseInfo('02453889-v', 7), SenseInfo('02556817-v', 1), SenseInfo('02447793-v', 1), SenseInfo('00997794-v', 0), SenseInfo('02453889-v', 7), SenseInfo('02556817-v', 1), SenseInfo('02447793-v', 1), SenseInfo('00997794-v', 0) ],
"_all+season+long_a_1_rel" : [  ],
"_forcemeat_n_1_rel" : [ SenseInfo('07679140-n', 0) ],
"_sophistication_n_1_rel" : [ SenseInfo('05987835-n', 2), SenseInfo('05895138-n', 0), SenseInfo('05641205-n', 0), SenseInfo('04880273-n', 0), SenseInfo('00753472-n', 0) ],
"_temporal_a_1_rel" : [ SenseInfo('01757914-a', 3), SenseInfo('02810882-a', 0), SenseInfo('02810739-a', 0), SenseInfo('02577061-a', 0), SenseInfo('01181904-a', 0) ],
"_oesophageal_a_1_rel" : [  ],
"_chalk_v_1_rel" : [ SenseInfo('01690163-v', 0) ],
"_rub_v_out_rel" : [ SenseInfo('01249724-v', 19), SenseInfo('01250908-v', 1), SenseInfo('02119874-v', 0) ],
"_more_x_rel" : [ SenseInfo('00099341-r', 374), SenseInfo('01555133-a', 134), SenseInfo('01556355-a', 67), SenseInfo('00099712-r', 34), SenseInfo('11190183-n', 0) ],
"_quixotic_a_1_rel" : [ SenseInfo('01837182-a', 2) ],
"_rainforest_n_1_rel" : [ SenseInfo('08439126-n', 0) ],
"_sharpen_v_up_rel" : [ SenseInfo('01246601-v', 1), SenseInfo('00392426-v', 1), SenseInfo('00392314-v', 1), SenseInfo('00314272-v', 1), SenseInfo('02190786-v', 0), SenseInfo('00393398-v', 0), SenseInfo('00392960-v', 0), SenseInfo('00392588-v', 0), SenseInfo('01246601-v', 1), SenseInfo('00392426-v', 1), SenseInfo('00392314-v', 1), SenseInfo('00314272-v', 1), SenseInfo('02190786-v', 0), SenseInfo('00393398-v', 0), SenseInfo('00392960-v', 0), SenseInfo('00392588-v', 0) ],
"_gut_n_1_rel" : [ SenseInfo('05534333-n', 2), SenseInfo('09300483-n', 0), SenseInfo('02983741-n', 0) ],
"_unforgiving_a_1_rel" : [ SenseInfo('01041481-a', 0), SenseInfo('01785341-a', 0), SenseInfo('01041481-a', 0), SenseInfo('01785341-a', 0) ],
"_tryout_n_1_rel" : [ SenseInfo('05799212-n', 0), SenseInfo('00794614-n', 0) ],
"_interpose_v_1_rel" : [ SenseInfo('02098964-v', 2), SenseInfo('02079051-v', 1), SenseInfo('00914769-v', 1), SenseInfo('02538765-v', 0), SenseInfo('02098964-v', 2), SenseInfo('02079051-v', 1), SenseInfo('00914769-v', 1), SenseInfo('02538765-v', 0) ],
"_go_v_into_rel" : [ SenseInfo('01835496-v', 343), SenseInfo('02372605-v', 95), SenseInfo('01848718-v', 49), SenseInfo('00149583-v', 29), SenseInfo('02653862-v', 14), SenseInfo('02721284-v', 10), SenseInfo('02685951-v', 10), SenseInfo('00341560-v', 10), SenseInfo('00359916-v', 9), SenseInfo('02618001-v', 7), SenseInfo('02176268-v', 3), SenseInfo('01525666-v', 3), SenseInfo('01192773-v', 3), SenseInfo('00539110-v', 3), SenseInfo('02618149-v', 2), SenseInfo('02617798-v', 2), SenseInfo('00358431-v', 2), SenseInfo('02737876-v', 1), SenseInfo('02729819-v', 1), SenseInfo('01864230-v', 1), SenseInfo('01076615-v', 1), SenseInfo('02700772-v', 0), SenseInfo('02700666-v', 0), SenseInfo('02700455-v', 0), SenseInfo('02686471-v', 0), SenseInfo('02659763-v', 0), SenseInfo('01318849-v', 0), SenseInfo('01192992-v', 0), SenseInfo('00676267-v', 0), SenseInfo('00434374-v', 0) ],
"_prosecution_n_of_rel" : [ SenseInfo('01198307-n', 3), SenseInfo('08064742-n', 1), SenseInfo('01022008-n', 0) ],
"_bank_n_of_rel" : [ SenseInfo('09213565-n', 25), SenseInfo('08420278-n', 20), SenseInfo('09213434-n', 2), SenseInfo('08462066-n', 1), SenseInfo('13368318-n', 0), SenseInfo('13356402-n', 0), SenseInfo('09213828-n', 0), SenseInfo('04139859-n', 0), SenseInfo('02787772-n', 0), SenseInfo('00169305-n', 0) ],
"_hang+on_a_1_rel" : [  ],
"_tend_v_1_rel" : [ SenseInfo('02719399-v', 59), SenseInfo('02549847-v', 3), SenseInfo('02439047-v', 1), SenseInfo('02719399-v', 59), SenseInfo('02549847-v', 3), SenseInfo('02439047-v', 1) ],
"_similarity_n_to_rel" : [ SenseInfo('04743605-n', 9), SenseInfo('06251033-n', 0) ],
"_crossroad_n_1_rel" : [ SenseInfo('03581125-n', 1) ],
"_sine_n_1_rel" : [ SenseInfo('13787379-n', 0) ],
"_incidence_n_of_rel" : [ SenseInfo('13826959-n', 5), SenseInfo('11467996-n', 0) ],
"_dope_n_1_rel" : [ SenseInfo('03990834-n', 1), SenseInfo('10039391-n', 0), SenseInfo('07927931-n', 0), SenseInfo('06636113-n', 0) ],
"_roll_v_1_rel" : [ SenseInfo('01866192-v', 22), SenseInfo('01887020-v', 10), SenseInfo('02687251-v', 7), SenseInfo('01391280-v', 6), SenseInfo('02198014-v', 2), SenseInfo('01522276-v', 2), SenseInfo('01526139-v', 1), SenseInfo('00143204-v', 1), SenseInfo('00100410-v', 1), SenseInfo('02322596-v', 0), SenseInfo('01901783-v', 0), SenseInfo('01881180-v', 0), SenseInfo('01875684-v', 0), SenseInfo('01866610-v', 0), SenseInfo('01055978-v', 0), SenseInfo('00324427-v', 0), SenseInfo('00125289-v', 0), SenseInfo('00125078-v', 0) ],
"_obtainable_a_1_rel" : [ SenseInfo('00184363-a', 3), SenseInfo('00184363-a', 3) ],
"_those_q_dem_rel" : [  ],
"_fortification_n_of_rel" : [ SenseInfo('03385557-n', 1), SenseInfo('05635624-n', 0), SenseInfo('00264529-n', 0) ],
"_bucolic_a_1_rel" : [ SenseInfo('02051179-a', 1), SenseInfo('02895044-a', 0) ],
"_water-repellent_a_1_rel" : [ SenseInfo('01773094-a', 0) ],
"_ISP_n_1_rel" : [  ],
"_patch_v_1_rel" : [ SenseInfo('01590171-v', 2), SenseInfo('02357693-v', 1), SenseInfo('00262703-v', 0), SenseInfo('00261705-v', 0) ],
"_conformity_n_1_rel" : [ SenseInfo('04713692-n', 2), SenseInfo('01203676-n', 2), SenseInfo('06211963-n', 1), SenseInfo('07176804-n', 0), SenseInfo('04801763-n', 0) ],
"_col_n_1_rel" : [ SenseInfo('09249034-n', 0) ],
"_copious_a_1_rel" : [ SenseInfo('00014858-a', 0), SenseInfo('00014490-a', 0) ],
"_quay_n_1_rel" : [ SenseInfo('04033082-n', 0) ],
"_presumably_a_1_rel" : [  ],
"_fund_n_1_rel" : [ SenseInfo('13358549-n', 29), SenseInfo('13367070-n', 3), SenseInfo('08070850-n', 0), SenseInfo('13358549-n', 29), SenseInfo('13367070-n', 3), SenseInfo('08070850-n', 0), SenseInfo('13358549-n', 29), SenseInfo('13367070-n', 3), SenseInfo('08070850-n', 0) ],
"_skip_v_1_rel" : [ SenseInfo('00616498-v', 7), SenseInfo('02613860-v', 1), SenseInfo('01966861-v', 1), SenseInfo('02010698-v', 0), SenseInfo('01892734-v', 0), SenseInfo('01515924-v', 0), SenseInfo('00616498-v', 7), SenseInfo('02613860-v', 1), SenseInfo('01966861-v', 1), SenseInfo('02010698-v', 0), SenseInfo('01892734-v', 0), SenseInfo('01515924-v', 0) ],
"_figure_v_into_rel" : [ SenseInfo('00712135-v', 20), SenseInfo('02722207-v', 8), SenseInfo('01635432-v', 3), SenseInfo('00637259-v', 2), SenseInfo('00590241-v', 1) ],
"_single_v_1_rel" : [ SenseInfo('01409374-v', 6) ],
"_soak_v_cause_rel" : [ SenseInfo('01578513-v', 4), SenseInfo('02319050-v', 1), SenseInfo('00216216-v', 1), SenseInfo('02347220-v', 0), SenseInfo('01397870-v', 0), SenseInfo('01190494-v', 0), SenseInfo('01190277-v', 0), SenseInfo('00456151-v', 0), SenseInfo('00372157-v', 0) ],
"_great_a_for_rel" : [ SenseInfo('01386883-a', 114), SenseInfo('01278818-a', 38), SenseInfo('01677433-a', 18), SenseInfo('01123879-a', 7), SenseInfo('01467919-a', 0), SenseInfo('00173391-a', 0), SenseInfo('01386883-a', 114), SenseInfo('01278818-a', 38), SenseInfo('01677433-a', 18), SenseInfo('01123879-a', 7), SenseInfo('01467919-a', 0), SenseInfo('00173391-a', 0), SenseInfo('01386883-a', 114), SenseInfo('01278818-a', 38), SenseInfo('01677433-a', 18), SenseInfo('01123879-a', 7), SenseInfo('01467919-a', 0), SenseInfo('00173391-a', 0), SenseInfo('01386883-a', 114), SenseInfo('01278818-a', 38), SenseInfo('01677433-a', 18), SenseInfo('01123879-a', 7), SenseInfo('01467919-a', 0), SenseInfo('00173391-a', 0), SenseInfo('01386883-a', 114), SenseInfo('01278818-a', 38), SenseInfo('01677433-a', 18), SenseInfo('01123879-a', 7), SenseInfo('01467919-a', 0), SenseInfo('00173391-a', 0), SenseInfo('01386883-a', 114), SenseInfo('01278818-a', 38), SenseInfo('01677433-a', 18), SenseInfo('01123879-a', 7), SenseInfo('01467919-a', 0), SenseInfo('00173391-a', 0) ],
"_grotesque_n_1_rel" : [ SenseInfo('03462441-n', 1) ],
"_barrens_n_1_rel" : [ SenseInfo('08504594-n', 0), SenseInfo('08504594-n', 0) ],
"_univalve_n_1_rel" : [ SenseInfo('01942177-n', 0) ],
"_shotgun_n_1_rel" : [ SenseInfo('04206356-n', 2) ],
"_scheduler_n_1_rel" : [ SenseInfo('04145417-n', 0) ],
"_thickness_n_1_rel" : [ SenseInfo('05103072-n', 4), SenseInfo('07133143-n', 0), SenseInfo('05136662-n', 0), SenseInfo('04936403-n', 0) ],
"_activist_n_1_rel" : [ SenseInfo('10315837-n', 0) ],
"_first+hand_a_1_rel" : [ SenseInfo('01852812-a', 2), SenseInfo('01852812-a', 2), SenseInfo('01852812-a', 2), SenseInfo('01852812-a', 2) ],
"_autonomous_a_1_rel" : [ SenseInfo('01062393-a', 0), SenseInfo('00728431-a', 0), SenseInfo('00728225-a', 0) ],
"_problematic_a_1_rel" : [ SenseInfo('01916784-a', 0), SenseInfo('00746451-a', 0) ],
"_before+tax_a_1_rel" : [  ],
"_poundal_n_1_rel" : [ SenseInfo('13647997-n', 0) ],
"_mid_a_1_rel" : [ SenseInfo('00816324-a', 8) ],
"_implicate_v_1_rel" : [ SenseInfo('02677332-v', 0), SenseInfo('02634808-v', 0) ],
"_play_v_back_rel" : [ SenseInfo('01072949-v', 70), SenseInfo('02370650-v', 37), SenseInfo('01725051-v', 29), SenseInfo('01719302-v', 27), SenseInfo('02418686-v', 23), SenseInfo('01724459-v', 14), SenseInfo('01726172-v', 8), SenseInfo('00013615-v', 6), SenseInfo('01903385-v', 5), SenseInfo('01138911-v', 5), SenseInfo('02418421-v', 4), SenseInfo('01722077-v', 4), SenseInfo('01717436-v', 3), SenseInfo('01716619-v', 2), SenseInfo('01149470-v', 2), SenseInfo('00013328-v', 2), SenseInfo('02597601-v', 1), SenseInfo('01717169-v', 1), SenseInfo('01586278-v', 1), SenseInfo('01163355-v', 1), SenseInfo('00711932-v', 1), SenseInfo('02722449-v', 0), SenseInfo('02437465-v', 0), SenseInfo('01903562-v', 0), SenseInfo('01719921-v', 0), SenseInfo('01716882-v', 0), SenseInfo('01629589-v', 0), SenseInfo('01377239-v', 0), SenseInfo('01156115-v', 0), SenseInfo('01155687-v', 0), SenseInfo('01080691-v', 0), SenseInfo('01080064-v', 0), SenseInfo('01079873-v', 0), SenseInfo('01079480-v', 0), SenseInfo('00075875-v', 0), SenseInfo('01072949-v', 70), SenseInfo('02370650-v', 37), SenseInfo('01725051-v', 29), SenseInfo('01719302-v', 27), SenseInfo('02418686-v', 23), SenseInfo('01724459-v', 14), SenseInfo('01726172-v', 8), SenseInfo('00013615-v', 6), SenseInfo('01903385-v', 5), SenseInfo('01138911-v', 5), SenseInfo('02418421-v', 4), SenseInfo('01722077-v', 4), SenseInfo('01717436-v', 3), SenseInfo('01716619-v', 2), SenseInfo('01149470-v', 2), SenseInfo('00013328-v', 2), SenseInfo('02597601-v', 1), SenseInfo('01717169-v', 1), SenseInfo('01586278-v', 1), SenseInfo('01163355-v', 1), SenseInfo('00711932-v', 1), SenseInfo('02722449-v', 0), SenseInfo('02437465-v', 0), SenseInfo('01903562-v', 0), SenseInfo('01719921-v', 0), SenseInfo('01716882-v', 0), SenseInfo('01629589-v', 0), SenseInfo('01377239-v', 0), SenseInfo('01156115-v', 0), SenseInfo('01155687-v', 0), SenseInfo('01080691-v', 0), SenseInfo('01080064-v', 0), SenseInfo('01079873-v', 0), SenseInfo('01079480-v', 0), SenseInfo('00075875-v', 0) ],
"_for_p_rel" : [  ],
"_ugh_a_1_rel" : [  ],
"_breast_v_1_rel" : [ SenseInfo('02710244-v', 0), SenseInfo('02021149-v', 0), SenseInfo('01079172-v', 0) ],
"_physician_n_1_rel" : [ SenseInfo('10020890-n', 7) ],
"_outlying_a_1_rel" : [ SenseInfo('00444399-a', 1) ],
"_knock_v_down_rel" : [ SenseInfo('01238640-v', 7), SenseInfo('01414467-v', 6), SenseInfo('01239619-v', 4), SenseInfo('02185373-v', 0), SenseInfo('02178866-v', 0), SenseInfo('00826509-v', 0) ],
"_dupe_n_1_rel" : [ SenseInfo('10752480-n', 0) ],
"_hear_v_out_rel" : [ SenseInfo('02169702-v', 275), SenseInfo('00598954-v', 60), SenseInfo('02500902-v', 12), SenseInfo('02107442-v', 8), SenseInfo('02171039-v', 0) ],
"_gc_v_1_rel" : [  ],
"_precipice_n_1_rel" : [ SenseInfo('09398677-n', 1) ],
"_taste_n_of-i_rel" : [ SenseInfo('05715283-n', 8), SenseInfo('07498210-n', 7), SenseInfo('05749619-n', 3), SenseInfo('07288024-n', 1), SenseInfo('07578879-n', 0), SenseInfo('05658226-n', 0), SenseInfo('00882702-n', 0), SenseInfo('05715283-n', 8), SenseInfo('07498210-n', 7), SenseInfo('05749619-n', 3), SenseInfo('07288024-n', 1), SenseInfo('07578879-n', 0), SenseInfo('05658226-n', 0), SenseInfo('00882702-n', 0) ],
"_lip_n_1_rel" : [ SenseInfo('05305806-n', 57), SenseInfo('11691857-n', 0), SenseInfo('06721949-n', 0), SenseInfo('02902250-n', 0), SenseInfo('01941538-n', 0) ],
"_bow_n_1_rel" : [ SenseInfo('02880189-n', 4), SenseInfo('02879517-n', 2), SenseInfo('02880008-n', 1), SenseInfo('02879718-n', 1), SenseInfo('13896100-n', 0), SenseInfo('07274425-n', 0), SenseInfo('07229341-n', 0), SenseInfo('02880308-n', 0), SenseInfo('00547765-n', 0) ],
"_machinist_n_1_rel" : [ SenseInfo('10279018-n', 2), SenseInfo('10279018-n', 2), SenseInfo('10279018-n', 2) ],
"_scientific_a_1_rel" : [ SenseInfo('02793273-a', 12), SenseInfo('02084804-a', 12), SenseInfo('02793273-a', 12), SenseInfo('02084804-a', 12) ],
"_desert_n_1_rel" : [ SenseInfo('08505573-n', 4) ],
"_southward_a_2_rel" : [ SenseInfo('01602683-a', 0) ],
"_lire_n_1_rel" : [ SenseInfo('13695189-n', 0), SenseInfo('13687160-n', 0), SenseInfo('13686376-n', 0), SenseInfo('13695189-n', 0), SenseInfo('13687160-n', 0), SenseInfo('13686376-n', 0), SenseInfo('13695189-n', 0), SenseInfo('13687160-n', 0), SenseInfo('13686376-n', 0), SenseInfo('13695189-n', 0), SenseInfo('13687160-n', 0), SenseInfo('13686376-n', 0), SenseInfo('13695189-n', 0), SenseInfo('13687160-n', 0), SenseInfo('13686376-n', 0), SenseInfo('13695189-n', 0), SenseInfo('13687160-n', 0), SenseInfo('13686376-n', 0), SenseInfo('13695189-n', 0), SenseInfo('13687160-n', 0), SenseInfo('13686376-n', 0), SenseInfo('13695189-n', 0), SenseInfo('13687160-n', 0), SenseInfo('13686376-n', 0) ],
"_transfer_v_from-to_rel" : [ SenseInfo('02393086-v', 6), SenseInfo('02232190-v', 6), SenseInfo('01855155-v', 6), SenseInfo('02012344-v', 5), SenseInfo('02220461-v', 1), SenseInfo('02088241-v', 1), SenseInfo('01435380-v', 1), SenseInfo('02086458-v', 0), SenseInfo('00555240-v', 0) ],
"_at+once_a_1_rel" : [  ],
"_synthetic_n_1_rel" : [ SenseInfo('14901959-n', 0) ],
"_icecap_n_1_rel" : [ SenseInfo('09308743-n', 0) ],
"_glass_n_of_rel" : [ SenseInfo('14881303-n', 22), SenseInfo('03438257-n', 12), SenseInfo('13767239-n', 4), SenseInfo('03333129-n', 1), SenseInfo('03754295-n', 0), SenseInfo('03688832-n', 0), SenseInfo('03438661-n', 0) ],
"_raw_a_1_rel" : [ SenseInfo('01952643-a', 7), SenseInfo('01319061-a', 2), SenseInfo('00619433-a', 1), SenseInfo('01954943-a', 1), SenseInfo('01705195-a', 1), SenseInfo('00958020-a', 1), SenseInfo('00417204-a', 1), SenseInfo('01813081-a', 0), SenseInfo('01712753-a', 0), SenseInfo('01252399-a', 0), SenseInfo('01005914-a', 0), SenseInfo('00937186-a', 0), SenseInfo('00458266-a', 0), SenseInfo('01952643-a', 7), SenseInfo('01319061-a', 2), SenseInfo('00619433-a', 1), SenseInfo('01954943-a', 1), SenseInfo('01705195-a', 1), SenseInfo('00958020-a', 1), SenseInfo('00417204-a', 1), SenseInfo('01813081-a', 0), SenseInfo('01712753-a', 0), SenseInfo('01252399-a', 0), SenseInfo('01005914-a', 0), SenseInfo('00937186-a', 0), SenseInfo('00458266-a', 0), SenseInfo('01952643-a', 7), SenseInfo('01319061-a', 2), SenseInfo('00619433-a', 1), SenseInfo('01954943-a', 1), SenseInfo('01705195-a', 1), SenseInfo('00958020-a', 1), SenseInfo('00417204-a', 1), SenseInfo('01813081-a', 0), SenseInfo('01712753-a', 0), SenseInfo('01252399-a', 0), SenseInfo('01005914-a', 0), SenseInfo('00937186-a', 0), SenseInfo('00458266-a', 0) ],
"_sweetness_n_1_rel" : [ SenseInfo('05716577-n', 1), SenseInfo('04994413-n', 0), SenseInfo('04980463-n', 0), SenseInfo('04778630-n', 0) ],
"_probe_v_1_rel" : [ SenseInfo('00788564-v', 7), SenseInfo('01226875-v', 2) ],
"_demise_v_1_rel" : [ SenseInfo('02220914-v', 0) ],
"_find_n_1_rel" : [ SenseInfo('05808218-n', 0), SenseInfo('00043195-n', 0) ],
"_gradient_a_1_rel" : [ SenseInfo('13859512-n', 15), SenseInfo('05068461-n', 0), SenseInfo('13859512-n', 15), SenseInfo('05068461-n', 0) ],
"_startup_n_1_rel" : [ SenseInfo('00242431-n', 1), SenseInfo('00239910-n', 0), SenseInfo('00242431-n', 1), SenseInfo('00239910-n', 0), SenseInfo('00242431-n', 1), SenseInfo('00239910-n', 0) ],
"_forensic_a_1_rel" : [ SenseInfo('02017613-a', 1), SenseInfo('00863361-a', 0) ],
"_mailing_n_1_rel" : [ SenseInfo('08463647-n', 0), SenseInfo('00122338-n', 0) ],
"_crouched_a_1_rel" : [  ],
"_pickup_n_1_rel" : [ SenseInfo('03930630-n', 2), SenseInfo('06547832-n', 1), SenseInfo('03930777-n', 1), SenseInfo('10432053-n', 0), SenseInfo('05061003-n', 0), SenseInfo('04450465-n', 0), SenseInfo('02971940-n', 0), SenseInfo('01016201-n', 0), SenseInfo('00319176-n', 0) ],
"_gag_v_2_rel" : [ SenseInfo('02190943-v', 1), SenseInfo('01570562-v', 0), SenseInfo('01284683-v', 0), SenseInfo('00853958-v', 0), SenseInfo('00077698-v', 0), SenseInfo('00077606-v', 0), SenseInfo('00077458-v', 0) ],
"_what+a_q_rel" : [  ],
"_bra_n_1_rel" : [ SenseInfo('02892767-n', 0) ],
"_gymnastics_n_1_rel" : [ SenseInfo('00433802-n', 11), SenseInfo('00433802-n', 11), SenseInfo('00433802-n', 11) ],
"_unsmiling_a_1_rel" : [ SenseInfo('01368726-a', 2), SenseInfo('01368726-a', 2) ],
"_specific_a_to_rel" : [ SenseInfo('01103021-a', 39), SenseInfo('01099951-a', 5), SenseInfo('02989316-a', 0), SenseInfo('01105233-a', 0), SenseInfo('01103021-a', 39), SenseInfo('01099951-a', 5), SenseInfo('02989316-a', 0), SenseInfo('01105233-a', 0), SenseInfo('01103021-a', 39), SenseInfo('01099951-a', 5), SenseInfo('02989316-a', 0), SenseInfo('01105233-a', 0), SenseInfo('01103021-a', 39), SenseInfo('01099951-a', 5), SenseInfo('02989316-a', 0), SenseInfo('01105233-a', 0) ],
"_a+bit_x_deg_rel" : [ SenseInfo('00033663-r', 21) ],
"_freshwater_n_1_rel" : [ SenseInfo('15009326-n', 0) ],
"_ride_v_out_rel" : [ SenseInfo('01957529-v', 53), SenseInfo('01955984-v', 30), SenseInfo('02684644-v', 2), SenseInfo('01839538-v', 2), SenseInfo('00850501-v', 1), SenseInfo('02750154-v', 0), SenseInfo('02742232-v', 0), SenseInfo('02711987-v', 0), SenseInfo('02692089-v', 0), SenseInfo('02102398-v', 0), SenseInfo('02095545-v', 0), SenseInfo('01847676-v', 0), SenseInfo('01511134-v', 0), SenseInfo('01429322-v', 0) ],
"_challenge_n_1_rel" : [ SenseInfo('13932948-n', 5), SenseInfo('07231294-n', 3), SenseInfo('07193405-n', 1), SenseInfo('07208565-n', 0), SenseInfo('07191569-n', 0), SenseInfo('13932948-n', 5), SenseInfo('07231294-n', 3), SenseInfo('07193405-n', 1), SenseInfo('07208565-n', 0), SenseInfo('07191569-n', 0) ],
"_gossip_v_1_rel" : [ SenseInfo('01041954-v', 0), SenseInfo('01038666-v', 0) ],
"_carpentry_n_1_rel" : [ SenseInfo('00607775-n', 3) ],
"_chew_v_1_rel" : [ SenseInfo('01201089-v', 10) ],
"_end_v_up_rel" : [ SenseInfo('02609764-v', 53), SenseInfo('00352826-v', 29), SenseInfo('02735418-v', 10), SenseInfo('01620854-v', 0), SenseInfo('02609764-v', 53), SenseInfo('00352826-v', 29), SenseInfo('02735418-v', 10), SenseInfo('01620854-v', 0), SenseInfo('02609764-v', 53), SenseInfo('00352826-v', 29), SenseInfo('02735418-v', 10), SenseInfo('01620854-v', 0) ],
"_unlikely_a_for_rel" : [ SenseInfo('01413871-a', 5), SenseInfo('01412415-a', 5), SenseInfo('01800169-a', 0), SenseInfo('01413871-a', 5), SenseInfo('01412415-a', 5), SenseInfo('01800169-a', 0), SenseInfo('01413871-a', 5), SenseInfo('01412415-a', 5), SenseInfo('01800169-a', 0), SenseInfo('01413871-a', 5), SenseInfo('01412415-a', 5), SenseInfo('01800169-a', 0), SenseInfo('01413871-a', 5), SenseInfo('01412415-a', 5), SenseInfo('01800169-a', 0), SenseInfo('01413871-a', 5), SenseInfo('01412415-a', 5), SenseInfo('01800169-a', 0), SenseInfo('01413871-a', 5), SenseInfo('01412415-a', 5), SenseInfo('01800169-a', 0), SenseInfo('01413871-a', 5), SenseInfo('01412415-a', 5), SenseInfo('01800169-a', 0) ],
"_tone_v_down_rel" : [ SenseInfo('01066775-v', 0), SenseInfo('00982293-v', 0), SenseInfo('00290132-v', 0), SenseInfo('00289974-v', 0), SenseInfo('00101277-v', 0) ],
"_land_n_of_rel" : [ SenseInfo('13250048-n', 22), SenseInfo('09335240-n', 18), SenseInfo('08556491-n', 11), SenseInfo('09334396-n', 9), SenseInfo('08544813-n', 7), SenseInfo('14514805-n', 2), SenseInfo('13246662-n', 2), SenseInfo('08166552-n', 2), SenseInfo('08168978-n', 1), SenseInfo('11115558-n', 0), SenseInfo('00453731-n', 0) ],
"_spectrometric_a_1_rel" : [ SenseInfo('02918132-a', 0) ],
"_pride+of+place_n_1_rel" : [ SenseInfo('08621472-n', 0) ],
"_perfection_n_1_rel" : [ SenseInfo('14459422-n', 7), SenseInfo('05924519-n', 0), SenseInfo('00260494-n', 0) ],
"_even_a_sel_rel" : [ SenseInfo('00913387-a', 4), SenseInfo('00891170-a', 3), SenseInfo('00909545-a', 2), SenseInfo('02372520-a', 0), SenseInfo('02302187-a', 0), SenseInfo('00892243-a', 0) ],
"_swell_n_1_rel" : [ SenseInfo('07348258-n', 3), SenseInfo('09452760-n', 2), SenseInfo('04990692-n', 1), SenseInfo('09991026-n', 0) ],
"_dredge_v_up_rel" : [ SenseInfo('01261773-v', 0), SenseInfo('01244692-v', 0), SenseInfo('01244516-v', 0) ],
"_redcoat_n_1_rel" : [ SenseInfo('10029985-n', 12) ],
"_sanitary_a_1_rel" : [ SenseInfo('02112976-a', 0) ],
"_confrontation_n_of_rel" : [ SenseInfo('07231728-n', 1), SenseInfo('07181713-n', 0), SenseInfo('07181043-n', 0), SenseInfo('01169744-n', 0), SenseInfo('00651670-n', 0) ],
"_sullen_a_1_rel" : [ SenseInfo('01137378-a', 9), SenseInfo('00462409-a', 1), SenseInfo('01137378-a', 9), SenseInfo('00462409-a', 1) ],
"_possessive_a_1_rel" : [ SenseInfo('02862251-a', 1), SenseInfo('00030508-a', 1), SenseInfo('00792476-a', 0) ],
"_codename_n_1_rel" : [  ],
"_enthusiastic_a_1_rel" : [ SenseInfo('00885695-a', 9), SenseInfo('00885695-a', 9) ],
"_ex-dividend_a_1_rel" : [  ],
"_faint_v_1_rel" : [ SenseInfo('00023646-v', 1) ],
"_hint_v_at_rel" : [ SenseInfo('00927430-v', 7) ],
"_sinful_a_1_rel" : [ SenseInfo('02514543-a', 2), SenseInfo('02037531-a', 0), SenseInfo('01534648-a', 0), SenseInfo('02514543-a', 2), SenseInfo('02037531-a', 0), SenseInfo('01534648-a', 0) ],
"_lavender_n_1_rel" : [ SenseInfo('12849717-n', 0), SenseInfo('04970470-n', 0) ],
"_temperament_n_1_rel" : [ SenseInfo('04623612-n', 1), SenseInfo('04628466-n', 0), SenseInfo('01000411-n', 0) ],
"_urbane_a_1_rel" : [ SenseInfo('02271177-a', 0) ],
"_or+so_n_meas_rel" : [  ],
"_handbook_n_1_rel" : [ SenseInfo('06421301-n', 0) ],
"_cater_v_1_rel" : [ SenseInfo('01182709-v', 4), SenseInfo('01180844-v', 0) ],
"_rum_n_1_rel" : [ SenseInfo('07905038-n', 0), SenseInfo('00495331-n', 0) ],
"_veto_v_1_rel" : [ SenseInfo('02473431-v', 1), SenseInfo('00795863-v', 1) ],
"_puncture_v_cause_rel" : [ SenseInfo('01274971-v', 1), SenseInfo('01275182-v', 0), SenseInfo('00856234-v', 0), SenseInfo('00403798-v', 0), SenseInfo('00309990-v', 0) ],
"_upcoming_a_1_rel" : [ SenseInfo('01732601-a', 1) ],
"_dejection_n_1_rel" : [ SenseInfo('14486533-n', 2), SenseInfo('14854262-n', 0) ],
"_discharge_v_cause_rel" : [ SenseInfo('02563724-v', 3), SenseInfo('01377032-v', 3), SenseInfo('02422026-v', 1), SenseInfo('01489332-v', 1), SenseInfo('01134238-v', 1), SenseInfo('00904046-v', 1), SenseInfo('00104868-v', 1), SenseInfo('01489465-v', 0), SenseInfo('01133825-v', 0), SenseInfo('01097743-v', 0), SenseInfo('00448680-v', 0) ],
"_perfume_n_1_rel" : [ SenseInfo('05714466-n', 2), SenseInfo('03916031-n', 2) ],
"_till_n_1_rel" : [ SenseInfo('15074772-n', 0), SenseInfo('13357891-n', 0), SenseInfo('02976939-n', 0) ],
"_prize_n_for_rel" : [ SenseInfo('13268146-n', 9), SenseInfo('13262663-n', 1), SenseInfo('04487996-n', 0) ],
"_put_v_back_rel" : [ SenseInfo('01494310-v', 138), SenseInfo('01493741-v', 98), SenseInfo('00981276-v', 28), SenseInfo('01160370-v', 6), SenseInfo('02271137-v', 3), SenseInfo('00673448-v', 2), SenseInfo('02111499-v', 0), SenseInfo('01706375-v', 0), SenseInfo('00735571-v', 0) ],
"_feast_n_1_rel" : [ SenseInfo('08253640-n', 1), SenseInfo('07290144-n', 1), SenseInfo('07578093-n', 0), SenseInfo('07449862-n', 0) ],
"_dissection_n_of_rel" : [ SenseInfo('00387214-n', 2), SenseInfo('05782140-n', 1), SenseInfo('00648931-n', 0) ],
"_starvation_n_1_rel" : [ SenseInfo('14040310-n', 2), SenseInfo('01150662-n', 1) ],
"_regrettable_a_1_rel" : [ SenseInfo('01052038-a', 0), SenseInfo('01052038-a', 0), SenseInfo('01052038-a', 0) ],
"_boil_v_up_rel" : [ SenseInfo('00375021-v', 4), SenseInfo('00328128-v', 4), SenseInfo('00374668-v', 3), SenseInfo('01885430-v', 0), SenseInfo('01767612-v', 0) ],
"_pitch_n_1_rel" : [ SenseInfo('04985198-n', 5), SenseInfo('00106272-n', 3), SenseInfo('08624656-n', 1), SenseInfo('07248653-n', 1), SenseInfo('05069199-n', 1), SenseInfo('14911704-n', 0), SenseInfo('00573664-n', 0), SenseInfo('00498558-n', 0), SenseInfo('00337210-n', 0), SenseInfo('00106104-n', 0) ],
"_secret_n_1_rel" : [ SenseInfo('06673142-n', 9), SenseInfo('06672953-n', 0), SenseInfo('05685538-n', 0) ],
"_soil_n_1_rel" : [ SenseInfo('14498096-n', 24), SenseInfo('14844693-n', 12), SenseInfo('09335240-n', 3), SenseInfo('08493064-n', 0) ],
"_subordinate_a_1_rel" : [ SenseInfo('00792991-a', 2), SenseInfo('02329355-a', 0), SenseInfo('00730470-a', 0) ],
"_pay_n_1_rel" : [ SenseInfo('13279262-n', 14) ],
"_burgundy_a_1_rel" : [ SenseInfo('08941057-n', 0), SenseInfo('07893891-n', 0), SenseInfo('04963905-n', 0) ],
"_as_p_nbar_rel" : [ SenseInfo('13658027-n', 6), SenseInfo('15089803-n', 0), SenseInfo('14829565-n', 0), SenseInfo('14706889-n', 0), SenseInfo('13637376-n', 0), SenseInfo('06831177-n', 0), SenseInfo('05400860-n', 0) ],
"_solenoid_n_1_rel" : [ SenseInfo('04259202-n', 0) ],
"_herald_n_1_rel" : [ SenseInfo('10171219-n', 1), SenseInfo('06802571-n', 0) ],
"_sponge_n_1_rel" : [ SenseInfo('14597758-n', 1), SenseInfo('10501453-n', 0), SenseInfo('10252674-n', 0), SenseInfo('01906749-n', 0) ],
"_consultant_n_1_rel" : [ SenseInfo('09774266-n', 3) ],
"_fleeting_a_1_rel" : [ SenseInfo('01443097-a', 1) ],
"_net_v_1_rel" : [ SenseInfo('02291258-v', 1), SenseInfo('02291548-v', 0), SenseInfo('01672168-v', 0), SenseInfo('01365945-v', 0), SenseInfo('02291258-v', 1), SenseInfo('02291548-v', 0), SenseInfo('01672168-v', 0), SenseInfo('01365945-v', 0) ],
"_organize_v_1_rel" : [ SenseInfo('02448185-v', 11), SenseInfo('02432530-v', 6), SenseInfo('00710005-v', 5), SenseInfo('00404642-v', 4), SenseInfo('01651444-v', 2), SenseInfo('02434238-v', 1), SenseInfo('02448185-v', 11), SenseInfo('02432530-v', 6), SenseInfo('00710005-v', 5), SenseInfo('00404642-v', 4), SenseInfo('01651444-v', 2), SenseInfo('02434238-v', 1) ],
"_clamshell_n_1_rel" : [ SenseInfo('01956849-n', 2), SenseInfo('03037108-n', 0) ],
"_big-bucks_a_1_rel" : [  ],
"_landing_n_1_rel" : [ SenseInfo('03638511-n', 6), SenseInfo('03638321-n', 1), SenseInfo('00052500-n', 0), SenseInfo('00052334-n', 0) ],
"_mush_v_together_rel" : [ SenseInfo('01939678-v', 0), SenseInfo('01939406-v', 0) ],
"_tank_n_1_rel" : [ SenseInfo('04389033-n', 7), SenseInfo('04388743-n', 3), SenseInfo('13770529-n', 0), SenseInfo('04389521-n', 0), SenseInfo('03102771-n', 0) ],
"_cod_n_1_rel" : [ SenseInfo('13140049-n', 0), SenseInfo('07789063-n', 0), SenseInfo('02522399-n', 0) ],
"_raise_v_1_rel" : [ SenseInfo('00158503-v', 33), SenseInfo('01974062-v', 26), SenseInfo('00941166-v', 21), SenseInfo('02306281-v', 14), SenseInfo('01739814-v', 10), SenseInfo('02539788-v', 7), SenseInfo('01629958-v', 7), SenseInfo('01973759-v', 4), SenseInfo('01661243-v', 2), SenseInfo('01759326-v', 1), SenseInfo('01755651-v', 1), SenseInfo('00544549-v', 1), SenseInfo('00229605-v', 1), SenseInfo('02397637-v', 0), SenseInfo('01975587-v', 0), SenseInfo('01156406-v', 0), SenseInfo('01156291-v', 0), SenseInfo('01098452-v', 0), SenseInfo('01025246-v', 0), SenseInfo('00950782-v', 0), SenseInfo('00851625-v', 0), SenseInfo('00744070-v', 0), SenseInfo('00641929-v', 0), SenseInfo('00557537-v', 0), SenseInfo('00549982-v', 0), SenseInfo('00354195-v', 0), SenseInfo('00098517-v', 0) ],
"_instrumentation_n_1_rel" : [ SenseInfo('03575240-n', 3), SenseInfo('00097348-n', 1), SenseInfo('07038910-n', 0), SenseInfo('00939818-n', 0) ],
"_cross_v_off_rel" : [ SenseInfo('01912159-v', 47), SenseInfo('02023396-v', 7), SenseInfo('02558172-v', 1), SenseInfo('01914657-v', 1), SenseInfo('02685390-v', 0), SenseInfo('01913997-v', 0), SenseInfo('01691798-v', 0), SenseInfo('01429953-v', 0) ],
"_debt_n_1_rel" : [ SenseInfo('14490564-n', 3), SenseInfo('13397174-n', 3), SenseInfo('06773347-n', 0) ],
"_moonlike_a_1_rel" : [ SenseInfo('02042503-a', 0) ],
"_charge_n_of_rel" : [ SenseInfo('00974762-n', 16), SenseInfo('06561942-n', 13), SenseInfo('13306870-n', 4), SenseInfo('11435028-n', 3), SenseInfo('00829378-n', 2), SenseInfo('00731222-n', 2), SenseInfo('09909760-n', 1), SenseInfo('13400798-n', 0), SenseInfo('09185612-n', 0), SenseInfo('07528470-n', 0), SenseInfo('07190941-n', 0), SenseInfo('07169480-n', 0), SenseInfo('06730780-n', 0), SenseInfo('03008565-n', 0), SenseInfo('03008275-n', 0), SenseInfo('00974762-n', 16), SenseInfo('06561942-n', 13), SenseInfo('13306870-n', 4), SenseInfo('11435028-n', 3), SenseInfo('00829378-n', 2), SenseInfo('00731222-n', 2), SenseInfo('09909760-n', 1), SenseInfo('13400798-n', 0), SenseInfo('09185612-n', 0), SenseInfo('07528470-n', 0), SenseInfo('07190941-n', 0), SenseInfo('07169480-n', 0), SenseInfo('06730780-n', 0), SenseInfo('03008565-n', 0), SenseInfo('03008275-n', 0) ],
"_top_v_off_rel" : [ SenseInfo('02669081-v', 2), SenseInfo('02081178-v', 1), SenseInfo('02691722-v', 0), SenseInfo('02687385-v', 0), SenseInfo('02360497-v', 0), SenseInfo('02021376-v', 0), SenseInfo('01406897-v', 0), SenseInfo('01321509-v', 0), SenseInfo('00485891-v', 0), SenseInfo('00484712-v', 0) ],
"_poker_n_1_rel" : [ SenseInfo('03975926-n', 0), SenseInfo('00494768-n', 0) ],
"_capitalize_v_1_rel" : [ SenseInfo('02279772-v', 3), SenseInfo('02330742-v', 0), SenseInfo('01692266-v', 0), SenseInfo('00731159-v', 0), SenseInfo('00731000-v', 0), SenseInfo('00162167-v', 0), SenseInfo('02279772-v', 3), SenseInfo('02330742-v', 0), SenseInfo('01692266-v', 0), SenseInfo('00731159-v', 0), SenseInfo('00731000-v', 0), SenseInfo('00162167-v', 0) ],
"_sinker_n_1_rel" : [ SenseInfo('07639069-n', 0), SenseInfo('04223778-n', 0), SenseInfo('00108965-n', 0) ],
"_congratulate_v_for_rel" : [ SenseInfo('00881661-v', 5), SenseInfo('00881998-v', 3), SenseInfo('01772498-v', 1), SenseInfo('00883847-v', 0) ],
"_fire_n_1_rel" : [ SenseInfo('07302836-n', 43), SenseInfo('00986938-n', 18), SenseInfo('13480848-n', 7), SenseInfo('03343560-n', 4), SenseInfo('14842847-n', 3), SenseInfo('07481375-n', 3), SenseInfo('14686186-n', 0), SenseInfo('07420435-n', 0), SenseInfo('06711159-n', 0) ],
"_uninhabited_a_1_rel" : [ SenseInfo('01312739-a', 0), SenseInfo('01312739-a', 0) ],
"_cwc_n_1_rel" : [  ],
"_excessive_a_1_rel" : [ SenseInfo('01533974-a', 7), SenseInfo('02000968-a', 0), SenseInfo('01533974-a', 7), SenseInfo('02000968-a', 0) ],
"_ingenious_a_1_rel" : [ SenseInfo('00061885-a', 0) ],
"_birchbark_n_1_rel" : [ SenseInfo('02843029-n', 0) ],
"_houseplant_n_1_rel" : [ SenseInfo('13083023-n', 0) ],
"_mark_v_down_rel" : [ SenseInfo('01588493-v', 13), SenseInfo('00921738-v', 13), SenseInfo('00651991-v', 13), SenseInfo('00612612-v', 9), SenseInfo('00508032-v', 5), SenseInfo('02508245-v', 2), SenseInfo('02118476-v', 2), SenseInfo('01551195-v', 1), SenseInfo('01275762-v', 0), SenseInfo('01062395-v', 0), SenseInfo('01004062-v', 0), SenseInfo('00800750-v', 0), SenseInfo('00662182-v', 0), SenseInfo('00657728-v', 0), SenseInfo('00190023-v', 0) ],
"_muddle_n_1_rel" : [ SenseInfo('14500567-n', 1), SenseInfo('14409489-n', 0) ],
"_horse_n_1_rel" : [ SenseInfo('02374451-n', 103), SenseInfo('03538037-n', 1), SenseInfo('08397856-n', 0), SenseInfo('04140631-n', 0), SenseInfo('03624767-n', 0) ],
"_holly_n_1_rel" : [ SenseInfo('12756457-n', 0), SenseInfo('11056654-n', 0) ],
"_living_n_1_rel" : [ SenseInfo('05810561-n', 7), SenseInfo('07945818-n', 2), SenseInfo('13961642-n', 1), SenseInfo('13365286-n', 1) ],
"_lack_v_1_rel" : [ SenseInfo('02632353-v', 31) ],
"_not+that_x_rel" : [  ],
"_effing_x_deg_rel" : [  ],
"_instantaneous_a_1_rel" : [ SenseInfo('00979031-a', 1) ],
"_unfrost_v_cause_rel" : [  ],
"_call_v_up_rel" : [ SenseInfo('01028748-v', 91), SenseInfo('00971015-v', 51), SenseInfo('00789448-v', 38), SenseInfo('00913065-v', 25), SenseInfo('00792471-v', 25), SenseInfo('02487573-v', 9), SenseInfo('02429810-v', 9), SenseInfo('01067995-v', 1), SenseInfo('01062739-v', 1), SenseInfo('00975036-v', 1), SenseInfo('02643421-v', 0), SenseInfo('02601456-v', 0), SenseInfo('02487901-v', 0), SenseInfo('02359061-v', 0), SenseInfo('02300060-v', 0), SenseInfo('01899017-v', 0), SenseInfo('01068793-v', 0), SenseInfo('00917772-v', 0), SenseInfo('00874002-v', 0), SenseInfo('00869393-v', 0), SenseInfo('00822746-v', 0), SenseInfo('00783523-v', 0), SenseInfo('00754156-v', 0), SenseInfo('00753881-v', 0), SenseInfo('00738747-v', 0), SenseInfo('00738583-v', 0), SenseInfo('00691516-v', 0), SenseInfo('00107231-v', 0) ],
"_puffed_a_1_rel" : [ SenseInfo('01796736-a', 0) ],
"_displace_v_1_rel" : [ SenseInfo('02013571-v', 1), SenseInfo('02406011-v', 0), SenseInfo('02402825-v', 0), SenseInfo('01850315-v', 0) ],
"_keep_v_prd_rel" : [ SenseInfo('02681795-v', 206), SenseInfo('02684924-v', 39), SenseInfo('02202384-v', 32), SenseInfo('02450505-v', 22), SenseInfo('02578872-v', 10), SenseInfo('00732552-v', 9), SenseInfo('02202928-v', 8), SenseInfo('01065877-v', 4), SenseInfo('02651853-v', 3), SenseInfo('02410175-v', 3), SenseInfo('01184625-v', 3), SenseInfo('02734800-v', 2), SenseInfo('02578510-v', 2), SenseInfo('02422663-v', 2), SenseInfo('02733122-v', 1), SenseInfo('02652016-v', 0), SenseInfo('02283716-v', 0), SenseInfo('02204094-v', 0), SenseInfo('02203844-v', 0), SenseInfo('02203168-v', 0), SenseInfo('01302019-v', 0), SenseInfo('00212414-v', 0), SenseInfo('02681795-v', 206), SenseInfo('02684924-v', 39), SenseInfo('02202384-v', 32), SenseInfo('02450505-v', 22), SenseInfo('02578872-v', 10), SenseInfo('00732552-v', 9), SenseInfo('02202928-v', 8), SenseInfo('01065877-v', 4), SenseInfo('02651853-v', 3), SenseInfo('02410175-v', 3), SenseInfo('01184625-v', 3), SenseInfo('02734800-v', 2), SenseInfo('02578510-v', 2), SenseInfo('02422663-v', 2), SenseInfo('02733122-v', 1), SenseInfo('02652016-v', 0), SenseInfo('02283716-v', 0), SenseInfo('02204094-v', 0), SenseInfo('02203844-v', 0), SenseInfo('02203168-v', 0), SenseInfo('01302019-v', 0), SenseInfo('00212414-v', 0), SenseInfo('02681795-v', 206), SenseInfo('02684924-v', 39), SenseInfo('02202384-v', 32), SenseInfo('02450505-v', 22), SenseInfo('02578872-v', 10), SenseInfo('00732552-v', 9), SenseInfo('02202928-v', 8), SenseInfo('01065877-v', 4), SenseInfo('02651853-v', 3), SenseInfo('02410175-v', 3), SenseInfo('01184625-v', 3), SenseInfo('02734800-v', 2), SenseInfo('02578510-v', 2), SenseInfo('02422663-v', 2), SenseInfo('02733122-v', 1), SenseInfo('02652016-v', 0), SenseInfo('02283716-v', 0), SenseInfo('02204094-v', 0), SenseInfo('02203844-v', 0), SenseInfo('02203168-v', 0), SenseInfo('01302019-v', 0), SenseInfo('00212414-v', 0) ],
"_valet_n_1_rel" : [ SenseInfo('10745332-n', 2) ],
"_plough_v_1_rel" : [ SenseInfo('02096853-v', 0), SenseInfo('01741864-v', 0) ],
"_panamanian_a_1_rel" : [ SenseInfo('02966482-a', 0) ],
"_brash_a_1_rel" : [ SenseInfo('00204779-a', 1), SenseInfo('00204779-a', 1), SenseInfo('00204779-a', 1) ],
"_swing_v_cause_rel" : [ SenseInfo('02087745-v', 35), SenseInfo('01877355-v', 15), SenseInfo('01877620-v', 6), SenseInfo('02537238-v', 4), SenseInfo('01593763-v', 4), SenseInfo('02717472-v', 2), SenseInfo('01152040-v', 2), SenseInfo('00557216-v', 2), SenseInfo('02615140-v', 1), SenseInfo('02752277-v', 0), SenseInfo('02389815-v', 0), SenseInfo('01725375-v', 0), SenseInfo('01427483-v', 0) ],
"_patient_a_1_rel" : [ SenseInfo('01735736-a', 3), SenseInfo('01735736-a', 3) ],
"_mull_v_over_rel" : [ SenseInfo('00630380-v', 1), SenseInfo('02196540-v', 0) ],
"_young_n_1_rel" : [ SenseInfo('01321579-n', 7), SenseInfo('11404280-n', 0), SenseInfo('11404140-n', 0), SenseInfo('11403828-n', 0), SenseInfo('11403692-n', 0), SenseInfo('11403600-n', 0), SenseInfo('11403456-n', 0), SenseInfo('11403220-n', 0), SenseInfo('07944050-n', 0) ],
"_collaborate_v_1_rel" : [ SenseInfo('02416278-v', 9), SenseInfo('02416751-v', 0) ],
"_cramped_a_1_rel" : [ SenseInfo('00476663-a', 0) ],
"_dome_n_1_rel" : [ SenseInfo('13872072-n', 0), SenseInfo('05539454-n', 0), SenseInfo('03220692-n', 0), SenseInfo('03220513-n', 0) ],
"_roast_n_1_rel" : [ SenseInfo('07580782-n', 0), SenseInfo('05734381-n', 0) ],
"_climes_n_1_rel" : [ SenseInfo('14519366-n', 0), SenseInfo('14519366-n', 0) ],
"_old_n_1_rel" : [ SenseInfo('15121302-n', 0) ],
"_cheap_a_for_rel" : [ SenseInfo('00934199-a', 9), SenseInfo('02393791-a', 1), SenseInfo('02346013-a', 1), SenseInfo('01113114-a', 0), SenseInfo('00934199-a', 9), SenseInfo('02393791-a', 1), SenseInfo('02346013-a', 1), SenseInfo('01113114-a', 0), SenseInfo('00934199-a', 9), SenseInfo('02393791-a', 1), SenseInfo('02346013-a', 1), SenseInfo('01113114-a', 0) ],
"_aphorism_n_1_rel" : [ SenseInfo('07153130-n', 0), SenseInfo('07153130-n', 0) ],
"_theological_a_1_rel" : [ SenseInfo('02907000-a', 15) ],
"_long_a_2_rel" : [ SenseInfo('01437963-a', 118), SenseInfo('01433493-a', 105), SenseInfo('02386125-a', 2), SenseInfo('02005756-a', 0), SenseInfo('01444434-a', 0), SenseInfo('01444022-a', 0), SenseInfo('02274869-a', 0), SenseInfo('01895296-a', 0), SenseInfo('00015589-a', 0), SenseInfo('01437963-a', 118), SenseInfo('01433493-a', 105), SenseInfo('02386125-a', 2), SenseInfo('02005756-a', 0), SenseInfo('01444434-a', 0), SenseInfo('01444022-a', 0), SenseInfo('02274869-a', 0), SenseInfo('01895296-a', 0), SenseInfo('00015589-a', 0), SenseInfo('01437963-a', 118), SenseInfo('01433493-a', 105), SenseInfo('02386125-a', 2), SenseInfo('02005756-a', 0), SenseInfo('01444434-a', 0), SenseInfo('01444022-a', 0), SenseInfo('02274869-a', 0), SenseInfo('01895296-a', 0), SenseInfo('00015589-a', 0), SenseInfo('01437963-a', 118), SenseInfo('01433493-a', 105), SenseInfo('02386125-a', 2), SenseInfo('02005756-a', 0), SenseInfo('01444434-a', 0), SenseInfo('01444022-a', 0), SenseInfo('02274869-a', 0), SenseInfo('01895296-a', 0), SenseInfo('00015589-a', 0), SenseInfo('01437963-a', 118), SenseInfo('01433493-a', 105), SenseInfo('02386125-a', 2), SenseInfo('02005756-a', 0), SenseInfo('01444434-a', 0), SenseInfo('01444022-a', 0), SenseInfo('02274869-a', 0), SenseInfo('01895296-a', 0), SenseInfo('00015589-a', 0) ],
"_jolly+good_a_1_rel" : [  ],
"_used+to_v_qmodal_rel" : [  ],
"_quantifier_n_1_rel" : [ SenseInfo('06302542-n', 0), SenseInfo('06302381-n', 0) ],
"_type_n_1_rel" : [ SenseInfo('05840188-n', 136), SenseInfo('09909060-n', 7), SenseInfo('08111419-n', 0), SenseInfo('06825120-n', 0), SenseInfo('06795967-n', 0), SenseInfo('04504486-n', 0), SenseInfo('05840188-n', 136), SenseInfo('09909060-n', 7), SenseInfo('08111419-n', 0), SenseInfo('06825120-n', 0), SenseInfo('06795967-n', 0), SenseInfo('04504486-n', 0) ],
"_snag_n_1_rel" : [ SenseInfo('13895745-n', 0), SenseInfo('13103877-n', 0), SenseInfo('09410928-n', 0), SenseInfo('05691144-n', 0) ],
"_dihedral_a_1_rel" : [  ],
"_sprightly_a_1_rel" : [ SenseInfo('02280821-a', 1) ],
"_drake_n_1_rel" : [ SenseInfo('10942866-n', 0), SenseInfo('01847000-n', 0) ],
"_gag_v_1_rel" : [ SenseInfo('02190943-v', 1), SenseInfo('01570562-v', 0), SenseInfo('01284683-v', 0), SenseInfo('00853958-v', 0), SenseInfo('00077698-v', 0), SenseInfo('00077606-v', 0), SenseInfo('00077458-v', 0) ],
"_olden_a_1_rel" : [ SenseInfo('01730745-a', 0) ],
"_precipitous_a_1_rel" : [ SenseInfo('01270868-a', 0), SenseInfo('01145151-a', 0), SenseInfo('01270868-a', 0), SenseInfo('01145151-a', 0) ],
"_propel_n_1_rel" : [  ],
"_helpless_a_1_rel" : [ SenseInfo('01827946-a', 4), SenseInfo('01230616-a', 3), SenseInfo('00726317-a', 1), SenseInfo('01827946-a', 4), SenseInfo('01230616-a', 3), SenseInfo('00726317-a', 1) ],
"_porous_a_1_rel" : [ SenseInfo('01772305-a', 11), SenseInfo('00329396-a', 0), SenseInfo('01397998-a', 0) ],
"_incubate_v_cause_rel" : [ SenseInfo('00254150-v', 1), SenseInfo('00060185-v', 1) ],
"_yoga_n_1_rel" : [ SenseInfo('06239361-n', 1), SenseInfo('00630960-n', 0) ],
"_rearward_p_rel" : [ SenseInfo('00074407-r', 4), SenseInfo('08629746-n', 1), SenseInfo('00197891-a', 1), SenseInfo('00202250-a', 0) ],
"_lament_v_to_rel" : [ SenseInfo('01802219-v', 1), SenseInfo('00911350-v', 0), SenseInfo('01802219-v', 1), SenseInfo('00911350-v', 0) ],
"_buck_n_money_rel" : [ SenseInfo('04524142-n', 1), SenseInfo('13395897-n', 0), SenseInfo('10870235-n', 0), SenseInfo('04140631-n', 0), SenseInfo('01888264-n', 0) ],
"_plow_n_1_rel" : [ SenseInfo('03967562-n', 2) ],
"_anteater_n_1_rel" : [ SenseInfo('02461830-n', 1), SenseInfo('02460009-n', 0), SenseInfo('02082791-n', 0), SenseInfo('01885498-n', 0), SenseInfo('01872772-n', 0), SenseInfo('01872401-n', 0) ],
"_continuous_a_1_rel" : [ SenseInfo('00594413-a', 16), SenseInfo('00597424-a', 4), SenseInfo('00594413-a', 16), SenseInfo('00597424-a', 4) ],
"_nurture_n_of_rel" : [ SenseInfo('04922113-n', 0), SenseInfo('01129532-n', 0) ],
"_debut_v_1_rel" : [ SenseInfo('01718015-v', 2), SenseInfo('01717628-v', 1), SenseInfo('01717851-v', 0) ],
"_workaholic_a_1_rel" : [ SenseInfo('10791002-n', 0) ],
"_prospective_a_1_rel" : [ SenseInfo('01883898-a', 6) ],
"_cmon_a_1_rel" : [  ],
"_illuminate_v_1_rel" : [ SenseInfo('00291873-v', 9), SenseInfo('00621058-v', 5), SenseInfo('01683758-v', 0), SenseInfo('00291873-v', 9), SenseInfo('00621058-v', 5), SenseInfo('01683758-v', 0), SenseInfo('00291873-v', 9), SenseInfo('00621058-v', 5), SenseInfo('01683758-v', 0), SenseInfo('00291873-v', 9), SenseInfo('00621058-v', 5), SenseInfo('01683758-v', 0) ],
"_still_a_disc_rel" : [ SenseInfo('01564315-a', 16), SenseInfo('01919428-a', 9), SenseInfo('00302951-a', 3), SenseInfo('01565751-a', 2), SenseInfo('02277485-a', 0), SenseInfo('01241600-a', 0) ],
"_go_v_ing_rel" : [ SenseInfo('01835496-v', 343), SenseInfo('02372605-v', 95), SenseInfo('01848718-v', 49), SenseInfo('00149583-v', 29), SenseInfo('02653862-v', 14), SenseInfo('02721284-v', 10), SenseInfo('02685951-v', 10), SenseInfo('00341560-v', 10), SenseInfo('00359916-v', 9), SenseInfo('02618001-v', 7), SenseInfo('02176268-v', 3), SenseInfo('01525666-v', 3), SenseInfo('01192773-v', 3), SenseInfo('00539110-v', 3), SenseInfo('02618149-v', 2), SenseInfo('02617798-v', 2), SenseInfo('00358431-v', 2), SenseInfo('02737876-v', 1), SenseInfo('02729819-v', 1), SenseInfo('01864230-v', 1), SenseInfo('01076615-v', 1), SenseInfo('02700772-v', 0), SenseInfo('02700666-v', 0), SenseInfo('02700455-v', 0), SenseInfo('02686471-v', 0), SenseInfo('02659763-v', 0), SenseInfo('01318849-v', 0), SenseInfo('01192992-v', 0), SenseInfo('00676267-v', 0), SenseInfo('00434374-v', 0) ],
"_contemptuous_a_1_rel" : [ SenseInfo('01995288-a', 2) ],
"_perfectly_x_deg_rel" : [ SenseInfo('00008997-r', 13), SenseInfo('00009650-r', 2) ],
"_blemish_n_1_rel" : [ SenseInfo('04692157-n', 1) ],
"_suspicious_a_of_rel" : [ SenseInfo('02464277-a', 3), SenseInfo('01917594-a', 1) ],
"_transport_v_1_rel" : [ SenseInfo('01953810-v', 4), SenseInfo('01449974-v', 2), SenseInfo('01817314-v', 1), SenseInfo('01950798-v', 0), SenseInfo('01435380-v', 0), SenseInfo('01953810-v', 4), SenseInfo('01449974-v', 2), SenseInfo('01817314-v', 1), SenseInfo('01950798-v', 0), SenseInfo('01435380-v', 0), SenseInfo('01953810-v', 4), SenseInfo('01449974-v', 2), SenseInfo('01817314-v', 1), SenseInfo('01950798-v', 0), SenseInfo('01435380-v', 0) ],
"_historical_a_1_rel" : [ SenseInfo('02920121-a', 11), SenseInfo('01934284-a', 5), SenseInfo('01730060-a', 5), SenseInfo('02377418-a', 0), SenseInfo('02920121-a', 11), SenseInfo('01934284-a', 5), SenseInfo('01730060-a', 5), SenseInfo('02377418-a', 0) ],
"_note_n_i_rel" : [ SenseInfo('06504462-n', 14), SenseInfo('06626286-n', 13), SenseInfo('06865345-n', 4), SenseInfo('07082819-n', 3), SenseInfo('04727694-n', 2), SenseInfo('13393762-n', 1), SenseInfo('06763273-n', 1), SenseInfo('14435445-n', 0), SenseInfo('13398469-n', 0) ],
"_image_n_of_rel" : [ SenseInfo('05928118-n', 31), SenseInfo('04677716-n', 9), SenseInfo('03931044-n', 8), SenseInfo('05937524-n', 2), SenseInfo('07105475-n', 1), SenseInfo('10027246-n', 0), SenseInfo('08000304-n', 0), SenseInfo('04675777-n', 0), SenseInfo('03265874-n', 0) ],
"_chump_n_1_rel" : [ SenseInfo('09921409-n', 1) ],
"_sounding_n_1_rel" : [ SenseInfo('05135451-n', 0), SenseInfo('01004961-n', 0) ],
"_vaio_n_1_rel" : [  ],
"_boatbuilder_n_1_rel" : [ SenseInfo('09861863-n', 0) ],
"_vitamin+A_n_1_rel" : [  ],
"_campground_n_1_rel" : [ SenseInfo('08518171-n', 0) ],
"_zoom_n_1_rel" : [ SenseInfo('07375525-n', 0), SenseInfo('00326291-n', 0) ],
"_appetizing_a_1_rel" : [ SenseInfo('00133417-a', 0), SenseInfo('00133417-a', 0), SenseInfo('00133417-a', 0), SenseInfo('00133417-a', 0) ],
"_reimbursement_n_of_rel" : [ SenseInfo('13290002-n', 1) ],
"_past_n_1_rel" : [ SenseInfo('15120823-n', 42), SenseInfo('15141693-n', 5), SenseInfo('06330262-n', 1) ],
"_loop_n_1_rel" : [ SenseInfo('03132438-n', 1), SenseInfo('13875571-n', 0), SenseInfo('13504173-n', 0), SenseInfo('08241654-n', 0), SenseInfo('06644823-n', 0), SenseInfo('06572857-n', 0), SenseInfo('05730724-n', 0), SenseInfo('03689347-n', 0), SenseInfo('03048883-n', 0), SenseInfo('00169811-n', 0) ],
"_washer_n_of_rel" : [ SenseInfo('10768903-n', 0), SenseInfo('04554871-n', 0), SenseInfo('04554684-n', 0) ],
"_look_v_to_rel" : [ SenseInfo('02130524-v', 274), SenseInfo('02133435-v', 126), SenseInfo('00033599-v', 25), SenseInfo('02153709-v', 8), SenseInfo('02693319-v', 1), SenseInfo('02549581-v', 1), SenseInfo('00929362-v', 1), SenseInfo('00720063-v', 1), SenseInfo('02658447-v', 0), SenseInfo('00712708-v', 0) ],
"_rowboat_n_1_rel" : [ SenseInfo('03199901-n', 0) ],
"_anglo_n_1_rel" : [  ],
"_coniferous_a_1_rel" : [ SenseInfo('00913720-a', 0) ],
"_lively_a_1_rel" : [ SenseInfo('00804695-a', 7), SenseInfo('02280333-a', 0), SenseInfo('00874226-a', 0), SenseInfo('00843595-a', 0), SenseInfo('00804371-a', 0), SenseInfo('00119006-a', 0), SenseInfo('00804695-a', 7), SenseInfo('02280333-a', 0), SenseInfo('00874226-a', 0), SenseInfo('00843595-a', 0), SenseInfo('00804371-a', 0), SenseInfo('00119006-a', 0), SenseInfo('00804695-a', 7), SenseInfo('02280333-a', 0), SenseInfo('00874226-a', 0), SenseInfo('00843595-a', 0), SenseInfo('00804371-a', 0), SenseInfo('00119006-a', 0) ],
"_spread_n_of_rel" : [ SenseInfo('07445896-n', 3), SenseInfo('04752859-n', 3), SenseInfo('04052442-n', 2), SenseInfo('05088324-n', 1), SenseInfo('07856270-n', 0), SenseInfo('07578093-n', 0), SenseInfo('06258031-n', 0), SenseInfo('05101512-n', 0), SenseInfo('02822220-n', 0), SenseInfo('00367976-n', 0) ],
"_lurk_v_1_rel" : [ SenseInfo('02640053-v', 8), SenseInfo('02639075-v', 1), SenseInfo('01138204-v', 0) ],
"_verb_n_1_rel" : [ SenseInfo('06318062-n', 6), SenseInfo('06320569-n', 5) ],
"_except+for_p_rel" : [  ],
"_long-term_a_1_rel" : [ SenseInfo('01441000-a', 6), SenseInfo('01441000-a', 6) ],
"_after_p_n-n_rel" : [ SenseInfo('00061203-r', 5), SenseInfo('00508070-r', 0), SenseInfo('01033542-a', 0) ],
"_impeach_v_1_rel" : [ SenseInfo('00867843-v', 0), SenseInfo('00844744-v', 0), SenseInfo('00842989-v', 0) ],
"_exact_a_same-as_rel" : [ SenseInfo('00914421-a', 8), SenseInfo('00631798-a', 7) ],
"_cognitive_a_1_rel" : [ SenseInfo('02898584-a', 0) ],
"_negro_n_1_rel" : [ SenseInfo('09636339-n', 22) ],
"_let_v_i_rel" : [ SenseInfo('02423183-v', 219), SenseInfo('00771490-v', 15), SenseInfo('00802318-v', 2), SenseInfo('00120796-v', 2), SenseInfo('00496673-v', 1), SenseInfo('02208903-v', 0) ],
"_enquire_v_about_rel" : [ SenseInfo('00784342-v', 1), SenseInfo('00785962-v', 0), SenseInfo('00729378-v', 0) ],
"_turn_v_around_rel" : [ SenseInfo('01907258-v', 187), SenseInfo('00146138-v', 21), SenseInfo('02626604-v', 12), SenseInfo('02089984-v', 8), SenseInfo('00138508-v', 7), SenseInfo('01909812-v', 5), SenseInfo('00125841-v', 5), SenseInfo('01436518-v', 2), SenseInfo('02096167-v', 1), SenseInfo('02089420-v', 1), SenseInfo('01952208-v', 1), SenseInfo('01741864-v', 1), SenseInfo('01584450-v', 1), SenseInfo('00282523-v', 1), SenseInfo('00091124-v', 1), SenseInfo('02626934-v', 0), SenseInfo('02562425-v', 0), SenseInfo('02211948-v', 0), SenseInfo('02090435-v', 0), SenseInfo('01951937-v', 0), SenseInfo('01280014-v', 0), SenseInfo('01225215-v', 0), SenseInfo('01151889-v', 0), SenseInfo('00794640-v', 0), SenseInfo('00458471-v', 0), SenseInfo('00248387-v', 0) ],
"_mere_a_1_rel" : [ SenseInfo('01099707-a', 22), SenseInfo('01792573-a', 4), SenseInfo('01099707-a', 22), SenseInfo('01792573-a', 4), SenseInfo('01099707-a', 22), SenseInfo('01792573-a', 4) ],
"_riddled_a_with_rel" : [ SenseInfo('00680791-a', 1), SenseInfo('01085937-a', 0) ],
"_propagandist_a_1_rel" : [ SenseInfo('03022739-a', 0) ],
"_maybe_a_1_rel" : [  ],
"_iambic_a_1_rel" : [ SenseInfo('02897040-a', 0) ],
"_convoy_n_1_rel" : [ SenseInfo('08417801-n', 1), SenseInfo('08417673-n', 0), SenseInfo('00827974-n', 0) ],
"_compatriot_n_1_rel" : [ SenseInfo('09970699-n', 1) ],
"_this_q_dem_rel" : [  ],
"_indorse_v_1_rel" : [ SenseInfo('02453889-v', 1), SenseInfo('02556817-v', 0), SenseInfo('02447793-v', 0), SenseInfo('00997794-v', 0) ],
"_to+our+knowledge_a_1_rel" : [  ],
"_sensation_n_of_rel" : [ SenseInfo('05712076-n', 14), SenseInfo('09762509-n', 1), SenseInfo('07514782-n', 1), SenseInfo('14037480-n', 0), SenseInfo('05651971-n', 0), SenseInfo('05712076-n', 14), SenseInfo('09762509-n', 1), SenseInfo('07514782-n', 1), SenseInfo('14037480-n', 0), SenseInfo('05651971-n', 0) ],
"_thigh_n_1_rel" : [ SenseInfo('05562249-n', 9), SenseInfo('07648267-n', 0) ],
"_crop_v_1_rel" : [ SenseInfo('01553761-v', 1), SenseInfo('01741446-v', 0), SenseInfo('01652537-v', 0), SenseInfo('01576478-v', 0), SenseInfo('01576165-v', 0), SenseInfo('01321002-v', 0) ],
"_useful_a_for_rel" : [ SenseInfo('02495922-a', 16), SenseInfo('01090820-a', 0), SenseInfo('02495922-a', 16), SenseInfo('01090820-a', 0) ],
"_concern_v_about_rel" : [ SenseInfo('02676054-v', 56), SenseInfo('02678438-v', 22) ],
"_cinder_n_1_rel" : [ SenseInfo('09245212-n', 0) ],
"_newborn_a_1_rel" : [ SenseInfo('01649184-a', 4), SenseInfo('01641921-a', 2), SenseInfo('01649184-a', 4), SenseInfo('01641921-a', 2), SenseInfo('01649184-a', 4), SenseInfo('01641921-a', 2) ],
"_staff_v_1_rel" : [ SenseInfo('01088749-v', 4), SenseInfo('01095739-v', 0) ],
"_in+place+of_p_rel" : [  ],
"_cooperative_a_1_rel" : [ SenseInfo('02112108-a', 7), SenseInfo('00619972-a', 3), SenseInfo('00513388-a', 0), SenseInfo('02112108-a', 7), SenseInfo('00619972-a', 3), SenseInfo('00513388-a', 0) ],
"_for+lack+of_p_rel" : [  ],
"_situation_n_1_rel" : [ SenseInfo('13927383-n', 66), SenseInfo('13925752-n', 18), SenseInfo('14411243-n', 0), SenseInfo('08622950-n', 0), SenseInfo('00586262-n', 0), SenseInfo('13927383-n', 66), SenseInfo('13925752-n', 18), SenseInfo('14411243-n', 0), SenseInfo('08622950-n', 0), SenseInfo('00586262-n', 0), SenseInfo('13927383-n', 66), SenseInfo('13925752-n', 18), SenseInfo('14411243-n', 0), SenseInfo('08622950-n', 0), SenseInfo('00586262-n', 0) ],
"_hum_v_1_rel" : [ SenseInfo('01055829-v', 4), SenseInfo('02706605-v', 0), SenseInfo('02187041-v', 0), SenseInfo('01056214-v', 0) ],
"_distressed_a_1_rel" : [ SenseInfo('02457558-a', 1), SenseInfo('00909363-a', 0), SenseInfo('02458497-a', 0), SenseInfo('02457167-a', 0) ],
"_facial_n_1_rel" : [ SenseInfo('05479314-n', 0), SenseInfo('00665781-n', 0) ],
"_redundant_a_1_rel" : [ SenseInfo('01581305-a', 2), SenseInfo('00549826-a', 0) ],
"_catalogue_n_of_rel" : [ SenseInfo('06487897-n', 4), SenseInfo('06416206-n', 0), SenseInfo('06487897-n', 4), SenseInfo('06416206-n', 0) ],
"_arch_v_1_rel" : [ SenseInfo('02034986-v', 3) ],
"_fret_v_about_rel" : [ SenseInfo('01793933-v', 3), SenseInfo('01767461-v', 2), SenseInfo('02330109-v', 0), SenseInfo('02119659-v', 0), SenseInfo('01789164-v', 0), SenseInfo('01773825-v', 0), SenseInfo('01752025-v', 0), SenseInfo('01751722-v', 0), SenseInfo('01570562-v', 0), SenseInfo('01250908-v', 0), SenseInfo('00274724-v', 0), SenseInfo('00274633-v', 0) ],
"_omelette_n_1_rel" : [ SenseInfo('07842753-n', 0) ],
"_opposition_n_1_rel" : [ SenseInfo('00202284-n', 7), SenseInfo('13854649-n', 4), SenseInfo('01169744-n', 3), SenseInfo('10379620-n', 1), SenseInfo('08403787-n', 1), SenseInfo('13828905-n', 0), SenseInfo('10055847-n', 0), SenseInfo('08404188-n', 0) ],
"_carve_v_out_rel" : [ SenseInfo('01256157-v', 9), SenseInfo('01256600-v', 3), SenseInfo('01255967-v', 0) ],
"_simultaneous_a_1_rel" : [ SenseInfo('02378496-a', 4), SenseInfo('02378496-a', 4), SenseInfo('02378496-a', 4), SenseInfo('02378496-a', 4) ],
"_blame_n_1_rel" : [ SenseInfo('07237758-n', 3), SenseInfo('06713752-n', 2) ],
"_as+opposed+to_p_rel" : [  ],
"_scroll_n_1_rel" : [ SenseInfo('13875970-n', 0), SenseInfo('06407733-n', 0) ],
"_ring_v_cause_rel" : [ SenseInfo('02180898-v', 15), SenseInfo('02183787-v', 7), SenseInfo('02181538-v', 5), SenseInfo('00789448-v', 1), SenseInfo('01467370-v', 0), SenseInfo('01297401-v', 0) ],
"_honeysuckle_n_1_rel" : [ SenseInfo('12674120-n', 1), SenseInfo('12215824-n', 0), SenseInfo('11727358-n', 0) ],
"_new-fangled_a_1_rel" : [ SenseInfo('01687965-a', 0), SenseInfo('01687965-a', 0) ],
"_fore_n_1_rel" : [ SenseInfo('02880008-n', 0) ],
"_stake_n_1_rel" : [ SenseInfo('13286801-n', 2), SenseInfo('07257815-n', 1), SenseInfo('04298906-n', 1), SenseInfo('13343526-n', 0), SenseInfo('04298765-n', 0), SenseInfo('13286801-n', 2), SenseInfo('07257815-n', 1), SenseInfo('04298906-n', 1), SenseInfo('13343526-n', 0), SenseInfo('04298765-n', 0), SenseInfo('13286801-n', 2), SenseInfo('07257815-n', 1), SenseInfo('04298906-n', 1), SenseInfo('13343526-n', 0), SenseInfo('04298765-n', 0), SenseInfo('13286801-n', 2), SenseInfo('07257815-n', 1), SenseInfo('04298906-n', 1), SenseInfo('13343526-n', 0), SenseInfo('04298765-n', 0) ],
"_quasi_a_1_rel" : [ SenseInfo('02072806-a', 4), SenseInfo('02072806-a', 4), SenseInfo('02072806-a', 4) ],
"_dual_a_1_rel" : [ SenseInfo('02217452-a', 3), SenseInfo('02217799-a', 0), SenseInfo('02183135-a', 0) ],
"_awhile+ago_p_rel" : [  ],
"_predictable_a_to_rel" : [ SenseInfo('01841544-a', 5), SenseInfo('01841544-a', 5) ],
"_amorous_a_1_rel" : [ SenseInfo('01465061-a', 1), SenseInfo('01465214-a', 0) ],
"_imitate_v_1_rel" : [ SenseInfo('01742886-v', 4), SenseInfo('02674879-v', 2), SenseInfo('01694263-v', 0) ],
"_hear_v_about_rel" : [ SenseInfo('02169702-v', 275), SenseInfo('00598954-v', 60), SenseInfo('02500902-v', 12), SenseInfo('02107442-v', 8), SenseInfo('02171039-v', 0) ],
"_medicament_n_1_rel" : [ SenseInfo('03740161-n', 0) ],
"_minnow_n_1_rel" : [ SenseInfo('01442972-n', 0) ],
"_ramp_v_up_rel" : [ SenseInfo('02723016-v', 0), SenseInfo('02334595-v', 0), SenseInfo('02143124-v', 0), SenseInfo('01922754-v', 0), SenseInfo('01546513-v', 0), SenseInfo('02723016-v', 0), SenseInfo('02334595-v', 0), SenseInfo('02143124-v', 0), SenseInfo('01922754-v', 0), SenseInfo('01546513-v', 0) ],
"_graveyard_n_1_rel" : [ SenseInfo('08521623-n', 3) ],
"_geld_v_1_rel" : [ SenseInfo('00061219-v', 0) ],
"_disciple_n_1_rel" : [ SenseInfo('10016103-n', 1) ],
"_in+situ_a_1_rel" : [ SenseInfo('00353604-a', 0), SenseInfo('00353604-a', 0) ],
"_willy-nilly_a_1_rel" : [  ],
"_waterway_n_1_rel" : [ SenseInfo('09476331-n', 1), SenseInfo('04559275-n', 0) ],
"_yep_a_1_rel" : [  ],
"_stick_v_by_rel" : [ SenseInfo('01528069-v', 5), SenseInfo('01857392-v', 2), SenseInfo('01356750-v', 2), SenseInfo('02754032-v', 0), SenseInfo('02647798-v', 0), SenseInfo('02638845-v', 0), SenseInfo('02638630-v', 0), SenseInfo('01667969-v', 0), SenseInfo('01614581-v', 0), SenseInfo('01614426-v', 0), SenseInfo('01614235-v', 0), SenseInfo('01441993-v', 0), SenseInfo('01441793-v', 0), SenseInfo('01220885-v', 0), SenseInfo('00748084-v', 0), SenseInfo('00622384-v', 0) ],
"_push_v_1_rel" : [ SenseInfo('01871979-v', 56), SenseInfo('00765977-v', 7), SenseInfo('00976653-v', 6), SenseInfo('02406916-v', 3), SenseInfo('01872645-v', 3), SenseInfo('02054864-v', 1), SenseInfo('02589576-v', 0), SenseInfo('02245555-v', 0), SenseInfo('01872877-v', 0), SenseInfo('01447632-v', 0), SenseInfo('01871979-v', 56), SenseInfo('00765977-v', 7), SenseInfo('00976653-v', 6), SenseInfo('02406916-v', 3), SenseInfo('01872645-v', 3), SenseInfo('02054864-v', 1), SenseInfo('02589576-v', 0), SenseInfo('02245555-v', 0), SenseInfo('01872877-v', 0), SenseInfo('01447632-v', 0) ],
"_interchange_v_cause_rel" : [ SenseInfo('02257767-v', 0), SenseInfo('02257370-v', 0), SenseInfo('00121926-v', 0), SenseInfo('00121678-v', 0) ],
"_botanist_n_1_rel" : [ SenseInfo('09868270-n', 0) ],
"_fibreglass_n_1_rel" : [ SenseInfo('14866769-n', 0) ],
"_soldiery_n_1_rel" : [ SenseInfo('08397255-n', 2), SenseInfo('08397255-n', 2) ],
"_yokel_n_1_rel" : [ SenseInfo('10804102-n', 2) ],
"_centenarian_n_1_rel" : [ SenseInfo('09904208-n', 0) ],
"_pioneer_v_1_rel" : [ SenseInfo('01645421-v', 3), SenseInfo('01641914-v', 0), SenseInfo('00649757-v', 0), SenseInfo('01645421-v', 3), SenseInfo('01641914-v', 0), SenseInfo('00649757-v', 0) ],
"_chaos_n_of_rel" : [ SenseInfo('13976322-n', 12), SenseInfo('11434899-n', 0), SenseInfo('09557770-n', 0), SenseInfo('06246529-n', 0), SenseInfo('13976322-n', 12), SenseInfo('11434899-n', 0), SenseInfo('09557770-n', 0), SenseInfo('06246529-n', 0) ],
"_pragmatic_a_1_rel" : [ SenseInfo('01835409-a', 2), SenseInfo('02783085-a', 0), SenseInfo('01940651-a', 0) ],
"_added_a_1_rel" : [  ],
"_clog_v_cause_rel" : [ SenseInfo('01478603-v', 4), SenseInfo('01709931-v', 0), SenseInfo('01301230-v', 0), SenseInfo('00441007-v', 0), SenseInfo('00368367-v', 0), SenseInfo('00182037-v', 0) ],
"_science_n_1_rel" : [ SenseInfo('05999797-n', 5), SenseInfo('05636887-n', 1), SenseInfo('05999797-n', 5), SenseInfo('05636887-n', 1), SenseInfo('05999797-n', 5), SenseInfo('05636887-n', 1) ],
"_bang_v_up_rel" : [ SenseInfo('01242391-v', 3), SenseInfo('02187693-v', 2), SenseInfo('01242832-v', 2), SenseInfo('02100176-v', 1), SenseInfo('01426397-v', 0), SenseInfo('01236941-v', 0) ],
"_mortgage_v_1_rel" : [ SenseInfo('02351737-v', 0) ],
"_utility_n_1_rel" : [ SenseInfo('08185758-n', 6), SenseInfo('05148699-n', 1), SenseInfo('00579334-n', 1), SenseInfo('13580058-n', 0), SenseInfo('06581410-n', 0), SenseInfo('04516874-n', 0), SenseInfo('08185758-n', 6), SenseInfo('05148699-n', 1), SenseInfo('00579334-n', 1), SenseInfo('13580058-n', 0), SenseInfo('06581410-n', 0), SenseInfo('04516874-n', 0), SenseInfo('08185758-n', 6), SenseInfo('05148699-n', 1), SenseInfo('00579334-n', 1), SenseInfo('13580058-n', 0), SenseInfo('06581410-n', 0), SenseInfo('04516874-n', 0) ],
"_wedlock_n_1_rel" : [ SenseInfo('13963970-n', 0) ],
"_jasmine_n_1_rel" : [ SenseInfo('12306717-n', 0) ],
"_repetition_n_of_rel" : [ SenseInfo('07342049-n', 6), SenseInfo('01018630-n', 4), SenseInfo('07099271-n', 1) ],
"_radial_a_1_rel" : [ SenseInfo('02836910-a', 1), SenseInfo('02836757-a', 1), SenseInfo('02836626-a', 0), SenseInfo('02373055-a', 0), SenseInfo('02836910-a', 1), SenseInfo('02836757-a', 1), SenseInfo('02836626-a', 0), SenseInfo('02373055-a', 0) ],
"_fork_n_1_rel" : [ SenseInfo('03383948-n', 4), SenseInfo('00388392-n', 2), SenseInfo('13914265-n', 1), SenseInfo('03384167-n', 1), SenseInfo('05597436-n', 0) ],
"_subject_n_of_rel" : [ SenseInfo('06599788-n', 20), SenseInfo('04347225-n', 14), SenseInfo('05996646-n', 11), SenseInfo('05814291-n', 9), SenseInfo('06309931-n', 4), SenseInfo('10668666-n', 2), SenseInfo('09625401-n', 2), SenseInfo('06310125-n', 0) ],
"_mathematical_a_1_rel" : [ SenseInfo('02937876-a', 3), SenseInfo('02230795-a', 0), SenseInfo('01918771-a', 0), SenseInfo('01822933-a', 0), SenseInfo('00915141-a', 0) ],
"_lighting_n_1_rel" : [ SenseInfo('13983304-n', 3), SenseInfo('03667235-n', 2), SenseInfo('00608645-n', 1), SenseInfo('00378479-n', 0) ],
"_dangle_v_1_rel" : [ SenseInfo('02717472-v', 3), SenseInfo('01482285-v', 2) ],
"_library_n_of_rel" : [ SenseInfo('03660909-n', 3), SenseInfo('07977870-n', 2), SenseInfo('03660664-n', 2), SenseInfo('07977592-n', 0), SenseInfo('03661043-n', 0), SenseInfo('03660909-n', 3), SenseInfo('07977870-n', 2), SenseInfo('03660664-n', 2), SenseInfo('07977592-n', 0), SenseInfo('03661043-n', 0) ],
"_flowerless_a_1_rel" : [ SenseInfo('02597951-a', 0) ],
"_generally_x_rel" : [ SenseInfo('00155621-r', 37), SenseInfo('00041954-r', 11), SenseInfo('00221583-r', 2) ],
"_walk_n_1_rel" : [ SenseInfo('00283568-n', 4), SenseInfo('00127286-n', 4), SenseInfo('05003090-n', 3), SenseInfo('00284798-n', 2), SenseInfo('04544979-n', 1), SenseInfo('00287142-n', 1), SenseInfo('00584248-n', 0) ],
"_harass_v_1_rel" : [ SenseInfo('01789514-v', 0), SenseInfo('01120759-v', 0), SenseInfo('01789514-v', 0), SenseInfo('01120759-v', 0) ],
"_deliverable_a_1_rel" : [ SenseInfo('02710438-a', 0) ],
"_the+worst_a_1_rel" : [ SenseInfo('00229630-a', 9) ],
"_entice_v_into_rel" : [ SenseInfo('00782527-v', 1), SenseInfo('00782527-v', 1), SenseInfo('00782527-v', 1), SenseInfo('00782527-v', 1), SenseInfo('00782527-v', 1) ],
"_frown_v_1_rel" : [ SenseInfo('00032981-v', 12) ],
"_polyatomic_a_1_rel" : [ SenseInfo('02885076-a', 0) ],
"_discover_v_1_rel" : [ SenseInfo('02154508-v', 21), SenseInfo('00598954-v', 21), SenseInfo('01637982-v', 18), SenseInfo('00721437-v', 16), SenseInfo('02286687-v', 6), SenseInfo('00933821-v', 4), SenseInfo('02128066-v', 1), SenseInfo('00652346-v', 0), SenseInfo('02154508-v', 21), SenseInfo('00598954-v', 21), SenseInfo('01637982-v', 18), SenseInfo('00721437-v', 16), SenseInfo('02286687-v', 6), SenseInfo('00933821-v', 4), SenseInfo('02128066-v', 1), SenseInfo('00652346-v', 0), SenseInfo('02154508-v', 21), SenseInfo('00598954-v', 21), SenseInfo('01637982-v', 18), SenseInfo('00721437-v', 16), SenseInfo('02286687-v', 6), SenseInfo('00933821-v', 4), SenseInfo('02128066-v', 1), SenseInfo('00652346-v', 0), SenseInfo('02154508-v', 21), SenseInfo('00598954-v', 21), SenseInfo('01637982-v', 18), SenseInfo('00721437-v', 16), SenseInfo('02286687-v', 6), SenseInfo('00933821-v', 4), SenseInfo('02128066-v', 1), SenseInfo('00652346-v', 0), SenseInfo('02154508-v', 21), SenseInfo('00598954-v', 21), SenseInfo('01637982-v', 18), SenseInfo('00721437-v', 16), SenseInfo('02286687-v', 6), SenseInfo('00933821-v', 4), SenseInfo('02128066-v', 1), SenseInfo('00652346-v', 0) ],
"_recurrence_n_1_rel" : [ SenseInfo('07343363-n', 1) ],
"_not+only_x_deg_rel" : [ SenseInfo('00004722-r', 258), SenseInfo('00008600-r', 226), SenseInfo('00010759-r', 13), SenseInfo('00010914-r', 6), SenseInfo('00028319-r', 4), SenseInfo('00505114-r', 2), SenseInfo('00011011-r', 0), SenseInfo('02214736-a', 0), SenseInfo('01862697-a', 0) ],
"_climate_n_1_rel" : [ SenseInfo('14519366-n', 5), SenseInfo('14524661-n', 3) ],
"_form_v_1_rel" : [ SenseInfo('02448185-v', 28), SenseInfo('02621395-v', 26), SenseInfo('02623906-v', 18), SenseInfo('00142191-v', 12), SenseInfo('01659248-v', 11), SenseInfo('02430922-v', 3), SenseInfo('00144850-v', 0) ],
"_rocky_a_1_rel" : [ SenseInfo('02241988-a', 3), SenseInfo('02243567-a', 0), SenseInfo('02293141-a', 0), SenseInfo('00747910-a', 0), SenseInfo('02241988-a', 3), SenseInfo('02243567-a', 0), SenseInfo('02293141-a', 0), SenseInfo('00747910-a', 0), SenseInfo('02241988-a', 3), SenseInfo('02243567-a', 0), SenseInfo('02293141-a', 0), SenseInfo('00747910-a', 0) ],
"_firmware_n_1_rel" : [ SenseInfo('06357814-n', 0) ],
"_gen_n_abb_rel" : [ SenseInfo('06637677-n', 0), SenseInfo('06637677-n', 0) ],
"_short-circuit_v_1_rel" : [ SenseInfo('02558811-v', 0), SenseInfo('01618884-v', 0), SenseInfo('00811171-v', 0), SenseInfo('02558811-v', 0), SenseInfo('01618884-v', 0), SenseInfo('00811171-v', 0) ],
"_bandage_n_1_rel" : [ SenseInfo('02785648-n', 6) ],
"_agile_a_1_rel" : [ SenseInfo('00032733-a', 1), SenseInfo('01334833-a', 0) ],
"_gild_v_1_rel" : [ SenseInfo('01683101-v', 1) ],
"_proceed_v_1_rel" : [ SenseInfo('00781000-v', 19), SenseInfo('01995549-v', 17), SenseInfo('02372605-v', 8), SenseInfo('00341560-v', 3), SenseInfo('02684924-v', 1), SenseInfo('00781000-v', 19), SenseInfo('01995549-v', 17), SenseInfo('02372605-v', 8), SenseInfo('00341560-v', 3), SenseInfo('02684924-v', 1) ],
"_plot_v_1_rel" : [ SenseInfo('00708128-v', 6), SenseInfo('01693453-v', 2), SenseInfo('00710922-v', 1), SenseInfo('01638825-v', 0), SenseInfo('00708128-v', 6), SenseInfo('01693453-v', 2), SenseInfo('00710922-v', 1), SenseInfo('01638825-v', 0) ],
"_excellence_n_1_rel" : [ SenseInfo('04728786-n', 2), SenseInfo('05851744-n', 0) ],
"_fling_n_1_rel" : [ SenseInfo('00787061-n', 0), SenseInfo('00510475-n', 0), SenseInfo('00105164-n', 0) ],
"_taste_n_of_rel" : [ SenseInfo('05715283-n', 8), SenseInfo('07498210-n', 7), SenseInfo('05749619-n', 3), SenseInfo('07288024-n', 1), SenseInfo('07578879-n', 0), SenseInfo('05658226-n', 0), SenseInfo('00882702-n', 0) ],
"_kind_n_of-n_rel" : [ SenseInfo('05839024-n', 126), SenseInfo('05839024-n', 126), SenseInfo('05839024-n', 126) ],
"_restart_n_1_rel" : [  ],
"_yo_a_1_rel" : [  ],
"_haven_n_1_rel" : [ SenseInfo('03499796-n', 1), SenseInfo('08639058-n', 0) ],
"_knight_n_1_rel" : [ SenseInfo('10238375-n', 3), SenseInfo('03624767-n', 0) ],
"_shutter_n_1_rel" : [ SenseInfo('04211528-n', 5), SenseInfo('04211356-n', 5) ],
"_carol_v_1_rel" : [ SenseInfo('01731828-v', 0) ],
"_befogged_a_1_rel" : [ SenseInfo('00436385-a', 0) ],
"_squirrel_n_1_rel" : [ SenseInfo('02355227-n', 3), SenseInfo('14766189-n', 0) ],
"_appraisal_n_of_rel" : [ SenseInfo('05733583-n', 1), SenseInfo('06528783-n', 0), SenseInfo('00875519-n', 0) ],
"_over_a_1_rel" : [ SenseInfo('01003277-a', 21) ],
"_out+of+state_a_1_rel" : [  ],
"_counter_v_1_rel" : [ SenseInfo('00815379-v', 2), SenseInfo('02565491-v', 1), SenseInfo('00815379-v', 2), SenseInfo('02565491-v', 1) ],
"_mail_v_1_rel" : [ SenseInfo('01437888-v', 12), SenseInfo('01031256-v', 0), SenseInfo('01437888-v', 12), SenseInfo('01031256-v', 0) ],
"_back_v_out_rel" : [ SenseInfo('02453889-v', 7), SenseInfo('01997119-v', 6), SenseInfo('02556817-v', 4), SenseInfo('01997512-v', 4), SenseInfo('02217695-v', 2), SenseInfo('02693965-v', 0), SenseInfo('01139104-v', 0), SenseInfo('00560628-v', 0), SenseInfo('00223109-v', 0), SenseInfo('00185857-v', 0) ],
"_disciplinary_a_1_rel" : [ SenseInfo('03061455-a', 0), SenseInfo('03061081-a', 0), SenseInfo('01300661-a', 0) ],
"_itch_n_1_rel" : [ SenseInfo('14180327-n', 0), SenseInfo('07490451-n', 0), SenseInfo('05723563-n', 0) ],
"_caress_v_1_rel" : [ SenseInfo('01226215-v', 5) ],
"_east+west_a_1_rel" : [  ],
"_arrogance_n_1_rel" : [ SenseInfo('04887912-n', 1) ],
"_train_n_of_rel" : [ SenseInfo('04468005-n', 24), SenseInfo('08459648-n', 1), SenseInfo('08427629-n', 0), SenseInfo('07294777-n', 0), SenseInfo('04468476-n', 0), SenseInfo('03431745-n', 0) ],
"_duodenal_a_1_rel" : [ SenseInfo('02908647-a', 0) ],
"_care_n_1_rel" : [ SenseInfo('00654885-n', 9), SenseInfo('05615869-n', 4), SenseInfo('07524529-n', 1), SenseInfo('07505047-n', 1), SenseInfo('00829378-n', 1), SenseInfo('00267522-n', 1) ],
"_ground_v_out_rel" : [ SenseInfo('01304944-v', 2), SenseInfo('01502762-v', 1), SenseInfo('01502654-v', 1), SenseInfo('00830648-v', 1), SenseInfo('02022486-v', 0), SenseInfo('02022359-v', 0), SenseInfo('01406684-v', 0), SenseInfo('01406512-v', 0), SenseInfo('01406356-v', 0), SenseInfo('01365355-v', 0), SenseInfo('01292534-v', 0), SenseInfo('00636888-v', 0) ],
"_picturebook_n_of_rel" : [  ],
"_ship_v_1_rel" : [ SenseInfo('01950798-v', 7), SenseInfo('02409838-v', 0), SenseInfo('01979462-v', 0), SenseInfo('01847582-v', 0), SenseInfo('01496978-v', 0) ],
"_ambitious_a_1_rel" : [ SenseInfo('00104051-a', 5), SenseInfo('00745642-a', 4) ],
"_prejudice_v_1_rel" : [ SenseInfo('02513742-v', 0), SenseInfo('00680145-v', 0) ],
"_watertight_a_1_rel" : [ SenseInfo('01399235-a', 0), SenseInfo('00591513-a', 0) ],
"thing_rel" : [  ],
"_bogus_a_1_rel" : [ SenseInfo('01117477-a', 3) ],
"_railroad_n_1_rel" : [ SenseInfo('04048568-n', 13), SenseInfo('04048075-n', 0) ],
"_endoscopic_a_1_rel" : [ SenseInfo('03063601-a', 0) ],
"_punctuation_n_1_rel" : [ SenseInfo('07368130-n', 0), SenseInfo('06841365-n', 0), SenseInfo('00390198-n', 0) ],
"_wind_v_1_rel" : [ SenseInfo('01882814-v', 3), SenseInfo('02738701-v', 2), SenseInfo('01522276-v', 2), SenseInfo('02125223-v', 0), SenseInfo('01522052-v', 0), SenseInfo('01516965-v', 0), SenseInfo('01455184-v', 0), SenseInfo('01882814-v', 3), SenseInfo('02738701-v', 2), SenseInfo('01522276-v', 2), SenseInfo('02125223-v', 0), SenseInfo('01522052-v', 0), SenseInfo('01516965-v', 0), SenseInfo('01455184-v', 0) ],
"_vault_n_1_rel" : [ SenseInfo('04523690-n', 1), SenseInfo('04523831-n', 0), SenseInfo('04523525-n', 0), SenseInfo('00120515-n', 0) ],
"_climax_v_1_rel" : [ SenseInfo('00485609-v', 2) ],
"_archipelago_n_1_rel" : [ SenseInfo('09203827-n', 0) ],
"_grudging_a_1_rel" : [ SenseInfo('02566299-a', 0), SenseInfo('01113636-a', 0) ],
"_outlook_n_1_rel" : [ SenseInfo('06195839-n', 11), SenseInfo('05944958-n', 5), SenseInfo('00881545-n', 0) ],
"_inward_a_1_rel" : [ SenseInfo('00951247-a', 5), SenseInfo('01294583-a', 0), SenseInfo('00951247-a', 5), SenseInfo('01294583-a', 0) ],
"_gamble_v_1_rel" : [ SenseInfo('02544348-v', 2), SenseInfo('01138523-v', 0) ],
"_nonexistent_a_1_rel" : [ SenseInfo('00927578-a', 3) ],
"_less+than_x_rel" : [  ],
"_sexuality_n_1_rel" : [ SenseInfo('05006898-n', 0) ],
"_heath_n_1_rel" : [ SenseInfo('12226932-n', 0), SenseInfo('08504851-n', 0) ],
"_pitch_v_in_rel" : [ SenseInfo('01512625-v', 6), SenseInfo('01864634-v', 5), SenseInfo('01978436-v', 2), SenseInfo('00298420-v', 1), SenseInfo('02302817-v', 0), SenseInfo('02037090-v', 0), SenseInfo('01884577-v', 0), SenseInfo('01514126-v', 0), SenseInfo('01509079-v', 0), SenseInfo('01402637-v', 0), SenseInfo('01149868-v', 0), SenseInfo('00298244-v', 0) ],
"_economist_n_1_rel" : [ SenseInfo('10043643-n', 4) ],
"_variegate_v_1_rel" : [ SenseInfo('00581509-v', 0), SenseInfo('00436879-v', 0) ],
"_contrary_a_to_rel" : [ SenseInfo('02065958-a', 5), SenseInfo('02382396-a', 1), SenseInfo('01613839-a', 0), SenseInfo('00995647-a', 0) ],
"_jointing_n_1_rel" : [  ],
"_reappearance_n_1_rel" : [ SenseInfo('07321967-n', 1), SenseInfo('00050887-n', 0) ],
"_picture_v_1_rel" : [ SenseInfo('01635432-v', 5), SenseInfo('01686956-v', 4) ],
"_reassure_v_1_rel" : [ SenseInfo('01766407-v', 5), SenseInfo('01019808-v', 1), SenseInfo('01766407-v', 5), SenseInfo('01019808-v', 1), SenseInfo('01766407-v', 5), SenseInfo('01019808-v', 1), SenseInfo('01766407-v', 5), SenseInfo('01019808-v', 1), SenseInfo('01766407-v', 5), SenseInfo('01019808-v', 1), SenseInfo('01766407-v', 5), SenseInfo('01019808-v', 1), SenseInfo('01766407-v', 5), SenseInfo('01019808-v', 1) ],
"_bawl_v_1_rel" : [ SenseInfo('01048569-v', 8), SenseInfo('01046480-v', 0), SenseInfo('00066862-v', 0) ],
"_test_v_1_rel" : [ SenseInfo('02531625-v', 32), SenseInfo('02533109-v', 9), SenseInfo('00786458-v', 4), SenseInfo('02745713-v', 0), SenseInfo('01112584-v', 0), SenseInfo('00920778-v', 0), SenseInfo('00669970-v', 0), SenseInfo('02531625-v', 32), SenseInfo('02533109-v', 9), SenseInfo('00786458-v', 4), SenseInfo('02745713-v', 0), SenseInfo('01112584-v', 0), SenseInfo('00920778-v', 0), SenseInfo('00669970-v', 0), SenseInfo('02531625-v', 32), SenseInfo('02533109-v', 9), SenseInfo('00786458-v', 4), SenseInfo('02745713-v', 0), SenseInfo('01112584-v', 0), SenseInfo('00920778-v', 0), SenseInfo('00669970-v', 0) ],
"_rifle_n_1_rel" : [ SenseInfo('04090263-n', 75) ],
"_dodge_v_1_rel" : [ SenseInfo('02096494-v', 6), SenseInfo('02096670-v', 1), SenseInfo('00809654-v', 1) ],
"_centimeter_n_1_rel" : [ SenseInfo('13658828-n', 3), SenseInfo('13658828-n', 3), SenseInfo('13658828-n', 3) ],
"_break_v_up_rel" : [ SenseInfo('00364064-v', 15), SenseInfo('00334186-v', 13), SenseInfo('00258665-v', 9), SenseInfo('01369758-v', 8), SenseInfo('00334996-v', 8), SenseInfo('02566528-v', 5), SenseInfo('02073233-v', 4), SenseInfo('02029369-v', 4), SenseInfo('01785395-v', 4), SenseInfo('00362348-v', 4), SenseInfo('02570684-v', 3), SenseInfo('00202569-v', 3), SenseInfo('02668523-v', 2), SenseInfo('01106864-v', 2), SenseInfo('00933821-v', 2), SenseInfo('00558536-v', 2), SenseInfo('00434374-v', 2), SenseInfo('02535716-v', 1), SenseInfo('02030764-v', 1), SenseInfo('01972976-v', 1), SenseInfo('00390215-v', 1), SenseInfo('00202784-v', 1), SenseInfo('02746617-v', 0), SenseInfo('02746449-v', 0), SenseInfo('02681639-v', 0), SenseInfo('02681524-v', 0), SenseInfo('02625187-v', 0), SenseInfo('02600082-v', 0), SenseInfo('02559395-v', 0), SenseInfo('02478469-v', 0), SenseInfo('02431320-v', 0), SenseInfo('02399331-v', 0), SenseInfo('02318165-v', 0), SenseInfo('02101373-v', 0), SenseInfo('01991347-v', 0), SenseInfo('01989053-v', 0), SenseInfo('01896484-v', 0), SenseInfo('01610666-v', 0), SenseInfo('01610463-v', 0), SenseInfo('01597995-v', 0), SenseInfo('01557646-v', 0), SenseInfo('01369346-v', 0), SenseInfo('01298931-v', 0), SenseInfo('01228524-v', 0), SenseInfo('01228396-v', 0), SenseInfo('00935987-v', 0), SenseInfo('00779061-v', 0), SenseInfo('00778745-v', 0), SenseInfo('00744439-v', 0), SenseInfo('00738440-v', 0), SenseInfo('00738314-v', 0), SenseInfo('00551412-v', 0), SenseInfo('00339464-v', 0), SenseInfo('00336260-v', 0), SenseInfo('00258366-v', 0), SenseInfo('00155046-v', 0), SenseInfo('00107739-v', 0), SenseInfo('00107604-v', 0), SenseInfo('00030463-v', 0), SenseInfo('00364064-v', 15), SenseInfo('00334186-v', 13), SenseInfo('00258665-v', 9), SenseInfo('01369758-v', 8), SenseInfo('00334996-v', 8), SenseInfo('02566528-v', 5), SenseInfo('02073233-v', 4), SenseInfo('02029369-v', 4), SenseInfo('01785395-v', 4), SenseInfo('00362348-v', 4), SenseInfo('02570684-v', 3), SenseInfo('00202569-v', 3), SenseInfo('02668523-v', 2), SenseInfo('01106864-v', 2), SenseInfo('00933821-v', 2), SenseInfo('00558536-v', 2), SenseInfo('00434374-v', 2), SenseInfo('02535716-v', 1), SenseInfo('02030764-v', 1), SenseInfo('01972976-v', 1), SenseInfo('00390215-v', 1), SenseInfo('00202784-v', 1), SenseInfo('02746617-v', 0), SenseInfo('02746449-v', 0), SenseInfo('02681639-v', 0), SenseInfo('02681524-v', 0), SenseInfo('02625187-v', 0), SenseInfo('02600082-v', 0), SenseInfo('02559395-v', 0), SenseInfo('02478469-v', 0), SenseInfo('02431320-v', 0), SenseInfo('02399331-v', 0), SenseInfo('02318165-v', 0), SenseInfo('02101373-v', 0), SenseInfo('01991347-v', 0), SenseInfo('01989053-v', 0), SenseInfo('01896484-v', 0), SenseInfo('01610666-v', 0), SenseInfo('01610463-v', 0), SenseInfo('01597995-v', 0), SenseInfo('01557646-v', 0), SenseInfo('01369346-v', 0), SenseInfo('01298931-v', 0), SenseInfo('01228524-v', 0), SenseInfo('01228396-v', 0), SenseInfo('00935987-v', 0), SenseInfo('00779061-v', 0), SenseInfo('00778745-v', 0), SenseInfo('00744439-v', 0), SenseInfo('00738440-v', 0), SenseInfo('00738314-v', 0), SenseInfo('00551412-v', 0), SenseInfo('00339464-v', 0), SenseInfo('00336260-v', 0), SenseInfo('00258366-v', 0), SenseInfo('00155046-v', 0), SenseInfo('00107739-v', 0), SenseInfo('00107604-v', 0), SenseInfo('00030463-v', 0) ],
"_drag_v_down_rel" : [ SenseInfo('01453433-v', 16), SenseInfo('01454810-v', 13), SenseInfo('02677797-v', 1), SenseInfo('02099544-v', 1), SenseInfo('02058756-v', 1), SenseInfo('01199009-v', 1), SenseInfo('02101789-v', 0), SenseInfo('01917845-v', 0), SenseInfo('01244692-v', 0), SenseInfo('00783689-v', 0), SenseInfo('00341757-v', 0) ],
"_oilcloth_n_1_rel" : [ SenseInfo('03843438-n', 1) ],
"_abutment_n_1_rel" : [ SenseInfo('08620763-n', 0), SenseInfo('02669295-n', 0) ],
"_automobile_n_1_rel" : [ SenseInfo('02958343-n', 15), SenseInfo('02958343-n', 15) ],
"_bitterness_n_1_rel" : [ SenseInfo('07548978-n', 7), SenseInfo('04643397-n', 1), SenseInfo('05717115-n', 0), SenseInfo('04994824-n', 0) ],
"_mayonnaise_n_1_rel" : [ SenseInfo('07834507-n', 0) ],
"_drapery_n_1_rel" : [ SenseInfo('03151077-n', 4), SenseInfo('03233123-n', 0) ],
"_early_a_1_rel" : [ SenseInfo('00812952-a', 79), SenseInfo('00817424-a', 22), SenseInfo('01729384-a', 10), SenseInfo('01648617-a', 6), SenseInfo('00819852-a', 2), SenseInfo('01732958-a', 0), SenseInfo('00812952-a', 79), SenseInfo('00817424-a', 22), SenseInfo('01729384-a', 10), SenseInfo('01648617-a', 6), SenseInfo('00819852-a', 2), SenseInfo('01732958-a', 0), SenseInfo('00812952-a', 79), SenseInfo('00817424-a', 22), SenseInfo('01729384-a', 10), SenseInfo('01648617-a', 6), SenseInfo('00819852-a', 2), SenseInfo('01732958-a', 0) ],
"_cardinal_a_1_rel" : [ SenseInfo('01277097-a', 3), SenseInfo('02183611-a', 0) ],
"_snuggle_v_1_rel" : [ SenseInfo('01424948-v', 3), SenseInfo('01425348-v', 0) ],
"_laughter_n_1_rel" : [ SenseInfo('07127006-n', 15), SenseInfo('01072402-n', 0) ],
"_vim_n_1_rel" : [ SenseInfo('14050143-n', 0), SenseInfo('04633197-n', 0) ],
"_strange+looking_a_1_rel" : [  ],
"_prevention_n_of_rel" : [ SenseInfo('01077350-n', 17) ],
"free_relative_q_rel" : [  ],
"_channel_v_1_rel" : [ SenseInfo('02079933-v', 1), SenseInfo('01933900-v', 0), SenseInfo('01435380-v', 0), SenseInfo('02079933-v', 1), SenseInfo('01933900-v', 0), SenseInfo('01435380-v', 0) ],
"_ruler_n_1_rel" : [ SenseInfo('10541229-n', 4), SenseInfo('04118776-n', 1) ],
"_bit_n_1_rel" : [ SenseInfo('13761407-n', 18), SenseInfo('09222051-n', 4), SenseInfo('15246853-n', 1), SenseInfo('07309457-n', 1), SenseInfo('02844714-n', 1), SenseInfo('13625237-n', 0), SenseInfo('07579076-n', 0), SenseInfo('07009042-n', 0), SenseInfo('06892016-n', 0), SenseInfo('02845002-n', 0), SenseInfo('02844307-n', 0) ],
"_obsessive-compulsive_n_1_rel" : [ SenseInfo('10349090-n', 0), SenseInfo('10349090-n', 0) ],
"_sit_v_out_rel" : [ SenseInfo('01543123-v', 134), SenseInfo('02692882-v', 33), SenseInfo('01984902-v', 10), SenseInfo('02024874-v', 6), SenseInfo('02142775-v', 1), SenseInfo('01957529-v', 1), SenseInfo('02691214-v', 0), SenseInfo('02456270-v', 0), SenseInfo('01543998-v', 0), SenseInfo('01095581-v', 0) ],
"_sooth_n_1_rel" : [ SenseInfo('04867440-n', 0) ],
"_ethical_a_1_rel" : [ SenseInfo('02723563-a', 3), SenseInfo('00905386-a', 2), SenseInfo('02035086-a', 1) ],
"_get-rich-quick_a_1_rel" : [  ],
"_sunshine_n_1_rel" : [ SenseInfo('11485367-n', 1), SenseInfo('11456462-n', 0), SenseInfo('04630689-n', 0) ],
"_synopsis_n_1_rel" : [ SenseInfo('06468951-n', 0) ],
"_grunt_v_1_rel" : [ SenseInfo('01043231-v', 11), SenseInfo('01043231-v', 11) ],
"_seduce_v_1_rel" : [ SenseInfo('01428578-v', 0), SenseInfo('00783246-v', 0), SenseInfo('01428578-v', 0), SenseInfo('00783246-v', 0) ],
"_mechanism_n_1_rel" : [ SenseInfo('13512506-n', 8), SenseInfo('00098385-n', 3), SenseInfo('09349797-n', 2), SenseInfo('05972781-n', 0), SenseInfo('03738472-n', 0) ],
"_slowness_n_1_rel" : [ SenseInfo('05648459-n', 2), SenseInfo('05061977-n', 1), SenseInfo('05646218-n', 0) ],
"_determinate_a_1_rel" : [ SenseInfo('00739932-a', 1), SenseInfo('00741076-a', 0), SenseInfo('00550574-a', 0) ],
"_worthless_a_to_rel" : [ SenseInfo('02502163-a', 1), SenseInfo('01133017-a', 0) ],
"_interchange_v_1_rel" : [ SenseInfo('02257767-v', 0), SenseInfo('02257370-v', 0), SenseInfo('00121926-v', 0), SenseInfo('00121678-v', 0) ],
"_germinate_v_1_rel" : [ SenseInfo('00357332-v', 2), SenseInfo('01738597-v', 0), SenseInfo('00357667-v', 0) ],
"_raise_v_up_rel" : [ SenseInfo('00158503-v', 33), SenseInfo('01974062-v', 26), SenseInfo('00941166-v', 21), SenseInfo('02306281-v', 14), SenseInfo('01739814-v', 10), SenseInfo('02539788-v', 7), SenseInfo('01629958-v', 7), SenseInfo('01973759-v', 4), SenseInfo('01661243-v', 2), SenseInfo('01759326-v', 1), SenseInfo('01755651-v', 1), SenseInfo('00544549-v', 1), SenseInfo('00229605-v', 1), SenseInfo('02397637-v', 0), SenseInfo('01975587-v', 0), SenseInfo('01156406-v', 0), SenseInfo('01156291-v', 0), SenseInfo('01098452-v', 0), SenseInfo('01025246-v', 0), SenseInfo('00950782-v', 0), SenseInfo('00851625-v', 0), SenseInfo('00744070-v', 0), SenseInfo('00641929-v', 0), SenseInfo('00557537-v', 0), SenseInfo('00549982-v', 0), SenseInfo('00354195-v', 0), SenseInfo('00098517-v', 0) ],
"_gang_v_up_rel" : [ SenseInfo('01089737-v', 0), SenseInfo('01089737-v', 0) ],
"_floor_n_1_rel" : [ SenseInfo('03365592-n', 38), SenseInfo('03365991-n', 16), SenseInfo('06658118-n', 3), SenseInfo('09282208-n', 2), SenseInfo('09282084-n', 1), SenseInfo('09282363-n', 0), SenseInfo('07976596-n', 0), SenseInfo('05176341-n', 0), SenseInfo('03366464-n', 0), SenseInfo('03366301-n', 0), SenseInfo('03365592-n', 38), SenseInfo('03365991-n', 16), SenseInfo('06658118-n', 3), SenseInfo('09282208-n', 2), SenseInfo('09282084-n', 1), SenseInfo('09282363-n', 0), SenseInfo('07976596-n', 0), SenseInfo('05176341-n', 0), SenseInfo('03366464-n', 0), SenseInfo('03366301-n', 0) ],
"_together_p_sel_rel" : [ SenseInfo('00116791-r', 22), SenseInfo('00116994-r', 18), SenseInfo('00507927-r', 12), SenseInfo('00116510-r', 9), SenseInfo('00116588-r', 7), SenseInfo('01586194-a', 2), SenseInfo('00116705-r', 1) ],
"_auto+immune_a_1_rel" : [ SenseInfo('02649399-a', 0), SenseInfo('02649399-a', 0) ],
"_horseback_n_1_rel" : [ SenseInfo('01902274-n', 2), SenseInfo('09304376-n', 0) ],
"_head_v_out_rel" : [ SenseInfo('01935233-v', 29), SenseInfo('02440244-v', 19), SenseInfo('01999423-v', 3), SenseInfo('02729023-v', 2), SenseInfo('01931768-v', 2), SenseInfo('02754463-v', 0), SenseInfo('02694287-v', 0), SenseInfo('02624128-v', 0), SenseInfo('01590915-v', 0) ],
"_bond_n_1_rel" : [ SenseInfo('11436283-n', 15), SenseInfo('13417410-n', 13), SenseInfo('13792183-n', 6), SenseInfo('13350976-n', 1), SenseInfo('04181228-n', 1), SenseInfo('02755352-n', 1), SenseInfo('14782529-n', 0), SenseInfo('10855987-n', 0), SenseInfo('09590377-n', 0), SenseInfo('04935528-n', 0) ],
"_booze_v_1_rel" : [ SenseInfo('01171183-v', 0) ],
"_maritime_a_1_rel" : [ SenseInfo('02889746-a', 0), SenseInfo('00463399-a', 0) ],
"_back+country_n_1_rel" : [ SenseInfo('08502672-n', 1), SenseInfo('08502672-n', 1) ],
"_jacuzzi_n_1_rel" : [  ],
"_mend_v_1_rel" : [ SenseInfo('00260648-v', 5), SenseInfo('00270561-v', 1) ],
"_occupational_a_1_rel" : [ SenseInfo('02894591-a', 4) ],
"_arability_n_1_rel" : [ SenseInfo('04715818-n', 0) ],
"_plaza_n_1_rel" : [ SenseInfo('08619795-n', 0), SenseInfo('03965456-n', 0), SenseInfo('08619795-n', 0), SenseInfo('03965456-n', 0) ],
"_safe_a_for_rel" : [ SenseInfo('02057829-a', 25), SenseInfo('00066933-a', 1), SenseInfo('02061307-a', 0), SenseInfo('02273643-a', 0), SenseInfo('02057829-a', 25), SenseInfo('00066933-a', 1), SenseInfo('02061307-a', 0), SenseInfo('02273643-a', 0), SenseInfo('02057829-a', 25), SenseInfo('00066933-a', 1), SenseInfo('02061307-a', 0), SenseInfo('02273643-a', 0), SenseInfo('02057829-a', 25), SenseInfo('00066933-a', 1), SenseInfo('02061307-a', 0), SenseInfo('02273643-a', 0), SenseInfo('02057829-a', 25), SenseInfo('00066933-a', 1), SenseInfo('02061307-a', 0), SenseInfo('02273643-a', 0), SenseInfo('02057829-a', 25), SenseInfo('00066933-a', 1), SenseInfo('02061307-a', 0), SenseInfo('02273643-a', 0), SenseInfo('02057829-a', 25), SenseInfo('00066933-a', 1), SenseInfo('02061307-a', 0), SenseInfo('02273643-a', 0) ],
"_immortalize_v_1_rel" : [ SenseInfo('00612042-v', 0), SenseInfo('00553208-v', 0), SenseInfo('00612042-v', 0), SenseInfo('00553208-v', 0) ],
"_cul-de-sac_n_1_rel" : [ SenseInfo('03146449-n', 0), SenseInfo('02851540-n', 0), SenseInfo('03146449-n', 0), SenseInfo('02851540-n', 0) ],
"_buy_v_back_rel" : [ SenseInfo('02207206-v', 102), SenseInfo('02284096-v', 2), SenseInfo('02646757-v', 0), SenseInfo('02212103-v', 0), SenseInfo('00683670-v', 0) ],
"_at+most_a_1_rel" : [  ],
"_untrusting_a_1_rel" : [ SenseInfo('02464277-a', 0), SenseInfo('02464277-a', 0) ],
"_farm_n_1_rel" : [ SenseInfo('03322099-n', 49), SenseInfo('03322099-n', 49) ],
"_numb_v_1_rel" : [ SenseInfo('02115273-v', 0) ],
"_broker_v_1_rel" : [ SenseInfo('02261464-v', 0) ],
"_nervous_a_1_rel" : [ SenseInfo('02406908-a', 9), SenseInfo('02456157-a', 3), SenseInfo('02904518-a', 0), SenseInfo('00919813-a', 0), SenseInfo('00919155-a', 0) ],
"_misconduct_n_1_rel" : [ SenseInfo('01134330-n', 0), SenseInfo('00732746-n', 0) ],
"_scrutiny_n_of_rel" : [ SenseInfo('00635850-n', 3), SenseInfo('00878052-n', 2) ],
"_breathless_a_1_rel" : [ SenseInfo('00267871-a', 5), SenseInfo('00921369-a', 1), SenseInfo('00096595-a', 0), SenseInfo('00267871-a', 5), SenseInfo('00921369-a', 1), SenseInfo('00096595-a', 0) ],
"_pet_n_1_rel" : [ SenseInfo('01318894-n', 2), SenseInfo('09991867-n', 0), SenseInfo('07553176-n', 0), SenseInfo('00902376-n', 0) ],
"_cookbook_n_1_rel" : [ SenseInfo('06413020-n', 0) ],
"_bound_n_1_rel" : [ SenseInfo('13903079-n', 1), SenseInfo('08512259-n', 0), SenseInfo('05124057-n', 0), SenseInfo('00120202-n', 0) ],
"_chisel_n_1_rel" : [ SenseInfo('03020692-n', 4) ],
"_cobra_n_1_rel" : [ SenseInfo('01747885-n', 0) ],
"_nurse_v_1_rel" : [ SenseInfo('00080705-v', 2), SenseInfo('01773130-v', 1), SenseInfo('02550698-v', 0), SenseInfo('02515194-v', 0), SenseInfo('01186428-v', 0) ],
"_bitch_v_to_rel" : [ SenseInfo('00910973-v', 0), SenseInfo('00907657-v', 0), SenseInfo('00910973-v', 0), SenseInfo('00907657-v', 0) ],
"_league_n_1_rel" : [ SenseInfo('08231184-n', 9), SenseInfo('08305114-n', 2), SenseInfo('13652066-n', 0), SenseInfo('08231184-n', 9), SenseInfo('08305114-n', 2), SenseInfo('13652066-n', 0) ],
"_barbule_n_1_rel" : [  ],
"_slack_a_1_rel" : [ SenseInfo('02404421-a', 5), SenseInfo('01241455-a', 0), SenseInfo('00755482-a', 0), SenseInfo('02404421-a', 5), SenseInfo('01241455-a', 0), SenseInfo('00755482-a', 0), SenseInfo('02404421-a', 5), SenseInfo('01241455-a', 0), SenseInfo('00755482-a', 0), SenseInfo('02404421-a', 5), SenseInfo('01241455-a', 0), SenseInfo('00755482-a', 0) ],
"_exploitive_a_1_rel" : [ SenseInfo('01867768-a', 0) ],
"_sob_n_1_rel" : [ SenseInfo('14370122-n', 0), SenseInfo('09815188-n', 0), SenseInfo('00868669-n', 0) ],
"_surfer_n_1_rel" : [ SenseInfo('10679054-n', 0) ],
"_brambling_n_1_rel" : [ SenseInfo('01530575-n', 0), SenseInfo('01530575-n', 0) ],
"_zone_n_of_rel" : [ SenseInfo('08688247-n', 1), SenseInfo('08541841-n', 0), SenseInfo('08509442-n', 0), SenseInfo('05611062-n', 0) ],
"_rendezvous_n_1_rel" : [ SenseInfo('01231548-n', 3), SenseInfo('08642870-n', 1), SenseInfo('08385717-n', 0) ],
"_smell_v_of_rel" : [ SenseInfo('02124748-v', 14), SenseInfo('02123672-v', 12), SenseInfo('02124332-v', 3), SenseInfo('02194723-v', 0), SenseInfo('00589469-v', 0), SenseInfo('02124748-v', 14), SenseInfo('02123672-v', 12), SenseInfo('02124332-v', 3), SenseInfo('02194723-v', 0), SenseInfo('00589469-v', 0) ],
"_push_v_off_rel" : [ SenseInfo('01871979-v', 56), SenseInfo('00765977-v', 7), SenseInfo('00976653-v', 6), SenseInfo('02406916-v', 3), SenseInfo('01872645-v', 3), SenseInfo('02054864-v', 1), SenseInfo('02589576-v', 0), SenseInfo('02245555-v', 0), SenseInfo('01872877-v', 0), SenseInfo('01447632-v', 0), SenseInfo('01871979-v', 56), SenseInfo('00765977-v', 7), SenseInfo('00976653-v', 6), SenseInfo('02406916-v', 3), SenseInfo('01872645-v', 3), SenseInfo('02054864-v', 1), SenseInfo('02589576-v', 0), SenseInfo('02245555-v', 0), SenseInfo('01872877-v', 0), SenseInfo('01447632-v', 0), SenseInfo('01871979-v', 56), SenseInfo('00765977-v', 7), SenseInfo('00976653-v', 6), SenseInfo('02406916-v', 3), SenseInfo('01872645-v', 3), SenseInfo('02054864-v', 1), SenseInfo('02589576-v', 0), SenseInfo('02245555-v', 0), SenseInfo('01872877-v', 0), SenseInfo('01447632-v', 0) ],
"_ascidian_n_1_rel" : [ SenseInfo('01468712-n', 0) ],
"_accounting_n_1_rel" : [ SenseInfo('06739509-n', 1), SenseInfo('05662532-n', 1), SenseInfo('00618734-n', 1), SenseInfo('13405962-n', 0), SenseInfo('13354985-n', 0) ],
"_advance_v_x_rel" : [ SenseInfo('01992503-v', 7), SenseInfo('00875806-v', 6), SenseInfo('00497061-v', 5), SenseInfo('02554922-v', 4), SenseInfo('01993926-v', 4), SenseInfo('01111028-v', 3), SenseInfo('00248659-v', 2), SenseInfo('00558371-v', 1), SenseInfo('02397637-v', 0), SenseInfo('02283949-v', 0), SenseInfo('01994288-v', 0), SenseInfo('00158222-v', 0) ],
"_run_v_off_rel" : [ SenseInfo('01926311-v', 106), SenseInfo('02075049-v', 38), SenseInfo('02685951-v', 21), SenseInfo('02443849-v', 20), SenseInfo('02721284-v', 10), SenseInfo('02066939-v', 9), SenseInfo('01525666-v', 8), SenseInfo('02727039-v', 7), SenseInfo('01094086-v', 7), SenseInfo('01717169-v', 5), SenseInfo('02099829-v', 4), SenseInfo('02719399-v', 3), SenseInfo('01526290-v', 3), SenseInfo('00549063-v', 3), SenseInfo('00517529-v', 3), SenseInfo('02720904-v', 2), SenseInfo('02647497-v', 2), SenseInfo('02612234-v', 2), SenseInfo('02563327-v', 2), SenseInfo('01746359-v', 2), SenseInfo('01641545-v', 2), SenseInfo('01212230-v', 2), SenseInfo('02686625-v', 1), SenseInfo('02525312-v', 1), SenseInfo('02242256-v', 1), SenseInfo('02092309-v', 1), SenseInfo('02060792-v', 1), SenseInfo('01927903-v', 1), SenseInfo('01914947-v', 1), SenseInfo('02648110-v', 0), SenseInfo('02421921-v', 0), SenseInfo('01927747-v', 0), SenseInfo('01927447-v', 0), SenseInfo('01926984-v', 0), SenseInfo('01864038-v', 0), SenseInfo('01143838-v', 0), SenseInfo('01086103-v', 0), SenseInfo('00539110-v', 0), SenseInfo('00444629-v', 0), SenseInfo('00334803-v', 0), SenseInfo('00332672-v', 0) ],
"_thrill_n_1_rel" : [ SenseInfo('07528470-n', 5), SenseInfo('07520112-n', 2), SenseInfo('01261293-n', 1) ],
"_hap_v_1_rel" : [ SenseInfo('00339934-v', 0) ],
"_markkaa_n_2_rel" : [ SenseInfo('13688447-n', 0) ],
"_storytelling_n_1_rel" : [  ],
"_issue_v_1_rel" : [ SenseInfo('00967625-v', 21), SenseInfo('02479323-v', 12), SenseInfo('01063049-v', 12), SenseInfo('00528990-v', 6), SenseInfo('01064799-v', 1), SenseInfo('00967625-v', 21), SenseInfo('02479323-v', 12), SenseInfo('01063049-v', 12), SenseInfo('00528990-v', 6), SenseInfo('01064799-v', 1), SenseInfo('00967625-v', 21), SenseInfo('02479323-v', 12), SenseInfo('01063049-v', 12), SenseInfo('00528990-v', 6), SenseInfo('01064799-v', 1) ],
"_abstract_v_away_rel" : [ SenseInfo('00692329-v', 5), SenseInfo('02276866-v', 1), SenseInfo('00734587-v', 1), SenseInfo('01008288-v', 0), SenseInfo('00692329-v', 5), SenseInfo('02276866-v', 1), SenseInfo('00734587-v', 1), SenseInfo('01008288-v', 0) ],
"_somber_a_1_rel" : [ SenseInfo('00405179-a', 1), SenseInfo('00365261-a', 0), SenseInfo('00405179-a', 1), SenseInfo('00365261-a', 0), SenseInfo('00405179-a', 1), SenseInfo('00365261-a', 0) ],
"_hydroelectric_a_1_rel" : [ SenseInfo('02827950-a', 0) ],
"_township_n_1_rel" : [ SenseInfo('08672199-n', 0), SenseInfo('08672199-n', 0) ],
"_pleasing_a_to_rel" : [ SenseInfo('01807219-a', 7) ],
"_borderline_n_1_rel" : [ SenseInfo('08512736-n', 0) ],
"_last_n_1_rel" : [ SenseInfo('15267536-n', 3), SenseInfo('13850148-n', 1), SenseInfo('01264667-n', 1), SenseInfo('15143276-n', 0), SenseInfo('13718178-n', 0), SenseInfo('13618180-n', 0), SenseInfo('07291794-n', 0), SenseInfo('03644532-n', 0), SenseInfo('15267536-n', 3), SenseInfo('13850148-n', 1), SenseInfo('01264667-n', 1), SenseInfo('15143276-n', 0), SenseInfo('13718178-n', 0), SenseInfo('13618180-n', 0), SenseInfo('07291794-n', 0), SenseInfo('03644532-n', 0) ],
"_assay_v_1_rel" : [ SenseInfo('00694974-v', 1), SenseInfo('02530167-v', 0), SenseInfo('00694974-v', 1), SenseInfo('02530167-v', 0) ],
"_mid+range_a_1_rel" : [  ],
"_spellbinding_a_1_rel" : [ SenseInfo('00168188-a', 1) ],
"_coaster_n_1_rel" : [ SenseInfo('09932706-n', 0), SenseInfo('09932616-n', 0), SenseInfo('03056701-n', 0) ],
"_whirl_v_1_rel" : [ SenseInfo('02048891-v', 6), SenseInfo('02048051-v', 2), SenseInfo('02047650-v', 1), SenseInfo('02046755-v', 1), SenseInfo('02047857-v', 0) ],
"_mop_v_up_rel" : [ SenseInfo('01393339-v', 2), SenseInfo('00034758-v', 0), SenseInfo('01393339-v', 2), SenseInfo('00034758-v', 0) ],
"_correlative_n_1_rel" : [ SenseInfo('05858407-n', 0) ],
"_guest_n_of_rel" : [ SenseInfo('10150940-n', 26), SenseInfo('11018683-n', 0), SenseInfo('10151133-n', 0), SenseInfo('03827107-n', 0) ],
"_hide_v_away_rel" : [ SenseInfo('02144835-v', 28), SenseInfo('02145814-v', 6), SenseInfo('01582200-v', 0), SenseInfo('00313987-v', 0), SenseInfo('02144835-v', 28), SenseInfo('02145814-v', 6), SenseInfo('01582200-v', 0), SenseInfo('00313987-v', 0), SenseInfo('02144835-v', 28), SenseInfo('02145814-v', 6), SenseInfo('01582200-v', 0), SenseInfo('00313987-v', 0) ],
"_hutkeeper_n_1_rel" : [  ],
"_join_v_up_rel" : [ SenseInfo('02434976-v', 75), SenseInfo('01295275-v', 18), SenseInfo('02598765-v', 8), SenseInfo('01291069-v', 7), SenseInfo('02622234-v', 1) ],
"_the+most_q_rel" : [  ],
"_coat_n_of_rel" : [ SenseInfo('03057021-n', 29), SenseInfo('03058107-n', 1), SenseInfo('01898731-n', 0) ],
"_perpetration_n_1_rel" : [ SenseInfo('00773235-n', 1) ],
"_healthy_a_1_rel" : [ SenseInfo('01170243-a', 15), SenseInfo('02273838-a', 3), SenseInfo('02558184-a', 1), SenseInfo('01944088-a', 0), SenseInfo('00624576-a', 0), SenseInfo('01170243-a', 15), SenseInfo('02273838-a', 3), SenseInfo('02558184-a', 1), SenseInfo('01944088-a', 0), SenseInfo('00624576-a', 0), SenseInfo('01170243-a', 15), SenseInfo('02273838-a', 3), SenseInfo('02558184-a', 1), SenseInfo('01944088-a', 0), SenseInfo('00624576-a', 0) ],
"_fresh-ground_a_1_rel" : [  ],
"_pour_v_1_rel" : [ SenseInfo('02069551-v', 12), SenseInfo('02028366-v', 7), SenseInfo('02070296-v', 6), SenseInfo('02069248-v', 4), SenseInfo('02355806-v', 1), SenseInfo('02758033-v', 0), SenseInfo('02069551-v', 12), SenseInfo('02028366-v', 7), SenseInfo('02070296-v', 6), SenseInfo('02069248-v', 4), SenseInfo('02355806-v', 1), SenseInfo('02758033-v', 0), SenseInfo('02069551-v', 12), SenseInfo('02028366-v', 7), SenseInfo('02070296-v', 6), SenseInfo('02069248-v', 4), SenseInfo('02355806-v', 1), SenseInfo('02758033-v', 0), SenseInfo('02069551-v', 12), SenseInfo('02028366-v', 7), SenseInfo('02070296-v', 6), SenseInfo('02069248-v', 4), SenseInfo('02355806-v', 1), SenseInfo('02758033-v', 0), SenseInfo('02069551-v', 12), SenseInfo('02028366-v', 7), SenseInfo('02070296-v', 6), SenseInfo('02069248-v', 4), SenseInfo('02355806-v', 1), SenseInfo('02758033-v', 0) ],
"_ha+ha_a_1_rel" : [  ],
"_pot_v_1_rel" : [ SenseInfo('01529491-v', 1) ],
"_laugh_v_at_rel" : [ SenseInfo('00031820-v', 64), SenseInfo('00031820-v', 64) ],
"_taffrail_n_1_rel" : [ SenseInfo('04383923-n', 0) ],
"_kill_v_off_rel" : [ SenseInfo('01323958-v', 103), SenseInfo('02473688-v', 1), SenseInfo('00355038-v', 1), SenseInfo('02748495-v', 0), SenseInfo('02198819-v', 0), SenseInfo('01809617-v', 0), SenseInfo('01407376-v', 0), SenseInfo('01407235-v', 0), SenseInfo('01325774-v', 0), SenseInfo('01325536-v', 0), SenseInfo('01202374-v', 0), SenseInfo('00478830-v', 0), SenseInfo('00355524-v', 0), SenseInfo('00355365-v', 0), SenseInfo('00355177-v', 0) ],
"_bravado_n_1_rel" : [ SenseInfo('06889591-n', 2) ],
"_flash_v_cause_rel" : [ SenseInfo('02159890-v', 9), SenseInfo('00424691-v', 6), SenseInfo('02141973-v', 3), SenseInfo('00929509-v', 3), SenseInfo('02061495-v', 2), SenseInfo('02138611-v', 1), SenseInfo('01335461-v', 0), SenseInfo('00424869-v', 0) ],
"_snowclad_a_1_rel" : [  ],
"_legend_n_1_rel" : [ SenseInfo('06371413-n', 15), SenseInfo('06346891-n', 0) ],
"_proof_v_1_rel" : [ SenseInfo('01752316-v', 0), SenseInfo('01235558-v', 0), SenseInfo('00628302-v', 0), SenseInfo('00534545-v', 0), SenseInfo('00165971-v', 0) ],
"_mauve_a_1_rel" : [ SenseInfo('00377890-a', 2) ],
"_straight_x_deg_rel" : [ SenseInfo('00051848-r', 14), SenseInfo('00596511-a', 10), SenseInfo('00058128-r', 7), SenseInfo('02310895-a', 6), SenseInfo('01030826-a', 5), SenseInfo('01237754-a', 2), SenseInfo('00509432-r', 1), SenseInfo('00022962-a', 1), SenseInfo('02318464-a', 0), SenseInfo('02318272-a', 0), SenseInfo('02314584-a', 0), SenseInfo('10173895-n', 0), SenseInfo('07958294-n', 0), SenseInfo('04331126-n', 0), SenseInfo('02423981-a', 0), SenseInfo('01201298-a', 0), SenseInfo('00911204-a', 0), SenseInfo('00766102-a', 0), SenseInfo('00757120-a', 0), SenseInfo('00632306-a', 0), SenseInfo('00607857-a', 0) ],
"_crystalization_n_1_rel" : [  ],
"_pulse_n_1_rel" : [ SenseInfo('07420991-n', 1), SenseInfo('07400906-n', 1), SenseInfo('15280695-n', 0), SenseInfo('07709046-n', 0) ],
"_freaked_a_1_rel" : [  ],
"_castle_n_1_rel" : [ SenseInfo('03878066-n', 3), SenseInfo('02980441-n', 1), SenseInfo('02980625-n', 0), SenseInfo('00166552-n', 0), SenseInfo('03878066-n', 3), SenseInfo('02980441-n', 1), SenseInfo('02980625-n', 0), SenseInfo('00166552-n', 0) ],
"_walrus_n_1_rel" : [ SenseInfo('02081571-n', 1) ],
"_hank_n_1_rel" : [ SenseInfo('03491988-n', 0) ],
"_leniency_n_1_rel" : [ SenseInfo('04829922-n', 0), SenseInfo('04638585-n', 0), SenseInfo('01071213-n', 0) ],
"_stimulus_n_of_rel" : [ SenseInfo('05827684-n', 10) ],
"_wont_a_1_rel" : [ SenseInfo('05669034-n', 0) ],
"_around-the-clock_a_1_rel" : [ SenseInfo('00595147-a', 0), SenseInfo('00595147-a', 0) ],
"_strike_n_1_rel" : [ SenseInfo('01243674-n', 7), SenseInfo('00977301-n', 2), SenseInfo('07410021-n', 0), SenseInfo('00187710-n', 0), SenseInfo('00109414-n', 0), SenseInfo('00064504-n', 0), SenseInfo('01243674-n', 7), SenseInfo('00977301-n', 2), SenseInfo('07410021-n', 0), SenseInfo('00187710-n', 0), SenseInfo('00109414-n', 0), SenseInfo('00064504-n', 0) ],
"_courtyard_n_1_rel" : [ SenseInfo('03120198-n', 2) ],
"_guise_n_1_rel" : [ SenseInfo('04678908-n', 0) ],
"_counterbalance_n_1_rel" : [ SenseInfo('03118539-n', 1), SenseInfo('13897996-n', 0), SenseInfo('13291189-n', 0), SenseInfo('03118539-n', 1), SenseInfo('13897996-n', 0), SenseInfo('13291189-n', 0), SenseInfo('03118539-n', 1), SenseInfo('13897996-n', 0), SenseInfo('13291189-n', 0), SenseInfo('03118539-n', 1), SenseInfo('13897996-n', 0), SenseInfo('13291189-n', 0), SenseInfo('03118539-n', 1), SenseInfo('13897996-n', 0), SenseInfo('13291189-n', 0), SenseInfo('03118539-n', 1), SenseInfo('13897996-n', 0), SenseInfo('13291189-n', 0) ],
"_advertise_v_as_rel" : [ SenseInfo('00975902-v', 7), SenseInfo('00976653-v', 0), SenseInfo('00975902-v', 7), SenseInfo('00976653-v', 0) ],
"_secular_a_1_rel" : [ SenseInfo('02793988-a', 0), SenseInfo('02577061-a', 0), SenseInfo('02056880-a', 0), SenseInfo('01782854-a', 0), SenseInfo('02057226-a', 0) ],
"_disturbance_n_1_rel" : [ SenseInfo('07428450-n', 4), SenseInfo('14403282-n', 2), SenseInfo('13977366-n', 1), SenseInfo('01176335-n', 1), SenseInfo('00333829-n', 1), SenseInfo('14083790-n', 0), SenseInfo('07430211-n', 0) ],
"_lock_v_in_rel" : [ SenseInfo('01348174-v', 8), SenseInfo('01510827-v', 7), SenseInfo('00219775-v', 4), SenseInfo('01606736-v', 2), SenseInfo('01606018-v', 2), SenseInfo('01810320-v', 1), SenseInfo('01347678-v', 1), SenseInfo('02050865-v', 0), SenseInfo('01655347-v', 0), SenseInfo('01348174-v', 8), SenseInfo('01510827-v', 7), SenseInfo('00219775-v', 4), SenseInfo('01606736-v', 2), SenseInfo('01606018-v', 2), SenseInfo('01810320-v', 1), SenseInfo('01347678-v', 1), SenseInfo('02050865-v', 0), SenseInfo('01655347-v', 0), SenseInfo('01348174-v', 8), SenseInfo('01510827-v', 7), SenseInfo('00219775-v', 4), SenseInfo('01606736-v', 2), SenseInfo('01606018-v', 2), SenseInfo('01810320-v', 1), SenseInfo('01347678-v', 1), SenseInfo('02050865-v', 0), SenseInfo('01655347-v', 0) ],
"_veteran_a_1_rel" : [ SenseInfo('00936523-a', 11) ],
"_procure_v_1_rel" : [ SenseInfo('02238770-v', 3), SenseInfo('01180975-v', 0), SenseInfo('02238770-v', 3), SenseInfo('01180975-v', 0) ],
"_lawyer_n_1_rel" : [ SenseInfo('10249950-n', 15) ],
"_consecrate_v_1_rel" : [ SenseInfo('02386012-v', 0), SenseInfo('00887463-v', 0), SenseInfo('00886978-v', 0), SenseInfo('00866702-v', 0) ],
"_taint_v_1_rel" : [ SenseInfo('01537959-v', 0), SenseInfo('00088713-v', 0) ],
"_mismatch_n_1_rel" : [ SenseInfo('05696199-n', 0) ],
"_fizzy_a_1_rel" : [ SenseInfo('02276752-a', 0) ],
"_voluminous_a_1_rel" : [ SenseInfo('01390900-a', 3), SenseInfo('02313784-a', 0), SenseInfo('00014858-a', 0) ],
"_oregonian_n_1_rel" : [ SenseInfo('09745229-n', 0) ],
"_enforceability_n_of_rel" : [  ],
"_top-of-the-line_a_1_rel" : [  ],
"_simple_a_for_rel" : [ SenseInfo('02174896-a', 56), SenseInfo('00750296-a', 10), SenseInfo('01792573-a', 4), SenseInfo('02272047-a', 2), SenseInfo('01841390-a', 1), SenseInfo('02166346-a', 0), SenseInfo('01793812-a', 0), SenseInfo('02174896-a', 56), SenseInfo('00750296-a', 10), SenseInfo('01792573-a', 4), SenseInfo('02272047-a', 2), SenseInfo('01841390-a', 1), SenseInfo('02166346-a', 0), SenseInfo('01793812-a', 0), SenseInfo('02174896-a', 56), SenseInfo('00750296-a', 10), SenseInfo('01792573-a', 4), SenseInfo('02272047-a', 2), SenseInfo('01841390-a', 1), SenseInfo('02166346-a', 0), SenseInfo('01793812-a', 0), SenseInfo('02174896-a', 56), SenseInfo('00750296-a', 10), SenseInfo('01792573-a', 4), SenseInfo('02272047-a', 2), SenseInfo('01841390-a', 1), SenseInfo('02166346-a', 0), SenseInfo('01793812-a', 0) ],
"_feign_v_1_rel" : [ SenseInfo('00838043-v', 1), SenseInfo('01721754-v', 0) ],
"_starfruit_n_1_rel" : [  ],
"_isolate_n_1_rel" : [  ],
"_maintain_v_1_rel" : [ SenseInfo('02681795-v', 41), SenseInfo('02280132-v', 38), SenseInfo('01184625-v', 13), SenseInfo('01016778-v', 8), SenseInfo('02204564-v', 4), SenseInfo('02203168-v', 0), SenseInfo('01065877-v', 0), SenseInfo('01017643-v', 0), SenseInfo('00896497-v', 0), SenseInfo('00732552-v', 0), SenseInfo('02681795-v', 41), SenseInfo('02280132-v', 38), SenseInfo('01184625-v', 13), SenseInfo('01016778-v', 8), SenseInfo('02204564-v', 4), SenseInfo('02203168-v', 0), SenseInfo('01065877-v', 0), SenseInfo('01017643-v', 0), SenseInfo('00896497-v', 0), SenseInfo('00732552-v', 0) ],
"_recklessness_n_1_rel" : [ SenseInfo('04661926-n', 2) ],
"_ninja_n_1_rel" : [ SenseInfo('10358889-n', 0), SenseInfo('08389094-n', 0) ],
"_fourth+place_n_1_rel" : [  ],
"_screen_v_out_rel" : [ SenseInfo('02533109-v', 2), SenseInfo('00697419-v', 2), SenseInfo('02400378-v', 0), SenseInfo('02139883-v', 0), SenseInfo('01477538-v', 0), SenseInfo('01460785-v', 0), SenseInfo('01130169-v', 0) ],
"_put_v_down_rel" : [ SenseInfo('01494310-v', 138), SenseInfo('01493741-v', 98), SenseInfo('00981276-v', 28), SenseInfo('01160370-v', 6), SenseInfo('02271137-v', 3), SenseInfo('00673448-v', 2), SenseInfo('02111499-v', 0), SenseInfo('01706375-v', 0), SenseInfo('00735571-v', 0) ],
"_puddle_n_1_rel" : [ SenseInfo('14992945-n', 0), SenseInfo('09397607-n', 0), SenseInfo('08665101-n', 0) ],
"_thitherward_p_rel" : [  ],
"_sleep_v_1_rel" : [ SenseInfo('00014742-v', 58), SenseInfo('02701445-v', 0) ],
"_airman_n_1_rel" : [ SenseInfo('09826204-n', 0) ],
"_intimation_n_1_rel" : [ SenseInfo('07163988-n', 0), SenseInfo('05916306-n', 0), SenseInfo('07163988-n', 0), SenseInfo('05916306-n', 0) ],
"_waveform_n_1_rel" : [ SenseInfo('07347664-n', 0) ],
"_bedroom_n_1_rel" : [ SenseInfo('02821627-n', 22) ],
"_northwestward_a_2_rel" : [ SenseInfo('01602250-a', 0), SenseInfo('01602250-a', 0) ],
"_stew_v_1_rel" : [ SenseInfo('01805384-v', 0), SenseInfo('01774005-v', 0), SenseInfo('00323856-v', 0) ],
"_department_n_1_rel" : [ SenseInfo('08114861-n', 28), SenseInfo('08548733-n', 0), SenseInfo('05853273-n', 0), SenseInfo('08114861-n', 28), SenseInfo('08548733-n', 0), SenseInfo('05853273-n', 0), SenseInfo('08114861-n', 28), SenseInfo('08548733-n', 0), SenseInfo('05853273-n', 0) ],
"_actinal_a_1_rel" : [ SenseInfo('01665816-a', 0) ],
"_incomprehensible_a_1_rel" : [ SenseInfo('00939105-a', 1), SenseInfo('00533851-a', 1) ],
"_hamper_n_1_rel" : [ SenseInfo('04181228-n', 2), SenseInfo('03482405-n', 0) ],
"_whip_v_out_rel" : [ SenseInfo('01411085-v', 8), SenseInfo('01102997-v', 4), SenseInfo('01891092-v', 3), SenseInfo('01398032-v', 3), SenseInfo('01417868-v', 0), SenseInfo('00863906-v', 0) ],
"_purposely_a_1_rel" : [  ],
"_active_a_1_rel" : [ SenseInfo('00037457-a', 9), SenseInfo('01660444-a', 7), SenseInfo('00038750-a', 5), SenseInfo('01515280-a', 4), SenseInfo('00031974-a', 3), SenseInfo('00042457-a', 2), SenseInfo('00035465-a', 2), SenseInfo('00927373-a', 1), SenseInfo('00043411-a', 0), SenseInfo('00042037-a', 0), SenseInfo('00041618-a', 0), SenseInfo('00041361-a', 0), SenseInfo('00040325-a', 0), SenseInfo('00034710-a', 0), SenseInfo('00037457-a', 9), SenseInfo('01660444-a', 7), SenseInfo('00038750-a', 5), SenseInfo('01515280-a', 4), SenseInfo('00031974-a', 3), SenseInfo('00042457-a', 2), SenseInfo('00035465-a', 2), SenseInfo('00927373-a', 1), SenseInfo('00043411-a', 0), SenseInfo('00042037-a', 0), SenseInfo('00041618-a', 0), SenseInfo('00041361-a', 0), SenseInfo('00040325-a', 0), SenseInfo('00034710-a', 0) ],
"_every+once+in+a+while_a_1_rel" : [  ],
"_drugstore_n_1_rel" : [ SenseInfo('03249342-n', 6) ],
"_conventionality_n_1_rel" : [ SenseInfo('06212155-n', 0), SenseInfo('05650180-n', 0), SenseInfo('04801532-n', 0) ],
"_renaissance_n_of_rel" : [ SenseInfo('15259812-n', 5), SenseInfo('01047803-n', 1) ],
"_admiral_n_1_rel" : [ SenseInfo('09771204-n', 0), SenseInfo('02276258-n', 0), SenseInfo('09771204-n', 0), SenseInfo('02276258-n', 0), SenseInfo('09771204-n', 0), SenseInfo('02276258-n', 0) ],
"_thwart_v_1_rel" : [ SenseInfo('02558172-v', 5) ],
"_stroll_v_1_rel" : [ SenseInfo('01917980-v', 1), SenseInfo('01917980-v', 1) ],
"_daunt_v_1_rel" : [ SenseInfo('01785748-v', 1), SenseInfo('01785748-v', 1), SenseInfo('01785748-v', 1), SenseInfo('01785748-v', 1), SenseInfo('01785748-v', 1) ],
"_stick_v_with_rel" : [ SenseInfo('01528069-v', 5), SenseInfo('01857392-v', 2), SenseInfo('01356750-v', 2), SenseInfo('02754032-v', 0), SenseInfo('02647798-v', 0), SenseInfo('02638845-v', 0), SenseInfo('02638630-v', 0), SenseInfo('01667969-v', 0), SenseInfo('01614581-v', 0), SenseInfo('01614426-v', 0), SenseInfo('01614235-v', 0), SenseInfo('01441993-v', 0), SenseInfo('01441793-v', 0), SenseInfo('01220885-v', 0), SenseInfo('00748084-v', 0), SenseInfo('00622384-v', 0) ],
"_greens_n_1_rel" : [ SenseInfo('04967191-n', 6), SenseInfo('08615374-n', 1), SenseInfo('11013324-n', 0), SenseInfo('10060904-n', 0), SenseInfo('09294066-n', 0), SenseInfo('08579780-n', 0), SenseInfo('07709333-n', 0), SenseInfo('03606572-n', 0), SenseInfo('04967191-n', 6), SenseInfo('08615374-n', 1), SenseInfo('11013324-n', 0), SenseInfo('10060904-n', 0), SenseInfo('09294066-n', 0), SenseInfo('08579780-n', 0), SenseInfo('07709333-n', 0), SenseInfo('03606572-n', 0) ],
"_gravel_n_1_rel" : [ SenseInfo('14698884-n', 3) ],
"_protestant_n_1_rel" : [ SenseInfo('09679316-n', 15), SenseInfo('08087570-n', 5) ],
"_shout_v_out_rel" : [ SenseInfo('00912473-v', 39), SenseInfo('00913065-v', 18), SenseInfo('00912048-v', 2), SenseInfo('00845299-v', 0), SenseInfo('00912473-v', 39), SenseInfo('00913065-v', 18), SenseInfo('00912048-v', 2), SenseInfo('00845299-v', 0) ],
"_scramble_n_1_rel" : [ SenseInfo('00789391-n', 1), SenseInfo('00556142-n', 0) ],
"_pontificate_n_1_rel" : [ SenseInfo('08053260-n', 0) ],
"_smirk_v_1_rel" : [ SenseInfo('00029336-v', 1), SenseInfo('00029336-v', 1) ],
"_focus_v_1_rel" : [ SenseInfo('00722232-v', 6), SenseInfo('02161922-v', 4), SenseInfo('00731789-v', 1), SenseInfo('00314782-v', 0), SenseInfo('00314272-v', 0) ],
"_sardine_n_1_rel" : [ SenseInfo('07794063-n', 1), SenseInfo('02532602-n', 1), SenseInfo('15019734-n', 0), SenseInfo('02533209-n', 0) ],
"_deficiency_n_1_rel" : [ SenseInfo('14449405-n', 6), SenseInfo('05113133-n', 2) ],
"_wrecked_a_1_rel" : [ SenseInfo('00737116-a', 0) ],
"_slather_v_1_rel" : [ SenseInfo('01379449-v', 0), SenseInfo('01379449-v', 0) ],
"_italics_n_1_rel" : [ SenseInfo('06350918-n', 1), SenseInfo('06961853-n', 0), SenseInfo('06827344-n', 0), SenseInfo('06350918-n', 1), SenseInfo('06961853-n', 0), SenseInfo('06827344-n', 0) ],
"_motor_n_1_rel" : [ SenseInfo('03789946-n', 6), SenseInfo('09359631-n', 0) ],
"_no+doubt_a_1_rel" : [  ],
"_mate_v_1_rel" : [ SenseInfo('01428853-v', 7), SenseInfo('01292885-v', 1), SenseInfo('01114475-v', 0) ],
"_make_v_of-i_rel" : [ SenseInfo('02560585-v', 508), SenseInfo('00120316-v', 459), SenseInfo('01617192-v', 243), SenseInfo('00770437-v', 85), SenseInfo('01645601-v', 78), SenseInfo('01621555-v', 52), SenseInfo('00730758-v', 33), SenseInfo('01646075-v', 17), SenseInfo('01640207-v', 16), SenseInfo('02289295-v', 14), SenseInfo('01619014-v', 14), SenseInfo('02621395-v', 12), SenseInfo('02022162-v', 12), SenseInfo('02674708-v', 10), SenseInfo('01653873-v', 9), SenseInfo('01755816-v', 8), SenseInfo('01654628-v', 5), SenseInfo('00556855-v', 5), SenseInfo('00012267-v', 5), SenseInfo('02396716-v', 4), SenseInfo('02355596-v', 4), SenseInfo('02020590-v', 4), SenseInfo('00665476-v', 4), SenseInfo('02582921-v', 3), SenseInfo('02598483-v', 2), SenseInfo('01733477-v', 2), SenseInfo('00276068-v', 2), SenseInfo('02075857-v', 1), SenseInfo('00074038-v', 1), SenseInfo('02748759-v', 0), SenseInfo('02748627-v', 0), SenseInfo('02745332-v', 0), SenseInfo('02665124-v', 0), SenseInfo('02621133-v', 0), SenseInfo('02134050-v', 0), SenseInfo('02051031-v', 0), SenseInfo('02021532-v', 0), SenseInfo('01755504-v', 0), SenseInfo('01664172-v', 0), SenseInfo('01428578-v', 0), SenseInfo('00891038-v', 0), SenseInfo('00838524-v', 0), SenseInfo('00698256-v', 0), SenseInfo('00698104-v', 0), SenseInfo('00562182-v', 0), SenseInfo('00562067-v', 0), SenseInfo('00545953-v', 0), SenseInfo('00107369-v', 0), SenseInfo('00072012-v', 0) ],
"_look_v_out_rel" : [ SenseInfo('02130524-v', 274), SenseInfo('02133435-v', 126), SenseInfo('00033599-v', 25), SenseInfo('02153709-v', 8), SenseInfo('02693319-v', 1), SenseInfo('02549581-v', 1), SenseInfo('00929362-v', 1), SenseInfo('00720063-v', 1), SenseInfo('02658447-v', 0), SenseInfo('00712708-v', 0), SenseInfo('02130524-v', 274), SenseInfo('02133435-v', 126), SenseInfo('00033599-v', 25), SenseInfo('02153709-v', 8), SenseInfo('02693319-v', 1), SenseInfo('02549581-v', 1), SenseInfo('00929362-v', 1), SenseInfo('00720063-v', 1), SenseInfo('02658447-v', 0), SenseInfo('00712708-v', 0), SenseInfo('02130524-v', 274), SenseInfo('02133435-v', 126), SenseInfo('00033599-v', 25), SenseInfo('02153709-v', 8), SenseInfo('02693319-v', 1), SenseInfo('02549581-v', 1), SenseInfo('00929362-v', 1), SenseInfo('00720063-v', 1), SenseInfo('02658447-v', 0), SenseInfo('00712708-v', 0) ],
"_bombproof_n_1_rel" : [ SenseInfo('02868638-n', 3) ],
"_mess_v_around_rel" : [ SenseInfo('01176079-v', 0), SenseInfo('00276214-v', 0) ],
"_direction_n_of_rel" : [ SenseInfo('08679972-n', 35), SenseInfo('13827426-n', 17), SenseInfo('06197215-n', 14), SenseInfo('06650701-n', 5), SenseInfo('01133281-n', 3), SenseInfo('06786629-n', 2), SenseInfo('00815320-n', 1), SenseInfo('07169480-n', 0), SenseInfo('05704694-n', 0) ],
"_agree_v_1_rel" : [ SenseInfo('00805376-v', 62), SenseInfo('00764222-v', 25), SenseInfo('02657219-v', 4), SenseInfo('02700104-v', 1), SenseInfo('02741793-v', 0), SenseInfo('02291135-v', 0), SenseInfo('01035530-v', 0) ],
"_in+lieu+of_p_rel" : [  ],
"_flake_v_cause_rel" : [ SenseInfo('01585276-v', 1), SenseInfo('01336440-v', 0), SenseInfo('01259951-v', 0) ],
"_commemoration_n_of_rel" : [ SenseInfo('07452841-n', 0), SenseInfo('06688522-n', 0) ],
"_irishman_n_1_rel" : [ SenseInfo('09715165-n', 2) ],
"_drip_v_cause_rel" : [ SenseInfo('02071142-v', 11), SenseInfo('01611516-v', 0) ],
"_bewitch_v_1_rel" : [ SenseInfo('01806505-v', 1), SenseInfo('00777522-v', 0), SenseInfo('00776988-v', 0) ],
"_campsite_n_1_rel" : [ SenseInfo('08518171-n', 0) ],
"_cleavage_n_1_rel" : [ SenseInfo('13920012-n', 0), SenseInfo('13449319-n', 0), SenseInfo('13449156-n', 0), SenseInfo('05553897-n', 0), SenseInfo('00386345-n', 0) ],
"_demolition_n_of_rel" : [ SenseInfo('07334490-n', 1), SenseInfo('01249483-n', 0) ],
"_plus+fours_n_1_rel" : [ SenseInfo('03970363-n', 0), SenseInfo('03970363-n', 0) ],
"_multidrop_n_1_rel" : [  ],
"_alien_n_1_rel" : [ SenseInfo('10103485-n', 2), SenseInfo('10661002-n', 0), SenseInfo('09484465-n', 0) ],
"_commemorate_v_1_rel" : [ SenseInfo('00612612-v', 3), SenseInfo('00611481-v', 2), SenseInfo('00612042-v', 0) ],
"_almond_n_1_rel" : [ SenseInfo('12645174-n', 0), SenseInfo('07750586-n', 0) ],
"_no-brainer_n_1_rel" : [ SenseInfo('00797468-n', 0), SenseInfo('00797468-n', 0) ],
"_expert_n_1_rel" : [ SenseInfo('09617867-n', 20) ],
"_upside+down_p_sel_rel" : [ SenseInfo('00219641-r', 3), SenseInfo('00219641-r', 3) ],
"_departure_n_1_rel" : [ SenseInfo('00042757-n', 8), SenseInfo('07366289-n', 2), SenseInfo('07333649-n', 0), SenseInfo('00042757-n', 8), SenseInfo('07366289-n', 2), SenseInfo('07333649-n', 0) ],
"_hostile_n_1_rel" : [ SenseInfo('08397675-n', 0) ],
"comp_rel" : [  ],
"_roast_v_1_rel" : [ SenseInfo('00324560-v', 4), SenseInfo('00851933-v', 0) ],
"_opium_n_1_rel" : [ SenseInfo('03850966-n', 14) ],
"_hesitate_v_1_rel" : [ SenseInfo('02640440-v', 16), SenseInfo('02641035-v', 9), SenseInfo('02640440-v', 16), SenseInfo('02641035-v', 9) ],
"_sprint_v_1_rel" : [ SenseInfo('01928579-v', 1) ],
"_crave_v_1_rel" : [ SenseInfo('01188485-v', 5), SenseInfo('00758538-v', 0) ],
"_grimace_v_1_rel" : [ SenseInfo('00034288-v', 2) ],
"_kick_n_1_rel" : [ SenseInfo('00136329-n', 3), SenseInfo('07528470-n', 1), SenseInfo('07350754-n', 0), SenseInfo('07209965-n', 0), SenseInfo('05827509-n', 0), SenseInfo('00336805-n', 0) ],
"_skill_n_1_rel" : [ SenseInfo('05637558-n', 39), SenseInfo('05636887-n', 10), SenseInfo('05637558-n', 39), SenseInfo('05636887-n', 10) ],
"_appropriate_a_to_rel" : [ SenseInfo('00134701-a', 29), SenseInfo('00134701-a', 29), SenseInfo('00134701-a', 29) ],
"_translate_v_into_rel" : [ SenseInfo('00959827-v', 10), SenseInfo('00383542-v', 7), SenseInfo('00593852-v', 4), SenseInfo('01436290-v', 2), SenseInfo('00522441-v', 2), SenseInfo('02753100-v', 0), SenseInfo('02728142-v', 0), SenseInfo('02103925-v', 0), SenseInfo('00961947-v', 0), SenseInfo('00919608-v', 0), SenseInfo('00959827-v', 10), SenseInfo('00383542-v', 7), SenseInfo('00593852-v', 4), SenseInfo('01436290-v', 2), SenseInfo('00522441-v', 2), SenseInfo('02753100-v', 0), SenseInfo('02728142-v', 0), SenseInfo('02103925-v', 0), SenseInfo('00961947-v', 0), SenseInfo('00919608-v', 0) ],
"_discount_n_1_rel" : [ SenseInfo('00362103-n', 1), SenseInfo('13319253-n', 0), SenseInfo('13282275-n', 0), SenseInfo('13274597-n', 0) ],
"_audience_n_1_rel" : [ SenseInfo('08221897-n', 60), SenseInfo('08222293-n', 9), SenseInfo('14484778-n', 0), SenseInfo('07143624-n', 0) ],
"_requite_v_1_rel" : [ SenseInfo('02344060-v', 0) ],
"_deactivate_v_1_rel" : [ SenseInfo('00191728-v', 0), SenseInfo('00191517-v', 0), SenseInfo('00191728-v', 0), SenseInfo('00191517-v', 0) ],
"_labyrinthine_a_1_rel" : [ SenseInfo('02947928-a', 0), SenseInfo('02178628-a', 0) ],
"_sew_v_1_rel" : [ SenseInfo('01329239-v', 5), SenseInfo('01666327-v', 0), SenseInfo('01329239-v', 5), SenseInfo('01666327-v', 0) ],
"_bower_n_1_rel" : [ SenseInfo('02732827-n', 1) ],
"_lick_n_1_rel" : [ SenseInfo('09420689-n', 0), SenseInfo('00150591-n', 0), SenseInfo('00134780-n', 0) ],
"_complaint_n_1_rel" : [ SenseInfo('14055408-n', 3), SenseInfo('07208930-n', 1), SenseInfo('07208708-n', 1), SenseInfo('06562217-n', 0), SenseInfo('06561942-n', 0), SenseInfo('14055408-n', 3), SenseInfo('07208930-n', 1), SenseInfo('07208708-n', 1), SenseInfo('06562217-n', 0), SenseInfo('06561942-n', 0) ],
"_ailment_n_1_rel" : [ SenseInfo('14055408-n', 7) ],
"_nonrefundable_a_1_rel" : [  ],
"_character_n_1_rel" : [ SenseInfo('09587565-n', 16), SenseInfo('05849284-n', 12), SenseInfo('04620216-n', 11), SenseInfo('05929008-n', 9), SenseInfo('09909060-n', 4), SenseInfo('14438693-n', 1), SenseInfo('06694796-n', 1), SenseInfo('06818970-n', 0), SenseInfo('04616916-n', 0) ],
"_conserve_v_as_rel" : [ SenseInfo('02682567-v', 0), SenseInfo('02280132-v', 0), SenseInfo('02269143-v', 0), SenseInfo('00212049-v', 0) ],
"_flagship_n_1_rel" : [ SenseInfo('03356158-n', 0), SenseInfo('03356038-n', 0) ],
"_listen_v_up_rel" : [ SenseInfo('02169891-v', 60), SenseInfo('02171039-v', 34), SenseInfo('02571901-v', 4) ],
"_dissension_n_1_rel" : [ SenseInfo('07181546-n', 1), SenseInfo('13982357-n', 0) ],
"_highball_v_1_rel" : [  ],
"_reference_n_1_rel" : [ SenseInfo('06766190-n', 9), SenseInfo('06763681-n', 6), SenseInfo('07258332-n', 5), SenseInfo('06417598-n', 5), SenseInfo('06694796-n', 4), SenseInfo('05922949-n', 3), SenseInfo('01264050-n', 2), SenseInfo('07258664-n', 0), SenseInfo('06356515-n', 0), SenseInfo('05923314-n', 0), SenseInfo('06766190-n', 9), SenseInfo('06763681-n', 6), SenseInfo('07258332-n', 5), SenseInfo('06417598-n', 5), SenseInfo('06694796-n', 4), SenseInfo('05922949-n', 3), SenseInfo('01264050-n', 2), SenseInfo('07258664-n', 0), SenseInfo('06356515-n', 0), SenseInfo('05923314-n', 0), SenseInfo('06766190-n', 9), SenseInfo('06763681-n', 6), SenseInfo('07258332-n', 5), SenseInfo('06417598-n', 5), SenseInfo('06694796-n', 4), SenseInfo('05922949-n', 3), SenseInfo('01264050-n', 2), SenseInfo('07258664-n', 0), SenseInfo('06356515-n', 0), SenseInfo('05923314-n', 0) ],
"_southeastern_a_1_rel" : [ SenseInfo('01603518-a', 1), SenseInfo('00827743-a', 0), SenseInfo('01603518-a', 1), SenseInfo('00827743-a', 0) ],
"_suit_v_1_rel" : [ SenseInfo('02702830-v', 7), SenseInfo('02735282-v', 1), SenseInfo('02699941-v', 1), SenseInfo('02724258-v', 0) ],
"_doh_a_1_rel" : [ SenseInfo('06868309-n', 0), SenseInfo('06868309-n', 0), SenseInfo('06868309-n', 0), SenseInfo('06868309-n', 0), SenseInfo('06868309-n', 0), SenseInfo('06868309-n', 0), SenseInfo('06868309-n', 0), SenseInfo('06868309-n', 0), SenseInfo('06868309-n', 0), SenseInfo('06868309-n', 0), SenseInfo('06868309-n', 0), SenseInfo('06868309-n', 0) ],
"_associate_n_of_rel" : [ SenseInfo('09816771-n', 7), SenseInfo('09945905-n', 0), SenseInfo('09817174-n', 0), SenseInfo('07284848-n', 0), SenseInfo('06697703-n', 0) ],
"_crown_v_as_rel" : [ SenseInfo('02390949-v', 2), SenseInfo('00485891-v', 2), SenseInfo('02694677-v', 0), SenseInfo('01338247-v', 0) ],
"_subscribe_v_to_rel" : [ SenseInfo('02299110-v', 2), SenseInfo('00996485-v', 1), SenseInfo('00806314-v', 1), SenseInfo('02299269-v', 0), SenseInfo('02209745-v', 0) ],
"_picturesque_a_1_rel" : [ SenseInfo('00219924-a', 2), SenseInfo('00407887-a', 1) ],
"_card_n_1_rel" : [ SenseInfo('02962545-n', 5), SenseInfo('06477371-n', 2), SenseInfo('06627006-n', 1), SenseInfo('14800034-n', 0), SenseInfo('10762342-n', 0), SenseInfo('06793426-n', 0), SenseInfo('06633205-n', 0), SenseInfo('06507941-n', 0), SenseInfo('06492939-n', 0), SenseInfo('06486161-n', 0), SenseInfo('03033986-n', 0) ],
"_squall_n_1_rel" : [ SenseInfo('11514008-n', 0) ],
"_on-deck_a_1_rel" : [  ],
"_degasser_n_1_rel" : [  ],
"_a+tad_x_deg_rel" : [  ],
"_shave_v_off_rel" : [ SenseInfo('00037298-v', 8), SenseInfo('01248782-v', 1), SenseInfo('02349597-v', 0), SenseInfo('01249490-v', 0), SenseInfo('01249147-v', 0), SenseInfo('01248597-v', 0) ],
"_eke_v_out_rel" : [  ],
"_deposit_v_1_rel" : [ SenseInfo('01528069-v', 3), SenseInfo('02310855-v', 2), SenseInfo('01575675-v', 2), SenseInfo('01528069-v', 3), SenseInfo('02310855-v', 2), SenseInfo('01575675-v', 2) ],
"_methodist_a_1_rel" : [ SenseInfo('02955562-a', 1) ],
"_fork_v_over_rel" : [ SenseInfo('01579340-v', 0), SenseInfo('01118888-v', 0), SenseInfo('00328802-v', 0), SenseInfo('00141914-v', 0) ],
"_trump_v_1_rel" : [ SenseInfo('02179154-v', 0), SenseInfo('01109259-v', 0), SenseInfo('01078235-v', 0), SenseInfo('00975202-v', 0) ],
"_dull_v_1_rel" : [ SenseInfo('01246321-v', 1), SenseInfo('00391971-v', 1), SenseInfo('02191311-v', 0), SenseInfo('02115273-v', 0), SenseInfo('01246444-v', 0), SenseInfo('00538199-v', 0), SenseInfo('00391672-v', 0) ],
"_disused_a_1_rel" : [ SenseInfo('00669021-a', 0) ],
"_third+prize_n_1_rel" : [  ],
"_arc_n_1_rel" : [ SenseInfo('11511523-n', 37), SenseInfo('13874384-n', 6), SenseInfo('13896100-n', 0) ],
"_keynote_n_1_rel" : [ SenseInfo('07240278-n', 1), SenseInfo('05926049-n', 1), SenseInfo('06857726-n', 0) ],
"_asymmetrical_a_1_rel" : [ SenseInfo('02373599-a', 0), SenseInfo('01961048-a', 0) ],
"_barbeque_n_1_rel" : [ SenseInfo('07654148-n', 0), SenseInfo('07576781-n', 0), SenseInfo('02790669-n', 0) ],
"_hematite_n_1_rel" : [ SenseInfo('14905720-n', 0) ],
"_intercourse_n_1_rel" : [ SenseInfo('07134445-n', 1), SenseInfo('00845523-n', 0) ],
"_overpower_v_1_rel" : [ SenseInfo('01110517-v', 2), SenseInfo('01809321-v', 1), SenseInfo('01110517-v', 2), SenseInfo('01809321-v', 1) ],
"_chest_n_1_rel" : [ SenseInfo('05552607-n', 34), SenseInfo('03014705-n', 1), SenseInfo('05553288-n', 0), SenseInfo('03015254-n', 0) ],
"_reject_v_as_rel" : [ SenseInfo('00685683-v', 19), SenseInfo('02237338-v', 15), SenseInfo('00807178-v', 2), SenseInfo('00796976-v', 1), SenseInfo('02755017-v', 0), SenseInfo('02502916-v', 0), SenseInfo('00685419-v', 0), SenseInfo('00685683-v', 19), SenseInfo('02237338-v', 15), SenseInfo('00807178-v', 2), SenseInfo('00796976-v', 1), SenseInfo('02755017-v', 0), SenseInfo('02502916-v', 0), SenseInfo('00685419-v', 0) ],
"_satisfy_v_1_rel" : [ SenseInfo('02671880-v', 13), SenseInfo('01816431-v', 8), SenseInfo('01183573-v', 8), SenseInfo('02671880-v', 13), SenseInfo('01816431-v', 8), SenseInfo('01183573-v', 8), SenseInfo('02671880-v', 13), SenseInfo('01816431-v', 8), SenseInfo('01183573-v', 8), SenseInfo('02671880-v', 13), SenseInfo('01816431-v', 8), SenseInfo('01183573-v', 8) ],
"_antithesis_n_1_rel" : [ SenseInfo('13855230-n', 1), SenseInfo('07101406-n', 0) ],
"_farther_a_1_rel" : [ SenseInfo('00443490-a', 2), SenseInfo('00443988-a', 1) ],
"_access_v_1_rel" : [ SenseInfo('02248808-v', 0), SenseInfo('02007417-v', 0) ],
"_brighten_v_up_rel" : [ SenseInfo('00312815-v', 1), SenseInfo('02771169-v', 0), SenseInfo('00312815-v', 1), SenseInfo('02771169-v', 0) ],
"_partner_n_1_rel" : [ SenseInfo('10640620-n', 8), SenseInfo('09935434-n', 7), SenseInfo('10402417-n', 0), SenseInfo('10640620-n', 8), SenseInfo('09935434-n', 7), SenseInfo('10402417-n', 0) ],
"_minus+sign_n_1_rel" : [ SenseInfo('06812085-n', 0) ],
"_karaoke_n_1_rel" : [ SenseInfo('01255302-n', 0) ],
"_bakery_n_1_rel" : [ SenseInfo('02776631-n', 0) ],
"_snub_n_1_rel" : [ SenseInfo('07208000-n', 0), SenseInfo('01225997-n', 0) ],
"_investment_n_1_rel" : [ SenseInfo('01099436-n', 7), SenseInfo('13333237-n', 5), SenseInfo('04647185-n', 0), SenseInfo('01458616-n', 0), SenseInfo('00828462-n', 0), SenseInfo('00198919-n', 0) ],
"_anglican_n_1_rel" : [ SenseInfo('09958292-n', 2) ],
"_run_v_up_rel" : [ SenseInfo('01926311-v', 106), SenseInfo('02075049-v', 38), SenseInfo('02685951-v', 21), SenseInfo('02443849-v', 20), SenseInfo('02721284-v', 10), SenseInfo('02066939-v', 9), SenseInfo('01525666-v', 8), SenseInfo('02727039-v', 7), SenseInfo('01094086-v', 7), SenseInfo('01717169-v', 5), SenseInfo('02099829-v', 4), SenseInfo('02719399-v', 3), SenseInfo('01526290-v', 3), SenseInfo('00549063-v', 3), SenseInfo('00517529-v', 3), SenseInfo('02720904-v', 2), SenseInfo('02647497-v', 2), SenseInfo('02612234-v', 2), SenseInfo('02563327-v', 2), SenseInfo('01746359-v', 2), SenseInfo('01641545-v', 2), SenseInfo('01212230-v', 2), SenseInfo('02686625-v', 1), SenseInfo('02525312-v', 1), SenseInfo('02242256-v', 1), SenseInfo('02092309-v', 1), SenseInfo('02060792-v', 1), SenseInfo('01927903-v', 1), SenseInfo('01914947-v', 1), SenseInfo('02648110-v', 0), SenseInfo('02421921-v', 0), SenseInfo('01927747-v', 0), SenseInfo('01927447-v', 0), SenseInfo('01926984-v', 0), SenseInfo('01864038-v', 0), SenseInfo('01143838-v', 0), SenseInfo('01086103-v', 0), SenseInfo('00539110-v', 0), SenseInfo('00444629-v', 0), SenseInfo('00334803-v', 0), SenseInfo('00332672-v', 0) ],
"_peek_v_at_rel" : [ SenseInfo('02165304-v', 0), SenseInfo('02165304-v', 0), SenseInfo('02165304-v', 0) ],
"_betray_v_to_rel" : [ SenseInfo('00936330-v', 8), SenseInfo('02537407-v', 3), SenseInfo('01799235-v', 2), SenseInfo('02576503-v', 1), SenseInfo('00841986-v', 1), SenseInfo('00854420-v', 0) ],
"_complement_n_1_rel" : [ SenseInfo('06315638-n', 15), SenseInfo('13591998-n', 1), SenseInfo('08218212-n', 1), SenseInfo('05109511-n', 1), SenseInfo('14736201-n', 0), SenseInfo('05696297-n', 0) ],
"_pare_v_off_rel" : [ SenseInfo('00233089-v', 1), SenseInfo('01552219-v', 0), SenseInfo('01262936-v', 0), SenseInfo('01262564-v', 0) ],
"_shackle_n_1_rel" : [ SenseInfo('04181228-n', 2), SenseInfo('04181561-n', 0) ],
"_output_n_of_rel" : [ SenseInfo('03287178-n', 5), SenseInfo('00914632-n', 2), SenseInfo('07264925-n', 1), SenseInfo('13758745-n', 0), SenseInfo('03860882-n', 0) ],
"_canvass_v_1_rel" : [ SenseInfo('02454312-v', 2), SenseInfo('02458747-v', 0), SenseInfo('00644583-v', 0) ],
"_recrimination_n_1_rel" : [ SenseInfo('07234657-n', 2) ],
"_statistic_n_1_rel" : [ SenseInfo('06021499-n', 7), SenseInfo('06021499-n', 7) ],
"_cheaper_a_1_rel" : [  ],
"_wont_n_1_rel" : [ SenseInfo('05669034-n', 0) ],
"_uneasy_a_about_rel" : [ SenseInfo('00822449-a', 15), SenseInfo('01922562-a', 0), SenseInfo('02456157-a', 0), SenseInfo('00480439-a', 0), SenseInfo('00479073-a', 0), SenseInfo('00822449-a', 15), SenseInfo('01922562-a', 0), SenseInfo('02456157-a', 0), SenseInfo('00480439-a', 0), SenseInfo('00479073-a', 0) ],
"_identifier_n_1_rel" : [ SenseInfo('07270601-n', 0) ],
"_cruel_a_1_rel" : [ SenseInfo('01263013-a', 3), SenseInfo('01263013-a', 3), SenseInfo('01263013-a', 3), SenseInfo('01263013-a', 3) ],
"_applied_a_1_rel" : [ SenseInfo('00863049-a', 0) ],
"_authorization_n_of_rel" : [ SenseInfo('06556481-n', 5), SenseInfo('05196582-n', 0), SenseInfo('05176607-n', 0), SenseInfo('01138670-n', 0), SenseInfo('06556481-n', 5), SenseInfo('05196582-n', 0), SenseInfo('05176607-n', 0), SenseInfo('01138670-n', 0) ],
"_sprout_n_1_rel" : [ SenseInfo('13164583-n', 0), SenseInfo('07719437-n', 0) ],
"_clinical_a_1_rel" : [ SenseInfo('02885529-a', 14), SenseInfo('01615460-a', 1) ],
"_brightness_n_1_rel" : [ SenseInfo('04952242-n', 11), SenseInfo('05620955-n', 0), SenseInfo('05018103-n', 0) ],
"_wildflower_n_1_rel" : [ SenseInfo('11672400-n', 0) ],
"_tickle_v_cause_rel" : [ SenseInfo('02120140-v', 0), SenseInfo('01796346-v', 0), SenseInfo('01431987-v', 0) ],
"_integer_n_1_rel" : [ SenseInfo('13728499-n', 5) ],
"_ninefold_a_1_rel" : [ SenseInfo('02220099-a', 0), SenseInfo('02220099-a', 0) ],
"_faction_n_1_rel" : [ SenseInfo('08241798-n', 2), SenseInfo('08251877-n', 0) ],
"_front+to+back_p_rel" : [  ],
"_discharge_n_of_rel" : [ SenseInfo('07307754-n', 13), SenseInfo('01253277-n', 3), SenseInfo('14852450-n', 1), SenseInfo('13466586-n', 1), SenseInfo('11511523-n', 1), SenseInfo('07407777-n', 0), SenseInfo('00216174-n', 0), SenseInfo('00213694-n', 0), SenseInfo('00123234-n', 0) ],
"_connector_n_1_rel" : [ SenseInfo('03091374-n', 0) ],
"_then_a_1_rel" : [ SenseInfo('01731108-a', 1), SenseInfo('01731108-a', 1), SenseInfo('01731108-a', 1), SenseInfo('01731108-a', 1), SenseInfo('01731108-a', 1) ],
"_aura_n_1_rel" : [ SenseInfo('14302460-n', 0), SenseInfo('04951716-n', 0), SenseInfo('04727214-n', 0) ],
"_binoculars_n_1_rel" : [ SenseInfo('02841315-n', 1), SenseInfo('02841315-n', 1) ],
"_laserdisc_n_1_rel" : [  ],
"_crossbar_n_1_rel" : [ SenseInfo('03135917-n', 0), SenseInfo('03135788-n', 0), SenseInfo('03135656-n', 0) ],
"_proliferate_v_1_rel" : [ SenseInfo('00310635-v', 0), SenseInfo('00247830-v', 0) ],
"_craftsmanship_n_1_rel" : [ SenseInfo('05638063-n', 1) ],
"_bread_v_1_rel" : [ SenseInfo('01337653-v', 0) ],
"_pluck_v_1_rel" : [ SenseInfo('01592456-v', 3), SenseInfo('02322596-v', 0), SenseInfo('02319050-v', 0), SenseInfo('01452546-v', 0), SenseInfo('01384275-v', 0), SenseInfo('01382083-v', 0) ],
"_pound_n_1_rel" : [ SenseInfo('13720096-n', 42), SenseInfo('13686660-n', 2), SenseInfo('13720302-n', 0), SenseInfo('13695674-n', 0), SenseInfo('13695420-n', 0), SenseInfo('13694936-n', 0), SenseInfo('13694657-n', 0), SenseInfo('13694017-n', 0), SenseInfo('13693641-n', 0), SenseInfo('13648184-n', 0), SenseInfo('11244550-n', 0), SenseInfo('06809756-n', 0), SenseInfo('03993703-n', 0), SenseInfo('01175316-n', 0), SenseInfo('13720096-n', 42), SenseInfo('13686660-n', 2), SenseInfo('13720302-n', 0), SenseInfo('13695674-n', 0), SenseInfo('13695420-n', 0), SenseInfo('13694936-n', 0), SenseInfo('13694657-n', 0), SenseInfo('13694017-n', 0), SenseInfo('13693641-n', 0), SenseInfo('13648184-n', 0), SenseInfo('11244550-n', 0), SenseInfo('06809756-n', 0), SenseInfo('03993703-n', 0), SenseInfo('01175316-n', 0), SenseInfo('13720096-n', 42), SenseInfo('13686660-n', 2), SenseInfo('13720302-n', 0), SenseInfo('13695674-n', 0), SenseInfo('13695420-n', 0), SenseInfo('13694936-n', 0), SenseInfo('13694657-n', 0), SenseInfo('13694017-n', 0), SenseInfo('13693641-n', 0), SenseInfo('13648184-n', 0), SenseInfo('11244550-n', 0), SenseInfo('06809756-n', 0), SenseInfo('03993703-n', 0), SenseInfo('01175316-n', 0) ],
"_micron_n_1_rel" : [ SenseInfo('13658496-n', 4) ],
"_keel_v_over_rel" : [ SenseInfo('01924882-v', 0) ],
"_remnant_n_of_rel" : [ SenseInfo('13811184-n', 3), SenseInfo('03286383-n', 0) ],
"_constitute_v_1_rel" : [ SenseInfo('02620587-v', 31), SenseInfo('02396205-v', 1), SenseInfo('02621395-v', 0), SenseInfo('01647229-v', 0) ],
"_put_v_1_rel" : [ SenseInfo('01494310-v', 138), SenseInfo('01493741-v', 98), SenseInfo('00981276-v', 28), SenseInfo('01160370-v', 6), SenseInfo('02271137-v', 3), SenseInfo('00673448-v', 2), SenseInfo('02111499-v', 0), SenseInfo('01706375-v', 0), SenseInfo('00735571-v', 0), SenseInfo('01494310-v', 138), SenseInfo('01493741-v', 98), SenseInfo('00981276-v', 28), SenseInfo('01160370-v', 6), SenseInfo('02271137-v', 3), SenseInfo('00673448-v', 2), SenseInfo('02111499-v', 0), SenseInfo('01706375-v', 0), SenseInfo('00735571-v', 0) ],
"_keen_a_1_rel" : [ SenseInfo('01744515-a', 3), SenseInfo('01511387-a', 0), SenseInfo('01123879-a', 0), SenseInfo('00803432-a', 0), SenseInfo('00802179-a', 0), SenseInfo('01744515-a', 3), SenseInfo('01511387-a', 0), SenseInfo('01123879-a', 0), SenseInfo('00803432-a', 0), SenseInfo('00802179-a', 0), SenseInfo('01744515-a', 3), SenseInfo('01511387-a', 0), SenseInfo('01123879-a', 0), SenseInfo('00803432-a', 0), SenseInfo('00802179-a', 0), SenseInfo('01744515-a', 3), SenseInfo('01511387-a', 0), SenseInfo('01123879-a', 0), SenseInfo('00803432-a', 0), SenseInfo('00802179-a', 0) ],
"_seed_n_1_rel" : [ SenseInfo('13135832-n', 12), SenseInfo('11683989-n', 5), SenseInfo('10575463-n', 0), SenseInfo('05834758-n', 0), SenseInfo('05404336-n', 0) ],
"_unmixed_a_1_rel" : [ SenseInfo('01907103-a', 0), SenseInfo('01330890-a', 0), SenseInfo('01907103-a', 0), SenseInfo('01330890-a', 0) ],
"_savory_a_1_rel" : [ SenseInfo('01627836-a', 1), SenseInfo('02398378-a', 0), SenseInfo('00133669-a', 0) ],
"_commission_v_1_rel" : [ SenseInfo('02475401-v', 2), SenseInfo('02480803-v', 0), SenseInfo('02475261-v', 0), SenseInfo('02475401-v', 2), SenseInfo('02480803-v', 0), SenseInfo('02475261-v', 0), SenseInfo('02475401-v', 2), SenseInfo('02480803-v', 0), SenseInfo('02475261-v', 0), SenseInfo('02475401-v', 2), SenseInfo('02480803-v', 0), SenseInfo('02475261-v', 0) ],
"_gyp_n_1_rel" : [ SenseInfo('00779248-n', 0) ],
"_mammoth_a_1_rel" : [ SenseInfo('01386538-a', 1) ],
"_revive_v_cause_rel" : [ SenseInfo('00098083-v', 5), SenseInfo('00024279-v', 5), SenseInfo('00169298-v', 2), SenseInfo('00168910-v', 1), SenseInfo('00024047-v', 0) ],
"_leering_n_1_rel" : [ SenseInfo('00225408-a', 2), SenseInfo('02133653-a', 0) ],
"_inset_n_1_rel" : [ SenseInfo('03573464-n', 1), SenseInfo('03573282-n', 0), SenseInfo('03471190-n', 0) ],
"_feedback_n_1_rel" : [ SenseInfo('13479380-n', 1), SenseInfo('06746471-n', 1) ],
"_scan_n_of_rel" : [ SenseInfo('00643943-n', 3), SenseInfo('04142549-n', 0) ],
"_declension_n_1_rel" : [ SenseInfo('13804203-n', 0), SenseInfo('13464204-n', 0), SenseInfo('09265620-n', 0), SenseInfo('08006511-n', 0) ],
"_theology_n_1_rel" : [ SenseInfo('06182144-n', 11), SenseInfo('06183899-n', 6), SenseInfo('00613973-n', 1) ],
"_help_v_out_rel" : [ SenseInfo('02547586-v', 183), SenseInfo('00082081-v', 23), SenseInfo('02735897-v', 19), SenseInfo('02726164-v', 5), SenseInfo('01181295-v', 2), SenseInfo('02555434-v', 0), SenseInfo('01193569-v', 0), SenseInfo('00206998-v', 0), SenseInfo('02547586-v', 183), SenseInfo('00082081-v', 23), SenseInfo('02735897-v', 19), SenseInfo('02726164-v', 5), SenseInfo('01181295-v', 2), SenseInfo('02555434-v', 0), SenseInfo('01193569-v', 0), SenseInfo('00206998-v', 0) ],
"_murmur_n_1_rel" : [ SenseInfo('07386920-n', 2), SenseInfo('07114154-n', 1), SenseInfo('14334814-n', 0), SenseInfo('07211092-n', 0) ],
"_element_n_1_rel" : [ SenseInfo('05868954-n', 34), SenseInfo('03081021-n', 10), SenseInfo('14622893-n', 3), SenseInfo('08568579-n', 1), SenseInfo('14840755-n', 0), SenseInfo('13934465-n', 0), SenseInfo('13877408-n', 0) ],
"_drover_n_1_rel" : [ SenseInfo('10171567-n', 1) ],
"_analyze_v_1_rel" : [ SenseInfo('00644583-v', 21), SenseInfo('00643473-v', 2), SenseInfo('00736216-v', 0), SenseInfo('00643197-v', 0), SenseInfo('00644583-v', 21), SenseInfo('00643473-v', 2), SenseInfo('00736216-v', 0), SenseInfo('00643197-v', 0) ],
"_grinch_n_1_rel" : [  ],
"_reaffirmation_n_of_rel" : [ SenseInfo('06732581-n', 0), SenseInfo('06732581-n', 0) ],
"_fuss_v_1_rel" : [ SenseInfo('01793933-v', 4), SenseInfo('02550516-v', 1) ],
"_hairdresser_n_1_rel" : [ SenseInfo('10155849-n', 0) ],
"_garden_v_1_rel" : [ SenseInfo('01740969-v', 3) ],
"_cornerstone_n_1_rel" : [ SenseInfo('05793554-n', 0), SenseInfo('03110470-n', 0), SenseInfo('03110332-n', 0) ],
"_wax_v_to_rel" : [ SenseInfo('01268726-v', 2), SenseInfo('00433232-v', 1), SenseInfo('00433525-v', 0) ],
"_fine_a_for_rel" : [ SenseInfo('02081114-a', 4), SenseInfo('01838253-a', 4), SenseInfo('02414031-a', 2), SenseInfo('00850183-a', 2), SenseInfo('02232251-a', 1), SenseInfo('01906817-a', 0), SenseInfo('02081114-a', 4), SenseInfo('01838253-a', 4), SenseInfo('02414031-a', 2), SenseInfo('00850183-a', 2), SenseInfo('02232251-a', 1), SenseInfo('01906817-a', 0), SenseInfo('02081114-a', 4), SenseInfo('01838253-a', 4), SenseInfo('02414031-a', 2), SenseInfo('00850183-a', 2), SenseInfo('02232251-a', 1), SenseInfo('01906817-a', 0), SenseInfo('02081114-a', 4), SenseInfo('01838253-a', 4), SenseInfo('02414031-a', 2), SenseInfo('00850183-a', 2), SenseInfo('02232251-a', 1), SenseInfo('01906817-a', 0), SenseInfo('02081114-a', 4), SenseInfo('01838253-a', 4), SenseInfo('02414031-a', 2), SenseInfo('00850183-a', 2), SenseInfo('02232251-a', 1), SenseInfo('01906817-a', 0), SenseInfo('02081114-a', 4), SenseInfo('01838253-a', 4), SenseInfo('02414031-a', 2), SenseInfo('00850183-a', 2), SenseInfo('02232251-a', 1), SenseInfo('01906817-a', 0) ],
"_exception_n_to_rel" : [ SenseInfo('05707269-n', 18), SenseInfo('05821246-n', 8), SenseInfo('07209533-n', 0) ],
"_graceful_a_1_rel" : [ SenseInfo('01139352-a', 2), SenseInfo('01142069-a', 0), SenseInfo('01139352-a', 2), SenseInfo('01142069-a', 0) ],
"_shred_n_1_rel" : [ SenseInfo('13773725-n', 3), SenseInfo('04045941-n', 0) ],
"_nanny_v_1_rel" : [  ],
"_deathless_a_1_rel" : [ SenseInfo('01558194-a', 0) ],
"_tussle_n_1_rel" : [ SenseInfo('01172441-n', 0) ],
"_the+same_p_as_rel" : [ SenseInfo('02068476-a', 129), SenseInfo('02062670-a', 80), SenseInfo('01411065-a', 20), SenseInfo('00355611-a', 17), SenseInfo('09720033-n', 0), SenseInfo('06959427-n', 0), SenseInfo('02068476-a', 129), SenseInfo('02062670-a', 80), SenseInfo('01411065-a', 20), SenseInfo('00355611-a', 17), SenseInfo('09720033-n', 0), SenseInfo('06959427-n', 0) ],
"_bacterial_a_1_rel" : [ SenseInfo('02833544-a', 14) ],
"_sitcom_n_1_rel" : [ SenseInfo('07017733-n', 0), SenseInfo('07017379-n', 0) ],
"_dance_v_1_rel" : [ SenseInfo('01894649-v', 17), SenseInfo('01708676-v', 14), SenseInfo('02099075-v', 2) ],
"_react_v_against_rel" : [ SenseInfo('00717358-v', 22), SenseInfo('02378623-v', 2), SenseInfo('00446885-v', 2) ],
"_squeaky_a_1_rel" : [ SenseInfo('01214606-a', 1) ],
"_bunker_n_1_rel" : [ SenseInfo('02920369-n', 1), SenseInfo('02920658-n', 0), SenseInfo('02920503-n', 0) ],
"_road+west_n_1_rel" : [  ],
"_power_v_1_rel" : [ SenseInfo('01181559-v', 3), SenseInfo('01181559-v', 3) ],
"_stem_v_1_rel" : [ SenseInfo('02627753-v', 19), SenseInfo('02713065-v', 0), SenseInfo('00354452-v', 0), SenseInfo('00176137-v', 0), SenseInfo('02627753-v', 19), SenseInfo('02713065-v', 0), SenseInfo('00354452-v', 0), SenseInfo('00176137-v', 0) ],
"_chuckle_n_1_rel" : [ SenseInfo('07127563-n', 1) ],
"_meal_n_1_rel" : [ SenseInfo('07573696-n', 20), SenseInfo('15245990-n', 0), SenseInfo('07567707-n', 0) ],
"_slumber_n_1_rel" : [ SenseInfo('14024882-n', 1), SenseInfo('14015148-n', 0) ],
"_avoidance_n_1_rel" : [ SenseInfo('00203753-n', 4) ],
"_democratic_a_1_rel" : [ SenseInfo('00715140-a', 13), SenseInfo('02710530-a', 8), SenseInfo('00486539-a', 0) ],
"_quake_v_1_rel" : [ SenseInfo('01889129-v', 2), SenseInfo('01888784-v', 0) ],
"_laureate_n_1_rel" : [ SenseInfo('10249011-n', 0) ],
"_inopportune_a_1_rel" : [ SenseInfo('01661914-a', 0), SenseInfo('01661914-a', 0) ],
"_echo_n_1_rel" : [ SenseInfo('05010801-n', 5), SenseInfo('09549047-n', 0), SenseInfo('07200290-n', 0), SenseInfo('05011162-n', 0), SenseInfo('04746607-n', 0), SenseInfo('01021119-n', 0) ],
"_blackboard_n_1_rel" : [ SenseInfo('02846511-n', 2) ],
"_hesitancy_n_1_rel" : [ SenseInfo('07523485-n', 1), SenseInfo('04645943-n', 0) ],
"_see_v_to_rel" : [ SenseInfo('02129289-v', 613), SenseInfo('00591115-v', 159), SenseInfo('02128873-v', 140), SenseInfo('01635432-v', 58), SenseInfo('00690614-v', 47), SenseInfo('00598954-v', 40), SenseInfo('02150948-v', 29), SenseInfo('02023107-v', 27), SenseInfo('00920336-v', 27), SenseInfo('00662589-v', 22), SenseInfo('02488304-v', 13), SenseInfo('02488488-v', 12), SenseInfo('02493030-v', 10), SenseInfo('02549581-v', 7), SenseInfo('01470670-v', 4), SenseInfo('02486232-v', 1), SenseInfo('02129709-v', 1), SenseInfo('00703708-v', 1), SenseInfo('02156225-v', 0), SenseInfo('02131279-v', 0), SenseInfo('02110220-v', 0), SenseInfo('02026086-v', 0), SenseInfo('01156568-v', 0), SenseInfo('00623151-v', 0), SenseInfo('02129289-v', 613), SenseInfo('00591115-v', 159), SenseInfo('02128873-v', 140), SenseInfo('01635432-v', 58), SenseInfo('00690614-v', 47), SenseInfo('00598954-v', 40), SenseInfo('02150948-v', 29), SenseInfo('02023107-v', 27), SenseInfo('00920336-v', 27), SenseInfo('00662589-v', 22), SenseInfo('02488304-v', 13), SenseInfo('02488488-v', 12), SenseInfo('02493030-v', 10), SenseInfo('02549581-v', 7), SenseInfo('01470670-v', 4), SenseInfo('02486232-v', 1), SenseInfo('02129709-v', 1), SenseInfo('00703708-v', 1), SenseInfo('02156225-v', 0), SenseInfo('02131279-v', 0), SenseInfo('02110220-v', 0), SenseInfo('02026086-v', 0), SenseInfo('01156568-v', 0), SenseInfo('00623151-v', 0) ],
"_right-to-lifer_n_1_rel" : [  ],
"_wishful_a_1_rel" : [ SenseInfo('00887719-a', 0), SenseInfo('00104533-a', 0) ],
"_creme+fraiche_n_1_rel" : [  ],
"_clergy_n_1_rel" : [ SenseInfo('08152787-n', 2) ],
"_filter_n_1_rel" : [ SenseInfo('03339643-n', 4), SenseInfo('03340009-n', 1) ],
"_authorization_n_1_rel" : [ SenseInfo('06556481-n', 5), SenseInfo('05196582-n', 0), SenseInfo('05176607-n', 0), SenseInfo('01138670-n', 0), SenseInfo('06556481-n', 5), SenseInfo('05196582-n', 0), SenseInfo('05176607-n', 0), SenseInfo('01138670-n', 0) ],
"_soften_v_1_rel" : [ SenseInfo('02190632-v', 4), SenseInfo('00390215-v', 1), SenseInfo('02703289-v', 0), SenseInfo('01576917-v', 0), SenseInfo('01058036-v', 0), SenseInfo('00255389-v', 0), SenseInfo('00254867-v', 0) ],
"_terminus_n_of_rel" : [ SenseInfo('08566554-n', 0), SenseInfo('05981768-n', 0), SenseInfo('04413723-n', 0), SenseInfo('04413631-n', 0), SenseInfo('04412901-n', 0) ],
"_lessen_v_cause_rel" : [ SenseInfo('00151689-v', 5), SenseInfo('00441445-v', 2), SenseInfo('00232956-v', 1) ],
"_economize_v_1_rel" : [ SenseInfo('02269143-v', 4), SenseInfo('02357228-v', 0) ],
"_incompatibility_n_1_rel" : [ SenseInfo('13858045-n', 1), SenseInfo('13975037-n', 0), SenseInfo('04714440-n', 0) ],
"_pre-processing_n_1_rel" : [  ],
"_ruby_a_1_rel" : [ SenseInfo('00381097-a', 0) ],
"_catalog_v_1_rel" : [ SenseInfo('01626844-v', 0), SenseInfo('00652622-v', 0) ],
"_medium_a_1_rel" : [ SenseInfo('01531957-a', 5), SenseInfo('00617752-a', 0) ],
"_convocation_n_1_rel" : [ SenseInfo('08402222-n', 0), SenseInfo('01230850-n', 0) ],
"_thoroughfare_n_1_rel" : [ SenseInfo('04426618-n', 2) ],
"_buy_v_out_rel" : [ SenseInfo('02207206-v', 102), SenseInfo('02284096-v', 2), SenseInfo('02646757-v', 0), SenseInfo('02212103-v', 0), SenseInfo('00683670-v', 0) ],
"_exercise_v_1_rel" : [ SenseInfo('01166093-v', 14), SenseInfo('02568672-v', 11), SenseInfo('00100551-v', 3), SenseInfo('00099721-v', 3), SenseInfo('00606093-v', 0) ],
"_duration_n_of_rel" : [ SenseInfo('15133621-n', 5), SenseInfo('15133488-n', 1), SenseInfo('05051249-n', 1) ],
"_cutting_n_1_rel" : [ SenseInfo('00945205-n', 2), SenseInfo('13127473-n', 1), SenseInfo('00386915-n', 1), SenseInfo('09262371-n', 0), SenseInfo('06612649-n', 0), SenseInfo('00942234-n', 0), SenseInfo('00489475-n', 0), SenseInfo('00387657-n', 0), SenseInfo('00363052-n', 0), SenseInfo('00359238-n', 0) ],
"_mesh_n_1_rel" : [ SenseInfo('13654889-n', 1), SenseInfo('07338114-n', 0), SenseInfo('05731062-n', 0), SenseInfo('03819595-n', 0), SenseInfo('00140393-n', 0), SenseInfo('13654889-n', 1), SenseInfo('07338114-n', 0), SenseInfo('05731062-n', 0), SenseInfo('03819595-n', 0), SenseInfo('00140393-n', 0) ],
"_restriction_n_of_rel" : [ SenseInfo('05846355-n', 5), SenseInfo('00808182-n', 1), SenseInfo('01148614-n', 0), SenseInfo('05846355-n', 5), SenseInfo('00808182-n', 1), SenseInfo('01148614-n', 0) ],
"_deterrence_n_1_rel" : [ SenseInfo('09180118-n', 0), SenseInfo('07254057-n', 0), SenseInfo('01076488-n', 0) ],
"_gemstone_n_1_rel" : [ SenseInfo('14699752-n', 0) ],
"_feces_n_1_rel" : [ SenseInfo('14854262-n', 0), SenseInfo('14854262-n', 0) ],
"_goldfish_n_1_rel" : [ SenseInfo('01443537-n', 0) ],
"_parasitic_a_1_rel" : [ SenseInfo('02833692-a', 0), SenseInfo('02720484-a', 0), SenseInfo('00726723-a', 0) ],
"_huff_v_1_rel" : [ SenseInfo('01200245-v', 0), SenseInfo('00006802-v', 0) ],
"_bring_v_down_rel" : [ SenseInfo('02077656-v', 122), SenseInfo('01438902-v', 55), SenseInfo('01629589-v', 31), SenseInfo('01433294-v', 19), SenseInfo('00135857-v', 9), SenseInfo('01434140-v', 4), SenseInfo('01618547-v', 3), SenseInfo('02324478-v', 2), SenseInfo('02247390-v', 1), SenseInfo('01808218-v', 0), SenseInfo('00767334-v', 0) ],
"_idle_n_1_rel" : [ SenseInfo('14009618-n', 0) ],
"_applicant_n_1_rel" : [ SenseInfo('09607280-n', 13) ],
"_loot_v_1_rel" : [ SenseInfo('02345288-v', 1), SenseInfo('02344568-v', 0) ],
"_cover_v_up_rel" : [ SenseInfo('01332730-v', 35), SenseInfo('01207951-v', 19), SenseInfo('02687916-v', 18), SenseInfo('02675935-v', 16), SenseInfo('01033527-v', 14), SenseInfo('02629793-v', 10), SenseInfo('01912159-v', 4), SenseInfo('00967098-v', 3), SenseInfo('01129201-v', 2), SenseInfo('02395000-v', 1), SenseInfo('02148369-v', 1), SenseInfo('01148296-v', 1), SenseInfo('00967455-v', 1), SenseInfo('00891216-v', 1), SenseInfo('02672859-v', 0), SenseInfo('02474446-v', 0), SenseInfo('02395194-v', 0), SenseInfo('02310674-v', 0), SenseInfo('02147109-v', 0), SenseInfo('01582200-v', 0), SenseInfo('01430447-v', 0), SenseInfo('01336635-v', 0), SenseInfo('01150010-v', 0), SenseInfo('01148580-v', 0), SenseInfo('00060185-v', 0), SenseInfo('00048633-v', 0) ],
"_orris_n_1_rel" : [ SenseInfo('12413419-n', 0), SenseInfo('12412987-n', 0) ],
"_anthropoid_n_1_rel" : [ SenseInfo('09796185-n', 0), SenseInfo('02470709-n', 0) ],
"_tongue_n_1_rel" : [ SenseInfo('05301072-n', 13), SenseInfo('06904171-n', 4), SenseInfo('13918387-n', 2), SenseInfo('07082198-n', 1), SenseInfo('09442595-n', 0), SenseInfo('07652995-n', 0), SenseInfo('04450994-n', 0), SenseInfo('03037228-n', 0) ],
"_peaceful_a_1_rel" : [ SenseInfo('01740892-a', 5), SenseInfo('02513101-a', 0), SenseInfo('01740892-a', 5), SenseInfo('02513101-a', 0) ],
"_indecisive_a_1_rel" : [ SenseInfo('00686081-a', 0), SenseInfo('00685483-a', 0), SenseInfo('00702118-a', 0) ],
"_absolute_n_1_rel" : [ SenseInfo('05854474-n', 1) ],
"_vesicant_n_1_rel" : [ SenseInfo('15112239-n', 0) ],
"_distributive_a_1_rel" : [ SenseInfo('00467913-a', 1) ],
"_disband_v_1_rel" : [ SenseInfo('02030967-v', 1), SenseInfo('02029944-v', 1) ],
"_industrious_a_1_rel" : [ SenseInfo('00754682-a', 1), SenseInfo('00885099-a', 0) ],
"_dazzle_v_1_rel" : [ SenseInfo('02162434-v', 3), SenseInfo('00725046-v', 0), SenseInfo('02162434-v', 3), SenseInfo('00725046-v', 0) ],
"_nettle_v_1_rel" : [ SenseInfo('02120715-v', 0), SenseInfo('01787955-v', 0) ],
"_thereafter_p_rel" : [ SenseInfo('00146281-r', 8) ],
"_microphone_n_1_rel" : [ SenseInfo('03759954-n', 4) ],
"_trapezius_n_1_rel" : [ SenseInfo('05591770-n', 0) ],
"_cobbled_a_1_rel" : [  ],
"_acre_n_1_rel" : [ SenseInfo('13613742-n', 15), SenseInfo('08854725-n', 0), SenseInfo('08793310-n', 0) ],
"_recreation_n_1_rel" : [ SenseInfo('00426928-n', 23), SenseInfo('00401783-n', 0) ],
"_appall_n_1_rel" : [  ],
"_european_n_1_rel" : [ SenseInfo('09686536-n', 2) ],
"_not+more+than_x_deg_rel" : [  ],
"_gloss_v_over_rel" : [ SenseInfo('01682582-v', 0), SenseInfo('00961329-v', 0), SenseInfo('00960961-v', 0), SenseInfo('00837133-v', 0) ],
"_see_v_off_rel" : [ SenseInfo('02129289-v', 613), SenseInfo('00591115-v', 159), SenseInfo('02128873-v', 140), SenseInfo('01635432-v', 58), SenseInfo('00690614-v', 47), SenseInfo('00598954-v', 40), SenseInfo('02150948-v', 29), SenseInfo('02023107-v', 27), SenseInfo('00920336-v', 27), SenseInfo('00662589-v', 22), SenseInfo('02488304-v', 13), SenseInfo('02488488-v', 12), SenseInfo('02493030-v', 10), SenseInfo('02549581-v', 7), SenseInfo('01470670-v', 4), SenseInfo('02486232-v', 1), SenseInfo('02129709-v', 1), SenseInfo('00703708-v', 1), SenseInfo('02156225-v', 0), SenseInfo('02131279-v', 0), SenseInfo('02110220-v', 0), SenseInfo('02026086-v', 0), SenseInfo('01156568-v', 0), SenseInfo('00623151-v', 0) ],
"_paste_v_in_rel" : [ SenseInfo('01332205-v', 5), SenseInfo('01412644-v', 0), SenseInfo('01332599-v', 0) ],
"_sonuvabitch_n_1_rel" : [  ],
"_schoolteacher_n_1_rel" : [ SenseInfo('10560352-n', 0) ],
"_relish_v_1_rel" : [ SenseInfo('01820302-v', 2) ],
"_shack_v_up-with_rel" : [ SenseInfo('02650552-v', 0), SenseInfo('02059916-v', 0), SenseInfo('02650552-v', 0), SenseInfo('02059916-v', 0), SenseInfo('02650552-v', 0), SenseInfo('02059916-v', 0) ],
"_right+to+left_p_1_rel" : [  ],
"_muster_n_1_rel" : [ SenseInfo('08479615-n', 0), SenseInfo('01157850-n', 0) ],
"_suburbian_a_1_rel" : [  ],
"_resent_v_1_rel" : [ SenseInfo('01773346-v', 14), SenseInfo('01825125-v', 0), SenseInfo('01773346-v', 14), SenseInfo('01825125-v', 0) ],
"_nudge_v_up_rel" : [ SenseInfo('01231252-v', 3), SenseInfo('00766289-v', 0) ],
"_garment_n_1_rel" : [ SenseInfo('03419014-n', 4) ],
"_symptom_n_1_rel" : [ SenseInfo('14299637-n', 8), SenseInfo('06798187-n', 6) ],
"_bind_n_1_rel" : [ SenseInfo('05689801-n', 0) ],
"_saucer_n_1_rel" : [ SenseInfo('13875185-n', 0), SenseInfo('04139291-n', 0), SenseInfo('03207305-n', 0), SenseInfo('03206602-n', 0) ],
"_femoral_a_1_rel" : [ SenseInfo('02726017-a', 0) ],
"_regiment_n_1_rel" : [ SenseInfo('08213817-n', 145) ],
"_unbending_a_1_rel" : [ SenseInfo('01029151-a', 0), SenseInfo('01029151-a', 0) ],
"_standup_a_1_rel" : [  ],
"_scarf_v_up_rel" : [ SenseInfo('01431132-v', 0), SenseInfo('01294889-v', 0), SenseInfo('00051060-v', 0) ],
"_pricewise_a_1_rel" : [  ],
"_complete_v_1_rel" : [ SenseInfo('00484166-v', 52), SenseInfo('00455750-v', 5), SenseInfo('02563724-v', 3), SenseInfo('01117484-v', 1), SenseInfo('01020731-v', 1) ],
"_glitter_n_1_rel" : [ SenseInfo('04952944-n', 2), SenseInfo('07412668-n', 0) ],
"_fingerprint_v_1_rel" : [ SenseInfo('01748748-v', 0) ],
"_instinctive_a_1_rel" : [ SenseInfo('02282985-a', 0), SenseInfo('02282985-a', 0) ],
"_bog_n_1_rel" : [ SenseInfo('09225943-n', 1) ],
"_further+on_p_rel" : [  ],
"_mediaeval_a_1_rel" : [ SenseInfo('02989754-a', 0), SenseInfo('01537448-a', 0) ],
"_polite_a_1_rel" : [ SenseInfo('00641158-a', 3), SenseInfo('01947741-a', 1), SenseInfo('00642379-a', 0), SenseInfo('00641158-a', 3), SenseInfo('01947741-a', 1), SenseInfo('00642379-a', 0), SenseInfo('00641158-a', 3), SenseInfo('01947741-a', 1), SenseInfo('00642379-a', 0), SenseInfo('00641158-a', 3), SenseInfo('01947741-a', 1), SenseInfo('00642379-a', 0) ],
"_leftovers_n_1_rel" : [ SenseInfo('13811184-n', 0), SenseInfo('13811184-n', 0), SenseInfo('13811184-n', 0), SenseInfo('13811184-n', 0), SenseInfo('13811184-n', 0), SenseInfo('13811184-n', 0) ],
"_disconcerting_a_1_rel" : [ SenseInfo('01809019-a', 2) ],
"_tree_n_of_rel" : [ SenseInfo('13104059-n', 107), SenseInfo('13912260-n', 0), SenseInfo('11348160-n', 0) ],
"_pretence_n_1_rel" : [ SenseInfo('04788853-n', 1), SenseInfo('04678908-n', 1), SenseInfo('06759349-n', 0), SenseInfo('05769930-n', 0), SenseInfo('00754956-n', 0), SenseInfo('04788853-n', 1), SenseInfo('04678908-n', 1), SenseInfo('06759349-n', 0), SenseInfo('05769930-n', 0), SenseInfo('00754956-n', 0) ],
"_downstream+of_p_rel" : [  ],
"_value_n_1_rel" : [ SenseInfo('05856388-n', 65), SenseInfo('05138488-n', 52), SenseInfo('13413493-n', 13), SenseInfo('04979425-n', 2), SenseInfo('15134913-n', 0), SenseInfo('05923983-n', 0) ],
"_stick_v_in_rel" : [ SenseInfo('01528069-v', 5), SenseInfo('01857392-v', 2), SenseInfo('01356750-v', 2), SenseInfo('02754032-v', 0), SenseInfo('02647798-v', 0), SenseInfo('02638845-v', 0), SenseInfo('02638630-v', 0), SenseInfo('01667969-v', 0), SenseInfo('01614581-v', 0), SenseInfo('01614426-v', 0), SenseInfo('01614235-v', 0), SenseInfo('01441993-v', 0), SenseInfo('01441793-v', 0), SenseInfo('01220885-v', 0), SenseInfo('00748084-v', 0), SenseInfo('00622384-v', 0) ],
"_midevening_n_1_rel" : [  ],
"_smart_a_1_rel" : [ SenseInfo('00438707-a', 8), SenseInfo('00975487-a', 3), SenseInfo('01335458-a', 2), SenseInfo('00205295-a', 2), SenseInfo('01513376-a', 0), SenseInfo('00980144-a', 0), SenseInfo('00182718-a', 0), SenseInfo('00438707-a', 8), SenseInfo('00975487-a', 3), SenseInfo('01335458-a', 2), SenseInfo('00205295-a', 2), SenseInfo('01513376-a', 0), SenseInfo('00980144-a', 0), SenseInfo('00182718-a', 0), SenseInfo('00438707-a', 8), SenseInfo('00975487-a', 3), SenseInfo('01335458-a', 2), SenseInfo('00205295-a', 2), SenseInfo('01513376-a', 0), SenseInfo('00980144-a', 0), SenseInfo('00182718-a', 0), SenseInfo('00438707-a', 8), SenseInfo('00975487-a', 3), SenseInfo('01335458-a', 2), SenseInfo('00205295-a', 2), SenseInfo('01513376-a', 0), SenseInfo('00980144-a', 0), SenseInfo('00182718-a', 0), SenseInfo('00438707-a', 8), SenseInfo('00975487-a', 3), SenseInfo('01335458-a', 2), SenseInfo('00205295-a', 2), SenseInfo('01513376-a', 0), SenseInfo('00980144-a', 0), SenseInfo('00182718-a', 0) ],
"_clotheshorse_n_1_rel" : [ SenseInfo('03051041-n', 2), SenseInfo('09991026-n', 0) ],
"_hearten_v_1_rel" : [ SenseInfo('01817938-v', 0), SenseInfo('01817938-v', 0), SenseInfo('01817938-v', 0), SenseInfo('01817938-v', 0), SenseInfo('01817938-v', 0) ],
"_flush_v_out_rel" : [ SenseInfo('00103317-v', 3), SenseInfo('00455212-v', 2), SenseInfo('02199435-v', 0), SenseInfo('01307142-v', 0), SenseInfo('00455529-v', 0), SenseInfo('00455368-v', 0), SenseInfo('00454868-v', 0) ],
"_nearest+neighbor_n_1_rel" : [  ],
"_major_n_1_rel" : [ SenseInfo('10283170-n', 2), SenseInfo('11150634-n', 0), SenseInfo('10283366-n', 0), SenseInfo('05997659-n', 0) ],
"_nude_n_1_rel" : [ SenseInfo('03835197-n', 2), SenseInfo('14456435-n', 0), SenseInfo('10365399-n', 0), SenseInfo('03835298-n', 0) ],
"_handkerchief_n_1_rel" : [ SenseInfo('03485794-n', 6) ],
"_wit_n_1_rel" : [ SenseInfo('06776138-n', 9), SenseInfo('05618056-n', 3), SenseInfo('10762342-n', 0) ],
"_lacking_a_1_rel" : [ SenseInfo('00052012-a', 4), SenseInfo('00927832-a', 0) ],
"_to+name+a+few_c_rel" : [  ],
"_befall_v_1_rel" : [ SenseInfo('00345000-v', 3), SenseInfo('00344643-v', 0), SenseInfo('00345000-v', 3), SenseInfo('00344643-v', 0) ],
"_profile_v_1_rel" : [ SenseInfo('01699346-v', 0), SenseInfo('01680913-v', 0) ],
"_snowslope_n_1_rel" : [  ],
"_steepen_v_1_rel" : [ SenseInfo('00536807-v', 0), SenseInfo('00536678-v', 0) ],
"_finish_n_1_rel" : [ SenseInfo('04700642-n', 3), SenseInfo('15267536-n', 0), SenseInfo('14459824-n', 0), SenseInfo('08567877-n', 0), SenseInfo('07353376-n', 0), SenseInfo('07333162-n', 0), SenseInfo('07291312-n', 0), SenseInfo('05717747-n', 0), SenseInfo('00210518-n', 0) ],
"_overlord_n_1_rel" : [ SenseInfo('10388440-n', 0) ],
"_belongings_n_1_rel" : [ SenseInfo('13244109-n', 0), SenseInfo('13244109-n', 0) ],
"_behind_n_1_rel" : [ SenseInfo('05559256-n', 1) ],
"_kinetic_a_1_rel" : [ SenseInfo('02893827-a', 3), SenseInfo('01563349-a', 0), SenseInfo('00809164-a', 0), SenseInfo('02893827-a', 3), SenseInfo('01563349-a', 0), SenseInfo('00809164-a', 0) ],
"_blurt_v_1_rel" : [ SenseInfo('00981944-v', 1), SenseInfo('00981944-v', 1) ],
"_abdomen_n_1_rel" : [ SenseInfo('05556943-n', 2), SenseInfo('05558345-n', 0) ],
"_expletive_n_1_rel" : [ SenseInfo('07125096-n', 1), SenseInfo('07126228-n', 0) ],
"_millennium_n_1_rel" : [ SenseInfo('15141213-n', 4), SenseInfo('15263283-n', 0), SenseInfo('15252146-n', 0) ],
"_nervous_a_about_rel" : [ SenseInfo('02406908-a', 9), SenseInfo('02456157-a', 3), SenseInfo('02904518-a', 0), SenseInfo('00919813-a', 0), SenseInfo('00919155-a', 0), SenseInfo('02406908-a', 9), SenseInfo('02456157-a', 3), SenseInfo('02904518-a', 0), SenseInfo('00919813-a', 0), SenseInfo('00919155-a', 0) ],
"_teem_v_1_rel" : [ SenseInfo('02714974-v', 1), SenseInfo('02028366-v', 0) ],
"_bell_n_1_rel" : [ SenseInfo('02824448-n', 9), SenseInfo('03222516-n', 2), SenseInfo('07377244-n', 1), SenseInfo('15227593-n', 0), SenseInfo('13886260-n', 0), SenseInfo('10842575-n', 0), SenseInfo('10842376-n', 0), SenseInfo('10842213-n', 0), SenseInfo('03017168-n', 0), SenseInfo('02824858-n', 0) ],
"_patriarchal_a_1_rel" : [ SenseInfo('01737825-a', 1), SenseInfo('02759765-a', 0) ],
"_float_v_cause_rel" : [ SenseInfo('01902783-v', 14), SenseInfo('01904293-v', 4), SenseInfo('01874568-v', 3), SenseInfo('02532079-v', 0), SenseInfo('01838651-v', 0), SenseInfo('01514887-v', 0), SenseInfo('01361998-v', 0), SenseInfo('00696042-v', 0), SenseInfo('00566181-v', 0) ],
"_mill_v_1_rel" : [ SenseInfo('01902126-v', 1), SenseInfo('00332017-v', 1), SenseInfo('01457825-v', 0), SenseInfo('01391697-v', 0) ],
"_prick_n_1_rel" : [ SenseInfo('09815188-n', 2), SenseInfo('13904843-n', 0), SenseInfo('05526713-n', 0), SenseInfo('00944789-n', 0) ],
"_inducement_n_1_rel" : [ SenseInfo('09179776-n', 1), SenseInfo('00159177-n', 0), SenseInfo('09179776-n', 1), SenseInfo('00159177-n', 0) ],
"_darn_a_1_rel" : [ SenseInfo('05140793-n', 0), SenseInfo('03745285-n', 0), SenseInfo('05140793-n', 0), SenseInfo('03745285-n', 0), SenseInfo('05140793-n', 0), SenseInfo('03745285-n', 0) ],
"_prone_a_to_rel" : [ SenseInfo('01292884-a', 4), SenseInfo('01239534-a', 2), SenseInfo('01292884-a', 4), SenseInfo('01239534-a', 2) ],
"_well_a_2_rel" : [ SenseInfo('02540578-a', 4), SenseInfo('01048762-a', 3), SenseInfo('00067638-a', 3), SenseInfo('02540578-a', 4), SenseInfo('01048762-a', 3), SenseInfo('00067638-a', 3), SenseInfo('02540578-a', 4), SenseInfo('01048762-a', 3), SenseInfo('00067638-a', 3) ],
"_near_x_deg_rel" : [ SenseInfo('00444519-a', 44), SenseInfo('00409709-r', 19), SenseInfo('02053941-v', 11), SenseInfo('00073033-r', 1), SenseInfo('02033556-a', 0), SenseInfo('01573762-a', 0), SenseInfo('01113225-a', 0), SenseInfo('00452883-a', 0), SenseInfo('00451872-a', 0), SenseInfo('00444519-a', 44), SenseInfo('00409709-r', 19), SenseInfo('02053941-v', 11), SenseInfo('00073033-r', 1), SenseInfo('02033556-a', 0), SenseInfo('01573762-a', 0), SenseInfo('01113225-a', 0), SenseInfo('00452883-a', 0), SenseInfo('00451872-a', 0) ],
"_inoculate_v_against_rel" : [ SenseInfo('00832617-v', 0), SenseInfo('00188252-v', 0), SenseInfo('00086835-v', 0), SenseInfo('00056093-v', 0), SenseInfo('00053517-v', 0), SenseInfo('00832617-v', 0), SenseInfo('00188252-v', 0), SenseInfo('00086835-v', 0), SenseInfo('00056093-v', 0), SenseInfo('00053517-v', 0) ],
"_balance_v_out_rel" : [ SenseInfo('02673134-v', 6), SenseInfo('02264967-v', 3), SenseInfo('01602318-v', 2), SenseInfo('02743020-v', 1) ],
"_coati_n_1_rel" : [ SenseInfo('02509515-n', 0) ],
"_list_v_as_rel" : [ SenseInfo('00945853-v', 23), SenseInfo('02472223-v', 19), SenseInfo('02039013-v', 0), SenseInfo('02038791-v', 0), SenseInfo('00946755-v', 0), SenseInfo('00945853-v', 23), SenseInfo('02472223-v', 19), SenseInfo('02039013-v', 0), SenseInfo('02038791-v', 0), SenseInfo('00946755-v', 0) ],
"_de-energize_v_1_rel" : [ SenseInfo('00023244-v', 0) ],
"_purport_n_1_rel" : [ SenseInfo('06605897-n', 0), SenseInfo('05922651-n', 0) ],
"_hem_v_in_rel" : [ SenseInfo('01329732-v', 0), SenseInfo('01061799-v', 0) ],
"_accident_n_1_rel" : [ SenseInfo('07301336-n', 7), SenseInfo('07300960-n', 5), SenseInfo('07301336-n', 7), SenseInfo('07300960-n', 5) ],
"_pacify_v_1_rel" : [ SenseInfo('01765392-v', 3), SenseInfo('01647867-v', 0) ],
"_prose_n_1_rel" : [ SenseInfo('06376572-n', 3), SenseInfo('07072434-n', 0) ],
"_interrelate_v_1_rel" : [ SenseInfo('02724417-v', 0), SenseInfo('00713818-v', 0) ],
"_syrian_a_1_rel" : [ SenseInfo('03016519-a', 1) ],
"_across_p_sel_rel" : [ SenseInfo('00272951-r', 4), SenseInfo('00272844-r', 1) ],
"_sweat_v_off_rel" : [ SenseInfo('00067545-v', 5) ],
"_sweep_v_away_rel" : [ SenseInfo('01870043-v', 13), SenseInfo('01869563-v', 12), SenseInfo('01393714-v', 5), SenseInfo('02677797-v', 3), SenseInfo('02685390-v', 2), SenseInfo('01393996-v', 1), SenseInfo('01100952-v', 1), SenseInfo('02688403-v', 0), SenseInfo('01593763-v', 0) ],
"_limitless_a_1_rel" : [ SenseInfo('01499269-a', 1), SenseInfo('01415605-a', 0), SenseInfo('01007657-a', 0) ],
"_predicate_n_1_rel" : [ SenseInfo('06316813-n', 0), SenseInfo('06316626-n', 0) ],
"_identical_a_to_rel" : [ SenseInfo('02064127-a', 12), SenseInfo('02068946-a', 9), SenseInfo('00292448-a', 0), SenseInfo('01360962-a', 0), SenseInfo('00561896-a', 0) ],
"_graduation_n_of_rel" : [ SenseInfo('00212065-n', 6), SenseInfo('07454758-n', 0), SenseInfo('06801965-n', 0), SenseInfo('01003729-n', 0) ],
"_cosy_a_1_rel" : [ SenseInfo('00477284-a', 0), SenseInfo('00477284-a', 0), SenseInfo('00477284-a', 0), SenseInfo('00477284-a', 0) ],
"_warning_n_of_rel" : [ SenseInfo('07224151-n', 13), SenseInfo('06672297-n', 9), SenseInfo('07212874-n', 0), SenseInfo('07224151-n', 13), SenseInfo('06672297-n', 9), SenseInfo('07212874-n', 0) ],
"_homestead_n_1_rel" : [ SenseInfo('13249699-n', 0), SenseInfo('13249400-n', 0), SenseInfo('03529629-n', 0) ],
"_daunting_a_1_rel" : [ SenseInfo('00867520-a', 0) ],
"_bottom_v_out_rel" : [ SenseInfo('02337699-v', 0), SenseInfo('01238358-v', 0), SenseInfo('00728954-v', 0) ],
"_sarcasm_n_1_rel" : [ SenseInfo('06777164-n', 2) ],
"_head_v_on_rel" : [ SenseInfo('01935233-v', 29), SenseInfo('02440244-v', 19), SenseInfo('01999423-v', 3), SenseInfo('02729023-v', 2), SenseInfo('01931768-v', 2), SenseInfo('02754463-v', 0), SenseInfo('02694287-v', 0), SenseInfo('02624128-v', 0), SenseInfo('01590915-v', 0) ],
"_hydrolysis_n_1_rel" : [ SenseInfo('13494919-n', 0) ],
"_emergent_a_1_rel" : [ SenseInfo('01143855-a', 0), SenseInfo('00003553-a', 0) ],
"_inform_v_of_rel" : [ SenseInfo('00831651-v', 46), SenseInfo('00522613-v', 2), SenseInfo('00833199-v', 1) ],
"_beach_n_1_rel" : [ SenseInfo('09217230-n', 14), SenseInfo('09217230-n', 14) ],
"_fairly_x_deg_rel" : [ SenseInfo('00035718-r', 20), SenseInfo('00106759-r', 3), SenseInfo('00285092-r', 0) ],
"_pleased_a_with_rel" : [ SenseInfo('01805157-a', 9), SenseInfo('01892506-a', 3), SenseInfo('01805157-a', 9), SenseInfo('01892506-a', 3), SenseInfo('01805157-a', 9), SenseInfo('01892506-a', 3), SenseInfo('01805157-a', 9), SenseInfo('01892506-a', 3) ],
"_movable_a_1_rel" : [ SenseInfo('01526062-a', 0), SenseInfo('01523724-a', 0) ],
"_sunlit_a_1_rel" : [ SenseInfo('00272771-a', 0) ],
"_stare_n_1_rel" : [ SenseInfo('00878456-n', 9) ],
"_co-worker_n_1_rel" : [ SenseInfo('09936215-n', 3), SenseInfo('09936215-n', 3) ],
"_aboveboard_p_rel" : [ SenseInfo('00314384-r', 0), SenseInfo('02318728-a', 0) ],
"_photograph_n_1_rel" : [ SenseInfo('03925226-n', 17), SenseInfo('03925226-n', 17) ],
"_canine_a_1_rel" : [ SenseInfo('02677861-a', 0), SenseInfo('02677703-a', 0) ],
"_dweller_n_1_rel" : [ SenseInfo('09620078-n', 3) ],
"_cock_v_1_rel" : [ SenseInfo('01884868-v', 2), SenseInfo('01247426-v', 2), SenseInfo('01916634-v', 0) ],
"_aliment_n_1_rel" : [ SenseInfo('07570720-n', 0) ],
"_adage_n_1_rel" : [ SenseInfo('07153838-n', 0) ],
"_entirety_n_1_rel" : [ SenseInfo('14461231-n', 2) ],
"_close_n_of_rel" : [ SenseInfo('15267536-n', 8), SenseInfo('06398401-n', 0), SenseInfo('00210797-n', 0), SenseInfo('15267536-n', 8), SenseInfo('06398401-n', 0), SenseInfo('00210797-n', 0) ],
"_endow_v_with_rel" : [ SenseInfo('02474239-v', 3), SenseInfo('02201268-v', 1) ],
"_african_n_1_rel" : [ SenseInfo('09634494-n', 0) ],
"_snap-on_a_1_rel" : [  ],
"_alumna_n_1_rel" : [ SenseInfo('09786338-n', 0) ],
"_update_v_1_rel" : [ SenseInfo('00170695-v', 2), SenseInfo('00833546-v', 1), SenseInfo('00170857-v', 0) ],
"_defile_n_1_rel" : [ SenseInfo('09263912-n', 0) ],
"_swarm_v_with_rel" : [ SenseInfo('02714974-v', 3), SenseInfo('02028366-v', 3) ],
"_conserve_v_1_rel" : [ SenseInfo('02682567-v', 0), SenseInfo('02280132-v', 0), SenseInfo('02269143-v', 0), SenseInfo('00212049-v', 0) ],
"_freeze_v_cause_rel" : [ SenseInfo('01834730-v', 5), SenseInfo('00374135-v', 5), SenseInfo('00078138-v', 3), SenseInfo('00375865-v', 1), SenseInfo('00363493-v', 1), SenseInfo('02758826-v', 0), SenseInfo('00445711-v', 0), SenseInfo('00269423-v', 0), SenseInfo('00021997-v', 0), SenseInfo('00012613-v', 0) ],
"_localization_n_of_rel" : [ SenseInfo('00155487-n', 2), SenseInfo('05992274-n', 0), SenseInfo('00155487-n', 2), SenseInfo('05992274-n', 0) ],
"_willingness_n_1_rel" : [ SenseInfo('04644512-n', 8), SenseInfo('04644512-n', 8) ],
"_catlike_a_1_rel" : [  ],
"_dispose_v_1_rel" : [ SenseInfo('02354922-v', 3), SenseInfo('02222318-v', 3), SenseInfo('00680841-v', 2), SenseInfo('01496497-v', 0), SenseInfo('00300761-v', 0) ],
"_stamen_n_1_rel" : [ SenseInfo('11675096-n', 1) ],
"_close-up_n_1_rel" : [ SenseInfo('03049695-n', 3), SenseInfo('03049695-n', 3), SenseInfo('03049695-n', 3) ],
"_arrangement_n_1_rel" : [ SenseInfo('05795044-n', 13), SenseInfo('07938773-n', 4), SenseInfo('05726596-n', 4), SenseInfo('05075602-n', 2), SenseInfo('07038400-n', 1), SenseInfo('00939628-n', 0), SenseInfo('05795044-n', 13), SenseInfo('07938773-n', 4), SenseInfo('05726596-n', 4), SenseInfo('05075602-n', 2), SenseInfo('07038400-n', 1), SenseInfo('00939628-n', 0), SenseInfo('05795044-n', 13), SenseInfo('07938773-n', 4), SenseInfo('05726596-n', 4), SenseInfo('05075602-n', 2), SenseInfo('07038400-n', 1), SenseInfo('00939628-n', 0), SenseInfo('05795044-n', 13), SenseInfo('07938773-n', 4), SenseInfo('05726596-n', 4), SenseInfo('05075602-n', 2), SenseInfo('07038400-n', 1), SenseInfo('00939628-n', 0) ],
"_diligence_n_1_rel" : [ SenseInfo('04673006-n', 1), SenseInfo('04865114-n', 0), SenseInfo('00633329-n', 0) ],
"_oxidize_v_1_rel" : [ SenseInfo('00239321-v', 0), SenseInfo('00238867-v', 0) ],
"_follow-through_n_1_rel" : [ SenseInfo('00211593-n', 1), SenseInfo('00211776-n', 0), SenseInfo('00211593-n', 1), SenseInfo('00211776-n', 0) ],
"_increase_n_1_rel" : [ SenseInfo('13754293-n', 49), SenseInfo('07356676-n', 21), SenseInfo('13497135-n', 7), SenseInfo('05108947-n', 3), SenseInfo('00363260-n', 3) ],
"_disconnect_v_1_rel" : [ SenseInfo('01421417-v', 1), SenseInfo('01356038-v', 1) ],
"_progress_v_1_rel" : [ SenseInfo('00248659-v', 12), SenseInfo('01992503-v', 3), SenseInfo('00252990-v', 0) ],
"_injection_n_of_rel" : [ SenseInfo('00322634-n', 4), SenseInfo('14849215-n', 0), SenseInfo('00697365-n', 0) ],
"_woollens_n_1_rel" : [ SenseInfo('04599235-n', 0), SenseInfo('04599235-n', 0) ],
"_yap_n_1_rel" : [ SenseInfo('05302307-n', 0) ],
"_consideration_n_1_rel" : [ SenseInfo('05784831-n', 17), SenseInfo('05822746-n', 11), SenseInfo('07138915-n', 1), SenseInfo('04841358-n', 1), SenseInfo('13323313-n', 0), SenseInfo('01229793-n', 0) ],
"_pause_n_1_rel" : [ SenseInfo('15271008-n', 12), SenseInfo('01062817-n', 3) ],
"_probability_n_of_rel" : [ SenseInfo('05091770-n', 30), SenseInfo('04756172-n', 2), SenseInfo('05091770-n', 30), SenseInfo('04756172-n', 2) ],
"_dietary_a_1_rel" : [ SenseInfo('02846322-a', 4) ],
"_unbound_a_1_rel" : [ SenseInfo('00257462-a', 0), SenseInfo('00254152-a', 0), SenseInfo('01058756-a', 0), SenseInfo('00257462-a', 0), SenseInfo('00254152-a', 0), SenseInfo('01058756-a', 0) ],
"_impersonal_a_1_rel" : [ SenseInfo('01769565-a', 6), SenseInfo('01615625-a', 1), SenseInfo('01769565-a', 6), SenseInfo('01615625-a', 1) ],
"_episcopal_a_1_rel" : [ SenseInfo('02954981-a', 0), SenseInfo('02721057-a', 0) ],
"_envisage_v_as_rel" : [ SenseInfo('01636397-v', 2), SenseInfo('01636397-v', 2) ],
"_contractual_a_1_rel" : [ SenseInfo('02702656-a', 4) ],
"_dice_v_1_rel" : [ SenseInfo('01256867-v', 0), SenseInfo('01138733-v', 0) ],
"_ask_v_off_rel" : [ SenseInfo('00784342-v', 244), SenseInfo('00752493-v', 165), SenseInfo('00784727-v', 16), SenseInfo('00755745-v', 2), SenseInfo('00897746-v', 1), SenseInfo('02627934-v', 0), SenseInfo('01068565-v', 0) ],
"_blame_v_on_rel" : [ SenseInfo('00842538-v', 12), SenseInfo('00842772-v', 9), SenseInfo('00727991-v', 4) ],
"_must_n_1_rel" : [ SenseInfo('09363970-n', 0), SenseInfo('07924655-n', 0), SenseInfo('04928194-n', 0) ],
"_unembarrassed_a_1_rel" : [ SenseInfo('00155886-a', 0), SenseInfo('00155886-a', 0) ],
"_suffocate_v_1_rel" : [ SenseInfo('01569181-v', 3), SenseInfo('01476180-v', 0), SenseInfo('00391203-v', 0), SenseInfo('00391021-v', 0), SenseInfo('00359511-v', 0), SenseInfo('00106412-v', 0), SenseInfo('00077698-v', 0), SenseInfo('01569181-v', 3), SenseInfo('01476180-v', 0), SenseInfo('00391203-v', 0), SenseInfo('00391021-v', 0), SenseInfo('00359511-v', 0), SenseInfo('00106412-v', 0), SenseInfo('00077698-v', 0) ],
"_chalky_a_1_rel" : [ SenseInfo('02673969-a', 0), SenseInfo('00388571-a', 0), SenseInfo('02673969-a', 0), SenseInfo('00388571-a', 0), SenseInfo('02673969-a', 0), SenseInfo('00388571-a', 0) ],
"_unprecedented_a_1_rel" : [ SenseInfo('00128572-a', 5), SenseInfo('00128572-a', 5) ],
"_maximize_v_1_rel" : [ SenseInfo('00428583-v', 2), SenseInfo('00428870-v', 1) ],
"_rampant_a_1_rel" : [ SenseInfo('00601032-a', 1), SenseInfo('01236964-a', 0), SenseInfo('00016005-a', 0) ],
"_saddle_v_with_rel" : [ SenseInfo('01492422-v', 1), SenseInfo('01490814-v', 1), SenseInfo('00750532-v', 1) ],
"_anti+democratic_a_1_rel" : [  ],
"_cunning_n_1_rel" : [ SenseInfo('05621178-n', 0), SenseInfo('04876888-n', 0) ],
"_reuse_n_1_rel" : [  ],
"_gentle_v_1_rel" : [ SenseInfo('01765392-v', 1), SenseInfo('02398463-v', 0), SenseInfo('01426072-v', 0) ],
"_comings+and+goings_n_1_rel" : [  ],
"_estrange_v_1_rel" : [ SenseInfo('02597246-v', 0), SenseInfo('01823528-v', 0) ],
"_in+time_a_1_rel" : [  ],
"_laugh_v_away_rel" : [ SenseInfo('00031820-v', 64) ],
"_artifice_n_1_rel" : [ SenseInfo('00172598-n', 1) ],
"_despair_v_1_rel" : [ SenseInfo('01810933-v', 3) ],
"_make+up_a_1_rel" : [  ],
"_snowboard_v_1_rel" : [ SenseInfo('02104860-v', 0) ],
"_sling_v_1_rel" : [ SenseInfo('01514348-v', 2), SenseInfo('02105453-v', 0), SenseInfo('02105340-v', 0), SenseInfo('01601547-v', 0), SenseInfo('01514348-v', 2), SenseInfo('02105453-v', 0), SenseInfo('02105340-v', 0), SenseInfo('01601547-v', 0) ],
"_tonal_a_1_rel" : [ SenseInfo('02816663-a', 6), SenseInfo('02437148-a', 1) ],
"_airspeed_n_1_rel" : [ SenseInfo('15283433-n', 2) ],
"_navy_a_1_rel" : [ SenseInfo('08191701-n', 9), SenseInfo('04969703-n', 1), SenseInfo('08191987-n', 0) ],
"_rat_v_out_rel" : [ SenseInfo('02584475-v', 0), SenseInfo('02413140-v', 0), SenseInfo('02412939-v', 0), SenseInfo('01527135-v', 0), SenseInfo('01480641-v', 0), SenseInfo('00841986-v', 0) ],
"_jeez_a_1_rel" : [  ],
"_rage_n_1_rel" : [ SenseInfo('07516997-n', 21), SenseInfo('14036735-n', 4), SenseInfo('14039179-n', 1), SenseInfo('13980128-n', 0), SenseInfo('05751173-n', 0) ],
"_much_a_1_rel" : [ SenseInfo('01553629-a', 137) ],
"_egoboo_n_1_rel" : [  ],
"_blank_v_out_rel" : [ SenseInfo('02451261-v', 0), SenseInfo('02451261-v', 0) ],
"_by+means+of_p_rel" : [  ],
"_enrichment_n_of_rel" : [ SenseInfo('00264366-n', 1), SenseInfo('13271498-n', 0) ],
"_certitude_n_1_rel" : [ SenseInfo('05697789-n', 1) ],
"_eccentric_n_1_rel" : [ SenseInfo('10042845-n', 3), SenseInfo('09909060-n', 0) ],
"_splinter_v_cause_rel" : [ SenseInfo('02535457-v', 1), SenseInfo('02469274-v', 1), SenseInfo('00337903-v', 1) ],
"_smelt_v_1_rel" : [ SenseInfo('01681913-v', 0) ],
"_GmbH_n_1_rel" : [  ],
"_reactionary_a_1_rel" : [ SenseInfo('02030562-a', 3) ],
"_galvanize_v_1_rel" : [ SenseInfo('01821634-v', 0), SenseInfo('01266895-v', 0), SenseInfo('00090513-v', 0) ],
"_constrict_v_1_rel" : [ SenseInfo('01387786-v', 1), SenseInfo('00304422-v', 0), SenseInfo('01387786-v', 1), SenseInfo('00304422-v', 0) ],
"_fume_n_1_rel" : [ SenseInfo('11508092-n', 0) ],
"_eagle_n_1_rel" : [ SenseInfo('01613294-n', 1), SenseInfo('13595968-n', 0), SenseInfo('13392472-n', 0), SenseInfo('06881563-n', 0) ],
"_hydraulic_a_1_rel" : [ SenseInfo('03073888-a', 0), SenseInfo('03073751-a', 0), SenseInfo('03073888-a', 0), SenseInfo('03073751-a', 0) ],
"_divisional_n_1_rel" : [ SenseInfo('03061626-a', 0), SenseInfo('00565115-a', 0), SenseInfo('00517010-a', 0) ],
"_goldenrod_a_1_rel" : [ SenseInfo('12015959-n', 0) ],
"_blasphemous_a_1_rel" : [ SenseInfo('02012748-a', 1), SenseInfo('00425002-a', 0) ],
"_mirror_v_1_rel" : [ SenseInfo('02766925-v', 4), SenseInfo('00821944-v', 0) ],
"_weaken_v_cause_rel" : [ SenseInfo('00224901-v', 6), SenseInfo('00223500-v', 2), SenseInfo('02543607-v', 1), SenseInfo('00290740-v', 1), SenseInfo('00390215-v', 0) ],
"_bushed_a_1_rel" : [ SenseInfo('02432154-a', 0) ],
"_if+not_a_1_rel" : [  ],
"_sympathy_n_1_rel" : [ SenseInfo('06199142-n', 10), SenseInfo('07553301-n', 7), SenseInfo('13811900-n', 4) ],
"_dad_n_1_rel" : [ SenseInfo('09988063-n', 3) ],
"_marvelous_a_1_rel" : [ SenseInfo('01676517-a', 3), SenseInfo('00646117-a', 3), SenseInfo('01576551-a', 0), SenseInfo('01676517-a', 3), SenseInfo('00646117-a', 3), SenseInfo('01576551-a', 0) ],
"_belch_v_1_rel" : [ SenseInfo('00003431-v', 2), SenseInfo('00307568-v', 0) ],
"_crash_v_1_rel" : [ SenseInfo('01972570-v', 9), SenseInfo('02088627-v', 3), SenseInfo('01561819-v', 2), SenseInfo('02019282-v', 1), SenseInfo('01562061-v', 1), SenseInfo('02657080-v', 0), SenseInfo('02177512-v', 0), SenseInfo('02019011-v', 0), SenseInfo('01562209-v', 0), SenseInfo('01507407-v', 0), SenseInfo('00583064-v', 0), SenseInfo('00434919-v', 0), SenseInfo('00017674-v', 0) ],
"_lottery_n_1_rel" : [ SenseInfo('07317144-n', 0), SenseInfo('00508091-n', 0) ],
"_around_p_rel" : [ SenseInfo('00071165-r', 26), SenseInfo('00071601-r', 13), SenseInfo('00072329-r', 12), SenseInfo('00071741-r', 6), SenseInfo('00007015-r', 2), SenseInfo('00072201-r', 1), SenseInfo('00072043-r', 1), SenseInfo('00071840-r', 1), SenseInfo('00071050-r', 1), SenseInfo('00071456-r', 0), SenseInfo('00071165-r', 26), SenseInfo('00071601-r', 13), SenseInfo('00072329-r', 12), SenseInfo('00071741-r', 6), SenseInfo('00007015-r', 2), SenseInfo('00072201-r', 1), SenseInfo('00072043-r', 1), SenseInfo('00071840-r', 1), SenseInfo('00071050-r', 1), SenseInfo('00071456-r', 0) ],
"_around_p_sel_rel" : [ SenseInfo('00071165-r', 26), SenseInfo('00071601-r', 13), SenseInfo('00072329-r', 12), SenseInfo('00071741-r', 6), SenseInfo('00007015-r', 2), SenseInfo('00072201-r', 1), SenseInfo('00072043-r', 1), SenseInfo('00071840-r', 1), SenseInfo('00071050-r', 1), SenseInfo('00071456-r', 0) ],
"_cobalt_n_1_rel" : [ SenseInfo('14635290-n', 0) ],
"_poultice_n_1_rel" : [ SenseInfo('03993403-n', 0) ],
"_almanac_n_1_rel" : [ SenseInfo('06426655-n', 0), SenseInfo('06426279-n', 0) ],
"_victorian_a_1_rel" : [ SenseInfo('03027793-a', 3), SenseInfo('01880163-a', 0), SenseInfo('01537759-a', 0) ],
"_speed_n_1_rel" : [ SenseInfo('15282696-n', 25), SenseInfo('05058140-n', 9), SenseInfo('00330160-n', 4), SenseInfo('13821408-n', 0), SenseInfo('02704153-n', 0) ],
"_advancement_n_1_rel" : [ SenseInfo('07251984-n', 0), SenseInfo('00282050-n', 0), SenseInfo('00249501-n', 0) ],
"_farmyard_n_1_rel" : [ SenseInfo('03323211-n', 0) ],
"_conceivable_a_to_rel" : [ SenseInfo('02418249-a', 2), SenseInfo('02418249-a', 2) ],
"_hook+line+and+sinker_a_1_rel" : [  ],
"_parallelipiped_n_1_rel" : [  ],
"_operation_n_of_rel" : [ SenseInfo('14008806-n', 12), SenseInfo('01095966-n', 11), SenseInfo('00409483-n', 8), SenseInfo('13524925-n', 4), SenseInfo('00955060-n', 4), SenseInfo('00671351-n', 2), SenseInfo('00577068-n', 2), SenseInfo('13525549-n', 0), SenseInfo('05701363-n', 0), SenseInfo('00869583-n', 0), SenseInfo('00409211-n', 0), SenseInfo('14008806-n', 12), SenseInfo('01095966-n', 11), SenseInfo('00409483-n', 8), SenseInfo('13524925-n', 4), SenseInfo('00955060-n', 4), SenseInfo('00671351-n', 2), SenseInfo('00577068-n', 2), SenseInfo('13525549-n', 0), SenseInfo('05701363-n', 0), SenseInfo('00869583-n', 0), SenseInfo('00409211-n', 0), SenseInfo('14008806-n', 12), SenseInfo('01095966-n', 11), SenseInfo('00409483-n', 8), SenseInfo('13524925-n', 4), SenseInfo('00955060-n', 4), SenseInfo('00671351-n', 2), SenseInfo('00577068-n', 2), SenseInfo('13525549-n', 0), SenseInfo('05701363-n', 0), SenseInfo('00869583-n', 0), SenseInfo('00409211-n', 0) ],
"_dreamland_n_1_rel" : [ SenseInfo('05631304-n', 0) ],
"_warmth_n_1_rel" : [ SenseInfo('05725527-n', 4), SenseInfo('07546279-n', 1), SenseInfo('05016753-n', 1), SenseInfo('04628192-n', 0), SenseInfo('04627000-n', 0) ],
"_sizzle_v_1_rel" : [ SenseInfo('00862591-v', 1), SenseInfo('01767818-v', 0), SenseInfo('00377906-v', 0) ],
"_gerbil_n_1_rel" : [ SenseInfo('02343772-n', 0) ],
"_fairly_x_rel" : [ SenseInfo('00035718-r', 20), SenseInfo('00106759-r', 3), SenseInfo('00285092-r', 0) ],
"_persuasive_a_1_rel" : [ SenseInfo('01769843-a', 1) ],
"_dress_v_up_rel" : [ SenseInfo('00046534-v', 15), SenseInfo('00047945-v', 8), SenseInfo('01266269-v', 2), SenseInfo('00044797-v', 2), SenseInfo('00043683-v', 2), SenseInfo('00542809-v', 1), SenseInfo('02036650-v', 0), SenseInfo('01679433-v', 0), SenseInfo('01466543-v', 0), SenseInfo('01364184-v', 0), SenseInfo('01321002-v', 0), SenseInfo('01262813-v', 0), SenseInfo('00511636-v', 0), SenseInfo('00082714-v', 0), SenseInfo('00045639-v', 0), SenseInfo('00038849-v', 0), SenseInfo('00046534-v', 15), SenseInfo('00047945-v', 8), SenseInfo('01266269-v', 2), SenseInfo('00044797-v', 2), SenseInfo('00043683-v', 2), SenseInfo('00542809-v', 1), SenseInfo('02036650-v', 0), SenseInfo('01679433-v', 0), SenseInfo('01466543-v', 0), SenseInfo('01364184-v', 0), SenseInfo('01321002-v', 0), SenseInfo('01262813-v', 0), SenseInfo('00511636-v', 0), SenseInfo('00082714-v', 0), SenseInfo('00045639-v', 0), SenseInfo('00038849-v', 0) ],
"_or+what_a_2_rel" : [  ],
"_intensify_v_cause_rel" : [ SenseInfo('00290302-v', 3), SenseInfo('00227165-v', 2), SenseInfo('00226566-v', 2), SenseInfo('00574735-v', 0) ],
"_much-celebrated_a_1_rel" : [  ],
"_aspirin_n_1_rel" : [ SenseInfo('02748618-n', 1) ],
"_log_n_of_rel" : [ SenseInfo('14942762-n', 7), SenseInfo('06812631-n', 0), SenseInfo('06504155-n', 0), SenseInfo('06503884-n', 0), SenseInfo('03686658-n', 0) ],
"_bury_v_1_rel" : [ SenseInfo('02147466-v', 7), SenseInfo('02456493-v', 6), SenseInfo('01234625-v', 3), SenseInfo('01582409-v', 1), SenseInfo('01530098-v', 1), SenseInfo('00610167-v', 0) ],
"_parley_n_1_rel" : [ SenseInfo('07141437-n', 0) ],
"_pickle_v_1_rel" : [ SenseInfo('00213223-v', 0) ],
"_improve_v_1_rel" : [ SenseInfo('00205885-v', 66), SenseInfo('00205046-v', 12) ],
"_tricky_a_1_rel" : [ SenseInfo('02466734-a', 0), SenseInfo('00746819-a', 0), SenseInfo('00148078-a', 0), SenseInfo('02466734-a', 0), SenseInfo('00746819-a', 0), SenseInfo('00148078-a', 0), SenseInfo('02466734-a', 0), SenseInfo('00746819-a', 0), SenseInfo('00148078-a', 0) ],
"_gully_n_1_rel" : [ SenseInfo('09300306-n', 1) ],
"_axial_a_1_rel" : [ SenseInfo('02654894-a', 1), SenseInfo('02655015-a', 0), SenseInfo('01445063-a', 0), SenseInfo('02654894-a', 1), SenseInfo('02655015-a', 0), SenseInfo('01445063-a', 0) ],
"_convenient_a_for_rel" : [ SenseInfo('00604617-a', 16), SenseInfo('00475996-a', 0), SenseInfo('00604617-a', 16), SenseInfo('00475996-a', 0), SenseInfo('00604617-a', 16), SenseInfo('00475996-a', 0), SenseInfo('00604617-a', 16), SenseInfo('00475996-a', 0) ],
"_cineast_n_1_rel" : [  ],
"_georgian_a_1_rel" : [ SenseInfo('03068198-a', 0), SenseInfo('03067957-a', 0), SenseInfo('03067712-a', 0), SenseInfo('03067506-a', 0) ],
"_mapmaking_n_1_rel" : [ SenseInfo('00924579-n', 0), SenseInfo('00924579-n', 0) ],
"_dawn_v_1_rel" : [ SenseInfo('00591755-v', 1), SenseInfo('02609614-v', 0), SenseInfo('00528836-v', 0) ],
"_common_a_for_rel" : [ SenseInfo('00492677-a', 32), SenseInfo('00485711-a', 14), SenseInfo('02152473-a', 13), SenseInfo('00970610-a', 9), SenseInfo('01046226-a', 2), SenseInfo('01593079-a', 1), SenseInfo('02346557-a', 0), SenseInfo('01950198-a', 0), SenseInfo('01673815-a', 0), SenseInfo('00492677-a', 32), SenseInfo('00485711-a', 14), SenseInfo('02152473-a', 13), SenseInfo('00970610-a', 9), SenseInfo('01046226-a', 2), SenseInfo('01593079-a', 1), SenseInfo('02346557-a', 0), SenseInfo('01950198-a', 0), SenseInfo('01673815-a', 0), SenseInfo('00492677-a', 32), SenseInfo('00485711-a', 14), SenseInfo('02152473-a', 13), SenseInfo('00970610-a', 9), SenseInfo('01046226-a', 2), SenseInfo('01593079-a', 1), SenseInfo('02346557-a', 0), SenseInfo('01950198-a', 0), SenseInfo('01673815-a', 0), SenseInfo('00492677-a', 32), SenseInfo('00485711-a', 14), SenseInfo('02152473-a', 13), SenseInfo('00970610-a', 9), SenseInfo('01046226-a', 2), SenseInfo('01593079-a', 1), SenseInfo('02346557-a', 0), SenseInfo('01950198-a', 0), SenseInfo('01673815-a', 0), SenseInfo('00492677-a', 32), SenseInfo('00485711-a', 14), SenseInfo('02152473-a', 13), SenseInfo('00970610-a', 9), SenseInfo('01046226-a', 2), SenseInfo('01593079-a', 1), SenseInfo('02346557-a', 0), SenseInfo('01950198-a', 0), SenseInfo('01673815-a', 0) ],
"_ostrich_n_1_rel" : [ SenseInfo('10385707-n', 0), SenseInfo('01518878-n', 0) ],
"_hazel_n_1_rel" : [ SenseInfo('13144084-n', 0), SenseInfo('12289115-n', 0), SenseInfo('12288823-n', 0), SenseInfo('04972603-n', 0) ],
"_directory_n_1_rel" : [ SenseInfo('06423619-n', 1), SenseInfo('06490451-n', 0) ],
"_chase_v_down_rel" : [ SenseInfo('02001858-v', 10), SenseInfo('02535093-v', 0), SenseInfo('01583881-v', 0), SenseInfo('01277649-v', 0) ],
"_kindly_a_1_rel" : [ SenseInfo('01372948-a', 1), SenseInfo('00226891-a', 0), SenseInfo('01372948-a', 1), SenseInfo('00226891-a', 0), SenseInfo('01372948-a', 1), SenseInfo('00226891-a', 0) ],
"_contention_n_1_rel" : [ SenseInfo('06731378-n', 5), SenseInfo('07183151-n', 1), SenseInfo('01168569-n', 0), SenseInfo('06731378-n', 5), SenseInfo('07183151-n', 1), SenseInfo('01168569-n', 0) ],
"_indivisible_a_1_rel" : [ SenseInfo('00785684-a', 0) ],
"_optimum_a_1_rel" : [ SenseInfo('00228645-a', 6) ],
"_diffuse_a_1_rel" : [ SenseInfo('00540487-a', 1), SenseInfo('01157887-a', 0), SenseInfo('00549133-a', 0) ],
"_booth_n_1_rel" : [ SenseInfo('02874214-n', 1), SenseInfo('02873839-n', 1), SenseInfo('10857540-n', 0), SenseInfo('02874086-n', 0) ],
"_certainty_n_1_rel" : [ SenseInfo('05697135-n', 3), SenseInfo('04753455-n', 1), SenseInfo('05697135-n', 3), SenseInfo('04753455-n', 1) ],
"_gallon_n_1_rel" : [ SenseInfo('13619764-n', 2), SenseInfo('13622209-n', 0), SenseInfo('13619764-n', 2), SenseInfo('13622209-n', 0), SenseInfo('13619764-n', 2), SenseInfo('13622209-n', 0) ],
"_oscarcompound_n_1_rel" : [  ],
"_shivery_a_1_rel" : [ SenseInfo('01254026-a', 1), SenseInfo('00194924-a', 0) ],
"_sock_n_1_rel" : [ SenseInfo('04254777-n', 3), SenseInfo('07257582-n', 0) ],
"_danish_a_1_rel" : [ SenseInfo('02960338-a', 3) ],
"_stack_v_up_rel" : [ SenseInfo('01503952-v', 2), SenseInfo('01503404-v', 0), SenseInfo('01464781-v', 0), SenseInfo('01503952-v', 2), SenseInfo('01503404-v', 0), SenseInfo('01464781-v', 0) ],
"_protestation_n_1_rel" : [ SenseInfo('07210225-n', 1), SenseInfo('06733119-n', 1) ],
"_cluster_v_1_rel" : [ SenseInfo('02025009-v', 4), SenseInfo('01484392-v', 2) ],
"_tinge_n_1_rel" : [ SenseInfo('13774115-n', 0), SenseInfo('04959567-n', 0) ],
"_cool_a_1_rel" : [ SenseInfo('02529945-a', 25), SenseInfo('00530772-a', 2), SenseInfo('02532200-a', 0), SenseInfo('02531422-a', 0), SenseInfo('01914250-a', 0), SenseInfo('00971660-a', 0), SenseInfo('02529945-a', 25), SenseInfo('00530772-a', 2), SenseInfo('02532200-a', 0), SenseInfo('02531422-a', 0), SenseInfo('01914250-a', 0), SenseInfo('00971660-a', 0), SenseInfo('02529945-a', 25), SenseInfo('00530772-a', 2), SenseInfo('02532200-a', 0), SenseInfo('02531422-a', 0), SenseInfo('01914250-a', 0), SenseInfo('00971660-a', 0), SenseInfo('02529945-a', 25), SenseInfo('00530772-a', 2), SenseInfo('02532200-a', 0), SenseInfo('02531422-a', 0), SenseInfo('01914250-a', 0), SenseInfo('00971660-a', 0), SenseInfo('02529945-a', 25), SenseInfo('00530772-a', 2), SenseInfo('02532200-a', 0), SenseInfo('02531422-a', 0), SenseInfo('01914250-a', 0), SenseInfo('00971660-a', 0), SenseInfo('02529945-a', 25), SenseInfo('00530772-a', 2), SenseInfo('02532200-a', 0), SenseInfo('02531422-a', 0), SenseInfo('01914250-a', 0), SenseInfo('00971660-a', 0), SenseInfo('02529945-a', 25), SenseInfo('00530772-a', 2), SenseInfo('02532200-a', 0), SenseInfo('02531422-a', 0), SenseInfo('01914250-a', 0), SenseInfo('00971660-a', 0) ],
"_wrap_n_1_rel" : [ SenseInfo('04605446-n', 1), SenseInfo('07698782-n', 0), SenseInfo('04605726-n', 0) ],
"_combination_n_1_rel" : [ SenseInfo('07963711-n', 18), SenseInfo('08373723-n', 0), SenseInfo('08373544-n', 0), SenseInfo('08272961-n', 0), SenseInfo('07964495-n', 0), SenseInfo('00870453-n', 0), SenseInfo('00378985-n', 0) ],
"_in+particular_p_1_rel" : [ SenseInfo('00248765-r', 9), SenseInfo('00248765-r', 9), SenseInfo('00248765-r', 9) ],
"_gin_v_up_rel" : [ SenseInfo('01557517-v', 0), SenseInfo('01481027-v', 0) ],
"_pretty+well_a_1_rel" : [  ],
"_packet_n_of_rel" : [ SenseInfo('08008017-n', 7), SenseInfo('07281099-n', 0), SenseInfo('03871628-n', 0), SenseInfo('03710079-n', 0) ],
"_add_v_up-to_rel" : [ SenseInfo('00182406-v', 116), SenseInfo('01027174-v', 68), SenseInfo('02324478-v', 15), SenseInfo('00640828-v', 3), SenseInfo('00949288-v', 1), SenseInfo('02745172-v', 0) ],
"_agreed_a_1_rel" : [ SenseInfo('02476338-a', 0), SenseInfo('02476338-a', 0), SenseInfo('02476338-a', 0) ],
"_harness_v_up_rel" : [ SenseInfo('01491697-v', 2), SenseInfo('01163495-v', 1), SenseInfo('02442737-v', 0), SenseInfo('00234857-v', 0) ],
"_cockpit_n_1_rel" : [ SenseInfo('03061505-n', 2), SenseInfo('03061819-n', 0), SenseInfo('03061674-n', 0) ],
"_slope_v_1_rel" : [ SenseInfo('02037090-v', 0) ],
"_televise_v_1_rel" : [ SenseInfo('00969506-v', 3) ],
"_speedy_a_1_rel" : [ SenseInfo('00979862-a', 2), SenseInfo('00979366-a', 1) ],
"_follow_v_1_rel" : [ SenseInfo('01998432-v', 74), SenseInfo('02712772-v', 50), SenseInfo('02720149-v', 26), SenseInfo('01991931-v', 20), SenseInfo('02542280-v', 18), SenseInfo('02720354-v', 17), SenseInfo('00150776-v', 13), SenseInfo('02720544-v', 12), SenseInfo('02346895-v', 9), SenseInfo('02720697-v', 8), SenseInfo('01744450-v', 8), SenseInfo('00729109-v', 4), SenseInfo('02455407-v', 3), SenseInfo('02406585-v', 2), SenseInfo('01728355-v', 1), SenseInfo('00118764-v', 1), SenseInfo('02625339-v', 0), SenseInfo('02600255-v', 0), SenseInfo('02561697-v', 0), SenseInfo('02445925-v', 0), SenseInfo('02198602-v', 0), SenseInfo('02000868-v', 0), SenseInfo('00589738-v', 0), SenseInfo('00351406-v', 0), SenseInfo('01998432-v', 74), SenseInfo('02712772-v', 50), SenseInfo('02720149-v', 26), SenseInfo('01991931-v', 20), SenseInfo('02542280-v', 18), SenseInfo('02720354-v', 17), SenseInfo('00150776-v', 13), SenseInfo('02720544-v', 12), SenseInfo('02346895-v', 9), SenseInfo('02720697-v', 8), SenseInfo('01744450-v', 8), SenseInfo('00729109-v', 4), SenseInfo('02455407-v', 3), SenseInfo('02406585-v', 2), SenseInfo('01728355-v', 1), SenseInfo('00118764-v', 1), SenseInfo('02625339-v', 0), SenseInfo('02600255-v', 0), SenseInfo('02561697-v', 0), SenseInfo('02445925-v', 0), SenseInfo('02198602-v', 0), SenseInfo('02000868-v', 0), SenseInfo('00589738-v', 0), SenseInfo('00351406-v', 0), SenseInfo('01998432-v', 74), SenseInfo('02712772-v', 50), SenseInfo('02720149-v', 26), SenseInfo('01991931-v', 20), SenseInfo('02542280-v', 18), SenseInfo('02720354-v', 17), SenseInfo('00150776-v', 13), SenseInfo('02720544-v', 12), SenseInfo('02346895-v', 9), SenseInfo('02720697-v', 8), SenseInfo('01744450-v', 8), SenseInfo('00729109-v', 4), SenseInfo('02455407-v', 3), SenseInfo('02406585-v', 2), SenseInfo('01728355-v', 1), SenseInfo('00118764-v', 1), SenseInfo('02625339-v', 0), SenseInfo('02600255-v', 0), SenseInfo('02561697-v', 0), SenseInfo('02445925-v', 0), SenseInfo('02198602-v', 0), SenseInfo('02000868-v', 0), SenseInfo('00589738-v', 0), SenseInfo('00351406-v', 0), SenseInfo('01998432-v', 74), SenseInfo('02712772-v', 50), SenseInfo('02720149-v', 26), SenseInfo('01991931-v', 20), SenseInfo('02542280-v', 18), SenseInfo('02720354-v', 17), SenseInfo('00150776-v', 13), SenseInfo('02720544-v', 12), SenseInfo('02346895-v', 9), SenseInfo('02720697-v', 8), SenseInfo('01744450-v', 8), SenseInfo('00729109-v', 4), SenseInfo('02455407-v', 3), SenseInfo('02406585-v', 2), SenseInfo('01728355-v', 1), SenseInfo('00118764-v', 1), SenseInfo('02625339-v', 0), SenseInfo('02600255-v', 0), SenseInfo('02561697-v', 0), SenseInfo('02445925-v', 0), SenseInfo('02198602-v', 0), SenseInfo('02000868-v', 0), SenseInfo('00589738-v', 0), SenseInfo('00351406-v', 0) ],
"_oath_n_of_rel" : [ SenseInfo('07125096-n', 15), SenseInfo('06684572-n', 2), SenseInfo('07226841-n', 0) ],
"_pry_v_into_rel" : [ SenseInfo('01593254-v', 3), SenseInfo('00784874-v', 2), SenseInfo('02169119-v', 1), SenseInfo('01630903-v', 0), SenseInfo('01593254-v', 3), SenseInfo('00784874-v', 2), SenseInfo('02169119-v', 1), SenseInfo('01630903-v', 0) ],
"_conclusive_a_1_rel" : [ SenseInfo('00550282-a', 3) ],
"_crimp_v_cause_rel" : [ SenseInfo('01457206-v', 0), SenseInfo('01223833-v', 0) ],
"_sand_v_1_rel" : [ SenseInfo('01386433-v', 2) ],
"_politician_n_1_rel" : [ SenseInfo('10451263-n', 9), SenseInfo('10450303-n', 4), SenseInfo('10451450-n', 0) ],
"_ripen_v_cause_rel" : [ SenseInfo('00249969-v', 1), SenseInfo('00249852-v', 1) ],
"_failing_n_1_rel" : [ SenseInfo('14462946-n', 0), SenseInfo('00066901-n', 0) ],
"_drag_v_1_rel" : [ SenseInfo('01453433-v', 16), SenseInfo('01454810-v', 13), SenseInfo('02677797-v', 1), SenseInfo('02099544-v', 1), SenseInfo('02058756-v', 1), SenseInfo('01199009-v', 1), SenseInfo('02101789-v', 0), SenseInfo('01917845-v', 0), SenseInfo('01244692-v', 0), SenseInfo('00783689-v', 0), SenseInfo('00341757-v', 0) ],
"_yet_x_deg_rel" : [ SenseInfo('00027795-r', 22), SenseInfo('00027918-r', 15), SenseInfo('00017639-r', 6), SenseInfo('00047641-r', 0), SenseInfo('00028198-r', 0), SenseInfo('00027384-r', 0), SenseInfo('00027795-r', 22), SenseInfo('00027918-r', 15), SenseInfo('00017639-r', 6), SenseInfo('00047641-r', 0), SenseInfo('00028198-r', 0), SenseInfo('00027384-r', 0) ],
"_a+whole+lot_x_rel" : [  ],
"_every+bit_x_deg_rel" : [ SenseInfo('00022131-r', 1) ],
"_kin_n_1_rel" : [ SenseInfo('10236304-n', 0), SenseInfo('07969695-n', 0), SenseInfo('10236304-n', 0), SenseInfo('07969695-n', 0), SenseInfo('10236304-n', 0), SenseInfo('07969695-n', 0) ],
"_updraft_n_1_rel" : [ SenseInfo('11522649-n', 0) ],
"_unavailable_a_1_rel" : [ SenseInfo('00185921-a', 4), SenseInfo('00185921-a', 4) ],
"_cue_n_1_rel" : [ SenseInfo('07011209-n', 0), SenseInfo('06643763-n', 0), SenseInfo('05829213-n', 0), SenseInfo('03145522-n', 0), SenseInfo('07011209-n', 0), SenseInfo('06643763-n', 0), SenseInfo('05829213-n', 0), SenseInfo('03145522-n', 0) ],
"_bad_a_at_rel" : [ SenseInfo('01125429-a', 51), SenseInfo('01510444-a', 3), SenseInfo('00478311-a', 3), SenseInfo('01069283-a', 1), SenseInfo('01150475-a', 0), SenseInfo('02500050-a', 0), SenseInfo('02345713-a', 0), SenseInfo('02298642-a', 0), SenseInfo('02274537-a', 0), SenseInfo('01174222-a', 0), SenseInfo('01160775-a', 0), SenseInfo('01131803-a', 0), SenseInfo('01117226-a', 0), SenseInfo('01092572-a', 0) ],
"_abate_v_cause_rel" : [ SenseInfo('00245289-v', 0), SenseInfo('00245059-v', 0) ],
"_ache_v_for_rel" : [ SenseInfo('02121511-v', 3), SenseInfo('01805684-v', 3), SenseInfo('02122164-v', 2) ],
"_mammogram_n_1_rel" : [ SenseInfo('03716228-n', 0) ],
"_thirdly_a_1_rel" : [  ],
"_worm_v_1_rel" : [ SenseInfo('01868370-v', 0) ],
"_hardy_n_1_rel" : [ SenseInfo('11028780-n', 0), SenseInfo('11028675-n', 0) ],
"_both_a_1_rel" : [ SenseInfo('02268133-a', 4), SenseInfo('02268133-a', 4) ],
"_toner_n_1_rel" : [ SenseInfo('15076011-n', 0), SenseInfo('15075867-n', 0), SenseInfo('04450640-n', 0) ],
"_declare_v_to_rel" : [ SenseInfo('01010118-v', 33), SenseInfo('00965871-v', 13), SenseInfo('00820801-v', 11), SenseInfo('00822367-v', 9), SenseInfo('02444555-v', 1), SenseInfo('02300549-v', 0), SenseInfo('01010852-v', 0), SenseInfo('00977689-v', 0), SenseInfo('01010118-v', 33), SenseInfo('00965871-v', 13), SenseInfo('00820801-v', 11), SenseInfo('00822367-v', 9), SenseInfo('02444555-v', 1), SenseInfo('02300549-v', 0), SenseInfo('01010852-v', 0), SenseInfo('00977689-v', 0), SenseInfo('01010118-v', 33), SenseInfo('00965871-v', 13), SenseInfo('00820801-v', 11), SenseInfo('00822367-v', 9), SenseInfo('02444555-v', 1), SenseInfo('02300549-v', 0), SenseInfo('01010852-v', 0), SenseInfo('00977689-v', 0), SenseInfo('01010118-v', 33), SenseInfo('00965871-v', 13), SenseInfo('00820801-v', 11), SenseInfo('00822367-v', 9), SenseInfo('02444555-v', 1), SenseInfo('02300549-v', 0), SenseInfo('01010852-v', 0), SenseInfo('00977689-v', 0), SenseInfo('01010118-v', 33), SenseInfo('00965871-v', 13), SenseInfo('00820801-v', 11), SenseInfo('00822367-v', 9), SenseInfo('02444555-v', 1), SenseInfo('02300549-v', 0), SenseInfo('01010852-v', 0), SenseInfo('00977689-v', 0) ],
"_stencil_n_1_rel" : [ SenseInfo('04314216-n', 0) ],
"_boottree_n_1_rel" : [  ],
"_knuckle_n_1_rel" : [ SenseInfo('05585205-n', 3) ],
"_glucose_n_1_rel" : [ SenseInfo('14884120-n', 0) ],
"_backseat_a_1_rel" : [ SenseInfo('13951629-n', 0), SenseInfo('02770830-n', 0) ],
"_lilac_n_1_rel" : [ SenseInfo('12310349-n', 3) ],
"_smash_v_up_rel" : [ SenseInfo('01401772-v', 6), SenseInfo('00335923-v', 5), SenseInfo('02318165-v', 0), SenseInfo('02104373-v', 0), SenseInfo('01800195-v', 0), SenseInfo('01566705-v', 0), SenseInfo('01561583-v', 0), SenseInfo('01561408-v', 0), SenseInfo('01083576-v', 0), SenseInfo('00334649-v', 0), SenseInfo('01401772-v', 6), SenseInfo('00335923-v', 5), SenseInfo('02318165-v', 0), SenseInfo('02104373-v', 0), SenseInfo('01800195-v', 0), SenseInfo('01566705-v', 0), SenseInfo('01561583-v', 0), SenseInfo('01561408-v', 0), SenseInfo('01083576-v', 0), SenseInfo('00334649-v', 0) ],
"_freeze_v_up_rel" : [ SenseInfo('01834730-v', 5), SenseInfo('00374135-v', 5), SenseInfo('00078138-v', 3), SenseInfo('00375865-v', 1), SenseInfo('00363493-v', 1), SenseInfo('02758826-v', 0), SenseInfo('00445711-v', 0), SenseInfo('00269423-v', 0), SenseInfo('00021997-v', 0), SenseInfo('00012613-v', 0) ],
"_querulous_a_1_rel" : [ SenseInfo('00513981-a', 2) ],
"_a+la_p_rel" : [ SenseInfo('05309965-n', 0), SenseInfo('02151940-n', 0), SenseInfo('05309965-n', 0), SenseInfo('02151940-n', 0) ],
"_rapid_a_1_rel" : [ SenseInfo('00979697-a', 21), SenseInfo('00979862-a', 0), SenseInfo('00979697-a', 21), SenseInfo('00979862-a', 0) ],
"_blur_n_1_rel" : [ SenseInfo('05940414-n', 4) ],
"_suntan_n_1_rel" : [ SenseInfo('14290534-n', 0) ],
"_sack_v_1_rel" : [ SenseInfo('02345048-v', 1), SenseInfo('02402825-v', 0), SenseInfo('02291258-v', 0), SenseInfo('01486151-v', 0) ],
"_sign_n_of_rel" : [ SenseInfo('06646243-n', 18), SenseInfo('06793231-n', 5), SenseInfo('06791372-n', 4), SenseInfo('04217882-n', 3), SenseInfo('08685677-n', 2), SenseInfo('14301785-n', 1), SenseInfo('13856574-n', 1), SenseInfo('07286014-n', 1), SenseInfo('06876144-n', 1), SenseInfo('07276018-n', 0), SenseInfo('06811625-n', 0), SenseInfo('06646243-n', 18), SenseInfo('06793231-n', 5), SenseInfo('06791372-n', 4), SenseInfo('04217882-n', 3), SenseInfo('08685677-n', 2), SenseInfo('14301785-n', 1), SenseInfo('13856574-n', 1), SenseInfo('07286014-n', 1), SenseInfo('06876144-n', 1), SenseInfo('07276018-n', 0), SenseInfo('06811625-n', 0) ],
"_petrol_n_1_rel" : [ SenseInfo('14686913-n', 0) ],
"_horizon_n_1_rel" : [ SenseInfo('08585657-n', 9), SenseInfo('05127782-n', 7), SenseInfo('08658118-n', 0), SenseInfo('08585846-n', 0) ],
"_intensified_a_1_rel" : [ SenseInfo('01512142-a', 0) ],
"_estimation_n_of_rel" : [ SenseInfo('06528783-n', 0), SenseInfo('06207029-n', 0), SenseInfo('05803379-n', 0), SenseInfo('00875246-n', 0), SenseInfo('06528783-n', 0), SenseInfo('06207029-n', 0), SenseInfo('05803379-n', 0), SenseInfo('00875246-n', 0) ],
"_separation_n_of_rel" : [ SenseInfo('14414294-n', 3), SenseInfo('07331400-n', 3), SenseInfo('05089947-n', 1), SenseInfo('01254253-n', 1), SenseInfo('01201021-n', 1), SenseInfo('08647121-n', 0), SenseInfo('07295391-n', 0), SenseInfo('01201429-n', 0), SenseInfo('00383606-n', 0) ],
"_tick_v_off_rel" : [ SenseInfo('02185664-v', 2), SenseInfo('02175578-v', 1), SenseInfo('01331689-v', 0), SenseInfo('00662182-v', 0) ],
"_unsafe_a_1_rel" : [ SenseInfo('02094755-a', 0), SenseInfo('02058794-a', 0), SenseInfo('02524443-a', 0), SenseInfo('02094755-a', 0), SenseInfo('02058794-a', 0), SenseInfo('02524443-a', 0) ],
"_contiguity_n_1_rel" : [ SenseInfo('05085991-n', 0) ],
"_comedy_n_1_rel" : [ SenseInfo('07015510-n', 18), SenseInfo('06781383-n', 2) ],
"_volcanic_a_1_rel" : [ SenseInfo('02826169-a', 0), SenseInfo('02293760-a', 0), SenseInfo('01355746-a', 0) ],
"_suspect_a_1_rel" : [ SenseInfo('01917594-a', 2) ],
"_jot_v_down_rel" : [ SenseInfo('01006056-v', 0) ],
"_official_n_1_rel" : [ SenseInfo('10372373-n', 23), SenseInfo('10372076-n', 3) ],
"_come_v_of_rel" : [ SenseInfo('01849221-v', 276), SenseInfo('02005948-v', 235), SenseInfo('00341917-v', 147), SenseInfo('00542120-v', 41), SenseInfo('02625339-v', 40), SenseInfo('00342812-v', 11), SenseInfo('02743921-v', 9), SenseInfo('02743214-v', 7), SenseInfo('02686805-v', 6), SenseInfo('02743565-v', 3), SenseInfo('01839690-v', 3), SenseInfo('02729963-v', 2), SenseInfo('00344886-v', 2), SenseInfo('02645007-v', 1), SenseInfo('02627363-v', 1), SenseInfo('02006709-v', 1), SenseInfo('00723349-v', 1), SenseInfo('02737187-v', 0), SenseInfo('02617567-v', 0), SenseInfo('02197360-v', 0), SenseInfo('00659984-v', 0) ],
"_admin_n_1_rel" : [  ],
"_fraudulent_a_1_rel" : [ SenseInfo('01223941-a', 0) ],
"_digraph_n_1_rel" : [ SenseInfo('06830838-n', 0) ],
"_cattle_n_1_rel" : [ SenseInfo('02402425-n', 25) ],
"_hang_v_cause_rel" : [ SenseInfo('01482075-v', 35), SenseInfo('01481360-v', 12), SenseInfo('02485451-v', 11), SenseInfo('01977962-v', 6), SenseInfo('01542668-v', 5), SenseInfo('02734952-v', 2), SenseInfo('02170427-v', 1), SenseInfo('01481957-v', 1), SenseInfo('01216331-v', 1), SenseInfo('02741003-v', 0), SenseInfo('02557790-v', 0), SenseInfo('01677716-v', 0), SenseInfo('01481819-v', 0), SenseInfo('01481647-v', 0), SenseInfo('00210110-v', 0) ],
"_liberty_n_1_rel" : [ SenseInfo('13992514-n', 7), SenseInfo('13994456-n', 2), SenseInfo('13996061-n', 1), SenseInfo('15140080-n', 0), SenseInfo('00737070-n', 0) ],
"_efficient_a_1_rel" : [ SenseInfo('00839619-a', 7), SenseInfo('00510644-a', 3), SenseInfo('00839619-a', 7), SenseInfo('00510644-a', 3) ],
"_surcharge_n_of_rel" : [ SenseInfo('13325505-n', 0) ],
"_not+necessarily_a_1_rel" : [  ],
"_anime_n_1_rel" : [ SenseInfo('14896018-n', 0), SenseInfo('14766265-n', 0) ],
"_engineer_v_1_rel" : [ SenseInfo('00711550-v', 0), SenseInfo('00710005-v', 0) ],
"_complex_v_1_rel" : [  ],
"_equal_v_1_rel" : [ SenseInfo('02664769-v', 13), SenseInfo('02672187-v', 1), SenseInfo('00417001-v', 0) ],
"_tender_n_1_rel" : [ SenseInfo('13374008-n', 0), SenseInfo('09821831-n', 0), SenseInfo('07165086-n', 0), SenseInfo('04409279-n', 0), SenseInfo('04409128-n', 0), SenseInfo('04409011-n', 0) ],
"_rent_v_out_rel" : [ SenseInfo('02460199-v', 6), SenseInfo('02208903-v', 2), SenseInfo('02208537-v', 1), SenseInfo('02460619-v', 0), SenseInfo('02460199-v', 6), SenseInfo('02208903-v', 2), SenseInfo('02208537-v', 1), SenseInfo('02460619-v', 0) ],
"_prank_n_1_rel" : [ SenseInfo('00513401-n', 1), SenseInfo('00427580-n', 0) ],
"_parallel_n_1_rel" : [ SenseInfo('04746430-n', 5), SenseInfo('08595720-n', 1), SenseInfo('13880994-n', 0) ],
"_bacteria_n_1_rel" : [ SenseInfo('01348530-n', 3) ],
"_greenish_a_1_rel" : [ SenseInfo('00375969-a', 0) ],
"_devastating_a_1_rel" : [ SenseInfo('01995047-a', 1), SenseInfo('00586617-a', 1), SenseInfo('00587697-a', 0) ],
"_earthquake_n_1_rel" : [ SenseInfo('07428954-n', 17), SenseInfo('13977870-n', 0) ],
"_completely_x_deg_rel" : [ SenseInfo('00008007-r', 37), SenseInfo('00157624-r', 10) ],
"_municipal_a_1_rel" : [ SenseInfo('02697452-a', 11), SenseInfo('01038580-a', 0) ],
"_marry_v_off_rel" : [ SenseInfo('02488834-v', 44), SenseInfo('02489456-v', 2) ],
"_banishment_n_1_rel" : [ SenseInfo('14427633-n', 0), SenseInfo('00206302-n', 0) ],
"_ichthyosis_n_1_rel" : [ SenseInfo('14158997-n', 0) ],
"_bob_n_1_rel" : [ SenseInfo('13686877-n', 0), SenseInfo('05259109-n', 0), SenseInfo('02860847-n', 0), SenseInfo('02860239-n', 0), SenseInfo('02860063-n', 0), SenseInfo('02158066-n', 0), SenseInfo('00336274-n', 0) ],
"_lace_n_1_rel" : [ SenseInfo('03631445-n', 0), SenseInfo('03631177-n', 0) ],
"_leave_v_open_rel" : [ SenseInfo('02009433-v', 146), SenseInfo('00613683-v', 63), SenseInfo('02729414-v', 56), SenseInfo('00136991-v', 27), SenseInfo('02015598-v', 20), SenseInfo('02721438-v', 19), SenseInfo('02635659-v', 16), SenseInfo('02383440-v', 14), SenseInfo('02356230-v', 8), SenseInfo('02229055-v', 7), SenseInfo('02730135-v', 5), SenseInfo('00360092-v', 5), SenseInfo('02296153-v', 3), SenseInfo('00613018-v', 3) ],
"_spur_v_on_rel" : [ SenseInfo('02554647-v', 2), SenseInfo('01818835-v', 2), SenseInfo('01241490-v', 1), SenseInfo('01241253-v', 1), SenseInfo('01241379-v', 0), SenseInfo('02554647-v', 2), SenseInfo('01818835-v', 2), SenseInfo('01241490-v', 1), SenseInfo('01241253-v', 1), SenseInfo('01241379-v', 0) ],
"_number_n_grm_rel" : [ SenseInfo('05121418-n', 131), SenseInfo('13582013-n', 63), SenseInfo('06892016-n', 5), SenseInfo('06426111-n', 5), SenseInfo('06807198-n', 2), SenseInfo('06596978-n', 2), SenseInfo('08480512-n', 1), SenseInfo('06425065-n', 1), SenseInfo('05096294-n', 1), SenseInfo('06326526-n', 0), SenseInfo('03835412-n', 0) ],
"_seed_v_1_rel" : [ SenseInfo('01542056-v', 1), SenseInfo('02217546-v', 0), SenseInfo('01652429-v', 0), SenseInfo('01500873-v', 0), SenseInfo('00658913-v', 0), SenseInfo('00516425-v', 0), SenseInfo('00188375-v', 0), SenseInfo('00179718-v', 0) ],
"_linen_n_1_rel" : [ SenseInfo('03672521-n', 2), SenseInfo('14934998-n', 1), SenseInfo('03672352-n', 0) ],
"_bow_v_down_rel" : [ SenseInfo('00898691-v', 11), SenseInfo('00878348-v', 3), SenseInfo('02040273-v', 1), SenseInfo('02062632-v', 0), SenseInfo('01729295-v', 0), SenseInfo('00898691-v', 11), SenseInfo('00878348-v', 3), SenseInfo('02040273-v', 1), SenseInfo('02062632-v', 0), SenseInfo('01729295-v', 0), SenseInfo('00898691-v', 11), SenseInfo('00878348-v', 3), SenseInfo('02040273-v', 1), SenseInfo('02062632-v', 0), SenseInfo('01729295-v', 0) ],
"_inconceivable_a_to_rel" : [ SenseInfo('02418692-a', 1), SenseInfo('02418692-a', 1) ],
"_insurers_a_1_rel" : [  ],
"_sink_v_in_rel" : [ SenseInfo('01985923-v', 8), SenseInfo('01986869-v', 5), SenseInfo('01972131-v', 4), SenseInfo('01989873-v', 3), SenseInfo('01971929-v', 3), SenseInfo('02039679-v', 2), SenseInfo('00432839-v', 2), SenseInfo('01988886-v', 1), SenseInfo('01530098-v', 1) ],
"_sabotage_v_1_rel" : [ SenseInfo('02543607-v', 0) ],
"_brad_n_1_rel" : [ SenseInfo('02888817-n', 1) ],
"_cognizant_a_of_rel" : [ SenseInfo('00190115-a', 0), SenseInfo('00190115-a', 0) ],
"_outsider_n_1_rel" : [ SenseInfo('10103921-n', 2), SenseInfo('10388192-n', 0) ],
"_fold_n_1_rel" : [ SenseInfo('13907415-n', 3), SenseInfo('07991364-n', 1), SenseInfo('13482940-n', 0), SenseInfo('07991169-n', 0), SenseInfo('05492259-n', 0), SenseInfo('03376159-n', 0), SenseInfo('00406612-n', 0), SenseInfo('13907415-n', 3), SenseInfo('07991364-n', 1), SenseInfo('13482940-n', 0), SenseInfo('07991169-n', 0), SenseInfo('05492259-n', 0), SenseInfo('03376159-n', 0), SenseInfo('00406612-n', 0) ],
"_purplish_a_1_rel" : [ SenseInfo('00380312-a', 0) ],
"_vote_v_1_rel" : [ SenseInfo('02461314-v', 30), SenseInfo('02462580-v', 10), SenseInfo('02462386-v', 1), SenseInfo('02473890-v', 0), SenseInfo('02462201-v', 0), SenseInfo('02461314-v', 30), SenseInfo('02462580-v', 10), SenseInfo('02462386-v', 1), SenseInfo('02473890-v', 0), SenseInfo('02462201-v', 0), SenseInfo('02461314-v', 30), SenseInfo('02462580-v', 10), SenseInfo('02462386-v', 1), SenseInfo('02473890-v', 0), SenseInfo('02462201-v', 0), SenseInfo('02461314-v', 30), SenseInfo('02462580-v', 10), SenseInfo('02462386-v', 1), SenseInfo('02473890-v', 0), SenseInfo('02462201-v', 0), SenseInfo('02461314-v', 30), SenseInfo('02462580-v', 10), SenseInfo('02462386-v', 1), SenseInfo('02473890-v', 0), SenseInfo('02462201-v', 0) ],
"_eclectic_a_1_rel" : [ SenseInfo('00775486-a', 2) ],
"_asbestos_n_1_rel" : [ SenseInfo('14725591-n', 0) ],
"_enmesh_v_1_rel" : [ SenseInfo('01463340-v', 2) ],
"_soft_a_1_rel" : [ SenseInfo('01152746-a', 18), SenseInfo('01156112-a', 13), SenseInfo('01454636-a', 4), SenseInfo('02448324-a', 2), SenseInfo('02286083-a', 0), SenseInfo('01459295-a', 0), SenseInfo('01458303-a', 0), SenseInfo('01157887-a', 0), SenseInfo('01156925-a', 0), SenseInfo('02487540-a', 0), SenseInfo('01914767-a', 0), SenseInfo('01763159-a', 0), SenseInfo('01509066-a', 0), SenseInfo('01192035-a', 0), SenseInfo('01019713-a', 0), SenseInfo('00760473-a', 0), SenseInfo('00750054-a', 0), SenseInfo('00438332-a', 0), SenseInfo('00284400-a', 0), SenseInfo('01152746-a', 18), SenseInfo('01156112-a', 13), SenseInfo('01454636-a', 4), SenseInfo('02448324-a', 2), SenseInfo('02286083-a', 0), SenseInfo('01459295-a', 0), SenseInfo('01458303-a', 0), SenseInfo('01157887-a', 0), SenseInfo('01156925-a', 0), SenseInfo('02487540-a', 0), SenseInfo('01914767-a', 0), SenseInfo('01763159-a', 0), SenseInfo('01509066-a', 0), SenseInfo('01192035-a', 0), SenseInfo('01019713-a', 0), SenseInfo('00760473-a', 0), SenseInfo('00750054-a', 0), SenseInfo('00438332-a', 0), SenseInfo('00284400-a', 0), SenseInfo('01152746-a', 18), SenseInfo('01156112-a', 13), SenseInfo('01454636-a', 4), SenseInfo('02448324-a', 2), SenseInfo('02286083-a', 0), SenseInfo('01459295-a', 0), SenseInfo('01458303-a', 0), SenseInfo('01157887-a', 0), SenseInfo('01156925-a', 0), SenseInfo('02487540-a', 0), SenseInfo('01914767-a', 0), SenseInfo('01763159-a', 0), SenseInfo('01509066-a', 0), SenseInfo('01192035-a', 0), SenseInfo('01019713-a', 0), SenseInfo('00760473-a', 0), SenseInfo('00750054-a', 0), SenseInfo('00438332-a', 0), SenseInfo('00284400-a', 0), SenseInfo('01152746-a', 18), SenseInfo('01156112-a', 13), SenseInfo('01454636-a', 4), SenseInfo('02448324-a', 2), SenseInfo('02286083-a', 0), SenseInfo('01459295-a', 0), SenseInfo('01458303-a', 0), SenseInfo('01157887-a', 0), SenseInfo('01156925-a', 0), SenseInfo('02487540-a', 0), SenseInfo('01914767-a', 0), SenseInfo('01763159-a', 0), SenseInfo('01509066-a', 0), SenseInfo('01192035-a', 0), SenseInfo('01019713-a', 0), SenseInfo('00760473-a', 0), SenseInfo('00750054-a', 0), SenseInfo('00438332-a', 0), SenseInfo('00284400-a', 0) ],
"_drive_v_up_rel" : [ SenseInfo('01930874-v', 56), SenseInfo('01930117-v', 24), SenseInfo('02056971-v', 13), SenseInfo('01516534-v', 13), SenseInfo('02505358-v', 6), SenseInfo('01506157-v', 5), SenseInfo('01646300-v', 4), SenseInfo('01512259-v', 2), SenseInfo('01509584-v', 2), SenseInfo('02406916-v', 1), SenseInfo('01026975-v', 1), SenseInfo('02742232-v', 0), SenseInfo('02408281-v', 0), SenseInfo('02057656-v', 0), SenseInfo('01939553-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01407904-v', 0), SenseInfo('01407722-v', 0), SenseInfo('01310964-v', 0), SenseInfo('01181741-v', 0), SenseInfo('01142636-v', 0), SenseInfo('01142490-v', 0), SenseInfo('01930874-v', 56), SenseInfo('01930117-v', 24), SenseInfo('02056971-v', 13), SenseInfo('01516534-v', 13), SenseInfo('02505358-v', 6), SenseInfo('01506157-v', 5), SenseInfo('01646300-v', 4), SenseInfo('01512259-v', 2), SenseInfo('01509584-v', 2), SenseInfo('02406916-v', 1), SenseInfo('01026975-v', 1), SenseInfo('02742232-v', 0), SenseInfo('02408281-v', 0), SenseInfo('02057656-v', 0), SenseInfo('01939553-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01407904-v', 0), SenseInfo('01407722-v', 0), SenseInfo('01310964-v', 0), SenseInfo('01181741-v', 0), SenseInfo('01142636-v', 0), SenseInfo('01142490-v', 0) ],
"_consume_v_1_rel" : [ SenseInfo('01197014-v', 3), SenseInfo('01156834-v', 3), SenseInfo('01158181-v', 2), SenseInfo('01565921-v', 1), SenseInfo('01157517-v', 0), SenseInfo('00600903-v', 0), SenseInfo('01197014-v', 3), SenseInfo('01156834-v', 3), SenseInfo('01158181-v', 2), SenseInfo('01565921-v', 1), SenseInfo('01157517-v', 0), SenseInfo('00600903-v', 0), SenseInfo('01197014-v', 3), SenseInfo('01156834-v', 3), SenseInfo('01158181-v', 2), SenseInfo('01565921-v', 1), SenseInfo('01157517-v', 0), SenseInfo('00600903-v', 0) ],
"_boom_n_1_rel" : [ SenseInfo('07377682-n', 2), SenseInfo('14488813-n', 0), SenseInfo('07477587-n', 0), SenseInfo('02871824-n', 0), SenseInfo('02871631-n', 0) ],
"_swelter_v_1_rel" : [ SenseInfo('00078316-v', 0), SenseInfo('00069747-v', 0) ],
"_loam_n_1_rel" : [ SenseInfo('14942223-n', 0) ],
"_run_v_across_rel" : [ SenseInfo('01926311-v', 106), SenseInfo('02075049-v', 38), SenseInfo('02685951-v', 21), SenseInfo('02443849-v', 20), SenseInfo('02721284-v', 10), SenseInfo('02066939-v', 9), SenseInfo('01525666-v', 8), SenseInfo('02727039-v', 7), SenseInfo('01094086-v', 7), SenseInfo('01717169-v', 5), SenseInfo('02099829-v', 4), SenseInfo('02719399-v', 3), SenseInfo('01526290-v', 3), SenseInfo('00549063-v', 3), SenseInfo('00517529-v', 3), SenseInfo('02720904-v', 2), SenseInfo('02647497-v', 2), SenseInfo('02612234-v', 2), SenseInfo('02563327-v', 2), SenseInfo('01746359-v', 2), SenseInfo('01641545-v', 2), SenseInfo('01212230-v', 2), SenseInfo('02686625-v', 1), SenseInfo('02525312-v', 1), SenseInfo('02242256-v', 1), SenseInfo('02092309-v', 1), SenseInfo('02060792-v', 1), SenseInfo('01927903-v', 1), SenseInfo('01914947-v', 1), SenseInfo('02648110-v', 0), SenseInfo('02421921-v', 0), SenseInfo('01927747-v', 0), SenseInfo('01927447-v', 0), SenseInfo('01926984-v', 0), SenseInfo('01864038-v', 0), SenseInfo('01143838-v', 0), SenseInfo('01086103-v', 0), SenseInfo('00539110-v', 0), SenseInfo('00444629-v', 0), SenseInfo('00334803-v', 0), SenseInfo('00332672-v', 0) ],
"_augmentation_n_of_rel" : [ SenseInfo('07369470-n', 0), SenseInfo('07030376-n', 0), SenseInfo('00365231-n', 0) ],
"_implausibility_n_1_rel" : [ SenseInfo('04784322-n', 0) ],
"_participle_n_1_rel" : [ SenseInfo('06330528-n', 0) ],
"_lading_n_1_rel" : [ SenseInfo('02964389-n', 0) ],
"_pavilion_n_1_rel" : [ SenseInfo('03900979-n', 0), SenseInfo('03900979-n', 0) ],
"_difference_n_1_rel" : [ SenseInfo('04748836-n', 73), SenseInfo('07366289-n', 16), SenseInfo('07181935-n', 2), SenseInfo('13859307-n', 1), SenseInfo('13729236-n', 0) ],
"_bait_n_1_rel" : [ SenseInfo('05695232-n', 1), SenseInfo('02776205-n', 0) ],
"_arrears_n_1_rel" : [ SenseInfo('14490685-n', 0), SenseInfo('13397443-n', 0), SenseInfo('14490685-n', 0), SenseInfo('13397443-n', 0) ],
"_dam_v_1_rel" : [ SenseInfo('01477224-v', 1) ],
"_velocity_n_1_rel" : [ SenseInfo('15282696-n', 21) ],
"_aboveground_a_1_rel" : [ SenseInfo('02471264-a', 1) ],
"_employ_v_1_rel" : [ SenseInfo('01158872-v', 42), SenseInfo('02409412-v', 14) ],
"_infrared_n_1_rel" : [ SenseInfo('05056811-n', 1), SenseInfo('11469481-n', 0) ],
"_unwind_v_1_rel" : [ SenseInfo('01523654-v', 1), SenseInfo('01523823-v', 0), SenseInfo('00026385-v', 0), SenseInfo('00025654-v', 0) ],
"_inflect_v_1_rel" : [ SenseInfo('00982514-v', 1), SenseInfo('00982293-v', 0) ],
"_lack_n_1_rel" : [ SenseInfo('14449405-n', 42) ],
"_perceptive_a_1_rel" : [ SenseInfo('02868326-a', 1), SenseInfo('01744111-a', 1) ],
"_stand_v_2_rel" : [ SenseInfo('01546111-v', 169), SenseInfo('02611373-v', 53), SenseInfo('02734488-v', 38), SenseInfo('02702120-v', 18), SenseInfo('00668099-v', 9), SenseInfo('00670991-v', 8), SenseInfo('02707125-v', 5), SenseInfo('02703018-v', 3), SenseInfo('02702368-v', 2), SenseInfo('01546768-v', 1), SenseInfo('01115916-v', 1), SenseInfo('01428203-v', 0) ],
"_recede_v_1_rel" : [ SenseInfo('01994442-v', 4), SenseInfo('01113806-v', 0), SenseInfo('00570694-v', 0) ],
"_devotion_n_to_rel" : [ SenseInfo('07544491-n', 2), SenseInfo('01206553-n', 1), SenseInfo('01044448-n', 0), SenseInfo('01042764-n', 0) ],
"_lead_v_out_rel" : [ SenseInfo('01999798-v', 40), SenseInfo('02635659-v', 35), SenseInfo('02635956-v', 27), SenseInfo('01999423-v', 17), SenseInfo('00771632-v', 17), SenseInfo('02685951-v', 13), SenseInfo('02440244-v', 13), SenseInfo('02687385-v', 10), SenseInfo('02555908-v', 9), SenseInfo('01732921-v', 8), SenseInfo('02686471-v', 5), SenseInfo('01999218-v', 2), SenseInfo('02686625-v', 1), SenseInfo('00813790-v', 0), SenseInfo('01999798-v', 40), SenseInfo('02635659-v', 35), SenseInfo('02635956-v', 27), SenseInfo('01999423-v', 17), SenseInfo('00771632-v', 17), SenseInfo('02685951-v', 13), SenseInfo('02440244-v', 13), SenseInfo('02687385-v', 10), SenseInfo('02555908-v', 9), SenseInfo('01732921-v', 8), SenseInfo('02686471-v', 5), SenseInfo('01999218-v', 2), SenseInfo('02686625-v', 1), SenseInfo('00813790-v', 0) ],
"_deformation_n_of_rel" : [ SenseInfo('07433973-n', 3), SenseInfo('07358060-n', 0), SenseInfo('00404726-n', 0) ],
"_annex_v_1_rel" : [ SenseInfo('02215355-v', 0), SenseInfo('01329141-v', 0) ],
"_comforting_a_1_rel" : [ SenseInfo('02081563-a', 1), SenseInfo('00197319-a', 1) ],
"_scrupulous_a_1_rel" : [ SenseInfo('02085449-a', 0), SenseInfo('00310138-a', 0) ],
"_ghastly_a_1_rel" : [ SenseInfo('00195684-a', 2), SenseInfo('01625492-a', 0), SenseInfo('00195684-a', 2), SenseInfo('01625492-a', 0), SenseInfo('00195684-a', 2), SenseInfo('01625492-a', 0) ],
"_innovative_a_1_rel" : [ SenseInfo('01876261-a', 0), SenseInfo('01687586-a', 0) ],
"_sauce_n_1_rel" : [ SenseInfo('07829412-n', 1) ],
"_characterize_v_as_rel" : [ SenseInfo('00956687-v', 9), SenseInfo('02697950-v', 8), SenseInfo('00956687-v', 9), SenseInfo('02697950-v', 8) ],
"_RFID_n_1_rel" : [  ],
"_plumbing_n_1_rel" : [ SenseInfo('03969041-n', 2), SenseInfo('00609669-n', 1), SenseInfo('00999089-n', 0) ],
"_incomparable_a_1_rel" : [ SenseInfo('00504592-a', 0) ],
"_equator_n_1_rel" : [ SenseInfo('08568719-n', 1), SenseInfo('13874073-n', 0) ],
"_alternation_n_1_rel" : [ SenseInfo('01010684-n', 0) ],
"_ace_v_1_rel" : [ SenseInfo('02522581-v', 0), SenseInfo('01113367-v', 0), SenseInfo('01085130-v', 0), SenseInfo('01077759-v', 0) ],
"_inspire_v_1_rel" : [ SenseInfo('01812720-v', 9), SenseInfo('01646682-v', 5), SenseInfo('00771961-v', 5), SenseInfo('00858781-v', 1), SenseInfo('00605310-v', 0), SenseInfo('00005041-v', 0), SenseInfo('01812720-v', 9), SenseInfo('01646682-v', 5), SenseInfo('00771961-v', 5), SenseInfo('00858781-v', 1), SenseInfo('00605310-v', 0), SenseInfo('00005041-v', 0), SenseInfo('01812720-v', 9), SenseInfo('01646682-v', 5), SenseInfo('00771961-v', 5), SenseInfo('00858781-v', 1), SenseInfo('00605310-v', 0), SenseInfo('00005041-v', 0), SenseInfo('01812720-v', 9), SenseInfo('01646682-v', 5), SenseInfo('00771961-v', 5), SenseInfo('00858781-v', 1), SenseInfo('00605310-v', 0), SenseInfo('00005041-v', 0), SenseInfo('01812720-v', 9), SenseInfo('01646682-v', 5), SenseInfo('00771961-v', 5), SenseInfo('00858781-v', 1), SenseInfo('00605310-v', 0), SenseInfo('00005041-v', 0) ],
"_devoted_a_1_rel" : [ SenseInfo('00519668-a', 6), SenseInfo('00519477-a', 0) ],
"_n-gram_n_1_rel" : [  ],
"_relocation_n_of_rel" : [ SenseInfo('01252566-n', 0), SenseInfo('00168658-n', 0) ],
"_bind_v_1_rel" : [ SenseInfo('01356750-v', 8), SenseInfo('02538086-v', 4), SenseInfo('01303242-v', 4), SenseInfo('01303547-v', 3), SenseInfo('01286913-v', 1), SenseInfo('00885217-v', 1), SenseInfo('01335804-v', 0), SenseInfo('01285440-v', 0), SenseInfo('00567291-v', 0), SenseInfo('00074558-v', 0) ],
"_fv_n_1_rel" : [  ],
"_inadvertent_a_1_rel" : [ SenseInfo('01338909-a', 0), SenseInfo('01338909-a', 0) ],
"_incubate_v_1_rel" : [ SenseInfo('00254150-v', 1), SenseInfo('00060185-v', 1) ],
"_hanger_n_1_rel" : [ SenseInfo('10159434-n', 0), SenseInfo('03490884-n', 0) ],
"_layer_v_cause_rel" : [ SenseInfo('01262113-v', 3) ],
"_fix_v_on_rel" : [ SenseInfo('00260648-v', 9), SenseInfo('01340439-v', 7), SenseInfo('00947077-v', 6), SenseInfo('01664172-v', 5), SenseInfo('01153947-v', 3), SenseInfo('01647543-v', 2), SenseInfo('00407458-v', 2), SenseInfo('00486998-v', 1), SenseInfo('00061595-v', 1), SenseInfo('02603299-v', 0), SenseInfo('01575675-v', 0), SenseInfo('00406243-v', 0) ],
"place_n_rel" : [ SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1) ],
"_crookery_n_1_rel" : [  ],
"_pace_v_1_rel" : [ SenseInfo('01929254-v', 10), SenseInfo('02091165-v', 6), SenseInfo('00490722-v', 2), SenseInfo('00702601-v', 0) ],
"_drudgery_n_1_rel" : [ SenseInfo('00621476-n', 0), SenseInfo('00621476-n', 0) ],
"_shit_n_1_rel" : [ SenseInfo('14854581-n', 1), SenseInfo('06611376-n', 1), SenseInfo('13773047-n', 0), SenseInfo('13555775-n', 0), SenseInfo('09815188-n', 0), SenseInfo('05140793-n', 0) ],
"_deduction_n_of_rel" : [ SenseInfo('13329047-n', 12), SenseInfo('13274597-n', 1), SenseInfo('05780885-n', 1), SenseInfo('05774129-n', 1), SenseInfo('00360757-n', 1), SenseInfo('00362103-n', 0), SenseInfo('13329047-n', 12), SenseInfo('13274597-n', 1), SenseInfo('05780885-n', 1), SenseInfo('05774129-n', 1), SenseInfo('00360757-n', 1), SenseInfo('00362103-n', 0) ],
"_array_n_1_rel" : [ SenseInfo('07939382-n', 4), SenseInfo('06888174-n', 1), SenseInfo('02742322-n', 0), SenseInfo('02742194-n', 0) ],
"_cynical_a_about_rel" : [ SenseInfo('02463582-a', 2) ],
"_reek_n_1_rel" : [ SenseInfo('05714894-n', 0) ],
"_credulity_n_1_rel" : [ SenseInfo('04895558-n', 0) ],
"_v+t_n_1_rel" : [ SenseInfo('09147964-n', 0), SenseInfo('09147964-n', 0), SenseInfo('09147964-n', 0) ],
"_weary_a_of_rel" : [ SenseInfo('02432428-a', 11) ],
"_demise_n_1_rel" : [ SenseInfo('15143477-n', 0) ],
"_aurora+australis_n_1_rel" : [ SenseInfo('11427501-n', 0), SenseInfo('11427501-n', 0) ],
"_remaining_a_1_rel" : [ SenseInfo('00926505-a', 3) ],
"_psychiatry_n_1_rel" : [ SenseInfo('06055946-n', 0) ],
"_fairway_n_1_rel" : [ SenseInfo('08569319-n', 2), SenseInfo('08617751-n', 0), SenseInfo('08614900-n', 0) ],
"_mistrust_v_1_rel" : [ SenseInfo('00687926-v', 2) ],
"_hand-me-down_n_1_rel" : [ SenseInfo('03487642-n', 0), SenseInfo('03487642-n', 0) ],
"_trapper_n_1_rel" : [ SenseInfo('10726233-n', 3) ],
"_visualize_v_1_rel" : [ SenseInfo('01635432-v', 4), SenseInfo('02151394-v', 0), SenseInfo('01636008-v', 0), SenseInfo('00581205-v', 0), SenseInfo('01635432-v', 4), SenseInfo('02151394-v', 0), SenseInfo('01636008-v', 0), SenseInfo('00581205-v', 0), SenseInfo('01635432-v', 4), SenseInfo('02151394-v', 0), SenseInfo('01636008-v', 0), SenseInfo('00581205-v', 0), SenseInfo('01635432-v', 4), SenseInfo('02151394-v', 0), SenseInfo('01636008-v', 0), SenseInfo('00581205-v', 0) ],
"_punctual_a_1_rel" : [ SenseInfo('01900349-a', 0), SenseInfo('01900349-a', 0) ],
"_growl_n_1_rel" : [ SenseInfo('07384473-n', 1) ],
"_stores_n_1_rel" : [ SenseInfo('04202417-n', 25), SenseInfo('13367070-n', 5), SenseInfo('03744276-n', 1), SenseInfo('04329190-n', 0) ],
"_bee_n_1_rel" : [ SenseInfo('02206856-n', 20), SenseInfo('07975909-n', 0) ],
"_full_a_of_rel" : [ SenseInfo('01083157-a', 41), SenseInfo('00515380-a', 32), SenseInfo('00522885-a', 7), SenseInfo('02300501-a', 2), SenseInfo('01456710-a', 1), SenseInfo('00106020-a', 1), SenseInfo('01211531-a', 0), SenseInfo('00106277-a', 0), SenseInfo('01083157-a', 41), SenseInfo('00515380-a', 32), SenseInfo('00522885-a', 7), SenseInfo('02300501-a', 2), SenseInfo('01456710-a', 1), SenseInfo('00106020-a', 1), SenseInfo('01211531-a', 0), SenseInfo('00106277-a', 0), SenseInfo('01083157-a', 41), SenseInfo('00515380-a', 32), SenseInfo('00522885-a', 7), SenseInfo('02300501-a', 2), SenseInfo('01456710-a', 1), SenseInfo('00106020-a', 1), SenseInfo('01211531-a', 0), SenseInfo('00106277-a', 0), SenseInfo('01083157-a', 41), SenseInfo('00515380-a', 32), SenseInfo('00522885-a', 7), SenseInfo('02300501-a', 2), SenseInfo('01456710-a', 1), SenseInfo('00106020-a', 1), SenseInfo('01211531-a', 0), SenseInfo('00106277-a', 0) ],
"_retention_n_of_rel" : [ SenseInfo('00810598-n', 8), SenseInfo('05651399-n', 1), SenseInfo('04942172-n', 0) ],
"_chime_n_1_rel" : [ SenseInfo('03017168-n', 0) ],
"_flysheet_n_1_rel" : [  ],
"_kickoff_n_1_rel" : [ SenseInfo('00241507-n', 2), SenseInfo('15265518-n', 1), SenseInfo('07329568-n', 0), SenseInfo('00241507-n', 2), SenseInfo('15265518-n', 1), SenseInfo('07329568-n', 0) ],
"_following_n_1_rel" : [ SenseInfo('08223263-n', 1), SenseInfo('00319939-n', 0), SenseInfo('08223263-n', 1), SenseInfo('00319939-n', 0) ],
"_kitchen_n_1_rel" : [ SenseInfo('03619890-n', 43) ],
"_affliction_n_1_rel" : [ SenseInfo('14477342-n', 0), SenseInfo('14213199-n', 0), SenseInfo('07305234-n', 0) ],
"_whatsoever_a_1_rel" : [ SenseInfo('02267686-a', 0) ],
"_but+for_p_rel" : [  ],
"_future_n_1_rel" : [ SenseInfo('15121625-n', 46), SenseInfo('06330401-n', 2), SenseInfo('03408721-n', 0), SenseInfo('15121625-n', 46), SenseInfo('06330401-n', 2), SenseInfo('03408721-n', 0), SenseInfo('15121625-n', 46), SenseInfo('06330401-n', 2), SenseInfo('03408721-n', 0) ],
"_hang_v_around_rel" : [ SenseInfo('01482075-v', 35), SenseInfo('01481360-v', 12), SenseInfo('02485451-v', 11), SenseInfo('01977962-v', 6), SenseInfo('01542668-v', 5), SenseInfo('02734952-v', 2), SenseInfo('02170427-v', 1), SenseInfo('01481957-v', 1), SenseInfo('01216331-v', 1), SenseInfo('02741003-v', 0), SenseInfo('02557790-v', 0), SenseInfo('01677716-v', 0), SenseInfo('01481819-v', 0), SenseInfo('01481647-v', 0), SenseInfo('00210110-v', 0) ],
"_though_a_1_rel" : [  ],
"_dolly_n_1_rel" : [ SenseInfo('03219732-n', 0), SenseInfo('03219612-n', 0), SenseInfo('03219135-n', 0) ],
"_chrome_n_1_rel" : [ SenseInfo('14810704-n', 3) ],
"_iroquois_n_1_rel" : [ SenseInfo('09657887-n', 0), SenseInfo('06916803-n', 0) ],
"_disgrace_n_1_rel" : [ SenseInfo('14440137-n', 2) ],
"_pastor_v_1_rel" : [  ],
"_abort_v_1_rel" : [ SenseInfo('00353839-v', 0), SenseInfo('00060063-v', 0), SenseInfo('00059899-v', 0) ],
"_torque_v_cause_rel" : [  ],
"_perspective_n_1_rel" : [ SenseInfo('06208751-n', 6), SenseInfo('04676308-n', 1) ],
"_cervix_n_1_rel" : [ SenseInfo('05546540-n', 0), SenseInfo('05303232-n', 0) ],
"_literacy_n_1_rel" : [ SenseInfo('05638486-n', 0) ],
"_direct_n_1_rel" : [ SenseInfo('00760916-a', 23), SenseInfo('00770480-a', 16), SenseInfo('00763901-a', 5), SenseInfo('01416508-a', 0), SenseInfo('00769926-a', 0), SenseInfo('00769239-a', 0), SenseInfo('00763633-a', 0), SenseInfo('01852666-a', 0), SenseInfo('00914808-a', 0), SenseInfo('00005473-a', 0) ],
"_dialogue_n_1_rel" : [ SenseInfo('07136206-n', 3), SenseInfo('07010541-n', 2), SenseInfo('06366391-n', 2), SenseInfo('07148192-n', 0), SenseInfo('07136206-n', 3), SenseInfo('07010541-n', 2), SenseInfo('06366391-n', 2), SenseInfo('07148192-n', 0) ],
"_mail_v_back_rel" : [ SenseInfo('01437888-v', 12), SenseInfo('01031256-v', 0) ],
"_exemption_n_from_rel" : [ SenseInfo('14528873-n', 4), SenseInfo('13310985-n', 0), SenseInfo('00213903-n', 0) ],
"_architect_n_of_rel" : [ SenseInfo('09805475-n', 9) ],
"_insulin_n_1_rel" : [ SenseInfo('05410646-n', 3) ],
"_that+is_p_rel" : [  ],
"_number_v_1_rel" : [ SenseInfo('02645007-v', 6), SenseInfo('00948853-v', 2), SenseInfo('00946755-v', 1), SenseInfo('02731632-v', 0), SenseInfo('00948071-v', 0), SenseInfo('00235918-v', 0) ],
"_regain_v_1_rel" : [ SenseInfo('02247977-v', 5), SenseInfo('02285629-v', 0) ],
"_afraid+so_a_1_rel" : [  ],
"_recall_v_1_rel" : [ SenseInfo('00607780-v', 47), SenseInfo('00959524-v', 4), SenseInfo('02675458-v', 1), SenseInfo('00791506-v', 1), SenseInfo('00722848-v', 1), SenseInfo('02480216-v', 0), SenseInfo('02312478-v', 0), SenseInfo('00607780-v', 47), SenseInfo('00959524-v', 4), SenseInfo('02675458-v', 1), SenseInfo('00791506-v', 1), SenseInfo('00722848-v', 1), SenseInfo('02480216-v', 0), SenseInfo('02312478-v', 0), SenseInfo('00607780-v', 47), SenseInfo('00959524-v', 4), SenseInfo('02675458-v', 1), SenseInfo('00791506-v', 1), SenseInfo('00722848-v', 1), SenseInfo('02480216-v', 0), SenseInfo('02312478-v', 0) ],
"_vocal_a_1_rel" : [ SenseInfo('02825533-a', 1), SenseInfo('02825355-a', 1), SenseInfo('00499530-a', 1), SenseInfo('01454494-a', 0) ],
"_grunt_v_at_rel" : [ SenseInfo('01043231-v', 11) ],
"manner_rel" : [  ],
"_scornful_a_1_rel" : [ SenseInfo('01995288-a', 2) ],
"_husky_a_1_rel" : [ SenseInfo('02038126-a', 3), SenseInfo('00299690-a', 1), SenseInfo('02038126-a', 3), SenseInfo('00299690-a', 1), SenseInfo('02038126-a', 3), SenseInfo('00299690-a', 1) ],
"_kb_n_1_rel" : [ SenseInfo('13627810-n', 0), SenseInfo('13627681-n', 0), SenseInfo('13627516-n', 0), SenseInfo('13627810-n', 0), SenseInfo('13627681-n', 0), SenseInfo('13627516-n', 0) ],
"_respiratory_a_1_rel" : [ SenseInfo('03110322-a', 13) ],
"_sexy_a_1_rel" : [ SenseInfo('02131072-a', 1), SenseInfo('02137538-a', 0), SenseInfo('02131072-a', 1), SenseInfo('02137538-a', 0), SenseInfo('02131072-a', 1), SenseInfo('02137538-a', 0) ],
"_counteract_v_1_rel" : [ SenseInfo('02564841-v', 2), SenseInfo('02564973-v', 1), SenseInfo('02543874-v', 1), SenseInfo('02543607-v', 0), SenseInfo('02564841-v', 2), SenseInfo('02564973-v', 1), SenseInfo('02543874-v', 1), SenseInfo('02543607-v', 0) ],
"_bellow_v_at_rel" : [ SenseInfo('01048569-v', 10), SenseInfo('01048718-v', 0) ],
"_aborigine_n_1_rel" : [ SenseInfo('09620794-n', 1), SenseInfo('09676490-n', 0) ],
"_assassin_n_1_rel" : [ SenseInfo('09813696-n', 6), SenseInfo('09814084-n', 0) ],
"_rut_n_1_rel" : [ SenseInfo('13894154-n', 1), SenseInfo('01026744-n', 1), SenseInfo('14038264-n', 0) ],
"_ring_v_1_rel" : [ SenseInfo('02180898-v', 15), SenseInfo('02183787-v', 7), SenseInfo('02181538-v', 5), SenseInfo('00789448-v', 1), SenseInfo('01467370-v', 0), SenseInfo('01297401-v', 0) ],
"_publicity_n_1_rel" : [ SenseInfo('07247071-n', 4), SenseInfo('04720536-n', 0) ],
"_run_v_out-of_rel" : [ SenseInfo('01926311-v', 106), SenseInfo('02075049-v', 38), SenseInfo('02685951-v', 21), SenseInfo('02443849-v', 20), SenseInfo('02721284-v', 10), SenseInfo('02066939-v', 9), SenseInfo('01525666-v', 8), SenseInfo('02727039-v', 7), SenseInfo('01094086-v', 7), SenseInfo('01717169-v', 5), SenseInfo('02099829-v', 4), SenseInfo('02719399-v', 3), SenseInfo('01526290-v', 3), SenseInfo('00549063-v', 3), SenseInfo('00517529-v', 3), SenseInfo('02720904-v', 2), SenseInfo('02647497-v', 2), SenseInfo('02612234-v', 2), SenseInfo('02563327-v', 2), SenseInfo('01746359-v', 2), SenseInfo('01641545-v', 2), SenseInfo('01212230-v', 2), SenseInfo('02686625-v', 1), SenseInfo('02525312-v', 1), SenseInfo('02242256-v', 1), SenseInfo('02092309-v', 1), SenseInfo('02060792-v', 1), SenseInfo('01927903-v', 1), SenseInfo('01914947-v', 1), SenseInfo('02648110-v', 0), SenseInfo('02421921-v', 0), SenseInfo('01927747-v', 0), SenseInfo('01927447-v', 0), SenseInfo('01926984-v', 0), SenseInfo('01864038-v', 0), SenseInfo('01143838-v', 0), SenseInfo('01086103-v', 0), SenseInfo('00539110-v', 0), SenseInfo('00444629-v', 0), SenseInfo('00334803-v', 0), SenseInfo('00332672-v', 0) ],
"_label_n_1_rel" : [ SenseInfo('07202579-n', 3), SenseInfo('06851516-n', 2), SenseInfo('14620066-n', 1), SenseInfo('07272172-n', 1), SenseInfo('07202579-n', 3), SenseInfo('06851516-n', 2), SenseInfo('14620066-n', 1), SenseInfo('07272172-n', 1) ],
"_escritoire_n_1_rel" : [ SenseInfo('04164868-n', 2) ],
"_bang_v_cause_rel" : [ SenseInfo('01242391-v', 3), SenseInfo('02187693-v', 2), SenseInfo('01242832-v', 2), SenseInfo('02100176-v', 1), SenseInfo('01426397-v', 0), SenseInfo('01236941-v', 0) ],
"_heap_v_1_rel" : [ SenseInfo('02263788-v', 1), SenseInfo('01503404-v', 1), SenseInfo('00453424-v', 0) ],
"_deter_v_from_rel" : [ SenseInfo('00908099-v', 1), SenseInfo('00770141-v', 0) ],
"_wall_v_off_rel" : [ SenseInfo('01130607-v', 0) ],
"_prosodic_a_1_rel" : [ SenseInfo('02997329-a', 1) ],
"_bubble_v_over_rel" : [ SenseInfo('00519056-v', 3), SenseInfo('02187922-v', 0), SenseInfo('01969084-v', 0), SenseInfo('00519229-v', 0), SenseInfo('00003431-v', 0) ],
"_budge_v_cause_rel" : [ SenseInfo('01893988-v', 3) ],
"_emission_n_of_rel" : [ SenseInfo('01253060-n', 6), SenseInfo('14852450-n', 0), SenseInfo('13474290-n', 0), SenseInfo('13466586-n', 0), SenseInfo('07433868-n', 0), SenseInfo('01253060-n', 6), SenseInfo('14852450-n', 0), SenseInfo('13474290-n', 0), SenseInfo('13466586-n', 0), SenseInfo('07433868-n', 0), SenseInfo('01253060-n', 6), SenseInfo('14852450-n', 0), SenseInfo('13474290-n', 0), SenseInfo('13466586-n', 0), SenseInfo('07433868-n', 0) ],
"_choke_n_1_rel" : [ SenseInfo('03024518-n', 0), SenseInfo('03024333-n', 0) ],
"_box_n_of_rel" : [ SenseInfo('02883344-n', 25), SenseInfo('02884225-n', 8), SenseInfo('13765624-n', 3), SenseInfo('14408951-n', 1), SenseInfo('13883494-n', 0), SenseInfo('12746106-n', 0), SenseInfo('02884607-n', 0), SenseInfo('02884450-n', 0), SenseInfo('02884011-n', 0), SenseInfo('00135148-n', 0) ],
"_seethe_v_1_rel" : [ SenseInfo('02706605-v', 0), SenseInfo('01767612-v', 0), SenseInfo('00519751-v', 0), SenseInfo('00324427-v', 0) ],
"_lateral_a_1_rel" : [ SenseInfo('02441469-a', 0), SenseInfo('00778828-a', 0), SenseInfo('02441469-a', 0), SenseInfo('00778828-a', 0) ],
"_in_p_rel" : [ SenseInfo('00501990-r', 19), SenseInfo('13649791-n', 3), SenseInfo('14641223-n', 0), SenseInfo('09084750-n', 0), SenseInfo('02332204-a', 0), SenseInfo('01295143-a', 0), SenseInfo('00972501-a', 0), SenseInfo('00501990-r', 19), SenseInfo('13649791-n', 3), SenseInfo('14641223-n', 0), SenseInfo('09084750-n', 0), SenseInfo('02332204-a', 0), SenseInfo('01295143-a', 0), SenseInfo('00972501-a', 0), SenseInfo('00501990-r', 19), SenseInfo('13649791-n', 3), SenseInfo('14641223-n', 0), SenseInfo('09084750-n', 0), SenseInfo('02332204-a', 0), SenseInfo('01295143-a', 0), SenseInfo('00972501-a', 0), SenseInfo('00501990-r', 19), SenseInfo('13649791-n', 3), SenseInfo('14641223-n', 0), SenseInfo('09084750-n', 0), SenseInfo('02332204-a', 0), SenseInfo('01295143-a', 0), SenseInfo('00972501-a', 0), SenseInfo('00501990-r', 19), SenseInfo('13649791-n', 3), SenseInfo('14641223-n', 0), SenseInfo('09084750-n', 0), SenseInfo('02332204-a', 0), SenseInfo('01295143-a', 0), SenseInfo('00972501-a', 0) ],
"_stormy_a_1_rel" : [ SenseInfo('00303727-a', 2), SenseInfo('01742912-a', 1), SenseInfo('00303727-a', 2), SenseInfo('01742912-a', 1), SenseInfo('00303727-a', 2), SenseInfo('01742912-a', 1) ],
"_ice+cream_n_1_rel" : [ SenseInfo('07614500-n', 1), SenseInfo('07614500-n', 1) ],
"_part_n_of_rel" : [ SenseInfo('13809207-n', 113), SenseInfo('03892891-n', 24), SenseInfo('09385911-n', 19), SenseInfo('05671974-n', 19), SenseInfo('08630039-n', 15), SenseInfo('00720565-n', 13), SenseInfo('05929008-n', 9), SenseInfo('13285176-n', 8), SenseInfo('05867413-n', 7), SenseInfo('05256358-n', 3), SenseInfo('07030718-n', 2), SenseInfo('00787465-n', 2), SenseInfo('13809207-n', 113), SenseInfo('03892891-n', 24), SenseInfo('09385911-n', 19), SenseInfo('05671974-n', 19), SenseInfo('08630039-n', 15), SenseInfo('00720565-n', 13), SenseInfo('05929008-n', 9), SenseInfo('13285176-n', 8), SenseInfo('05867413-n', 7), SenseInfo('05256358-n', 3), SenseInfo('07030718-n', 2), SenseInfo('00787465-n', 2) ],
"_outline_v_to_rel" : [ SenseInfo('01006421-v', 12), SenseInfo('01701634-v', 0), SenseInfo('01689379-v', 0), SenseInfo('01006421-v', 12), SenseInfo('01701634-v', 0), SenseInfo('01689379-v', 0) ],
"_fall_v_to-i_rel" : [ SenseInfo('01972298-v', 43), SenseInfo('01970826-v', 21), SenseInfo('00147815-v', 16), SenseInfo('02729963-v', 6), SenseInfo('02756821-v', 4), SenseInfo('02528985-v', 4), SenseInfo('02620213-v', 3), SenseInfo('02611976-v', 3), SenseInfo('02304507-v', 3), SenseInfo('00342443-v', 3), SenseInfo('00151689-v', 3), SenseInfo('02565911-v', 2), SenseInfo('02385153-v', 2), SenseInfo('02358655-v', 2), SenseInfo('02099413-v', 1), SenseInfo('02661015-v', 0), SenseInfo('02566092-v', 0), SenseInfo('02358922-v', 0), SenseInfo('02230056-v', 0), SenseInfo('02229828-v', 0), SenseInfo('02229550-v', 0), SenseInfo('02037839-v', 0), SenseInfo('01984317-v', 0), SenseInfo('01984119-v', 0), SenseInfo('01542668-v', 0), SenseInfo('00561375-v', 0), SenseInfo('00561266-v', 0), SenseInfo('00530177-v', 0), SenseInfo('00360678-v', 0), SenseInfo('00346839-v', 0), SenseInfo('00342314-v', 0), SenseInfo('00342164-v', 0) ],
"_ridgewalk_n_1_rel" : [  ],
"_decade_n_1_rel" : [ SenseInfo('15204983-n', 25), SenseInfo('13746512-n', 0) ],
"_unit_n_of_rel" : [ SenseInfo('13583724-n', 14), SenseInfo('13810323-n', 13), SenseInfo('08189659-n', 9), SenseInfo('05869857-n', 6), SenseInfo('09465459-n', 2), SenseInfo('00003553-n', 0) ],
"_usury_n_1_rel" : [ SenseInfo('13320045-n', 0), SenseInfo('01093855-n', 0) ],
"_comb_n_1_rel" : [ SenseInfo('03074855-n', 3), SenseInfo('01792255-n', 1), SenseInfo('03075097-n', 0), SenseInfo('01921440-n', 0), SenseInfo('00256746-n', 0) ],
"_crystalline_a_1_rel" : [ SenseInfo('00268869-a', 0), SenseInfo('00780575-a', 0), SenseInfo('00431774-a', 0) ],
"_circuitry_n_1_rel" : [ SenseInfo('03034405-n', 1) ],
"_level_v_out_rel" : [ SenseInfo('01152896-v', 4), SenseInfo('01661804-v', 1), SenseInfo('01307142-v', 1), SenseInfo('01152214-v', 0), SenseInfo('00964237-v', 0), SenseInfo('00356649-v', 0), SenseInfo('01152896-v', 4), SenseInfo('01661804-v', 1), SenseInfo('01307142-v', 1), SenseInfo('01152214-v', 0), SenseInfo('00964237-v', 0), SenseInfo('00356649-v', 0) ],
"_aid_n_1_rel" : [ SenseInfo('05154908-n', 10), SenseInfo('01207609-n', 9), SenseInfo('13265904-n', 6), SenseInfo('00654885-n', 0) ],
"_voter_n_1_rel" : [ SenseInfo('10760340-n', 7) ],
"_inane_a_1_rel" : [ SenseInfo('02571277-a', 1) ],
"_bum_v_around_rel" : [ SenseInfo('02270404-v', 1), SenseInfo('02639606-v', 0) ],
"_scandal_n_1_rel" : [ SenseInfo('07223811-n', 3), SenseInfo('07306252-n', 1) ],
"_reasonably_x_deg_rel" : [ SenseInfo('00035718-r', 11), SenseInfo('00215811-r', 1) ],
"_cook_v_1_rel" : [ SenseInfo('01665638-v', 9), SenseInfo('01664172-v', 9), SenseInfo('00322847-v', 6), SenseInfo('02576921-v', 0), SenseInfo('00323377-v', 0), SenseInfo('01665638-v', 9), SenseInfo('01664172-v', 9), SenseInfo('00322847-v', 6), SenseInfo('02576921-v', 0), SenseInfo('00323377-v', 0) ],
"_snow+bunting_n_1_rel" : [ SenseInfo('01538630-n', 0), SenseInfo('01538630-n', 0) ],
"_season_v_1_rel" : [ SenseInfo('02191766-v', 0), SenseInfo('00295120-v', 0), SenseInfo('00294884-v', 0) ],
"_flatout_a_1_rel" : [  ],
"_quarter_n_temp_rel" : [ SenseInfo('13737480-n', 7), SenseInfo('08627919-n', 4), SenseInfo('15258450-n', 0), SenseInfo('15234942-n', 0), SenseInfo('15226046-n', 0), SenseInfo('15206590-n', 0), SenseInfo('13830166-n', 0), SenseInfo('13720852-n', 0), SenseInfo('13623054-n', 0), SenseInfo('13390244-n', 0), SenseInfo('10498699-n', 0), SenseInfo('04316646-n', 0), SenseInfo('04031600-n', 0), SenseInfo('01258579-n', 0) ],
"_cost-of-living_a_1_rel" : [  ],
"_angle_v_for_rel" : [ SenseInfo('02044866-v', 2), SenseInfo('02038357-v', 0), SenseInfo('01319346-v', 0), SenseInfo('01141612-v', 0), SenseInfo('00680485-v', 0) ],
"_lashing_n_1_rel" : [ SenseInfo('01163047-n', 1), SenseInfo('03644073-n', 0) ],
"_char_n_1_rel" : [ SenseInfo('14685172-n', 0), SenseInfo('09911226-n', 0), SenseInfo('02538406-n', 0) ],
"_rotate_v_1_rel" : [ SenseInfo('02045043-v', 8), SenseInfo('02393894-v', 1), SenseInfo('01096305-v', 1), SenseInfo('02045790-v', 0), SenseInfo('02045415-v', 0), SenseInfo('00245913-v', 0) ],
"_squint_v_at_rel" : [ SenseInfo('00008602-v', 3), SenseInfo('02168070-v', 0), SenseInfo('00008799-v', 0) ],
"_match_v_cause_rel" : [ SenseInfo('02657219-v', 16), SenseInfo('02332627-v', 12), SenseInfo('01292885-v', 6), SenseInfo('02672187-v', 5), SenseInfo('00456740-v', 3), SenseInfo('02594674-v', 0), SenseInfo('01293389-v', 0), SenseInfo('01081152-v', 0), SenseInfo('00456596-v', 0), SenseInfo('00417001-v', 0) ],
"_bounce_v_1_rel" : [ SenseInfo('01892104-v', 13), SenseInfo('01404389-v', 5), SenseInfo('01892608-v', 4), SenseInfo('02254923-v', 1), SenseInfo('01964788-v', 1), SenseInfo('02254767-v', 0), SenseInfo('01469080-v', 0) ],
"_in+between_a_1_rel" : [ SenseInfo('01014953-a', 0) ],
"_reasoning_n_1_rel" : [ SenseInfo('05772356-n', 5) ],
"_weary_a_1_rel" : [ SenseInfo('02432428-a', 11) ],
"_commonplace_a_1_rel" : [ SenseInfo('01673946-a', 1), SenseInfo('00922840-a', 1), SenseInfo('01688757-a', 0) ],
"_television_n_1_rel" : [ SenseInfo('06277280-n', 12), SenseInfo('04404412-n', 2), SenseInfo('04405907-n', 1) ],
"_penultimate_a_1_rel" : [ SenseInfo('01015392-a', 0) ],
"_ersatz_n_1_rel" : [ SenseInfo('05696701-n', 0) ],
"_weight_n_of_rel" : [ SenseInfo('05026843-n', 26), SenseInfo('04571292-n', 5), SenseInfo('05172322-n', 4), SenseInfo('04571088-n', 3), SenseInfo('07538812-n', 2), SenseInfo('13715755-n', 0), SenseInfo('13608788-n', 0), SenseInfo('13589321-n', 0), SenseInfo('05026843-n', 26), SenseInfo('04571292-n', 5), SenseInfo('05172322-n', 4), SenseInfo('04571088-n', 3), SenseInfo('07538812-n', 2), SenseInfo('13715755-n', 0), SenseInfo('13608788-n', 0), SenseInfo('13589321-n', 0) ],
"_herdsmen_a_1_rel" : [  ],
"_horrify_v_1_rel" : [ SenseInfo('01782650-v', 0), SenseInfo('01782650-v', 0), SenseInfo('01782650-v', 0), SenseInfo('01782650-v', 0) ],
"_expansive_a_1_rel" : [ SenseInfo('00946499-a', 0), SenseInfo('01284544-a', 0), SenseInfo('00909220-a', 0), SenseInfo('00496938-a', 0) ],
"_puff_v_up_rel" : [ SenseInfo('01198616-v', 2), SenseInfo('01199009-v', 1), SenseInfo('00005526-v', 1), SenseInfo('01812197-v', 0), SenseInfo('01065272-v', 0), SenseInfo('00797303-v', 0), SenseInfo('00263682-v', 0), SenseInfo('00006802-v', 0) ],
"_guard_n_1_rel" : [ SenseInfo('10150071-n', 15), SenseInfo('10149720-n', 2), SenseInfo('03464467-n', 2), SenseInfo('05082222-n', 1), SenseInfo('10150281-n', 0), SenseInfo('08215603-n', 0), SenseInfo('00822970-n', 0), SenseInfo('00730538-n', 0), SenseInfo('00727743-n', 0), SenseInfo('00725673-n', 0) ],
"_queue_v_1_rel" : [ SenseInfo('02036755-v', 0) ],
"_vanish_v_1_rel" : [ SenseInfo('00426958-v', 11), SenseInfo('02156546-v', 6), SenseInfo('02073065-v', 0), SenseInfo('00427397-v', 0), SenseInfo('00153061-v', 0), SenseInfo('00426958-v', 11), SenseInfo('02156546-v', 6), SenseInfo('02073065-v', 0), SenseInfo('00427397-v', 0), SenseInfo('00153061-v', 0) ],
"_crew_n_of_rel" : [ SenseInfo('08273167-n', 15), SenseInfo('08242799-n', 4), SenseInfo('08273843-n', 0), SenseInfo('08273736-n', 0) ],
"_logon_n_1_rel" : [  ],
"_dwarf_n_1_rel" : [ SenseInfo('10040344-n', 1), SenseInfo('09541125-n', 0), SenseInfo('00005930-n', 0) ],
"_gold_n_1_rel" : [ SenseInfo('13371760-n', 8), SenseInfo('04966240-n', 8), SenseInfo('14638799-n', 2), SenseInfo('13353446-n', 0), SenseInfo('05141492-n', 0) ],
"_monthly_a_1_rel" : [ SenseInfo('01969707-a', 0), SenseInfo('01969707-a', 0) ],
"_interruption_n_of_rel" : [ SenseInfo('00383952-n', 5), SenseInfo('07367812-n', 1), SenseInfo('15271008-n', 0) ],
"_case-by-case_a_1_rel" : [ SenseInfo('00729246-a', 0), SenseInfo('00729246-a', 0), SenseInfo('00729246-a', 0), SenseInfo('00729246-a', 0) ],
"_ferry_n_1_rel" : [ SenseInfo('03329663-n', 0), SenseInfo('01106587-n', 0) ],
"_missile_n_1_rel" : [ SenseInfo('03773504-n', 10), SenseInfo('04008634-n', 4) ],
"_fame_n_1_rel" : [ SenseInfo('14437386-n', 7), SenseInfo('14438898-n', 0) ],
"_put+upon_a_1_rel" : [ SenseInfo('02495687-a', 0) ],
"_thermos_n_1_rel" : [ SenseInfo('04422727-n', 0) ],
"_nave_n_1_rel" : [ SenseInfo('03813078-n', 0) ],
"_spatial_a_1_rel" : [ SenseInfo('02841066-a', 8), SenseInfo('02841066-a', 8) ],
"_lunge_n_1_rel" : [ SenseInfo('00290276-n', 1), SenseInfo('01174251-n', 0) ],
"_vaudeville_n_1_rel" : [ SenseInfo('07020423-n', 4) ],
"_rpm_n_1_rel" : [ SenseInfo('15281870-n', 6) ],
"_seaway_n_1_rel" : [ SenseInfo('04163364-n', 0) ],
"_see_v_around_rel" : [ SenseInfo('02129289-v', 613), SenseInfo('00591115-v', 159), SenseInfo('02128873-v', 140), SenseInfo('01635432-v', 58), SenseInfo('00690614-v', 47), SenseInfo('00598954-v', 40), SenseInfo('02150948-v', 29), SenseInfo('02023107-v', 27), SenseInfo('00920336-v', 27), SenseInfo('00662589-v', 22), SenseInfo('02488304-v', 13), SenseInfo('02488488-v', 12), SenseInfo('02493030-v', 10), SenseInfo('02549581-v', 7), SenseInfo('01470670-v', 4), SenseInfo('02486232-v', 1), SenseInfo('02129709-v', 1), SenseInfo('00703708-v', 1), SenseInfo('02156225-v', 0), SenseInfo('02131279-v', 0), SenseInfo('02110220-v', 0), SenseInfo('02026086-v', 0), SenseInfo('01156568-v', 0), SenseInfo('00623151-v', 0) ],
"_coatimundi_n_1_rel" : [  ],
"_hutmaster_n_1_rel" : [  ],
"_pass_v_out_rel" : [ SenseInfo('02050132-v', 32), SenseInfo('02051694-v', 31), SenseInfo('02466670-v', 29), SenseInfo('02072849-v', 17), SenseInfo('02230772-v', 13), SenseInfo('02685951-v', 8), SenseInfo('02049696-v', 8), SenseInfo('00339934-v', 7), SenseInfo('02523351-v', 4), SenseInfo('02708420-v', 3), SenseInfo('01212230-v', 3), SenseInfo('00742320-v', 3), SenseInfo('00421691-v', 3), SenseInfo('02525044-v', 2), SenseInfo('02669081-v', 1), SenseInfo('02523953-v', 1), SenseInfo('02423513-v', 1), SenseInfo('02221635-v', 1), SenseInfo('01972131-v', 1), SenseInfo('02231473-v', 0), SenseInfo('02229550-v', 0), SenseInfo('02052476-v', 0), SenseInfo('00803325-v', 0), SenseInfo('00358431-v', 0), SenseInfo('00072989-v', 0), SenseInfo('02050132-v', 32), SenseInfo('02051694-v', 31), SenseInfo('02466670-v', 29), SenseInfo('02072849-v', 17), SenseInfo('02230772-v', 13), SenseInfo('02685951-v', 8), SenseInfo('02049696-v', 8), SenseInfo('00339934-v', 7), SenseInfo('02523351-v', 4), SenseInfo('02708420-v', 3), SenseInfo('01212230-v', 3), SenseInfo('00742320-v', 3), SenseInfo('00421691-v', 3), SenseInfo('02525044-v', 2), SenseInfo('02669081-v', 1), SenseInfo('02523953-v', 1), SenseInfo('02423513-v', 1), SenseInfo('02221635-v', 1), SenseInfo('01972131-v', 1), SenseInfo('02231473-v', 0), SenseInfo('02229550-v', 0), SenseInfo('02052476-v', 0), SenseInfo('00803325-v', 0), SenseInfo('00358431-v', 0), SenseInfo('00072989-v', 0) ],
"_pack_v_1_rel" : [ SenseInfo('01482449-v', 11), SenseInfo('02086963-v', 2), SenseInfo('01483779-v', 2), SenseInfo('01451176-v', 2), SenseInfo('02396536-v', 1), SenseInfo('02717102-v', 0), SenseInfo('02064131-v', 0), SenseInfo('01926031-v', 0), SenseInfo('01574571-v', 0), SenseInfo('01484884-v', 0), SenseInfo('01484027-v', 0), SenseInfo('01483131-v', 0), SenseInfo('00108909-v', 0) ],
"_steed_n_1_rel" : [ SenseInfo('02378755-n', 1) ],
"_drab_a_1_rel" : [ SenseInfo('00807399-a', 2), SenseInfo('00405179-a', 1), SenseInfo('00378687-a', 0), SenseInfo('00364881-a', 0), SenseInfo('00807399-a', 2), SenseInfo('00405179-a', 1), SenseInfo('00378687-a', 0), SenseInfo('00364881-a', 0), SenseInfo('00807399-a', 2), SenseInfo('00405179-a', 1), SenseInfo('00378687-a', 0), SenseInfo('00364881-a', 0) ],
"_crocodile_n_1_rel" : [ SenseInfo('01697178-n', 0) ],
"_penis_n_1_rel" : [ SenseInfo('05526384-n', 0) ],
"_cut_v_in_rel" : [ SenseInfo('01552519-v', 58), SenseInfo('00429060-v', 18), SenseInfo('02033295-v', 3), SenseInfo('01610834-v', 2), SenseInfo('02422283-v', 1), SenseInfo('01754915-v', 1), SenseInfo('01666717-v', 1), SenseInfo('01413917-v', 1), SenseInfo('01064799-v', 1), SenseInfo('00201722-v', 1), SenseInfo('02613860-v', 0), SenseInfo('02588280-v', 0), SenseInfo('02134232-v', 0), SenseInfo('02101649-v', 0), SenseInfo('01915865-v', 0), SenseInfo('01915730-v', 0), SenseInfo('01860107-v', 0), SenseInfo('01859995-v', 0), SenseInfo('01756563-v', 0), SenseInfo('01756416-v', 0), SenseInfo('01756277-v', 0), SenseInfo('01754737-v', 0), SenseInfo('01713491-v', 0), SenseInfo('01611123-v', 0), SenseInfo('01610990-v', 0), SenseInfo('01555437-v', 0), SenseInfo('01510576-v', 0), SenseInfo('01320424-v', 0), SenseInfo('01319738-v', 0), SenseInfo('01227088-v', 0), SenseInfo('01059564-v', 0), SenseInfo('00561090-v', 0), SenseInfo('00473322-v', 0), SenseInfo('00447654-v', 0), SenseInfo('00429968-v', 0), SenseInfo('00292507-v', 0), SenseInfo('00243900-v', 0), SenseInfo('00226071-v', 0), SenseInfo('00108475-v', 0), SenseInfo('00096136-v', 0), SenseInfo('00061219-v', 0) ],
"_borne_a_1_rel" : [  ],
"_surprise_a_1_rel" : [ SenseInfo('07510348-n', 16), SenseInfo('07298154-n', 5), SenseInfo('00553655-n', 0) ],
"_pH_n_1_rel" : [ SenseInfo('05039106-n', 7) ],
"_flick_v_at_rel" : [ SenseInfo('02160177-v', 1), SenseInfo('02153023-v', 1), SenseInfo('01893465-v', 1), SenseInfo('01591158-v', 1), SenseInfo('02763609-v', 0), SenseInfo('01591357-v', 0), SenseInfo('01242208-v', 0), SenseInfo('01242071-v', 0), SenseInfo('00190586-v', 0), SenseInfo('02160177-v', 1), SenseInfo('02153023-v', 1), SenseInfo('01893465-v', 1), SenseInfo('01591158-v', 1), SenseInfo('02763609-v', 0), SenseInfo('01591357-v', 0), SenseInfo('01242208-v', 0), SenseInfo('01242071-v', 0), SenseInfo('00190586-v', 0) ],
"_on+sale_a_1_rel" : [  ],
"_amid_p_rel" : [  ],
"_portrayal_n_1_rel" : [ SenseInfo('07202391-n', 1), SenseInfo('00548802-n', 1), SenseInfo('05766984-n', 0), SenseInfo('03987079-n', 0), SenseInfo('00900726-n', 0) ],
"_discordant_a_1_rel" : [ SenseInfo('00553899-a', 0), SenseInfo('01164250-a', 0), SenseInfo('00553899-a', 0), SenseInfo('01164250-a', 0) ],
"_efficacious_a_1_rel" : [ SenseInfo('00838856-a', 1), SenseInfo('00834198-a', 0) ],
"_jazz_n_1_rel" : [ SenseInfo('07136711-n', 0), SenseInfo('07062697-n', 0), SenseInfo('07060976-n', 0) ],
"_fade_n_1_rel" : [ SenseInfo('00572043-n', 0), SenseInfo('00230172-n', 0) ],
"_s100_n_1_rel" : [  ],
"_considerate_a_of_rel" : [ SenseInfo('00638981-a', 2) ],
"_smore_n_1_rel" : [  ],
"_appropriate_v_1_rel" : [ SenseInfo('00724150-v', 11), SenseInfo('02272549-v', 1) ],
"_improve_v_on_rel" : [ SenseInfo('00205885-v', 66), SenseInfo('00205046-v', 12) ],
"_apportion_v_1_rel" : [ SenseInfo('02234087-v', 3), SenseInfo('02294179-v', 0) ],
"_interconnected_a_1_rel" : [ SenseInfo('02006933-a', 0), SenseInfo('01328229-a', 0) ],
"_controversy_n_1_rel" : [ SenseInfo('07183151-n', 8) ],
"_coincidence_n_1_rel" : [ SenseInfo('07316999-n', 6), SenseInfo('05077661-n', 0), SenseInfo('05048301-n', 0), SenseInfo('07316999-n', 6), SenseInfo('05077661-n', 0), SenseInfo('05048301-n', 0) ],
"_conceptual_a_1_rel" : [ SenseInfo('00012362-a', 1), SenseInfo('00012362-a', 1) ],
"_guilty_a_1_rel" : [ SenseInfo('01320988-a', 10), SenseInfo('00154583-a', 2), SenseInfo('01320988-a', 10), SenseInfo('00154583-a', 2) ],
"_heat_v_1_rel" : [ SenseInfo('00371264-v', 11), SenseInfo('02333358-v', 0), SenseInfo('01761120-v', 0), SenseInfo('00372665-v', 0) ],
"_brim_v_with_rel" : [ SenseInfo('02715812-v', 0), SenseInfo('00182269-v', 0), SenseInfo('02715812-v', 0), SenseInfo('00182269-v', 0) ],
"_that_x_deg_rel" : [  ],
"_dashing_a_1_rel" : [ SenseInfo('02279622-a', 1), SenseInfo('00971933-a', 0) ],
"_northwesterly_a_1_rel" : [ SenseInfo('01602112-a', 0), SenseInfo('01601981-a', 0), SenseInfo('01602112-a', 0), SenseInfo('01601981-a', 0) ],
"_clot_v_1_rel" : [ SenseInfo('00457998-v', 1), SenseInfo('00458276-v', 0), SenseInfo('00457770-v', 0), SenseInfo('00368367-v', 0) ],
"_unplowed_a_1_rel" : [ SenseInfo('01833226-a', 1), SenseInfo('01833226-a', 1) ],
"_adverbal_a_1_rel" : [  ],
"_government_n_of_rel" : [ SenseInfo('08050678-n', 100), SenseInfo('01124794-n', 7), SenseInfo('05663671-n', 1), SenseInfo('06148148-n', 0) ],
"_check_v_through_rel" : [ SenseInfo('00661824-v', 27), SenseInfo('02533282-v', 7), SenseInfo('00662589-v', 6), SenseInfo('02510337-v', 5), SenseInfo('01861403-v', 1), SenseInfo('00662182-v', 1), SenseInfo('00440286-v', 1), SenseInfo('02658283-v', 0), SenseInfo('02657219-v', 0), SenseInfo('02557638-v', 0), SenseInfo('02553697-v', 0), SenseInfo('02347905-v', 0), SenseInfo('02347447-v', 0), SenseInfo('01861767-v', 0), SenseInfo('01861622-v', 0), SenseInfo('01692978-v', 0), SenseInfo('01139756-v', 0), SenseInfo('01131473-v', 0), SenseInfo('01114764-v', 0), SenseInfo('01064999-v', 0), SenseInfo('00920336-v', 0), SenseInfo('00663353-v', 0), SenseInfo('00354634-v', 0), SenseInfo('00336539-v', 0), SenseInfo('00336260-v', 0) ],
"_receiver_n_of_rel" : [ SenseInfo('04060647-n', 4), SenseInfo('10265532-n', 3), SenseInfo('04402580-n', 3), SenseInfo('09627906-n', 1), SenseInfo('10510974-n', 0), SenseInfo('10510818-n', 0) ],
"_de-energize_v_cause_rel" : [ SenseInfo('00023244-v', 0) ],
"_personnel_n_1_rel" : [ SenseInfo('08208016-n', 27), SenseInfo('08118991-n', 0) ],
"_burgeon_v_1_rel" : [ SenseInfo('00357854-v', 3) ],
"_haul_v_out_rel" : [ SenseInfo('01454810-v', 7), SenseInfo('01452255-v', 5) ],
"_lug_n_1_rel" : [ SenseInfo('09510305-n', 0), SenseInfo('03696568-n', 0), SenseInfo('03695616-n', 0), SenseInfo('01936671-n', 0) ],
"_hail_v_as_rel" : [ SenseInfo('00861725-v', 4), SenseInfo('02743214-v', 1), SenseInfo('00900499-v', 1), SenseInfo('00900376-v', 1), SenseInfo('02759115-v', 0), SenseInfo('00861725-v', 4), SenseInfo('02743214-v', 1), SenseInfo('00900499-v', 1), SenseInfo('00900376-v', 1), SenseInfo('02759115-v', 0) ],
"_thank_v_for_rel" : [ SenseInfo('00892315-v', 17) ],
"_triplet_a_1_rel" : [ SenseInfo('13744044-n', 0), SenseInfo('10729801-n', 0), SenseInfo('07986198-n', 0) ],
"_pssst_a_1_rel" : [  ],
"_shock_n_1_rel" : [ SenseInfo('07510625-n', 6), SenseInfo('01172252-n', 2), SenseInfo('00839292-n', 2), SenseInfo('14067076-n', 1), SenseInfo('07429276-n', 1), SenseInfo('07298982-n', 1), SenseInfo('07962707-n', 0), SenseInfo('07962500-n', 0), SenseInfo('07339098-n', 0), SenseInfo('04198797-n', 0) ],
"_reinstall_n_1_rel" : [  ],
"_handle_n_1_rel" : [ SenseInfo('03485997-n', 4) ],
"_handball_n_1_rel" : [ SenseInfo('03482877-n', 0), SenseInfo('00479440-n', 0) ],
"_phase_n_1_rel" : [ SenseInfo('15290337-n', 24), SenseInfo('14480065-n', 22), SenseInfo('15290132-n', 1), SenseInfo('04676540-n', 0) ],
"_burn_n_1_rel" : [ SenseInfo('14325437-n', 1), SenseInfo('14290534-n', 1), SenseInfo('14289590-n', 0), SenseInfo('04694090-n', 0), SenseInfo('00403911-n', 0) ],
"_handsome_a_1_rel" : [ SenseInfo('00218950-a', 7), SenseInfo('01111418-a', 3) ],
"_halfway_x_rel" : [ SenseInfo('00255415-r', 5), SenseInfo('00330506-a', 4), SenseInfo('01014838-a', 1), SenseInfo('00517710-a', 0) ],
"_gay_n_1_rel" : [ SenseInfo('10182913-n', 0) ],
"_blowhole_n_1_rel" : [ SenseInfo('05250420-n', 0), SenseInfo('04526241-n', 0) ],
"_connection_n_of_rel" : [ SenseInfo('13791389-n', 14), SenseInfo('14419164-n', 11), SenseInfo('03091374-n', 4), SenseInfo('09956147-n', 2), SenseInfo('05763916-n', 1), SenseInfo('13870805-n', 0), SenseInfo('09956035-n', 0), SenseInfo('00316989-n', 0), SenseInfo('00145218-n', 0) ],
"_unwarranted_a_1_rel" : [ SenseInfo('01722367-a', 1), SenseInfo('02353211-a', 0), SenseInfo('01945350-a', 0), SenseInfo('01722367-a', 1), SenseInfo('02353211-a', 0), SenseInfo('01945350-a', 0) ],
"_explain_v_1_rel" : [ SenseInfo('00939277-v', 109), SenseInfo('01065456-v', 9), SenseInfo('00893435-v', 7), SenseInfo('00939277-v', 109), SenseInfo('01065456-v', 9), SenseInfo('00893435-v', 7) ],
"_gamble_n_1_rel" : [ SenseInfo('13342987-n', 0), SenseInfo('00802962-n', 0), SenseInfo('13342987-n', 0), SenseInfo('00802962-n', 0) ],
"_discomfit_v_1_rel" : [ SenseInfo('01790020-v', 0) ],
"_sting_n_1_rel" : [ SenseInfo('14332085-n', 2), SenseInfo('14329762-n', 0), SenseInfo('14297870-n', 0), SenseInfo('00779248-n', 0) ],
"_fjord-side_a_1_rel" : [  ],
"_minstrel_n_1_rel" : [ SenseInfo('10099093-n', 1), SenseInfo('10321474-n', 0) ],
"_task_v_with_rel" : [ SenseInfo('02392600-v', 0), SenseInfo('01166237-v', 0), SenseInfo('02392600-v', 0), SenseInfo('01166237-v', 0), SenseInfo('02392600-v', 0), SenseInfo('01166237-v', 0) ],
"_water_v_down_rel" : [ SenseInfo('00228236-v', 3), SenseInfo('02357873-v', 2), SenseInfo('00069570-v', 2), SenseInfo('00452098-v', 0) ],
"_californian_a_1_rel" : [ SenseInfo('03052403-a', 0) ],
"_scatter_n_1_rel" : [ SenseInfo('05088324-n', 0), SenseInfo('00369138-n', 0), SenseInfo('05088324-n', 0), SenseInfo('00369138-n', 0) ],
"_interrogative_n_1_rel" : [ SenseInfo('07196682-n', 1), SenseInfo('13802485-n', 0) ],
"_incision_n_1_rel" : [ SenseInfo('13904843-n', 0), SenseInfo('00678010-n', 0) ],
"_taiwanese_n_1_rel" : [ SenseInfo('09733899-n', 0), SenseInfo('06930633-n', 0), SenseInfo('09733899-n', 0), SenseInfo('06930633-n', 0), SenseInfo('09733899-n', 0), SenseInfo('06930633-n', 0) ],
"_thud_v_1_rel" : [ SenseInfo('02184610-v', 1), SenseInfo('01238204-v', 1), SenseInfo('02184797-v', 0) ],
"_meg_n_of_rel" : [ SenseInfo('13751533-n', 0) ],
"_curve_v_1_rel" : [ SenseInfo('02033295-v', 2), SenseInfo('02738701-v', 1), SenseInfo('02034986-v', 1), SenseInfo('02034671-v', 0), SenseInfo('00362128-v', 0) ],
"_mate_n_1_rel" : [ SenseInfo('10300041-n', 4), SenseInfo('10695050-n', 2), SenseInfo('10300303-n', 2), SenseInfo('10640620-n', 1), SenseInfo('03728811-n', 1), SenseInfo('13743100-n', 0), SenseInfo('12757668-n', 0), SenseInfo('10300154-n', 0), SenseInfo('07926785-n', 0), SenseInfo('00167764-n', 0) ],
"_boast_v_of_rel" : [ SenseInfo('00883226-v', 7), SenseInfo('02631659-v', 6) ],
"_yankee-come-lately_n_1_rel" : [  ],
"_contact_n_1_rel" : [ SenseInfo('00039297-n', 29), SenseInfo('00124880-n', 4), SenseInfo('14419510-n', 2), SenseInfo('07339329-n', 2), SenseInfo('09960117-n', 1), SenseInfo('06261260-n', 1), SenseInfo('03093792-n', 1), SenseInfo('07279285-n', 0), SenseInfo('03094159-n', 0) ],
"_hail_v_1_rel" : [ SenseInfo('00861725-v', 4), SenseInfo('02743214-v', 1), SenseInfo('00900499-v', 1), SenseInfo('00900376-v', 1), SenseInfo('02759115-v', 0), SenseInfo('00861725-v', 4), SenseInfo('02743214-v', 1), SenseInfo('00900499-v', 1), SenseInfo('00900376-v', 1), SenseInfo('02759115-v', 0) ],
"_remand_n_1_rel" : [ SenseInfo('00328327-n', 0) ],
"_chiaroscuro_n_1_rel" : [ SenseInfo('03016056-n', 0) ],
"_roam_v_1_rel" : [ SenseInfo('01881180-v', 7) ],
"_mix_v_up_rel" : [ SenseInfo('00394813-v', 7), SenseInfo('02481900-v', 1), SenseInfo('00556193-v', 1), SenseInfo('00184117-v', 1), SenseInfo('01462005-v', 0), SenseInfo('01418667-v', 0) ],
"_gravitate_v_1_rel" : [ SenseInfo('02732148-v', 0), SenseInfo('02731996-v', 0), SenseInfo('01835280-v', 0) ],
"_neuron_n_1_rel" : [ SenseInfo('05465567-n', 0) ],
"_evaluation_n_of_rel" : [ SenseInfo('00874806-n', 8), SenseInfo('05736149-n', 3), SenseInfo('00874806-n', 8), SenseInfo('05736149-n', 3) ],
"_parody_n_1_rel" : [ SenseInfo('06780309-n', 2), SenseInfo('00549610-n', 0) ],
"_remember_v_from_rel" : [ SenseInfo('00607780-v', 106), SenseInfo('00609683-v', 53), SenseInfo('00611256-v', 23), SenseInfo('02356567-v', 2), SenseInfo('00882802-v', 0), SenseInfo('00882523-v', 0), SenseInfo('00611802-v', 0), SenseInfo('00611481-v', 0), SenseInfo('00607780-v', 106), SenseInfo('00609683-v', 53), SenseInfo('00611256-v', 23), SenseInfo('02356567-v', 2), SenseInfo('00882802-v', 0), SenseInfo('00882523-v', 0), SenseInfo('00611802-v', 0), SenseInfo('00611481-v', 0), SenseInfo('00607780-v', 106), SenseInfo('00609683-v', 53), SenseInfo('00611256-v', 23), SenseInfo('02356567-v', 2), SenseInfo('00882802-v', 0), SenseInfo('00882523-v', 0), SenseInfo('00611802-v', 0), SenseInfo('00611481-v', 0), SenseInfo('00607780-v', 106), SenseInfo('00609683-v', 53), SenseInfo('00611256-v', 23), SenseInfo('02356567-v', 2), SenseInfo('00882802-v', 0), SenseInfo('00882523-v', 0), SenseInfo('00611802-v', 0), SenseInfo('00611481-v', 0), SenseInfo('00607780-v', 106), SenseInfo('00609683-v', 53), SenseInfo('00611256-v', 23), SenseInfo('02356567-v', 2), SenseInfo('00882802-v', 0), SenseInfo('00882523-v', 0), SenseInfo('00611802-v', 0), SenseInfo('00611481-v', 0), SenseInfo('00607780-v', 106), SenseInfo('00609683-v', 53), SenseInfo('00611256-v', 23), SenseInfo('02356567-v', 2), SenseInfo('00882802-v', 0), SenseInfo('00882523-v', 0), SenseInfo('00611802-v', 0), SenseInfo('00611481-v', 0) ],
"_agitation_n_1_rel" : [ SenseInfo('14403107-n', 1), SenseInfo('13979503-n', 0), SenseInfo('07513508-n', 0), SenseInfo('00554300-n', 0), SenseInfo('00333366-n', 0) ],
"_safeguard_n_1_rel" : [ SenseInfo('00822970-n', 1), SenseInfo('06691267-n', 0) ],
"_so+that_x_rel" : [  ],
"_counter-attack_v_1_rel" : [ SenseInfo('01125084-v', 1) ],
"_damn_n_1_rel" : [ SenseInfo('05140793-n', 1) ],
"_threaten_v_with_rel" : [ SenseInfo('02697120-v', 23), SenseInfo('00871405-v', 21), SenseInfo('00871781-v', 10) ],
"_solar_n_1_rel" : [ SenseInfo('02799016-a', 4) ],
"_juggle_v_1_rel" : [ SenseInfo('02578235-v', 0), SenseInfo('02577391-v', 0), SenseInfo('02438383-v', 0), SenseInfo('01604814-v', 0), SenseInfo('01602527-v', 0) ],
"_confident_a_1_rel" : [ SenseInfo('00338817-a', 7), SenseInfo('00337172-a', 0), SenseInfo('00306909-a', 0) ],
"_sportif_n_1_rel" : [  ],
"_face-up_a_1_rel" : [  ],
"_per_a_1_rel" : [  ],
"_twig_v_1_rel" : [ SenseInfo('00329654-v', 1), SenseInfo('00590366-v', 0), SenseInfo('00329654-v', 1), SenseInfo('00590366-v', 0) ],
"_login_v_1_rel" : [  ],
"_disgust_n_1_rel" : [ SenseInfo('07503260-n', 1) ],
"_nagging_n_1_rel" : [ SenseInfo('01138610-a', 1) ],
"_goodness_a_1_rel" : [ SenseInfo('05142180-n', 7), SenseInfo('04849241-n', 0) ],
"_surname_v_1_rel" : [  ],
"_logistics_n_of_rel" : [ SenseInfo('01060745-n', 1) ],
"_fish_n_1_rel" : [ SenseInfo('02512053-n', 12), SenseInfo('07775375-n', 3), SenseInfo('09753792-n', 1), SenseInfo('08688076-n', 0) ],
"_lead_n_1_rel" : [ SenseInfo('05157143-n', 7), SenseInfo('14643467-n', 6), SenseInfo('05826914-n', 3), SenseInfo('01256743-n', 3), SenseInfo('13893129-n', 1), SenseInfo('06270879-n', 1), SenseInfo('13596422-n', 0), SenseInfo('10648696-n', 0), SenseInfo('08592165-n', 0), SenseInfo('06651577-n', 0), SenseInfo('06271192-n', 0), SenseInfo('05051088-n', 0), SenseInfo('03652932-n', 0), SenseInfo('03651265-n', 0), SenseInfo('03651084-n', 0), SenseInfo('03604843-n', 0), SenseInfo('01256270-n', 0) ],
"_legacy_n_1_rel" : [ SenseInfo('13263779-n', 1) ],
"_ordination_n_of_rel" : [ SenseInfo('14432167-n', 0), SenseInfo('08456993-n', 0), SenseInfo('00165298-n', 0) ],
"_philippine_a_1_rel" : [ SenseInfo('03066180-a', 0) ],
"_downstream_p_rel" : [ SenseInfo('00097231-r', 1), SenseInfo('02494499-a', 0), SenseInfo('00097231-r', 1), SenseInfo('02494499-a', 0) ],
"_rosette_n_1_rel" : [ SenseInfo('04109899-n', 1), SenseInfo('14281549-n', 0), SenseInfo('13161998-n', 0), SenseInfo('04110178-n', 0) ],
"_awestruck_a_by_rel" : [ SenseInfo('02014715-a', 3) ],
"_excuse_n_1_rel" : [ SenseInfo('06741305-n', 10), SenseInfo('06626446-n', 0), SenseInfo('05821102-n', 0), SenseInfo('06741305-n', 10), SenseInfo('06626446-n', 0), SenseInfo('05821102-n', 0), SenseInfo('06741305-n', 10), SenseInfo('06626446-n', 0), SenseInfo('05821102-n', 0) ],
"_crisp_v_up_rel" : [ SenseInfo('01278427-v', 0), SenseInfo('00322151-v', 0) ],
"_put_v_aside_rel" : [ SenseInfo('01494310-v', 138), SenseInfo('01493741-v', 98), SenseInfo('00981276-v', 28), SenseInfo('01160370-v', 6), SenseInfo('02271137-v', 3), SenseInfo('00673448-v', 2), SenseInfo('02111499-v', 0), SenseInfo('01706375-v', 0), SenseInfo('00735571-v', 0) ],
"_referee_n_1_rel" : [ SenseInfo('10514429-n', 1), SenseInfo('10526927-n', 0), SenseInfo('10514643-n', 0) ],
"_cholera_n_1_rel" : [ SenseInfo('14129579-n', 0) ],
"_unbounded_a_1_rel" : [ SenseInfo('01007657-a', 1), SenseInfo('01007657-a', 1) ],
"_imagine_v_1_rel" : [ SenseInfo('01636397-v', 66), SenseInfo('00631737-v', 11), SenseInfo('01636397-v', 66), SenseInfo('00631737-v', 11), SenseInfo('01636397-v', 66), SenseInfo('00631737-v', 11), SenseInfo('01636397-v', 66), SenseInfo('00631737-v', 11), SenseInfo('01636397-v', 66), SenseInfo('00631737-v', 11) ],
"_areaway_n_1_rel" : [ SenseInfo('02736396-n', 1) ],
"_shed_v_1_rel" : [ SenseInfo('01513430-v', 5), SenseInfo('01541803-v', 3), SenseInfo('01541579-v', 0), SenseInfo('00009147-v', 0) ],
"_relieve_v_of_rel" : [ SenseInfo('00064095-v', 9), SenseInfo('02412175-v', 4), SenseInfo('02564146-v', 2), SenseInfo('01815185-v', 2), SenseInfo('02550868-v', 1), SenseInfo('00936648-v', 1), SenseInfo('00082563-v', 1), SenseInfo('02312996-v', 0), SenseInfo('02312882-v', 0), SenseInfo('00893878-v', 0), SenseInfo('00199067-v', 0) ],
"_northwest_n_of_rel" : [ SenseInfo('08564139-n', 1), SenseInfo('13836253-n', 0), SenseInfo('13834885-n', 0), SenseInfo('08561946-n', 0), SenseInfo('08564139-n', 1), SenseInfo('13836253-n', 0), SenseInfo('13834885-n', 0), SenseInfo('08561946-n', 0), SenseInfo('08564139-n', 1), SenseInfo('13836253-n', 0), SenseInfo('13834885-n', 0), SenseInfo('08561946-n', 0), SenseInfo('08564139-n', 1), SenseInfo('13836253-n', 0), SenseInfo('13834885-n', 0), SenseInfo('08561946-n', 0), SenseInfo('08564139-n', 1), SenseInfo('13836253-n', 0), SenseInfo('13834885-n', 0), SenseInfo('08561946-n', 0), SenseInfo('08564139-n', 1), SenseInfo('13836253-n', 0), SenseInfo('13834885-n', 0), SenseInfo('08561946-n', 0), SenseInfo('08564139-n', 1), SenseInfo('13836253-n', 0), SenseInfo('13834885-n', 0), SenseInfo('08561946-n', 0) ],
"_trim_v_down_rel" : [ SenseInfo('01262564-v', 8), SenseInfo('01679806-v', 1), SenseInfo('00429060-v', 1), SenseInfo('02752107-v', 0), SenseInfo('02751952-v', 0), SenseInfo('01679433-v', 0), SenseInfo('01321002-v', 0), SenseInfo('01248782-v', 0), SenseInfo('00297193-v', 0) ],
"_lock_n_1_rel" : [ SenseInfo('03682487-n', 6), SenseInfo('05257737-n', 2), SenseInfo('03683341-n', 1), SenseInfo('03683079-n', 0), SenseInfo('03682877-n', 0), SenseInfo('00814458-n', 0) ],
"_whiff_v_1_rel" : [ SenseInfo('02125032-v', 0), SenseInfo('02100861-v', 0), SenseInfo('01409888-v', 0), SenseInfo('01198616-v', 0), SenseInfo('00943436-v', 0) ],
"_tired_a_of_rel" : [ SenseInfo('02431728-a', 9), SenseInfo('01688757-a', 0) ],
"_woolly_a_1_rel" : [ SenseInfo('01154351-a', 1), SenseInfo('00436115-a', 1), SenseInfo('00216668-a', 0), SenseInfo('00214640-a', 0), SenseInfo('01154351-a', 1), SenseInfo('00436115-a', 1), SenseInfo('00216668-a', 0), SenseInfo('00214640-a', 0), SenseInfo('01154351-a', 1), SenseInfo('00436115-a', 1), SenseInfo('00216668-a', 0), SenseInfo('00214640-a', 0) ],
"_ambiguity_n_1_rel" : [ SenseInfo('06604319-n', 6), SenseInfo('04825114-n', 1) ],
"_leave_v_to_rel" : [ SenseInfo('02009433-v', 146), SenseInfo('00613683-v', 63), SenseInfo('02729414-v', 56), SenseInfo('00136991-v', 27), SenseInfo('02015598-v', 20), SenseInfo('02721438-v', 19), SenseInfo('02635659-v', 16), SenseInfo('02383440-v', 14), SenseInfo('02356230-v', 8), SenseInfo('02229055-v', 7), SenseInfo('02730135-v', 5), SenseInfo('00360092-v', 5), SenseInfo('02296153-v', 3), SenseInfo('00613018-v', 3) ],
"_reparation_n_1_rel" : [ SenseInfo('13292613-n', 0), SenseInfo('13292390-n', 0), SenseInfo('00266806-n', 0), SenseInfo('00095329-n', 0) ],
"_diaeresis_n_1_rel" : [ SenseInfo('06823760-n', 0) ],
"_anymore_a_1_rel" : [  ],
"_solidity_n_1_rel" : [ SenseInfo('04941124-n', 2), SenseInfo('14452442-n', 0), SenseInfo('04671075-n', 0) ],
"_discourage_v_1_rel" : [ SenseInfo('00908099-v', 12), SenseInfo('01819147-v', 3), SenseInfo('00870577-v', 2), SenseInfo('00908099-v', 12), SenseInfo('01819147-v', 3), SenseInfo('00870577-v', 2), SenseInfo('00908099-v', 12), SenseInfo('01819147-v', 3), SenseInfo('00870577-v', 2), SenseInfo('00908099-v', 12), SenseInfo('01819147-v', 3), SenseInfo('00870577-v', 2), SenseInfo('00908099-v', 12), SenseInfo('01819147-v', 3), SenseInfo('00870577-v', 2) ],
"_liberate_v_for_rel" : [ SenseInfo('02497400-v', 2), SenseInfo('02421374-v', 1), SenseInfo('02497062-v', 0), SenseInfo('01757994-v', 0), SenseInfo('02497400-v', 2), SenseInfo('02421374-v', 1), SenseInfo('02497062-v', 0), SenseInfo('01757994-v', 0) ],
"_car+pool_n_1_rel" : [ SenseInfo('08240484-n', 0) ],
"_lane_n_1_rel" : [ SenseInfo('03640589-n', 4), SenseInfo('03640660-n', 1) ],
"_festivity_n_1_rel" : [ SenseInfo('00428000-n', 3) ],
"_throw_v_away_rel" : [ SenseInfo('01508368-v', 53), SenseInfo('02097204-v', 9), SenseInfo('01513430-v', 7), SenseInfo('01499265-v', 7), SenseInfo('01060317-v', 6), SenseInfo('01510173-v', 5), SenseInfo('01632897-v', 4), SenseInfo('02097341-v', 2), SenseInfo('01791232-v', 2), SenseInfo('01067664-v', 2), SenseInfo('01733477-v', 1), SenseInfo('01663443-v', 0), SenseInfo('01527754-v', 0), SenseInfo('01437011-v', 0), SenseInfo('00621734-v', 0) ],
"_relation_n_of_rel" : [ SenseInfo('00031921-n', 23), SenseInfo('00845523-n', 2), SenseInfo('10235549-n', 0), SenseInfo('07222823-n', 0), SenseInfo('05957428-n', 0), SenseInfo('00040962-n', 0) ],
"_grim_a_1_rel" : [ SenseInfo('01785341-a', 8), SenseInfo('00195684-a', 7), SenseInfo('02079507-a', 3), SenseInfo('01802932-a', 1), SenseInfo('00703615-a', 0), SenseInfo('00364881-a', 0), SenseInfo('01785341-a', 8), SenseInfo('00195684-a', 7), SenseInfo('02079507-a', 3), SenseInfo('01802932-a', 1), SenseInfo('00703615-a', 0), SenseInfo('00364881-a', 0), SenseInfo('01785341-a', 8), SenseInfo('00195684-a', 7), SenseInfo('02079507-a', 3), SenseInfo('01802932-a', 1), SenseInfo('00703615-a', 0), SenseInfo('00364881-a', 0), SenseInfo('01785341-a', 8), SenseInfo('00195684-a', 7), SenseInfo('02079507-a', 3), SenseInfo('01802932-a', 1), SenseInfo('00703615-a', 0), SenseInfo('00364881-a', 0) ],
"_quash_v_1_rel" : [ SenseInfo('02424128-v', 1), SenseInfo('02478059-v', 0) ],
"_luck_n_1_rel" : [ SenseInfo('14473222-n', 8), SenseInfo('11418138-n', 6), SenseInfo('11418460-n', 2) ],
"_point_v_to_rel" : [ SenseInfo('00923793-v', 25), SenseInfo('02713184-v', 8), SenseInfo('01152214-v', 8), SenseInfo('01931768-v', 5), SenseInfo('00921300-v', 1), SenseInfo('01928154-v', 0), SenseInfo('01589363-v', 0), SenseInfo('01589224-v', 0), SenseInfo('01589056-v', 0), SenseInfo('01152670-v', 0), SenseInfo('01150559-v', 0), SenseInfo('00924255-v', 0), SenseInfo('00392960-v', 0), SenseInfo('00261957-v', 0) ],
"_blare_v_1_rel" : [ SenseInfo('02182479-v', 1), SenseInfo('02183175-v', 0) ],
"_tuna_n_1_rel" : [ SenseInfo('11852148-n', 0), SenseInfo('07780627-n', 0), SenseInfo('02626762-n', 0), SenseInfo('02527057-n', 0) ],
"_unripe_a_1_rel" : [ SenseInfo('01493897-a', 0), SenseInfo('01932902-a', 0), SenseInfo('01493897-a', 0), SenseInfo('01932902-a', 0) ],
"_mid+thigh_n_1_rel" : [  ],
"_ambassador_n_1_rel" : [ SenseInfo('09787534-n', 7), SenseInfo('09787765-n', 0) ],
"_contaminate_v_1_rel" : [ SenseInfo('00492706-v', 4), SenseInfo('00493259-v', 1) ],
"_mercury_n_1_rel" : [ SenseInfo('14645346-n', 6), SenseInfo('09562704-n', 0), SenseInfo('09351408-n', 0), SenseInfo('05014308-n', 0) ],
"_extrude_v_1_rel" : [ SenseInfo('01675780-v', 1) ],
"_luxuriant_a_1_rel" : [ SenseInfo('01795933-a', 0), SenseInfo('01298239-a', 0), SenseInfo('00015247-a', 0) ],
"_cap_n_1_rel" : [ SenseInfo('02954340-n', 10), SenseInfo('02954938-n', 2), SenseInfo('03182232-n', 1), SenseInfo('02955065-n', 1), SenseInfo('11532351-n', 0), SenseInfo('09305358-n', 0), SenseInfo('06657646-n', 0), SenseInfo('03139089-n', 0), SenseInfo('02956247-n', 0) ],
"_advocate_v_as_rel" : [ SenseInfo('00875141-v', 9), SenseInfo('00827730-v', 1), SenseInfo('00875141-v', 9), SenseInfo('00827730-v', 1) ],
"_arid_a_1_rel" : [ SenseInfo('02552415-a', 0), SenseInfo('00806991-a', 0) ],
"_icon_n_1_rel" : [ SenseInfo('07269916-n', 0), SenseInfo('03931044-n', 0), SenseInfo('03558971-n', 0) ],
"_set_v_apart_rel" : [ SenseInfo('01494310-v', 30), SenseInfo('00699815-v', 29), SenseInfo('00947077-v', 12), SenseInfo('01062395-v', 10), SenseInfo('00298896-v', 9), SenseInfo('01607445-v', 6), SenseInfo('00406243-v', 5), SenseInfo('00298556-v', 5), SenseInfo('01711749-v', 3), SenseInfo('01970646-v', 2), SenseInfo('01706129-v', 2), SenseInfo('01567275-v', 2), SenseInfo('01628899-v', 1), SenseInfo('00442669-v', 1), SenseInfo('01744888-v', 0), SenseInfo('01613239-v', 0), SenseInfo('01530273-v', 0), SenseInfo('01247322-v', 0), SenseInfo('01115006-v', 0), SenseInfo('00673448-v', 0), SenseInfo('00408085-v', 0), SenseInfo('00407848-v', 0), SenseInfo('00296178-v', 0), SenseInfo('00056188-v', 0), SenseInfo('00038849-v', 0) ],
"_behavior_n_1_rel" : [ SenseInfo('01220984-n', 30), SenseInfo('14008342-n', 8), SenseInfo('04897762-n', 8), SenseInfo('01221254-n', 0), SenseInfo('01220984-n', 30), SenseInfo('14008342-n', 8), SenseInfo('04897762-n', 8), SenseInfo('01221254-n', 0) ],
"_narrative_a_1_rel" : [ SenseInfo('00498912-a', 1) ],
"_notify_v_of_rel" : [ SenseInfo('00873682-v', 10), SenseInfo('00873682-v', 10) ],
"_aside_p_sel_rel" : [ SenseInfo('00233892-r', 7), SenseInfo('00234052-r', 5), SenseInfo('00180756-r', 4), SenseInfo('07011075-n', 0), SenseInfo('06600684-n', 0), SenseInfo('00234951-r', 0), SenseInfo('00234201-r', 0), SenseInfo('00233687-r', 0) ],
"_islamic_a_1_rel" : [ SenseInfo('02923510-a', 0) ],
"_pull_v_out-of_rel" : [ SenseInfo('01448100-v', 44), SenseInfo('01505254-v', 8), SenseInfo('02057499-v', 6), SenseInfo('01609287-v', 3), SenseInfo('02582615-v', 2), SenseInfo('01995211-v', 2), SenseInfo('02057337-v', 1), SenseInfo('00071803-v', 1), SenseInfo('02103162-v', 0), SenseInfo('01947247-v', 0), SenseInfo('01858573-v', 0), SenseInfo('01573276-v', 0), SenseInfo('01407059-v', 0), SenseInfo('01384275-v', 0), SenseInfo('01351170-v', 0), SenseInfo('01148710-v', 0), SenseInfo('00571596-v', 0) ],
"_gigabyte_n_of_rel" : [ SenseInfo('13628955-n', 0), SenseInfo('13628761-n', 0), SenseInfo('13628955-n', 0), SenseInfo('13628761-n', 0), SenseInfo('13628955-n', 0), SenseInfo('13628761-n', 0) ],
"_track_v_down_rel" : [ SenseInfo('02078453-v', 2), SenseInfo('02197629-v', 1), SenseInfo('02001858-v', 1), SenseInfo('01912159-v', 0), SenseInfo('01618468-v', 0) ],
"_conclave_n_1_rel" : [ SenseInfo('08308410-n', 1) ],
"_garth_n_1_rel" : [  ],
"_favor_n_1_rel" : [ SenseInfo('01226941-n', 12), SenseInfo('05156319-n', 5), SenseInfo('06200617-n', 1), SenseInfo('07500414-n', 0), SenseInfo('03894762-n', 0), SenseInfo('01226941-n', 12), SenseInfo('05156319-n', 5), SenseInfo('06200617-n', 1), SenseInfo('07500414-n', 0), SenseInfo('03894762-n', 0), SenseInfo('01226941-n', 12), SenseInfo('05156319-n', 5), SenseInfo('06200617-n', 1), SenseInfo('07500414-n', 0), SenseInfo('03894762-n', 0), SenseInfo('01226941-n', 12), SenseInfo('05156319-n', 5), SenseInfo('06200617-n', 1), SenseInfo('07500414-n', 0), SenseInfo('03894762-n', 0) ],
"_dither_v_1_rel" : [ SenseInfo('01820189-v', 0), SenseInfo('01819911-v', 0) ],
"_needle_n_1_rel" : [ SenseInfo('13157595-n', 2), SenseInfo('03816394-n', 2), SenseInfo('03816136-n', 1), SenseInfo('03923918-n', 0) ],
"_forward_p_sel_rel" : [ SenseInfo('00074641-r', 53), SenseInfo('00203237-a', 8), SenseInfo('00103859-r', 5), SenseInfo('00075442-r', 3), SenseInfo('00067265-r', 3), SenseInfo('01955508-v', 3), SenseInfo('00204491-a', 0), SenseInfo('00203774-a', 0), SenseInfo('10105733-n', 0), SenseInfo('00725383-n', 0), SenseInfo('00275694-r', 0), SenseInfo('01876555-a', 0) ],
"_peach_n_1_rel" : [ SenseInfo('12648045-n', 0), SenseInfo('10613996-n', 0), SenseInfo('07751004-n', 0), SenseInfo('04971675-n', 0) ],
"_tenfold_a_1_rel" : [ SenseInfo('02220207-a', 0), SenseInfo('02220207-a', 0) ],
"_turn_n_of_rel" : [ SenseInfo('13869327-n', 7), SenseInfo('00350030-n', 6), SenseInfo('00457382-n', 4), SenseInfo('07423365-n', 2), SenseInfo('07351612-n', 1), SenseInfo('00346532-n', 1), SenseInfo('00345454-n', 1), SenseInfo('15292069-n', 0), SenseInfo('15256714-n', 0), SenseInfo('06892016-n', 0), SenseInfo('01227083-n', 0), SenseInfo('00292599-n', 0), SenseInfo('13869327-n', 7), SenseInfo('00350030-n', 6), SenseInfo('00457382-n', 4), SenseInfo('07423365-n', 2), SenseInfo('07351612-n', 1), SenseInfo('00346532-n', 1), SenseInfo('00345454-n', 1), SenseInfo('15292069-n', 0), SenseInfo('15256714-n', 0), SenseInfo('06892016-n', 0), SenseInfo('01227083-n', 0), SenseInfo('00292599-n', 0), SenseInfo('13869327-n', 7), SenseInfo('00350030-n', 6), SenseInfo('00457382-n', 4), SenseInfo('07423365-n', 2), SenseInfo('07351612-n', 1), SenseInfo('00346532-n', 1), SenseInfo('00345454-n', 1), SenseInfo('15292069-n', 0), SenseInfo('15256714-n', 0), SenseInfo('06892016-n', 0), SenseInfo('01227083-n', 0), SenseInfo('00292599-n', 0) ],
"_corgi_n_1_rel" : [ SenseInfo('02112826-n', 0) ],
"_flicker_n_1_rel" : [ SenseInfo('07412310-n', 0), SenseInfo('01839598-n', 0), SenseInfo('00348571-n', 0) ],
"_fully_x_deg_rel" : [ SenseInfo('00010466-r', 29), SenseInfo('00178909-r', 2), SenseInfo('00504620-r', 1) ],
"_tobacco_n_1_rel" : [ SenseInfo('04442831-n', 4), SenseInfo('12907465-n', 0) ],
"_erosion_n_1_rel" : [ SenseInfo('13475538-n', 1), SenseInfo('14518924-n', 0), SenseInfo('13475944-n', 0), SenseInfo('13453428-n', 0) ],
"_allure_v_1_rel" : [ SenseInfo('00793785-v', 0) ],
"_flick_v_off_rel" : [ SenseInfo('02160177-v', 1), SenseInfo('02153023-v', 1), SenseInfo('01893465-v', 1), SenseInfo('01591158-v', 1), SenseInfo('02763609-v', 0), SenseInfo('01591357-v', 0), SenseInfo('01242208-v', 0), SenseInfo('01242071-v', 0), SenseInfo('00190586-v', 0), SenseInfo('02160177-v', 1), SenseInfo('02153023-v', 1), SenseInfo('01893465-v', 1), SenseInfo('01591158-v', 1), SenseInfo('02763609-v', 0), SenseInfo('01591357-v', 0), SenseInfo('01242208-v', 0), SenseInfo('01242071-v', 0), SenseInfo('00190586-v', 0) ],
"_spoon_n_1_rel" : [ SenseInfo('04284002-n', 1), SenseInfo('13770169-n', 0), SenseInfo('04284341-n', 0) ],
"_pretty+much_a_1_rel" : [  ],
"_♡_v_1_rel" : [  ],
"_crossbeam_n_1_rel" : [ SenseInfo('04475496-n', 0) ],
"_institutional_a_1_rel" : [ SenseInfo('02749778-a', 3), SenseInfo('01231191-a', 0) ],
"_still_x_deg_rel" : [ SenseInfo('00031304-r', 233), SenseInfo('00027384-r', 51), SenseInfo('00017639-r', 26), SenseInfo('01564315-a', 16), SenseInfo('01919428-a', 9), SenseInfo('00467269-r', 3), SenseInfo('00302951-a', 3), SenseInfo('01565751-a', 2), SenseInfo('04319248-n', 2), SenseInfo('01764800-v', 1), SenseInfo('00461493-v', 1), SenseInfo('02277485-a', 0), SenseInfo('04982478-n', 0), SenseInfo('04318982-n', 0), SenseInfo('03212811-n', 0), SenseInfo('01241600-a', 0), SenseInfo('01815185-v', 0), SenseInfo('00583905-v', 0) ],
"_stellate_a_1_rel" : [ SenseInfo('02373055-a', 0) ],
"_politics_n_1_rel" : [ SenseInfo('13840719-n', 21), SenseInfo('06148148-n', 4), SenseInfo('00611972-n', 3), SenseInfo('06149192-n', 1), SenseInfo('01124508-n', 0), SenseInfo('13840719-n', 21), SenseInfo('06148148-n', 4), SenseInfo('00611972-n', 3), SenseInfo('06149192-n', 1), SenseInfo('01124508-n', 0) ],
"_plant_v_out_rel" : [ SenseInfo('01567275-v', 8), SenseInfo('01528821-v', 2), SenseInfo('01647229-v', 1), SenseInfo('02322810-v', 0), SenseInfo('01371201-v', 0), SenseInfo('00734790-v', 0) ],
"_remains_n_1_rel" : [ SenseInfo('09407346-n', 1), SenseInfo('05218119-n', 0), SenseInfo('09407346-n', 1), SenseInfo('05218119-n', 0) ],
"_shop_v_around_rel" : [ SenseInfo('02325968-v', 7), SenseInfo('02466134-v', 1), SenseInfo('02326355-v', 0), SenseInfo('00841986-v', 0), SenseInfo('02325968-v', 7), SenseInfo('02466134-v', 1), SenseInfo('02326355-v', 0), SenseInfo('00841986-v', 0) ],
"_heck_a_1_rel" : [  ],
"_elegance_n_1_rel" : [ SenseInfo('04812268-n', 3), SenseInfo('04812636-n', 0) ],
"_cuff_n_1_rel" : [ SenseInfo('03145843-n', 1), SenseInfo('03484576-n', 0) ],
"_abject_a_1_rel" : [ SenseInfo('00904745-a', 3), SenseInfo('01049941-a', 1), SenseInfo('01229435-a', 0), SenseInfo('00789281-a', 0), SenseInfo('00904745-a', 3), SenseInfo('01049941-a', 1), SenseInfo('01229435-a', 0), SenseInfo('00789281-a', 0) ],
"_abundant_a_1_rel" : [ SenseInfo('00013887-a', 1), SenseInfo('00013887-a', 1) ],
"_receivable_n_1_rel" : [ SenseInfo('00137277-a', 0) ],
"_silver_n_1_rel" : [ SenseInfo('14654954-n', 2), SenseInfo('13371866-n', 2), SenseInfo('04962062-n', 2), SenseInfo('03361837-n', 1), SenseInfo('04220523-n', 0) ],
"_busywork_n_1_rel" : [ SenseInfo('00581621-n', 0) ],
"_slam_v_down_rel" : [ SenseInfo('01242832-v', 8), SenseInfo('01242391-v', 8), SenseInfo('01897885-v', 0), SenseInfo('01242689-v', 0) ],
"_low_a_1_rel" : [ SenseInfo('01212469-a', 55), SenseInfo('01206474-a', 23), SenseInfo('01455888-a', 11), SenseInfo('01951008-a', 6), SenseInfo('01215421-a', 4), SenseInfo('00904745-a', 3), SenseInfo('02340458-a', 0), SenseInfo('02336759-a', 0), SenseInfo('01893303-a', 0), SenseInfo('00703615-a', 0), SenseInfo('01212469-a', 55), SenseInfo('01206474-a', 23), SenseInfo('01455888-a', 11), SenseInfo('01951008-a', 6), SenseInfo('01215421-a', 4), SenseInfo('00904745-a', 3), SenseInfo('02340458-a', 0), SenseInfo('02336759-a', 0), SenseInfo('01893303-a', 0), SenseInfo('00703615-a', 0), SenseInfo('01212469-a', 55), SenseInfo('01206474-a', 23), SenseInfo('01455888-a', 11), SenseInfo('01951008-a', 6), SenseInfo('01215421-a', 4), SenseInfo('00904745-a', 3), SenseInfo('02340458-a', 0), SenseInfo('02336759-a', 0), SenseInfo('01893303-a', 0), SenseInfo('00703615-a', 0) ],
"_conclude_v_1_rel" : [ SenseInfo('00634472-v', 33), SenseInfo('00715074-v', 9), SenseInfo('01021420-v', 1), SenseInfo('02610628-v', 0), SenseInfo('01071762-v', 0), SenseInfo('00634472-v', 33), SenseInfo('00715074-v', 9), SenseInfo('01021420-v', 1), SenseInfo('02610628-v', 0), SenseInfo('01071762-v', 0) ],
"_hypothetical_a_1_rel" : [ SenseInfo('00861216-a', 3) ],
"_drain_v_1_rel" : [ SenseInfo('02071457-v', 2), SenseInfo('01158022-v', 1), SenseInfo('00451648-v', 1), SenseInfo('00389638-v', 0) ],
"_birch_n_1_rel" : [ SenseInfo('12281600-n', 0), SenseInfo('12281241-n', 0), SenseInfo('02842809-n', 0) ],
"_preside_v_1_rel" : [ SenseInfo('02443609-v', 3) ],
"_harm_v_1_rel" : [ SenseInfo('00102586-v', 3) ],
"_pine_v_for_rel" : [ SenseInfo('01805684-v', 0) ],
"_enclosure_n_1_rel" : [ SenseInfo('03285912-n', 2), SenseInfo('00321956-n', 1), SenseInfo('09273291-n', 0), SenseInfo('06473381-n', 0) ],
"_subdivide_v_1_rel" : [ SenseInfo('00333277-v', 0), SenseInfo('00333066-v', 0) ],
"_ballot_n_1_rel" : [ SenseInfo('06470922-n', 3), SenseInfo('00183505-n', 1) ],
"_placing_n_1_rel" : [  ],
"_fill_v_up_rel" : [ SenseInfo('00452512-v', 61), SenseInfo('00451838-v', 12), SenseInfo('02649042-v', 8), SenseInfo('02394183-v', 5), SenseInfo('01183573-v', 5), SenseInfo('02394081-v', 1), SenseInfo('01203893-v', 1), SenseInfo('01193721-v', 1), SenseInfo('00261533-v', 1), SenseInfo('00452512-v', 61), SenseInfo('00451838-v', 12), SenseInfo('02649042-v', 8), SenseInfo('02394183-v', 5), SenseInfo('01183573-v', 5), SenseInfo('02394081-v', 1), SenseInfo('01203893-v', 1), SenseInfo('01193721-v', 1), SenseInfo('00261533-v', 1) ],
"_overspread_v_1_rel" : [ SenseInfo('02689299-v', 0), SenseInfo('02689299-v', 0) ],
"_tower_v_1_rel" : [ SenseInfo('02696503-v', 2) ],
"_vx_n_1_rel" : [  ],
"_tenement_n_1_rel" : [ SenseInfo('04409384-n', 4) ],
"_cursive_n_1_rel" : [ SenseInfo('06350274-n', 0) ],
"_above+all_a_1_rel" : [  ],
"_changeable_a_1_rel" : [ SenseInfo('00356339-a', 0), SenseInfo('00344125-a', 0), SenseInfo('02504558-a', 0), SenseInfo('00403072-a', 0) ],
"_disprove_v_to_rel" : [ SenseInfo('00667424-v', 1), SenseInfo('00667424-v', 1), SenseInfo('00667424-v', 1), SenseInfo('00667424-v', 1) ],
"_disdain_v_from_rel" : [ SenseInfo('01774799-v', 2), SenseInfo('00796976-v', 1), SenseInfo('01774799-v', 2), SenseInfo('00796976-v', 1) ],
"_lobby_v_1_rel" : [ SenseInfo('02458943-v', 1), SenseInfo('02458943-v', 1), SenseInfo('02458943-v', 1) ],
"_zooid_n_1_rel" : [ SenseInfo('01416213-n', 0) ],
"_wrack_v_1_rel" : [ SenseInfo('01566185-v', 1) ],
"_algorithm_n_1_rel" : [ SenseInfo('05847438-n', 0) ],
"_whack_v_at_rel" : [ SenseInfo('01415807-v', 2) ],
"_gross_v_1_rel" : [ SenseInfo('02291434-v', 0) ],
"_sick_n_1_rel" : [ SenseInfo('07950418-n', 1) ],
"_hard+disk_n_1_rel" : [ SenseInfo('03492542-n', 0) ],
"_expectation_n_of_rel" : [ SenseInfo('05944958-n', 5), SenseInfo('14486122-n', 4), SenseInfo('07510923-n', 0), SenseInfo('06024230-n', 0), SenseInfo('05944958-n', 5), SenseInfo('14486122-n', 4), SenseInfo('07510923-n', 0), SenseInfo('06024230-n', 0) ],
"_null_a_1_rel" : [ SenseInfo('02500590-a', 1) ],
"_forthcoming_a_1_rel" : [ SenseInfo('02258249-a', 0), SenseInfo('01732601-a', 0), SenseInfo('00184229-a', 0) ],
"_debit_n_1_rel" : [ SenseInfo('13405807-n', 0) ],
"_wag_n_1_rel" : [ SenseInfo('10762342-n', 1), SenseInfo('00347652-n', 0) ],
"_remote_n_1_rel" : [ SenseInfo('04074963-n', 0) ],
"_secrecy_n_1_rel" : [ SenseInfo('04652177-n', 2), SenseInfo('14416089-n', 1) ],
"_bicycle_v_1_rel" : [ SenseInfo('01935476-v', 0) ],
"_dishearten_v_1_rel" : [ SenseInfo('01819387-v', 2), SenseInfo('01819387-v', 2), SenseInfo('01819387-v', 2), SenseInfo('01819387-v', 2), SenseInfo('01819387-v', 2) ],
"_damage_v_to_rel" : [ SenseInfo('00258857-v', 12), SenseInfo('00588084-v', 0) ],
"_UK_n_1_rel" : [ SenseInfo('08860123-n', 0) ],
"_dial_n_1_rel" : [ SenseInfo('03186696-n', 1), SenseInfo('03187153-n', 0), SenseInfo('03187037-n', 0), SenseInfo('03186818-n', 0) ],
"_auction_v_1_rel" : [ SenseInfo('02244773-v', 0) ],
"_drench_v_1_rel" : [ SenseInfo('02771564-v', 0), SenseInfo('01169589-v', 0), SenseInfo('00498163-v', 0), SenseInfo('00216216-v', 0) ],
"_scalp_n_1_rel" : [ SenseInfo('05539947-n', 1) ],
"_too_a_also_rel" : [  ],
"_ward_v_1_rel" : [ SenseInfo('01129337-v', 0) ],
"_static_a_1_rel" : [ SenseInfo('01564315-a', 1), SenseInfo('02719009-a', 0), SenseInfo('00348018-a', 0) ],
"_nonogenarian_n_1_rel" : [  ],
"_exceeding_a_1_rel" : [ SenseInfo('01676026-a', 0) ],
"_defect_n_1_rel" : [ SenseInfo('14464005-n', 2), SenseInfo('05162642-n', 2), SenseInfo('14464203-n', 1), SenseInfo('04692157-n', 1) ],
"_type_n_of-n_rel" : [ SenseInfo('05840188-n', 136), SenseInfo('09909060-n', 7), SenseInfo('08111419-n', 0), SenseInfo('06825120-n', 0), SenseInfo('06795967-n', 0), SenseInfo('04504486-n', 0), SenseInfo('05840188-n', 136), SenseInfo('09909060-n', 7), SenseInfo('08111419-n', 0), SenseInfo('06825120-n', 0), SenseInfo('06795967-n', 0), SenseInfo('04504486-n', 0) ],
"_therapeutic_a_1_rel" : [ SenseInfo('01165943-a', 5), SenseInfo('02914213-a', 4) ],
"_calcify_v_1_rel" : [ SenseInfo('00498988-v', 1), SenseInfo('00572362-v', 0), SenseInfo('00498662-v', 0), SenseInfo('00498530-v', 0) ],
"_concept_n_1_rel" : [ SenseInfo('05835747-n', 37), SenseInfo('05835747-n', 37), SenseInfo('05835747-n', 37) ],
"_gripe_n_1_rel" : [ SenseInfo('07209965-n', 1), SenseInfo('07209965-n', 1) ],
"_intelligence_n_1_rel" : [ SenseInfo('05617606-n', 7), SenseInfo('08339454-n', 1), SenseInfo('06642672-n', 0), SenseInfo('06642138-n', 0), SenseInfo('00981830-n', 0) ],
"_look_v_forward-to_rel" : [ SenseInfo('02130524-v', 274), SenseInfo('02133435-v', 126), SenseInfo('00033599-v', 25), SenseInfo('02153709-v', 8), SenseInfo('02693319-v', 1), SenseInfo('02549581-v', 1), SenseInfo('00929362-v', 1), SenseInfo('00720063-v', 1), SenseInfo('02658447-v', 0), SenseInfo('00712708-v', 0) ],
"_bruise_n_1_rel" : [ SenseInfo('14288871-n', 1) ],
"_woodlands_n_1_rel" : [ SenseInfo('09284015-n', 0), SenseInfo('09284015-n', 0) ],
"_supposition_n_1_rel" : [ SenseInfo('06782680-n', 0), SenseInfo('05892096-n', 0), SenseInfo('05779712-n', 0), SenseInfo('06782680-n', 0), SenseInfo('05892096-n', 0), SenseInfo('05779712-n', 0) ],
"_on-screen_a_1_rel" : [  ],
"_damage_v_1_rel" : [ SenseInfo('00258857-v', 12), SenseInfo('00588084-v', 0) ],
"_indeterminate_a_1_rel" : [ SenseInfo('00740336-a', 1), SenseInfo('00741459-a', 0), SenseInfo('00896378-a', 0), SenseInfo('00739495-a', 0), SenseInfo('00551267-a', 0) ],
"_nugget_n_1_rel" : [ SenseInfo('09375481-n', 0) ],
"_furnish_v_to_rel" : [ SenseInfo('02327200-v', 28), SenseInfo('02336483-v', 3) ],
"_tantalize_v_1_rel" : [ SenseInfo('00850501-v', 1), SenseInfo('00850501-v', 1) ],
"_damned_x_deg_rel" : [ SenseInfo('00669942-a', 8), SenseInfo('01451225-a', 6), SenseInfo('07945490-n', 2), SenseInfo('00297563-r', 1) ],
"_so_x_rel" : [ SenseInfo('00146594-r', 322), SenseInfo('00118363-r', 79), SenseInfo('00146926-r', 73), SenseInfo('00147126-r', 7), SenseInfo('00147272-r', 6), SenseInfo('00121135-r', 2), SenseInfo('00146763-r', 1), SenseInfo('00117620-r', 1), SenseInfo('06868844-n', 0), SenseInfo('00043003-r', 0), SenseInfo('00037641-r', 0) ],
"_hoodwink_v_1_rel" : [ SenseInfo('02578235-v', 0), SenseInfo('00839194-v', 0), SenseInfo('02578235-v', 0), SenseInfo('00839194-v', 0) ],
"_grandiose_a_1_rel" : [ SenseInfo('01285713-a', 1), SenseInfo('01850288-a', 0) ],
"_ride_v_1_rel" : [ SenseInfo('01957529-v', 53), SenseInfo('01955984-v', 30), SenseInfo('02684644-v', 2), SenseInfo('01839538-v', 2), SenseInfo('00850501-v', 1), SenseInfo('02750154-v', 0), SenseInfo('02742232-v', 0), SenseInfo('02711987-v', 0), SenseInfo('02692089-v', 0), SenseInfo('02102398-v', 0), SenseInfo('02095545-v', 0), SenseInfo('01847676-v', 0), SenseInfo('01511134-v', 0), SenseInfo('01429322-v', 0), SenseInfo('01957529-v', 53), SenseInfo('01955984-v', 30), SenseInfo('02684644-v', 2), SenseInfo('01839538-v', 2), SenseInfo('00850501-v', 1), SenseInfo('02750154-v', 0), SenseInfo('02742232-v', 0), SenseInfo('02711987-v', 0), SenseInfo('02692089-v', 0), SenseInfo('02102398-v', 0), SenseInfo('02095545-v', 0), SenseInfo('01847676-v', 0), SenseInfo('01511134-v', 0), SenseInfo('01429322-v', 0), SenseInfo('01957529-v', 53), SenseInfo('01955984-v', 30), SenseInfo('02684644-v', 2), SenseInfo('01839538-v', 2), SenseInfo('00850501-v', 1), SenseInfo('02750154-v', 0), SenseInfo('02742232-v', 0), SenseInfo('02711987-v', 0), SenseInfo('02692089-v', 0), SenseInfo('02102398-v', 0), SenseInfo('02095545-v', 0), SenseInfo('01847676-v', 0), SenseInfo('01511134-v', 0), SenseInfo('01429322-v', 0) ],
"_other+than_p_rel" : [ SenseInfo('00113082-r', 0), SenseInfo('00113082-r', 0) ],
"_whoa_a_1_rel" : [  ],
"_count_n_1_rel" : [ SenseInfo('13591761-n', 4), SenseInfo('00634586-n', 4), SenseInfo('09969218-n', 0), SenseInfo('13591761-n', 4), SenseInfo('00634586-n', 4), SenseInfo('09969218-n', 0) ],
"_casino_n_1_rel" : [ SenseInfo('02977936-n', 1), SenseInfo('00491713-n', 0) ],
"_dictionary_n_of_rel" : [ SenseInfo('06418901-n', 52) ],
"_veritable_a_1_rel" : [ SenseInfo('02469577-a', 1), SenseInfo('01115635-a', 1) ],
"_songbird_n_1_rel" : [ SenseInfo('01526521-n', 0) ],
"_capture_n_of_rel" : [ SenseInfo('00088481-n', 2), SenseInfo('13442867-n', 1), SenseInfo('13442715-n', 0), SenseInfo('00775286-n', 0), SenseInfo('00166702-n', 0) ],
"_cirque_n_1_rel" : [ SenseInfo('09245515-n', 0) ],
"_original_n_1_rel" : [ SenseInfo('03727274-n', 3), SenseInfo('05938400-n', 2) ],
"_farce_n_1_rel" : [ SenseInfo('07016250-n', 2), SenseInfo('07679140-n', 0) ],
"_blast_v_off_rel" : [ SenseInfo('02182479-v', 3), SenseInfo('01401772-v', 2), SenseInfo('01135922-v', 1), SenseInfo('02101216-v', 0), SenseInfo('01759021-v', 0), SenseInfo('01758276-v', 0), SenseInfo('01134781-v', 0), SenseInfo('00823827-v', 0), SenseInfo('00336158-v', 0), SenseInfo('00241924-v', 0) ],
"_prepare_v_1_rel" : [ SenseInfo('00406243-v', 45), SenseInfo('01664172-v', 15), SenseInfo('01754271-v', 8), SenseInfo('01651444-v', 8), SenseInfo('02387034-v', 5), SenseInfo('00603298-v', 2), SenseInfo('02179915-v', 0), SenseInfo('00602805-v', 0), SenseInfo('00406243-v', 45), SenseInfo('01664172-v', 15), SenseInfo('01754271-v', 8), SenseInfo('01651444-v', 8), SenseInfo('02387034-v', 5), SenseInfo('00603298-v', 2), SenseInfo('02179915-v', 0), SenseInfo('00602805-v', 0), SenseInfo('00406243-v', 45), SenseInfo('01664172-v', 15), SenseInfo('01754271-v', 8), SenseInfo('01651444-v', 8), SenseInfo('02387034-v', 5), SenseInfo('00603298-v', 2), SenseInfo('02179915-v', 0), SenseInfo('00602805-v', 0), SenseInfo('00406243-v', 45), SenseInfo('01664172-v', 15), SenseInfo('01754271-v', 8), SenseInfo('01651444-v', 8), SenseInfo('02387034-v', 5), SenseInfo('00603298-v', 2), SenseInfo('02179915-v', 0), SenseInfo('00602805-v', 0) ],
"_encounter_v_1_rel" : [ SenseInfo('02023107-v', 17), SenseInfo('02248465-v', 8), SenseInfo('02730326-v', 4), SenseInfo('02739480-v', 1), SenseInfo('01079480-v', 1) ],
"_tag_n_1_rel" : [ SenseInfo('07273136-n', 4), SenseInfo('07273416-n', 0), SenseInfo('04045941-n', 0), SenseInfo('00487874-n', 0), SenseInfo('00145024-n', 0) ],
"_wander_v_up_rel" : [ SenseInfo('01881180-v', 18), SenseInfo('02576503-v', 1), SenseInfo('02102840-v', 0), SenseInfo('01882814-v', 0), SenseInfo('00780575-v', 0) ],
"_swedish_n_1_rel" : [ SenseInfo('06954925-n', 0), SenseInfo('06954925-n', 0), SenseInfo('06954925-n', 0) ],
"_gestate_v_1_rel" : [ SenseInfo('01633343-v', 0), SenseInfo('00059019-v', 0) ],
"_convene_v_cause_rel" : [ SenseInfo('02024508-v', 2), SenseInfo('00793037-v', 0) ],
"_cascade_v_1_rel" : [ SenseInfo('02071316-v', 1), SenseInfo('01465732-v', 0), SenseInfo('02071316-v', 1), SenseInfo('01465732-v', 0) ],
"_demagogue_n_1_rel" : [ SenseInfo('10001481-n', 1) ],
"_submachine_n_1_rel" : [  ],
"_thrash_v_out_rel" : [ SenseInfo('01416193-v', 2), SenseInfo('01890792-v', 1), SenseInfo('01897885-v', 0), SenseInfo('01880390-v', 0), SenseInfo('01838860-v', 0), SenseInfo('01416364-v', 0), SenseInfo('01412912-v', 0) ],
"_simulation_n_of_rel" : [ SenseInfo('00899049-n', 1), SenseInfo('05666700-n', 0), SenseInfo('03777283-n', 0), SenseInfo('00754956-n', 0) ],
"_buckle_v_1_rel" : [ SenseInfo('01548290-v', 1), SenseInfo('01279186-v', 1), SenseInfo('00356954-v', 1) ],
"_accept_v_1_rel" : [ SenseInfo('00686447-v', 34), SenseInfo('02236124-v', 33), SenseInfo('00797697-v', 17), SenseInfo('00719231-v', 12), SenseInfo('02236624-v', 8), SenseInfo('02301825-v', 7), SenseInfo('00668805-v', 2), SenseInfo('02741546-v', 0), SenseInfo('02210622-v', 0), SenseInfo('02209936-v', 0), SenseInfo('00718489-v', 0), SenseInfo('00686447-v', 34), SenseInfo('02236124-v', 33), SenseInfo('00797697-v', 17), SenseInfo('00719231-v', 12), SenseInfo('02236624-v', 8), SenseInfo('02301825-v', 7), SenseInfo('00668805-v', 2), SenseInfo('02741546-v', 0), SenseInfo('02210622-v', 0), SenseInfo('02209936-v', 0), SenseInfo('00718489-v', 0), SenseInfo('00686447-v', 34), SenseInfo('02236124-v', 33), SenseInfo('00797697-v', 17), SenseInfo('00719231-v', 12), SenseInfo('02236624-v', 8), SenseInfo('02301825-v', 7), SenseInfo('00668805-v', 2), SenseInfo('02741546-v', 0), SenseInfo('02210622-v', 0), SenseInfo('02209936-v', 0), SenseInfo('00718489-v', 0) ],
"_proverbial_a_1_rel" : [ SenseInfo('02990304-a', 1), SenseInfo('01376522-a', 0), SenseInfo('02990304-a', 1), SenseInfo('01376522-a', 0) ],
"_forward_a_1_rel" : [ SenseInfo('00203237-a', 8), SenseInfo('00204491-a', 0), SenseInfo('00203774-a', 0), SenseInfo('01876555-a', 0) ],
"_soak_v_up_rel" : [ SenseInfo('01578513-v', 4), SenseInfo('02319050-v', 1), SenseInfo('00216216-v', 1), SenseInfo('02347220-v', 0), SenseInfo('01397870-v', 0), SenseInfo('01190494-v', 0), SenseInfo('01190277-v', 0), SenseInfo('00456151-v', 0), SenseInfo('00372157-v', 0) ],
"_effectively_x_deg_rel" : [ SenseInfo('00326324-r', 12), SenseInfo('00060032-r', 1) ],
"_quit_v_1_rel" : [ SenseInfo('02680814-v', 13), SenseInfo('02382367-v', 1), SenseInfo('02008396-v', 1), SenseInfo('02227487-v', 0), SenseInfo('01083044-v', 0) ],
"_vomit_v_1_rel" : [ SenseInfo('00076400-v', 1) ],
"_hum_n_1_rel" : [ SenseInfo('14008050-n', 0), SenseInfo('08022972-n', 0), SenseInfo('07385803-n', 0) ],
"_among+other+things_a_1_rel" : [  ],
"_calf_n_1_rel" : [ SenseInfo('01887896-n', 6), SenseInfo('05574332-n', 1), SenseInfo('14761334-n', 0), SenseInfo('01888045-n', 0) ],
"_franchise_n_1_rel" : [ SenseInfo('06526811-n', 2), SenseInfo('08060193-n', 0), SenseInfo('05187446-n', 0) ],
"_sweater_n_1_rel" : [ SenseInfo('04370048-n', 1), SenseInfo('10418735-n', 0) ],
"_faith_n_1_rel" : [ SenseInfo('05946687-n', 18), SenseInfo('05943066-n', 9), SenseInfo('08081668-n', 6), SenseInfo('01207187-n', 1) ],
"_Dalmatian_n_1_rel" : [ SenseInfo('09988918-n', 0), SenseInfo('02110341-n', 0) ],
"_measure_v_up_rel" : [ SenseInfo('00647094-v', 35), SenseInfo('00489837-v', 20), SenseInfo('02704349-v', 14), SenseInfo('00681429-v', 10), SenseInfo('00647094-v', 35), SenseInfo('00489837-v', 20), SenseInfo('02704349-v', 14), SenseInfo('00681429-v', 10) ],
"_germanic_a_1_rel" : [ SenseInfo('03068330-a', 0), SenseInfo('02958126-a', 0) ],
"_interrupt_v_1_rel" : [ SenseInfo('00778275-v', 14), SenseInfo('00520019-v', 5), SenseInfo('00520357-v', 3), SenseInfo('00364064-v', 0), SenseInfo('00778275-v', 14), SenseInfo('00520019-v', 5), SenseInfo('00520357-v', 3), SenseInfo('00364064-v', 0), SenseInfo('00778275-v', 14), SenseInfo('00520019-v', 5), SenseInfo('00520357-v', 3), SenseInfo('00364064-v', 0) ],
"_unite_v_1_rel" : [ SenseInfo('02469835-v', 7), SenseInfo('00367685-v', 7), SenseInfo('02631163-v', 0), SenseInfo('02622234-v', 0), SenseInfo('02603056-v', 0), SenseInfo('00243124-v', 0) ],
"_defective_a_1_rel" : [ SenseInfo('01752953-a', 2), SenseInfo('01597240-a', 1), SenseInfo('01092572-a', 0) ],
"_nacelle_n_1_rel" : [ SenseInfo('03804211-n', 0) ],
"_tilt_n_of_rel" : [ SenseInfo('07472460-n', 0), SenseInfo('07183151-n', 0), SenseInfo('06202296-n', 0), SenseInfo('05068080-n', 0), SenseInfo('00348008-n', 0) ],
"_cool_v_down_rel" : [ SenseInfo('00370412-v', 15), SenseInfo('00369864-v', 1), SenseInfo('00370126-v', 0) ],
"_catcher_n_1_rel" : [ SenseInfo('09901143-n', 15), SenseInfo('00723241-n', 0) ],
"_at-bat_n_1_rel" : [ SenseInfo('00458456-n', 1), SenseInfo('00458456-n', 1) ],
"_junky_a_1_rel" : [ SenseInfo('10035952-n', 0), SenseInfo('09769076-n', 0), SenseInfo('10035952-n', 0), SenseInfo('09769076-n', 0), SenseInfo('10035952-n', 0), SenseInfo('09769076-n', 0) ],
"_waterfall_n_1_rel" : [ SenseInfo('09475292-n', 3), SenseInfo('09475292-n', 3) ],
"_stomach_v_1_rel" : [ SenseInfo('01197626-v', 0), SenseInfo('00668099-v', 0) ],
"_topaz_n_1_rel" : [ SenseInfo('15076523-n', 0), SenseInfo('15076349-n', 0), SenseInfo('04973020-n', 0) ],
"_familiar_a_with_rel" : [ SenseInfo('00965606-a', 23), SenseInfo('00970249-a', 1), SenseInfo('01307067-a', 1), SenseInfo('00453053-a', 0) ],
"_if+necessary_a_1_rel" : [  ],
"_adhere_v_1_rel" : [ SenseInfo('02718178-v', 5), SenseInfo('00486557-v', 3), SenseInfo('01220885-v', 1), SenseInfo('02638845-v', 0), SenseInfo('02638630-v', 0), SenseInfo('01356750-v', 0) ],
"_order_v_up_rel" : [ SenseInfo('00746718-v', 28), SenseInfo('00745499-v', 14), SenseInfo('00747135-v', 5), SenseInfo('02511551-v', 3), SenseInfo('00277659-v', 1), SenseInfo('00276883-v', 1), SenseInfo('02386012-v', 0), SenseInfo('00735571-v', 0), SenseInfo('00658052-v', 0) ],
"_reported_a_1_rel" : [ SenseInfo('00471348-a', 2), SenseInfo('00471348-a', 2), SenseInfo('00471348-a', 2), SenseInfo('00471348-a', 2) ],
"_extra_a_1_rel" : [ SenseInfo('01581305-a', 4), SenseInfo('02367319-a', 0), SenseInfo('00048858-a', 0) ],
"_ski_v_1_rel" : [ SenseInfo('01938426-v', 0), SenseInfo('01938426-v', 0) ],
"_all-terrain_n_1_rel" : [  ],
"_morning_n_of_rel" : [ SenseInfo('15165289-n', 86), SenseInfo('06632671-n', 2), SenseInfo('15168790-n', 0), SenseInfo('07326108-n', 0), SenseInfo('15165289-n', 86), SenseInfo('06632671-n', 2), SenseInfo('15168790-n', 0), SenseInfo('07326108-n', 0), SenseInfo('15165289-n', 86), SenseInfo('06632671-n', 2), SenseInfo('15168790-n', 0), SenseInfo('07326108-n', 0), SenseInfo('15165289-n', 86), SenseInfo('06632671-n', 2), SenseInfo('15168790-n', 0), SenseInfo('07326108-n', 0), SenseInfo('15165289-n', 86), SenseInfo('06632671-n', 2), SenseInfo('15168790-n', 0), SenseInfo('07326108-n', 0) ],
"_fanciful_a_1_rel" : [ SenseInfo('00643598-a', 1), SenseInfo('01936528-a', 0), SenseInfo('01796304-a', 0) ],
"_disregard_n_for_rel" : [ SenseInfo('05706629-n', 1), SenseInfo('00418615-n', 1) ],
"_partner_v_with_rel" : [ SenseInfo('02332086-v', 1), SenseInfo('02371684-v', 0), SenseInfo('02332086-v', 1), SenseInfo('02371684-v', 0), SenseInfo('02332086-v', 1), SenseInfo('02371684-v', 0) ],
"_advanced_a_1_rel" : [ SenseInfo('01840121-a', 5), SenseInfo('00819526-a', 3), SenseInfo('01876261-a', 2), SenseInfo('01211296-a', 2), SenseInfo('01208738-a', 1), SenseInfo('00816839-a', 1), SenseInfo('00412171-a', 1), SenseInfo('00198383-a', 1) ],
"_sign+up_n_1_rel" : [  ],
"_experimental_a_1_rel" : [ SenseInfo('02940392-a', 14), SenseInfo('00859949-a', 3), SenseInfo('00860127-a', 2), SenseInfo('02940392-a', 14), SenseInfo('00859949-a', 3), SenseInfo('00860127-a', 2) ],
"_stapler_n_1_rel" : [ SenseInfo('04303497-n', 0) ],
"_caption_n_1_rel" : [ SenseInfo('07209691-n', 0), SenseInfo('06347588-n', 0), SenseInfo('06346891-n', 0) ],
"_bootlegger_n_1_rel" : [ SenseInfo('09866922-n', 2) ],
"_catamaran_n_1_rel" : [ SenseInfo('02981792-n', 0) ],
"_gray_v_out_rel" : [ SenseInfo('00289679-v', 0), SenseInfo('00289392-v', 0), SenseInfo('00289679-v', 0), SenseInfo('00289392-v', 0) ],
"_at+random_p_rel" : [ SenseInfo('00070765-r', 1) ],
"_die_v_down_rel" : [ SenseInfo('00358431-v', 141), SenseInfo('02109818-v', 1), SenseInfo('01784953-v', 1), SenseInfo('00434374-v', 1), SenseInfo('01829475-v', 0), SenseInfo('01785242-v', 0), SenseInfo('01555034-v', 0), SenseInfo('01074914-v', 0), SenseInfo('00538323-v', 0), SenseInfo('00354845-v', 0), SenseInfo('00224295-v', 0) ],
"_beneficial_a_1_rel" : [ SenseInfo('00064787-a', 6) ],
"_carry_v_on_rel" : [ SenseInfo('01449974-v', 72), SenseInfo('02717102-v', 36), SenseInfo('02079933-v', 8), SenseInfo('01061017-v', 8), SenseInfo('01218084-v', 6), SenseInfo('01601234-v', 5), SenseInfo('02700867-v', 4), SenseInfo('02561168-v', 4), SenseInfo('00235110-v', 3), SenseInfo('02636325-v', 2), SenseInfo('01101416-v', 2), SenseInfo('00738951-v', 2), SenseInfo('02518161-v', 1), SenseInfo('02285392-v', 1), SenseInfo('01746359-v', 1), SenseInfo('01408760-v', 1), SenseInfo('01061320-v', 1), SenseInfo('02746735-v', 0), SenseInfo('02741357-v', 0), SenseInfo('02682954-v', 0), SenseInfo('02636516-v', 0), SenseInfo('02630734-v', 0), SenseInfo('02586121-v', 0), SenseInfo('02556537-v', 0), SenseInfo('02555684-v', 0), SenseInfo('02359228-v', 0), SenseInfo('02303878-v', 0), SenseInfo('02233195-v', 0), SenseInfo('02012725-v', 0), SenseInfo('02001699-v', 0), SenseInfo('01740320-v', 0), SenseInfo('01241881-v', 0), SenseInfo('01205153-v', 0), SenseInfo('01203074-v', 0), SenseInfo('01123609-v', 0), SenseInfo('01123415-v', 0), SenseInfo('01101571-v', 0), SenseInfo('01100672-v', 0), SenseInfo('01049606-v', 0), SenseInfo('00059019-v', 0), SenseInfo('01449974-v', 72), SenseInfo('02717102-v', 36), SenseInfo('02079933-v', 8), SenseInfo('01061017-v', 8), SenseInfo('01218084-v', 6), SenseInfo('01601234-v', 5), SenseInfo('02700867-v', 4), SenseInfo('02561168-v', 4), SenseInfo('00235110-v', 3), SenseInfo('02636325-v', 2), SenseInfo('01101416-v', 2), SenseInfo('00738951-v', 2), SenseInfo('02518161-v', 1), SenseInfo('02285392-v', 1), SenseInfo('01746359-v', 1), SenseInfo('01408760-v', 1), SenseInfo('01061320-v', 1), SenseInfo('02746735-v', 0), SenseInfo('02741357-v', 0), SenseInfo('02682954-v', 0), SenseInfo('02636516-v', 0), SenseInfo('02630734-v', 0), SenseInfo('02586121-v', 0), SenseInfo('02556537-v', 0), SenseInfo('02555684-v', 0), SenseInfo('02359228-v', 0), SenseInfo('02303878-v', 0), SenseInfo('02233195-v', 0), SenseInfo('02012725-v', 0), SenseInfo('02001699-v', 0), SenseInfo('01740320-v', 0), SenseInfo('01241881-v', 0), SenseInfo('01205153-v', 0), SenseInfo('01203074-v', 0), SenseInfo('01123609-v', 0), SenseInfo('01123415-v', 0), SenseInfo('01101571-v', 0), SenseInfo('01100672-v', 0), SenseInfo('01049606-v', 0), SenseInfo('00059019-v', 0) ],
"_class_v_as_rel" : [ SenseInfo('00654625-v', 2), SenseInfo('00654625-v', 2) ],
"_sud_n_1_rel" : [  ],
"_entryway_n_1_rel" : [ SenseInfo('03290771-n', 0) ],
"_thrill_v_1_rel" : [ SenseInfo('02117333-v', 2), SenseInfo('01796346-v', 1), SenseInfo('01888946-v', 0), SenseInfo('01812324-v', 0), SenseInfo('02117333-v', 2), SenseInfo('01796346-v', 1), SenseInfo('01888946-v', 0), SenseInfo('01812324-v', 0), SenseInfo('02117333-v', 2), SenseInfo('01796346-v', 1), SenseInfo('01888946-v', 0), SenseInfo('01812324-v', 0), SenseInfo('02117333-v', 2), SenseInfo('01796346-v', 1), SenseInfo('01888946-v', 0), SenseInfo('01812324-v', 0) ],
"_angstrom_n_1_rel" : [ SenseInfo('13658027-n', 0), SenseInfo('13658027-n', 0), SenseInfo('13658027-n', 0), SenseInfo('13658027-n', 0) ],
"_genuine_a_1_rel" : [ SenseInfo('01115349-a', 6), SenseInfo('02180277-a', 4), SenseInfo('02460964-a', 2), SenseInfo('01115349-a', 6), SenseInfo('02180277-a', 4), SenseInfo('02460964-a', 2) ],
"_mumbo-jumbo_n_1_rel" : [ SenseInfo('06612420-n', 1), SenseInfo('06612420-n', 1) ],
"_gulf_n_1_rel" : [ SenseInfo('09296121-n', 1), SenseInfo('04753060-n', 1), SenseInfo('09296053-n', 0) ],
"_problematical_a_1_rel" : [ SenseInfo('01916784-a', 0), SenseInfo('00746451-a', 0) ],
"_every_a_1_rel" : [ SenseInfo('02269794-a', 57), SenseInfo('02270186-a', 11) ],
"_baseball_n_1_rel" : [ SenseInfo('00471613-n', 21), SenseInfo('02799071-n', 2) ],
"_offhand_a_1_rel" : [ SenseInfo('01845451-a', 0), SenseInfo('00313217-a', 0), SenseInfo('01845451-a', 0), SenseInfo('00313217-a', 0), SenseInfo('01845451-a', 0), SenseInfo('00313217-a', 0), SenseInfo('01845451-a', 0), SenseInfo('00313217-a', 0) ],
"_disagree_v_1_rel" : [ SenseInfo('00804802-v', 10), SenseInfo('02718543-v', 0), SenseInfo('00804802-v', 10), SenseInfo('02718543-v', 0) ],
"_menses_n_1_rel" : [ SenseInfo('13513747-n', 0) ],
"_behead_v_1_rel" : [ SenseInfo('01571354-v', 1) ],
"_pair_n_of-i_rel" : [ SenseInfo('07985223-n', 18), SenseInfo('13743605-n', 10), SenseInfo('07976936-n', 7), SenseInfo('07958407-n', 0) ],
"_worsted_a_1_rel" : [ SenseInfo('04605163-n', 1), SenseInfo('04605321-n', 0) ],
"_face+to+face_a_1_rel" : [ SenseInfo('01767975-a', 0), SenseInfo('01767975-a', 0), SenseInfo('01767975-a', 0), SenseInfo('01767975-a', 0), SenseInfo('01767975-a', 0), SenseInfo('01767975-a', 0) ],
"_elder_n_1_rel" : [ SenseInfo('10048218-n', 3), SenseInfo('12678224-n', 0), SenseInfo('10048367-n', 0) ],
"_bath_n_1_rel" : [ SenseInfo('02806530-n', 5), SenseInfo('00257770-n', 2), SenseInfo('02808440-n', 1), SenseInfo('13616560-n', 0), SenseInfo('08878202-n', 0), SenseInfo('02807731-n', 0) ],
"_photographer_n_of_rel" : [ SenseInfo('10426749-n', 0) ],
"_release_n_of_rel" : [ SenseInfo('04073208-n', 6), SenseInfo('00095502-n', 3), SenseInfo('13549672-n', 2), SenseInfo('06747484-n', 2), SenseInfo('00216174-n', 2), SenseInfo('07333649-n', 1), SenseInfo('06552814-n', 0), SenseInfo('04073425-n', 0), SenseInfo('01264447-n', 0), SenseInfo('00329619-n', 0), SenseInfo('00213694-n', 0), SenseInfo('00210940-n', 0) ],
"_functionality_n_1_rel" : [ SenseInfo('05151372-n', 0) ],
"_importance_n_1_rel" : [ SenseInfo('05168261-n', 50), SenseInfo('14434681-n', 4), SenseInfo('05168261-n', 50), SenseInfo('14434681-n', 4) ],
"_clearance_n_1_rel" : [ SenseInfo('05090111-n', 1), SenseInfo('13778261-n', 0), SenseInfo('01141593-n', 0), SenseInfo('05090111-n', 1), SenseInfo('13778261-n', 0), SenseInfo('01141593-n', 0) ],
"_jog_v_1_rel" : [ SenseInfo('02684453-v', 1), SenseInfo('01987648-v', 0), SenseInfo('01928390-v', 0), SenseInfo('01901447-v', 0), SenseInfo('01231528-v', 0), SenseInfo('00794533-v', 0), SenseInfo('02684453-v', 1), SenseInfo('01987648-v', 0), SenseInfo('01928390-v', 0), SenseInfo('01901447-v', 0), SenseInfo('01231528-v', 0), SenseInfo('00794533-v', 0) ],
"_all-purpose_a_1_rel" : [ SenseInfo('01102058-a', 0), SenseInfo('01102058-a', 0) ],
"_word_n_of_rel" : [ SenseInfo('06286395-n', 117), SenseInfo('06738162-n', 18), SenseInfo('06642138-n', 5), SenseInfo('07169242-n', 3), SenseInfo('07140659-n', 3), SenseInfo('07227301-n', 1), SenseInfo('13627327-n', 0), SenseInfo('09537144-n', 0), SenseInfo('06674188-n', 0), SenseInfo('06431740-n', 0), SenseInfo('06286395-n', 117), SenseInfo('06738162-n', 18), SenseInfo('06642138-n', 5), SenseInfo('07169242-n', 3), SenseInfo('07140659-n', 3), SenseInfo('07227301-n', 1), SenseInfo('13627327-n', 0), SenseInfo('09537144-n', 0), SenseInfo('06674188-n', 0), SenseInfo('06431740-n', 0), SenseInfo('06286395-n', 117), SenseInfo('06738162-n', 18), SenseInfo('06642138-n', 5), SenseInfo('07169242-n', 3), SenseInfo('07140659-n', 3), SenseInfo('07227301-n', 1), SenseInfo('13627327-n', 0), SenseInfo('09537144-n', 0), SenseInfo('06674188-n', 0), SenseInfo('06431740-n', 0) ],
"_condom_n_1_rel" : [ SenseInfo('03088164-n', 0) ],
"_storefront_n_1_rel" : [ SenseInfo('04203705-n', 2) ],
"_preclude_v_1_rel" : [ SenseInfo('02452885-v', 2), SenseInfo('02629390-v', 0) ],
"_shaft_n_1_rel" : [ SenseInfo('06821770-n', 3), SenseInfo('06767922-n', 3), SenseInfo('04182322-n', 1), SenseInfo('11428023-n', 0), SenseInfo('05592733-n', 0), SenseInfo('05526713-n', 0), SenseInfo('04270891-n', 0), SenseInfo('04182890-n', 0), SenseInfo('04182708-n', 0), SenseInfo('04182514-n', 0), SenseInfo('04111190-n', 0), SenseInfo('02468617-n', 0) ],
"_surveillance_n_of_rel" : [ SenseInfo('00652466-n', 2) ],
"_journey_v_1_rel" : [ SenseInfo('01845720-v', 1), SenseInfo('01846916-v', 0) ],
"_butler_n_1_rel" : [ SenseInfo('09884509-n', 1), SenseInfo('10876513-n', 0), SenseInfo('10876419-n', 0) ],
"_consumption_n_of_rel" : [ SenseInfo('00838098-n', 2), SenseInfo('14144064-n', 0), SenseInfo('13451804-n', 0), SenseInfo('00356367-n', 0) ],
"_credit_v_back_rel" : [ SenseInfo('00727143-v', 4), SenseInfo('00727791-v', 3), SenseInfo('02264752-v', 2), SenseInfo('00683930-v', 1), SenseInfo('00727143-v', 4), SenseInfo('00727791-v', 3), SenseInfo('02264752-v', 2), SenseInfo('00683930-v', 1) ],
"_serializable_a_1_rel" : [  ],
"_re-acquaint_v_1_rel" : [ SenseInfo('00874867-v', 1), SenseInfo('00874867-v', 1) ],
"_vaporization_n_of_rel" : [ SenseInfo('00218902-n', 1), SenseInfo('13572436-n', 0) ],
"_moraine_n_1_rel" : [ SenseInfo('09358907-n', 0) ],
"_hunker_v_down_rel" : [ SenseInfo('01545314-v', 0) ],
"_boundary_n_1_rel" : [ SenseInfo('08512259-n', 4), SenseInfo('13903079-n', 2), SenseInfo('05124057-n', 0) ],
"_cast_v_off_rel" : [ SenseInfo('01632897-v', 15), SenseInfo('02236023-v', 3), SenseInfo('01710481-v', 2), SenseInfo('01507143-v', 1), SenseInfo('02385813-v', 0), SenseInfo('01881180-v', 0), SenseInfo('01662771-v', 0), SenseInfo('01513430-v', 0), SenseInfo('01078050-v', 0), SenseInfo('00981276-v', 0), SenseInfo('00076400-v', 0), SenseInfo('01632897-v', 15), SenseInfo('02236023-v', 3), SenseInfo('01710481-v', 2), SenseInfo('01507143-v', 1), SenseInfo('02385813-v', 0), SenseInfo('01881180-v', 0), SenseInfo('01662771-v', 0), SenseInfo('01513430-v', 0), SenseInfo('01078050-v', 0), SenseInfo('00981276-v', 0), SenseInfo('00076400-v', 0) ],
"_advocate_v_1_rel" : [ SenseInfo('00875141-v', 9), SenseInfo('00827730-v', 1), SenseInfo('00875141-v', 9), SenseInfo('00827730-v', 1) ],
"_cash_n_1_rel" : [ SenseInfo('13386614-n', 9), SenseInfo('13386465-n', 0), SenseInfo('10886222-n', 0) ],
"_trap_v_1_rel" : [ SenseInfo('02496185-v', 2), SenseInfo('01480770-v', 2), SenseInfo('01606931-v', 1), SenseInfo('01207149-v', 0), SenseInfo('02496185-v', 2), SenseInfo('01480770-v', 2), SenseInfo('01606931-v', 1), SenseInfo('01207149-v', 0) ],
"_universal_a_1_rel" : [ SenseInfo('00527188-a', 21), SenseInfo('01102674-a', 0), SenseInfo('01028623-a', 0), SenseInfo('00527188-a', 21), SenseInfo('01102674-a', 0), SenseInfo('01028623-a', 0) ],
"_designate_v_as_rel" : [ SenseInfo('01030132-v', 12), SenseInfo('02391803-v', 1), SenseInfo('00923793-v', 0), SenseInfo('00746479-v', 0), SenseInfo('00709379-v', 0), SenseInfo('01030132-v', 12), SenseInfo('02391803-v', 1), SenseInfo('00923793-v', 0), SenseInfo('00746479-v', 0), SenseInfo('00709379-v', 0) ],
"_fact_n_1_rel" : [ SenseInfo('05817396-n', 85), SenseInfo('06636259-n', 34), SenseInfo('13955874-n', 11), SenseInfo('05889896-n', 3), SenseInfo('05817396-n', 85), SenseInfo('06636259-n', 34), SenseInfo('13955874-n', 11), SenseInfo('05889896-n', 3) ],
"_bookshelf_n_1_rel" : [ SenseInfo('02871439-n', 2) ],
"_divide_v_cause_rel" : [ SenseInfo('02467662-v', 20), SenseInfo('00642098-v', 11), SenseInfo('02621853-v', 4), SenseInfo('01557774-v', 2), SenseInfo('02031158-v', 1), SenseInfo('01556921-v', 1) ],
"_play_v_down_rel" : [ SenseInfo('01072949-v', 70), SenseInfo('02370650-v', 37), SenseInfo('01725051-v', 29), SenseInfo('01719302-v', 27), SenseInfo('02418686-v', 23), SenseInfo('01724459-v', 14), SenseInfo('01726172-v', 8), SenseInfo('00013615-v', 6), SenseInfo('01903385-v', 5), SenseInfo('01138911-v', 5), SenseInfo('02418421-v', 4), SenseInfo('01722077-v', 4), SenseInfo('01717436-v', 3), SenseInfo('01716619-v', 2), SenseInfo('01149470-v', 2), SenseInfo('00013328-v', 2), SenseInfo('02597601-v', 1), SenseInfo('01717169-v', 1), SenseInfo('01586278-v', 1), SenseInfo('01163355-v', 1), SenseInfo('00711932-v', 1), SenseInfo('02722449-v', 0), SenseInfo('02437465-v', 0), SenseInfo('01903562-v', 0), SenseInfo('01719921-v', 0), SenseInfo('01716882-v', 0), SenseInfo('01629589-v', 0), SenseInfo('01377239-v', 0), SenseInfo('01156115-v', 0), SenseInfo('01155687-v', 0), SenseInfo('01080691-v', 0), SenseInfo('01080064-v', 0), SenseInfo('01079873-v', 0), SenseInfo('01079480-v', 0), SenseInfo('00075875-v', 0) ],
"_visitor_n_of_rel" : [ SenseInfo('10757193-n', 8) ],
"_domed_a_1_rel" : [ SenseInfo('02046017-a', 0) ],
"_waterline_n_1_rel" : [ SenseInfo('08678783-n', 0) ],
"_tile_n_1_rel" : [ SenseInfo('04435180-n', 1), SenseInfo('15074568-n', 0), SenseInfo('04435378-n', 0) ],
"_experience_v_1_rel" : [ SenseInfo('02110220-v', 18), SenseInfo('00596644-v', 10), SenseInfo('02108026-v', 8), SenseInfo('01771535-v', 5), SenseInfo('00121046-v', 0) ],
"_artisan_n_1_rel" : [ SenseInfo('09974648-n', 1) ],
"_disorder_n_1_rel" : [ SenseInfo('14052403-n', 5), SenseInfo('14499262-n', 0), SenseInfo('13972797-n', 0) ],
"_imperial_a_1_rel" : [ SenseInfo('02747036-a', 1), SenseInfo('02747246-a', 0), SenseInfo('02746897-a', 0), SenseInfo('01591394-a', 0), SenseInfo('02747036-a', 1), SenseInfo('02747246-a', 0), SenseInfo('02746897-a', 0), SenseInfo('01591394-a', 0) ],
"_columnar_a_1_rel" : [ SenseInfo('00141111-a', 0), SenseInfo('00140989-a', 0) ],
"_grind_v_out_rel" : [ SenseInfo('01594978-v', 4), SenseInfo('01394464-v', 3), SenseInfo('02419773-v', 1), SenseInfo('02048682-v', 1), SenseInfo('00331082-v', 1), SenseInfo('01624449-v', 0), SenseInfo('01624321-v', 0) ],
"_name_n_of_rel" : [ SenseInfo('06333653-n', 94), SenseInfo('14438788-n', 6), SenseInfo('07972279-n', 2), SenseInfo('10344443-n', 1), SenseInfo('01139636-n', 1), SenseInfo('06720964-n', 0), SenseInfo('06333653-n', 94), SenseInfo('14438788-n', 6), SenseInfo('07972279-n', 2), SenseInfo('10344443-n', 1), SenseInfo('01139636-n', 1), SenseInfo('06720964-n', 0) ],
"_debut_n_1_rel" : [ SenseInfo('00238022-n', 5), SenseInfo('07217579-n', 0) ],
"_yea_n_1_rel" : [ SenseInfo('07204008-n', 0) ],
"_felon_n_1_rel" : [ SenseInfo('09977660-n', 1), SenseInfo('14176570-n', 0) ],
"_tweezer_n_1_rel" : [ SenseInfo('03941684-n', 0) ],
"_flip_v_on_rel" : [ SenseInfo('01893079-v', 3), SenseInfo('01510173-v', 1), SenseInfo('02153023-v', 0), SenseInfo('01893601-v', 0), SenseInfo('01893465-v', 0), SenseInfo('01512625-v', 0), SenseInfo('01241614-v', 0), SenseInfo('01222958-v', 0), SenseInfo('00717921-v', 0), SenseInfo('00584810-v', 0), SenseInfo('00121678-v', 0) ],
"_choragus_n_1_rel" : [ SenseInfo('09920106-n', 0) ],
"_hands-on_a_1_rel" : [ SenseInfo('00039259-a', 0), SenseInfo('00039259-a', 0) ],
"_anisotropy_n_1_rel" : [ SenseInfo('04917680-n', 0) ],
"_quarantine_n_of_rel" : [ SenseInfo('14415335-n', 0), SenseInfo('01201645-n', 0) ],
"_privateering_n_1_rel" : [  ],
"_plunk_v_down_rel" : [ SenseInfo('02184965-v', 1), SenseInfo('01500572-v', 1), SenseInfo('01967373-v', 0), SenseInfo('01452546-v', 0) ],
"_pile_n_of_rel" : [ SenseInfo('07961480-n', 9), SenseInfo('13774404-n', 3), SenseInfo('13250680-n', 2), SenseInfo('05255692-n', 0), SenseInfo('04541136-n', 0), SenseInfo('03936269-n', 0), SenseInfo('03936045-n', 0), SenseInfo('02753710-n', 0) ],
"_ginko_n_1_rel" : [  ],
"_dependency_n_on_rel" : [ SenseInfo('14001348-n', 3), SenseInfo('14062725-n', 0), SenseInfo('08499840-n', 0) ],
"_spontaneous_a_1_rel" : [ SenseInfo('02282376-a', 8), SenseInfo('02213557-a', 0), SenseInfo('02282376-a', 8), SenseInfo('02213557-a', 0) ],
"_crisis_n_1_rel" : [ SenseInfo('13933560-n', 9), SenseInfo('07417644-n', 8) ],
"_traffic_n_1_rel" : [ SenseInfo('08425303-n', 13), SenseInfo('01113867-n', 1), SenseInfo('07279453-n', 0), SenseInfo('00040804-n', 0) ],
"_club_v_1_rel" : [ SenseInfo('02592250-v', 0), SenseInfo('02592111-v', 0), SenseInfo('01423929-v', 0), SenseInfo('01320321-v', 0) ],
"_better-than-average_a_1_rel" : [  ],
"_allow_v_to_rel" : [ SenseInfo('02423183-v', 65), SenseInfo('00802318-v', 49), SenseInfo('02255462-v', 17), SenseInfo('00724150-v', 8), SenseInfo('02721438-v', 3), SenseInfo('00723545-v', 3), SenseInfo('02745486-v', 0), SenseInfo('02423650-v', 0), SenseInfo('02319669-v', 0), SenseInfo('00802946-v', 0) ],
"_inviolate_a_1_rel" : [ SenseInfo('01319434-a', 1), SenseInfo('02055900-a', 0) ],
"_distal_a_1_rel" : [ SenseInfo('00778363-a', 9), SenseInfo('00778680-a', 0) ],
"_throw_n_1_rel" : [ SenseInfo('00104539-n', 4), SenseInfo('14485990-n', 1), SenseInfo('07351195-n', 0), SenseInfo('04429971-n', 0), SenseInfo('01245618-n', 0) ],
"_passers+by_n_1_rel" : [  ],
"_find_v_1_rel" : [ SenseInfo('02248465-v', 159), SenseInfo('02154508-v', 141), SenseInfo('02285629-v', 86), SenseInfo('00918872-v', 57), SenseInfo('00715239-v', 57), SenseInfo('02128873-v', 45), SenseInfo('02213336-v', 41), SenseInfo('01637982-v', 34), SenseInfo('00721437-v', 29), SenseInfo('02212275-v', 16), SenseInfo('00971999-v', 16), SenseInfo('00522751-v', 13), SenseInfo('02197781-v', 11), SenseInfo('02247977-v', 0), SenseInfo('02021653-v', 0), SenseInfo('00250691-v', 0), SenseInfo('02248465-v', 159), SenseInfo('02154508-v', 141), SenseInfo('02285629-v', 86), SenseInfo('00918872-v', 57), SenseInfo('00715239-v', 57), SenseInfo('02128873-v', 45), SenseInfo('02213336-v', 41), SenseInfo('01637982-v', 34), SenseInfo('00721437-v', 29), SenseInfo('02212275-v', 16), SenseInfo('00971999-v', 16), SenseInfo('00522751-v', 13), SenseInfo('02197781-v', 11), SenseInfo('02247977-v', 0), SenseInfo('02021653-v', 0), SenseInfo('00250691-v', 0), SenseInfo('02248465-v', 159), SenseInfo('02154508-v', 141), SenseInfo('02285629-v', 86), SenseInfo('00918872-v', 57), SenseInfo('00715239-v', 57), SenseInfo('02128873-v', 45), SenseInfo('02213336-v', 41), SenseInfo('01637982-v', 34), SenseInfo('00721437-v', 29), SenseInfo('02212275-v', 16), SenseInfo('00971999-v', 16), SenseInfo('00522751-v', 13), SenseInfo('02197781-v', 11), SenseInfo('02247977-v', 0), SenseInfo('02021653-v', 0), SenseInfo('00250691-v', 0), SenseInfo('02248465-v', 159), SenseInfo('02154508-v', 141), SenseInfo('02285629-v', 86), SenseInfo('00918872-v', 57), SenseInfo('00715239-v', 57), SenseInfo('02128873-v', 45), SenseInfo('02213336-v', 41), SenseInfo('01637982-v', 34), SenseInfo('00721437-v', 29), SenseInfo('02212275-v', 16), SenseInfo('00971999-v', 16), SenseInfo('00522751-v', 13), SenseInfo('02197781-v', 11), SenseInfo('02247977-v', 0), SenseInfo('02021653-v', 0), SenseInfo('00250691-v', 0), SenseInfo('02248465-v', 159), SenseInfo('02154508-v', 141), SenseInfo('02285629-v', 86), SenseInfo('00918872-v', 57), SenseInfo('00715239-v', 57), SenseInfo('02128873-v', 45), SenseInfo('02213336-v', 41), SenseInfo('01637982-v', 34), SenseInfo('00721437-v', 29), SenseInfo('02212275-v', 16), SenseInfo('00971999-v', 16), SenseInfo('00522751-v', 13), SenseInfo('02197781-v', 11), SenseInfo('02247977-v', 0), SenseInfo('02021653-v', 0), SenseInfo('00250691-v', 0), SenseInfo('02248465-v', 159), SenseInfo('02154508-v', 141), SenseInfo('02285629-v', 86), SenseInfo('00918872-v', 57), SenseInfo('00715239-v', 57), SenseInfo('02128873-v', 45), SenseInfo('02213336-v', 41), SenseInfo('01637982-v', 34), SenseInfo('00721437-v', 29), SenseInfo('02212275-v', 16), SenseInfo('00971999-v', 16), SenseInfo('00522751-v', 13), SenseInfo('02197781-v', 11), SenseInfo('02247977-v', 0), SenseInfo('02021653-v', 0), SenseInfo('00250691-v', 0), SenseInfo('02248465-v', 159), SenseInfo('02154508-v', 141), SenseInfo('02285629-v', 86), SenseInfo('00918872-v', 57), SenseInfo('00715239-v', 57), SenseInfo('02128873-v', 45), SenseInfo('02213336-v', 41), SenseInfo('01637982-v', 34), SenseInfo('00721437-v', 29), SenseInfo('02212275-v', 16), SenseInfo('00971999-v', 16), SenseInfo('00522751-v', 13), SenseInfo('02197781-v', 11), SenseInfo('02247977-v', 0), SenseInfo('02021653-v', 0), SenseInfo('00250691-v', 0), SenseInfo('02248465-v', 159), SenseInfo('02154508-v', 141), SenseInfo('02285629-v', 86), SenseInfo('00918872-v', 57), SenseInfo('00715239-v', 57), SenseInfo('02128873-v', 45), SenseInfo('02213336-v', 41), SenseInfo('01637982-v', 34), SenseInfo('00721437-v', 29), SenseInfo('02212275-v', 16), SenseInfo('00971999-v', 16), SenseInfo('00522751-v', 13), SenseInfo('02197781-v', 11), SenseInfo('02247977-v', 0), SenseInfo('02021653-v', 0), SenseInfo('00250691-v', 0) ],
"_excruciating_a_1_rel" : [ SenseInfo('01711724-a', 1) ],
"_stuffy_a_1_rel" : [ SenseInfo('02509484-a', 1), SenseInfo('00606347-a', 1), SenseInfo('01622033-a', 0), SenseInfo('02509484-a', 1), SenseInfo('00606347-a', 1), SenseInfo('01622033-a', 0), SenseInfo('02509484-a', 1), SenseInfo('00606347-a', 1), SenseInfo('01622033-a', 0) ],
"_grab_v_i_rel" : [ SenseInfo('01439190-v', 27), SenseInfo('02304648-v', 4), SenseInfo('02099239-v', 1), SenseInfo('02358217-v', 0), SenseInfo('01350283-v', 0), SenseInfo('00737476-v', 0) ],
"_at+all_a_1_rel" : [  ],
"_solubility_n_1_rel" : [ SenseInfo('13583272-n', 0), SenseInfo('05215483-n', 0), SenseInfo('05210221-n', 0) ],
"_aide_n_1_rel" : [ SenseInfo('09770179-n', 3), SenseInfo('09780249-n', 1) ],
"_afoot_a_1_rel" : [ SenseInfo('01562167-a', 0), SenseInfo('00666784-a', 0) ],
"_homebound_a_1_rel" : [ SenseInfo('00558827-a', 0) ],
"_smuggler_n_1_rel" : [ SenseInfo('10615334-n', 2) ],
"_predelivery_n_of_rel" : [  ],
"_revolution_n_of_rel" : [ SenseInfo('07424109-n', 6), SenseInfo('00962722-n', 6), SenseInfo('07440979-n', 0) ],
"_outcast_n_1_rel" : [ SenseInfo('10386312-n', 2) ],
"_bug_v_1_rel" : [ SenseInfo('01803380-v', 1), SenseInfo('02188848-v', 0) ],
"_derivatize_v_1_rel" : [  ],
"_by+the+way_a_1_rel" : [  ],
"_iris_n_1_rel" : [ SenseInfo('12411922-n', 0), SenseInfo('05319936-n', 0), SenseInfo('03584649-n', 0) ],
"_unsupported_a_1_rel" : [ SenseInfo('02353026-a', 0), SenseInfo('02352301-a', 0), SenseInfo('02353026-a', 0), SenseInfo('02352301-a', 0) ],
"_had+better_v_qmodal_rel" : [  ],
"_conceive_v_1_rel" : [ SenseInfo('01633343-v', 21), SenseInfo('00689344-v', 10), SenseInfo('00054285-v', 2), SenseInfo('01633343-v', 21), SenseInfo('00689344-v', 10), SenseInfo('00054285-v', 2), SenseInfo('01633343-v', 21), SenseInfo('00689344-v', 10), SenseInfo('00054285-v', 2) ],
"_bunch_v_1_rel" : [ SenseInfo('02027411-v', 2), SenseInfo('01484392-v', 1) ],
"_aka_p_rel" : [  ],
"_spurt_v_out_rel" : [ SenseInfo('02068413-v', 0), SenseInfo('01884126-v', 0) ],
"_mind_v_1_rel" : [ SenseInfo('00848707-v', 15), SenseInfo('00724492-v', 5), SenseInfo('02437707-v', 2), SenseInfo('02571901-v', 0), SenseInfo('00724664-v', 0), SenseInfo('00609506-v', 0), SenseInfo('00848707-v', 15), SenseInfo('00724492-v', 5), SenseInfo('02437707-v', 2), SenseInfo('02571901-v', 0), SenseInfo('00724664-v', 0), SenseInfo('00609506-v', 0), SenseInfo('00848707-v', 15), SenseInfo('00724492-v', 5), SenseInfo('02437707-v', 2), SenseInfo('02571901-v', 0), SenseInfo('00724664-v', 0), SenseInfo('00609506-v', 0) ],
"_bastille_n_1_rel" : [ SenseInfo('02805584-n', 0), SenseInfo('02805443-n', 0) ],
"_have_v_off_rel" : [ SenseInfo('02203362-v', 1202), SenseInfo('02630189-v', 377), SenseInfo('02108026-v', 220), SenseInfo('02204692-v', 143), SenseInfo('00120796-v', 64), SenseInfo('01156834-v', 42), SenseInfo('02378453-v', 31), SenseInfo('01733477-v', 30), SenseInfo('02205098-v', 28), SenseInfo('02740745-v', 25), SenseInfo('00121046-v', 25), SenseInfo('00065370-v', 11), SenseInfo('00770437-v', 8), SenseInfo('02236124-v', 7), SenseInfo('02210119-v', 7), SenseInfo('00065639-v', 5), SenseInfo('02355596-v', 3), SenseInfo('00056930-v', 3), SenseInfo('01427127-v', 2) ],
"_cookery_n_1_rel" : [ SenseInfo('00243918-n', 0) ],
"_non_a_1_rel" : [  ],
"_view_v_as_rel" : [ SenseInfo('00690614-v', 19), SenseInfo('02130300-v', 12), SenseInfo('02150948-v', 2), SenseInfo('00690614-v', 19), SenseInfo('02130300-v', 12), SenseInfo('02150948-v', 2), SenseInfo('00690614-v', 19), SenseInfo('02130300-v', 12), SenseInfo('02150948-v', 2) ],
"_champ_n_1_rel" : [ SenseInfo('09906704-n', 1) ],
"_sculpt_v_1_rel" : [ SenseInfo('01684337-v', 0), SenseInfo('01551871-v', 0) ],
"_becoming_a_1_rel" : [ SenseInfo('01878870-a', 0), SenseInfo('00907972-a', 0) ],
"_suppression_n_of_rel" : [ SenseInfo('13563647-n', 0), SenseInfo('01147950-n', 0), SenseInfo('01079604-n', 0), SenseInfo('01070892-n', 0) ],
"_uncomfortable_a_1_rel" : [ SenseInfo('00479933-a', 2), SenseInfo('00478015-a', 2), SenseInfo('00479933-a', 2), SenseInfo('00478015-a', 2), SenseInfo('00479933-a', 2), SenseInfo('00478015-a', 2) ],
"_implant_n_1_rel" : [ SenseInfo('03563710-n', 0) ],
"_very_x_deg_rel" : [ SenseInfo('00031899-r', 260), SenseInfo('01839317-a', 19), SenseInfo('02068946-a', 14), SenseInfo('00510749-r', 11) ],
"_stash_n_1_rel" : [ SenseInfo('13366912-n', 0) ],
"_mint_n_1_rel" : [ SenseInfo('13774404-n', 1), SenseInfo('12855042-n', 0), SenseInfo('12839319-n', 0), SenseInfo('07819166-n', 0), SenseInfo('07606278-n', 0), SenseInfo('03772269-n', 0) ],
"_coil_v_1_rel" : [ SenseInfo('02049190-v', 2), SenseInfo('01663580-v', 0), SenseInfo('01523986-v', 0) ],
"_remain_v_of_rel" : [ SenseInfo('00117985-v', 128), SenseInfo('02727462-v', 38), SenseInfo('02637592-v', 34), SenseInfo('02731024-v', 9) ],
"_paragliding_n_1_rel" : [ SenseInfo('00304349-n', 0) ],
"_pluck_v_up_rel" : [ SenseInfo('01592456-v', 3), SenseInfo('02322596-v', 0), SenseInfo('02319050-v', 0), SenseInfo('01452546-v', 0), SenseInfo('01384275-v', 0), SenseInfo('01382083-v', 0), SenseInfo('01592456-v', 3), SenseInfo('02322596-v', 0), SenseInfo('02319050-v', 0), SenseInfo('01452546-v', 0), SenseInfo('01384275-v', 0), SenseInfo('01382083-v', 0) ],
"_encounter_n_1_rel" : [ SenseInfo('00959376-n', 7), SenseInfo('07414922-n', 4), SenseInfo('00147187-n', 3), SenseInfo('07181043-n', 0) ],
"_free+wheeling_a_1_rel" : [ SenseInfo('02001240-a', 1), SenseInfo('01998260-a', 0), SenseInfo('02001240-a', 1), SenseInfo('01998260-a', 0) ],
"_diphthong_n_1_rel" : [ SenseInfo('07112364-n', 0), SenseInfo('07112364-n', 0) ],
"_islet_n_1_rel" : [ SenseInfo('09319456-n', 0) ],
"_dress_v_in_rel" : [ SenseInfo('00046534-v', 15), SenseInfo('00047945-v', 8), SenseInfo('01266269-v', 2), SenseInfo('00044797-v', 2), SenseInfo('00043683-v', 2), SenseInfo('00542809-v', 1), SenseInfo('02036650-v', 0), SenseInfo('01679433-v', 0), SenseInfo('01466543-v', 0), SenseInfo('01364184-v', 0), SenseInfo('01321002-v', 0), SenseInfo('01262813-v', 0), SenseInfo('00511636-v', 0), SenseInfo('00082714-v', 0), SenseInfo('00045639-v', 0), SenseInfo('00038849-v', 0), SenseInfo('00046534-v', 15), SenseInfo('00047945-v', 8), SenseInfo('01266269-v', 2), SenseInfo('00044797-v', 2), SenseInfo('00043683-v', 2), SenseInfo('00542809-v', 1), SenseInfo('02036650-v', 0), SenseInfo('01679433-v', 0), SenseInfo('01466543-v', 0), SenseInfo('01364184-v', 0), SenseInfo('01321002-v', 0), SenseInfo('01262813-v', 0), SenseInfo('00511636-v', 0), SenseInfo('00082714-v', 0), SenseInfo('00045639-v', 0), SenseInfo('00038849-v', 0) ],
"_offer_v_up_rel" : [ SenseInfo('02296726-v', 95), SenseInfo('02297142-v', 31), SenseInfo('02425112-v', 12), SenseInfo('00706557-v', 4), SenseInfo('02297742-v', 3), SenseInfo('02297409-v', 3), SenseInfo('02298632-v', 1), SenseInfo('02157361-v', 1), SenseInfo('02613487-v', 0), SenseInfo('02376289-v', 0), SenseInfo('02297948-v', 0), SenseInfo('00879764-v', 0), SenseInfo('00871623-v', 0) ],
"_inevitable_a_1_rel" : [ SenseInfo('00343015-a', 5), SenseInfo('01841834-a', 3), SenseInfo('00343015-a', 5), SenseInfo('01841834-a', 3), SenseInfo('00343015-a', 5), SenseInfo('01841834-a', 3) ],
"_inure_v_to_rel" : [ SenseInfo('00272910-v', 3), SenseInfo('00272910-v', 3) ],
"_anglo-saxon_a_1_rel" : [ SenseInfo('03114843-a', 1), SenseInfo('03114843-a', 1) ],
"_inconspicuous_a_1_rel" : [ SenseInfo('00581401-a', 0) ],
"_buffer_v_1_rel" : [ SenseInfo('00513344-v', 5), SenseInfo('01576917-v', 0) ],
"_guestroom_n_1_rel" : [ SenseInfo('03465718-n', 0) ],
"_detection_n_of_rel" : [ SenseInfo('05710687-n', 4), SenseInfo('00151087-n', 2), SenseInfo('06281175-n', 0), SenseInfo('00635205-n', 0) ],
"_stirring_a_for_rel" : [ SenseInfo('02307026-a', 0), SenseInfo('01561429-a', 0), SenseInfo('02307026-a', 0), SenseInfo('01561429-a', 0), SenseInfo('02307026-a', 0), SenseInfo('01561429-a', 0) ],
"_name-drop_v_1_rel" : [ SenseInfo('01025089-v', 0), SenseInfo('01025089-v', 0) ],
"_back_v_off_rel" : [ SenseInfo('02453889-v', 7), SenseInfo('01997119-v', 6), SenseInfo('02556817-v', 4), SenseInfo('01997512-v', 4), SenseInfo('02217695-v', 2), SenseInfo('02693965-v', 0), SenseInfo('01139104-v', 0), SenseInfo('00560628-v', 0), SenseInfo('00223109-v', 0), SenseInfo('00185857-v', 0) ],
"_average_v_1_rel" : [ SenseInfo('02645389-v', 15), SenseInfo('02527294-v', 2), SenseInfo('00639998-v', 1) ],
"_chromatographic_a_1_rel" : [ SenseInfo('02987910-a', 3) ],
"_inclusion_n_of_rel" : [ SenseInfo('13936304-n', 0), SenseInfo('13794034-n', 0), SenseInfo('09310806-n', 0), SenseInfo('00373130-n', 0) ],
"_crucify_v_1_rel" : [ SenseInfo('02484049-v', 2), SenseInfo('01803003-v', 1), SenseInfo('01801847-v', 0), SenseInfo('00823827-v', 0) ],
"_piston_v_1_rel" : [  ],
"_pay_v_for_rel" : [ SenseInfo('02251743-v', 138), SenseInfo('01060494-v', 26), SenseInfo('02252931-v', 12), SenseInfo('02291708-v', 6), SenseInfo('02253456-v', 6), SenseInfo('00732224-v', 4), SenseInfo('02732292-v', 3), SenseInfo('02488056-v', 1), SenseInfo('00737884-v', 1), SenseInfo('02344243-v', 0), SenseInfo('02253154-v', 0), SenseInfo('02251743-v', 138), SenseInfo('01060494-v', 26), SenseInfo('02252931-v', 12), SenseInfo('02291708-v', 6), SenseInfo('02253456-v', 6), SenseInfo('00732224-v', 4), SenseInfo('02732292-v', 3), SenseInfo('02488056-v', 1), SenseInfo('00737884-v', 1), SenseInfo('02344243-v', 0), SenseInfo('02253154-v', 0), SenseInfo('02251743-v', 138), SenseInfo('01060494-v', 26), SenseInfo('02252931-v', 12), SenseInfo('02291708-v', 6), SenseInfo('02253456-v', 6), SenseInfo('00732224-v', 4), SenseInfo('02732292-v', 3), SenseInfo('02488056-v', 1), SenseInfo('00737884-v', 1), SenseInfo('02344243-v', 0), SenseInfo('02253154-v', 0), SenseInfo('02251743-v', 138), SenseInfo('01060494-v', 26), SenseInfo('02252931-v', 12), SenseInfo('02291708-v', 6), SenseInfo('02253456-v', 6), SenseInfo('00732224-v', 4), SenseInfo('02732292-v', 3), SenseInfo('02488056-v', 1), SenseInfo('00737884-v', 1), SenseInfo('02344243-v', 0), SenseInfo('02253154-v', 0), SenseInfo('02251743-v', 138), SenseInfo('01060494-v', 26), SenseInfo('02252931-v', 12), SenseInfo('02291708-v', 6), SenseInfo('02253456-v', 6), SenseInfo('00732224-v', 4), SenseInfo('02732292-v', 3), SenseInfo('02488056-v', 1), SenseInfo('00737884-v', 1), SenseInfo('02344243-v', 0), SenseInfo('02253154-v', 0) ],
"_repetitious_a_1_rel" : [ SenseInfo('01964367-a', 0), SenseInfo('01964367-a', 0) ],
"_whereas_x_rel" : [  ],
"_downs_n_1_rel" : [ SenseInfo('01896561-n', 1), SenseInfo('00458286-n', 1), SenseInfo('10942144-n', 0), SenseInfo('09269341-n', 0), SenseInfo('05255692-n', 0), SenseInfo('01896561-n', 1), SenseInfo('00458286-n', 1), SenseInfo('10942144-n', 0), SenseInfo('09269341-n', 0), SenseInfo('05255692-n', 0) ],
"_wrestle_v_1_rel" : [ SenseInfo('01092981-v', 2), SenseInfo('00813495-v', 1), SenseInfo('01868370-v', 0), SenseInfo('01504699-v', 0), SenseInfo('01092981-v', 2), SenseInfo('00813495-v', 1), SenseInfo('01868370-v', 0), SenseInfo('01504699-v', 0) ],
"_fret_v_1_rel" : [ SenseInfo('01793933-v', 3), SenseInfo('01767461-v', 2), SenseInfo('02330109-v', 0), SenseInfo('02119659-v', 0), SenseInfo('01789164-v', 0), SenseInfo('01773825-v', 0), SenseInfo('01752025-v', 0), SenseInfo('01751722-v', 0), SenseInfo('01570562-v', 0), SenseInfo('01250908-v', 0), SenseInfo('00274724-v', 0), SenseInfo('00274633-v', 0), SenseInfo('01793933-v', 3), SenseInfo('01767461-v', 2), SenseInfo('02330109-v', 0), SenseInfo('02119659-v', 0), SenseInfo('01789164-v', 0), SenseInfo('01773825-v', 0), SenseInfo('01752025-v', 0), SenseInfo('01751722-v', 0), SenseInfo('01570562-v', 0), SenseInfo('01250908-v', 0), SenseInfo('00274724-v', 0), SenseInfo('00274633-v', 0) ],
"_clout_n_1_rel" : [ SenseInfo('07262278-n', 0), SenseInfo('05157274-n', 0), SenseInfo('03052917-n', 0), SenseInfo('00134780-n', 0) ],
"_malnutrition_n_1_rel" : [ SenseInfo('14199700-n', 0) ],
"_resident_a_1_rel" : [ SenseInfo('02125409-a', 2), SenseInfo('02129136-a', 1) ],
"_cash_v_in-i_rel" : [ SenseInfo('02256354-v', 2) ],
"_scaly_a_1_rel" : [ SenseInfo('02241247-a', 0), SenseInfo('00147160-a', 0) ],
"_clench_v_1_rel" : [ SenseInfo('01572978-v', 1), SenseInfo('01394812-v', 1) ],
"_cranny_n_1_rel" : [ SenseInfo('13907272-n', 0), SenseInfo('09259104-n', 0) ],
"_exhale_v_1_rel" : [ SenseInfo('00004227-v', 2), SenseInfo('00004605-v', 0) ],
"_journey_n_of_rel" : [ SenseInfo('00306426-n', 17) ],
"_hawaiian_n_1_rel" : [ SenseInfo('06938493-n', 2), SenseInfo('09742569-n', 0) ],
"_rebate_n_of_rel" : [ SenseInfo('13282275-n', 0), SenseInfo('04036776-n', 0) ],
"_outcrop_n_1_rel" : [ SenseInfo('09381242-n', 0) ],
"_outboard_a_1_rel" : [ SenseInfo('01291391-a', 0) ],
"_mass_n_of_rel" : [ SenseInfo('05024254-n', 35), SenseInfo('13774404-n', 14), SenseInfo('07962124-n', 12), SenseInfo('01042242-n', 10), SenseInfo('09348055-n', 6), SenseInfo('08180190-n', 4), SenseInfo('05099389-n', 3), SenseInfo('07033753-n', 0), SenseInfo('07033613-n', 0) ],
"_hammer_v_out_rel" : [ SenseInfo('01416539-v', 4), SenseInfo('01675245-v', 0) ],
"_read_v_off_rel" : [ SenseInfo('00625119-v', 115), SenseInfo('02730813-v', 17), SenseInfo('00626428-v', 15), SenseInfo('00627520-v', 5), SenseInfo('00627091-v', 5), SenseInfo('00624476-v', 5), SenseInfo('00599992-v', 4), SenseInfo('00922867-v', 3), SenseInfo('01718755-v', 0), SenseInfo('00620239-v', 0), SenseInfo('00593852-v', 0) ],
"_settlement_n_of_rel" : [ SenseInfo('08374049-n', 7), SenseInfo('08226699-n', 2), SenseInfo('07177924-n', 2), SenseInfo('01252280-n', 2), SenseInfo('05789089-n', 1), SenseInfo('08672562-n', 0), SenseInfo('00228535-n', 0) ],
"_recognizable_a_1_rel" : [ SenseInfo('01747996-a', 2), SenseInfo('01272920-a', 2) ],
"_young_a_1_rel" : [ SenseInfo('01646941-a', 107), SenseInfo('00818008-a', 1), SenseInfo('01649720-a', 0), SenseInfo('01643480-a', 0), SenseInfo('00937732-a', 0), SenseInfo('01646941-a', 107), SenseInfo('00818008-a', 1), SenseInfo('01649720-a', 0), SenseInfo('01643480-a', 0), SenseInfo('00937732-a', 0), SenseInfo('01646941-a', 107), SenseInfo('00818008-a', 1), SenseInfo('01649720-a', 0), SenseInfo('01643480-a', 0), SenseInfo('00937732-a', 0) ],
"_formal_a_1_rel" : [ SenseInfo('01041916-a', 13), SenseInfo('01633153-a', 3), SenseInfo('01045216-a', 2), SenseInfo('01980796-a', 0), SenseInfo('01430628-a', 0), SenseInfo('00751838-a', 0), SenseInfo('01041916-a', 13), SenseInfo('01633153-a', 3), SenseInfo('01045216-a', 2), SenseInfo('01980796-a', 0), SenseInfo('01430628-a', 0), SenseInfo('00751838-a', 0) ],
"_creepy_a_1_rel" : [ SenseInfo('01625760-a', 0), SenseInfo('00195191-a', 0), SenseInfo('01625760-a', 0), SenseInfo('00195191-a', 0), SenseInfo('01625760-a', 0), SenseInfo('00195191-a', 0) ],
"_prudence_n_1_rel" : [ SenseInfo('04892794-n', 1), SenseInfo('05615500-n', 0) ],
"_wing_v_1_rel" : [ SenseInfo('01940403-v', 5), SenseInfo('01940403-v', 5) ],
"_defuel_v_1_rel" : [  ],
"_foreordained_a_1_rel" : [ SenseInfo('00341017-a', 0) ],
"_factual_a_1_rel" : [ SenseInfo('01933731-a', 1), SenseInfo('02899112-a', 0) ],
"_file_n_of_rel" : [ SenseInfo('06508816-n', 17), SenseInfo('08428756-n', 1), SenseInfo('03337140-n', 1), SenseInfo('03336839-n', 1), SenseInfo('06508816-n', 17), SenseInfo('08428756-n', 1), SenseInfo('03337140-n', 1), SenseInfo('03336839-n', 1) ],
"_bounty_n_1_rel" : [ SenseInfo('13272059-n', 0), SenseInfo('05115418-n', 0), SenseInfo('04832244-n', 0), SenseInfo('02878883-n', 0) ],
"_congratulations_n_1_rel" : [ SenseInfo('06633896-n', 4), SenseInfo('07140348-n', 0) ],
"_roger_a_1_rel" : [  ],
"_oval_n_1_rel" : [ SenseInfo('13878306-n', 3) ],
"_begrudge_v_1_rel" : [ SenseInfo('01827064-v', 0), SenseInfo('01825125-v', 0) ],
"_lark_n_1_rel" : [ SenseInfo('01573074-n', 0), SenseInfo('01528654-n', 0), SenseInfo('01527617-n', 0), SenseInfo('00429322-n', 0) ],
"_reaffirm_v_1_rel" : [ SenseInfo('01011923-v', 6) ],
"_hindrance_n_1_rel" : [ SenseInfo('05689249-n', 0), SenseInfo('03520811-n', 0), SenseInfo('01073995-n', 0) ],
"_abstract_v_1_rel" : [ SenseInfo('00692329-v', 5), SenseInfo('02276866-v', 1), SenseInfo('00734587-v', 1), SenseInfo('01008288-v', 0) ],
"_lending_n_1_rel" : [ SenseInfo('01093666-n', 1) ],
"_inflate_v_cause_rel" : [ SenseInfo('00264386-v', 1), SenseInfo('00264034-v', 1), SenseInfo('00562882-v', 0), SenseInfo('00562523-v', 0), SenseInfo('00256117-v', 0) ],
"_hardtack_n_1_rel" : [ SenseInfo('07694839-n', 3), SenseInfo('15100570-n', 1) ],
"_bedrock_n_1_rel" : [ SenseInfo('09218044-n', 0), SenseInfo('05871362-n', 0) ],
"_webcam_n_1_rel" : [ SenseInfo('04569063-n', 0) ],
"_holey_a_1_rel" : [ SenseInfo('01397998-a', 0) ],
"_eavesdrop_v_1_rel" : [ SenseInfo('02189714-v', 0) ],
"_consecutive_a_1_rel" : [ SenseInfo('00127543-a', 3), SenseInfo('01667729-a', 0), SenseInfo('00596511-a', 0), SenseInfo('00127543-a', 3), SenseInfo('01667729-a', 0), SenseInfo('00596511-a', 0) ],
"_yellow_v_1_rel" : [ SenseInfo('00289840-v', 2) ],
"_turban_n_1_rel" : [ SenseInfo('04498389-n', 2), SenseInfo('03937835-n', 0) ],
"_six-pack_n_of_rel" : [ SenseInfo('04225222-n', 0), SenseInfo('04225222-n', 0) ],
"_magic_a_1_rel" : [ SenseInfo('01576071-a', 3) ],
"_self-interest_n_1_rel" : [ SenseInfo('04835488-n', 1), SenseInfo('04835028-n', 0) ],
"_spectroscopy_n_1_rel" : [ SenseInfo('00649482-n', 3) ],
"_sinapism_n_1_rel" : [ SenseInfo('03802800-n', 0) ],
"_ply_v_1_rel" : [ SenseInfo('01182709-v', 1), SenseInfo('02595383-v', 0), SenseInfo('01864038-v', 0), SenseInfo('01291817-v', 0), SenseInfo('01224653-v', 0), SenseInfo('01160806-v', 0) ],
"_believable_a_1_rel" : [ SenseInfo('00644839-a', 1), SenseInfo('00644839-a', 1) ],
"_shot_a_1_rel" : [ SenseInfo('00403072-a', 0) ],
"_sample_v_1_rel" : [ SenseInfo('01195299-v', 7) ],
"_believer_n_1_rel" : [ SenseInfo('09848489-n', 1), SenseInfo('09847727-n', 1) ],
"_born_a_of_rel" : [ SenseInfo('01733462-a', 5), SenseInfo('01335708-a', 0), SenseInfo('01733462-a', 5), SenseInfo('01335708-a', 0) ],
"_masculine_a_1_rel" : [ SenseInfo('01486084-a', 2), SenseInfo('01483324-a', 1), SenseInfo('02319922-a', 0) ],
"_infield_a_1_rel" : [ SenseInfo('02799593-n', 4) ],
"_treeline_n_1_rel" : [  ],
"_specialty_n_1_rel" : [ SenseInfo('05159225-n', 2), SenseInfo('04763925-n', 0), SenseInfo('00583461-n', 0) ],
"_pointillism_n_1_rel" : [ SenseInfo('08276053-n', 0), SenseInfo('03975419-n', 0) ],
"_reservoir_n_1_rel" : [ SenseInfo('13776854-n', 2), SenseInfo('04078747-n', 1), SenseInfo('04078574-n', 1), SenseInfo('09407867-n', 0) ],
"_substrate_n_1_rel" : [ SenseInfo('14738892-n', 2), SenseInfo('08660146-n', 0), SenseInfo('08657887-n', 0), SenseInfo('06903699-n', 0) ],
"_opt_v_out+of_rel" : [ SenseInfo('00679389-v', 0) ],
"_handy_a_1_rel" : [ SenseInfo('00019731-a', 2), SenseInfo('00604897-a', 1), SenseInfo('00062626-a', 0) ],
"_socialist_n_1_rel" : [ SenseInfo('10618848-n', 1) ],
"_in+the+event_x_rel" : [  ],
"_affect_v_1_rel" : [ SenseInfo('00137313-v', 43), SenseInfo('00019448-v', 11), SenseInfo('02677097-v', 4), SenseInfo('00838043-v', 4), SenseInfo('01767949-v', 0), SenseInfo('00137313-v', 43), SenseInfo('00019448-v', 11), SenseInfo('02677097-v', 4), SenseInfo('00838043-v', 4), SenseInfo('01767949-v', 0), SenseInfo('00137313-v', 43), SenseInfo('00019448-v', 11), SenseInfo('02677097-v', 4), SenseInfo('00838043-v', 4), SenseInfo('01767949-v', 0) ],
"_rewarding_a_1_rel" : [ SenseInfo('02015571-a', 2), SenseInfo('02015571-a', 2) ],
"_co-ed_n_1_rel" : [ SenseInfo('09934213-n', 0), SenseInfo('09934213-n', 0) ],
"_iPod_n_1_rel" : [ SenseInfo('03584254-n', 0), SenseInfo('03584254-n', 0), SenseInfo('03584254-n', 0), SenseInfo('03584254-n', 0) ],
"_rich_a_in_rel" : [ SenseInfo('02021905-a', 17), SenseInfo('02024143-a', 5), SenseInfo('02501693-a', 2), SenseInfo('01081340-a', 2), SenseInfo('00403385-a', 2), SenseInfo('01866429-a', 1), SenseInfo('02026785-a', 0), SenseInfo('02024758-a', 0), SenseInfo('02560402-a', 0), SenseInfo('02397234-a', 0), SenseInfo('01457369-a', 0), SenseInfo('00014490-a', 0), SenseInfo('02021905-a', 17), SenseInfo('02024143-a', 5), SenseInfo('02501693-a', 2), SenseInfo('01081340-a', 2), SenseInfo('00403385-a', 2), SenseInfo('01866429-a', 1), SenseInfo('02026785-a', 0), SenseInfo('02024758-a', 0), SenseInfo('02560402-a', 0), SenseInfo('02397234-a', 0), SenseInfo('01457369-a', 0), SenseInfo('00014490-a', 0), SenseInfo('02021905-a', 17), SenseInfo('02024143-a', 5), SenseInfo('02501693-a', 2), SenseInfo('01081340-a', 2), SenseInfo('00403385-a', 2), SenseInfo('01866429-a', 1), SenseInfo('02026785-a', 0), SenseInfo('02024758-a', 0), SenseInfo('02560402-a', 0), SenseInfo('02397234-a', 0), SenseInfo('01457369-a', 0), SenseInfo('00014490-a', 0), SenseInfo('02021905-a', 17), SenseInfo('02024143-a', 5), SenseInfo('02501693-a', 2), SenseInfo('01081340-a', 2), SenseInfo('00403385-a', 2), SenseInfo('01866429-a', 1), SenseInfo('02026785-a', 0), SenseInfo('02024758-a', 0), SenseInfo('02560402-a', 0), SenseInfo('02397234-a', 0), SenseInfo('01457369-a', 0), SenseInfo('00014490-a', 0), SenseInfo('02021905-a', 17), SenseInfo('02024143-a', 5), SenseInfo('02501693-a', 2), SenseInfo('01081340-a', 2), SenseInfo('00403385-a', 2), SenseInfo('01866429-a', 1), SenseInfo('02026785-a', 0), SenseInfo('02024758-a', 0), SenseInfo('02560402-a', 0), SenseInfo('02397234-a', 0), SenseInfo('01457369-a', 0), SenseInfo('00014490-a', 0), SenseInfo('02021905-a', 17), SenseInfo('02024143-a', 5), SenseInfo('02501693-a', 2), SenseInfo('01081340-a', 2), SenseInfo('00403385-a', 2), SenseInfo('01866429-a', 1), SenseInfo('02026785-a', 0), SenseInfo('02024758-a', 0), SenseInfo('02560402-a', 0), SenseInfo('02397234-a', 0), SenseInfo('01457369-a', 0), SenseInfo('00014490-a', 0) ],
"_goggle_n_1_rel" : [  ],
"_religion_n_1_rel" : [ SenseInfo('05946687-n', 63), SenseInfo('08081668-n', 9) ],
"_photon_n_1_rel" : [ SenseInfo('09391223-n', 1) ],
"_finale_n_1_rel" : [ SenseInfo('07039478-n', 2), SenseInfo('15267536-n', 0), SenseInfo('00210797-n', 0) ],
"_prime+minister_n_of_rel" : [ SenseInfo('09907196-n', 16), SenseInfo('09906986-n', 16) ],
"_handwriting_n_1_rel" : [ SenseInfo('06403393-n', 2), SenseInfo('00614730-n', 0) ],
"_pretend_a_1_rel" : [ SenseInfo('01937759-a', 0) ],
"_ox_n_1_rel" : [ SenseInfo('02403003-n', 1), SenseInfo('02402175-n', 0) ],
"_emperor_n_1_rel" : [ SenseInfo('10053004-n', 0), SenseInfo('07760070-n', 0), SenseInfo('02301935-n', 0), SenseInfo('02278839-n', 0) ],
"_geometric_a_1_rel" : [ SenseInfo('01981009-a', 9), SenseInfo('02735208-a', 2) ],
"_lustrous_a_1_rel" : [ SenseInfo('01812237-a', 0), SenseInfo('01122269-a', 0), SenseInfo('00281657-a', 0) ],
"_slippery_a_1_rel" : [ SenseInfo('02234781-a', 3), SenseInfo('02466734-a', 0), SenseInfo('02234781-a', 3), SenseInfo('02466734-a', 0), SenseInfo('02234781-a', 3), SenseInfo('02466734-a', 0) ],
"_preface_n_1_rel" : [ SenseInfo('06397903-n', 1) ],
"_unconfirmed_a_1_rel" : [ SenseInfo('01634851-a', 0), SenseInfo('01634851-a', 0) ],
"_laboratory_n_1_rel" : [ SenseInfo('03629986-n', 19), SenseInfo('08662570-n', 0) ],
"_philosophical_a_1_rel" : [ SenseInfo('02858231-a', 7), SenseInfo('00858053-a', 2), SenseInfo('02858231-a', 7), SenseInfo('00858053-a', 2) ],
"_stiff_a_1_rel" : [ SenseInfo('01525659-a', 2), SenseInfo('02323726-a', 1), SenseInfo('01043924-a', 1), SenseInfo('01824244-a', 0), SenseInfo('01990653-a', 0), SenseInfo('01023706-a', 0), SenseInfo('00798103-a', 0), SenseInfo('01525659-a', 2), SenseInfo('02323726-a', 1), SenseInfo('01043924-a', 1), SenseInfo('01824244-a', 0), SenseInfo('01990653-a', 0), SenseInfo('01023706-a', 0), SenseInfo('00798103-a', 0), SenseInfo('01525659-a', 2), SenseInfo('02323726-a', 1), SenseInfo('01043924-a', 1), SenseInfo('01824244-a', 0), SenseInfo('01990653-a', 0), SenseInfo('01023706-a', 0), SenseInfo('00798103-a', 0), SenseInfo('01525659-a', 2), SenseInfo('02323726-a', 1), SenseInfo('01043924-a', 1), SenseInfo('01824244-a', 0), SenseInfo('01990653-a', 0), SenseInfo('01023706-a', 0), SenseInfo('00798103-a', 0) ],
"_backpack_n_1_rel" : [ SenseInfo('02769748-n', 0) ],
"_operations+research_n_1_rel" : [ SenseInfo('00637546-n', 0) ],
"_nylon_n_1_rel" : [ SenseInfo('14966192-n', 0), SenseInfo('03836906-n', 0) ],
"_advisor_n_1_rel" : [ SenseInfo('09774266-n', 1) ],
"_chick_n_1_rel" : [ SenseInfo('01792042-n', 2), SenseInfo('09989045-n', 0) ],
"_vase_n_1_rel" : [ SenseInfo('04522168-n', 12) ],
"_temporary_a_1_rel" : [ SenseInfo('01755627-a', 6), SenseInfo('01089775-a', 0), SenseInfo('01755627-a', 6), SenseInfo('01089775-a', 0) ],
"_cart_n_1_rel" : [ SenseInfo('02970849-n', 5), SenseInfo('03484083-n', 1) ],
"_corrosive_a_1_rel" : [ SenseInfo('00587376-a', 1), SenseInfo('02079732-a', 0) ],
"_despise_v_1_rel" : [ SenseInfo('01774799-v', 8) ],
"_gaseous_a_1_rel" : [ SenseInfo('02262542-a', 1) ],
"_disclaim_v_1_rel" : [ SenseInfo('00758197-v', 0), SenseInfo('00757375-v', 0) ],
"_report_n_of_rel" : [ SenseInfo('07218470-n', 50), SenseInfo('07217924-n', 10), SenseInfo('06681551-n', 10), SenseInfo('07391516-n', 2), SenseInfo('07220300-n', 0), SenseInfo('06409752-n', 0), SenseInfo('06207199-n', 0), SenseInfo('07218470-n', 50), SenseInfo('07217924-n', 10), SenseInfo('06681551-n', 10), SenseInfo('07391516-n', 2), SenseInfo('07220300-n', 0), SenseInfo('06409752-n', 0), SenseInfo('06207199-n', 0), SenseInfo('07218470-n', 50), SenseInfo('07217924-n', 10), SenseInfo('06681551-n', 10), SenseInfo('07391516-n', 2), SenseInfo('07220300-n', 0), SenseInfo('06409752-n', 0), SenseInfo('06207199-n', 0), SenseInfo('07218470-n', 50), SenseInfo('07217924-n', 10), SenseInfo('06681551-n', 10), SenseInfo('07391516-n', 2), SenseInfo('07220300-n', 0), SenseInfo('06409752-n', 0), SenseInfo('06207199-n', 0) ],
"_degrade_v_1_rel" : [ SenseInfo('01307896-v', 1), SenseInfo('01800422-v', 0), SenseInfo('00207728-v', 0), SenseInfo('01307896-v', 1), SenseInfo('01800422-v', 0), SenseInfo('00207728-v', 0) ],
"_calligrapher_n_1_rel" : [ SenseInfo('09889170-n', 0) ],
"_device_n_1_rel" : [ SenseInfo('03183080-n', 36), SenseInfo('07068844-n', 2), SenseInfo('00171249-n', 2), SenseInfo('03185746-n', 0), SenseInfo('03185562-n', 0), SenseInfo('03183080-n', 36), SenseInfo('07068844-n', 2), SenseInfo('00171249-n', 2), SenseInfo('03185746-n', 0), SenseInfo('03185562-n', 0), SenseInfo('03183080-n', 36), SenseInfo('07068844-n', 2), SenseInfo('00171249-n', 2), SenseInfo('03185746-n', 0), SenseInfo('03185562-n', 0) ],
"_symbiotic_a_1_rel" : [ SenseInfo('00727268-a', 0) ],
"_ideal_n_1_rel" : [ SenseInfo('05923696-n', 7), SenseInfo('10325243-n', 2) ],
"_aposematic_a_1_rel" : [  ],
"_mint_v_1_rel" : [ SenseInfo('01639105-v', 0) ],
"_cassette_n_1_rel" : [ SenseInfo('02978881-n', 0) ],
"_prestige_n_1_rel" : [ SenseInfo('14435809-n', 11) ],
"_bassoon_n_1_rel" : [ SenseInfo('02804610-n', 0) ],
"_define_v_1_rel" : [ SenseInfo('02611630-v', 20), SenseInfo('00957378-v', 13), SenseInfo('02698319-v', 9), SenseInfo('02736778-v', 2), SenseInfo('00947077-v', 0), SenseInfo('02611630-v', 20), SenseInfo('00957378-v', 13), SenseInfo('02698319-v', 9), SenseInfo('02736778-v', 2), SenseInfo('00947077-v', 0) ],
"_seawater_n_1_rel" : [ SenseInfo('15008847-n', 1) ],
"_doghouse_n_1_rel" : [ SenseInfo('03610524-n', 1), SenseInfo('06200929-n', 0) ],
"_beside_p_rel" : [  ],
"_ecosystem_n_1_rel" : [ SenseInfo('08368757-n', 0) ],
"_snow_v_in_rel" : [ SenseInfo('02758977-v', 10), SenseInfo('00839194-v', 0) ],
"_genius_n_1_rel" : [ SenseInfo('10126926-n', 2), SenseInfo('05619743-n', 2), SenseInfo('09762509-n', 1), SenseInfo('05625373-n', 0), SenseInfo('05624461-n', 0) ],
"_modular_a_1_rel" : [ SenseInfo('02296415-a', 0) ],
"_capillary_n_1_rel" : [ SenseInfo('02956069-n', 2), SenseInfo('05425910-n', 0) ],
"_soap_v_1_rel" : [ SenseInfo('00036932-v', 0) ],
"_gas_v_1_rel" : [ SenseInfo('01125373-v', 1), SenseInfo('00883226-v', 0) ],
"_condensation_n_1_rel" : [ SenseInfo('06246700-n', 3), SenseInfo('13451348-n', 0), SenseInfo('11446242-n', 0), SenseInfo('07313241-n', 0), SenseInfo('06468123-n', 0), SenseInfo('00357680-n', 0) ],
"_silvery_a_1_rel" : [ SenseInfo('00301032-a', 1), SenseInfo('00283327-a', 1), SenseInfo('00387392-a', 0) ],
"_preliminary_a_1_rel" : [ SenseInfo('00878086-a', 11), SenseInfo('00878086-a', 11) ],
"_rebellion_n_1_rel" : [ SenseInfo('01177327-n', 5), SenseInfo('00962129-n', 5) ],
"_presumably_x_deg_rel" : [ SenseInfo('00053952-r', 16) ],
"_unwilling_a_1_rel" : [ SenseInfo('02566015-a', 1), SenseInfo('02522164-a', 0), SenseInfo('02566015-a', 1), SenseInfo('02522164-a', 0), SenseInfo('02566015-a', 1), SenseInfo('02522164-a', 0), SenseInfo('02566015-a', 1), SenseInfo('02522164-a', 0), SenseInfo('02566015-a', 1), SenseInfo('02522164-a', 0) ],
"_ministerial_a_1_rel" : [ SenseInfo('02764828-a', 1), SenseInfo('02764643-a', 0) ],
"_chase_v_1_rel" : [ SenseInfo('02001858-v', 10), SenseInfo('02535093-v', 0), SenseInfo('01583881-v', 0), SenseInfo('01277649-v', 0), SenseInfo('02001858-v', 10), SenseInfo('02535093-v', 0), SenseInfo('01583881-v', 0), SenseInfo('01277649-v', 0) ],
"_dictates_n_1_rel" : [ SenseInfo('06663940-n', 1), SenseInfo('05871245-n', 1), SenseInfo('06663940-n', 1), SenseInfo('05871245-n', 1) ],
"_relational_a_1_rel" : [ SenseInfo('00006245-a', 0) ],
"_bough_n_1_rel" : [ SenseInfo('13165727-n', 6) ],
"_cradle_n_1_rel" : [ SenseInfo('03125729-n', 2), SenseInfo('08510456-n', 1), SenseInfo('15142452-n', 0), SenseInfo('04098795-n', 0) ],
"_serene_a_1_rel" : [ SenseInfo('00529657-a', 0), SenseInfo('00461195-a', 0) ],
"_mostly_a_1_rel" : [  ],
"_although_p_1_rel" : [  ],
"_senior_a_1_rel" : [ SenseInfo('02099774-a', 3), SenseInfo('01013681-a', 1), SenseInfo('01644225-a', 0) ],
"_remarkable_a_1_rel" : [ SenseInfo('01678417-a', 13), SenseInfo('02163602-a', 2) ],
"_gorilla_n_1_rel" : [ SenseInfo('02480855-n', 0) ],
"_nanosecond_n_1_rel" : [ SenseInfo('15236015-n', 0), SenseInfo('15236015-n', 0), SenseInfo('15236015-n', 0) ],
"_henceforth_a_1_rel" : [  ],
"_wretch_n_1_rel" : [ SenseInfo('10793492-n', 1), SenseInfo('10453265-n', 1) ],
"_fetch_n_1_rel" : [ SenseInfo('00039916-n', 0) ],
"_japanese_a_1_rel" : [ SenseInfo('02965043-a', 10) ],
"_far_x_deg_rel" : [ SenseInfo('00101323-r', 61), SenseInfo('00101051-r', 39), SenseInfo('00101490-r', 22), SenseInfo('00442361-a', 20), SenseInfo('01434717-a', 5), SenseInfo('00101201-r', 3), SenseInfo('02032386-a', 1), SenseInfo('08016900-n', 0), SenseInfo('00101655-r', 0), SenseInfo('01535481-a', 0), SenseInfo('00101323-r', 61), SenseInfo('00101051-r', 39), SenseInfo('00101490-r', 22), SenseInfo('00442361-a', 20), SenseInfo('01434717-a', 5), SenseInfo('00101201-r', 3), SenseInfo('02032386-a', 1), SenseInfo('08016900-n', 0), SenseInfo('00101655-r', 0), SenseInfo('01535481-a', 0), SenseInfo('00101323-r', 61), SenseInfo('00101051-r', 39), SenseInfo('00101490-r', 22), SenseInfo('00442361-a', 20), SenseInfo('01434717-a', 5), SenseInfo('00101201-r', 3), SenseInfo('02032386-a', 1), SenseInfo('08016900-n', 0), SenseInfo('00101655-r', 0), SenseInfo('01535481-a', 0), SenseInfo('00101323-r', 61), SenseInfo('00101051-r', 39), SenseInfo('00101490-r', 22), SenseInfo('00442361-a', 20), SenseInfo('01434717-a', 5), SenseInfo('00101201-r', 3), SenseInfo('02032386-a', 1), SenseInfo('08016900-n', 0), SenseInfo('00101655-r', 0), SenseInfo('01535481-a', 0), SenseInfo('00101323-r', 61), SenseInfo('00101051-r', 39), SenseInfo('00101490-r', 22), SenseInfo('00442361-a', 20), SenseInfo('01434717-a', 5), SenseInfo('00101201-r', 3), SenseInfo('02032386-a', 1), SenseInfo('08016900-n', 0), SenseInfo('00101655-r', 0), SenseInfo('01535481-a', 0) ],
"_disagreeable_a_1_rel" : [ SenseInfo('00089355-a', 0), SenseInfo('01137882-a', 0), SenseInfo('00561359-a', 0) ],
"_bag_v_1_rel" : [ SenseInfo('01479874-v', 1), SenseInfo('02717362-v', 0), SenseInfo('02714360-v', 0), SenseInfo('02292432-v', 0), SenseInfo('01485839-v', 0) ],
"_incriminate_v_1_rel" : [ SenseInfo('02636921-v', 0), SenseInfo('00842989-v', 0), SenseInfo('02636921-v', 0), SenseInfo('00842989-v', 0), SenseInfo('02636921-v', 0), SenseInfo('00842989-v', 0), SenseInfo('02636921-v', 0), SenseInfo('00842989-v', 0), SenseInfo('02636921-v', 0), SenseInfo('00842989-v', 0) ],
"_entrance_n_1_rel" : [ SenseInfo('03290771-n', 10), SenseInfo('07370125-n', 5), SenseInfo('00049003-n', 3) ],
"_e+g_p_rel" : [  ],
"_drop+off_n_1_rel" : [ SenseInfo('13556509-n', 0), SenseInfo('09246464-n', 0), SenseInfo('07355887-n', 0), SenseInfo('13556509-n', 0), SenseInfo('09246464-n', 0), SenseInfo('07355887-n', 0) ],
"_spanker_n_1_rel" : [ SenseInfo('10608803-n', 0), SenseInfo('04267435-n', 0) ],
"_beauty_n_1_rel" : [ SenseInfo('04683814-n', 16), SenseInfo('10613996-n', 1), SenseInfo('05925702-n', 1) ],
"_fry_v_up_rel" : [ SenseInfo('02738241-v', 1), SenseInfo('00325328-v', 1), SenseInfo('02484957-v', 0) ],
"_divinity_n_1_rel" : [ SenseInfo('09505418-n', 4), SenseInfo('04854976-n', 1), SenseInfo('07605693-n', 0), SenseInfo('06182144-n', 0) ],
"_besiege_v_1_rel" : [ SenseInfo('01127411-v', 2), SenseInfo('01798287-v', 0), SenseInfo('00778122-v', 0) ],
"_deter_v_1_rel" : [ SenseInfo('00908099-v', 1), SenseInfo('00770141-v', 0) ],
"_shop_v_for_rel" : [ SenseInfo('02325968-v', 7), SenseInfo('02466134-v', 1), SenseInfo('02326355-v', 0), SenseInfo('00841986-v', 0) ],
"_repellency_n_1_rel" : [  ],
"_hitchhike_v_1_rel" : [ SenseInfo('01956955-v', 0), SenseInfo('01956955-v', 0) ],
"_knowing_a_1_rel" : [ SenseInfo('01307690-a', 2), SenseInfo('01338116-a', 0), SenseInfo('01307850-a', 0), SenseInfo('00830051-a', 0), SenseInfo('01307690-a', 2), SenseInfo('01338116-a', 0), SenseInfo('01307850-a', 0), SenseInfo('00830051-a', 0) ],
"_dutch_a_1_rel" : [ SenseInfo('02960686-a', 5) ],
"_ceiling_n_1_rel" : [ SenseInfo('02990373-n', 7), SenseInfo('05132542-n', 3), SenseInfo('06657646-n', 2), SenseInfo('05132667-n', 0) ],
"_mudstone_n_1_rel" : [  ],
"_level_v_off_rel" : [ SenseInfo('01152896-v', 4), SenseInfo('01661804-v', 1), SenseInfo('01307142-v', 1), SenseInfo('01152214-v', 0), SenseInfo('00964237-v', 0), SenseInfo('00356649-v', 0), SenseInfo('01152896-v', 4), SenseInfo('01661804-v', 1), SenseInfo('01307142-v', 1), SenseInfo('01152214-v', 0), SenseInfo('00964237-v', 0), SenseInfo('00356649-v', 0) ],
"_excavate_v_1_rel" : [ SenseInfo('02143539-v', 0), SenseInfo('01313923-v', 0), SenseInfo('01311378-v', 0), SenseInfo('01310660-v', 0) ],
"_interrogative_a_1_rel" : [ SenseInfo('03094740-a', 0), SenseInfo('00687163-a', 0), SenseInfo('03094740-a', 0), SenseInfo('00687163-a', 0) ],
"_manifestation_n_1_rel" : [ SenseInfo('07323231-n', 6), SenseInfo('06798558-n', 3), SenseInfo('07323024-n', 0), SenseInfo('06880249-n', 0), SenseInfo('01177703-n', 0) ],
"_forum_n_1_rel" : [ SenseInfo('08309754-n', 0), SenseInfo('03386420-n', 0) ],
"_send_v_in_rel" : [ SenseInfo('01951480-v', 79), SenseInfo('01437254-v', 20), SenseInfo('01031256-v', 20), SenseInfo('01950798-v', 14), SenseInfo('01088923-v', 5), SenseInfo('01062555-v', 5), SenseInfo('02348568-v', 3), SenseInfo('00973056-v', 2) ],
"_unusable_a_1_rel" : [ SenseInfo('02497830-a', 0), SenseInfo('02497830-a', 0) ],
"_workbench_n_1_rel" : [ SenseInfo('04600486-n', 8) ],
"_abridge_v_1_rel" : [ SenseInfo('00243900-v', 1), SenseInfo('00236843-v', 0) ],
"_verse_v_in_rel" : [ SenseInfo('01702514-v', 0), SenseInfo('00874714-v', 0), SenseInfo('01702514-v', 0), SenseInfo('00874714-v', 0) ],
"_get_v_of-i_rel" : [ SenseInfo('02210855-v', 235), SenseInfo('00149583-v', 157), SenseInfo('00120796-v', 82), SenseInfo('00522751-v', 64), SenseInfo('02005948-v', 58), SenseInfo('01433294-v', 45), SenseInfo('02108026-v', 36), SenseInfo('01153947-v', 14), SenseInfo('02355596-v', 9), SenseInfo('00770437-v', 7), SenseInfo('01215421-v', 4), SenseInfo('00094460-v', 4), SenseInfo('00087736-v', 4), SenseInfo('01066036-v', 3), SenseInfo('00120316-v', 3), SenseInfo('01026975-v', 2), SenseInfo('00589904-v', 2), SenseInfo('01505958-v', 1), SenseInfo('01401115-v', 1), SenseInfo('00639849-v', 1), SenseInfo('02359340-v', 0), SenseInfo('02208265-v', 0), SenseInfo('02189398-v', 0), SenseInfo('02109645-v', 0), SenseInfo('02108654-v', 0), SenseInfo('02010864-v', 0), SenseInfo('02006573-v', 0), SenseInfo('01771194-v', 0), SenseInfo('01771039-v', 0), SenseInfo('01738107-v', 0), SenseInfo('01643297-v', 0), SenseInfo('01565211-v', 0), SenseInfo('00622384-v', 0), SenseInfo('00345761-v', 0), SenseInfo('00065639-v', 0), SenseInfo('00054628-v', 0) ],
"_offer_v_1_rel" : [ SenseInfo('02296726-v', 95), SenseInfo('02297142-v', 31), SenseInfo('02425112-v', 12), SenseInfo('00706557-v', 4), SenseInfo('02297742-v', 3), SenseInfo('02297409-v', 3), SenseInfo('02298632-v', 1), SenseInfo('02157361-v', 1), SenseInfo('02613487-v', 0), SenseInfo('02376289-v', 0), SenseInfo('02297948-v', 0), SenseInfo('00879764-v', 0), SenseInfo('00871623-v', 0), SenseInfo('02296726-v', 95), SenseInfo('02297142-v', 31), SenseInfo('02425112-v', 12), SenseInfo('00706557-v', 4), SenseInfo('02297742-v', 3), SenseInfo('02297409-v', 3), SenseInfo('02298632-v', 1), SenseInfo('02157361-v', 1), SenseInfo('02613487-v', 0), SenseInfo('02376289-v', 0), SenseInfo('02297948-v', 0), SenseInfo('00879764-v', 0), SenseInfo('00871623-v', 0), SenseInfo('02296726-v', 95), SenseInfo('02297142-v', 31), SenseInfo('02425112-v', 12), SenseInfo('00706557-v', 4), SenseInfo('02297742-v', 3), SenseInfo('02297409-v', 3), SenseInfo('02298632-v', 1), SenseInfo('02157361-v', 1), SenseInfo('02613487-v', 0), SenseInfo('02376289-v', 0), SenseInfo('02297948-v', 0), SenseInfo('00879764-v', 0), SenseInfo('00871623-v', 0), SenseInfo('02296726-v', 95), SenseInfo('02297142-v', 31), SenseInfo('02425112-v', 12), SenseInfo('00706557-v', 4), SenseInfo('02297742-v', 3), SenseInfo('02297409-v', 3), SenseInfo('02298632-v', 1), SenseInfo('02157361-v', 1), SenseInfo('02613487-v', 0), SenseInfo('02376289-v', 0), SenseInfo('02297948-v', 0), SenseInfo('00879764-v', 0), SenseInfo('00871623-v', 0) ],
"_dissociation_n_of_rel" : [ SenseInfo('00384802-n', 3), SenseInfo('14416845-n', 0), SenseInfo('13467700-n', 0) ],
"_adventuresome_a_1_rel" : [ SenseInfo('00065791-a', 0) ],
"_unfazed_a_1_rel" : [  ],
"_condition_v_on_rel" : [ SenseInfo('02571768-v', 2), SenseInfo('02553697-v', 1), SenseInfo('01018928-v', 1), SenseInfo('00207418-v', 0), SenseInfo('00041687-v', 0) ],
"_magnitude_n_1_rel" : [ SenseInfo('05090441-n', 15), SenseInfo('13823651-n', 1), SenseInfo('05168890-n', 1) ],
"_festivities_n_1_rel" : [ SenseInfo('00428000-n', 3), SenseInfo('00428000-n', 3) ],
"_look+and+feel_n_1_rel" : [  ],
"_father_v_1_rel" : [ SenseInfo('00054628-v', 2) ],
"_big+mac_n_1_rel" : [  ],
"_jaunty_a_1_rel" : [ SenseInfo('00971933-a', 1), SenseInfo('00364145-a', 1), SenseInfo('00971933-a', 1), SenseInfo('00364145-a', 1), SenseInfo('00971933-a', 1), SenseInfo('00364145-a', 1) ],
"_sexual_a_1_rel" : [ SenseInfo('02887578-a', 16), SenseInfo('02135389-a', 1), SenseInfo('02132735-a', 0), SenseInfo('02887578-a', 16), SenseInfo('02135389-a', 1), SenseInfo('02132735-a', 0) ],
"_resonance_n_1_rel" : [ SenseInfo('11478299-n', 5), SenseInfo('11477921-n', 3), SenseInfo('04989657-n', 1), SenseInfo('13811740-n', 0), SenseInfo('04988258-n', 0) ],
"_assault_n_1_rel" : [ SenseInfo('00974444-n', 6), SenseInfo('00767826-n', 1), SenseInfo('02384225-n', 0), SenseInfo('00773402-n', 0) ],
"_gunner_n_1_rel" : [ SenseInfo('09811852-n', 4) ],
"_tangle_v_1_rel" : [ SenseInfo('02677797-v', 0), SenseInfo('01521124-v', 0), SenseInfo('01474034-v', 0), SenseInfo('01462928-v', 0) ],
"_yield_v_to_rel" : [ SenseInfo('02339171-v', 6), SenseInfo('00435103-v', 5), SenseInfo('01629000-v', 4), SenseInfo('02316649-v', 3), SenseInfo('02703289-v', 2), SenseInfo('01848465-v', 1), SenseInfo('01629403-v', 1), SenseInfo('00806049-v', 1), SenseInfo('02620466-v', 0), SenseInfo('02291708-v', 0), SenseInfo('01449796-v', 0), SenseInfo('01116447-v', 0), SenseInfo('00804476-v', 0) ],
"_headgear_n_1_rel" : [ SenseInfo('03502509-n', 1), SenseInfo('03503908-n', 0), SenseInfo('03503718-n', 0) ],
"_webbed_a_1_rel" : [ SenseInfo('02591088-a', 0), SenseInfo('02007067-a', 0) ],
"_draw_v_back_rel" : [ SenseInfo('01448100-v', 13), SenseInfo('02293148-v', 10), SenseInfo('01582645-v', 10), SenseInfo('00730758-v', 10), SenseInfo('01995211-v', 9), SenseInfo('01690294-v', 7), SenseInfo('01854132-v', 6), SenseInfo('00987071-v', 6), SenseInfo('00675901-v', 6), SenseInfo('01760300-v', 5), SenseInfo('01199009-v', 5), SenseInfo('02088107-v', 4), SenseInfo('02311387-v', 3), SenseInfo('01078050-v', 3), SenseInfo('01643297-v', 2), SenseInfo('00556593-v', 2), SenseInfo('02097800-v', 1), SenseInfo('01690816-v', 1), SenseInfo('01643464-v', 1), SenseInfo('01243148-v', 1), SenseInfo('02742107-v', 0), SenseInfo('02628832-v', 0), SenseInfo('02483564-v', 0), SenseInfo('02103162-v', 0), SenseInfo('01539063-v', 0), SenseInfo('01505254-v', 0), SenseInfo('01359432-v', 0), SenseInfo('01243298-v', 0), SenseInfo('01212230-v', 0), SenseInfo('01115190-v', 0), SenseInfo('00476965-v', 0), SenseInfo('00430808-v', 0), SenseInfo('00327982-v', 0), SenseInfo('00197590-v', 0), SenseInfo('00143338-v', 0), SenseInfo('00097029-v', 0), SenseInfo('01448100-v', 13), SenseInfo('02293148-v', 10), SenseInfo('01582645-v', 10), SenseInfo('00730758-v', 10), SenseInfo('01995211-v', 9), SenseInfo('01690294-v', 7), SenseInfo('01854132-v', 6), SenseInfo('00987071-v', 6), SenseInfo('00675901-v', 6), SenseInfo('01760300-v', 5), SenseInfo('01199009-v', 5), SenseInfo('02088107-v', 4), SenseInfo('02311387-v', 3), SenseInfo('01078050-v', 3), SenseInfo('01643297-v', 2), SenseInfo('00556593-v', 2), SenseInfo('02097800-v', 1), SenseInfo('01690816-v', 1), SenseInfo('01643464-v', 1), SenseInfo('01243148-v', 1), SenseInfo('02742107-v', 0), SenseInfo('02628832-v', 0), SenseInfo('02483564-v', 0), SenseInfo('02103162-v', 0), SenseInfo('01539063-v', 0), SenseInfo('01505254-v', 0), SenseInfo('01359432-v', 0), SenseInfo('01243298-v', 0), SenseInfo('01212230-v', 0), SenseInfo('01115190-v', 0), SenseInfo('00476965-v', 0), SenseInfo('00430808-v', 0), SenseInfo('00327982-v', 0), SenseInfo('00197590-v', 0), SenseInfo('00143338-v', 0), SenseInfo('00097029-v', 0) ],
"_lockup_n_1_rel" : [ SenseInfo('03684740-n', 2), SenseInfo('00827638-n', 0) ],
"_destroy_v_1_rel" : [ SenseInfo('01619929-v', 42), SenseInfo('01564144-v', 28), SenseInfo('01083373-v', 2), SenseInfo('01326528-v', 0) ],
"_hereby_a_1_rel" : [  ],
"_place_v_1_rel" : [ SenseInfo('01494310-v', 135), SenseInfo('02392762-v', 13), SenseInfo('00658052-v', 7), SenseInfo('02333689-v', 4), SenseInfo('00745970-v', 4), SenseInfo('00659776-v', 3), SenseInfo('01150559-v', 2), SenseInfo('00618878-v', 2), SenseInfo('02537960-v', 1), SenseInfo('01711749-v', 1), SenseInfo('00673448-v', 1), SenseInfo('02695895-v', 0), SenseInfo('02271137-v', 0), SenseInfo('01088923-v', 0), SenseInfo('01086691-v', 0), SenseInfo('01049276-v', 0), SenseInfo('01494310-v', 135), SenseInfo('02392762-v', 13), SenseInfo('00658052-v', 7), SenseInfo('02333689-v', 4), SenseInfo('00745970-v', 4), SenseInfo('00659776-v', 3), SenseInfo('01150559-v', 2), SenseInfo('00618878-v', 2), SenseInfo('02537960-v', 1), SenseInfo('01711749-v', 1), SenseInfo('00673448-v', 1), SenseInfo('02695895-v', 0), SenseInfo('02271137-v', 0), SenseInfo('01088923-v', 0), SenseInfo('01086691-v', 0), SenseInfo('01049276-v', 0) ],
"_decare_n_1_rel" : [  ],
"_stoop_n_1_rel" : [ SenseInfo('00336654-n', 1), SenseInfo('04330109-n', 0), SenseInfo('04327204-n', 0) ],
"_as_p_rel" : [ SenseInfo('13658027-n', 6), SenseInfo('15089803-n', 0), SenseInfo('14829565-n', 0), SenseInfo('14706889-n', 0), SenseInfo('13637376-n', 0), SenseInfo('06831177-n', 0), SenseInfo('05400860-n', 0), SenseInfo('13658027-n', 6), SenseInfo('15089803-n', 0), SenseInfo('14829565-n', 0), SenseInfo('14706889-n', 0), SenseInfo('13637376-n', 0), SenseInfo('06831177-n', 0), SenseInfo('05400860-n', 0), SenseInfo('13658027-n', 6), SenseInfo('15089803-n', 0), SenseInfo('14829565-n', 0), SenseInfo('14706889-n', 0), SenseInfo('13637376-n', 0), SenseInfo('06831177-n', 0), SenseInfo('05400860-n', 0), SenseInfo('13658027-n', 6), SenseInfo('15089803-n', 0), SenseInfo('14829565-n', 0), SenseInfo('14706889-n', 0), SenseInfo('13637376-n', 0), SenseInfo('06831177-n', 0), SenseInfo('05400860-n', 0), SenseInfo('13658027-n', 6), SenseInfo('15089803-n', 0), SenseInfo('14829565-n', 0), SenseInfo('14706889-n', 0), SenseInfo('13637376-n', 0), SenseInfo('06831177-n', 0), SenseInfo('05400860-n', 0) ],
"_head_v_dir_rel" : [ SenseInfo('01935233-v', 29), SenseInfo('02440244-v', 19), SenseInfo('01999423-v', 3), SenseInfo('02729023-v', 2), SenseInfo('01931768-v', 2), SenseInfo('02754463-v', 0), SenseInfo('02694287-v', 0), SenseInfo('02624128-v', 0), SenseInfo('01590915-v', 0), SenseInfo('01935233-v', 29), SenseInfo('02440244-v', 19), SenseInfo('01999423-v', 3), SenseInfo('02729023-v', 2), SenseInfo('01931768-v', 2), SenseInfo('02754463-v', 0), SenseInfo('02694287-v', 0), SenseInfo('02624128-v', 0), SenseInfo('01590915-v', 0) ],
"_alight_a_1_rel" : [ SenseInfo('00475308-a', 0) ],
"_hysterical_a_1_rel" : [ SenseInfo('01584287-a', 3), SenseInfo('00086606-a', 1) ],
"_fearful_a_of_rel" : [ SenseInfo('00079485-a', 2), SenseInfo('00193799-a', 1), SenseInfo('00264776-a', 0), SenseInfo('01127147-a', 0), SenseInfo('00252498-a', 0) ],
"_ebb_v_1_rel" : [ SenseInfo('01903935-v', 1), SenseInfo('01127638-v', 0), SenseInfo('00570907-v', 0) ],
"_ruble_n_1_rel" : [ SenseInfo('13702531-n', 0), SenseInfo('13699076-n', 0) ],
"_for+example_p_rel" : [ SenseInfo('00159040-r', 63), SenseInfo('00159040-r', 63) ],
"_upright_a_1_rel" : [ SenseInfo('01234030-a', 5), SenseInfo('02036934-a', 1), SenseInfo('01235859-a', 0) ],
"_splice_v_1_rel" : [ SenseInfo('01560184-v', 1), SenseInfo('02489456-v', 0), SenseInfo('01560034-v', 0), SenseInfo('01559868-v', 0) ],
"_get_v_over_rel" : [ SenseInfo('02210855-v', 235), SenseInfo('00149583-v', 157), SenseInfo('00120796-v', 82), SenseInfo('00522751-v', 64), SenseInfo('02005948-v', 58), SenseInfo('01433294-v', 45), SenseInfo('02108026-v', 36), SenseInfo('01153947-v', 14), SenseInfo('02355596-v', 9), SenseInfo('00770437-v', 7), SenseInfo('01215421-v', 4), SenseInfo('00094460-v', 4), SenseInfo('00087736-v', 4), SenseInfo('01066036-v', 3), SenseInfo('00120316-v', 3), SenseInfo('01026975-v', 2), SenseInfo('00589904-v', 2), SenseInfo('01505958-v', 1), SenseInfo('01401115-v', 1), SenseInfo('00639849-v', 1), SenseInfo('02359340-v', 0), SenseInfo('02208265-v', 0), SenseInfo('02189398-v', 0), SenseInfo('02109645-v', 0), SenseInfo('02108654-v', 0), SenseInfo('02010864-v', 0), SenseInfo('02006573-v', 0), SenseInfo('01771194-v', 0), SenseInfo('01771039-v', 0), SenseInfo('01738107-v', 0), SenseInfo('01643297-v', 0), SenseInfo('01565211-v', 0), SenseInfo('00622384-v', 0), SenseInfo('00345761-v', 0), SenseInfo('00065639-v', 0), SenseInfo('00054628-v', 0) ],
"_spend_v_1_rel" : [ SenseInfo('02708420-v', 98), SenseInfo('02267060-v', 36), SenseInfo('02267529-v', 3), SenseInfo('02708420-v', 98), SenseInfo('02267060-v', 36), SenseInfo('02267529-v', 3), SenseInfo('02708420-v', 98), SenseInfo('02267060-v', 36), SenseInfo('02267529-v', 3), SenseInfo('02708420-v', 98), SenseInfo('02267060-v', 36), SenseInfo('02267529-v', 3), SenseInfo('02708420-v', 98), SenseInfo('02267060-v', 36), SenseInfo('02267529-v', 3) ],
"_aberrant_a_1_rel" : [ SenseInfo('01596122-a', 1) ],
"_chipping_n_1_rel" : [ SenseInfo('00377169-n', 0) ],
"_thereabouts_p_rel" : [ SenseInfo('00467810-r', 0), SenseInfo('00467686-r', 0) ],
"_disarm_v_1_rel" : [ SenseInfo('01087835-v', 2), SenseInfo('01830445-v', 0), SenseInfo('01088005-v', 0) ],
"_appreciate_v_2_rel" : [ SenseInfo('01805982-v', 12), SenseInfo('00592341-v', 11), SenseInfo('02256109-v', 5), SenseInfo('00316195-v', 0), SenseInfo('00315605-v', 0) ],
"_casing_n_1_rel" : [ SenseInfo('04190747-n', 0), SenseInfo('02977822-n', 0), SenseInfo('02977619-n', 0) ],
"_sample_n_of_rel" : [ SenseInfo('05821775-n', 48), SenseInfo('06026635-n', 13), SenseInfo('09421425-n', 0) ],
"_esteem_n_1_rel" : [ SenseInfo('14437552-n', 2), SenseInfo('07500741-n', 0), SenseInfo('06206800-n', 0) ],
"_glacier_n_1_rel" : [ SenseInfo('09289331-n', 1), SenseInfo('09289331-n', 1) ],
"_discrimination_n_of_rel" : [ SenseInfo('01153548-n', 6), SenseInfo('05748054-n', 5) ],
"_scissors_n_1_rel" : [ SenseInfo('04148054-n', 0), SenseInfo('00814665-n', 0), SenseInfo('00438725-n', 0) ],
"_margin_n_1_rel" : [ SenseInfo('13903387-n', 6), SenseInfo('05120683-n', 2), SenseInfo('13351278-n', 0), SenseInfo('13260762-n', 0), SenseInfo('06389398-n', 0), SenseInfo('04749991-n', 0) ],
"_lend_v_1_rel" : [ SenseInfo('02324478-v', 7), SenseInfo('02324182-v', 7), SenseInfo('02736391-v', 2), SenseInfo('02324478-v', 7), SenseInfo('02324182-v', 7), SenseInfo('02736391-v', 2) ],
"_telepathy_n_1_rel" : [ SenseInfo('07255998-n', 1) ],
"_to_p_sel_rel" : [  ],
"_boyfriend_n_1_rel" : [ SenseInfo('09871364-n', 0) ],
"_ampere_n_1_rel" : [ SenseInfo('13637841-n', 0), SenseInfo('13637376-n', 0), SenseInfo('13637841-n', 0), SenseInfo('13637376-n', 0) ],
"_bulletin_n_1_rel" : [ SenseInfo('06682290-n', 2) ],
"_necessary_a_1_rel" : [ SenseInfo('01580050-a', 81), SenseInfo('00343552-a', 1) ],
"_scorn_n_1_rel" : [ SenseInfo('07502980-n', 6), SenseInfo('06715927-n', 1) ],
"_solar_a_1_rel" : [ SenseInfo('02799016-a', 4) ],
"_CCTV_n_1_rel" : [  ],
"_dial_v_in_rel" : [ SenseInfo('00790308-v', 3), SenseInfo('00676135-v', 0), SenseInfo('00790308-v', 3), SenseInfo('00676135-v', 0) ],
"_lob_n_1_rel" : [ SenseInfo('00569361-n', 0), SenseInfo('00120804-n', 0) ],
"_outdoor_a_1_rel" : [ SenseInfo('01692222-a', 6), SenseInfo('03095372-a', 2) ],
"_coin_n_1_rel" : [ SenseInfo('13388245-n', 7) ],
"_town_n_i_rel" : [ SenseInfo('08665504-n', 67), SenseInfo('08226514-n', 8), SenseInfo('08672199-n', 4), SenseInfo('11346710-n', 0) ],
"_oasis_n_1_rel" : [ SenseInfo('08506496-n', 0), SenseInfo('03499796-n', 0) ],
"_instant_a_1_rel" : [ SenseInfo('00979031-a', 2), SenseInfo('01732012-a', 0), SenseInfo('00712877-a', 0), SenseInfo('00979031-a', 2), SenseInfo('01732012-a', 0), SenseInfo('00712877-a', 0) ],
"_workable_a_1_rel" : [ SenseInfo('01822563-a', 4) ],
"_private_a_1_rel" : [ SenseInfo('01858094-a', 44), SenseInfo('01769378-a', 0), SenseInfo('01768086-a', 0), SenseInfo('00952181-a', 0), SenseInfo('01858094-a', 44), SenseInfo('01769378-a', 0), SenseInfo('01768086-a', 0), SenseInfo('00952181-a', 0), SenseInfo('01858094-a', 44), SenseInfo('01769378-a', 0), SenseInfo('01768086-a', 0), SenseInfo('00952181-a', 0), SenseInfo('01858094-a', 44), SenseInfo('01769378-a', 0), SenseInfo('01768086-a', 0), SenseInfo('00952181-a', 0), SenseInfo('01858094-a', 44), SenseInfo('01769378-a', 0), SenseInfo('01768086-a', 0), SenseInfo('00952181-a', 0), SenseInfo('01858094-a', 44), SenseInfo('01769378-a', 0), SenseInfo('01768086-a', 0), SenseInfo('00952181-a', 0) ],
"_intestine_n_1_rel" : [ SenseInfo('05534333-n', 0) ],
"_skip_n_1_rel" : [ SenseInfo('00289906-n', 0), SenseInfo('00074624-n', 0) ],
"_notate_v_1_rel" : [ SenseInfo('00995286-v', 0) ],
"_gadget_n_1_rel" : [ SenseInfo('02729965-n', 9) ],
"_clock_v_at_rel" : [ SenseInfo('00490968-v', 1) ],
"_camouflage_n_1_rel" : [ SenseInfo('04679074-n', 0), SenseInfo('02944579-n', 0), SenseInfo('02944459-n', 0), SenseInfo('01049266-n', 0) ],
"_check_v_up-on_rel" : [ SenseInfo('00661824-v', 27), SenseInfo('02533282-v', 7), SenseInfo('00662589-v', 6), SenseInfo('02510337-v', 5), SenseInfo('01861403-v', 1), SenseInfo('00662182-v', 1), SenseInfo('00440286-v', 1), SenseInfo('02658283-v', 0), SenseInfo('02657219-v', 0), SenseInfo('02557638-v', 0), SenseInfo('02553697-v', 0), SenseInfo('02347905-v', 0), SenseInfo('02347447-v', 0), SenseInfo('01861767-v', 0), SenseInfo('01861622-v', 0), SenseInfo('01692978-v', 0), SenseInfo('01139756-v', 0), SenseInfo('01131473-v', 0), SenseInfo('01114764-v', 0), SenseInfo('01064999-v', 0), SenseInfo('00920336-v', 0), SenseInfo('00663353-v', 0), SenseInfo('00354634-v', 0), SenseInfo('00336539-v', 0), SenseInfo('00336260-v', 0) ],
"_terrific_a_for_rel" : [ SenseInfo('01513619-a', 3), SenseInfo('01676517-a', 2), SenseInfo('00196449-a', 0), SenseInfo('01513619-a', 3), SenseInfo('01676517-a', 2), SenseInfo('00196449-a', 0), SenseInfo('01513619-a', 3), SenseInfo('01676517-a', 2), SenseInfo('00196449-a', 0), SenseInfo('01513619-a', 3), SenseInfo('01676517-a', 2), SenseInfo('00196449-a', 0), SenseInfo('01513619-a', 3), SenseInfo('01676517-a', 2), SenseInfo('00196449-a', 0), SenseInfo('01513619-a', 3), SenseInfo('01676517-a', 2), SenseInfo('00196449-a', 0) ],
"_gloss_v_1_rel" : [ SenseInfo('01682582-v', 0), SenseInfo('00961329-v', 0), SenseInfo('00960961-v', 0), SenseInfo('00837133-v', 0) ],
"_physical_a_1_rel" : [ SenseInfo('01778212-a', 29), SenseInfo('02779774-a', 5), SenseInfo('00627004-a', 5), SenseInfo('01574259-a', 3), SenseInfo('00874092-a', 2), SenseInfo('00842324-a', 0), SenseInfo('00627204-a', 0), SenseInfo('01778212-a', 29), SenseInfo('02779774-a', 5), SenseInfo('00627004-a', 5), SenseInfo('01574259-a', 3), SenseInfo('00874092-a', 2), SenseInfo('00842324-a', 0), SenseInfo('00627204-a', 0) ],
"_selection_n_of_rel" : [ SenseInfo('00161243-n', 13), SenseInfo('08399818-n', 2), SenseInfo('05790242-n', 1), SenseInfo('13563746-n', 0), SenseInfo('06400510-n', 0) ],
"_warlike_a_1_rel" : [ SenseInfo('01742715-a', 2), SenseInfo('01518860-a', 0) ],
"_ridge_n_1_rel" : [ SenseInfo('09409512-n', 6), SenseInfo('13902048-n', 0), SenseInfo('09409898-n', 0), SenseInfo('09409752-n', 0), SenseInfo('05603342-n', 0), SenseInfo('04089152-n', 0), SenseInfo('09409512-n', 6), SenseInfo('13902048-n', 0), SenseInfo('09409898-n', 0), SenseInfo('09409752-n', 0), SenseInfo('05603342-n', 0), SenseInfo('04089152-n', 0) ],
"_beak_n_1_rel" : [ SenseInfo('01758510-n', 1), SenseInfo('01758308-n', 1), SenseInfo('12875594-n', 0), SenseInfo('05598707-n', 0) ],
"_navigation_n_of_rel" : [ SenseInfo('00815801-n', 1), SenseInfo('01105737-n', 0), SenseInfo('00314469-n', 0) ],
"_blossom_v_1_rel" : [ SenseInfo('00294245-v', 3), SenseInfo('00293760-v', 2) ],
"_transitory_a_1_rel" : [ SenseInfo('01756292-a', 0) ],
"_list_v_1_rel" : [ SenseInfo('00945853-v', 23), SenseInfo('02472223-v', 19), SenseInfo('02039013-v', 0), SenseInfo('02038791-v', 0), SenseInfo('00946755-v', 0) ],
"_course_n_of_rel" : [ SenseInfo('00884466-n', 61), SenseInfo('08377085-n', 14), SenseInfo('08681222-n', 11), SenseInfo('00038262-n', 9), SenseInfo('09387222-n', 5), SenseInfo('08238463-n', 0), SenseInfo('07556970-n', 0), SenseInfo('03120029-n', 0), SenseInfo('03119790-n', 0), SenseInfo('00884466-n', 61), SenseInfo('08377085-n', 14), SenseInfo('08681222-n', 11), SenseInfo('00038262-n', 9), SenseInfo('09387222-n', 5), SenseInfo('08238463-n', 0), SenseInfo('07556970-n', 0), SenseInfo('03120029-n', 0), SenseInfo('03119790-n', 0) ],
"_balk_v_1_rel" : [ SenseInfo('02583545-v', 3) ],
"_intimidation_n_1_rel" : [ SenseInfo('01222477-n', 2), SenseInfo('07542881-n', 0), SenseInfo('07523760-n', 0), SenseInfo('07254057-n', 0) ],
"_ignoramus_n_1_rel" : [ SenseInfo('10198958-n', 1) ],
"_flap_v_cause_rel" : [ SenseInfo('01901783-v', 4), SenseInfo('01880888-v', 2), SenseInfo('02093610-v', 1), SenseInfo('02093390-v', 0), SenseInfo('01819911-v', 0), SenseInfo('01055558-v', 0) ],
"_influence_n_1_rel" : [ SenseInfo('05194151-n', 27), SenseInfo('00157081-n', 10), SenseInfo('05692910-n', 9), SenseInfo('11414608-n', 3), SenseInfo('10461747-n', 0) ],
"_lay_v_down_rel" : [ SenseInfo('01494310-v', 24), SenseInfo('01544692-v', 11), SenseInfo('01651972-v', 5), SenseInfo('01545079-v', 4), SenseInfo('02307261-v', 1) ],
"_sally_v_1_rel" : [  ],
"_flimsy_a_1_rel" : [ SenseInfo('02325484-a', 2), SenseInfo('00615457-a', 0), SenseInfo('02164913-a', 0), SenseInfo('02325484-a', 2), SenseInfo('00615457-a', 0), SenseInfo('02164913-a', 0), SenseInfo('02325484-a', 2), SenseInfo('00615457-a', 0), SenseInfo('02164913-a', 0) ],
"_casserole_n_1_rel" : [ SenseInfo('07580359-n', 0), SenseInfo('02978753-n', 0) ],
"_scriptwriter_n_1_rel" : [ SenseInfo('10564905-n', 0) ],
"_exotic_n_1_rel" : [ SenseInfo('01035007-a', 2), SenseInfo('00968730-a', 0) ],
"_tiring_a_1_rel" : [ SenseInfo('00837249-a', 1) ],
"_outfield_n_1_rel" : [ SenseInfo('03859717-n', 2) ],
"_down-play_v_1_rel" : [ SenseInfo('00841125-v', 0), SenseInfo('00513492-v', 0) ],
"_economic_a_1_rel" : [ SenseInfo('02716739-a', 65), SenseInfo('02716605-a', 5), SenseInfo('00840212-a', 1), SenseInfo('02577454-a', 0), SenseInfo('01871565-a', 0) ],
"_finger_v_1_rel" : [ SenseInfo('01209953-v', 1), SenseInfo('01209678-v', 1), SenseInfo('01314573-v', 0), SenseInfo('00924431-v', 0) ],
"_picture_n_of_rel" : [ SenseInfo('03931044-n', 25), SenseInfo('03876519-n', 24), SenseInfo('05936704-n', 22), SenseInfo('13937075-n', 10), SenseInfo('06999436-n', 3), SenseInfo('06613686-n', 3), SenseInfo('06277803-n', 3), SenseInfo('07201804-n', 2), SenseInfo('05766077-n', 1), SenseInfo('03925226-n', 0) ],
"_converter_n_1_rel" : [ SenseInfo('03099945-n', 0) ],
"_button_v_down_rel" : [ SenseInfo('01368126-v', 0), SenseInfo('01367862-v', 0) ],
"_assyrian_a_1_rel" : [ SenseInfo('09640490-n', 1), SenseInfo('06988684-n', 1), SenseInfo('06987659-n', 0) ],
"_write+off_n_1_rel" : [ SenseInfo('13328853-n', 0), SenseInfo('00232604-n', 0), SenseInfo('13328853-n', 0), SenseInfo('00232604-n', 0) ],
"_position_v_1_rel" : [ SenseInfo('01987160-v', 2), SenseInfo('01494310-v', 1) ],
"_accession_n_1_rel" : [ SenseInfo('13424477-n', 0), SenseInfo('13341962-n', 0), SenseInfo('13253423-n', 0), SenseInfo('07177192-n', 0), SenseInfo('05176188-n', 0), SenseInfo('00236581-n', 0) ],
"_pepperoni_n_1_rel" : [ SenseInfo('07677480-n', 0) ],
"_par_n_1_rel" : [ SenseInfo('13596756-n', 2), SenseInfo('13946760-n', 1) ],
"_sly_n_i_rel" : [ SenseInfo('00148078-a', 1) ],
"_valuable_a_to-for_rel" : [ SenseInfo('02500884-a', 16), SenseInfo('02587738-a', 5), SenseInfo('02500884-a', 16), SenseInfo('02587738-a', 5) ],
"_shrewd_a_1_rel" : [ SenseInfo('00438909-a', 2), SenseInfo('01155603-a', 0), SenseInfo('00438909-a', 2), SenseInfo('01155603-a', 0), SenseInfo('00438909-a', 2), SenseInfo('01155603-a', 0) ],
"_mound_n_of_rel" : [ SenseInfo('03792334-n', 5), SenseInfo('09326662-n', 1), SenseInfo('07961480-n', 1), SenseInfo('03792048-n', 0), SenseInfo('00722984-n', 0) ],
"_brigade_n_of_rel" : [ SenseInfo('08213978-n', 19), SenseInfo('08213978-n', 19) ],
"_matter_n_of_rel" : [ SenseInfo('05671325-n', 35), SenseInfo('05814291-n', 32), SenseInfo('00020827-n', 7), SenseInfo('05688397-n', 1), SenseInfo('05169242-n', 1), SenseInfo('06365467-n', 0) ],
"_professional_n_1_rel" : [ SenseInfo('10480253-n', 3), SenseInfo('10480583-n', 1), SenseInfo('10298482-n', 1) ],
"_underwater_a_2_rel" : [ SenseInfo('02472252-a', 2), SenseInfo('00124685-a', 0) ],
"_timetable_v_1_rel" : [  ],
"_profuse_a_1_rel" : [ SenseInfo('00015247-a', 1), SenseInfo('00015247-a', 1) ],
"_fear_v_for_rel" : [ SenseInfo('01780729-v', 23), SenseInfo('01780202-v', 20), SenseInfo('01780568-v', 1), SenseInfo('01780434-v', 0), SenseInfo('01778568-v', 0) ],
"_abridgment_n_1_rel" : [ SenseInfo('06468123-n', 1) ],
"_extant_a_1_rel" : [ SenseInfo('00928525-a', 1) ],
"_cloak_v_in_rel" : [ SenseInfo('02147603-v', 0), SenseInfo('01617034-v', 0), SenseInfo('01334535-v', 0), SenseInfo('02147603-v', 0), SenseInfo('01617034-v', 0), SenseInfo('01334535-v', 0) ],
"_ladybug_n_1_rel" : [ SenseInfo('02165456-n', 0) ],
"_don_n_1_rel" : [ SenseInfo('10025195-n', 1), SenseInfo('10464542-n', 0), SenseInfo('10025295-n', 0), SenseInfo('09508975-n', 0), SenseInfo('09268778-n', 0), SenseInfo('06340395-n', 0) ],
"_regretful_a_1_rel" : [ SenseInfo('01150475-a', 0) ],
"_headquarters_n_1_rel" : [ SenseInfo('03504723-n', 7), SenseInfo('03504420-n', 2), SenseInfo('08404895-n', 1), SenseInfo('03504723-n', 7), SenseInfo('03504420-n', 2), SenseInfo('08404895-n', 1) ],
"_abeyance_n_1_rel" : [ SenseInfo('14010636-n', 0) ],
"_black_a_1_rel" : [ SenseInfo('00392812-a', 52), SenseInfo('00241952-a', 4), SenseInfo('00114797-a', 4), SenseInfo('01229561-a', 2), SenseInfo('01131935-a', 2), SenseInfo('01050088-a', 2), SenseInfo('00396296-a', 1), SenseInfo('00274068-a', 1), SenseInfo('02079507-a', 0), SenseInfo('01706341-a', 0), SenseInfo('01402580-a', 0), SenseInfo('01227546-a', 0), SenseInfo('00756897-a', 0), SenseInfo('00421002-a', 0), SenseInfo('00392812-a', 52), SenseInfo('00241952-a', 4), SenseInfo('00114797-a', 4), SenseInfo('01229561-a', 2), SenseInfo('01131935-a', 2), SenseInfo('01050088-a', 2), SenseInfo('00396296-a', 1), SenseInfo('00274068-a', 1), SenseInfo('02079507-a', 0), SenseInfo('01706341-a', 0), SenseInfo('01402580-a', 0), SenseInfo('01227546-a', 0), SenseInfo('00756897-a', 0), SenseInfo('00421002-a', 0), SenseInfo('00392812-a', 52), SenseInfo('00241952-a', 4), SenseInfo('00114797-a', 4), SenseInfo('01229561-a', 2), SenseInfo('01131935-a', 2), SenseInfo('01050088-a', 2), SenseInfo('00396296-a', 1), SenseInfo('00274068-a', 1), SenseInfo('02079507-a', 0), SenseInfo('01706341-a', 0), SenseInfo('01402580-a', 0), SenseInfo('01227546-a', 0), SenseInfo('00756897-a', 0), SenseInfo('00421002-a', 0) ],
"_year-to-date_n_1_rel" : [  ],
"_hierarchy_n_1_rel" : [ SenseInfo('08377806-n', 2), SenseInfo('08376051-n', 2) ],
"_venue_n_1_rel" : [ SenseInfo('08677628-n', 0), SenseInfo('08677525-n', 0) ],
"_explode_v_cause_rel" : [ SenseInfo('00306723-v', 14), SenseInfo('00306017-v', 5), SenseInfo('00719062-v', 4), SenseInfo('00306539-v', 3), SenseInfo('01565795-v', 0), SenseInfo('01055661-v', 0), SenseInfo('00862467-v', 0), SenseInfo('00665335-v', 0), SenseInfo('00306298-v', 0), SenseInfo('00157623-v', 0) ],
"_compile_v_1_rel" : [ SenseInfo('02304982-v', 3), SenseInfo('01626138-v', 3), SenseInfo('01627105-v', 0) ],
"_upstream_p_rel" : [ SenseInfo('00097108-r', 2), SenseInfo('02494401-a', 1), SenseInfo('00097108-r', 2), SenseInfo('02494401-a', 1) ],
"_ever+since_p_rel" : [  ],
"_high_a_1_rel" : [ SenseInfo('01210854-a', 134), SenseInfo('01204557-a', 51), SenseInfo('02339120-a', 10), SenseInfo('01213197-a', 7), SenseInfo('00705498-a', 2), SenseInfo('01054047-a', 0), SenseInfo('00799224-a', 0), SenseInfo('01210854-a', 134), SenseInfo('01204557-a', 51), SenseInfo('02339120-a', 10), SenseInfo('01213197-a', 7), SenseInfo('00705498-a', 2), SenseInfo('01054047-a', 0), SenseInfo('00799224-a', 0), SenseInfo('01210854-a', 134), SenseInfo('01204557-a', 51), SenseInfo('02339120-a', 10), SenseInfo('01213197-a', 7), SenseInfo('00705498-a', 2), SenseInfo('01054047-a', 0), SenseInfo('00799224-a', 0), SenseInfo('01210854-a', 134), SenseInfo('01204557-a', 51), SenseInfo('02339120-a', 10), SenseInfo('01213197-a', 7), SenseInfo('00705498-a', 2), SenseInfo('01054047-a', 0), SenseInfo('00799224-a', 0), SenseInfo('01210854-a', 134), SenseInfo('01204557-a', 51), SenseInfo('02339120-a', 10), SenseInfo('01213197-a', 7), SenseInfo('00705498-a', 2), SenseInfo('01054047-a', 0), SenseInfo('00799224-a', 0) ],
"_clean_v_of_rel" : [ SenseInfo('01532589-v', 16), SenseInfo('00177714-v', 3), SenseInfo('01533442-v', 2), SenseInfo('00035758-v', 1), SenseInfo('02741960-v', 0), SenseInfo('01608951-v', 0), SenseInfo('01608706-v', 0), SenseInfo('01532434-v', 0), SenseInfo('00180837-v', 0), SenseInfo('00177861-v', 0) ],
"_privatize_v_1_rel" : [ SenseInfo('00412048-v', 0) ],
"_displeasure_n_1_rel" : [ SenseInfo('07540424-n', 3) ],
"_mansion_n_1_rel" : [ SenseInfo('08685677-n', 0), SenseInfo('03719053-n', 0), SenseInfo('08685677-n', 0), SenseInfo('03719053-n', 0) ],
"_onwards_p_sel_rel" : [ SenseInfo('00067265-r', 0) ],
"_sportsman_n_1_rel" : [ SenseInfo('10638922-n', 6) ],
"_see_v_through_rel" : [ SenseInfo('02129289-v', 613), SenseInfo('00591115-v', 159), SenseInfo('02128873-v', 140), SenseInfo('01635432-v', 58), SenseInfo('00690614-v', 47), SenseInfo('00598954-v', 40), SenseInfo('02150948-v', 29), SenseInfo('02023107-v', 27), SenseInfo('00920336-v', 27), SenseInfo('00662589-v', 22), SenseInfo('02488304-v', 13), SenseInfo('02488488-v', 12), SenseInfo('02493030-v', 10), SenseInfo('02549581-v', 7), SenseInfo('01470670-v', 4), SenseInfo('02486232-v', 1), SenseInfo('02129709-v', 1), SenseInfo('00703708-v', 1), SenseInfo('02156225-v', 0), SenseInfo('02131279-v', 0), SenseInfo('02110220-v', 0), SenseInfo('02026086-v', 0), SenseInfo('01156568-v', 0), SenseInfo('00623151-v', 0) ],
"_drink_v_up_rel" : [ SenseInfo('01170052-v', 30), SenseInfo('01171183-v', 10), SenseInfo('01175467-v', 1), SenseInfo('00737005-v', 1), SenseInfo('01172275-v', 0), SenseInfo('01170052-v', 30), SenseInfo('01171183-v', 10), SenseInfo('01175467-v', 1), SenseInfo('00737005-v', 1), SenseInfo('01172275-v', 0) ],
"_deterrant_n_1_rel" : [  ],
"_over_p_sel_rel" : [ SenseInfo('00226550-r', 23), SenseInfo('01003277-a', 21), SenseInfo('00226677-r', 2), SenseInfo('00226458-r', 1), SenseInfo('15258694-n', 0), SenseInfo('00226758-r', 0), SenseInfo('00198039-r', 0) ],
"_archers_n_1_rel" : [ SenseInfo('09805324-n', 0), SenseInfo('09753348-n', 0), SenseInfo('08687525-n', 0) ],
"_observer_n_1_rel" : [ SenseInfo('09626589-n', 11), SenseInfo('10369528-n', 9) ],
"_slough_v_off_rel" : [ SenseInfo('00009147-v', 0), SenseInfo('00009147-v', 0) ],
"_cant_v_1_rel" : [ SenseInfo('01884577-v', 0) ],
"_winch_n_1_rel" : [ SenseInfo('04585745-n', 0) ],
"_restructure_v_1_rel" : [ SenseInfo('00404401-v', 0) ],
"_share_n_of_rel" : [ SenseInfo('13285176-n', 29), SenseInfo('13342135-n', 12), SenseInfo('01085098-n', 3), SenseInfo('00787465-n', 3), SenseInfo('03967788-n', 0), SenseInfo('13285176-n', 29), SenseInfo('13342135-n', 12), SenseInfo('01085098-n', 3), SenseInfo('00787465-n', 3), SenseInfo('03967788-n', 0) ],
"_campaigner_n_1_rel" : [ SenseInfo('09889691-n', 0) ],
"_deny_v_to_rel" : [ SenseInfo('00816556-v', 24), SenseInfo('00817003-v', 20), SenseInfo('02214190-v', 16), SenseInfo('02212825-v', 15), SenseInfo('02213074-v', 0), SenseInfo('01068380-v', 0), SenseInfo('00817167-v', 0), SenseInfo('00816556-v', 24), SenseInfo('00817003-v', 20), SenseInfo('02214190-v', 16), SenseInfo('02212825-v', 15), SenseInfo('02213074-v', 0), SenseInfo('01068380-v', 0), SenseInfo('00817167-v', 0), SenseInfo('00816556-v', 24), SenseInfo('00817003-v', 20), SenseInfo('02214190-v', 16), SenseInfo('02212825-v', 15), SenseInfo('02213074-v', 0), SenseInfo('01068380-v', 0), SenseInfo('00817167-v', 0), SenseInfo('00816556-v', 24), SenseInfo('00817003-v', 20), SenseInfo('02214190-v', 16), SenseInfo('02212825-v', 15), SenseInfo('02213074-v', 0), SenseInfo('01068380-v', 0), SenseInfo('00817167-v', 0), SenseInfo('00816556-v', 24), SenseInfo('00817003-v', 20), SenseInfo('02214190-v', 16), SenseInfo('02212825-v', 15), SenseInfo('02213074-v', 0), SenseInfo('01068380-v', 0), SenseInfo('00817167-v', 0) ],
"_thankfulness_n_1_rel" : [ SenseInfo('07504529-n', 1) ],
"_pour_v_out_rel" : [ SenseInfo('02069551-v', 12), SenseInfo('02028366-v', 7), SenseInfo('02070296-v', 6), SenseInfo('02069248-v', 4), SenseInfo('02355806-v', 1), SenseInfo('02758033-v', 0), SenseInfo('02069551-v', 12), SenseInfo('02028366-v', 7), SenseInfo('02070296-v', 6), SenseInfo('02069248-v', 4), SenseInfo('02355806-v', 1), SenseInfo('02758033-v', 0) ],
"_orthodoxy_n_1_rel" : [ SenseInfo('04801313-n', 1), SenseInfo('06211811-n', 0), SenseInfo('04801313-n', 1), SenseInfo('06211811-n', 0) ],
"_lard_v_1_rel" : [ SenseInfo('01679669-v', 0), SenseInfo('00956405-v', 0) ],
"_battalion_n_1_rel" : [ SenseInfo('08214083-n', 2), SenseInfo('13775093-n', 0) ],
"_taro_n_1_rel" : [ SenseInfo('11786843-n', 0), SenseInfo('11786539-n', 0), SenseInfo('07736813-n', 0) ],
"_turn_v_1_rel" : [ SenseInfo('01907258-v', 187), SenseInfo('00146138-v', 21), SenseInfo('02626604-v', 12), SenseInfo('02089984-v', 8), SenseInfo('00138508-v', 7), SenseInfo('01909812-v', 5), SenseInfo('00125841-v', 5), SenseInfo('01436518-v', 2), SenseInfo('02096167-v', 1), SenseInfo('02089420-v', 1), SenseInfo('01952208-v', 1), SenseInfo('01741864-v', 1), SenseInfo('01584450-v', 1), SenseInfo('00282523-v', 1), SenseInfo('00091124-v', 1), SenseInfo('02626934-v', 0), SenseInfo('02562425-v', 0), SenseInfo('02211948-v', 0), SenseInfo('02090435-v', 0), SenseInfo('01951937-v', 0), SenseInfo('01280014-v', 0), SenseInfo('01225215-v', 0), SenseInfo('01151889-v', 0), SenseInfo('00794640-v', 0), SenseInfo('00458471-v', 0), SenseInfo('00248387-v', 0), SenseInfo('01907258-v', 187), SenseInfo('00146138-v', 21), SenseInfo('02626604-v', 12), SenseInfo('02089984-v', 8), SenseInfo('00138508-v', 7), SenseInfo('01909812-v', 5), SenseInfo('00125841-v', 5), SenseInfo('01436518-v', 2), SenseInfo('02096167-v', 1), SenseInfo('02089420-v', 1), SenseInfo('01952208-v', 1), SenseInfo('01741864-v', 1), SenseInfo('01584450-v', 1), SenseInfo('00282523-v', 1), SenseInfo('00091124-v', 1), SenseInfo('02626934-v', 0), SenseInfo('02562425-v', 0), SenseInfo('02211948-v', 0), SenseInfo('02090435-v', 0), SenseInfo('01951937-v', 0), SenseInfo('01280014-v', 0), SenseInfo('01225215-v', 0), SenseInfo('01151889-v', 0), SenseInfo('00794640-v', 0), SenseInfo('00458471-v', 0), SenseInfo('00248387-v', 0) ],
"_hoist_n_1_rel" : [ SenseInfo('03525074-n', 0) ],
"_detention_n_of_rel" : [ SenseInfo('13999663-n', 0), SenseInfo('01161635-n', 0) ],
"_tug_v_at_rel" : [ SenseInfo('01452918-v', 7), SenseInfo('02406916-v', 0), SenseInfo('01454636-v', 0), SenseInfo('01454246-v', 0), SenseInfo('01453256-v', 0), SenseInfo('01453109-v', 0), SenseInfo('01091298-v', 0) ],
"_oppress_v_1_rel" : [ SenseInfo('02424652-v', 1), SenseInfo('02585489-v', 0) ],
"_tug_v_on_rel" : [ SenseInfo('01452918-v', 7), SenseInfo('02406916-v', 0), SenseInfo('01454636-v', 0), SenseInfo('01454246-v', 0), SenseInfo('01453256-v', 0), SenseInfo('01453109-v', 0), SenseInfo('01091298-v', 0) ],
"_embellish_v_1_rel" : [ SenseInfo('00956405-v', 1), SenseInfo('02748927-v', 0), SenseInfo('01675963-v', 0), SenseInfo('00293141-v', 0) ],
"_asphalt_v_1_rel" : [ SenseInfo('01267866-v', 0) ],
"_giveaway_n_1_rel" : [ SenseInfo('13272712-n', 1), SenseInfo('07214894-n', 0), SenseInfo('06621061-n', 0), SenseInfo('13272712-n', 1), SenseInfo('07214894-n', 0), SenseInfo('06621061-n', 0) ],
"_prod_v_1_rel" : [ SenseInfo('01231252-v', 2), SenseInfo('01230710-v', 2), SenseInfo('01229976-v', 0), SenseInfo('01231252-v', 2), SenseInfo('01230710-v', 2), SenseInfo('01229976-v', 0) ],
"_layover_n_1_rel" : [ SenseInfo('01056411-n', 0) ],
"_vegetarian_a_1_rel" : [ SenseInfo('10747119-n', 0) ],
"_uninclosed_a_1_rel" : [  ],
"_separable_a_1_rel" : [ SenseInfo('00785002-a', 2) ],
"_concertgoer_n_1_rel" : [  ],
"_official_a_1_rel" : [ SenseInfo('01632537-a', 10), SenseInfo('02991463-a', 1), SenseInfo('01634736-a', 1), SenseInfo('01959918-a', 0), SenseInfo('01636363-a', 0), SenseInfo('01632537-a', 10), SenseInfo('02991463-a', 1), SenseInfo('01634736-a', 1), SenseInfo('01959918-a', 0), SenseInfo('01636363-a', 0) ],
"_appraise_v_1_rel" : [ SenseInfo('00681429-v', 2), SenseInfo('00646542-v', 0) ],
"_pack_n_of_rel" : [ SenseInfo('13775093-n', 1), SenseInfo('07956426-n', 1), SenseInfo('03870546-n', 1), SenseInfo('08244062-n', 0), SenseInfo('08240633-n', 0), SenseInfo('07994941-n', 0), SenseInfo('03870980-n', 0), SenseInfo('03870822-n', 0), SenseInfo('03870672-n', 0) ],
"_stellate_v_1_rel" : [  ],
"_san_n_1_rel" : [  ],
"_logger_n_1_rel" : [ SenseInfo('10276045-n', 1) ],
"_thesis_n_1_rel" : [ SenseInfo('06755454-n', 3), SenseInfo('06409085-n', 0) ],
"_virtue_n_of_rel" : [ SenseInfo('04847298-n', 6), SenseInfo('05138958-n', 3), SenseInfo('04849759-n', 0), SenseInfo('04847482-n', 0) ],
"_transact_v_1_rel" : [ SenseInfo('02245765-v', 2) ],
"_that_q_dem_rel" : [  ],
"_retreat_n_1_rel" : [ SenseInfo('00056912-n', 3), SenseInfo('08643015-n', 0), SenseInfo('06804988-n', 0), SenseInfo('06804847-n', 0), SenseInfo('03517647-n', 0), SenseInfo('00054652-n', 0), SenseInfo('00054483-n', 0) ],
"_error_n_1_rel" : [ SenseInfo('00070965-n', 15), SenseInfo('04802629-n', 6), SenseInfo('05895465-n', 4), SenseInfo('00072068-n', 3), SenseInfo('04853765-n', 2), SenseInfo('07299569-n', 0), SenseInfo('06769392-n', 0) ],
"_wide+ranging_a_1_rel" : [ SenseInfo('01391237-a', 1), SenseInfo('00783469-a', 0), SenseInfo('01391237-a', 1), SenseInfo('00783469-a', 0) ],
"_particulate_n_1_rel" : [ SenseInfo('14839439-n', 0) ],
"_being_n_i_rel" : [ SenseInfo('13954253-n', 12), SenseInfo('00004475-n', 6), SenseInfo('13954253-n', 12), SenseInfo('00004475-n', 6) ],
"_midway_x_deg_rel" : [ SenseInfo('00330506-a', 2), SenseInfo('00255415-r', 1), SenseInfo('08614746-n', 0), SenseInfo('01287782-n', 0) ],
"_know_v_1_rel" : [ SenseInfo('00594621-v', 585), SenseInfo('00595935-v', 142), SenseInfo('00595630-v', 123), SenseInfo('00594337-v', 76), SenseInfo('00596644-v', 17), SenseInfo('00592883-v', 10), SenseInfo('00596132-v', 1), SenseInfo('01426397-v', 0), SenseInfo('00608670-v', 0), SenseInfo('00608502-v', 0), SenseInfo('00608372-v', 0), SenseInfo('00594621-v', 585), SenseInfo('00595935-v', 142), SenseInfo('00595630-v', 123), SenseInfo('00594337-v', 76), SenseInfo('00596644-v', 17), SenseInfo('00592883-v', 10), SenseInfo('00596132-v', 1), SenseInfo('01426397-v', 0), SenseInfo('00608670-v', 0), SenseInfo('00608502-v', 0), SenseInfo('00608372-v', 0), SenseInfo('00594621-v', 585), SenseInfo('00595935-v', 142), SenseInfo('00595630-v', 123), SenseInfo('00594337-v', 76), SenseInfo('00596644-v', 17), SenseInfo('00592883-v', 10), SenseInfo('00596132-v', 1), SenseInfo('01426397-v', 0), SenseInfo('00608670-v', 0), SenseInfo('00608502-v', 0), SenseInfo('00608372-v', 0), SenseInfo('00594621-v', 585), SenseInfo('00595935-v', 142), SenseInfo('00595630-v', 123), SenseInfo('00594337-v', 76), SenseInfo('00596644-v', 17), SenseInfo('00592883-v', 10), SenseInfo('00596132-v', 1), SenseInfo('01426397-v', 0), SenseInfo('00608670-v', 0), SenseInfo('00608502-v', 0), SenseInfo('00608372-v', 0), SenseInfo('00594621-v', 585), SenseInfo('00595935-v', 142), SenseInfo('00595630-v', 123), SenseInfo('00594337-v', 76), SenseInfo('00596644-v', 17), SenseInfo('00592883-v', 10), SenseInfo('00596132-v', 1), SenseInfo('01426397-v', 0), SenseInfo('00608670-v', 0), SenseInfo('00608502-v', 0), SenseInfo('00608372-v', 0), SenseInfo('00594621-v', 585), SenseInfo('00595935-v', 142), SenseInfo('00595630-v', 123), SenseInfo('00594337-v', 76), SenseInfo('00596644-v', 17), SenseInfo('00592883-v', 10), SenseInfo('00596132-v', 1), SenseInfo('01426397-v', 0), SenseInfo('00608670-v', 0), SenseInfo('00608502-v', 0), SenseInfo('00608372-v', 0) ],
"_self-service+hut_n_1_rel" : [  ],
"_alternate_n_to_rel" : [ SenseInfo('10680153-n', 0) ],
"_matter+of+course_n_1_rel" : [ SenseInfo('07295850-n', 1) ],
"_logon_v_to_rel" : [  ],
"_affirmation_n_of_rel" : [ SenseInfo('06732350-n', 1), SenseInfo('07203126-n', 0), SenseInfo('06684798-n', 0), SenseInfo('01186192-n', 0), SenseInfo('06732350-n', 1), SenseInfo('07203126-n', 0), SenseInfo('06684798-n', 0), SenseInfo('01186192-n', 0) ],
"_start_v_out_rel" : [ SenseInfo('00345761-v', 159), SenseInfo('00348746-v', 45), SenseInfo('02014165-v', 29), SenseInfo('02608347-v', 17), SenseInfo('01628449-v', 16), SenseInfo('01650610-v', 11), SenseInfo('01910373-v', 7), SenseInfo('01857717-v', 7), SenseInfo('01864230-v', 5), SenseInfo('02379528-v', 2), SenseInfo('01075164-v', 1), SenseInfo('02608823-v', 0), SenseInfo('02600948-v', 0), SenseInfo('02081946-v', 0), SenseInfo('00345761-v', 159), SenseInfo('00348746-v', 45), SenseInfo('02014165-v', 29), SenseInfo('02608347-v', 17), SenseInfo('01628449-v', 16), SenseInfo('01650610-v', 11), SenseInfo('01910373-v', 7), SenseInfo('01857717-v', 7), SenseInfo('01864230-v', 5), SenseInfo('02379528-v', 2), SenseInfo('01075164-v', 1), SenseInfo('02608823-v', 0), SenseInfo('02600948-v', 0), SenseInfo('02081946-v', 0) ],
"_wait_v_on_rel" : [ SenseInfo('02637938-v', 100), SenseInfo('02641463-v', 49), SenseInfo('00720063-v', 33), SenseInfo('02413290-v', 2) ],
"_synthesis_n_of_rel" : [ SenseInfo('13565379-n', 6), SenseInfo('05783940-n', 2), SenseInfo('05774129-n', 0) ],
"_countenance_n_1_rel" : [ SenseInfo('04679549-n', 6), SenseInfo('06687358-n', 1), SenseInfo('05601357-n', 1) ],
"_contrast_v_with_rel" : [ SenseInfo('00661213-v', 7), SenseInfo('02666882-v', 3), SenseInfo('00661213-v', 7), SenseInfo('02666882-v', 3), SenseInfo('00661213-v', 7), SenseInfo('02666882-v', 3), SenseInfo('00661213-v', 7), SenseInfo('02666882-v', 3) ],
"_so+far+as_x_rel" : [  ],
"_er_a_1_rel" : [ SenseInfo('14636988-n', 0), SenseInfo('03283221-n', 0) ],
"_inset_a_1_rel" : [ SenseInfo('03573464-n', 1), SenseInfo('03573282-n', 0), SenseInfo('03471190-n', 0) ],
"_lock_v_up_rel" : [ SenseInfo('01348174-v', 8), SenseInfo('01510827-v', 7), SenseInfo('00219775-v', 4), SenseInfo('01606736-v', 2), SenseInfo('01606018-v', 2), SenseInfo('01810320-v', 1), SenseInfo('01347678-v', 1), SenseInfo('02050865-v', 0), SenseInfo('01655347-v', 0), SenseInfo('01348174-v', 8), SenseInfo('01510827-v', 7), SenseInfo('00219775-v', 4), SenseInfo('01606736-v', 2), SenseInfo('01606018-v', 2), SenseInfo('01810320-v', 1), SenseInfo('01347678-v', 1), SenseInfo('02050865-v', 0), SenseInfo('01655347-v', 0) ],
"_low+grade_a_1_rel" : [ SenseInfo('02347489-a', 1) ],
"_proportion_n_1_rel" : [ SenseInfo('13815742-n', 9), SenseInfo('05091194-n', 7), SenseInfo('13898315-n', 1), SenseInfo('13815449-n', 0), SenseInfo('05076827-n', 0) ],
"_neglect_v_1_rel" : [ SenseInfo('00614999-v', 6), SenseInfo('02529284-v', 4), SenseInfo('00616153-v', 4), SenseInfo('00616857-v', 3), SenseInfo('00614999-v', 6), SenseInfo('02529284-v', 4), SenseInfo('00616153-v', 4), SenseInfo('00616857-v', 3) ],
"_count_n_i_rel" : [ SenseInfo('13591761-n', 4), SenseInfo('00634586-n', 4), SenseInfo('09969218-n', 0) ],
"_bogey_n_1_rel" : [ SenseInfo('09542258-n', 1), SenseInfo('13595414-n', 0), SenseInfo('02863638-n', 0) ],
"_miniature_a_1_rel" : [ SenseInfo('01394075-a', 1) ],
"_self-control_n_1_rel" : [ SenseInfo('01069578-n', 1), SenseInfo('04862005-n', 0) ],
"_receipt_n_of_rel" : [ SenseInfo('00090253-n', 3), SenseInfo('06520222-n', 2) ],
"_goddess_n_1_rel" : [ SenseInfo('09535622-n', 2) ],
"_leftmost_a_1_rel" : [ SenseInfo('02033450-a', 0), SenseInfo('02033450-a', 0), SenseInfo('02033450-a', 0), SenseInfo('02033450-a', 0), SenseInfo('02033450-a', 0), SenseInfo('02033450-a', 0) ],
"_desperation_n_1_rel" : [ SenseInfo('14486274-n', 4), SenseInfo('04662390-n', 0) ],
"_exquisite_a_1_rel" : [ SenseInfo('01511387-a', 3), SenseInfo('00850552-a', 0), SenseInfo('00706311-a', 0), SenseInfo('00218837-a', 0), SenseInfo('01511387-a', 3), SenseInfo('00850552-a', 0), SenseInfo('00706311-a', 0), SenseInfo('00218837-a', 0) ],
"_correctness_n_1_rel" : [ SenseInfo('04802198-n', 2), SenseInfo('04899201-n', 0) ],
"_bookstore_n_1_rel" : [ SenseInfo('02871525-n', 0), SenseInfo('02871525-n', 0) ],
"_deduct_v_from_rel" : [ SenseInfo('00641252-v', 13), SenseInfo('02215001-v', 3), SenseInfo('00636574-v', 0), SenseInfo('00641252-v', 13), SenseInfo('02215001-v', 3), SenseInfo('00636574-v', 0) ],
"_mutation_n_1_rel" : [ SenseInfo('10341660-n', 0), SenseInfo('07425011-n', 0), SenseInfo('07297811-n', 0) ],
"_composite_n_1_rel" : [ SenseInfo('05870365-n', 9), SenseInfo('11915214-n', 0), SenseInfo('05870365-n', 9), SenseInfo('11915214-n', 0) ],
"_plod_v_1_rel" : [ SenseInfo('01921204-v', 6) ],
"_parse_v_1_rel" : [ SenseInfo('00643910-v', 0) ],
"_competency_n_1_rel" : [ SenseInfo('05153520-n', 0) ],
"_breed_n_of-n_rel" : [ SenseInfo('08101410-n', 1), SenseInfo('05839547-n', 0), SenseInfo('08101410-n', 1), SenseInfo('05839547-n', 0) ],
"_makeshift_a_1_rel" : [ SenseInfo('01757211-a', 1) ],
"_curry_n_1_rel" : [ SenseInfo('07823951-n', 0) ],
"_cowherd_n_1_rel" : [ SenseInfo('09972661-n', 0) ],
"_fascination_n_with_rel" : [ SenseInfo('14407899-n', 2), SenseInfo('07497976-n', 0), SenseInfo('04689450-n', 0) ],
"_greet_v_1_rel" : [ SenseInfo('00897241-v', 12), SenseInfo('00897125-v', 4), SenseInfo('00718907-v', 3), SenseInfo('02197505-v', 1) ],
"_punto_n_1_rel" : [  ],
"_astonish_v_1_rel" : [ SenseInfo('00724832-v', 1), SenseInfo('00724832-v', 1), SenseInfo('00724832-v', 1), SenseInfo('00724832-v', 1), SenseInfo('00724832-v', 1), SenseInfo('00724832-v', 1), SenseInfo('00724832-v', 1) ],
"_feed_n_1_rel" : [ SenseInfo('07800091-n', 32) ],
"_tisane_n_1_rel" : [ SenseInfo('07934032-n', 0) ],
"_purchase_v_1_rel" : [ SenseInfo('02207206-v', 34) ],
"_peril_n_1_rel" : [ SenseInfo('14541852-n', 1), SenseInfo('14543552-n', 0), SenseInfo('00802238-n', 0) ],
"_slink_v_dir_rel" : [ SenseInfo('01917123-v', 2) ],
"_hinder_a_1_rel" : [ SenseInfo('00131692-a', 0) ],
"_methylphosphonic_a_1_rel" : [  ],
"_el_n_1_rel" : [ SenseInfo('13836550-n', 0), SenseInfo('03280813-n', 0) ],
"_hitherto_x_deg_rel" : [ SenseInfo('00027918-r', 2) ],
"_earthworm_n_1_rel" : [ SenseInfo('01935395-n', 0) ],
"_however_a_1_rel" : [  ],
"_ax_n_1_rel" : [ SenseInfo('02764044-n', 2), SenseInfo('02764044-n', 2) ],
"_say_v_1_rel" : [ SenseInfo('01009240-v', 1861), SenseInfo('01016002-v', 254), SenseInfo('00917300-v', 29), SenseInfo('02730813-v', 8), SenseInfo('00746718-v', 8), SenseInfo('00978549-v', 4), SenseInfo('00928959-v', 2), SenseInfo('00979870-v', 1), SenseInfo('01009821-v', 0), SenseInfo('00945499-v', 0), SenseInfo('00923197-v', 0), SenseInfo('01009240-v', 1861), SenseInfo('01016002-v', 254), SenseInfo('00917300-v', 29), SenseInfo('02730813-v', 8), SenseInfo('00746718-v', 8), SenseInfo('00978549-v', 4), SenseInfo('00928959-v', 2), SenseInfo('00979870-v', 1), SenseInfo('01009821-v', 0), SenseInfo('00945499-v', 0), SenseInfo('00923197-v', 0) ],
"_couch_v_in_rel" : [ SenseInfo('00981276-v', 1) ],
"_profitable_a_for_rel" : [ SenseInfo('01870889-a', 4), SenseInfo('01870889-a', 4), SenseInfo('01870889-a', 4), SenseInfo('01870889-a', 4) ],
"_celestial_a_1_rel" : [ SenseInfo('02685153-a', 3), SenseInfo('02684971-a', 1), SenseInfo('01179345-a', 1) ],
"_scorekeeping_n_1_rel" : [  ],
"_hang_v_on_rel" : [ SenseInfo('01482075-v', 35), SenseInfo('01481360-v', 12), SenseInfo('02485451-v', 11), SenseInfo('01977962-v', 6), SenseInfo('01542668-v', 5), SenseInfo('02734952-v', 2), SenseInfo('02170427-v', 1), SenseInfo('01481957-v', 1), SenseInfo('01216331-v', 1), SenseInfo('02741003-v', 0), SenseInfo('02557790-v', 0), SenseInfo('01677716-v', 0), SenseInfo('01481819-v', 0), SenseInfo('01481647-v', 0), SenseInfo('00210110-v', 0), SenseInfo('01482075-v', 35), SenseInfo('01481360-v', 12), SenseInfo('02485451-v', 11), SenseInfo('01977962-v', 6), SenseInfo('01542668-v', 5), SenseInfo('02734952-v', 2), SenseInfo('02170427-v', 1), SenseInfo('01481957-v', 1), SenseInfo('01216331-v', 1), SenseInfo('02741003-v', 0), SenseInfo('02557790-v', 0), SenseInfo('01677716-v', 0), SenseInfo('01481819-v', 0), SenseInfo('01481647-v', 0), SenseInfo('00210110-v', 0), SenseInfo('01482075-v', 35), SenseInfo('01481360-v', 12), SenseInfo('02485451-v', 11), SenseInfo('01977962-v', 6), SenseInfo('01542668-v', 5), SenseInfo('02734952-v', 2), SenseInfo('02170427-v', 1), SenseInfo('01481957-v', 1), SenseInfo('01216331-v', 1), SenseInfo('02741003-v', 0), SenseInfo('02557790-v', 0), SenseInfo('01677716-v', 0), SenseInfo('01481819-v', 0), SenseInfo('01481647-v', 0), SenseInfo('00210110-v', 0) ],
"_invoice_v_1_rel" : [ SenseInfo('02320903-v', 0) ],
"_auctioneer_n_1_rel" : [ SenseInfo('09608377-n', 0) ],
"_astrologer_n_1_rel" : [ SenseInfo('09817816-n', 0) ],
"_poke_v_up_rel" : [ SenseInfo('01229976-v', 7), SenseInfo('02169119-v', 5), SenseInfo('01424220-v', 0), SenseInfo('01414626-v', 0), SenseInfo('01230241-v', 0) ],
"_strawberry_a_1_rel" : [ SenseInfo('07745940-n', 1), SenseInfo('12630144-n', 0), SenseInfo('04696316-n', 0) ],
"_wobbly_a_1_rel" : [ SenseInfo('02292797-a', 1), SenseInfo('02292797-a', 1), SenseInfo('02292797-a', 1) ],
"_overlong_a_1_rel" : [  ],
"_stop_v_in_rel" : [ SenseInfo('01860795-v', 57), SenseInfo('02680814-v', 56), SenseInfo('02559752-v', 25), SenseInfo('01862918-v', 7), SenseInfo('01859221-v', 7), SenseInfo('00362348-v', 4), SenseInfo('01131473-v', 3), SenseInfo('01440378-v', 2), SenseInfo('02609764-v', 1), SenseInfo('01478002-v', 0), SenseInfo('00362610-v', 0) ],
"_cookie_n_1_rel" : [ SenseInfo('07635155-n', 1), SenseInfo('09963680-n', 0), SenseInfo('06387538-n', 0) ],
"_caretaker_n_of_rel" : [ SenseInfo('09895701-n', 1), SenseInfo('09895902-n', 0) ],
"_barberry_n_1_rel" : [ SenseInfo('11697560-n', 0) ],
"_crack_v_1_rel" : [ SenseInfo('00336260-v', 6), SenseInfo('02183024-v', 4), SenseInfo('02182851-v', 2), SenseInfo('01401955-v', 2), SenseInfo('00539770-v', 2), SenseInfo('00337234-v', 1), SenseInfo('00337065-v', 1), SenseInfo('02571067-v', 0), SenseInfo('01785579-v', 0), SenseInfo('00953923-v', 0), SenseInfo('00336718-v', 0), SenseInfo('00238542-v', 0), SenseInfo('00238372-v', 0) ],
"_mainland_n_1_rel" : [ SenseInfo('09346120-n', 3) ],
"_snooze_v_1_rel" : [ SenseInfo('00015303-v', 0) ],
"_dressy_a_1_rel" : [ SenseInfo('01795353-a', 2) ],
"_loom_n_1_rel" : [ SenseInfo('03689157-n', 1) ],
"_fanatic_a_1_rel" : [ SenseInfo('01726859-a', 0) ],
"_flip+flop_v_1_rel" : [ SenseInfo('00121678-v', 0) ],
"_yield_n_1_rel" : [ SenseInfo('00914632-n', 4), SenseInfo('13260190-n', 1), SenseInfo('04612722-n', 1), SenseInfo('13758745-n', 0) ],
"_wayside_n_1_rel" : [ SenseInfo('04565233-n', 1) ],
"_custom_n_of_rel" : [ SenseInfo('00413239-n', 4), SenseInfo('05667404-n', 3), SenseInfo('13317002-n', 0), SenseInfo('01096873-n', 0), SenseInfo('00413239-n', 4), SenseInfo('05667404-n', 3), SenseInfo('13317002-n', 0), SenseInfo('01096873-n', 0), SenseInfo('00413239-n', 4), SenseInfo('05667404-n', 3), SenseInfo('13317002-n', 0), SenseInfo('01096873-n', 0) ],
"_mutant_n_1_rel" : [ SenseInfo('10341660-n', 1), SenseInfo('01324305-n', 0) ],
"_and+associates_n_1_rel" : [  ],
"_ethyl_n_1_rel" : [ SenseInfo('14710325-n', 0) ],
"_spring_v_1_rel" : [ SenseInfo('01963942-v', 15), SenseInfo('02623906-v', 5), SenseInfo('01892104-v', 2), SenseInfo('00095271-v', 1), SenseInfo('00935827-v', 0), SenseInfo('01963942-v', 15), SenseInfo('02623906-v', 5), SenseInfo('01892104-v', 2), SenseInfo('00095271-v', 1), SenseInfo('00935827-v', 0) ],
"_conscientious_a_1_rel" : [ SenseInfo('00310138-a', 2), SenseInfo('02086115-a', 0) ],
"_nowhere+near_x_deg_rel" : [  ],
"_struggle_v_for_rel" : [ SenseInfo('02407338-v', 13), SenseInfo('01505058-v', 7), SenseInfo('01921772-v', 3), SenseInfo('01090335-v', 2) ],
"_lather_n_1_rel" : [ SenseInfo('09439213-n', 3), SenseInfo('14403560-n', 0), SenseInfo('10247800-n', 0), SenseInfo('09336555-n', 0) ],
"_extinguish_v_cause_rel" : [ SenseInfo('00478217-v', 1), SenseInfo('02761897-v', 0), SenseInfo('00478682-v', 0), SenseInfo('00471711-v', 0), SenseInfo('00470701-v', 0) ],
"_topsy-turvy_a_1_rel" : [ SenseInfo('02425529-a', 1), SenseInfo('02425529-a', 1) ],
"_flourish_n_1_rel" : [ SenseInfo('06890470-n', 1), SenseInfo('06890577-n', 0), SenseInfo('06890373-n', 0), SenseInfo('06890254-n', 0), SenseInfo('06856884-n', 0) ],
"_parliamentary_a_1_rel" : [ SenseInfo('02774411-a', 2), SenseInfo('00715830-a', 1), SenseInfo('00716056-a', 0) ],
"_quieten_v_cause_rel" : [ SenseInfo('02190188-v', 0), SenseInfo('01764800-v', 0), SenseInfo('00461493-v', 0) ],
"_monument_n_to-for_rel" : [ SenseInfo('03743902-n', 7), SenseInfo('08600443-n', 0), SenseInfo('04076713-n', 0), SenseInfo('03743902-n', 7), SenseInfo('08600443-n', 0), SenseInfo('04076713-n', 0) ],
"_industrial+strength_a_1_rel" : [ SenseInfo('02322704-a', 0), SenseInfo('02322704-a', 0) ],
"_horrified_a_1_rel" : [ SenseInfo('00079786-a', 2) ],
"_assist_n_1_rel" : [ SenseInfo('01207609-n', 1), SenseInfo('00558008-n', 1) ],
"_crustaceous_a_1_rel" : [ SenseInfo('02706160-a', 0), SenseInfo('02706051-a', 0) ],
"_thought_n_of_rel" : [ SenseInfo('05833840-n', 70), SenseInfo('05770926-n', 21), SenseInfo('05954481-n', 11), SenseInfo('05945642-n', 0), SenseInfo('05833840-n', 70), SenseInfo('05770926-n', 21), SenseInfo('05954481-n', 11), SenseInfo('05945642-n', 0) ],
"_alveld_n_1_rel" : [  ],
"_awkward_a_for_rel" : [ SenseInfo('00605406-a', 6), SenseInfo('01140514-a', 2), SenseInfo('02564023-a', 1), SenseInfo('01001180-a', 0), SenseInfo('00746047-a', 0), SenseInfo('00480439-a', 0), SenseInfo('00605406-a', 6), SenseInfo('01140514-a', 2), SenseInfo('02564023-a', 1), SenseInfo('01001180-a', 0), SenseInfo('00746047-a', 0), SenseInfo('00480439-a', 0), SenseInfo('00605406-a', 6), SenseInfo('01140514-a', 2), SenseInfo('02564023-a', 1), SenseInfo('01001180-a', 0), SenseInfo('00746047-a', 0), SenseInfo('00480439-a', 0) ],
"_tie_v_up_rel" : [ SenseInfo('01285440-v', 13), SenseInfo('01115190-v', 5), SenseInfo('00234217-v', 4), SenseInfo('01354673-v', 2), SenseInfo('00141632-v', 1), SenseInfo('02538086-v', 0), SenseInfo('02489456-v', 0), SenseInfo('01658444-v', 0), SenseInfo('01355411-v', 0) ],
"_brown_a_1_rel" : [ SenseInfo('00372111-a', 38), SenseInfo('00245112-a', 0), SenseInfo('00372111-a', 38), SenseInfo('00245112-a', 0), SenseInfo('00372111-a', 38), SenseInfo('00245112-a', 0) ],
"_do_v_be_rel" : [ SenseInfo('02560585-v', 526), SenseInfo('01712704-v', 173), SenseInfo('02561995-v', 134), SenseInfo('02617567-v', 58), SenseInfo('01645601-v', 35), SenseInfo('02568672-v', 20), SenseInfo('02669789-v', 11), SenseInfo('01619014-v', 9), SenseInfo('00010435-v', 3), SenseInfo('02709107-v', 2), SenseInfo('02523221-v', 2), SenseInfo('00038849-v', 2), SenseInfo('01841772-v', 1), SenseInfo('02560585-v', 526), SenseInfo('01712704-v', 173), SenseInfo('02561995-v', 134), SenseInfo('02617567-v', 58), SenseInfo('01645601-v', 35), SenseInfo('02568672-v', 20), SenseInfo('02669789-v', 11), SenseInfo('01619014-v', 9), SenseInfo('00010435-v', 3), SenseInfo('02709107-v', 2), SenseInfo('02523221-v', 2), SenseInfo('00038849-v', 2), SenseInfo('01841772-v', 1), SenseInfo('02560585-v', 526), SenseInfo('01712704-v', 173), SenseInfo('02561995-v', 134), SenseInfo('02617567-v', 58), SenseInfo('01645601-v', 35), SenseInfo('02568672-v', 20), SenseInfo('02669789-v', 11), SenseInfo('01619014-v', 9), SenseInfo('00010435-v', 3), SenseInfo('02709107-v', 2), SenseInfo('02523221-v', 2), SenseInfo('00038849-v', 2), SenseInfo('01841772-v', 1) ],
"_vale_n_1_rel" : [ SenseInfo('09468604-n', 0) ],
"_assimilate_v_1_rel" : [ SenseInfo('00602255-v', 2), SenseInfo('00159642-v', 2), SenseInfo('00160261-v', 1), SenseInfo('01540042-v', 0), SenseInfo('00160447-v', 0) ],
"_order_v_1_rel" : [ SenseInfo('00746718-v', 28), SenseInfo('00745499-v', 14), SenseInfo('00747135-v', 5), SenseInfo('02511551-v', 3), SenseInfo('00277659-v', 1), SenseInfo('00276883-v', 1), SenseInfo('02386012-v', 0), SenseInfo('00735571-v', 0), SenseInfo('00658052-v', 0), SenseInfo('00746718-v', 28), SenseInfo('00745499-v', 14), SenseInfo('00747135-v', 5), SenseInfo('02511551-v', 3), SenseInfo('00277659-v', 1), SenseInfo('00276883-v', 1), SenseInfo('02386012-v', 0), SenseInfo('00735571-v', 0), SenseInfo('00658052-v', 0), SenseInfo('00746718-v', 28), SenseInfo('00745499-v', 14), SenseInfo('00747135-v', 5), SenseInfo('02511551-v', 3), SenseInfo('00277659-v', 1), SenseInfo('00276883-v', 1), SenseInfo('02386012-v', 0), SenseInfo('00735571-v', 0), SenseInfo('00658052-v', 0), SenseInfo('00746718-v', 28), SenseInfo('00745499-v', 14), SenseInfo('00747135-v', 5), SenseInfo('02511551-v', 3), SenseInfo('00277659-v', 1), SenseInfo('00276883-v', 1), SenseInfo('02386012-v', 0), SenseInfo('00735571-v', 0), SenseInfo('00658052-v', 0), SenseInfo('00746718-v', 28), SenseInfo('00745499-v', 14), SenseInfo('00747135-v', 5), SenseInfo('02511551-v', 3), SenseInfo('00277659-v', 1), SenseInfo('00276883-v', 1), SenseInfo('02386012-v', 0), SenseInfo('00735571-v', 0), SenseInfo('00658052-v', 0) ],
"_threshold_n_of_rel" : [ SenseInfo('15268993-n', 7), SenseInfo('05712426-n', 1), SenseInfo('03224032-n', 1), SenseInfo('03223686-n', 1), SenseInfo('13903738-n', 0), SenseInfo('15268993-n', 7), SenseInfo('05712426-n', 1), SenseInfo('03224032-n', 1), SenseInfo('03223686-n', 1), SenseInfo('13903738-n', 0) ],
"_extreme_a_1_rel" : [ SenseInfo('01511520-a', 15), SenseInfo('01534858-a', 5), SenseInfo('01535082-a', 2), SenseInfo('00446107-a', 1), SenseInfo('01511520-a', 15), SenseInfo('01534858-a', 5), SenseInfo('01535082-a', 2), SenseInfo('00446107-a', 1) ],
"_privy_a_to_rel" : [ SenseInfo('01860580-a', 0), SenseInfo('01308089-a', 0) ],
"_broomstick_n_1_rel" : [ SenseInfo('02907082-n', 0) ],
"_nanometer-scale_a_1_rel" : [  ],
"_mountainside_n_1_rel" : [ SenseInfo('09361517-n', 2) ],
"_skein_n_1_rel" : [ SenseInfo('04226464-n', 0) ],
"_manage_v_cope_rel" : [ SenseInfo('02522864-v', 27), SenseInfo('02436349-v', 5), SenseInfo('02587532-v', 3), SenseInfo('02443049-v', 3), SenseInfo('02527431-v', 2), SenseInfo('02523221-v', 0), SenseInfo('01224415-v', 0) ],
"_castle_v_1_rel" : [ SenseInfo('01077329-v', 0) ],
"_vector_n_1_rel" : [ SenseInfo('05864577-n', 13), SenseInfo('13913263-n', 0), SenseInfo('09469285-n', 0), SenseInfo('01372038-n', 0) ],
"_proportioned_a_1_rel" : [  ],
"_tranquility_n_1_rel" : [ SenseInfo('04904352-n', 1), SenseInfo('13969101-n', 0), SenseInfo('07515560-n', 0), SenseInfo('04904352-n', 1), SenseInfo('13969101-n', 0), SenseInfo('07515560-n', 0) ],
"_primrose_a_1_rel" : [ SenseInfo('12090890-n', 0) ],
"_calligraphy_n_1_rel" : [ SenseInfo('06403969-n', 0) ],
"_stable_a_1_rel" : [ SenseInfo('02290998-a', 6), SenseInfo('02274089-a', 2), SenseInfo('01930417-a', 0), SenseInfo('00894551-a', 0), SenseInfo('00348018-a', 0) ],
"_franchise_v_1_rel" : [ SenseInfo('02447542-v', 0) ],
"_so+too_a_also_rel" : [  ],
"_discrepancy_n_1_rel" : [ SenseInfo('04749709-n', 5), SenseInfo('07366627-n', 3) ],
"_at+worst_x_deg_rel" : [ SenseInfo('00105908-r', 1) ],
"_handset_n_1_rel" : [ SenseInfo('03488438-n', 0) ],
"_sigh_v_to_rel" : [ SenseInfo('00004032-v', 24), SenseInfo('00985800-v', 2), SenseInfo('00004032-v', 24), SenseInfo('00985800-v', 2) ],
"_kudos_n_1_rel" : [ SenseInfo('06693198-n', 0), SenseInfo('06693198-n', 0) ],
"_bumpy_a_1_rel" : [ SenseInfo('02243567-a', 0), SenseInfo('02240006-a', 0), SenseInfo('02243567-a', 0), SenseInfo('02240006-a', 0), SenseInfo('02243567-a', 0), SenseInfo('02240006-a', 0) ],
"_male_a_1_rel" : [ SenseInfo('01476685-a', 8), SenseInfo('01483677-a', 0), SenseInfo('01477077-a', 0) ],
"_objective_n_1_rel" : [ SenseInfo('05981230-n', 38), SenseInfo('03838298-n', 0), SenseInfo('05981230-n', 38), SenseInfo('03838298-n', 0) ],
"_rune_n_1_rel" : [ SenseInfo('06840187-n', 0) ],
"_slant_n_1_rel" : [ SenseInfo('06211078-n', 1), SenseInfo('05069199-n', 1) ],
"_hike_v_up_rel" : [ SenseInfo('01975912-v', 1), SenseInfo('01920932-v', 0) ],
"_carnival_n_1_rel" : [ SenseInfo('00511555-n', 1), SenseInfo('00552679-n', 0), SenseInfo('00519333-n', 0) ],
"_warbler_n_1_rel" : [ SenseInfo('10766492-n', 0), SenseInfo('01563128-n', 0), SenseInfo('10766492-n', 0), SenseInfo('01563128-n', 0) ],
"_pirouette_n_1_rel" : [ SenseInfo('00343730-n', 0) ],
"_symmetric_a_1_rel" : [ SenseInfo('02371718-a', 7), SenseInfo('02371718-a', 7) ],
"_comparably_x_deg_rel" : [ SenseInfo('00370597-r', 0) ],
"_jowl_n_1_rel" : [ SenseInfo('05275905-n', 2), SenseInfo('05602982-n', 0) ],
"_recurrent_a_1_rel" : [ SenseInfo('00592880-a', 2), SenseInfo('00592880-a', 2) ],
"_homologous_a_1_rel" : [ SenseInfo('01220640-a', 0), SenseInfo('01220052-a', 0) ],
"_guy_n_1_rel" : [ SenseInfo('10153414-n', 33), SenseInfo('03471974-n', 1), SenseInfo('03471779-n', 0) ],
"_prostitution_n_1_rel" : [ SenseInfo('00748155-n', 2) ],
"_vein_v_1_rel" : [ SenseInfo('01696350-v', 1) ],
"_merit_n_1_rel" : [ SenseInfo('05138958-n', 5), SenseInfo('04807050-n', 3) ],
"_basejump_v_1_rel" : [  ],
"_reproach_v_1_rel" : [ SenseInfo('00825975-v', 2) ],
"_else_a_1_rel" : [  ],
"_century_n_1_rel" : [ SenseInfo('15205532-n', 103), SenseInfo('13750415-n', 0) ],
"_notice_n_1_rel" : [ SenseInfo('06747670-n', 8), SenseInfo('05703429-n', 3), SenseInfo('07185668-n', 2), SenseInfo('07212612-n', 1), SenseInfo('06793426-n', 1), SenseInfo('05703803-n', 1), SenseInfo('06410776-n', 0), SenseInfo('06747670-n', 8), SenseInfo('05703429-n', 3), SenseInfo('07185668-n', 2), SenseInfo('07212612-n', 1), SenseInfo('06793426-n', 1), SenseInfo('05703803-n', 1), SenseInfo('06410776-n', 0) ],
"_amiss_a_1_rel" : [ SenseInfo('01092371-a', 1) ],
"_davenport_n_1_rel" : [ SenseInfo('09086635-n', 0), SenseInfo('03164722-n', 0), SenseInfo('03164605-n', 0) ],
"_darn_v_1_rel" : [ SenseInfo('01330676-v', 1) ],
"_rung_n_1_rel" : [ SenseInfo('04119892-n', 0), SenseInfo('04119751-n', 0) ],
"_chestnut_a_1_rel" : [ SenseInfo('00373209-a', 1) ],
"_burial_n_of_rel" : [ SenseInfo('07451687-n', 5), SenseInfo('01050627-n', 0) ],
"_contradistinction_n_1_rel" : [ SenseInfo('05748614-n', 1) ],
"_bourgeois_n_1_rel" : [ SenseInfo('09882716-n', 0), SenseInfo('09869830-n', 0), SenseInfo('09882716-n', 0), SenseInfo('09869830-n', 0), SenseInfo('09882716-n', 0), SenseInfo('09869830-n', 0) ],
"_telegraph_v_1_rel" : [ SenseInfo('01007222-v', 2), SenseInfo('01007222-v', 2), SenseInfo('01007222-v', 2) ],
"_muffle_v_1_rel" : [ SenseInfo('01568630-v', 2), SenseInfo('02191311-v', 0) ],
"_in-house_a_1_rel" : [  ],
"_uptown_a_1_rel" : [ SenseInfo('02494594-a', 0) ],
"_woodworm_n_1_rel" : [ SenseInfo('01922948-n', 0) ],
"_inconstant_a_1_rel" : [ SenseInfo('00583990-a', 0) ],
"_jerk_v_around_rel" : [ SenseInfo('01592072-v', 15), SenseInfo('01891817-v', 4), SenseInfo('00009631-v', 2), SenseInfo('01884383-v', 0), SenseInfo('01591158-v', 0) ],
"_phonics_n_1_rel" : [ SenseInfo('00888409-n', 0) ],
"_needy_n_1_rel" : [ SenseInfo('08469678-n', 0) ],
"_fate_n_1_rel" : [ SenseInfo('07330007-n', 9), SenseInfo('09504915-n', 4), SenseInfo('14473222-n', 2) ],
"_markup_n_1_rel" : [ SenseInfo('13303880-n', 0), SenseInfo('06787602-n', 0), SenseInfo('13303880-n', 0), SenseInfo('06787602-n', 0), SenseInfo('13303880-n', 0), SenseInfo('06787602-n', 0) ],
"_seafaring_n_1_rel" : [ SenseInfo('00314469-n', 0), SenseInfo('00313647-n', 0) ],
"_expand_v_cause_rel" : [ SenseInfo('02077148-v', 7), SenseInfo('00257269-v', 6), SenseInfo('00541163-v', 4), SenseInfo('00310386-v', 4), SenseInfo('00264386-v', 3), SenseInfo('00955601-v', 0), SenseInfo('00540946-v', 0) ],
"_Zen-like_a_1_rel" : [  ],
"_towel_v_1_rel" : [ SenseInfo('01394335-v', 0) ],
"_goof_v_1_rel" : [ SenseInfo('02566227-v', 1) ],
"_homeward_a_1_rel" : [ SenseInfo('01683349-a', 0), SenseInfo('01683349-a', 0) ],
"_smooch_v_1_rel" : [ SenseInfo('01425709-v', 0) ],
"_dvd_n_1_rel" : [ SenseInfo('04533946-n', 0) ],
"_analytical_a_1_rel" : [ SenseInfo('00112231-a', 1), SenseInfo('00110853-a', 0) ],
"_heh_a_1_rel" : [  ],
"_synthetic_a_1_rel" : [ SenseInfo('01573568-a', 7), SenseInfo('00112628-a', 0), SenseInfo('00111856-a', 0), SenseInfo('00111129-a', 0), SenseInfo('01572458-a', 0), SenseInfo('01118409-a', 0), SenseInfo('01573568-a', 7), SenseInfo('00112628-a', 0), SenseInfo('00111856-a', 0), SenseInfo('00111129-a', 0), SenseInfo('01572458-a', 0), SenseInfo('01118409-a', 0) ],
"_come_v_out+of-i_rel" : [ SenseInfo('01849221-v', 276), SenseInfo('02005948-v', 235), SenseInfo('00341917-v', 147), SenseInfo('00542120-v', 41), SenseInfo('02625339-v', 40), SenseInfo('00342812-v', 11), SenseInfo('02743921-v', 9), SenseInfo('02743214-v', 7), SenseInfo('02686805-v', 6), SenseInfo('02743565-v', 3), SenseInfo('01839690-v', 3), SenseInfo('02729963-v', 2), SenseInfo('00344886-v', 2), SenseInfo('02645007-v', 1), SenseInfo('02627363-v', 1), SenseInfo('02006709-v', 1), SenseInfo('00723349-v', 1), SenseInfo('02737187-v', 0), SenseInfo('02617567-v', 0), SenseInfo('02197360-v', 0), SenseInfo('00659984-v', 0) ],
"_anther_n_1_rel" : [ SenseInfo('11675245-n', 0) ],
"_prospect_n_1_rel" : [ SenseInfo('14482968-n', 10), SenseInfo('05944958-n', 3), SenseInfo('09890749-n', 1), SenseInfo('05933246-n', 0), SenseInfo('00153665-n', 0), SenseInfo('14482968-n', 10), SenseInfo('05944958-n', 3), SenseInfo('09890749-n', 1), SenseInfo('05933246-n', 0), SenseInfo('00153665-n', 0), SenseInfo('14482968-n', 10), SenseInfo('05944958-n', 3), SenseInfo('09890749-n', 1), SenseInfo('05933246-n', 0), SenseInfo('00153665-n', 0) ],
"_whole-hearted_a_1_rel" : [ SenseInfo('02180486-a', 0), SenseInfo('02180486-a', 0) ],
"_biochemist_n_1_rel" : [ SenseInfo('09854915-n', 0) ],
"_unlucky_a_1_rel" : [ SenseInfo('01468682-a', 1), SenseInfo('01051410-a', 0), SenseInfo('01468682-a', 1), SenseInfo('01051410-a', 0), SenseInfo('01468682-a', 1), SenseInfo('01051410-a', 0), SenseInfo('01468682-a', 1), SenseInfo('01051410-a', 0), SenseInfo('01468682-a', 1), SenseInfo('01051410-a', 0), SenseInfo('01468682-a', 1), SenseInfo('01051410-a', 0), SenseInfo('01468682-a', 1), SenseInfo('01051410-a', 0) ],
"_inflexibility_n_1_rel" : [ SenseInfo('05024093-n', 0), SenseInfo('04660261-n', 0) ],
"_vacate_v_1_rel" : [ SenseInfo('02367032-v', 2), SenseInfo('02076676-v', 1), SenseInfo('00799798-v', 0) ],
"_altarpiece_n_1_rel" : [ SenseInfo('02699770-n', 0) ],
"_drabs_n_1_rel" : [ SenseInfo('04974463-n', 0), SenseInfo('04974463-n', 0) ],
"_doctoral_a_1_rel" : [ SenseInfo('02893338-a', 0) ],
"_hold_v_down_rel" : [ SenseInfo('02681795-v', 79), SenseInfo('01216670-v', 65), SenseInfo('01733477-v', 62), SenseInfo('02203362-v', 26), SenseInfo('00693780-v', 20), SenseInfo('01773130-v', 17), SenseInfo('01301410-v', 17), SenseInfo('02283324-v', 14), SenseInfo('02302220-v', 9), SenseInfo('01217043-v', 9), SenseInfo('02700867-v', 7), SenseInfo('02732798-v', 3), SenseInfo('02683489-v', 3), SenseInfo('01601234-v', 3), SenseInfo('02648502-v', 2), SenseInfo('00683771-v', 2), SenseInfo('02746275-v', 1), SenseInfo('02701210-v', 1), SenseInfo('02498320-v', 1), SenseInfo('01129876-v', 1), SenseInfo('00885217-v', 1), SenseInfo('00736586-v', 1), SenseInfo('00607000-v', 1), SenseInfo('02706816-v', 0), SenseInfo('02676789-v', 0), SenseInfo('02643574-v', 0), SenseInfo('02510337-v', 0), SenseInfo('02450989-v', 0), SenseInfo('02441897-v', 0), SenseInfo('01859586-v', 0), SenseInfo('01334744-v', 0), SenseInfo('01205153-v', 0), SenseInfo('01151753-v', 0), SenseInfo('00822367-v', 0), SenseInfo('00805376-v', 0), SenseInfo('00004492-v', 0) ],
"_administer_v_to_rel" : [ SenseInfo('02431971-v', 9), SenseInfo('02309621-v', 6), SenseInfo('02294436-v', 2), SenseInfo('00081072-v', 1), SenseInfo('02603567-v', 0) ],
"_unassuming_a_1_rel" : [ SenseInfo('01539444-a', 0), SenseInfo('01539444-a', 0) ],
"_engage_v_to_rel" : [ SenseInfo('02375131-v', 31), SenseInfo('00600370-v', 9), SenseInfo('02409412-v', 2), SenseInfo('02401399-v', 1), SenseInfo('00886602-v', 1), SenseInfo('00220115-v', 1), SenseInfo('02376089-v', 0), SenseInfo('02240151-v', 0), SenseInfo('02208537-v', 0), SenseInfo('01510827-v', 0) ],
"_by+chance_a_1_rel" : [  ],
"_turk_n_1_rel" : [ SenseInfo('09734885-n', 0) ],
"_rut_v_1_rel" : [ SenseInfo('02724705-v', 0), SenseInfo('01277431-v', 0) ],
"_notify_v_1_rel" : [ SenseInfo('00873682-v', 10) ],
"_furnace_n_1_rel" : [ SenseInfo('03404449-n', 1) ],
"_once+more_a_1_rel" : [  ],
"_quaver_n_1_rel" : [ SenseInfo('07390857-n', 1), SenseInfo('06871384-n', 0) ],
"_steamer_n_1_rel" : [ SenseInfo('07787429-n', 0), SenseInfo('04309548-n', 0), SenseInfo('04309348-n', 0), SenseInfo('01957335-n', 0) ],
"_handlebar_n_1_rel" : [ SenseInfo('03487090-n', 1) ],
"_drop_v_out_rel" : [ SenseInfo('01977701-v', 36), SenseInfo('01976841-v', 21), SenseInfo('00432683-v', 12), SenseInfo('01985923-v', 7), SenseInfo('02403920-v', 6), SenseInfo('00941446-v', 6), SenseInfo('00363110-v', 5), SenseInfo('01489465-v', 3), SenseInfo('01258302-v', 2), SenseInfo('01100008-v', 2), SenseInfo('02267060-v', 1), SenseInfo('00393534-v', 1), SenseInfo('02717472-v', 0), SenseInfo('02465939-v', 0), SenseInfo('01611516-v', 0), SenseInfo('01513430-v', 0), SenseInfo('01200661-v', 0), SenseInfo('00615615-v', 0), SenseInfo('00614999-v', 0), SenseInfo('00548616-v', 0), SenseInfo('00148341-v', 0), SenseInfo('00092293-v', 0), SenseInfo('00057764-v', 0), SenseInfo('01977701-v', 36), SenseInfo('01976841-v', 21), SenseInfo('00432683-v', 12), SenseInfo('01985923-v', 7), SenseInfo('02403920-v', 6), SenseInfo('00941446-v', 6), SenseInfo('00363110-v', 5), SenseInfo('01489465-v', 3), SenseInfo('01258302-v', 2), SenseInfo('01100008-v', 2), SenseInfo('02267060-v', 1), SenseInfo('00393534-v', 1), SenseInfo('02717472-v', 0), SenseInfo('02465939-v', 0), SenseInfo('01611516-v', 0), SenseInfo('01513430-v', 0), SenseInfo('01200661-v', 0), SenseInfo('00615615-v', 0), SenseInfo('00614999-v', 0), SenseInfo('00548616-v', 0), SenseInfo('00148341-v', 0), SenseInfo('00092293-v', 0), SenseInfo('00057764-v', 0) ],
"_kitchenette_n_1_rel" : [ SenseInfo('03620353-n', 2) ],
"_wind_n_1_rel" : [ SenseInfo('11525955-n', 28), SenseInfo('11415492-n', 1), SenseInfo('00836537-n', 1), SenseInfo('07136711-n', 0), SenseInfo('06651577-n', 0), SenseInfo('04586932-n', 0), SenseInfo('00839597-n', 0), SenseInfo('00345641-n', 0) ],
"_lighthouse_n_1_rel" : [ SenseInfo('02814860-n', 0) ],
"_purported_a_1_rel" : [  ],
"_arsenal_n_of_rel" : [ SenseInfo('02743426-n', 0), SenseInfo('02743207-n', 0), SenseInfo('02741367-n', 0) ],
"_spicy_a_1_rel" : [ SenseInfo('02398378-a', 0), SenseInfo('02397732-a', 0), SenseInfo('02132224-a', 0), SenseInfo('02398378-a', 0), SenseInfo('02397732-a', 0), SenseInfo('02132224-a', 0), SenseInfo('02398378-a', 0), SenseInfo('02397732-a', 0), SenseInfo('02132224-a', 0) ],
"_screech_v_at_rel" : [ SenseInfo('02171664-v', 5), SenseInfo('01048939-v', 0) ],
"_asymmetric_a_1_rel" : [ SenseInfo('02373599-a', 2) ],
"_academy_n_1_rel" : [ SenseInfo('08279298-n', 5), SenseInfo('08280124-n', 1), SenseInfo('08277805-n', 0), SenseInfo('02669885-n', 0), SenseInfo('08279298-n', 5), SenseInfo('08280124-n', 1), SenseInfo('08277805-n', 0), SenseInfo('02669885-n', 0) ],
"_bimonth_a_1_rel" : [  ],
"_account_n_of_rel" : [ SenseInfo('06514093-n', 12), SenseInfo('06681551-n', 7), SenseInfo('13929037-n', 5), SenseInfo('06738281-n', 3), SenseInfo('09179382-n', 1), SenseInfo('05169037-n', 1), SenseInfo('13354985-n', 0), SenseInfo('07217924-n', 0), SenseInfo('06516955-n', 0), SenseInfo('05157732-n', 0), SenseInfo('06514093-n', 12), SenseInfo('06681551-n', 7), SenseInfo('13929037-n', 5), SenseInfo('06738281-n', 3), SenseInfo('09179382-n', 1), SenseInfo('05169037-n', 1), SenseInfo('13354985-n', 0), SenseInfo('07217924-n', 0), SenseInfo('06516955-n', 0), SenseInfo('05157732-n', 0), SenseInfo('06514093-n', 12), SenseInfo('06681551-n', 7), SenseInfo('13929037-n', 5), SenseInfo('06738281-n', 3), SenseInfo('09179382-n', 1), SenseInfo('05169037-n', 1), SenseInfo('13354985-n', 0), SenseInfo('07217924-n', 0), SenseInfo('06516955-n', 0), SenseInfo('05157732-n', 0), SenseInfo('06514093-n', 12), SenseInfo('06681551-n', 7), SenseInfo('13929037-n', 5), SenseInfo('06738281-n', 3), SenseInfo('09179382-n', 1), SenseInfo('05169037-n', 1), SenseInfo('13354985-n', 0), SenseInfo('07217924-n', 0), SenseInfo('06516955-n', 0), SenseInfo('05157732-n', 0), SenseInfo('06514093-n', 12), SenseInfo('06681551-n', 7), SenseInfo('13929037-n', 5), SenseInfo('06738281-n', 3), SenseInfo('09179382-n', 1), SenseInfo('05169037-n', 1), SenseInfo('13354985-n', 0), SenseInfo('07217924-n', 0), SenseInfo('06516955-n', 0), SenseInfo('05157732-n', 0), SenseInfo('06514093-n', 12), SenseInfo('06681551-n', 7), SenseInfo('13929037-n', 5), SenseInfo('06738281-n', 3), SenseInfo('09179382-n', 1), SenseInfo('05169037-n', 1), SenseInfo('13354985-n', 0), SenseInfo('07217924-n', 0), SenseInfo('06516955-n', 0), SenseInfo('05157732-n', 0), SenseInfo('06514093-n', 12), SenseInfo('06681551-n', 7), SenseInfo('13929037-n', 5), SenseInfo('06738281-n', 3), SenseInfo('09179382-n', 1), SenseInfo('05169037-n', 1), SenseInfo('13354985-n', 0), SenseInfo('07217924-n', 0), SenseInfo('06516955-n', 0), SenseInfo('05157732-n', 0), SenseInfo('06514093-n', 12), SenseInfo('06681551-n', 7), SenseInfo('13929037-n', 5), SenseInfo('06738281-n', 3), SenseInfo('09179382-n', 1), SenseInfo('05169037-n', 1), SenseInfo('13354985-n', 0), SenseInfo('07217924-n', 0), SenseInfo('06516955-n', 0), SenseInfo('05157732-n', 0) ],
"_syndicate_n_1_rel" : [ SenseInfo('08246302-n', 1), SenseInfo('08236438-n', 1), SenseInfo('08355324-n', 0) ],
"_announcer_n_1_rel" : [ SenseInfo('09795334-n', 0), SenseInfo('09795124-n', 0) ],
"_capture_v_1_rel" : [ SenseInfo('01686626-v', 5), SenseInfo('01806505-v', 4), SenseInfo('01215421-v', 4), SenseInfo('02304241-v', 1), SenseInfo('02272549-v', 1), SenseInfo('01480149-v', 1) ],
"_rough+and+tumble_n_1_rel" : [ SenseInfo('01172441-n', 0), SenseInfo('01172441-n', 0) ],
"_long+past_p_rel" : [  ],
"_once_x_subord_rel" : [ SenseInfo('00118869-r', 98), SenseInfo('00181342-r', 28), SenseInfo('00118965-r', 21), SenseInfo('00118869-r', 98), SenseInfo('00181342-r', 28), SenseInfo('00118965-r', 21) ],
"_waste_v_1_rel" : [ SenseInfo('02268351-v', 10), SenseInfo('01161087-v', 8), SenseInfo('02223479-v', 0), SenseInfo('02067889-v', 0), SenseInfo('01327301-v', 0), SenseInfo('01158181-v', 0), SenseInfo('00389992-v', 0), SenseInfo('00389406-v', 0), SenseInfo('00388635-v', 0), SenseInfo('00093775-v', 0) ],
"_counterbid_n_1_rel" : [  ],
"_timid_a_1_rel" : [ SenseInfo('00251809-a', 3), SenseInfo('00339941-a', 0), SenseInfo('00265989-a', 0) ],
"_incessant_a_1_rel" : [ SenseInfo('00595299-a', 0) ],
"_afterward_p_rel" : [ SenseInfo('00061203-r', 13) ],
"_sign_v_up_rel" : [ SenseInfo('00996485-v', 16), SenseInfo('02464866-v', 13), SenseInfo('00889229-v', 8), SenseInfo('02409941-v', 2), SenseInfo('01039330-v', 1), SenseInfo('01498319-v', 0), SenseInfo('00929160-v', 0), SenseInfo('00867231-v', 0), SenseInfo('00996485-v', 16), SenseInfo('02464866-v', 13), SenseInfo('00889229-v', 8), SenseInfo('02409941-v', 2), SenseInfo('01039330-v', 1), SenseInfo('01498319-v', 0), SenseInfo('00929160-v', 0), SenseInfo('00867231-v', 0) ],
"_melody_n_1_rel" : [ SenseInfo('07028373-n', 8), SenseInfo('05711915-n', 4) ],
"_insipid_a_1_rel" : [ SenseInfo('02399595-a', 0), SenseInfo('01345997-a', 0) ],
"_surround_v_1_rel" : [ SenseInfo('01467370-v', 6), SenseInfo('01568886-v', 2), SenseInfo('01127411-v', 1), SenseInfo('01130607-v', 0) ],
"_pebbly_a_1_rel" : [ SenseInfo('02242223-a', 0) ],
"_encrypt_v_1_rel" : [ SenseInfo('00994076-v', 0) ],
"_requital_n_1_rel" : [ SenseInfo('13300828-n', 0), SenseInfo('01235137-n', 0) ],
"_spectrometer_n_1_rel" : [ SenseInfo('03726516-n', 2) ],
"_alphabet_n_1_rel" : [ SenseInfo('06497459-n', 0), SenseInfo('05872742-n', 0) ],
"_startled_a_1_rel" : [ SenseInfo('02359051-a', 6), SenseInfo('02359051-a', 6) ],
"_increment_v_1_rel" : [  ],
"_chorus_n_1_rel" : [ SenseInfo('07379695-n', 3), SenseInfo('08187837-n', 1), SenseInfo('07050177-n', 1), SenseInfo('08188449-n', 0), SenseInfo('08187988-n', 0) ],
"_pineapple_n_1_rel" : [ SenseInfo('12607456-n', 0), SenseInfo('07753275-n', 0) ],
"_b+_n_1_rel" : [ SenseInfo('01349948-n', 1), SenseInfo('15090742-n', 0), SenseInfo('14631871-n', 0), SenseInfo('13713521-n', 0), SenseInfo('13614256-n', 0), SenseInfo('06831284-n', 0), SenseInfo('05400978-n', 0) ],
"_aha_a_1_rel" : [  ],
"_get_v_across_rel" : [ SenseInfo('02210855-v', 235), SenseInfo('00149583-v', 157), SenseInfo('00120796-v', 82), SenseInfo('00522751-v', 64), SenseInfo('02005948-v', 58), SenseInfo('01433294-v', 45), SenseInfo('02108026-v', 36), SenseInfo('01153947-v', 14), SenseInfo('02355596-v', 9), SenseInfo('00770437-v', 7), SenseInfo('01215421-v', 4), SenseInfo('00094460-v', 4), SenseInfo('00087736-v', 4), SenseInfo('01066036-v', 3), SenseInfo('00120316-v', 3), SenseInfo('01026975-v', 2), SenseInfo('00589904-v', 2), SenseInfo('01505958-v', 1), SenseInfo('01401115-v', 1), SenseInfo('00639849-v', 1), SenseInfo('02359340-v', 0), SenseInfo('02208265-v', 0), SenseInfo('02189398-v', 0), SenseInfo('02109645-v', 0), SenseInfo('02108654-v', 0), SenseInfo('02010864-v', 0), SenseInfo('02006573-v', 0), SenseInfo('01771194-v', 0), SenseInfo('01771039-v', 0), SenseInfo('01738107-v', 0), SenseInfo('01643297-v', 0), SenseInfo('01565211-v', 0), SenseInfo('00622384-v', 0), SenseInfo('00345761-v', 0), SenseInfo('00065639-v', 0), SenseInfo('00054628-v', 0) ],
"_remove_n_1_rel" : [ SenseInfo('05090255-n', 0) ],
"_stress_n_1_rel" : [ SenseInfo('07085375-n', 67), SenseInfo('14376188-n', 5), SenseInfo('14435187-n', 3), SenseInfo('14410089-n', 2), SenseInfo('11514805-n', 2) ],
"_and+crew_n_1_rel" : [  ],
"_get_v_cause_rel" : [ SenseInfo('02210855-v', 235), SenseInfo('00149583-v', 157), SenseInfo('00120796-v', 82), SenseInfo('00522751-v', 64), SenseInfo('02005948-v', 58), SenseInfo('01433294-v', 45), SenseInfo('02108026-v', 36), SenseInfo('01153947-v', 14), SenseInfo('02355596-v', 9), SenseInfo('00770437-v', 7), SenseInfo('01215421-v', 4), SenseInfo('00094460-v', 4), SenseInfo('00087736-v', 4), SenseInfo('01066036-v', 3), SenseInfo('00120316-v', 3), SenseInfo('01026975-v', 2), SenseInfo('00589904-v', 2), SenseInfo('01505958-v', 1), SenseInfo('01401115-v', 1), SenseInfo('00639849-v', 1), SenseInfo('02359340-v', 0), SenseInfo('02208265-v', 0), SenseInfo('02189398-v', 0), SenseInfo('02109645-v', 0), SenseInfo('02108654-v', 0), SenseInfo('02010864-v', 0), SenseInfo('02006573-v', 0), SenseInfo('01771194-v', 0), SenseInfo('01771039-v', 0), SenseInfo('01738107-v', 0), SenseInfo('01643297-v', 0), SenseInfo('01565211-v', 0), SenseInfo('00622384-v', 0), SenseInfo('00345761-v', 0), SenseInfo('00065639-v', 0), SenseInfo('00054628-v', 0) ],
"_foothold_n_1_rel" : [ SenseInfo('08689028-n', 0), SenseInfo('03379989-n', 0), SenseInfo('00036299-n', 0) ],
"_lithium_n_1_rel" : [ SenseInfo('14643793-n', 0) ],
"_immoral_a_1_rel" : [ SenseInfo('01549291-a', 2), SenseInfo('02036077-a', 2) ],
"_prop_n_1_rel" : [ SenseInfo('04011242-n', 1), SenseInfo('04012260-n', 0), SenseInfo('02692086-n', 0) ],
"_inodorous_a_1_rel" : [ SenseInfo('01057775-a', 0) ],
"_handicapped_n_1_rel" : [ SenseInfo('07946288-n', 0) ],
"_unqualified_a_1_rel" : [ SenseInfo('01913715-a', 2), SenseInfo('01911415-a', 0), SenseInfo('00512261-a', 0), SenseInfo('00853631-a', 0) ],
"_take_v_for-i_rel" : [ SenseInfo('02599636-v', 92), SenseInfo('02267989-v', 74), SenseInfo('01999798-v', 73), SenseInfo('01214265-v', 50), SenseInfo('00524682-v', 38), SenseInfo('00624476-v', 36), SenseInfo('02077656-v', 32), SenseInfo('02205272-v', 28), SenseInfo('01842690-v', 26), SenseInfo('00674607-v', 26), SenseInfo('02236124-v', 25), SenseInfo('02394183-v', 22), SenseInfo('00734054-v', 22), SenseInfo('02627934-v', 21), SenseInfo('02109045-v', 21), SenseInfo('01002740-v', 16), SenseInfo('00173338-v', 16), SenseInfo('01156834-v', 15), SenseInfo('00669762-v', 15), SenseInfo('02209936-v', 14), SenseInfo('02206619-v', 13), SenseInfo('01982395-v', 10), SenseInfo('02236624-v', 8), SenseInfo('00523095-v', 7), SenseInfo('00599992-v', 6), SenseInfo('00756076-v', 5), SenseInfo('02075857-v', 4), SenseInfo('01151110-v', 4), SenseInfo('00557404-v', 4), SenseInfo('02717102-v', 2), SenseInfo('02208537-v', 2), SenseInfo('02209745-v', 1), SenseInfo('02208118-v', 1), SenseInfo('02201138-v', 1), SenseInfo('01427127-v', 1), SenseInfo('00758333-v', 1), SenseInfo('02741546-v', 0), SenseInfo('02701210-v', 0), SenseInfo('02590253-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01100830-v', 0), SenseInfo('00087736-v', 0) ],
"_bedtime_n_1_rel" : [ SenseInfo('15168475-n', 1) ],
"_poke_v_1_rel" : [ SenseInfo('01229976-v', 7), SenseInfo('02169119-v', 5), SenseInfo('01424220-v', 0), SenseInfo('01414626-v', 0), SenseInfo('01230241-v', 0), SenseInfo('01229976-v', 7), SenseInfo('02169119-v', 5), SenseInfo('01424220-v', 0), SenseInfo('01414626-v', 0), SenseInfo('01230241-v', 0) ],
"_vertical_a_1_rel" : [ SenseInfo('01233347-a', 9), SenseInfo('02824040-a', 0), SenseInfo('01235859-a', 0), SenseInfo('01204142-a', 0), SenseInfo('01233347-a', 9), SenseInfo('02824040-a', 0), SenseInfo('01235859-a', 0), SenseInfo('01204142-a', 0) ],
"_lovely_a_1_rel" : [ SenseInfo('00219809-a', 10), SenseInfo('01459755-a', 1), SenseInfo('00219809-a', 10), SenseInfo('01459755-a', 1), SenseInfo('00219809-a', 10), SenseInfo('01459755-a', 1) ],
"_suck_n_1_rel" : [ SenseInfo('00842692-n', 1) ],
"_pull_v_open_rel" : [ SenseInfo('01448100-v', 44), SenseInfo('01505254-v', 8), SenseInfo('02057499-v', 6), SenseInfo('01609287-v', 3), SenseInfo('02582615-v', 2), SenseInfo('01995211-v', 2), SenseInfo('02057337-v', 1), SenseInfo('00071803-v', 1), SenseInfo('02103162-v', 0), SenseInfo('01947247-v', 0), SenseInfo('01858573-v', 0), SenseInfo('01573276-v', 0), SenseInfo('01407059-v', 0), SenseInfo('01384275-v', 0), SenseInfo('01351170-v', 0), SenseInfo('01148710-v', 0), SenseInfo('00571596-v', 0), SenseInfo('01448100-v', 44), SenseInfo('01505254-v', 8), SenseInfo('02057499-v', 6), SenseInfo('01609287-v', 3), SenseInfo('02582615-v', 2), SenseInfo('01995211-v', 2), SenseInfo('02057337-v', 1), SenseInfo('00071803-v', 1), SenseInfo('02103162-v', 0), SenseInfo('01947247-v', 0), SenseInfo('01858573-v', 0), SenseInfo('01573276-v', 0), SenseInfo('01407059-v', 0), SenseInfo('01384275-v', 0), SenseInfo('01351170-v', 0), SenseInfo('01148710-v', 0), SenseInfo('00571596-v', 0) ],
"_anger_n_1_rel" : [ SenseInfo('07516354-n', 22), SenseInfo('14036539-n', 1), SenseInfo('00758972-n', 0) ],
"_resource_v_1_rel" : [  ],
"_best_v_1_rel" : [ SenseInfo('01109259-v', 1) ],
"_alluring_a_1_rel" : [ SenseInfo('02097480-a', 0) ],
"_sport_n_1_rel" : [ SenseInfo('00523513-n', 11), SenseInfo('00433216-n', 6), SenseInfo('10639238-n', 0), SenseInfo('10639047-n', 0), SenseInfo('10638922-n', 0), SenseInfo('10341660-n', 0), SenseInfo('06780882-n', 0) ],
"_derive_v_from_rel" : [ SenseInfo('00636574-v', 25), SenseInfo('02292125-v', 11), SenseInfo('00251791-v', 7), SenseInfo('00251615-v', 3), SenseInfo('02737187-v', 1), SenseInfo('00636574-v', 25), SenseInfo('02292125-v', 11), SenseInfo('00251791-v', 7), SenseInfo('00251615-v', 3), SenseInfo('02737187-v', 1) ],
"_place_v_with_rel" : [ SenseInfo('01494310-v', 135), SenseInfo('02392762-v', 13), SenseInfo('00658052-v', 7), SenseInfo('02333689-v', 4), SenseInfo('00745970-v', 4), SenseInfo('00659776-v', 3), SenseInfo('01150559-v', 2), SenseInfo('00618878-v', 2), SenseInfo('02537960-v', 1), SenseInfo('01711749-v', 1), SenseInfo('00673448-v', 1), SenseInfo('02695895-v', 0), SenseInfo('02271137-v', 0), SenseInfo('01088923-v', 0), SenseInfo('01086691-v', 0), SenseInfo('01049276-v', 0) ],
"_inhere_v_1_rel" : [ SenseInfo('02653564-v', 0) ],
"_attacker_n_1_rel" : [ SenseInfo('09821253-n', 3) ],
"_legion_a_1_rel" : [ SenseInfo('01552419-a', 0) ],
"_triple_v_cause_rel" : [ SenseInfo('00246746-v', 3), SenseInfo('01409642-v', 1) ],
"_decompose_v_1_rel" : [ SenseInfo('00209174-v', 3), SenseInfo('00399074-v', 0), SenseInfo('00209837-v', 0) ],
"_industrialize_v_1_rel" : [ SenseInfo('00576979-v', 0), SenseInfo('00500356-v', 0) ],
"_disassemble_v_1_rel" : [ SenseInfo('01657977-v', 1) ],
"_identifiable_a_1_rel" : [ SenseInfo('01272397-a', 1), SenseInfo('01272397-a', 1) ],
"_greek_n_1_rel" : [ SenseInfo('06976392-n', 6), SenseInfo('09710164-n', 4) ],
"_remand_v_to_rel" : [ SenseInfo('00949974-v', 3), SenseInfo('02494356-v', 0), SenseInfo('00949974-v', 3), SenseInfo('02494356-v', 0) ],
"_company_n_of_rel" : [ SenseInfo('08058098-n', 60), SenseInfo('08214272-n', 28), SenseInfo('13929588-n', 6), SenseInfo('08187033-n', 5), SenseInfo('09887850-n', 3), SenseInfo('08184861-n', 3), SenseInfo('08264897-n', 0), SenseInfo('08219059-n', 0), SenseInfo('08077711-n', 0) ],
"_sign_v_on_rel" : [ SenseInfo('00996485-v', 16), SenseInfo('02464866-v', 13), SenseInfo('00889229-v', 8), SenseInfo('02409941-v', 2), SenseInfo('01039330-v', 1), SenseInfo('01498319-v', 0), SenseInfo('00929160-v', 0), SenseInfo('00867231-v', 0) ],
"_geminate_n_1_rel" : [ SenseInfo('07119776-n', 0) ],
"_eventful_a_1_rel" : [ SenseInfo('00804220-a', 0), SenseInfo('01277753-a', 0) ],
"_ambush_n_1_rel" : [ SenseInfo('01246926-n', 5) ],
"_career_n_1_rel" : [ SenseInfo('00583246-n', 22), SenseInfo('00282613-n', 8) ],
"_behind-the-scenes_a_1_rel" : [ SenseInfo('01707531-a', 0), SenseInfo('01707531-a', 0) ],
"_wonder_v_1_rel" : [ SenseInfo('00729378-v', 58), SenseInfo('00925110-v', 41), SenseInfo('00925490-v', 2), SenseInfo('00729378-v', 58), SenseInfo('00925110-v', 41), SenseInfo('00925490-v', 2), SenseInfo('00729378-v', 58), SenseInfo('00925110-v', 41), SenseInfo('00925490-v', 2) ],
"_bookcase_n_1_rel" : [ SenseInfo('02870880-n', 2) ],
"_progressive_n_1_rel" : [ SenseInfo('13805734-n', 0), SenseInfo('10256756-n', 0) ],
"_qualification_n_1_rel" : [ SenseInfo('04717139-n', 8), SenseInfo('00200563-n', 2), SenseInfo('06762380-n', 0) ],
"_bangladeshi_a_1_rel" : [ SenseInfo('03046349-a', 0) ],
"_supreme_a_1_rel" : [ SenseInfo('01579467-a', 6), SenseInfo('00792641-a', 3), SenseInfo('02344512-a', 1), SenseInfo('01495912-a', 1) ],
"_classroom_n_1_rel" : [ SenseInfo('03038685-n', 5) ],
"_tanned_a_1_rel" : [ SenseInfo('00244958-a', 1), SenseInfo('01659355-a', 0) ],
"_transmission_n_of_rel" : [ SenseInfo('00121366-n', 4), SenseInfo('06251781-n', 2), SenseInfo('13589003-n', 0), SenseInfo('07360647-n', 0), SenseInfo('04472243-n', 0) ],
"_vampire_n_1_rel" : [ SenseInfo('09544109-n', 0) ],
"_rationale_n_1_rel" : [ SenseInfo('05793210-n', 3) ],
"_genetic_a_1_rel" : [ SenseInfo('01314537-a', 2), SenseInfo('02734544-a', 0), SenseInfo('02734391-a', 0), SenseInfo('02734192-a', 0) ],
"_verdict_n_1_rel" : [ SenseInfo('01192150-n', 1) ],
"_stirring_n_1_rel" : [ SenseInfo('00347490-n', 1), SenseInfo('01261845-n', 0) ],
"_embed_v_1_rel" : [ SenseInfo('01528821-v', 2), SenseInfo('01089423-v', 0), SenseInfo('01528821-v', 2), SenseInfo('01089423-v', 0) ],
"_malignancy_n_1_rel" : [ SenseInfo('14237561-n', 1), SenseInfo('04842788-n', 0) ],
"_amperage_n_of_rel" : [ SenseInfo('11424704-n', 0) ],
"_drupe_n_1_rel" : [ SenseInfo('13138308-n', 0) ],
"_roughly_x_deg_rel" : [ SenseInfo('00007015-r', 9), SenseInfo('00354033-r', 1), SenseInfo('00353916-r', 1), SenseInfo('00007015-r', 9), SenseInfo('00354033-r', 1), SenseInfo('00353916-r', 1) ],
"_ramp_v_down_rel" : [ SenseInfo('02723016-v', 0), SenseInfo('02334595-v', 0), SenseInfo('02143124-v', 0), SenseInfo('01922754-v', 0), SenseInfo('01546513-v', 0), SenseInfo('02723016-v', 0), SenseInfo('02334595-v', 0), SenseInfo('02143124-v', 0), SenseInfo('01922754-v', 0), SenseInfo('01546513-v', 0) ],
"_edible_a_1_rel" : [ SenseInfo('00828779-a', 0) ],
"_jaunt_n_1_rel" : [ SenseInfo('00311809-n', 0) ],
"_argue_v_for_rel" : [ SenseInfo('00772189-v', 34), SenseInfo('00773432-v', 17), SenseInfo('00772640-v', 0) ],
"_compliment_n_1_rel" : [ SenseInfo('06695227-n', 4) ],
"_rot_n_1_rel" : [ SenseInfo('14560926-n', 1), SenseInfo('13458019-n', 1), SenseInfo('06611681-n', 0) ],
"_shovel_v_out_rel" : [ SenseInfo('01312810-v', 1) ],
"_no+less+than_a_1_rel" : [  ],
"_olivefaced_a_1_rel" : [  ],
"_would_v_modal_rel" : [ SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0) ],
"_start_v_up_rel" : [ SenseInfo('00345761-v', 159), SenseInfo('00348746-v', 45), SenseInfo('02014165-v', 29), SenseInfo('02608347-v', 17), SenseInfo('01628449-v', 16), SenseInfo('01650610-v', 11), SenseInfo('01910373-v', 7), SenseInfo('01857717-v', 7), SenseInfo('01864230-v', 5), SenseInfo('02379528-v', 2), SenseInfo('01075164-v', 1), SenseInfo('02608823-v', 0), SenseInfo('02600948-v', 0), SenseInfo('02081946-v', 0), SenseInfo('00345761-v', 159), SenseInfo('00348746-v', 45), SenseInfo('02014165-v', 29), SenseInfo('02608347-v', 17), SenseInfo('01628449-v', 16), SenseInfo('01650610-v', 11), SenseInfo('01910373-v', 7), SenseInfo('01857717-v', 7), SenseInfo('01864230-v', 5), SenseInfo('02379528-v', 2), SenseInfo('01075164-v', 1), SenseInfo('02608823-v', 0), SenseInfo('02600948-v', 0), SenseInfo('02081946-v', 0) ],
"_dress_n_1_rel" : [ SenseInfo('03236735-n', 15), SenseInfo('02756098-n', 4), SenseInfo('02728440-n', 0) ],
"_bingo_n_1_rel" : [ SenseInfo('00504660-n', 0) ],
"_viable_a_1_rel" : [ SenseInfo('01822563-a', 1), SenseInfo('00094941-a', 0) ],
"_forward_p_rel" : [ SenseInfo('00074641-r', 53), SenseInfo('00203237-a', 8), SenseInfo('00103859-r', 5), SenseInfo('00075442-r', 3), SenseInfo('00067265-r', 3), SenseInfo('01955508-v', 3), SenseInfo('00204491-a', 0), SenseInfo('00203774-a', 0), SenseInfo('10105733-n', 0), SenseInfo('00725383-n', 0), SenseInfo('00275694-r', 0), SenseInfo('01876555-a', 0) ],
"_debug_v_1_rel" : [ SenseInfo('00200242-v', 0) ],
"_metamorphic_a_1_rel" : [ SenseInfo('02951869-a', 0), SenseInfo('01529643-a', 0) ],
"_baron_n_1_rel" : [ SenseInfo('09840520-n', 0), SenseInfo('09840435-n', 0), SenseInfo('09840217-n', 0) ],
"_fairytale_n_1_rel" : [ SenseInfo('07222581-n', 3), SenseInfo('06757289-n', 0), SenseInfo('07222581-n', 3), SenseInfo('06757289-n', 0) ],
"_facing_n_1_rel" : [ SenseInfo('03315805-n', 2), SenseInfo('03315990-n', 0), SenseInfo('03315644-n', 0), SenseInfo('00827379-n', 0) ],
"_slurp_v_up_rel" : [ SenseInfo('01169328-v', 1) ],
"_political_n_1_rel" : [ SenseInfo('01814385-a', 45), SenseInfo('02857407-a', 11), SenseInfo('02857587-a', 6) ],
"_classical_a_1_rel" : [ SenseInfo('00413622-a', 8), SenseInfo('02295098-a', 2), SenseInfo('02698145-a', 0), SenseInfo('02298152-a', 0), SenseInfo('00413861-a', 0), SenseInfo('00413622-a', 8), SenseInfo('02295098-a', 2), SenseInfo('02698145-a', 0), SenseInfo('02298152-a', 0), SenseInfo('00413861-a', 0) ],
"_childhood_n_1_rel" : [ SenseInfo('15147097-n', 9), SenseInfo('14427065-n', 2) ],
"_cosmos_n_1_rel" : [ SenseInfo('09466280-n', 1), SenseInfo('11958080-n', 0) ],
"_sedan_n_1_rel" : [ SenseInfo('04166281-n', 2), SenseInfo('04166436-n', 0) ],
"_lessor_n_1_rel" : [ SenseInfo('10255096-n', 0) ],
"_compensate_v_1_rel" : [ SenseInfo('02672540-v', 5), SenseInfo('02250625-v', 1), SenseInfo('02672859-v', 0), SenseInfo('02519991-v', 0), SenseInfo('02253456-v', 0), SenseInfo('02249741-v', 0) ],
"_blackjack_n_1_rel" : [ SenseInfo('12274863-n', 0), SenseInfo('02847461-n', 0), SenseInfo('02847009-n', 0), SenseInfo('00490350-n', 0) ],
"_perceive_v_as_rel" : [ SenseInfo('02106506-v', 26), SenseInfo('00591519-v', 9), SenseInfo('02106506-v', 26), SenseInfo('00591519-v', 9) ],
"_incredulity_n_1_rel" : [ SenseInfo('05698982-n', 0) ],
"_letter_v_1_rel" : [ SenseInfo('02290349-v', 1), SenseInfo('01692579-v', 0), SenseInfo('01692443-v', 0) ],
"_scary_a_for_rel" : [ SenseInfo('00194924-a', 0), SenseInfo('00194924-a', 0), SenseInfo('00194924-a', 0) ],
"_trip_v_up_rel" : [ SenseInfo('01900408-v', 2), SenseInfo('01900760-v', 0), SenseInfo('01843055-v', 0), SenseInfo('01643657-v', 0), SenseInfo('01200934-v', 0), SenseInfo('01900408-v', 2), SenseInfo('01900760-v', 0), SenseInfo('01843055-v', 0), SenseInfo('01643657-v', 0), SenseInfo('01200934-v', 0) ],
"_cuss+word_n_1_rel" : [  ],
"_linguistics_n_1_rel" : [ SenseInfo('06172789-n', 2), SenseInfo('06171040-n', 0) ],
"_anglo-_a_1_rel" : [  ],
"_strenuous_a_1_rel" : [ SenseInfo('00875235-a', 1), SenseInfo('00837977-a', 0), SenseInfo('00875235-a', 1), SenseInfo('00837977-a', 0) ],
"_cover-up_n_1_rel" : [ SenseInfo('01050187-n', 0), SenseInfo('01050187-n', 0) ],
"_floodgate_n_1_rel" : [ SenseInfo('06247867-n', 0), SenseInfo('04244615-n', 0) ],
"_sperm_n_1_rel" : [ SenseInfo('05457469-n', 0) ],
"_ogress_n_1_rel" : [ SenseInfo('09490961-n', 1) ],
"_sucker_n_for_rel" : [ SenseInfo('09921409-n', 1), SenseInfo('13164881-n', 0), SenseInfo('10672066-n', 0), SenseInfo('07779895-n', 0), SenseInfo('07607605-n', 0), SenseInfo('02465414-n', 0), SenseInfo('01444922-n', 0) ],
"_decal_n_1_rel" : [ SenseInfo('03167464-n', 0) ],
"_yet_p_sel_rel" : [ SenseInfo('00027795-r', 22), SenseInfo('00027918-r', 15), SenseInfo('00017639-r', 6), SenseInfo('00047641-r', 0), SenseInfo('00028198-r', 0), SenseInfo('00027384-r', 0) ],
"_imms_n_1_rel" : [  ],
"_merchant_n_of_rel" : [ SenseInfo('10309896-n', 8) ],
"_feed_v_dir_rel" : [ SenseInfo('01182021-v', 47), SenseInfo('01178565-v', 15), SenseInfo('01181166-v', 5), SenseInfo('00189511-v', 4), SenseInfo('02555787-v', 3), SenseInfo('01179865-v', 3), SenseInfo('01180206-v', 1), SenseInfo('02066939-v', 0), SenseInfo('01203715-v', 0), SenseInfo('01182152-v', 0), SenseInfo('00502757-v', 0) ],
"_reserve_n_1_rel" : [ SenseInfo('04900121-n', 2), SenseInfo('13368052-n', 1), SenseInfo('10671042-n', 1), SenseInfo('13759773-n', 0), SenseInfo('08587174-n', 0), SenseInfo('08206460-n', 0), SenseInfo('04652438-n', 0), SenseInfo('04900121-n', 2), SenseInfo('13368052-n', 1), SenseInfo('10671042-n', 1), SenseInfo('13759773-n', 0), SenseInfo('08587174-n', 0), SenseInfo('08206460-n', 0), SenseInfo('04652438-n', 0) ],
"_stride_n_1_rel" : [ SenseInfo('00285889-n', 6), SenseInfo('13757249-n', 2), SenseInfo('00249987-n', 1) ],
"_bulwark_n_1_rel" : [ SenseInfo('04051825-n', 0), SenseInfo('02918330-n', 0), SenseInfo('02894605-n', 0) ],
"_pliable_a_1_rel" : [ SenseInfo('02362030-a', 0), SenseInfo('02144436-a', 0), SenseInfo('01028163-a', 0), SenseInfo('01022367-a', 0) ],
"_decimal_n_1_rel" : [ SenseInfo('13736197-n', 0), SenseInfo('13585309-n', 0) ],
"_voyage_n_of_rel" : [ SenseInfo('00312784-n', 11), SenseInfo('00312553-n', 2) ],
"_grouse_n_1_rel" : [ SenseInfo('07647115-n', 0), SenseInfo('01795088-n', 0) ],
"_speed_v_up_rel" : [ SenseInfo('02058994-v', 7), SenseInfo('00438178-v', 5), SenseInfo('02055649-v', 3), SenseInfo('02055975-v', 2), SenseInfo('00439343-v', 1), SenseInfo('02058994-v', 7), SenseInfo('00438178-v', 5), SenseInfo('02055649-v', 3), SenseInfo('02055975-v', 2), SenseInfo('00439343-v', 1) ],
"_narcotics_n_1_rel" : [ SenseInfo('03808564-n', 0) ],
"_hari+kiri_n_1_rel" : [  ],
"_foresight_n_1_rel" : [ SenseInfo('04893172-n', 1), SenseInfo('05805277-n', 0) ],
"_failure_n_1_rel" : [ SenseInfo('00066636-n', 18), SenseInfo('07317764-n', 10), SenseInfo('14477877-n', 3), SenseInfo('10273064-n', 3), SenseInfo('00066397-n', 1), SenseInfo('14478433-n', 0), SenseInfo('14059663-n', 0), SenseInfo('00066636-n', 18), SenseInfo('07317764-n', 10), SenseInfo('14477877-n', 3), SenseInfo('10273064-n', 3), SenseInfo('00066397-n', 1), SenseInfo('14478433-n', 0), SenseInfo('14059663-n', 0) ],
"_season_n_1_rel" : [ SenseInfo('15239579-n', 40), SenseInfo('15236475-n', 14), SenseInfo('15239292-n', 0) ],
"_overwork_v_1_rel" : [ SenseInfo('01669174-v', 1), SenseInfo('02409148-v', 0), SenseInfo('01669174-v', 1), SenseInfo('02409148-v', 0) ],
"_virtual_a_1_rel" : [ SenseInfo('01941814-a', 1), SenseInfo('00902157-a', 0), SenseInfo('01941814-a', 1), SenseInfo('00902157-a', 0), SenseInfo('01941814-a', 1), SenseInfo('00902157-a', 0) ],
"_sweep_v_1_rel" : [ SenseInfo('01870043-v', 13), SenseInfo('01869563-v', 12), SenseInfo('01393714-v', 5), SenseInfo('02677797-v', 3), SenseInfo('02685390-v', 2), SenseInfo('01393996-v', 1), SenseInfo('01100952-v', 1), SenseInfo('02688403-v', 0), SenseInfo('01593763-v', 0), SenseInfo('01870043-v', 13), SenseInfo('01869563-v', 12), SenseInfo('01393714-v', 5), SenseInfo('02677797-v', 3), SenseInfo('02685390-v', 2), SenseInfo('01393996-v', 1), SenseInfo('01100952-v', 1), SenseInfo('02688403-v', 0), SenseInfo('01593763-v', 0), SenseInfo('01870043-v', 13), SenseInfo('01869563-v', 12), SenseInfo('01393714-v', 5), SenseInfo('02677797-v', 3), SenseInfo('02685390-v', 2), SenseInfo('01393996-v', 1), SenseInfo('01100952-v', 1), SenseInfo('02688403-v', 0), SenseInfo('01593763-v', 0) ],
"_reporter_n_of_rel" : [ SenseInfo('10521662-n', 10) ],
"_word_v_1_rel" : [ SenseInfo('00980453-v', 2) ],
"_whither_p_rel" : [  ],
"_organizational_a_1_rel" : [ SenseInfo('02898276-a', 3), SenseInfo('02898276-a', 3), SenseInfo('02898276-a', 3), SenseInfo('02898276-a', 3) ],
"_short-change_v_1_rel" : [ SenseInfo('02572667-v', 1), SenseInfo('02572119-v', 0), SenseInfo('02572667-v', 1), SenseInfo('02572119-v', 0) ],
"_ancient_a_1_rel" : [ SenseInfo('01728614-a', 5), SenseInfo('01644847-a', 5), SenseInfo('01728614-a', 5), SenseInfo('01644847-a', 5) ],
"_member_n_of_rel" : [ SenseInfo('10307234-n', 67), SenseInfo('13810615-n', 6), SenseInfo('05559908-n', 5), SenseInfo('08170686-n', 0), SenseInfo('05526384-n', 0), SenseInfo('10307234-n', 67), SenseInfo('13810615-n', 6), SenseInfo('05559908-n', 5), SenseInfo('08170686-n', 0), SenseInfo('05526384-n', 0) ],
"_flick_n_1_rel" : [ SenseInfo('07338358-n', 2), SenseInfo('06799688-n', 0), SenseInfo('06613686-n', 0) ],
"_recording_n_1_rel" : [ SenseInfo('04063661-n', 14), SenseInfo('00910203-n', 5), SenseInfo('04063868-n', 0) ],
"_biotech_n_1_rel" : [ SenseInfo('06126761-n', 0) ],
"_fireweed_n_1_rel" : [ SenseInfo('12342498-n', 0), SenseInfo('11965218-n', 0) ],
"_enthalpy_n_1_rel" : [ SenseInfo('05012272-n', 2) ],
"_bug_n_sea_rel" : [ SenseInfo('02236355-n', 1), SenseInfo('14464675-n', 0), SenseInfo('02912440-n', 0), SenseInfo('02236896-n', 0), SenseInfo('01384491-n', 0), SenseInfo('02236355-n', 1), SenseInfo('14464675-n', 0), SenseInfo('02912440-n', 0), SenseInfo('02236896-n', 0), SenseInfo('01384491-n', 0) ],
"_famed_a_1_rel" : [ SenseInfo('01375831-a', 3) ],
"_armament_n_1_rel" : [ SenseInfo('02738031-n', 1), SenseInfo('01156899-n', 0) ],
"_subject_v_to_rel" : [ SenseInfo('02110927-v', 10), SenseInfo('01118292-v', 6), SenseInfo('02496816-v', 1), SenseInfo('00878636-v', 0) ],
"_hydrous_a_1_rel" : [ SenseInfo('02555387-a', 1) ],
"_abstain_v_from_rel" : [ SenseInfo('02463426-v', 1), SenseInfo('01196037-v', 1), SenseInfo('02463426-v', 1), SenseInfo('01196037-v', 1) ],
"_polo_n_1_rel" : [ SenseInfo('11241300-n', 0), SenseInfo('00477639-n', 0) ],
"_delivery_n_of_rel" : [ SenseInfo('00317207-n', 3), SenseInfo('07320622-n', 0), SenseInfo('07071483-n', 0), SenseInfo('01108753-n', 0), SenseInfo('00106272-n', 0), SenseInfo('00093483-n', 0), SenseInfo('00042541-n', 0) ],
"_treasure_n_1_rel" : [ SenseInfo('13370669-n', 2), SenseInfo('03432972-n', 2), SenseInfo('13370448-n', 1), SenseInfo('08463969-n', 1) ],
"_must-have_n_1_rel" : [  ],
"_specialize_v_at_rel" : [ SenseInfo('00437449-v', 3), SenseInfo('01021973-v', 2), SenseInfo('00437732-v', 2), SenseInfo('02446164-v', 0), SenseInfo('00119266-v', 0), SenseInfo('00437449-v', 3), SenseInfo('01021973-v', 2), SenseInfo('00437732-v', 2), SenseInfo('02446164-v', 0), SenseInfo('00119266-v', 0) ],
"_auditor_n_1_rel" : [ SenseInfo('10165448-n', 0), SenseInfo('09823153-n', 0), SenseInfo('09822955-n', 0) ],
"_all+over_a_1_rel" : [ SenseInfo('00521976-a', 0) ],
"_floor_v_1_rel" : [ SenseInfo('01809064-v', 0), SenseInfo('01412346-v', 0) ],
"_development_n_of_rel" : [ SenseInfo('00250259-n', 52), SenseInfo('13464820-n', 46), SenseInfo('13489037-n', 11), SenseInfo('07423560-n', 9), SenseInfo('00948206-n', 7), SenseInfo('08549070-n', 6), SenseInfo('14422871-n', 4), SenseInfo('13464557-n', 0), SenseInfo('07068631-n', 0), SenseInfo('00250259-n', 52), SenseInfo('13464820-n', 46), SenseInfo('13489037-n', 11), SenseInfo('07423560-n', 9), SenseInfo('00948206-n', 7), SenseInfo('08549070-n', 6), SenseInfo('14422871-n', 4), SenseInfo('13464557-n', 0), SenseInfo('07068631-n', 0) ],
"_temper_v_1_rel" : [ SenseInfo('00303056-v', 0), SenseInfo('00302875-v', 0), SenseInfo('00295254-v', 0), SenseInfo('00294884-v', 0), SenseInfo('00202934-v', 0) ],
"_levitation_n_of_rel" : [ SenseInfo('11408733-n', 0), SenseInfo('07363067-n', 0), SenseInfo('00324699-n', 0) ],
"_queer_n_1_rel" : [ SenseInfo('10076033-n', 0) ],
"_interdependent_a_1_rel" : [ SenseInfo('00726445-a', 3) ],
"_chatter_v_1_rel" : [ SenseInfo('02185861-v', 1), SenseInfo('01553869-v', 1), SenseInfo('01038666-v', 1), SenseInfo('01036804-v', 1), SenseInfo('01037303-v', 0) ],
"_double-take_n_1_rel" : [ SenseInfo('00863417-n', 0), SenseInfo('00863417-n', 0) ],
"_draft_v_1_rel" : [ SenseInfo('01701634-v', 4), SenseInfo('01097500-v', 2), SenseInfo('01683582-v', 0) ],
"_decline_v_1_rel" : [ SenseInfo('00203866-v', 5), SenseInfo('02237338-v', 4), SenseInfo('00797430-v', 4), SenseInfo('00431826-v', 2), SenseInfo('02039876-v', 0), SenseInfo('01971603-v', 0), SenseInfo('00982913-v', 0), SenseInfo('00203866-v', 5), SenseInfo('02237338-v', 4), SenseInfo('00797430-v', 4), SenseInfo('00431826-v', 2), SenseInfo('02039876-v', 0), SenseInfo('01971603-v', 0), SenseInfo('00982913-v', 0), SenseInfo('00203866-v', 5), SenseInfo('02237338-v', 4), SenseInfo('00797430-v', 4), SenseInfo('00431826-v', 2), SenseInfo('02039876-v', 0), SenseInfo('01971603-v', 0), SenseInfo('00982913-v', 0) ],
"_one+after+another_a_1_rel" : [  ],
"_rust_v_away_rel" : [ SenseInfo('00273963-v', 2), SenseInfo('00274283-v', 0), SenseInfo('00239614-v', 0) ],
"_quorum_n_1_rel" : [ SenseInfo('08357992-n', 0) ],
"_inexpensive_a_1_rel" : [ SenseInfo('00934199-a', 4), SenseInfo('00934199-a', 4) ],
"_ferment_n_1_rel" : [ SenseInfo('13979503-n', 1), SenseInfo('14738752-n', 0), SenseInfo('13575433-n', 0) ],
"_situated_a_1_rel" : [ SenseInfo('02126430-a', 2) ],
"_annulment_n_1_rel" : [ SenseInfo('14564056-n', 0), SenseInfo('01240979-n', 0), SenseInfo('00231887-n', 0) ],
"_drawing_n_of_rel" : [ SenseInfo('07003119-n', 7), SenseInfo('03234306-n', 5), SenseInfo('00935940-n', 2), SenseInfo('00508091-n', 0), SenseInfo('00392093-n', 0), SenseInfo('00115667-n', 0) ],
"_chuck_v_1_rel" : [ SenseInfo('01514525-v', 2), SenseInfo('02227362-v', 0), SenseInfo('01243661-v', 0), SenseInfo('00076400-v', 0) ],
"_drove_n_of_rel" : [ SenseInfo('08184335-n', 0), SenseInfo('08184217-n', 0), SenseInfo('03247495-n', 0) ],
"_assassinate_v_1_rel" : [ SenseInfo('02483000-v', 0), SenseInfo('00847158-v', 0) ],
"_bloodstopper_n_1_rel" : [  ],
"_bum_v_1_rel" : [ SenseInfo('02270404-v', 1), SenseInfo('02639606-v', 0) ],
"_flesh_n_1_rel" : [ SenseInfo('05268112-n', 12), SenseInfo('05217168-n', 8), SenseInfo('13096035-n', 0) ],
"_right-click_v_cause_rel" : [  ],
"_preload_v_1_rel" : [  ],
"_bastard_n_1_rel" : [ SenseInfo('09815188-n', 22), SenseInfo('09842823-n', 0), SenseInfo('02804772-n', 0) ],
"_organic_a_1_rel" : [ SenseInfo('01679055-a', 21), SenseInfo('01679459-a', 0), SenseInfo('01093142-a', 0), SenseInfo('02558767-a', 0), SenseInfo('01166875-a', 0), SenseInfo('00901345-a', 0), SenseInfo('01679055-a', 21), SenseInfo('01679459-a', 0), SenseInfo('01093142-a', 0), SenseInfo('02558767-a', 0), SenseInfo('01166875-a', 0), SenseInfo('00901345-a', 0) ],
"_unprocessed_a_1_rel" : [ SenseInfo('01953467-a', 0), SenseInfo('01952405-a', 0), SenseInfo('01071321-a', 0), SenseInfo('01953467-a', 0), SenseInfo('01952405-a', 0), SenseInfo('01071321-a', 0) ],
"_deathly_a_1_rel" : [ SenseInfo('00097022-a', 1), SenseInfo('00993667-a', 0) ],
"_inactive_a_1_rel" : [ SenseInfo('01929802-a', 3), SenseInfo('00037757-a', 1), SenseInfo('01660857-a', 0), SenseInfo('00043125-a', 0), SenseInfo('00040685-a', 0), SenseInfo('00039592-a', 0), SenseInfo('00036481-a', 0), SenseInfo('00035074-a', 0), SenseInfo('00033574-a', 0), SenseInfo('01564315-a', 0) ],
"_kick_v_off_rel" : [ SenseInfo('01371756-v', 11), SenseInfo('01936233-v', 9), SenseInfo('01370561-v', 7), SenseInfo('02048511-v', 0), SenseInfo('01371454-v', 0), SenseInfo('01196524-v', 0), SenseInfo('01112979-v', 0), SenseInfo('00907147-v', 0), SenseInfo('01371756-v', 11), SenseInfo('01936233-v', 9), SenseInfo('01370561-v', 7), SenseInfo('02048511-v', 0), SenseInfo('01371454-v', 0), SenseInfo('01196524-v', 0), SenseInfo('01112979-v', 0), SenseInfo('00907147-v', 0) ],
"_showcase_n_1_rel" : [ SenseInfo('14516082-n', 2), SenseInfo('02975212-n', 0) ],
"_woolen_n_1_rel" : [ SenseInfo('04599235-n', 1) ],
"_inefficiency_n_1_rel" : [ SenseInfo('05648953-n', 0) ],
"_whiffletree_n_1_rel" : [ SenseInfo('04577567-n', 0) ],
"_fill_v_in_rel" : [ SenseInfo('00452512-v', 61), SenseInfo('00451838-v', 12), SenseInfo('02649042-v', 8), SenseInfo('02394183-v', 5), SenseInfo('01183573-v', 5), SenseInfo('02394081-v', 1), SenseInfo('01203893-v', 1), SenseInfo('01193721-v', 1), SenseInfo('00261533-v', 1), SenseInfo('00452512-v', 61), SenseInfo('00451838-v', 12), SenseInfo('02649042-v', 8), SenseInfo('02394183-v', 5), SenseInfo('01183573-v', 5), SenseInfo('02394081-v', 1), SenseInfo('01203893-v', 1), SenseInfo('01193721-v', 1), SenseInfo('00261533-v', 1) ],
"_trend_n_1_rel" : [ SenseInfo('08681777-n', 18), SenseInfo('08681222-n', 1), SenseInfo('06197664-n', 1), SenseInfo('05750163-n', 0) ],
"_self-termination_n_1_rel" : [  ],
"_shake-up_n_1_rel" : [ SenseInfo('01137987-n', 0), SenseInfo('01137987-n', 0) ],
"_verbal_a_1_rel" : [ SenseInfo('00500310-a', 5), SenseInfo('02823920-a', 3), SenseInfo('02823724-a', 0), SenseInfo('02230581-a', 0), SenseInfo('02284324-a', 0), SenseInfo('00549675-a', 0) ],
"_need_v_qmodal_rel" : [ SenseInfo('02627934-v', 110), SenseInfo('01188725-v', 98), SenseInfo('01189113-v', 1), SenseInfo('02627934-v', 110), SenseInfo('01188725-v', 98), SenseInfo('01189113-v', 1), SenseInfo('02627934-v', 110), SenseInfo('01188725-v', 98), SenseInfo('01189113-v', 1), SenseInfo('02627934-v', 110), SenseInfo('01188725-v', 98), SenseInfo('01189113-v', 1), SenseInfo('02627934-v', 110), SenseInfo('01188725-v', 98), SenseInfo('01189113-v', 1), SenseInfo('02627934-v', 110), SenseInfo('01188725-v', 98), SenseInfo('01189113-v', 1), SenseInfo('02627934-v', 110), SenseInfo('01188725-v', 98), SenseInfo('01189113-v', 1), SenseInfo('02627934-v', 110), SenseInfo('01188725-v', 98), SenseInfo('01189113-v', 1), SenseInfo('02627934-v', 110), SenseInfo('01188725-v', 98), SenseInfo('01189113-v', 1) ],
"_dissolution_n_of_rel" : [ SenseInfo('13467916-n', 1), SenseInfo('13468094-n', 0), SenseInfo('00748307-n', 0), SenseInfo('00216038-n', 0), SenseInfo('00215314-n', 0) ],
"_microbiology_n_1_rel" : [ SenseInfo('06077648-n', 0) ],
"_immigration_n_1_rel" : [ SenseInfo('00056311-n', 1), SenseInfo('08413834-n', 0) ],
"_discomforting_a_1_rel" : [  ],
"_shallow_a_1_rel" : [ SenseInfo('00691696-a', 6), SenseInfo('00693356-a', 0), SenseInfo('01875227-a', 0), SenseInfo('00691696-a', 6), SenseInfo('00693356-a', 0), SenseInfo('01875227-a', 0), SenseInfo('00691696-a', 6), SenseInfo('00693356-a', 0), SenseInfo('01875227-a', 0) ],
"_dig_v_1_rel" : [ SenseInfo('01309701-v', 9), SenseInfo('01311103-v', 5), SenseInfo('02419773-v', 0), SenseInfo('02143756-v', 0), SenseInfo('01899557-v', 0), SenseInfo('01310660-v', 0), SenseInfo('01229976-v', 0), SenseInfo('00588221-v', 0), SenseInfo('01309701-v', 9), SenseInfo('01311103-v', 5), SenseInfo('02419773-v', 0), SenseInfo('02143756-v', 0), SenseInfo('01899557-v', 0), SenseInfo('01310660-v', 0), SenseInfo('01229976-v', 0), SenseInfo('00588221-v', 0), SenseInfo('01309701-v', 9), SenseInfo('01311103-v', 5), SenseInfo('02419773-v', 0), SenseInfo('02143756-v', 0), SenseInfo('01899557-v', 0), SenseInfo('01310660-v', 0), SenseInfo('01229976-v', 0), SenseInfo('00588221-v', 0) ],
"_header_n_1_rel" : [ SenseInfo('06343971-n', 0), SenseInfo('03503233-n', 0), SenseInfo('03503097-n', 0), SenseInfo('03502897-n', 0), SenseInfo('03502777-n', 0), SenseInfo('00131485-n', 0), SenseInfo('00119893-n', 0) ],
"_hardware_n_1_rel" : [ SenseInfo('03493664-n', 3), SenseInfo('03493792-n', 0), SenseInfo('03493333-n', 0) ],
"_cull_n_1_rel" : [ SenseInfo('05790572-n', 0) ],
"_tack_n_1_rel" : [ SenseInfo('08681084-n', 0), SenseInfo('04383130-n', 0), SenseInfo('04295081-n', 0), SenseInfo('04188368-n', 0), SenseInfo('00351334-n', 0), SenseInfo('00314395-n', 0) ],
"_assimilation_n_of_rel" : [ SenseInfo('13930928-n', 0), SenseInfo('13434878-n', 0), SenseInfo('13434688-n', 0), SenseInfo('13434537-n', 0), SenseInfo('05757049-n', 0), SenseInfo('05755714-n', 0) ],
"_sell-out_n_1_rel" : [ SenseInfo('00750216-n', 0), SenseInfo('00750216-n', 0) ],
"_receive_v_1_rel" : [ SenseInfo('02210119-v', 122), SenseInfo('00522751-v', 27), SenseInfo('02107248-v', 25), SenseInfo('02108026-v', 22), SenseInfo('01470225-v', 16), SenseInfo('00686879-v', 8), SenseInfo('00900583-v', 2), SenseInfo('00117346-v', 2), SenseInfo('02739480-v', 1), SenseInfo('02493511-v', 0), SenseInfo('02108654-v', 0), SenseInfo('01172838-v', 0), SenseInfo('00617095-v', 0) ],
"_sulfur_n_1_rel" : [ SenseInfo('14656219-n', 1) ],
"_suitor_n_1_rel" : [ SenseInfo('10674130-n', 1) ],
"_inward_a_2_rel" : [ SenseInfo('00951247-a', 5), SenseInfo('01294583-a', 0), SenseInfo('00951247-a', 5), SenseInfo('01294583-a', 0) ],
"_dependent_a_on_rel" : [ SenseInfo('00725772-a', 8), SenseInfo('00556174-a', 2), SenseInfo('00730470-a', 0), SenseInfo('02351370-a', 0), SenseInfo('02329864-a', 0), SenseInfo('00047406-a', 0), SenseInfo('00725772-a', 8), SenseInfo('00556174-a', 2), SenseInfo('00730470-a', 0), SenseInfo('02351370-a', 0), SenseInfo('02329864-a', 0), SenseInfo('00047406-a', 0) ],
"_continence_n_1_rel" : [ SenseInfo('04882813-n', 1), SenseInfo('04884177-n', 0) ],
"_incumbent_a_on_rel" : [ SenseInfo('02349003-a', 0), SenseInfo('01580601-a', 0), SenseInfo('00667208-a', 0) ],
"_lush_n_1_rel" : [ SenseInfo('09782167-n', 0) ],
"_headlamp_n_1_rel" : [ SenseInfo('03503997-n', 0) ],
"_anti_x_deg_rel" : [ SenseInfo('01817405-a', 7), SenseInfo('09796809-n', 0) ],
"_tip-off_n_1_rel" : [ SenseInfo('05827129-n', 0), SenseInfo('00481666-n', 0), SenseInfo('05827129-n', 0), SenseInfo('00481666-n', 0) ],
"_clarinetist_n_1_rel" : [ SenseInfo('09926246-n', 0) ],
"_check+in_n_1_rel" : [ SenseInfo('00141669-n', 0) ],
"_behind_p_rel" : [ SenseInfo('00221985-r', 13), SenseInfo('00222180-r', 3), SenseInfo('05559256-n', 1), SenseInfo('02492383-a', 1), SenseInfo('00222879-r', 0), SenseInfo('00222713-r', 0), SenseInfo('00222479-r', 0), SenseInfo('00221985-r', 13), SenseInfo('00222180-r', 3), SenseInfo('05559256-n', 1), SenseInfo('02492383-a', 1), SenseInfo('00222879-r', 0), SenseInfo('00222713-r', 0), SenseInfo('00222479-r', 0), SenseInfo('00221985-r', 13), SenseInfo('00222180-r', 3), SenseInfo('05559256-n', 1), SenseInfo('02492383-a', 1), SenseInfo('00222879-r', 0), SenseInfo('00222713-r', 0), SenseInfo('00222479-r', 0) ],
"_secure_v_1_rel" : [ SenseInfo('02238770-v', 20), SenseInfo('01340439-v', 4), SenseInfo('02349706-v', 2), SenseInfo('00890590-v', 1), SenseInfo('01422886-v', 0), SenseInfo('01306425-v', 0), SenseInfo('02238770-v', 20), SenseInfo('01340439-v', 4), SenseInfo('02349706-v', 2), SenseInfo('00890590-v', 1), SenseInfo('01422886-v', 0), SenseInfo('01306425-v', 0), SenseInfo('02238770-v', 20), SenseInfo('01340439-v', 4), SenseInfo('02349706-v', 2), SenseInfo('00890590-v', 1), SenseInfo('01422886-v', 0), SenseInfo('01306425-v', 0) ],
"_mm-hmm_a_1_rel" : [  ],
"_merge_n_1_rel" : [  ],
"_come_v_on_rel" : [ SenseInfo('01849221-v', 276), SenseInfo('02005948-v', 235), SenseInfo('00341917-v', 147), SenseInfo('00542120-v', 41), SenseInfo('02625339-v', 40), SenseInfo('00342812-v', 11), SenseInfo('02743921-v', 9), SenseInfo('02743214-v', 7), SenseInfo('02686805-v', 6), SenseInfo('02743565-v', 3), SenseInfo('01839690-v', 3), SenseInfo('02729963-v', 2), SenseInfo('00344886-v', 2), SenseInfo('02645007-v', 1), SenseInfo('02627363-v', 1), SenseInfo('02006709-v', 1), SenseInfo('00723349-v', 1), SenseInfo('02737187-v', 0), SenseInfo('02617567-v', 0), SenseInfo('02197360-v', 0), SenseInfo('00659984-v', 0) ],
"_agreement_n_1_rel" : [ SenseInfo('06770275-n', 9), SenseInfo('04713428-n', 8), SenseInfo('13971065-n', 6), SenseInfo('05795044-n', 2), SenseInfo('13797313-n', 0), SenseInfo('07175241-n', 0), SenseInfo('06770275-n', 9), SenseInfo('04713428-n', 8), SenseInfo('13971065-n', 6), SenseInfo('05795044-n', 2), SenseInfo('13797313-n', 0), SenseInfo('07175241-n', 0), SenseInfo('06770275-n', 9), SenseInfo('04713428-n', 8), SenseInfo('13971065-n', 6), SenseInfo('05795044-n', 2), SenseInfo('13797313-n', 0), SenseInfo('07175241-n', 0) ],
"_malignant_a_1_rel" : [ SenseInfo('02594714-a', 0), SenseInfo('02594714-a', 0) ],
"_b-_n_1_rel" : [ SenseInfo('01349948-n', 1), SenseInfo('15090742-n', 0), SenseInfo('14631871-n', 0), SenseInfo('13713521-n', 0), SenseInfo('13614256-n', 0), SenseInfo('06831284-n', 0), SenseInfo('05400978-n', 0) ],
"_whiten_v_1_rel" : [ SenseInfo('00280301-v', 1) ],
"_lush_a_1_rel" : [ SenseInfo('00015247-a', 1), SenseInfo('02025274-a', 0), SenseInfo('01369078-a', 0), SenseInfo('00015247-a', 1), SenseInfo('02025274-a', 0), SenseInfo('01369078-a', 0), SenseInfo('00015247-a', 1), SenseInfo('02025274-a', 0), SenseInfo('01369078-a', 0) ],
"_hydracid_n_1_rel" : [  ],
"_demonstrate_v_1_rel" : [ SenseInfo('02148788-v', 24), SenseInfo('00664788-v', 22), SenseInfo('00820976-v', 2), SenseInfo('02521816-v', 1) ],
"_maternity_n_1_rel" : [ SenseInfo('14046202-n', 0), SenseInfo('13814041-n', 0), SenseInfo('04872958-n', 0) ],
"_brute_n_1_rel" : [ SenseInfo('09845589-n', 2), SenseInfo('00015388-n', 0) ],
"_fineness_n_1_rel" : [ SenseInfo('04728604-n', 1), SenseInfo('05136978-n', 0), SenseInfo('04948069-n', 0), SenseInfo('04813066-n', 0) ],
"_overgrown_a_1_rel" : [ SenseInfo('01697235-a', 1), SenseInfo('02574092-a', 0) ],
"_numerous_a_1_rel" : [ SenseInfo('01552419-a', 18) ],
"_view_n_of_rel" : [ SenseInfo('06208751-n', 36), SenseInfo('05933246-n', 12), SenseInfo('00881649-n', 9), SenseInfo('08560952-n', 7), SenseInfo('05945642-n', 6), SenseInfo('06782019-n', 4), SenseInfo('05983463-n', 4), SenseInfo('04144782-n', 2), SenseInfo('05127782-n', 0), SenseInfo('04674861-n', 0), SenseInfo('06208751-n', 36), SenseInfo('05933246-n', 12), SenseInfo('00881649-n', 9), SenseInfo('08560952-n', 7), SenseInfo('05945642-n', 6), SenseInfo('06782019-n', 4), SenseInfo('05983463-n', 4), SenseInfo('04144782-n', 2), SenseInfo('05127782-n', 0), SenseInfo('04674861-n', 0), SenseInfo('06208751-n', 36), SenseInfo('05933246-n', 12), SenseInfo('00881649-n', 9), SenseInfo('08560952-n', 7), SenseInfo('05945642-n', 6), SenseInfo('06782019-n', 4), SenseInfo('05983463-n', 4), SenseInfo('04144782-n', 2), SenseInfo('05127782-n', 0), SenseInfo('04674861-n', 0) ],
"_giggle_v_1_rel" : [ SenseInfo('00030142-v', 4) ],
"_suffer_v_from_rel" : [ SenseInfo('02109190-v', 17), SenseInfo('00065639-v', 17), SenseInfo('01794668-v', 12), SenseInfo('00668099-v', 8), SenseInfo('00204750-v', 7), SenseInfo('00065070-v', 4), SenseInfo('02121511-v', 1), SenseInfo('00078401-v', 1), SenseInfo('02719807-v', 0), SenseInfo('02110082-v', 0), SenseInfo('00204872-v', 0) ],
"_stand_v_out_rel" : [ SenseInfo('01546111-v', 169), SenseInfo('02611373-v', 53), SenseInfo('02734488-v', 38), SenseInfo('02702120-v', 18), SenseInfo('00668099-v', 9), SenseInfo('00670991-v', 8), SenseInfo('02707125-v', 5), SenseInfo('02703018-v', 3), SenseInfo('02702368-v', 2), SenseInfo('01546768-v', 1), SenseInfo('01115916-v', 1), SenseInfo('01428203-v', 0) ],
"_undergrad_n_1_rel" : [ SenseInfo('10736602-n', 0) ],
"_ferry_v_in_rel" : [ SenseInfo('01949674-v', 1), SenseInfo('01949435-v', 0), SenseInfo('01949218-v', 0) ],
"_graffiti_n_1_rel" : [ SenseInfo('03451798-n', 0) ],
"_offline_a_2_rel" : [  ],
"_offend_v_1_rel" : [ SenseInfo('01789270-v', 2), SenseInfo('02566528-v', 0), SenseInfo('01810447-v', 0), SenseInfo('01793177-v', 0), SenseInfo('01789270-v', 2), SenseInfo('02566528-v', 0), SenseInfo('01810447-v', 0), SenseInfo('01793177-v', 0) ],
"_trespass_n_1_rel" : [ SenseInfo('00734482-n', 0), SenseInfo('00733483-n', 0) ],
"_drape_v_1_rel" : [ SenseInfo('01542525-v', 3), SenseInfo('01543000-v', 1), SenseInfo('01617034-v', 0), SenseInfo('01612487-v', 0) ],
"_uninitiated_n_1_rel" : [ SenseInfo('00937341-a', 1) ],
"_gleam_n_1_rel" : [ SenseInfo('04954534-n', 3), SenseInfo('07412478-n', 2) ],
"_acorn_n_1_rel" : [ SenseInfo('12267677-n', 0) ],
"_earn_v_1_rel" : [ SenseInfo('02289295-v', 19), SenseInfo('02290196-v', 15), SenseInfo('02289295-v', 19), SenseInfo('02290196-v', 15) ],
"_overly_x_deg_rel" : [ SenseInfo('00047392-r', 0) ],
"_fodder_n_1_rel" : [ SenseInfo('09891300-n', 0), SenseInfo('07800740-n', 0) ],
"_each_a_1_rel" : [ SenseInfo('02269635-a', 64) ],
"_wooden_a_1_rel" : [ SenseInfo('02576489-a', 16), SenseInfo('01141595-a', 0) ],
"_veterinary_n_1_rel" : [ SenseInfo('10749715-n', 0) ],
"_essential_a_1_rel" : [ SenseInfo('01580306-a', 17), SenseInfo('00900616-a', 15), SenseInfo('01276150-a', 8), SenseInfo('02722988-a', 0), SenseInfo('00055539-a', 0), SenseInfo('01580306-a', 17), SenseInfo('00900616-a', 15), SenseInfo('01276150-a', 8), SenseInfo('02722988-a', 0), SenseInfo('00055539-a', 0), SenseInfo('01580306-a', 17), SenseInfo('00900616-a', 15), SenseInfo('01276150-a', 8), SenseInfo('02722988-a', 0), SenseInfo('00055539-a', 0), SenseInfo('01580306-a', 17), SenseInfo('00900616-a', 15), SenseInfo('01276150-a', 8), SenseInfo('02722988-a', 0), SenseInfo('00055539-a', 0) ],
"_pump_v_out_rel" : [ SenseInfo('01225684-v', 4), SenseInfo('01155307-v', 3), SenseInfo('01853310-v', 1), SenseInfo('02356113-v', 0), SenseInfo('02068324-v', 0), SenseInfo('01853192-v', 0), SenseInfo('01853069-v', 0), SenseInfo('00788057-v', 0), SenseInfo('01225684-v', 4), SenseInfo('01155307-v', 3), SenseInfo('01853310-v', 1), SenseInfo('02356113-v', 0), SenseInfo('02068324-v', 0), SenseInfo('01853192-v', 0), SenseInfo('01853069-v', 0), SenseInfo('00788057-v', 0) ],
"_factor_n_1_rel" : [ SenseInfo('07327805-n', 31), SenseInfo('05868954-n', 8), SenseInfo('13733402-n', 4), SenseInfo('09777012-n', 1), SenseInfo('13593219-n', 0), SenseInfo('05858317-n', 0), SenseInfo('05436752-n', 0) ],
"_nickname_n_of_rel" : [ SenseInfo('06337693-n', 1), SenseInfo('06338003-n', 0), SenseInfo('06337693-n', 1), SenseInfo('06338003-n', 0) ],
"_madness_n_1_rel" : [ SenseInfo('14395240-n', 2), SenseInfo('14271667-n', 0), SenseInfo('07516997-n', 0), SenseInfo('05647156-n', 0), SenseInfo('04885784-n', 0), SenseInfo('14395240-n', 2), SenseInfo('14271667-n', 0), SenseInfo('07516997-n', 0), SenseInfo('05647156-n', 0), SenseInfo('04885784-n', 0), SenseInfo('14395240-n', 2), SenseInfo('14271667-n', 0), SenseInfo('07516997-n', 0), SenseInfo('05647156-n', 0), SenseInfo('04885784-n', 0) ],
"_switchboard_n_1_rel" : [ SenseInfo('04373264-n', 1) ],
"_heat_n_1_rel" : [ SenseInfo('11466043-n', 19), SenseInfo('05016171-n', 6), SenseInfo('05725527-n', 5), SenseInfo('04628192-n', 2), SenseInfo('14038264-n', 1), SenseInfo('07461288-n', 0), SenseInfo('03509025-n', 0) ],
"_israeli_n_1_rel" : [ SenseInfo('09715833-n', 1) ],
"_cardamon_n_1_rel" : [ SenseInfo('12358293-n', 0), SenseInfo('07822323-n', 0) ],
"_overlay_v_1_rel" : [ SenseInfo('01336635-v', 1), SenseInfo('01326890-v', 0), SenseInfo('01336635-v', 1), SenseInfo('01326890-v', 0) ],
"_begonia_n_1_rel" : [ SenseInfo('12360108-n', 0) ],
"_decide_v_on_rel" : [ SenseInfo('00697589-v', 123), SenseInfo('00698855-v', 6), SenseInfo('00699485-v', 4), SenseInfo('00701877-v', 0) ],
"_muffler_n_1_rel" : [ SenseInfo('04218564-n', 2), SenseInfo('03797182-n', 0), SenseInfo('03161450-n', 0) ],
"_discriminatory_a_1_rel" : [ SenseInfo('00285148-a', 0), SenseInfo('00997394-a', 0), SenseInfo('00775301-a', 0), SenseInfo('00065184-a', 0) ],
"_role_n_of_rel" : [ SenseInfo('00720565-n', 34), SenseInfo('05929008-n', 10), SenseInfo('05149325-n', 8), SenseInfo('00722061-n', 6), SenseInfo('00720565-n', 34), SenseInfo('05929008-n', 10), SenseInfo('05149325-n', 8), SenseInfo('00722061-n', 6) ],
"_aggressive_a_1_rel" : [ SenseInfo('00082241-a', 6), SenseInfo('01356143-a', 0), SenseInfo('01244846-a', 0), SenseInfo('00082241-a', 6), SenseInfo('01356143-a', 0), SenseInfo('01244846-a', 0) ],
"_danish_n_2_rel" : [ SenseInfo('06954048-n', 2), SenseInfo('07693590-n', 0) ],
"_heave_v_2_rel" : [ SenseInfo('00986586-v', 5), SenseInfo('01507792-v', 3), SenseInfo('02041206-v', 2), SenseInfo('01455866-v', 2), SenseInfo('02088470-v', 1), SenseInfo('00005526-v', 1), SenseInfo('00356954-v', 0), SenseInfo('00077458-v', 0) ],
"_slider_n_1_rel" : [ SenseInfo('10605088-n', 0), SenseInfo('10275940-n', 0), SenseInfo('01668665-n', 0), SenseInfo('00109081-n', 0) ],
"_hold_n_i_rel" : [ SenseInfo('00812526-n', 5), SenseInfo('05806623-n', 2), SenseInfo('05197232-n', 2), SenseInfo('15272029-n', 0), SenseInfo('13999663-n', 0), SenseInfo('03525372-n', 0), SenseInfo('03525252-n', 0), SenseInfo('03485997-n', 0), SenseInfo('02964634-n', 0) ],
"_groom_n_1_rel" : [ SenseInfo('10148035-n', 1), SenseInfo('10644301-n', 0), SenseInfo('10147935-n', 0) ],
"_microwave_v_1_rel" : [ SenseInfo('00321936-v', 0) ],
"_prepaid_a_1_rel" : [ SenseInfo('01709437-a', 0) ],
"_jaded_a_1_rel" : [ SenseInfo('02433975-a', 3), SenseInfo('02078153-a', 2) ],
"_navy_n_1_rel" : [ SenseInfo('08191701-n', 9), SenseInfo('04969703-n', 1), SenseInfo('08191987-n', 0) ],
"_lackluster_a_1_rel" : [ SenseInfo('00808011-a', 0), SenseInfo('00284194-a', 0) ],
"_scrape_v_up_rel" : [ SenseInfo('01308160-v', 4), SenseInfo('01750156-v', 1), SenseInfo('01309143-v', 1), SenseInfo('02040709-v', 0), SenseInfo('01384752-v', 0), SenseInfo('01309478-v', 0) ],
"_interested_a_in_rel" : [ SenseInfo('01342237-a', 25), SenseInfo('01515692-a', 1), SenseInfo('01342237-a', 25), SenseInfo('01515692-a', 1), SenseInfo('01342237-a', 25), SenseInfo('01515692-a', 1) ],
"_ceremony_n_1_rel" : [ SenseInfo('07450842-n', 9), SenseInfo('01026897-n', 4), SenseInfo('01027379-n', 2) ],
"_kick_v_1_rel" : [ SenseInfo('01371756-v', 11), SenseInfo('01936233-v', 9), SenseInfo('01370561-v', 7), SenseInfo('02048511-v', 0), SenseInfo('01371454-v', 0), SenseInfo('01196524-v', 0), SenseInfo('01112979-v', 0), SenseInfo('00907147-v', 0) ],
"_basilect_n_1_rel" : [  ],
"_lure_n_1_rel" : [ SenseInfo('04689660-n', 1), SenseInfo('05695232-n', 0), SenseInfo('02776205-n', 0) ],
"_brute_a_1_rel" : [ SenseInfo('01263445-a', 1) ],
"_omit_v_1_rel" : [ SenseInfo('00615774-v', 10), SenseInfo('00614999-v', 0), SenseInfo('00615774-v', 10), SenseInfo('00614999-v', 0) ],
"_drizzle_v_1_rel" : [ SenseInfo('02757475-v', 0), SenseInfo('01376082-v', 0) ],
"_loafer_n_1_rel" : [ SenseInfo('10197967-n', 0), SenseInfo('03680355-n', 0) ],
"_burger_n_1_rel" : [ SenseInfo('10872287-n', 0), SenseInfo('07697100-n', 0) ],
"_shellfish_n_1_rel" : [ SenseInfo('07783210-n', 0), SenseInfo('01940736-n', 0) ],
"_cutlery_n_1_rel" : [ SenseInfo('03154073-n', 0), SenseInfo('03153375-n', 0) ],
"_seek_v_for_rel" : [ SenseInfo('02240481-v', 44), SenseInfo('01315613-v', 41), SenseInfo('02530167-v', 32), SenseInfo('01839170-v', 0), SenseInfo('01069989-v', 0) ],
"_neo-_a_1_rel" : [ SenseInfo('01536276-a', 4) ],
"_march_n_1_rel" : [ SenseInfo('15210870-n', 16), SenseInfo('00290579-n', 14), SenseInfo('00282840-n', 3), SenseInfo('08428019-n', 2), SenseInfo('08513163-n', 0), SenseInfo('07058296-n', 0), SenseInfo('06700844-n', 0) ],
"_wolf_v_down_rel" : [ SenseInfo('01169205-v', 0) ],
"_sorcery_n_1_rel" : [ SenseInfo('05978812-n', 0) ],
"_face_v_1_rel" : [ SenseInfo('00812298-v', 56), SenseInfo('01078783-v', 33), SenseInfo('02693319-v', 14), SenseInfo('02693691-v', 4), SenseInfo('01908365-v', 4), SenseInfo('01066433-v', 3), SenseInfo('02137907-v', 0), SenseInfo('01271936-v', 0), SenseInfo('01271189-v', 0), SenseInfo('00812298-v', 56), SenseInfo('01078783-v', 33), SenseInfo('02693319-v', 14), SenseInfo('02693691-v', 4), SenseInfo('01908365-v', 4), SenseInfo('01066433-v', 3), SenseInfo('02137907-v', 0), SenseInfo('01271936-v', 0), SenseInfo('01271189-v', 0) ],
"_lung_n_1_rel" : [ SenseInfo('05387544-n', 30) ],
"_shoreline_n_1_rel" : [ SenseInfo('09433839-n', 0) ],
"_team_n_of_rel" : [ SenseInfo('08208560-n', 43), SenseInfo('07985384-n', 8), SenseInfo('08208560-n', 43), SenseInfo('07985384-n', 8) ],
"_devote_v_1_rel" : [ SenseInfo('00887463-v', 30), SenseInfo('00732224-v', 5), SenseInfo('02214717-v', 0) ],
"_rightmost_a_1_rel" : [ SenseInfo('02032617-a', 0), SenseInfo('02032617-a', 0), SenseInfo('02032617-a', 0), SenseInfo('02032617-a', 0) ],
"_grey_v_cause_rel" : [ SenseInfo('00289679-v', 0), SenseInfo('00289392-v', 0) ],
"_continuation_n_of_rel" : [ SenseInfo('01017987-n', 2), SenseInfo('06399503-n', 0), SenseInfo('06250208-n', 0), SenseInfo('05051896-n', 0) ],
"_pliers_n_pair_rel" : [ SenseInfo('03966976-n', 0), SenseInfo('03966976-n', 0) ],
"_stave_n_1_rel" : [ SenseInfo('06861860-n', 0), SenseInfo('04307269-n', 0), SenseInfo('04119892-n', 0) ],
"_herald_v_1_rel" : [ SenseInfo('00974173-v', 1), SenseInfo('00861725-v', 1), SenseInfo('00900376-v', 0) ],
"_figure_v_out_rel" : [ SenseInfo('00712135-v', 20), SenseInfo('02722207-v', 8), SenseInfo('01635432-v', 3), SenseInfo('00637259-v', 2), SenseInfo('00590241-v', 1), SenseInfo('00712135-v', 20), SenseInfo('02722207-v', 8), SenseInfo('01635432-v', 3), SenseInfo('00637259-v', 2), SenseInfo('00590241-v', 1) ],
"_embroiled_a_in_rel" : [ SenseInfo('01516014-a', 0) ],
"_extinct_a_1_rel" : [ SenseInfo('00929164-a', 0), SenseInfo('00041051-a', 0), SenseInfo('00100213-a', 0) ],
"_old+hat_a_1_rel" : [ SenseInfo('01688757-a', 0), SenseInfo('00974159-a', 0) ],
"_apprise_v_of_rel" : [ SenseInfo('00873682-v', 0), SenseInfo('00831074-v', 0), SenseInfo('00316195-v', 0), SenseInfo('00315605-v', 0), SenseInfo('00873682-v', 0), SenseInfo('00831074-v', 0), SenseInfo('00316195-v', 0), SenseInfo('00315605-v', 0) ],
"_tuft_n_of_rel" : [ SenseInfo('07960769-n', 1), SenseInfo('01325775-n', 0) ],
"_ruins_n_1_rel" : [ SenseInfo('14562324-n', 3), SenseInfo('04118635-n', 2), SenseInfo('13466312-n', 0), SenseInfo('07335243-n', 0), SenseInfo('07318133-n', 0), SenseInfo('00217773-n', 0), SenseInfo('14562324-n', 3), SenseInfo('04118635-n', 2), SenseInfo('13466312-n', 0), SenseInfo('07335243-n', 0), SenseInfo('07318133-n', 0), SenseInfo('00217773-n', 0) ],
"_indiscreet_a_1_rel" : [ SenseInfo('00773109-a', 0), SenseInfo('00773109-a', 0) ],
"_improper_a_1_rel" : [ SenseInfo('01880531-a', 0), SenseInfo('01961410-a', 0), SenseInfo('00136185-a', 0) ],
"_cull_v_1_rel" : [ SenseInfo('02224781-v', 0), SenseInfo('01382083-v', 0) ],
"_break_v_away_rel" : [ SenseInfo('00364064-v', 15), SenseInfo('00334186-v', 13), SenseInfo('00258665-v', 9), SenseInfo('01369758-v', 8), SenseInfo('00334996-v', 8), SenseInfo('02566528-v', 5), SenseInfo('02073233-v', 4), SenseInfo('02029369-v', 4), SenseInfo('01785395-v', 4), SenseInfo('00362348-v', 4), SenseInfo('02570684-v', 3), SenseInfo('00202569-v', 3), SenseInfo('02668523-v', 2), SenseInfo('01106864-v', 2), SenseInfo('00933821-v', 2), SenseInfo('00558536-v', 2), SenseInfo('00434374-v', 2), SenseInfo('02535716-v', 1), SenseInfo('02030764-v', 1), SenseInfo('01972976-v', 1), SenseInfo('00390215-v', 1), SenseInfo('00202784-v', 1), SenseInfo('02746617-v', 0), SenseInfo('02746449-v', 0), SenseInfo('02681639-v', 0), SenseInfo('02681524-v', 0), SenseInfo('02625187-v', 0), SenseInfo('02600082-v', 0), SenseInfo('02559395-v', 0), SenseInfo('02478469-v', 0), SenseInfo('02431320-v', 0), SenseInfo('02399331-v', 0), SenseInfo('02318165-v', 0), SenseInfo('02101373-v', 0), SenseInfo('01991347-v', 0), SenseInfo('01989053-v', 0), SenseInfo('01896484-v', 0), SenseInfo('01610666-v', 0), SenseInfo('01610463-v', 0), SenseInfo('01597995-v', 0), SenseInfo('01557646-v', 0), SenseInfo('01369346-v', 0), SenseInfo('01298931-v', 0), SenseInfo('01228524-v', 0), SenseInfo('01228396-v', 0), SenseInfo('00935987-v', 0), SenseInfo('00779061-v', 0), SenseInfo('00778745-v', 0), SenseInfo('00744439-v', 0), SenseInfo('00738440-v', 0), SenseInfo('00738314-v', 0), SenseInfo('00551412-v', 0), SenseInfo('00339464-v', 0), SenseInfo('00336260-v', 0), SenseInfo('00258366-v', 0), SenseInfo('00155046-v', 0), SenseInfo('00107739-v', 0), SenseInfo('00107604-v', 0), SenseInfo('00030463-v', 0), SenseInfo('00364064-v', 15), SenseInfo('00334186-v', 13), SenseInfo('00258665-v', 9), SenseInfo('01369758-v', 8), SenseInfo('00334996-v', 8), SenseInfo('02566528-v', 5), SenseInfo('02073233-v', 4), SenseInfo('02029369-v', 4), SenseInfo('01785395-v', 4), SenseInfo('00362348-v', 4), SenseInfo('02570684-v', 3), SenseInfo('00202569-v', 3), SenseInfo('02668523-v', 2), SenseInfo('01106864-v', 2), SenseInfo('00933821-v', 2), SenseInfo('00558536-v', 2), SenseInfo('00434374-v', 2), SenseInfo('02535716-v', 1), SenseInfo('02030764-v', 1), SenseInfo('01972976-v', 1), SenseInfo('00390215-v', 1), SenseInfo('00202784-v', 1), SenseInfo('02746617-v', 0), SenseInfo('02746449-v', 0), SenseInfo('02681639-v', 0), SenseInfo('02681524-v', 0), SenseInfo('02625187-v', 0), SenseInfo('02600082-v', 0), SenseInfo('02559395-v', 0), SenseInfo('02478469-v', 0), SenseInfo('02431320-v', 0), SenseInfo('02399331-v', 0), SenseInfo('02318165-v', 0), SenseInfo('02101373-v', 0), SenseInfo('01991347-v', 0), SenseInfo('01989053-v', 0), SenseInfo('01896484-v', 0), SenseInfo('01610666-v', 0), SenseInfo('01610463-v', 0), SenseInfo('01597995-v', 0), SenseInfo('01557646-v', 0), SenseInfo('01369346-v', 0), SenseInfo('01298931-v', 0), SenseInfo('01228524-v', 0), SenseInfo('01228396-v', 0), SenseInfo('00935987-v', 0), SenseInfo('00779061-v', 0), SenseInfo('00778745-v', 0), SenseInfo('00744439-v', 0), SenseInfo('00738440-v', 0), SenseInfo('00738314-v', 0), SenseInfo('00551412-v', 0), SenseInfo('00339464-v', 0), SenseInfo('00336260-v', 0), SenseInfo('00258366-v', 0), SenseInfo('00155046-v', 0), SenseInfo('00107739-v', 0), SenseInfo('00107604-v', 0), SenseInfo('00030463-v', 0) ],
"_body_n_1_rel" : [ SenseInfo('05216365-n', 113), SenseInfo('07965085-n', 19), SenseInfo('05217859-n', 14), SenseInfo('09224911-n', 7), SenseInfo('05549830-n', 7), SenseInfo('08436288-n', 5), SenseInfo('04934546-n', 2), SenseInfo('06394701-n', 1), SenseInfo('05024616-n', 0), SenseInfo('04261506-n', 0), SenseInfo('02861886-n', 0) ],
"_corrode_v_1_rel" : [ SenseInfo('00274283-v', 1), SenseInfo('00273963-v', 0) ],
"_overhead_n_1_rel" : [ SenseInfo('13277179-n', 3), SenseInfo('15298011-n', 0), SenseInfo('08556065-n', 0), SenseInfo('04534779-n', 0), SenseInfo('03864542-n', 0), SenseInfo('00569474-n', 0) ],
"_fork_v_1_rel" : [ SenseInfo('01579340-v', 0), SenseInfo('01118888-v', 0), SenseInfo('00328802-v', 0), SenseInfo('00141914-v', 0) ],
"_huckster_n_1_rel" : [ SenseInfo('10190516-n', 2), SenseInfo('10190644-n', 0) ],
"_crimp_v_1_rel" : [ SenseInfo('01457206-v', 0), SenseInfo('01223833-v', 0) ],
"_owe_v_1_rel" : [ SenseInfo('02254155-v', 11), SenseInfo('02731814-v', 5), SenseInfo('02253956-v', 3), SenseInfo('02254155-v', 11), SenseInfo('02731814-v', 5), SenseInfo('02253956-v', 3) ],
"_prompt_a_1_rel" : [ SenseInfo('01900630-a', 1), SenseInfo('01931676-a', 0), SenseInfo('00978754-a', 0), SenseInfo('01900630-a', 1), SenseInfo('01931676-a', 0), SenseInfo('00978754-a', 0) ],
"_acquaintance_n_1_rel" : [ SenseInfo('05817145-n', 2), SenseInfo('13930245-n', 1), SenseInfo('09763784-n', 1) ],
"_in+relation+to_p_rel" : [  ],
"_billfish_n_1_rel" : [ SenseInfo('02641379-n', 0), SenseInfo('02630739-n', 0), SenseInfo('02551668-n', 0), SenseInfo('02549989-n', 0) ],
"_allot_v_to_rel" : [ SenseInfo('02228698-v', 6), SenseInfo('02255268-v', 4), SenseInfo('02294436-v', 2) ],
"_hood_v_1_rel" : [ SenseInfo('01337092-v', 0) ],
"_astronomy_n_1_rel" : [ SenseInfo('06095022-n', 1) ],
"_soviet_a_1_rel" : [ SenseInfo('02959406-a', 25) ],
"_wail_v_1_rel" : [ SenseInfo('01046932-v', 7), SenseInfo('00066025-v', 2) ],
"_arguable_a_1_rel" : [ SenseInfo('01799670-a', 0), SenseInfo('00602117-a', 0), SenseInfo('01799670-a', 0), SenseInfo('00602117-a', 0), SenseInfo('01799670-a', 0), SenseInfo('00602117-a', 0), SenseInfo('01799670-a', 0), SenseInfo('00602117-a', 0), SenseInfo('01799670-a', 0), SenseInfo('00602117-a', 0) ],
"_regional_a_1_rel" : [ SenseInfo('02871858-a', 14), SenseInfo('02408977-a', 4), SenseInfo('02871858-a', 14), SenseInfo('02408977-a', 4) ],
"_overcome_v_1_rel" : [ SenseInfo('01108148-v', 14), SenseInfo('01108627-v', 9), SenseInfo('01809321-v', 8), SenseInfo('01104018-v', 0), SenseInfo('01108148-v', 14), SenseInfo('01108627-v', 9), SenseInfo('01809321-v', 8), SenseInfo('01104018-v', 0) ],
"_warden_n_1_rel" : [ SenseInfo('10767154-n', 0) ],
"_potassium_n_1_rel" : [ SenseInfo('14650807-n', 5) ],
"_waitress_n_1_rel" : [ SenseInfo('10763620-n', 1) ],
"_insect_n_1_rel" : [ SenseInfo('02159955-n', 8), SenseInfo('10792028-n', 0) ],
"_exceptive_a_1_rel" : [  ],
"_overload_v_cause_rel" : [ SenseInfo('01488847-v', 1), SenseInfo('00182037-v', 1), SenseInfo('01488555-v', 0), SenseInfo('01488847-v', 1), SenseInfo('00182037-v', 1), SenseInfo('01488555-v', 0) ],
"_boro_n_1_rel" : [  ],
"_handfast_v_1_rel" : [  ],
"_need_n_of_rel" : [ SenseInfo('14449126-n', 56), SenseInfo('09367991-n', 29), SenseInfo('00023773-n', 12), SenseInfo('14493716-n', 1), SenseInfo('14449126-n', 56), SenseInfo('09367991-n', 29), SenseInfo('00023773-n', 12), SenseInfo('14493716-n', 1), SenseInfo('14449126-n', 56), SenseInfo('09367991-n', 29), SenseInfo('00023773-n', 12), SenseInfo('14493716-n', 1) ],
"_serbian_n_1_rel" : [ SenseInfo('09751076-n', 0) ],
"_patch_v_in_rel" : [ SenseInfo('01590171-v', 2), SenseInfo('02357693-v', 1), SenseInfo('00262703-v', 0), SenseInfo('00261705-v', 0), SenseInfo('01590171-v', 2), SenseInfo('02357693-v', 1), SenseInfo('00262703-v', 0), SenseInfo('00261705-v', 0) ],
"_laborer_n_1_rel" : [ SenseInfo('10241300-n', 5), SenseInfo('10241300-n', 5) ],
"_regulator_n_1_rel" : [ SenseInfo('04072193-n', 1), SenseInfo('10517826-n', 0), SenseInfo('03450018-n', 0) ],
"_headwaters_n_1_rel" : [ SenseInfo('08508629-n', 0), SenseInfo('08508629-n', 0) ],
"_semaphore_n_1_rel" : [ SenseInfo('04171208-n', 0) ],
"_sparkle_n_1_rel" : [ SenseInfo('04953380-n', 2), SenseInfo('07412668-n', 0), SenseInfo('04952944-n', 0) ],
"_above-market_a_1_rel" : [  ],
"_obsolete_a_1_rel" : [ SenseInfo('00669021-a', 0), SenseInfo('00669021-a', 0), SenseInfo('00669021-a', 0) ],
"_mess_v_up_rel" : [ SenseInfo('01176079-v', 0), SenseInfo('00276214-v', 0), SenseInfo('01176079-v', 0), SenseInfo('00276214-v', 0) ],
"_cough_n_1_rel" : [ SenseInfo('14359174-n', 0) ],
"_period_n_of_rel" : [ SenseInfo('15113229-n', 94), SenseInfo('15289779-n', 2), SenseInfo('15258281-n', 0), SenseInfo('15247518-n', 0), SenseInfo('15144178-n', 0), SenseInfo('13513747-n', 0), SenseInfo('06843520-n', 0) ],
"_infuriating_a_1_rel" : [ SenseInfo('01809245-a', 2) ],
"_exclusive_n_1_rel" : [ SenseInfo('06683183-n', 0) ],
"_let_v_out_rel" : [ SenseInfo('02423183-v', 219), SenseInfo('00771490-v', 15), SenseInfo('00802318-v', 2), SenseInfo('00120796-v', 2), SenseInfo('00496673-v', 1), SenseInfo('02208903-v', 0), SenseInfo('02423183-v', 219), SenseInfo('00771490-v', 15), SenseInfo('00802318-v', 2), SenseInfo('00120796-v', 2), SenseInfo('00496673-v', 1), SenseInfo('02208903-v', 0) ],
"_regular_n_1_rel" : [ SenseInfo('10517405-n', 1), SenseInfo('10517743-n', 0), SenseInfo('10517583-n', 0), SenseInfo('05096972-n', 0) ],
"_confer_v_1_rel" : [ SenseInfo('00876665-v', 1), SenseInfo('02263346-v', 0) ],
"_evolutionary_a_1_rel" : [ SenseInfo('03000725-a', 1) ],
"_disclaimer_n_1_rel" : [ SenseInfo('07207680-n', 0), SenseInfo('07205946-n', 0) ],
"_needless+to+say_a_1_rel" : [  ],
"_on+board_p_rel" : [ SenseInfo('00249878-r', 0), SenseInfo('00249878-r', 0), SenseInfo('00249878-r', 0) ],
"_gnarled_a_1_rel" : [ SenseInfo('02313235-a', 0) ],
"_supernatural_n_1_rel" : [ SenseInfo('09503877-n', 2) ],
"_rebound_n_1_rel" : [ SenseInfo('07350192-n', 0), SenseInfo('00859691-n', 0), SenseInfo('00140112-n', 0) ],
"_creak_n_1_rel" : [ SenseInfo('07381864-n', 0) ],
"_ethernet_n_1_rel" : [ SenseInfo('03300216-n', 0) ],
"_male_n_1_rel" : [ SenseInfo('01321230-n', 6), SenseInfo('09624168-n', 4), SenseInfo('08965475-n', 0) ],
"_my+goodness_a_1_rel" : [  ],
"_quaternary_a_1_rel" : [ SenseInfo('02219492-a', 0), SenseInfo('02202443-a', 0) ],
"_indisputably_x_deg_rel" : [  ],
"_add_v_up_rel" : [ SenseInfo('00182406-v', 116), SenseInfo('01027174-v', 68), SenseInfo('02324478-v', 15), SenseInfo('00640828-v', 3), SenseInfo('00949288-v', 1), SenseInfo('02745172-v', 0), SenseInfo('00182406-v', 116), SenseInfo('01027174-v', 68), SenseInfo('02324478-v', 15), SenseInfo('00640828-v', 3), SenseInfo('00949288-v', 1), SenseInfo('02745172-v', 0) ],
"_flog_v_1_rel" : [ SenseInfo('01411085-v', 1), SenseInfo('01412204-v', 0) ],
"_antecedent_a_1_rel" : [ SenseInfo('00121865-a', 0) ],
"_say_v_about_rel" : [ SenseInfo('01009240-v', 1861), SenseInfo('01016002-v', 254), SenseInfo('00917300-v', 29), SenseInfo('02730813-v', 8), SenseInfo('00746718-v', 8), SenseInfo('00978549-v', 4), SenseInfo('00928959-v', 2), SenseInfo('00979870-v', 1), SenseInfo('01009821-v', 0), SenseInfo('00945499-v', 0), SenseInfo('00923197-v', 0) ],
"_modem_n_1_rel" : [ SenseInfo('03777754-n', 0) ],
"_abyss_n_1_rel" : [ SenseInfo('09186359-n', 3) ],
"_loosen_v_1_rel" : [ SenseInfo('00419375-v', 5), SenseInfo('02601996-v', 0), SenseInfo('02601808-v', 0), SenseInfo('01463792-v', 0), SenseInfo('01284908-v', 0), SenseInfo('01275516-v', 0), SenseInfo('00419137-v', 0) ],
"_lyric_n_1_rel" : [ SenseInfo('07051975-n', 12), SenseInfo('06380726-n', 0) ],
"_give_v_of_rel" : [ SenseInfo('02316868-v', 179), SenseInfo('02339171-v', 160), SenseInfo('02199590-v', 96), SenseInfo('02235842-v', 78), SenseInfo('01060494-v', 32), SenseInfo('01733477-v', 29), SenseInfo('01060317-v', 24), SenseInfo('02200686-v', 20), SenseInfo('01629403-v', 18), SenseInfo('00732224-v', 18), SenseInfo('01629000-v', 16), SenseInfo('02296153-v', 14), SenseInfo('01647672-v', 14), SenseInfo('02200498-v', 12), SenseInfo('02562901-v', 10), SenseInfo('02343595-v', 10), SenseInfo('02230772-v', 10), SenseInfo('00887463-v', 8), SenseInfo('02309374-v', 5), SenseInfo('02309165-v', 5), SenseInfo('01060746-v', 5), SenseInfo('02317094-v', 4), SenseInfo('01848465-v', 4), SenseInfo('01178565-v', 4), SenseInfo('02308741-v', 3), SenseInfo('01989053-v', 1), SenseInfo('00673571-v', 1), SenseInfo('02564052-v', 0), SenseInfo('02359553-v', 0), SenseInfo('02358034-v', 0), SenseInfo('01716283-v', 0), SenseInfo('01716112-v', 0), SenseInfo('01449796-v', 0), SenseInfo('01175810-v', 0), SenseInfo('01069638-v', 0), SenseInfo('00944247-v', 0), SenseInfo('00888009-v', 0), SenseInfo('00878876-v', 0), SenseInfo('00771806-v', 0), SenseInfo('00748972-v', 0), SenseInfo('00748616-v', 0), SenseInfo('00341184-v', 0), SenseInfo('00108747-v', 0), SenseInfo('00108604-v', 0) ],
"_bloat_n_1_rel" : [ SenseInfo('14315549-n', 8) ],
"_aspen_n_1_rel" : [ SenseInfo('12733647-n', 0) ],
"_snowmelt_n_1_rel" : [  ],
"_A_a_colon_rel" : [  ],
"_trash_n_1_rel" : [ SenseInfo('14857497-n', 0), SenseInfo('08402147-n', 0), SenseInfo('06611998-n', 0), SenseInfo('03754295-n', 0) ],
"_poor_n_1_rel" : [ SenseInfo('08179205-n', 0) ],
"_fain_a_1_rel" : [ SenseInfo('02565425-a', 0) ],
"_nanostructure_n_1_rel" : [  ],
"_shut_v_1_rel" : [ SenseInfo('01345109-v', 10), SenseInfo('01346978-v', 2), SenseInfo('02449340-v', 1) ],
"_mood_n_1_rel" : [ SenseInfo('07551052-n', 14), SenseInfo('14524661-n', 6), SenseInfo('13801424-n', 0), SenseInfo('07551052-n', 14), SenseInfo('14524661-n', 6), SenseInfo('13801424-n', 0) ],
"_foilage_n_1_rel" : [  ],
"_saved_a_1_rel" : [ SenseInfo('01451498-a', 1), SenseInfo('00737703-a', 0) ],
"_streak_v_1_rel" : [ SenseInfo('02087605-v', 2), SenseInfo('01927330-v', 0), SenseInfo('01696135-v', 0) ],
"_predatory_a_1_rel" : [ SenseInfo('01629832-a', 0), SenseInfo('00084022-a', 0), SenseInfo('00030798-a', 0) ],
"_blight_v_1_rel" : [ SenseInfo('02771320-v', 1) ],
"neg_rel" : [  ],
"_peat_n_1_rel" : [ SenseInfo('14689493-n', 0) ],
"_eagerness_n_1_rel" : [ SenseInfo('07555184-n', 5), SenseInfo('04644719-n', 0), SenseInfo('07555184-n', 5), SenseInfo('04644719-n', 0) ],
"_reverence_n_1_rel" : [ SenseInfo('07521039-n', 0), SenseInfo('06207561-n', 0), SenseInfo('01228102-n', 0) ],
"_reluctant_a_1_rel" : [ SenseInfo('02566453-a', 3), SenseInfo('01293882-a', 2), SenseInfo('00811969-a', 1), SenseInfo('02566453-a', 3), SenseInfo('01293882-a', 2), SenseInfo('00811969-a', 1), SenseInfo('02566453-a', 3), SenseInfo('01293882-a', 2), SenseInfo('00811969-a', 1) ],
"_biped_n_1_rel" : [ SenseInfo('02157285-n', 0) ],
"_disability_n_1_rel" : [ SenseInfo('14548343-n', 3), SenseInfo('14548343-n', 3), SenseInfo('14548343-n', 3) ],
"_scraggy_a_1_rel" : [ SenseInfo('00990192-a', 0), SenseInfo('00912288-a', 0), SenseInfo('00990192-a', 0), SenseInfo('00912288-a', 0), SenseInfo('00990192-a', 0), SenseInfo('00912288-a', 0) ],
"_yooee_a_1_rel" : [  ],
"_angel_n_1_rel" : [ SenseInfo('09538915-n', 8), SenseInfo('10546850-n', 0), SenseInfo('09793717-n', 0), SenseInfo('09197660-n', 0) ],
"_most+likely_a_1_rel" : [  ],
"_remedy_n_1_rel" : [ SenseInfo('00259177-n', 2), SenseInfo('04074482-n', 1) ],
"_balance_n_of_rel" : [ SenseInfo('14002279-n', 28), SenseInfo('13408980-n', 3), SenseInfo('05076827-n', 1), SenseInfo('13897996-n', 0), SenseInfo('13810818-n', 0), SenseInfo('13409160-n', 0), SenseInfo('09753065-n', 0), SenseInfo('08687150-n', 0), SenseInfo('05064827-n', 0), SenseInfo('03118539-n', 0), SenseInfo('02777402-n', 0), SenseInfo('02777100-n', 0) ],
"_vet_n_abb_rel" : [ SenseInfo('10749715-n', 1), SenseInfo('10749353-n', 0) ],
"_launch_v_into_rel" : [ SenseInfo('02427103-v', 10), SenseInfo('01514655-v', 6), SenseInfo('01515415-v', 4), SenseInfo('00347918-v', 2), SenseInfo('01515196-v', 0), SenseInfo('01253363-v', 0) ],
"_exploration_n_of_rel" : [ SenseInfo('00310063-n', 5), SenseInfo('00945777-n', 4), SenseInfo('05785311-n', 2) ],
"_performer_n_1_rel" : [ SenseInfo('10415638-n', 8) ],
"_gasket_n_1_rel" : [ SenseInfo('03423719-n', 0) ],
"_deal_n_1_rel" : [ SenseInfo('01110274-n', 8), SenseInfo('06771159-n', 2), SenseInfo('13774404-n', 1), SenseInfo('15102622-n', 0), SenseInfo('15100257-n', 0), SenseInfo('07956887-n', 0), SenseInfo('07293180-n', 0), SenseInfo('01085337-n', 0), SenseInfo('01084637-n', 0) ],
"_necklace_n_1_rel" : [ SenseInfo('03814906-n', 1) ],
"_beard_n_1_rel" : [ SenseInfo('05261566-n', 8), SenseInfo('13090594-n', 0), SenseInfo('09845401-n', 0), SenseInfo('02416270-n', 0), SenseInfo('01955318-n', 0) ],
"_lend_v_to_rel" : [ SenseInfo('02324478-v', 7), SenseInfo('02324182-v', 7), SenseInfo('02736391-v', 2) ],
"_scissors_n_pair_rel" : [ SenseInfo('04148054-n', 0), SenseInfo('00814665-n', 0), SenseInfo('00438725-n', 0), SenseInfo('04148054-n', 0), SenseInfo('00814665-n', 0), SenseInfo('00438725-n', 0) ],
"_untypical_a_1_rel" : [ SenseInfo('02469928-a', 0), SenseInfo('02469928-a', 0) ],
"_hunger_n_1_rel" : [ SenseInfo('14039534-n', 9), SenseInfo('04945254-n', 1) ],
"_tower_n_of_rel" : [ SenseInfo('04460130-n', 4), SenseInfo('13900422-n', 1), SenseInfo('04495843-n', 0), SenseInfo('04460130-n', 4), SenseInfo('13900422-n', 1), SenseInfo('04495843-n', 0) ],
"_strip_v_down_rel" : [ SenseInfo('02314275-v', 7), SenseInfo('00049900-v', 2), SenseInfo('01263479-v', 1), SenseInfo('00488617-v', 1), SenseInfo('00194912-v', 1), SenseInfo('02344568-v', 0), SenseInfo('01608706-v', 0), SenseInfo('01263659-v', 0), SenseInfo('00194812-v', 0), SenseInfo('00194696-v', 0), SenseInfo('00194534-v', 0), SenseInfo('00194079-v', 0), SenseInfo('00177243-v', 0) ],
"_college_n_of_rel" : [ SenseInfo('08278169-n', 45), SenseInfo('08278324-n', 0), SenseInfo('03069752-n', 0) ],
"_precept_n_1_rel" : [ SenseInfo('06655388-n', 0), SenseInfo('06185955-n', 0) ],
"_misuse_n_of_rel" : [ SenseInfo('00947719-n', 1) ],
"_coast_n_1_rel" : [ SenseInfo('09428293-n', 20), SenseInfo('09248153-n', 0), SenseInfo('05934029-n', 0), SenseInfo('00328502-n', 0) ],
"_hog_v_1_rel" : [ SenseInfo('02304862-v', 1) ],
"_anecdote_n_1_rel" : [ SenseInfo('07220586-n', 8) ],
"_genealogy_n_1_rel" : [ SenseInfo('08102402-n', 0), SenseInfo('05998225-n', 0) ],
"_response_n_to_rel" : [ SenseInfo('11416988-n', 11), SenseInfo('00859001-n', 11), SenseInfo('06746005-n', 6), SenseInfo('06630852-n', 4), SenseInfo('06385582-n', 1), SenseInfo('07199565-n', 0), SenseInfo('05212808-n', 0), SenseInfo('11416988-n', 11), SenseInfo('00859001-n', 11), SenseInfo('06746005-n', 6), SenseInfo('06630852-n', 4), SenseInfo('06385582-n', 1), SenseInfo('07199565-n', 0), SenseInfo('05212808-n', 0), SenseInfo('11416988-n', 11), SenseInfo('00859001-n', 11), SenseInfo('06746005-n', 6), SenseInfo('06630852-n', 4), SenseInfo('06385582-n', 1), SenseInfo('07199565-n', 0), SenseInfo('05212808-n', 0) ],
"_review_v_1_rel" : [ SenseInfo('00696189-v', 13), SenseInfo('00855512-v', 9), SenseInfo('00696700-v', 3), SenseInfo('00696852-v', 0), SenseInfo('00696414-v', 0), SenseInfo('00696189-v', 13), SenseInfo('00855512-v', 9), SenseInfo('00696700-v', 3), SenseInfo('00696852-v', 0), SenseInfo('00696414-v', 0) ],
"_ascender_n_1_rel" : [ SenseInfo('09813522-n', 0), SenseInfo('06830561-n', 0), SenseInfo('06800532-n', 0) ],
"_adherent_n_1_rel" : [ SenseInfo('10016103-n', 3) ],
"_archangel_n_1_rel" : [ SenseInfo('09539183-n', 1), SenseInfo('12932173-n', 0) ],
"_undulate_v_1_rel" : [ SenseInfo('02040054-v', 1), SenseInfo('02687251-v', 0), SenseInfo('01901783-v', 0), SenseInfo('00581355-v', 0) ],
"_cube_n_1_rel" : [ SenseInfo('13916721-n', 2), SenseInfo('13914608-n', 1), SenseInfo('13731241-n', 0), SenseInfo('12544862-n', 0), SenseInfo('03144592-n', 0) ],
"_cutter_n_1_rel" : [ SenseInfo('10659294-n', 0), SenseInfo('09985470-n', 0), SenseInfo('09985279-n', 0), SenseInfo('04409128-n', 0), SenseInfo('03154316-n', 0), SenseInfo('03154073-n', 0) ],
"_runner_n_1_rel" : [ SenseInfo('10615334-n', 3), SenseInfo('10542761-n', 1), SenseInfo('10542608-n', 1), SenseInfo('09841696-n', 1), SenseInfo('13127843-n', 0), SenseInfo('10542888-n', 0), SenseInfo('09834378-n', 0), SenseInfo('04120266-n', 0), SenseInfo('04120093-n', 0), SenseInfo('02577164-n', 0) ],
"_in+sum_a_1_rel" : [  ],
"_appendant_a_to_rel" : [ SenseInfo('00158864-a', 0) ],
"_burn_v_down_rel" : [ SenseInfo('00378664-v', 11), SenseInfo('02768874-v', 10), SenseInfo('00377002-v', 9), SenseInfo('02120451-v', 4), SenseInfo('02762468-v', 2), SenseInfo('01829292-v', 2), SenseInfo('00378042-v', 2), SenseInfo('02485322-v', 1), SenseInfo('02268881-v', 1), SenseInfo('02121048-v', 1), SenseInfo('00373766-v', 1), SenseInfo('00104299-v', 1), SenseInfo('01756277-v', 0), SenseInfo('01205000-v', 0), SenseInfo('00196364-v', 0), SenseInfo('00378664-v', 11), SenseInfo('02768874-v', 10), SenseInfo('00377002-v', 9), SenseInfo('02120451-v', 4), SenseInfo('02762468-v', 2), SenseInfo('01829292-v', 2), SenseInfo('00378042-v', 2), SenseInfo('02485322-v', 1), SenseInfo('02268881-v', 1), SenseInfo('02121048-v', 1), SenseInfo('00373766-v', 1), SenseInfo('00104299-v', 1), SenseInfo('01756277-v', 0), SenseInfo('01205000-v', 0), SenseInfo('00196364-v', 0) ],
"_provincial_a_1_rel" : [ SenseInfo('02785874-a', 3), SenseInfo('00636547-a', 2) ],
"_mum_n_1_rel" : [ SenseInfo('11961100-n', 0), SenseInfo('10278128-n', 0), SenseInfo('04652345-n', 0) ],
"_indicate_v_1_rel" : [ SenseInfo('00921300-v', 68), SenseInfo('00923793-v', 65), SenseInfo('00928015-v', 37), SenseInfo('00772640-v', 14), SenseInfo('00928232-v', 4), SenseInfo('00921300-v', 68), SenseInfo('00923793-v', 65), SenseInfo('00928015-v', 37), SenseInfo('00772640-v', 14), SenseInfo('00928232-v', 4), SenseInfo('00921300-v', 68), SenseInfo('00923793-v', 65), SenseInfo('00928015-v', 37), SenseInfo('00772640-v', 14), SenseInfo('00928232-v', 4) ],
"_sled_v_1_rel" : [ SenseInfo('01939174-v', 0) ],
"_mystical_a_1_rel" : [ SenseInfo('02863247-a', 1), SenseInfo('02863464-a', 0), SenseInfo('00900071-a', 0) ],
"_guinea+pig_n_1_rel" : [ SenseInfo('10668666-n', 0), SenseInfo('02364673-n', 0) ],
"_endeavor_v_1_rel" : [ SenseInfo('02531199-v', 4), SenseInfo('02531199-v', 4) ],
"_amplify_v_1_rel" : [ SenseInfo('00434077-v', 4), SenseInfo('00839834-v', 0), SenseInfo('00264386-v', 0), SenseInfo('00263904-v', 0) ],
"_slip_n_1_rel" : [ SenseInfo('00076196-n', 4), SenseInfo('00073828-n', 1), SenseInfo('14814295-n', 0), SenseInfo('13127473-n', 0), SenseInfo('10612104-n', 0), SenseInfo('08640111-n', 0), SenseInfo('07317519-n', 0), SenseInfo('04947628-n', 0), SenseInfo('04339291-n', 0), SenseInfo('04240327-n', 0), SenseInfo('03013580-n', 0), SenseInfo('02975412-n', 0), SenseInfo('00329031-n', 0), SenseInfo('00170710-n', 0), SenseInfo('00059376-n', 0) ],
"_colonization_n_of_rel" : [ SenseInfo('01252280-n', 0), SenseInfo('01252280-n', 0) ],
"_coincide_v_1_rel" : [ SenseInfo('02660442-v', 9), SenseInfo('00345312-v', 5), SenseInfo('02658734-v', 4), SenseInfo('02660442-v', 9), SenseInfo('00345312-v', 5), SenseInfo('02658734-v', 4) ],
"_reliance_n_1_rel" : [ SenseInfo('05697976-n', 2), SenseInfo('14001728-n', 1) ],
"_athletics_n_1_rel" : [ SenseInfo('00523513-n', 1), SenseInfo('07456638-n', 0), SenseInfo('00886582-n', 0) ],
"_wear_v_on-i_rel" : [ SenseInfo('00052374-v', 83), SenseInfo('00047745-v', 22), SenseInfo('02740034-v', 6), SenseInfo('00469382-v', 2), SenseInfo('00047610-v', 2), SenseInfo('02705132-v', 1), SenseInfo('01369346-v', 0), SenseInfo('00075021-v', 0), SenseInfo('00050652-v', 0) ],
"_dbl+rt+angle_a_1_rel" : [  ],
"_hitchhiker_n_1_rel" : [ SenseInfo('10178077-n', 0) ],
"_stated_a_1_rel" : [ SenseInfo('00940870-a', 0) ],
"_nonchalant_a_1_rel" : [ SenseInfo('00545746-a', 1) ],
"_subtend_v_1_rel" : [ SenseInfo('02693842-v', 2) ],
"_influence_v_1_rel" : [ SenseInfo('02536557-v', 19), SenseInfo('00701040-v', 9), SenseInfo('00776523-v', 0), SenseInfo('02536557-v', 19), SenseInfo('00701040-v', 9), SenseInfo('00776523-v', 0), SenseInfo('02536557-v', 19), SenseInfo('00701040-v', 9), SenseInfo('00776523-v', 0) ],
"_spurious_a_1_rel" : [ SenseInfo('02462210-a', 0), SenseInfo('01407909-a', 0), SenseInfo('01117677-a', 0) ],
"_organization_n_1_rel" : [ SenseInfo('08008335-n', 29), SenseInfo('05726596-n', 12), SenseInfo('08164585-n', 11), SenseInfo('01136519-n', 3), SenseInfo('04768657-n', 0), SenseInfo('01008378-n', 0), SenseInfo('00237078-n', 0), SenseInfo('08008335-n', 29), SenseInfo('05726596-n', 12), SenseInfo('08164585-n', 11), SenseInfo('01136519-n', 3), SenseInfo('04768657-n', 0), SenseInfo('01008378-n', 0), SenseInfo('00237078-n', 0), SenseInfo('08008335-n', 29), SenseInfo('05726596-n', 12), SenseInfo('08164585-n', 11), SenseInfo('01136519-n', 3), SenseInfo('04768657-n', 0), SenseInfo('01008378-n', 0), SenseInfo('00237078-n', 0) ],
"_brevet+major_n_1_rel" : [  ],
"_stilt_n_1_rel" : [ SenseInfo('03936269-n', 1), SenseInfo('04319937-n', 0), SenseInfo('02036053-n', 0), SenseInfo('02034661-n', 0) ],
"_stool_n_1_rel" : [ SenseInfo('04326896-n', 3), SenseInfo('14854262-n', 0), SenseInfo('13111700-n', 0), SenseInfo('04446521-n', 0) ],
"_equitation_n_1_rel" : [ SenseInfo('00450335-n', 0) ],
"_scamper_v_1_rel" : [ SenseInfo('01902405-v', 5) ],
"_filthy_a_1_rel" : [ SenseInfo('00421590-a', 2), SenseInfo('01587474-a', 0), SenseInfo('00425313-a', 0), SenseInfo('00421590-a', 2), SenseInfo('01587474-a', 0), SenseInfo('00425313-a', 0), SenseInfo('00421590-a', 2), SenseInfo('01587474-a', 0), SenseInfo('00425313-a', 0) ],
"_embroidery_n_1_rel" : [ SenseInfo('07172979-n', 0), SenseInfo('03282933-n', 0) ],
"_average_n_of_rel" : [ SenseInfo('06021761-n', 13), SenseInfo('13820655-n', 0), SenseInfo('05856979-n', 0), SenseInfo('06021761-n', 13), SenseInfo('13820655-n', 0), SenseInfo('05856979-n', 0), SenseInfo('06021761-n', 13), SenseInfo('13820655-n', 0), SenseInfo('05856979-n', 0) ],
"_click_v_on_rel" : [ SenseInfo('01893771-v', 5), SenseInfo('02185664-v', 1), SenseInfo('02185861-v', 0), SenseInfo('01242208-v', 0), SenseInfo('01055146-v', 0), SenseInfo('01054849-v', 0), SenseInfo('00591755-v', 0) ],
"_weighting_n_1_rel" : [ SenseInfo('13589321-n', 1) ],
"_husbandry_n_1_rel" : [ SenseInfo('00916464-n', 1) ],
"_foundation_n_1_rel" : [ SenseInfo('13790712-n', 6), SenseInfo('08406486-n', 3), SenseInfo('03387016-n', 1), SenseInfo('05986594-n', 0), SenseInfo('05793554-n', 0), SenseInfo('03387323-n', 0), SenseInfo('00240184-n', 0), SenseInfo('13790712-n', 6), SenseInfo('08406486-n', 3), SenseInfo('03387016-n', 1), SenseInfo('05986594-n', 0), SenseInfo('05793554-n', 0), SenseInfo('03387323-n', 0), SenseInfo('00240184-n', 0) ],
"_quiet_n_1_rel" : [ SenseInfo('14522956-n', 1), SenseInfo('13969101-n', 1), SenseInfo('04982207-n', 1), SenseInfo('04904352-n', 0) ],
"_school_n_1_rel" : [ SenseInfo('08276720-n', 125), SenseInfo('04146050-n', 12), SenseInfo('05757536-n', 6), SenseInfo('08275185-n', 4), SenseInfo('15203229-n', 1), SenseInfo('08277393-n', 0), SenseInfo('07995453-n', 0), SenseInfo('08276720-n', 125), SenseInfo('04146050-n', 12), SenseInfo('05757536-n', 6), SenseInfo('08275185-n', 4), SenseInfo('15203229-n', 1), SenseInfo('08277393-n', 0), SenseInfo('07995453-n', 0), SenseInfo('08276720-n', 125), SenseInfo('04146050-n', 12), SenseInfo('05757536-n', 6), SenseInfo('08275185-n', 4), SenseInfo('15203229-n', 1), SenseInfo('08277393-n', 0), SenseInfo('07995453-n', 0), SenseInfo('08276720-n', 125), SenseInfo('04146050-n', 12), SenseInfo('05757536-n', 6), SenseInfo('08275185-n', 4), SenseInfo('15203229-n', 1), SenseInfo('08277393-n', 0), SenseInfo('07995453-n', 0), SenseInfo('08276720-n', 125), SenseInfo('04146050-n', 12), SenseInfo('05757536-n', 6), SenseInfo('08275185-n', 4), SenseInfo('15203229-n', 1), SenseInfo('08277393-n', 0), SenseInfo('07995453-n', 0), SenseInfo('08276720-n', 125), SenseInfo('04146050-n', 12), SenseInfo('05757536-n', 6), SenseInfo('08275185-n', 4), SenseInfo('15203229-n', 1), SenseInfo('08277393-n', 0), SenseInfo('07995453-n', 0) ],
"_slime_n_1_rel" : [ SenseInfo('14956661-n', 0) ],
"_stave_v_off_rel" : [ SenseInfo('02362798-v', 0), SenseInfo('00310274-v', 0) ],
"_blow_n_1_rel" : [ SenseInfo('01173038-n', 25), SenseInfo('07338681-n', 7), SenseInfo('07475870-n', 2), SenseInfo('07298982-n', 1), SenseInfo('11465017-n', 0), SenseInfo('03066743-n', 0), SenseInfo('00835501-n', 0) ],
"_genesis_n_1_rel" : [ SenseInfo('07324380-n', 3), SenseInfo('06432376-n', 0) ],
"_dispatcher_n_of_rel" : [ SenseInfo('10649308-n', 0), SenseInfo('10017422-n', 0) ],
"_underground_a_1_rel" : [ SenseInfo('02471984-a', 7), SenseInfo('01706465-a', 0) ],
"_snake_n_1_rel" : [ SenseInfo('01726692-n', 20), SenseInfo('10615702-n', 0), SenseInfo('09438554-n', 0), SenseInfo('09307552-n', 0), SenseInfo('04248010-n', 0) ],
"_wok_n_1_rel" : [ SenseInfo('04596742-n', 0) ],
"_capitulum_n_1_rel" : [ SenseInfo('13133786-n', 0), SenseInfo('13133613-n', 0), SenseInfo('13128156-n', 0) ],
"_pedal_n_1_rel" : [ SenseInfo('06858674-n', 0), SenseInfo('03903424-n', 0) ],
"_whoops_a_1_rel" : [  ],
"_filter_v_out_rel" : [ SenseInfo('01458664-v', 10), SenseInfo('01457954-v', 3), SenseInfo('02070874-v', 0) ],
"_come_v_through_rel" : [ SenseInfo('01849221-v', 276), SenseInfo('02005948-v', 235), SenseInfo('00341917-v', 147), SenseInfo('00542120-v', 41), SenseInfo('02625339-v', 40), SenseInfo('00342812-v', 11), SenseInfo('02743921-v', 9), SenseInfo('02743214-v', 7), SenseInfo('02686805-v', 6), SenseInfo('02743565-v', 3), SenseInfo('01839690-v', 3), SenseInfo('02729963-v', 2), SenseInfo('00344886-v', 2), SenseInfo('02645007-v', 1), SenseInfo('02627363-v', 1), SenseInfo('02006709-v', 1), SenseInfo('00723349-v', 1), SenseInfo('02737187-v', 0), SenseInfo('02617567-v', 0), SenseInfo('02197360-v', 0), SenseInfo('00659984-v', 0) ],
"_legislator_n_1_rel" : [ SenseInfo('10253995-n', 8) ],
"_bushing_n_1_rel" : [ SenseInfo('02925250-n', 0), SenseInfo('02925107-n', 0) ],
"_side_v_with_rel" : [ SenseInfo('01148961-v', 0) ],
"_kit_n_1_rel" : [ SenseInfo('03619650-n', 2), SenseInfo('03619396-n', 0), SenseInfo('01323155-n', 0) ],
"_profit_v_from_rel" : [ SenseInfo('02290461-v', 2), SenseInfo('02278830-v', 2) ],
"_adversative_a_1_rel" : [ SenseInfo('00564504-a', 0) ],
"_musical_a_1_rel" : [ SenseInfo('02867783-a', 21), SenseInfo('01505462-a', 2), SenseInfo('01504625-a', 0), SenseInfo('01501113-a', 0) ],
"_manmade_a_1_rel" : [  ],
"_mayo_n_1_rel" : [ SenseInfo('07834507-n', 0) ],
"_respire_v_1_rel" : [ SenseInfo('00002573-v', 0), SenseInfo('00002325-v', 0), SenseInfo('00001740-v', 0) ],
"_dew_n_1_rel" : [ SenseInfo('14834132-n', 2) ],
"_ludicrous_a_for_rel" : [ SenseInfo('01266397-a', 1), SenseInfo('02570643-a', 0), SenseInfo('01266397-a', 1), SenseInfo('02570643-a', 0) ],
"_fragrant_a_1_rel" : [ SenseInfo('01052248-a', 2) ],
"_inc_n_1_rel" : [ SenseInfo('08403907-n', 0), SenseInfo('08403907-n', 0), SenseInfo('08403907-n', 0), SenseInfo('08403907-n', 0), SenseInfo('08403907-n', 0) ],
"_upset_a_1_rel" : [ SenseInfo('02457167-a', 1), SenseInfo('01669246-a', 1), SenseInfo('00931395-a', 1), SenseInfo('02547217-a', 0), SenseInfo('02467766-a', 0), SenseInfo('02457167-a', 1), SenseInfo('01669246-a', 1), SenseInfo('00931395-a', 1), SenseInfo('02547217-a', 0), SenseInfo('02467766-a', 0) ],
"_impractical_a_1_rel" : [ SenseInfo('01836350-a', 2), SenseInfo('02498213-a', 0) ],
"_yew_n_1_rel" : [ SenseInfo('11661707-n', 0), SenseInfo('11661372-n', 0) ],
"_selective_a_1_rel" : [ SenseInfo('00775693-a', 3), SenseInfo('01863246-a', 0), SenseInfo('00775693-a', 3), SenseInfo('01863246-a', 0) ],
"_slump_v_1_rel" : [ SenseInfo('01989720-v', 4), SenseInfo('01988886-v', 1), SenseInfo('00432839-v', 1), SenseInfo('01971603-v', 0) ],
"_absolute_a_1_rel" : [ SenseInfo('00005205-a', 11), SenseInfo('00520892-a', 4), SenseInfo('00719328-a', 1), SenseInfo('00897015-a', 0), SenseInfo('00094069-a', 0), SenseInfo('00005205-a', 11), SenseInfo('00520892-a', 4), SenseInfo('00719328-a', 1), SenseInfo('00897015-a', 0), SenseInfo('00094069-a', 0), SenseInfo('00005205-a', 11), SenseInfo('00520892-a', 4), SenseInfo('00719328-a', 1), SenseInfo('00897015-a', 0), SenseInfo('00094069-a', 0), SenseInfo('00005205-a', 11), SenseInfo('00520892-a', 4), SenseInfo('00719328-a', 1), SenseInfo('00897015-a', 0), SenseInfo('00094069-a', 0), SenseInfo('00005205-a', 11), SenseInfo('00520892-a', 4), SenseInfo('00719328-a', 1), SenseInfo('00897015-a', 0), SenseInfo('00094069-a', 0), SenseInfo('00005205-a', 11), SenseInfo('00520892-a', 4), SenseInfo('00719328-a', 1), SenseInfo('00897015-a', 0), SenseInfo('00094069-a', 0) ],
"_insure_v_for_rel" : [ SenseInfo('00662589-v', 12), SenseInfo('00890590-v', 10), SenseInfo('00891216-v', 2), SenseInfo('02251065-v', 1), SenseInfo('00662589-v', 12), SenseInfo('00890590-v', 10), SenseInfo('00891216-v', 2), SenseInfo('02251065-v', 1) ],
"_roll_v_cause_rel" : [ SenseInfo('01866192-v', 22), SenseInfo('01887020-v', 10), SenseInfo('02687251-v', 7), SenseInfo('01391280-v', 6), SenseInfo('02198014-v', 2), SenseInfo('01522276-v', 2), SenseInfo('01526139-v', 1), SenseInfo('00143204-v', 1), SenseInfo('00100410-v', 1), SenseInfo('02322596-v', 0), SenseInfo('01901783-v', 0), SenseInfo('01881180-v', 0), SenseInfo('01875684-v', 0), SenseInfo('01866610-v', 0), SenseInfo('01055978-v', 0), SenseInfo('00324427-v', 0), SenseInfo('00125289-v', 0), SenseInfo('00125078-v', 0) ],
"_ship_v_out_rel" : [ SenseInfo('01950798-v', 7), SenseInfo('02409838-v', 0), SenseInfo('01979462-v', 0), SenseInfo('01847582-v', 0), SenseInfo('01496978-v', 0), SenseInfo('01950798-v', 7), SenseInfo('02409838-v', 0), SenseInfo('01979462-v', 0), SenseInfo('01847582-v', 0), SenseInfo('01496978-v', 0) ],
"_to+the+contrary_a_1_rel" : [  ],
"_murderer_n_1_rel" : [ SenseInfo('10338707-n', 12) ],
"_outcry_n_1_rel" : [ SenseInfo('07120524-n', 2) ],
"_bark_v_1_rel" : [ SenseInfo('01047596-v', 1), SenseInfo('01263904-v', 0), SenseInfo('01263784-v', 0), SenseInfo('01047745-v', 0), SenseInfo('00511763-v', 0) ],
"_essay_n_1_rel" : [ SenseInfo('06409562-n', 13), SenseInfo('00787218-n', 2) ],
"_unjust_a_for_rel" : [ SenseInfo('00957176-a', 1), SenseInfo('01370590-a', 0), SenseInfo('00958712-a', 0), SenseInfo('00957176-a', 1), SenseInfo('01370590-a', 0), SenseInfo('00958712-a', 0), SenseInfo('00957176-a', 1), SenseInfo('01370590-a', 0), SenseInfo('00958712-a', 0), SenseInfo('00957176-a', 1), SenseInfo('01370590-a', 0), SenseInfo('00958712-a', 0), SenseInfo('00957176-a', 1), SenseInfo('01370590-a', 0), SenseInfo('00958712-a', 0), SenseInfo('00957176-a', 1), SenseInfo('01370590-a', 0), SenseInfo('00958712-a', 0) ],
"_linguistic_a_1_rel" : [ SenseInfo('02842445-a', 4), SenseInfo('02843218-a', 3) ],
"_tandem_n_1_rel" : [ SenseInfo('05083567-n', 0), SenseInfo('02835271-n', 0) ],
"_course_v_1_rel" : [ SenseInfo('02067540-v', 0), SenseInfo('02066939-v', 0), SenseInfo('01144873-v', 0) ],
"_arise_v_from_rel" : [ SenseInfo('02624263-v', 29), SenseInfo('02625786-v', 9), SenseInfo('01983264-v', 8), SenseInfo('00339738-v', 7), SenseInfo('01968569-v', 1), SenseInfo('02583139-v', 0), SenseInfo('00018158-v', 0) ],
"_enquiry_n_1_rel" : [ SenseInfo('07193596-n', 0), SenseInfo('05797597-n', 0), SenseInfo('00636728-n', 0) ],
"_reusable_a_1_rel" : [ SenseInfo('02496425-a', 0) ],
"_robotics_n_1_rel" : [ SenseInfo('06133654-n', 0) ],
"_another_q_rel" : [  ],
"_glamor_n_1_rel" : [ SenseInfo('04685195-n', 1), SenseInfo('04685195-n', 1) ],
"_trailer_n_1_rel" : [ SenseInfo('09993252-n', 0), SenseInfo('06888674-n', 0), SenseInfo('04467307-n', 0), SenseInfo('04467099-n', 0) ],
"_batter_v_into_rel" : [ SenseInfo('01417705-v', 3), SenseInfo('01417416-v', 0), SenseInfo('00546609-v', 0), SenseInfo('01417705-v', 3), SenseInfo('01417416-v', 0), SenseInfo('00546609-v', 0) ],
"_sympathetic_a_1_rel" : [ SenseInfo('03008013-a', 13), SenseInfo('02374914-a', 8), SenseInfo('01372948-a', 1), SenseInfo('02376277-a', 0), SenseInfo('02072923-a', 0), SenseInfo('01163589-a', 0) ],
"_escarpment_n_1_rel" : [ SenseInfo('09274152-n', 0), SenseInfo('03296328-n', 0) ],
"_average_a_1_rel" : [ SenseInfo('01594146-a', 34), SenseInfo('00486290-a', 6), SenseInfo('01673061-a', 3), SenseInfo('01531957-a', 2), SenseInfo('01594811-a', 0), SenseInfo('01594472-a', 0) ],
"_seagull_n_1_rel" : [ SenseInfo('02041246-n', 1) ],
"_fiddle_v_1_rel" : [ SenseInfo('02463704-v', 0), SenseInfo('02292989-v', 0), SenseInfo('01733667-v', 0), SenseInfo('01724891-v', 0), SenseInfo('01586278-v', 0), SenseInfo('01586018-v', 0), SenseInfo('00261314-v', 0) ],
"_drape_v_cause_rel" : [ SenseInfo('01542525-v', 3), SenseInfo('01543000-v', 1), SenseInfo('01617034-v', 0), SenseInfo('01612487-v', 0) ],
"_primary_n_1_rel" : [ SenseInfo('00182571-n', 3), SenseInfo('02469080-n', 1), SenseInfo('09398769-n', 0), SenseInfo('04002629-n', 0) ],
"_hodge-podge_n_1_rel" : [ SenseInfo('08399977-n', 1), SenseInfo('05953416-n', 0), SenseInfo('08399977-n', 1), SenseInfo('05953416-n', 0), SenseInfo('08399977-n', 1), SenseInfo('05953416-n', 0) ],
"_ad+hoc_a_1_rel" : [ SenseInfo('01798371-a', 0), SenseInfo('01103529-a', 0), SenseInfo('01798371-a', 0), SenseInfo('01103529-a', 0) ],
"_reliance_n_on_rel" : [ SenseInfo('05697976-n', 2), SenseInfo('14001728-n', 1) ],
"_armada_n_1_rel" : [ SenseInfo('08293003-n', 0) ],
"_snowball_v_1_rel" : [ SenseInfo('00158384-v', 1), SenseInfo('01508166-v', 0) ],
"_spite_n_1_rel" : [ SenseInfo('07550666-n', 1), SenseInfo('04842515-n', 0) ],
"_despair_n_1_rel" : [ SenseInfo('14486274-n', 12), SenseInfo('07541923-n', 8) ],
"_exactly_x_deg_rel" : [ SenseInfo('00158309-r', 37), SenseInfo('00368663-r', 2), SenseInfo('00368287-r', 0) ],
"_dissatisfied_a_1_rel" : [ SenseInfo('00590163-a', 2) ],
"_dare_v_qmodal_rel" : [ SenseInfo('02374924-v', 11), SenseInfo('02545045-v', 10), SenseInfo('00868097-v', 3), SenseInfo('02374924-v', 11), SenseInfo('02545045-v', 10), SenseInfo('00868097-v', 3), SenseInfo('02374924-v', 11), SenseInfo('02545045-v', 10), SenseInfo('00868097-v', 3), SenseInfo('02374924-v', 11), SenseInfo('02545045-v', 10), SenseInfo('00868097-v', 3), SenseInfo('02374924-v', 11), SenseInfo('02545045-v', 10), SenseInfo('00868097-v', 3), SenseInfo('02374924-v', 11), SenseInfo('02545045-v', 10), SenseInfo('00868097-v', 3), SenseInfo('02374924-v', 11), SenseInfo('02545045-v', 10), SenseInfo('00868097-v', 3), SenseInfo('02374924-v', 11), SenseInfo('02545045-v', 10), SenseInfo('00868097-v', 3) ],
"_diagnostic_n_1_rel" : [ SenseInfo('02975538-a', 1), SenseInfo('00357254-a', 0), SenseInfo('02975538-a', 1), SenseInfo('00357254-a', 0), SenseInfo('02975538-a', 1), SenseInfo('00357254-a', 0) ],
"_turkey_n_1_rel" : [ SenseInfo('01794158-n', 2), SenseInfo('09039411-n', 1), SenseInfo('10224295-n', 0), SenseInfo('07647731-n', 0), SenseInfo('07365193-n', 0) ],
"_blush_v_1_rel" : [ SenseInfo('00103317-v', 9), SenseInfo('00289159-v', 0) ],
"_burn_v_cause_rel" : [ SenseInfo('00378664-v', 11), SenseInfo('02768874-v', 10), SenseInfo('00377002-v', 9), SenseInfo('02120451-v', 4), SenseInfo('02762468-v', 2), SenseInfo('01829292-v', 2), SenseInfo('00378042-v', 2), SenseInfo('02485322-v', 1), SenseInfo('02268881-v', 1), SenseInfo('02121048-v', 1), SenseInfo('00373766-v', 1), SenseInfo('00104299-v', 1), SenseInfo('01756277-v', 0), SenseInfo('01205000-v', 0), SenseInfo('00196364-v', 0) ],
"_pigging_n_1_rel" : [  ],
"_add+on_n_1_rel" : [ SenseInfo('02679415-n', 0), SenseInfo('02671421-n', 0), SenseInfo('02679415-n', 0), SenseInfo('02671421-n', 0) ],
"_sum_v_up_rel" : [ SenseInfo('02752695-v', 0), SenseInfo('00949288-v', 0), SenseInfo('02752695-v', 0), SenseInfo('00949288-v', 0) ],
"_deck_v_1_rel" : [ SenseInfo('02748927-v', 0), SenseInfo('01679980-v', 0), SenseInfo('01412346-v', 0) ],
"_dresser_n_1_rel" : [ SenseInfo('03015254-n', 1), SenseInfo('10033225-n', 0), SenseInfo('10033082-n', 0), SenseInfo('03238586-n', 0), SenseInfo('03237340-n', 0) ],
"_harbor_v_1_rel" : [ SenseInfo('01773130-v', 4), SenseInfo('02656189-v', 1), SenseInfo('02350065-v', 1), SenseInfo('02148604-v', 1), SenseInfo('01773130-v', 4), SenseInfo('02656189-v', 1), SenseInfo('02350065-v', 1), SenseInfo('02148604-v', 1) ],
"_evade_v_1_rel" : [ SenseInfo('00809654-v', 3), SenseInfo('02074377-v', 1), SenseInfo('02369811-v', 0), SenseInfo('00811039-v', 0) ],
"_kind_a_1_rel" : [ SenseInfo('01372049-a', 4), SenseInfo('01242282-a', 0), SenseInfo('01041209-a', 0) ],
"_lay_a_1_rel" : [ SenseInfo('02057226-a', 1), SenseInfo('01869975-a', 0) ],
"_give_v_up_rel" : [ SenseInfo('02316868-v', 179), SenseInfo('02339171-v', 160), SenseInfo('02199590-v', 96), SenseInfo('02235842-v', 78), SenseInfo('01060494-v', 32), SenseInfo('01733477-v', 29), SenseInfo('01060317-v', 24), SenseInfo('02200686-v', 20), SenseInfo('01629403-v', 18), SenseInfo('00732224-v', 18), SenseInfo('01629000-v', 16), SenseInfo('02296153-v', 14), SenseInfo('01647672-v', 14), SenseInfo('02200498-v', 12), SenseInfo('02562901-v', 10), SenseInfo('02343595-v', 10), SenseInfo('02230772-v', 10), SenseInfo('00887463-v', 8), SenseInfo('02309374-v', 5), SenseInfo('02309165-v', 5), SenseInfo('01060746-v', 5), SenseInfo('02317094-v', 4), SenseInfo('01848465-v', 4), SenseInfo('01178565-v', 4), SenseInfo('02308741-v', 3), SenseInfo('01989053-v', 1), SenseInfo('00673571-v', 1), SenseInfo('02564052-v', 0), SenseInfo('02359553-v', 0), SenseInfo('02358034-v', 0), SenseInfo('01716283-v', 0), SenseInfo('01716112-v', 0), SenseInfo('01449796-v', 0), SenseInfo('01175810-v', 0), SenseInfo('01069638-v', 0), SenseInfo('00944247-v', 0), SenseInfo('00888009-v', 0), SenseInfo('00878876-v', 0), SenseInfo('00771806-v', 0), SenseInfo('00748972-v', 0), SenseInfo('00748616-v', 0), SenseInfo('00341184-v', 0), SenseInfo('00108747-v', 0), SenseInfo('00108604-v', 0), SenseInfo('02316868-v', 179), SenseInfo('02339171-v', 160), SenseInfo('02199590-v', 96), SenseInfo('02235842-v', 78), SenseInfo('01060494-v', 32), SenseInfo('01733477-v', 29), SenseInfo('01060317-v', 24), SenseInfo('02200686-v', 20), SenseInfo('01629403-v', 18), SenseInfo('00732224-v', 18), SenseInfo('01629000-v', 16), SenseInfo('02296153-v', 14), SenseInfo('01647672-v', 14), SenseInfo('02200498-v', 12), SenseInfo('02562901-v', 10), SenseInfo('02343595-v', 10), SenseInfo('02230772-v', 10), SenseInfo('00887463-v', 8), SenseInfo('02309374-v', 5), SenseInfo('02309165-v', 5), SenseInfo('01060746-v', 5), SenseInfo('02317094-v', 4), SenseInfo('01848465-v', 4), SenseInfo('01178565-v', 4), SenseInfo('02308741-v', 3), SenseInfo('01989053-v', 1), SenseInfo('00673571-v', 1), SenseInfo('02564052-v', 0), SenseInfo('02359553-v', 0), SenseInfo('02358034-v', 0), SenseInfo('01716283-v', 0), SenseInfo('01716112-v', 0), SenseInfo('01449796-v', 0), SenseInfo('01175810-v', 0), SenseInfo('01069638-v', 0), SenseInfo('00944247-v', 0), SenseInfo('00888009-v', 0), SenseInfo('00878876-v', 0), SenseInfo('00771806-v', 0), SenseInfo('00748972-v', 0), SenseInfo('00748616-v', 0), SenseInfo('00341184-v', 0), SenseInfo('00108747-v', 0), SenseInfo('00108604-v', 0) ],
"_give_v_out-2_rel" : [ SenseInfo('02316868-v', 179), SenseInfo('02339171-v', 160), SenseInfo('02199590-v', 96), SenseInfo('02235842-v', 78), SenseInfo('01060494-v', 32), SenseInfo('01733477-v', 29), SenseInfo('01060317-v', 24), SenseInfo('02200686-v', 20), SenseInfo('01629403-v', 18), SenseInfo('00732224-v', 18), SenseInfo('01629000-v', 16), SenseInfo('02296153-v', 14), SenseInfo('01647672-v', 14), SenseInfo('02200498-v', 12), SenseInfo('02562901-v', 10), SenseInfo('02343595-v', 10), SenseInfo('02230772-v', 10), SenseInfo('00887463-v', 8), SenseInfo('02309374-v', 5), SenseInfo('02309165-v', 5), SenseInfo('01060746-v', 5), SenseInfo('02317094-v', 4), SenseInfo('01848465-v', 4), SenseInfo('01178565-v', 4), SenseInfo('02308741-v', 3), SenseInfo('01989053-v', 1), SenseInfo('00673571-v', 1), SenseInfo('02564052-v', 0), SenseInfo('02359553-v', 0), SenseInfo('02358034-v', 0), SenseInfo('01716283-v', 0), SenseInfo('01716112-v', 0), SenseInfo('01449796-v', 0), SenseInfo('01175810-v', 0), SenseInfo('01069638-v', 0), SenseInfo('00944247-v', 0), SenseInfo('00888009-v', 0), SenseInfo('00878876-v', 0), SenseInfo('00771806-v', 0), SenseInfo('00748972-v', 0), SenseInfo('00748616-v', 0), SenseInfo('00341184-v', 0), SenseInfo('00108747-v', 0), SenseInfo('00108604-v', 0) ],
"_jade_n_1_rel" : [ SenseInfo('14924602-n', 2), SenseInfo('09772930-n', 0), SenseInfo('04968749-n', 0), SenseInfo('02382204-n', 0) ],
"_carpool_n_1_rel" : [  ],
"_apocalyptic_a_1_rel" : [ SenseInfo('01882292-a', 1), SenseInfo('02633115-a', 0) ],
"_carry-out_n_1_rel" : [  ],
"_oppose_v_1_rel" : [ SenseInfo('00775831-v', 24), SenseInfo('01091427-v', 10), SenseInfo('02666531-v', 4), SenseInfo('01081152-v', 3), SenseInfo('02378623-v', 0), SenseInfo('00776059-v', 0) ],
"_asap_a_1_rel" : [  ],
"_preoccupy_v_1_rel" : [ SenseInfo('01783394-v', 1), SenseInfo('02273083-v', 0) ],
"_come_v_about_rel" : [ SenseInfo('01849221-v', 276), SenseInfo('02005948-v', 235), SenseInfo('00341917-v', 147), SenseInfo('00542120-v', 41), SenseInfo('02625339-v', 40), SenseInfo('00342812-v', 11), SenseInfo('02743921-v', 9), SenseInfo('02743214-v', 7), SenseInfo('02686805-v', 6), SenseInfo('02743565-v', 3), SenseInfo('01839690-v', 3), SenseInfo('02729963-v', 2), SenseInfo('00344886-v', 2), SenseInfo('02645007-v', 1), SenseInfo('02627363-v', 1), SenseInfo('02006709-v', 1), SenseInfo('00723349-v', 1), SenseInfo('02737187-v', 0), SenseInfo('02617567-v', 0), SenseInfo('02197360-v', 0), SenseInfo('00659984-v', 0) ],
"_pro+bono_a_1_rel" : [ SenseInfo('01710709-a', 0), SenseInfo('01710709-a', 0), SenseInfo('01710709-a', 0), SenseInfo('01710709-a', 0) ],
"_heyday_n_1_rel" : [ SenseInfo('15295045-n', 2) ],
"_needle_v_1_rel" : [ SenseInfo('00851733-v', 1), SenseInfo('01331027-v', 0) ],
"_prohibitive_a_1_rel" : [ SenseInfo('01765498-a', 0), SenseInfo('01765498-a', 0) ],
"_if+you+like_a_1_rel" : [  ],
"_embrace_n_1_rel" : [ SenseInfo('00417397-n', 2), SenseInfo('14427408-n', 1), SenseInfo('00180770-n', 0) ],
"_smuggle_v_1_rel" : [ SenseInfo('02345856-v', 3) ],
"_cease-and-desist_n_1_rel" : [  ],
"_amp_v_up_rel" : [  ],
"_pomp_n_1_rel" : [ SenseInfo('06880134-n', 0), SenseInfo('04815002-n', 0) ],
"_vegetarian_n_1_rel" : [ SenseInfo('10747119-n', 0) ],
"_print_v_1_rel" : [ SenseInfo('01745722-v', 12), SenseInfo('01746715-v', 1), SenseInfo('01749184-v', 0), SenseInfo('01747945-v', 0) ],
"_fight_v_off_rel" : [ SenseInfo('01090335-v', 112), SenseInfo('01091427-v', 34), SenseInfo('02407338-v', 8), SenseInfo('02589576-v', 5) ],
"_scarecrow_n_1_rel" : [ SenseInfo('04143712-n', 0), SenseInfo('04143712-n', 0) ],
"_adverb_n_1_rel" : [ SenseInfo('06319157-n', 3), SenseInfo('06323612-n', 0), SenseInfo('06319157-n', 3), SenseInfo('06323612-n', 0), SenseInfo('06319157-n', 3), SenseInfo('06323612-n', 0) ],
"_diagonal_n_1_rel" : [ SenseInfo('13904325-n', 0), SenseInfo('13904164-n', 0), SenseInfo('08270417-n', 0), SenseInfo('08268321-n', 0), SenseInfo('06844903-n', 0) ],
"_chromosome_n_1_rel" : [ SenseInfo('05442131-n', 0) ],
"_stream_n_of_rel" : [ SenseInfo('09448361-n', 20), SenseInfo('08461595-n', 4), SenseInfo('00329227-n', 3), SenseInfo('14005892-n', 2), SenseInfo('07406765-n', 2) ],
"_endowment_n_1_rel" : [ SenseInfo('05624042-n', 1), SenseInfo('13271320-n', 0), SenseInfo('01086744-n', 0) ],
"_scroll_v_1_rel" : [ SenseInfo('00124854-v', 0) ],
"_peripheral_n_1_rel" : [ SenseInfo('03916720-n', 0) ],
"_intrigue_v_1_rel" : [ SenseInfo('02678839-v', 1), SenseInfo('00707956-v', 0), SenseInfo('02678839-v', 1), SenseInfo('00707956-v', 0), SenseInfo('02678839-v', 1), SenseInfo('00707956-v', 0), SenseInfo('02678839-v', 1), SenseInfo('00707956-v', 0) ],
"_cut_v_up_rel" : [ SenseInfo('01552519-v', 58), SenseInfo('00429060-v', 18), SenseInfo('02033295-v', 3), SenseInfo('01610834-v', 2), SenseInfo('02422283-v', 1), SenseInfo('01754915-v', 1), SenseInfo('01666717-v', 1), SenseInfo('01413917-v', 1), SenseInfo('01064799-v', 1), SenseInfo('00201722-v', 1), SenseInfo('02613860-v', 0), SenseInfo('02588280-v', 0), SenseInfo('02134232-v', 0), SenseInfo('02101649-v', 0), SenseInfo('01915865-v', 0), SenseInfo('01915730-v', 0), SenseInfo('01860107-v', 0), SenseInfo('01859995-v', 0), SenseInfo('01756563-v', 0), SenseInfo('01756416-v', 0), SenseInfo('01756277-v', 0), SenseInfo('01754737-v', 0), SenseInfo('01713491-v', 0), SenseInfo('01611123-v', 0), SenseInfo('01610990-v', 0), SenseInfo('01555437-v', 0), SenseInfo('01510576-v', 0), SenseInfo('01320424-v', 0), SenseInfo('01319738-v', 0), SenseInfo('01227088-v', 0), SenseInfo('01059564-v', 0), SenseInfo('00561090-v', 0), SenseInfo('00473322-v', 0), SenseInfo('00447654-v', 0), SenseInfo('00429968-v', 0), SenseInfo('00292507-v', 0), SenseInfo('00243900-v', 0), SenseInfo('00226071-v', 0), SenseInfo('00108475-v', 0), SenseInfo('00096136-v', 0), SenseInfo('00061219-v', 0) ],
"_supplementary_a_1_rel" : [ SenseInfo('01854129-a', 1), SenseInfo('00049879-a', 0) ],
"_formalism_n_1_rel" : [ SenseInfo('05961867-n', 2), SenseInfo('05971621-n', 0), SenseInfo('00411717-n', 0) ],
"_fang_n_1_rel" : [ SenseInfo('06992929-n', 0), SenseInfo('01785234-n', 0), SenseInfo('01465593-n', 0), SenseInfo('01465472-n', 0) ],
"_restrictive_a_1_rel" : [ SenseInfo('02003725-a', 1), SenseInfo('01888941-a', 1) ],
"_happen_v_upon_rel" : [ SenseInfo('00339934-v', 149), SenseInfo('00344643-v', 20), SenseInfo('02593912-v', 17), SenseInfo('00344174-v', 9), SenseInfo('02248465-v', 0) ],
"_ineffective_a_1_rel" : [ SenseInfo('00835609-a', 0), SenseInfo('01825080-a', 0), SenseInfo('00511739-a', 0), SenseInfo('00835609-a', 0), SenseInfo('01825080-a', 0), SenseInfo('00511739-a', 0) ],
"_recyclable_a_1_rel" : [ SenseInfo('02496425-a', 0) ],
"_insufficient_a_1_rel" : [ SenseInfo('02336449-a', 3) ],
"_commercial_n_1_rel" : [ SenseInfo('07250034-n', 4) ],
"_rib_v_1_rel" : [ SenseInfo('01671755-v', 0), SenseInfo('00851933-v', 0) ],
"_not+quite_x_deg_rel" : [ SenseInfo('00018781-r', 57), SenseInfo('00018577-r', 47), SenseInfo('00018918-r', 6), SenseInfo('00019181-r', 0), SenseInfo('00018781-r', 57), SenseInfo('00018577-r', 47), SenseInfo('00018918-r', 6), SenseInfo('00019181-r', 0) ],
"_multimedia_n_1_rel" : [ SenseInfo('06261744-n', 0) ],
"_birds+eye_a_1_rel" : [  ],
"_uncouth_a_1_rel" : [ SenseInfo('01950198-a', 0) ],
"_inhalable_a_1_rel" : [  ],
"_whos+who_n_1_rel" : [  ],
"_from_p_sel_rel" : [  ],
"_medieval_a_1_rel" : [ SenseInfo('02989754-a', 11), SenseInfo('01537448-a', 1), SenseInfo('01729157-a', 0), SenseInfo('02989754-a', 11), SenseInfo('01537448-a', 1), SenseInfo('01729157-a', 0) ],
"_excuse_v_from_rel" : [ SenseInfo('00905852-v', 2), SenseInfo('00893878-v', 2), SenseInfo('00893435-v', 2), SenseInfo('00894738-v', 1), SenseInfo('00894221-v', 0), SenseInfo('00893167-v', 0), SenseInfo('00905852-v', 2), SenseInfo('00893878-v', 2), SenseInfo('00893435-v', 2), SenseInfo('00894738-v', 1), SenseInfo('00894221-v', 0), SenseInfo('00893167-v', 0), SenseInfo('00905852-v', 2), SenseInfo('00893878-v', 2), SenseInfo('00893435-v', 2), SenseInfo('00894738-v', 1), SenseInfo('00894221-v', 0), SenseInfo('00893167-v', 0) ],
"_to+the+best+of+our+knowledge_a_1_rel" : [  ],
"_prove_v_to_rel" : [ SenseInfo('02633881-v', 58), SenseInfo('00664788-v', 45), SenseInfo('01015244-v', 6), SenseInfo('00665630-v', 4), SenseInfo('02531625-v', 0), SenseInfo('01983134-v', 0), SenseInfo('01975587-v', 0), SenseInfo('01745052-v', 0), SenseInfo('00665771-v', 0), SenseInfo('02633881-v', 58), SenseInfo('00664788-v', 45), SenseInfo('01015244-v', 6), SenseInfo('00665630-v', 4), SenseInfo('02531625-v', 0), SenseInfo('01983134-v', 0), SenseInfo('01975587-v', 0), SenseInfo('01745052-v', 0), SenseInfo('00665771-v', 0), SenseInfo('02633881-v', 58), SenseInfo('00664788-v', 45), SenseInfo('01015244-v', 6), SenseInfo('00665630-v', 4), SenseInfo('02531625-v', 0), SenseInfo('01983134-v', 0), SenseInfo('01975587-v', 0), SenseInfo('01745052-v', 0), SenseInfo('00665771-v', 0), SenseInfo('02633881-v', 58), SenseInfo('00664788-v', 45), SenseInfo('01015244-v', 6), SenseInfo('00665630-v', 4), SenseInfo('02531625-v', 0), SenseInfo('01983134-v', 0), SenseInfo('01975587-v', 0), SenseInfo('01745052-v', 0), SenseInfo('00665771-v', 0), SenseInfo('02633881-v', 58), SenseInfo('00664788-v', 45), SenseInfo('01015244-v', 6), SenseInfo('00665630-v', 4), SenseInfo('02531625-v', 0), SenseInfo('01983134-v', 0), SenseInfo('01975587-v', 0), SenseInfo('01745052-v', 0), SenseInfo('00665771-v', 0), SenseInfo('02633881-v', 58), SenseInfo('00664788-v', 45), SenseInfo('01015244-v', 6), SenseInfo('00665630-v', 4), SenseInfo('02531625-v', 0), SenseInfo('01983134-v', 0), SenseInfo('01975587-v', 0), SenseInfo('01745052-v', 0), SenseInfo('00665771-v', 0), SenseInfo('02633881-v', 58), SenseInfo('00664788-v', 45), SenseInfo('01015244-v', 6), SenseInfo('00665630-v', 4), SenseInfo('02531625-v', 0), SenseInfo('01983134-v', 0), SenseInfo('01975587-v', 0), SenseInfo('01745052-v', 0), SenseInfo('00665771-v', 0) ],
"_dispose_v_of_rel" : [ SenseInfo('02354922-v', 3), SenseInfo('02222318-v', 3), SenseInfo('00680841-v', 2), SenseInfo('01496497-v', 0), SenseInfo('00300761-v', 0) ],
"_round_v_1_rel" : [ SenseInfo('01858910-v', 3), SenseInfo('00145147-v', 1), SenseInfo('00980339-v', 0), SenseInfo('00862683-v', 0), SenseInfo('00473799-v', 0), SenseInfo('00145623-v', 0), SenseInfo('00046382-v', 0) ],
"_hiker_n_1_rel" : [ SenseInfo('10176111-n', 0) ],
"_peal_n_1_rel" : [ SenseInfo('07389330-n', 1) ],
"_back_p_sel_rel" : [ SenseInfo('00075161-r', 91), SenseInfo('05558717-n', 53), SenseInfo('00074407-r', 36), SenseInfo('00075269-r', 24), SenseInfo('00197576-a', 15), SenseInfo('00074201-r', 15), SenseInfo('00075367-r', 14), SenseInfo('04059701-n', 12), SenseInfo('02453889-v', 7), SenseInfo('01997119-v', 6), SenseInfo('08625846-n', 4), SenseInfo('02556817-v', 4), SenseInfo('01997512-v', 4), SenseInfo('02217695-v', 2), SenseInfo('00074964-r', 1), SenseInfo('00131692-a', 1), SenseInfo('09830194-n', 0), SenseInfo('05588174-n', 0), SenseInfo('02840619-n', 0), SenseInfo('02767665-n', 0), SenseInfo('02767433-n', 0), SenseInfo('00725775-n', 0), SenseInfo('00668816-a', 0), SenseInfo('02693965-v', 0), SenseInfo('01139104-v', 0), SenseInfo('00560628-v', 0), SenseInfo('00223109-v', 0), SenseInfo('00185857-v', 0) ],
"_analyte_n_1_rel" : [  ],
"_toolhouse_n_1_rel" : [ SenseInfo('04452757-n', 0) ],
"_credibility_n_1_rel" : [ SenseInfo('04782878-n', 0) ],
"_flex_v_cause_rel" : [ SenseInfo('02036977-v', 1), SenseInfo('02142280-v', 0), SenseInfo('02035919-v', 0), SenseInfo('01280488-v', 0), SenseInfo('01280014-v', 0) ],
"_tilma_n_1_rel" : [  ],
"_kick_v_in_rel" : [ SenseInfo('01371756-v', 11), SenseInfo('01936233-v', 9), SenseInfo('01370561-v', 7), SenseInfo('02048511-v', 0), SenseInfo('01371454-v', 0), SenseInfo('01196524-v', 0), SenseInfo('01112979-v', 0), SenseInfo('00907147-v', 0), SenseInfo('01371756-v', 11), SenseInfo('01936233-v', 9), SenseInfo('01370561-v', 7), SenseInfo('02048511-v', 0), SenseInfo('01371454-v', 0), SenseInfo('01196524-v', 0), SenseInfo('01112979-v', 0), SenseInfo('00907147-v', 0) ],
"_asthma_n_1_rel" : [ SenseInfo('14145911-n', 0) ],
"_roller+skate_v_1_rel" : [ SenseInfo('01937534-v', 0), SenseInfo('01937534-v', 0) ],
"_go-ahead_n_1_rel" : [ SenseInfo('06874391-n', 0), SenseInfo('04836074-n', 0), SenseInfo('06874391-n', 0), SenseInfo('04836074-n', 0) ],
"_hypertension_n_1_rel" : [ SenseInfo('14103510-n', 0) ],
"_would+that_x_rel" : [  ],
"_snatch_v_at_rel" : [ SenseInfo('01439745-v', 13), SenseInfo('01213146-v', 1), SenseInfo('01471043-v', 0) ],
"_hollow_a_1_rel" : [ SenseInfo('02263982-a', 1), SenseInfo('02010127-a', 1), SenseInfo('01498084-a', 1), SenseInfo('02263982-a', 1), SenseInfo('02010127-a', 1), SenseInfo('01498084-a', 1), SenseInfo('02263982-a', 1), SenseInfo('02010127-a', 1), SenseInfo('01498084-a', 1) ],
"_hawk_v_1_rel" : [ SenseInfo('02302817-v', 2), SenseInfo('01145612-v', 0), SenseInfo('00035089-v', 0) ],
"_beaver_n_1_rel" : [ SenseInfo('14764617-n', 0), SenseInfo('09745229-n', 0), SenseInfo('05262120-n', 0), SenseInfo('03237416-n', 0), SenseInfo('02818254-n', 0), SenseInfo('02818135-n', 0), SenseInfo('02363005-n', 0) ],
"_counterfeit_v_1_rel" : [ SenseInfo('01654271-v', 0) ],
"_ravine_n_1_rel" : [ SenseInfo('09405787-n', 0) ],
"_injured_n_1_rel" : [ SenseInfo('01317954-a', 7) ],
"_cam_n_1_rel" : [ SenseInfo('09231587-n', 0), SenseInfo('02941716-n', 0) ],
"_investigate_v_1_rel" : [ SenseInfo('00789138-v', 17), SenseInfo('00785962-v', 11), SenseInfo('00789138-v', 17), SenseInfo('00785962-v', 11) ],
"_spit_v_1_rel" : [ SenseInfo('00101956-v', 11), SenseInfo('01045318-v', 1), SenseInfo('02757828-v', 0), SenseInfo('01444563-v', 0), SenseInfo('00101956-v', 11), SenseInfo('01045318-v', 1), SenseInfo('02757828-v', 0), SenseInfo('01444563-v', 0) ],
"_extended_a_1_rel" : [ SenseInfo('01439155-a', 4), SenseInfo('01431638-a', 1), SenseInfo('01434218-a', 0), SenseInfo('01419638-a', 0), SenseInfo('01386234-a', 0) ],
"_stroller_n_1_rel" : [ SenseInfo('10553235-n', 0), SenseInfo('02766534-n', 0) ],
"_geologist_n_1_rel" : [ SenseInfo('10127689-n', 2) ],
"_monarchist_n_1_rel" : [ SenseInfo('10327824-n', 0) ],
"_coating_n_of_rel" : [ SenseInfo('03058107-n', 1), SenseInfo('04700642-n', 0), SenseInfo('03058603-n', 0), SenseInfo('00712225-n', 0) ],
"_neurological_a_1_rel" : [ SenseInfo('02917893-a', 1) ],
"_unconscious_a_of_rel" : [ SenseInfo('00571643-a', 5), SenseInfo('02521998-a', 1), SenseInfo('00192332-a', 1), SenseInfo('00571643-a', 5), SenseInfo('02521998-a', 1), SenseInfo('00192332-a', 1) ],
"_unconcentrated_a_1_rel" : [  ],
"_nay_a_1_rel" : [ SenseInfo('07205210-n', 1) ],
"_unending_a_1_rel" : [ SenseInfo('01755024-a', 1), SenseInfo('01755024-a', 1) ],
"_developmental_a_1_rel" : [ SenseInfo('02945820-a', 4) ],
"_show_n_1_rel" : [ SenseInfo('00520257-n', 18), SenseInfo('06879521-n', 9), SenseInfo('06619065-n', 0), SenseInfo('00755277-n', 0) ],
"_amphibian_n_1_rel" : [ SenseInfo('02704792-n', 0), SenseInfo('02704645-n', 0), SenseInfo('01627424-n', 0) ],
"_frown_v_at_rel" : [ SenseInfo('00032981-v', 12) ],
"_mustache_n_1_rel" : [ SenseInfo('05262185-n', 6), SenseInfo('05262185-n', 6) ],
"_scroll_v_cause_rel" : [ SenseInfo('00124854-v', 0) ],
"_button_n_1_rel" : [ SenseInfo('02928608-n', 8), SenseInfo('04027023-n', 6), SenseInfo('11531916-n', 0), SenseInfo('07268413-n', 0), SenseInfo('05523420-n', 0), SenseInfo('04073425-n', 0), SenseInfo('02928841-n', 0) ],
"_concentrate_n_1_rel" : [ SenseInfo('14837506-n', 3), SenseInfo('07567390-n', 1), SenseInfo('05937878-n', 1) ],
"_listless_a_1_rel" : [ SenseInfo('00876465-a', 1), SenseInfo('02281938-a', 0) ],
"_gamecock_n_1_rel" : [ SenseInfo('01514752-n', 1), SenseInfo('10169678-n', 0) ],
"_imprecation_n_1_rel" : [ SenseInfo('07233996-n', 4), SenseInfo('07236957-n', 0) ],
"_zero_v_1_rel" : [ SenseInfo('00297507-v', 0), SenseInfo('00297333-v', 0) ],
"_incentive_n_to_rel" : [ SenseInfo('09179776-n', 5), SenseInfo('13273154-n', 1), SenseInfo('09179776-n', 5), SenseInfo('13273154-n', 1), SenseInfo('09179776-n', 5), SenseInfo('13273154-n', 1), SenseInfo('09179776-n', 5), SenseInfo('13273154-n', 1), SenseInfo('09179776-n', 5), SenseInfo('13273154-n', 1), SenseInfo('09179776-n', 5), SenseInfo('13273154-n', 1) ],
"_consummate_a_1_rel" : [ SenseInfo('02226979-a', 0), SenseInfo('01750386-a', 0), SenseInfo('01520091-a', 0) ],
"_stony_a_1_rel" : [ SenseInfo('02241988-a', 0), SenseInfo('01158180-a', 0), SenseInfo('01151951-a', 0), SenseInfo('02241988-a', 0), SenseInfo('01158180-a', 0), SenseInfo('01151951-a', 0), SenseInfo('02241988-a', 0), SenseInfo('01158180-a', 0), SenseInfo('01151951-a', 0) ],
"_tempt_v_1_rel" : [ SenseInfo('00793785-v', 4), SenseInfo('00782527-v', 4), SenseInfo('01807529-v', 1), SenseInfo('00776523-v', 1), SenseInfo('01807770-v', 0), SenseInfo('00784184-v', 0), SenseInfo('00793785-v', 4), SenseInfo('00782527-v', 4), SenseInfo('01807529-v', 1), SenseInfo('00776523-v', 1), SenseInfo('01807770-v', 0), SenseInfo('00784184-v', 0), SenseInfo('00793785-v', 4), SenseInfo('00782527-v', 4), SenseInfo('01807529-v', 1), SenseInfo('00776523-v', 1), SenseInfo('01807770-v', 0), SenseInfo('00784184-v', 0), SenseInfo('00793785-v', 4), SenseInfo('00782527-v', 4), SenseInfo('01807529-v', 1), SenseInfo('00776523-v', 1), SenseInfo('01807770-v', 0), SenseInfo('00784184-v', 0), SenseInfo('00793785-v', 4), SenseInfo('00782527-v', 4), SenseInfo('01807529-v', 1), SenseInfo('00776523-v', 1), SenseInfo('01807770-v', 0), SenseInfo('00784184-v', 0) ],
"_collateral_n_1_rel" : [ SenseInfo('13352865-n', 0) ],
"_discomfort_n_1_rel" : [ SenseInfo('14446652-n', 3), SenseInfo('07495973-n', 0) ],
"_intro_n_1_rel" : [ SenseInfo('07217349-n', 0), SenseInfo('07045245-n', 0) ],
"_boxwood_n_1_rel" : [ SenseInfo('12746474-n', 0), SenseInfo('12746106-n', 0) ],
"_try_n_1_rel" : [ SenseInfo('00786195-n', 5) ],
"_fuse_n_1_rel" : [ SenseInfo('03407369-n', 1), SenseInfo('03407122-n', 0) ],
"_reflexive_a_1_rel" : [ SenseInfo('02522669-a', 0), SenseInfo('00202508-a', 0), SenseInfo('02522669-a', 0), SenseInfo('00202508-a', 0) ],
"_little_a_1_rel" : [ SenseInfo('01391351-a', 163), SenseInfo('01554510-a', 71), SenseInfo('01649031-a', 12), SenseInfo('01280908-a', 8), SenseInfo('01455732-a', 3), SenseInfo('02386612-a', 0), SenseInfo('01467534-a', 0), SenseInfo('00855670-a', 0), SenseInfo('01391351-a', 163), SenseInfo('01554510-a', 71), SenseInfo('01649031-a', 12), SenseInfo('01280908-a', 8), SenseInfo('01455732-a', 3), SenseInfo('02386612-a', 0), SenseInfo('01467534-a', 0), SenseInfo('00855670-a', 0), SenseInfo('01391351-a', 163), SenseInfo('01554510-a', 71), SenseInfo('01649031-a', 12), SenseInfo('01280908-a', 8), SenseInfo('01455732-a', 3), SenseInfo('02386612-a', 0), SenseInfo('01467534-a', 0), SenseInfo('00855670-a', 0), SenseInfo('01391351-a', 163), SenseInfo('01554510-a', 71), SenseInfo('01649031-a', 12), SenseInfo('01280908-a', 8), SenseInfo('01455732-a', 3), SenseInfo('02386612-a', 0), SenseInfo('01467534-a', 0), SenseInfo('00855670-a', 0) ],
"_streak_n_of_rel" : [ SenseInfo('08460585-n', 1), SenseInfo('04920435-n', 1), SenseInfo('04683136-n', 1), SenseInfo('07413629-n', 0) ],
"_flora_n_1_rel" : [ SenseInfo('08436759-n', 0), SenseInfo('00017222-n', 0) ],
"_dues_n_1_rel" : [ SenseInfo('05176082-n', 4), SenseInfo('13396861-n', 0), SenseInfo('05176082-n', 4), SenseInfo('13396861-n', 0) ],
"_concerned_a_with_rel" : [ SenseInfo('00543603-a', 15), SenseInfo('01515692-a', 12), SenseInfo('01516346-a', 0) ],
"_disrupt_v_1_rel" : [ SenseInfo('00778275-v', 5), SenseInfo('00554298-v', 2), SenseInfo('00520357-v', 0) ],
"_cold_n_1_rel" : [ SenseInfo('14145501-n', 5), SenseInfo('05015117-n', 5), SenseInfo('05725676-n', 0) ],
"_parlor_n_1_rel" : [ SenseInfo('03891538-n', 8), SenseInfo('03679712-n', 1) ],
"_hatter_n_1_rel" : [ SenseInfo('10162354-n', 0) ],
"_acquaint_v_1_rel" : [ SenseInfo('00901103-v', 1), SenseInfo('00874175-v', 1), SenseInfo('00832778-v', 0), SenseInfo('00901103-v', 1), SenseInfo('00874175-v', 1), SenseInfo('00832778-v', 0) ],
"_fun_n_1_rel" : [ SenseInfo('00429949-n', 9), SenseInfo('06780882-n', 3), SenseInfo('01260556-n', 1), SenseInfo('04649261-n', 0) ],
"_glutinous_a_1_rel" : [ SenseInfo('00053691-a', 0) ],
"_swerve_v_1_rel" : [ SenseInfo('02033295-v', 4) ],
"_miracle_n_1_rel" : [ SenseInfo('07289481-n', 7), SenseInfo('07288801-n', 1) ],
"_gubernatorial_a_1_rel" : [ SenseInfo('02983978-a', 1) ],
"_gout_n_1_rel" : [ SenseInfo('14188804-n', 1) ],
"_configure_v_1_rel" : [ SenseInfo('01657641-v', 0), SenseInfo('01657641-v', 0) ],
"_bait_v_1_rel" : [ SenseInfo('00850501-v', 1), SenseInfo('02577877-v', 0), SenseInfo('01114911-v', 0) ],
"_tractor_n_1_rel" : [ SenseInfo('04465501-n', 3), SenseInfo('04465666-n', 0) ],
"_do_v_about_rel" : [ SenseInfo('02560585-v', 526), SenseInfo('01712704-v', 173), SenseInfo('02561995-v', 134), SenseInfo('02617567-v', 58), SenseInfo('01645601-v', 35), SenseInfo('02568672-v', 20), SenseInfo('02669789-v', 11), SenseInfo('01619014-v', 9), SenseInfo('00010435-v', 3), SenseInfo('02709107-v', 2), SenseInfo('02523221-v', 2), SenseInfo('00038849-v', 2), SenseInfo('01841772-v', 1) ],
"_underwriter_n_1_rel" : [ SenseInfo('10215953-n', 0), SenseInfo('10209731-n', 0), SenseInfo('08070465-n', 0) ],
"_preeminent_a_1_rel" : [ SenseInfo('02339341-a', 1), SenseInfo('02339341-a', 1) ],
"_lecherous_a_1_rel" : [ SenseInfo('02133431-a', 0) ],
"_whisk_n_1_rel" : [ SenseInfo('04578934-n', 0), SenseInfo('04578801-n', 0) ],
"_unfair_a_to_rel" : [ SenseInfo('00957176-a', 1), SenseInfo('00957176-a', 1), SenseInfo('00957176-a', 1), SenseInfo('00957176-a', 1) ],
"_green_v_cause_rel" : [ SenseInfo('00521478-v', 0) ],
"_australian_a_1_rel" : [ SenseInfo('03045750-a', 0) ],
"_grip_v_1_rel" : [ SenseInfo('01224001-v', 10), SenseInfo('01574292-v', 3), SenseInfo('01821132-v', 2), SenseInfo('01224001-v', 10), SenseInfo('01574292-v', 3), SenseInfo('01821132-v', 2) ],
"_lease_v_to_rel" : [ SenseInfo('02460199-v', 2), SenseInfo('02460619-v', 0), SenseInfo('02208903-v', 0), SenseInfo('02208537-v', 0) ],
"_momentary_a_1_rel" : [ SenseInfo('01443097-a', 3), SenseInfo('01443097-a', 3) ],
"_flush_v_1_rel" : [ SenseInfo('00103317-v', 3), SenseInfo('00455212-v', 2), SenseInfo('02199435-v', 0), SenseInfo('01307142-v', 0), SenseInfo('00455529-v', 0), SenseInfo('00455368-v', 0), SenseInfo('00454868-v', 0) ],
"_fond_a_1_rel" : [ SenseInfo('01464700-a', 3), SenseInfo('01464433-a', 1), SenseInfo('01292683-a', 1), SenseInfo('02571903-a', 0) ],
"_caller_n_of_rel" : [ SenseInfo('09887850-n', 3), SenseInfo('09888978-n', 0), SenseInfo('09888832-n', 0), SenseInfo('09888635-n', 0), SenseInfo('09888429-n', 0), SenseInfo('09888269-n', 0), SenseInfo('09888017-n', 0) ],
"_eats_n_1_rel" : [ SenseInfo('07565161-n', 0), SenseInfo('07565161-n', 0) ],
"_flake_v_1_rel" : [ SenseInfo('01585276-v', 1), SenseInfo('01336440-v', 0), SenseInfo('01259951-v', 0) ],
"_put_v_by_rel" : [ SenseInfo('01494310-v', 138), SenseInfo('01493741-v', 98), SenseInfo('00981276-v', 28), SenseInfo('01160370-v', 6), SenseInfo('02271137-v', 3), SenseInfo('00673448-v', 2), SenseInfo('02111499-v', 0), SenseInfo('01706375-v', 0), SenseInfo('00735571-v', 0) ],
"_synch_v_with_rel" : [  ],
"_desire_n_for_rel" : [ SenseInfo('07484265-n', 32), SenseInfo('04945057-n', 9), SenseInfo('14038993-n', 2), SenseInfo('07484265-n', 32), SenseInfo('04945057-n', 9), SenseInfo('14038993-n', 2), SenseInfo('07484265-n', 32), SenseInfo('04945057-n', 9), SenseInfo('14038993-n', 2), SenseInfo('07484265-n', 32), SenseInfo('04945057-n', 9), SenseInfo('14038993-n', 2), SenseInfo('07484265-n', 32), SenseInfo('04945057-n', 9), SenseInfo('14038993-n', 2) ],
"_down-to-earth_a_1_rel" : [ SenseInfo('01940472-a', 0), SenseInfo('01940472-a', 0) ],
"_undefined_a_1_rel" : [ SenseInfo('00697389-a', 0), SenseInfo('00697389-a', 0) ],
"_prioritize_v_1_rel" : [ SenseInfo('00660381-v', 0), SenseInfo('00660381-v', 0) ],
"_restrict_v_to_rel" : [ SenseInfo('00236592-v', 9), SenseInfo('02509287-v', 5), SenseInfo('00233335-v', 4), SenseInfo('00199309-v', 2), SenseInfo('00236592-v', 9), SenseInfo('02509287-v', 5), SenseInfo('00233335-v', 4), SenseInfo('00199309-v', 2), SenseInfo('00236592-v', 9), SenseInfo('02509287-v', 5), SenseInfo('00233335-v', 4), SenseInfo('00199309-v', 2), SenseInfo('00236592-v', 9), SenseInfo('02509287-v', 5), SenseInfo('00233335-v', 4), SenseInfo('00199309-v', 2) ],
"_russian_n_1_rel" : [ SenseInfo('09728403-n', 6), SenseInfo('06944348-n', 4) ],
"_lakeside_n_1_rel" : [ SenseInfo('09332890-n', 0) ],
"_disciple_v_1_rel" : [  ],
"_attendee_n_1_rel" : [ SenseInfo('09608002-n', 0) ],
"_follow_v_i_rel" : [ SenseInfo('01998432-v', 74), SenseInfo('02712772-v', 50), SenseInfo('02720149-v', 26), SenseInfo('01991931-v', 20), SenseInfo('02542280-v', 18), SenseInfo('02720354-v', 17), SenseInfo('00150776-v', 13), SenseInfo('02720544-v', 12), SenseInfo('02346895-v', 9), SenseInfo('02720697-v', 8), SenseInfo('01744450-v', 8), SenseInfo('00729109-v', 4), SenseInfo('02455407-v', 3), SenseInfo('02406585-v', 2), SenseInfo('01728355-v', 1), SenseInfo('00118764-v', 1), SenseInfo('02625339-v', 0), SenseInfo('02600255-v', 0), SenseInfo('02561697-v', 0), SenseInfo('02445925-v', 0), SenseInfo('02198602-v', 0), SenseInfo('02000868-v', 0), SenseInfo('00589738-v', 0), SenseInfo('00351406-v', 0) ],
"_digit_n_1_rel" : [ SenseInfo('13741022-n', 0), SenseInfo('13653461-n', 0), SenseInfo('05566097-n', 0) ],
"_draughts_n_1_rel" : [ SenseInfo('07883980-n', 2), SenseInfo('00840189-n', 1), SenseInfo('11522448-n', 0), SenseInfo('05135155-n', 0), SenseInfo('03230670-n', 0), SenseInfo('00115667-n', 0) ],
"_unfasten_v_cause_rel" : [ SenseInfo('01344293-v', 1), SenseInfo('01344140-v', 0) ],
"_branch_n_of_rel" : [ SenseInfo('08401248-n', 19), SenseInfo('13163250-n', 15), SenseInfo('13913849-n', 5), SenseInfo('11415721-n', 0), SenseInfo('09228324-n', 0), SenseInfo('02737833-n', 0) ],
"_table_n_1_rel" : [ SenseInfo('08266235-n', 52), SenseInfo('04379243-n', 25), SenseInfo('04379964-n', 5), SenseInfo('09351905-n', 0), SenseInfo('08480135-n', 0), SenseInfo('07565259-n', 0) ],
"_ride_v_up_rel" : [ SenseInfo('01957529-v', 53), SenseInfo('01955984-v', 30), SenseInfo('02684644-v', 2), SenseInfo('01839538-v', 2), SenseInfo('00850501-v', 1), SenseInfo('02750154-v', 0), SenseInfo('02742232-v', 0), SenseInfo('02711987-v', 0), SenseInfo('02692089-v', 0), SenseInfo('02102398-v', 0), SenseInfo('02095545-v', 0), SenseInfo('01847676-v', 0), SenseInfo('01511134-v', 0), SenseInfo('01429322-v', 0) ],
"_bombing_n_1_rel" : [ SenseInfo('00978413-n', 2), SenseInfo('00979742-n', 0) ],
"_pollution_n_of_rel" : [ SenseInfo('14516743-n', 1), SenseInfo('14498404-n', 0), SenseInfo('00276987-n', 0) ],
"_deduction_n_1_rel" : [ SenseInfo('13329047-n', 12), SenseInfo('13274597-n', 1), SenseInfo('05780885-n', 1), SenseInfo('05774129-n', 1), SenseInfo('00360757-n', 1), SenseInfo('00362103-n', 0) ],
"_parcel_n_of_rel" : [ SenseInfo('03871083-n', 1), SenseInfo('01085098-n', 1), SenseInfo('08673395-n', 0), SenseInfo('08008017-n', 0) ],
"_myriad_a_1_rel" : [ SenseInfo('00301951-a', 3) ],
"_observance_n_of_rel" : [ SenseInfo('00879759-n', 1), SenseInfo('07450842-n', 0), SenseInfo('05703429-n', 0), SenseInfo('01204419-n', 0) ],
"_geminate_a_1_rel" : [ SenseInfo('07119776-n', 0) ],
"_dispel_v_1_rel" : [ SenseInfo('02002720-v', 10), SenseInfo('02030424-v', 0) ],
"_clip_n_1_rel" : [ SenseInfo('02973017-n', 2), SenseInfo('07309599-n', 1), SenseInfo('03043958-n', 1), SenseInfo('03044166-n', 0), SenseInfo('00359614-n', 0), SenseInfo('00133234-n', 0) ],
"_honduran_n_1_rel" : [ SenseInfo('09712570-n', 0) ],
"_curry_v_i_rel" : [ SenseInfo('02192225-v', 0), SenseInfo('00516294-v', 0), SenseInfo('00045639-v', 0) ],
"_oxidant_n_1_rel" : [ SenseInfo('14780040-n', 0) ],
"_foreboding_n_1_rel" : [ SenseInfo('07522128-n', 1), SenseInfo('07286905-n', 0) ],
"_covetousness_n_1_rel" : [ SenseInfo('07549979-n', 1), SenseInfo('04945758-n', 0), SenseInfo('00758525-n', 0) ],
"_although_x_rel" : [  ],
"_snowmobile_n_1_rel" : [ SenseInfo('04252077-n', 0), SenseInfo('04252077-n', 0) ],
"_tumor_n_1_rel" : [ SenseInfo('14235200-n', 18), SenseInfo('14235200-n', 18) ],
"_smash_n_1_rel" : [ SenseInfo('07410207-n', 2), SenseInfo('07317369-n', 0), SenseInfo('00569474-n', 0), SenseInfo('00126236-n', 0), SenseInfo('00064504-n', 0) ],
"_stupidity_n_1_rel" : [ SenseInfo('05645597-n', 5), SenseInfo('01248075-n', 1) ],
"_panel_v_1_rel" : [ SenseInfo('01678519-v', 1), SenseInfo('00625963-v', 0) ],
"_grill_v_1_rel" : [ SenseInfo('00326773-v', 1), SenseInfo('00788821-v', 0) ],
"_gang_n_of_rel" : [ SenseInfo('08244062-n', 7), SenseInfo('08273843-n', 2), SenseInfo('08242799-n', 1), SenseInfo('03415363-n', 0) ],
"_hill_n_1_rel" : [ SenseInfo('09303008-n', 33), SenseInfo('03792048-n', 1), SenseInfo('11050057-n', 0), SenseInfo('11049938-n', 0), SenseInfo('03792334-n', 0), SenseInfo('09303008-n', 33), SenseInfo('03792048-n', 1), SenseInfo('11050057-n', 0), SenseInfo('11049938-n', 0), SenseInfo('03792334-n', 0) ],
"_factor_v_out_rel" : [ SenseInfo('00640385-v', 2), SenseInfo('02324901-v', 0), SenseInfo('00640650-v', 0) ],
"_chinese_a_1_rel" : [ SenseInfo('02964782-a', 5), SenseInfo('03122400-a', 0) ],
"_rub_n_1_rel" : [ SenseInfo('05691144-n', 0), SenseInfo('00125126-n', 0) ],
"_repeal_n_of_rel" : [ SenseInfo('00231887-n', 1) ],
"_swarm_v_1_rel" : [ SenseInfo('02714974-v', 3), SenseInfo('02028366-v', 3) ],
"_pop_v_off_rel" : [ SenseInfo('02081946-v', 3), SenseInfo('01404913-v', 3), SenseInfo('02185988-v', 1), SenseInfo('01134071-v', 1), SenseInfo('02186192-v', 0), SenseInfo('02157519-v', 0), SenseInfo('01499510-v', 0), SenseInfo('01474980-v', 0), SenseInfo('01401005-v', 0), SenseInfo('01202374-v', 0), SenseInfo('01199487-v', 0), SenseInfo('00309792-v', 0), SenseInfo('00309582-v', 0), SenseInfo('02081946-v', 3), SenseInfo('01404913-v', 3), SenseInfo('02185988-v', 1), SenseInfo('01134071-v', 1), SenseInfo('02186192-v', 0), SenseInfo('02157519-v', 0), SenseInfo('01499510-v', 0), SenseInfo('01474980-v', 0), SenseInfo('01401005-v', 0), SenseInfo('01202374-v', 0), SenseInfo('01199487-v', 0), SenseInfo('00309792-v', 0), SenseInfo('00309582-v', 0) ],
"_multiply_v_1_rel" : [ SenseInfo('00641672-v', 18), SenseInfo('00247390-v', 7), SenseInfo('00056334-v', 1), SenseInfo('00055142-v', 0) ],
"_greeting_n_1_rel" : [ SenseInfo('06630017-n', 5) ],
"_inter_a_1_rel" : [  ],
"_impersonate_v_1_rel" : [ SenseInfo('01723690-v', 2), SenseInfo('00849788-v', 0), SenseInfo('00837288-v', 0) ],
"_invariable_a_1_rel" : [ SenseInfo('02505716-a', 1), SenseInfo('02505716-a', 1) ],
"_crash-land_v_cause_rel" : [ SenseInfo('01980766-v', 0), SenseInfo('01980766-v', 0) ],
"_brew_v_cause_rel" : [ SenseInfo('01663920-v', 0), SenseInfo('00327813-v', 0) ],
"_tip_v_1_rel" : [ SenseInfo('02039544-v', 5), SenseInfo('00511178-v', 1), SenseInfo('02202133-v', 0), SenseInfo('02097047-v', 0), SenseInfo('02038357-v', 0), SenseInfo('01924023-v', 0), SenseInfo('01247804-v', 0), SenseInfo('00873469-v', 0), SenseInfo('00176021-v', 0), SenseInfo('02039544-v', 5), SenseInfo('00511178-v', 1), SenseInfo('02202133-v', 0), SenseInfo('02097047-v', 0), SenseInfo('02038357-v', 0), SenseInfo('01924023-v', 0), SenseInfo('01247804-v', 0), SenseInfo('00873469-v', 0), SenseInfo('00176021-v', 0), SenseInfo('02039544-v', 5), SenseInfo('00511178-v', 1), SenseInfo('02202133-v', 0), SenseInfo('02097047-v', 0), SenseInfo('02038357-v', 0), SenseInfo('01924023-v', 0), SenseInfo('01247804-v', 0), SenseInfo('00873469-v', 0), SenseInfo('00176021-v', 0) ],
"_pager_n_1_rel" : [ SenseInfo('02823124-n', 0) ],
"_probe_n_1_rel" : [ SenseInfo('05800611-n', 0), SenseInfo('04006411-n', 0), SenseInfo('00947041-n', 0), SenseInfo('00641522-n', 0) ],
"_litterbug_n_1_rel" : [ SenseInfo('10267166-n', 0) ],
"_sense_v_1_rel" : [ SenseInfo('02106006-v', 26), SenseInfo('02155248-v', 0), SenseInfo('00589469-v', 0), SenseInfo('00589309-v', 0), SenseInfo('02106006-v', 26), SenseInfo('02155248-v', 0), SenseInfo('00589469-v', 0), SenseInfo('00589309-v', 0), SenseInfo('02106006-v', 26), SenseInfo('02155248-v', 0), SenseInfo('00589469-v', 0), SenseInfo('00589309-v', 0) ],
"_ago_p_rel" : [ SenseInfo('00074095-r', 82), SenseInfo('01728476-a', 0) ],
"_like_a_1_rel" : [ SenseInfo('01409581-a', 30), SenseInfo('01411065-a', 1), SenseInfo('01410606-a', 1), SenseInfo('02063554-a', 0) ],
"_loot_n_1_rel" : [ SenseInfo('13262663-n', 2), SenseInfo('13385216-n', 1) ],
"_positional_a_1_rel" : [ SenseInfo('02782715-a', 0) ],
"_gastrin_n_1_rel" : [ SenseInfo('05408908-n', 0) ],
"_folks_n_1_rel" : [ SenseInfo('07947255-n', 14), SenseInfo('08372411-n', 1), SenseInfo('07970721-n', 1), SenseInfo('07060167-n', 0), SenseInfo('07947255-n', 14), SenseInfo('08372411-n', 1), SenseInfo('07970721-n', 1), SenseInfo('07060167-n', 0) ],
"_content_n_1_rel" : [ SenseInfo('07955057-n', 12), SenseInfo('06598915-n', 8), SenseInfo('13816521-n', 3), SenseInfo('13779374-n', 2), SenseInfo('05809192-n', 2), SenseInfo('14412882-n', 1), SenseInfo('04347225-n', 0) ],
"_compete_v_1_rel" : [ SenseInfo('01072262-v', 24) ],
"_historic_a_1_rel" : [ SenseInfo('01730060-a', 0), SenseInfo('01279028-a', 0) ],
"_to+wit_a_1_rel" : [  ],
"_narcotic_n_1_rel" : [ SenseInfo('03808564-n', 0) ],
"_tit+for+tat_n_1_rel" : [ SenseInfo('01237080-n', 0) ],
"_grief_n_1_rel" : [ SenseInfo('07535010-n', 5), SenseInfo('05833683-n', 0) ],
"_copy_v_out_rel" : [ SenseInfo('01747374-v', 3), SenseInfo('01742886-v', 3), SenseInfo('01734929-v', 0), SenseInfo('01693881-v', 0) ],
"_gamble_v_on_rel" : [ SenseInfo('02544348-v', 2), SenseInfo('01138523-v', 0) ],
"_visualize_v_as_rel" : [ SenseInfo('01635432-v', 4), SenseInfo('02151394-v', 0), SenseInfo('01636008-v', 0), SenseInfo('00581205-v', 0), SenseInfo('01635432-v', 4), SenseInfo('02151394-v', 0), SenseInfo('01636008-v', 0), SenseInfo('00581205-v', 0), SenseInfo('01635432-v', 4), SenseInfo('02151394-v', 0), SenseInfo('01636008-v', 0), SenseInfo('00581205-v', 0), SenseInfo('01635432-v', 4), SenseInfo('02151394-v', 0), SenseInfo('01636008-v', 0), SenseInfo('00581205-v', 0) ],
"_wordless_a_1_rel" : [ SenseInfo('00152285-a', 0), SenseInfo('00152285-a', 0) ],
"_skr_n_1_rel" : [  ],
"_fleet_n_1_rel" : [ SenseInfo('08293831-n', 1), SenseInfo('08293490-n', 0), SenseInfo('08293336-n', 0), SenseInfo('08292756-n', 0) ],
"_enact_v_1_rel" : [ SenseInfo('02427916-v', 13), SenseInfo('01722447-v', 4) ],
"_originator_n_of_rel" : [ SenseInfo('10383816-n', 0) ],
"_righteousness_n_1_rel" : [ SenseInfo('04826235-n', 1) ],
"_cart_v_1_rel" : [ SenseInfo('01454810-v', 1), SenseInfo('01451502-v', 0), SenseInfo('01454810-v', 1), SenseInfo('01451502-v', 0) ],
"_valet+de+chambre_n_1_rel" : [ SenseInfo('10745332-n', 0), SenseInfo('10745332-n', 0), SenseInfo('10745332-n', 0) ],
"_buddhist_a_1_rel" : [ SenseInfo('02924102-a', 1) ],
"_discharge_v_1_rel" : [ SenseInfo('02563724-v', 3), SenseInfo('01377032-v', 3), SenseInfo('02422026-v', 1), SenseInfo('01489332-v', 1), SenseInfo('01134238-v', 1), SenseInfo('00904046-v', 1), SenseInfo('00104868-v', 1), SenseInfo('01489465-v', 0), SenseInfo('01133825-v', 0), SenseInfo('01097743-v', 0), SenseInfo('00448680-v', 0) ],
"_hence_p_rel" : [ SenseInfo('00043003-r', 25), SenseInfo('00043521-r', 0), SenseInfo('00043436-r', 0), SenseInfo('00043003-r', 25), SenseInfo('00043521-r', 0), SenseInfo('00043436-r', 0) ],
"_buttress_n_1_rel" : [ SenseInfo('02929289-n', 0) ],
"_reside_v_with_rel" : [ SenseInfo('02650552-v', 10), SenseInfo('02648639-v', 1), SenseInfo('02664664-v', 0) ],
"_peregrine_n_1_rel" : [ SenseInfo('01611472-n', 0) ],
"_additional_a_1_rel" : [ SenseInfo('00048858-a', 0), SenseInfo('00048858-a', 0), SenseInfo('00048858-a', 0) ],
"_mycorhiza_n_1_rel" : [  ],
"_skulk_v_1_rel" : [ SenseInfo('02640053-v', 1), SenseInfo('02464132-v', 0), SenseInfo('01918521-v', 0) ],
"_key_v_in_rel" : [ SenseInfo('00652346-v', 1), SenseInfo('02338227-v', 0), SenseInfo('01520655-v', 0), SenseInfo('00483656-v', 0), SenseInfo('00482749-v', 0) ],
"_sleep_v_in_rel" : [ SenseInfo('00014742-v', 58), SenseInfo('02701445-v', 0) ],
"_hamper_v_1_rel" : [ SenseInfo('00236289-v', 4), SenseInfo('01085474-v', 1) ],
"_a+little+bit_x_rel" : [  ],
"_granny_n_1_rel" : [ SenseInfo('10142747-n', 3), SenseInfo('10143530-n', 0), SenseInfo('03453320-n', 0) ],
"_command_n_1_rel" : [ SenseInfo('07168131-n', 23), SenseInfo('08190292-n', 11), SenseInfo('05197797-n', 5), SenseInfo('04719376-n', 2), SenseInfo('13953608-n', 1), SenseInfo('05641959-n', 1), SenseInfo('06584891-n', 0), SenseInfo('07168131-n', 23), SenseInfo('08190292-n', 11), SenseInfo('05197797-n', 5), SenseInfo('04719376-n', 2), SenseInfo('13953608-n', 1), SenseInfo('05641959-n', 1), SenseInfo('06584891-n', 0), SenseInfo('07168131-n', 23), SenseInfo('08190292-n', 11), SenseInfo('05197797-n', 5), SenseInfo('04719376-n', 2), SenseInfo('13953608-n', 1), SenseInfo('05641959-n', 1), SenseInfo('06584891-n', 0), SenseInfo('07168131-n', 23), SenseInfo('08190292-n', 11), SenseInfo('05197797-n', 5), SenseInfo('04719376-n', 2), SenseInfo('13953608-n', 1), SenseInfo('05641959-n', 1), SenseInfo('06584891-n', 0) ],
"_inevitable_n_1_rel" : [ SenseInfo('07330250-n', 1) ],
"_ready_a_1_rel" : [ SenseInfo('01930512-a', 58), SenseInfo('00185759-a', 4), SenseInfo('02565701-a', 2), SenseInfo('01844742-a', 1), SenseInfo('01335903-a', 0), SenseInfo('01930512-a', 58), SenseInfo('00185759-a', 4), SenseInfo('02565701-a', 2), SenseInfo('01844742-a', 1), SenseInfo('01335903-a', 0), SenseInfo('01930512-a', 58), SenseInfo('00185759-a', 4), SenseInfo('02565701-a', 2), SenseInfo('01844742-a', 1), SenseInfo('01335903-a', 0), SenseInfo('01930512-a', 58), SenseInfo('00185759-a', 4), SenseInfo('02565701-a', 2), SenseInfo('01844742-a', 1), SenseInfo('01335903-a', 0), SenseInfo('01930512-a', 58), SenseInfo('00185759-a', 4), SenseInfo('02565701-a', 2), SenseInfo('01844742-a', 1), SenseInfo('01335903-a', 0), SenseInfo('01930512-a', 58), SenseInfo('00185759-a', 4), SenseInfo('02565701-a', 2), SenseInfo('01844742-a', 1), SenseInfo('01335903-a', 0) ],
"_talk_n_of-on_rel" : [ SenseInfo('07135734-n', 12), SenseInfo('07139316-n', 1), SenseInfo('00893243-n', 1), SenseInfo('07240549-n', 0), SenseInfo('07223985-n', 0), SenseInfo('07135734-n', 12), SenseInfo('07139316-n', 1), SenseInfo('00893243-n', 1), SenseInfo('07240549-n', 0), SenseInfo('07223985-n', 0), SenseInfo('07135734-n', 12), SenseInfo('07139316-n', 1), SenseInfo('00893243-n', 1), SenseInfo('07240549-n', 0), SenseInfo('07223985-n', 0) ],
"_consumer_n_of_rel" : [ SenseInfo('09612848-n', 10) ],
"_ostensible_a_1_rel" : [ SenseInfo('01873985-a', 0), SenseInfo('01117942-a', 0), SenseInfo('01873985-a', 0), SenseInfo('01117942-a', 0), SenseInfo('01873985-a', 0), SenseInfo('01117942-a', 0), SenseInfo('01873985-a', 0), SenseInfo('01117942-a', 0) ],
"_percipient_a_1_rel" : [ SenseInfo('00771616-a', 0) ],
"_roadless_a_1_rel" : [ SenseInfo('00020241-a', 0) ],
"_meander_v_1_rel" : [ SenseInfo('01882814-v', 1) ],
"_venerable_a_1_rel" : [ SenseInfo('01646794-a', 1), SenseInfo('01226660-a', 1) ],
"_war_n_1_rel" : [ SenseInfo('00973077-n', 78), SenseInfo('13981403-n', 27), SenseInfo('01236296-n', 1), SenseInfo('00801125-n', 0) ],
"_slurp_v_1_rel" : [ SenseInfo('01169328-v', 1) ],
"_puncture_n_1_rel" : [ SenseInfo('07314658-n', 0), SenseInfo('04024396-n', 0), SenseInfo('00942988-n', 0) ],
"_novices_a_1_rel" : [  ],
"_friendliness_n_to-towards_rel" : [ SenseInfo('07499615-n', 1), SenseInfo('04654337-n', 0), SenseInfo('07499615-n', 1), SenseInfo('04654337-n', 0) ],
"_vanilla_n_1_rel" : [ SenseInfo('12086539-n', 0), SenseInfo('07828807-n', 0), SenseInfo('05716462-n', 0) ],
"_catalunian_n_1_rel" : [  ],
"_unperformed_a_1_rel" : [ SenseInfo('02294662-a', 1), SenseInfo('02294662-a', 1) ],
"_disclosure_n_1_rel" : [ SenseInfo('07213395-n', 1), SenseInfo('07213395-n', 1) ],
"_yap_v_1_rel" : [ SenseInfo('01048171-v', 1), SenseInfo('01048171-v', 1) ],
"_watchtower_n_1_rel" : [ SenseInfo('04556948-n', 0) ],
"_shunt_v_1_rel" : [ SenseInfo('02012227-v', 1), SenseInfo('02065885-v', 0), SenseInfo('02012227-v', 1), SenseInfo('02065885-v', 0) ],
"_worshipper_n_1_rel" : [ SenseInfo('09847727-n', 1), SenseInfo('10792335-n', 0) ],
"_stripe_n_1_rel" : [ SenseInfo('02784732-n', 1), SenseInfo('07269758-n', 0), SenseInfo('07269552-n', 0), SenseInfo('05845749-n', 0), SenseInfo('04683136-n', 0) ],
"_clarify_v_1_rel" : [ SenseInfo('00939857-v', 3), SenseInfo('00505151-v', 0) ],
"_revise_v_1_rel" : [ SenseInfo('00996102-v', 6), SenseInfo('02433549-v', 3) ],
"_illness_n_1_rel" : [ SenseInfo('14061805-n', 6) ],
"_caliber_n_1_rel" : [ SenseInfo('04728068-n', 2), SenseInfo('05103283-n', 1) ],
"_overall_a_1_rel" : [ SenseInfo('01102451-a', 9), SenseInfo('01582946-a', 8), SenseInfo('01102451-a', 9), SenseInfo('01582946-a', 8), SenseInfo('01102451-a', 9), SenseInfo('01582946-a', 8) ],
"_spruce_v_up_rel" : [ SenseInfo('00293977-v', 0), SenseInfo('00043278-v', 0) ],
"_silver_a_1_rel" : [ SenseInfo('01529053-a', 4), SenseInfo('00283327-a', 4), SenseInfo('00387392-a', 1), SenseInfo('00150505-a', 0) ],
"_extent_n_of_rel" : [ SenseInfo('13941125-n', 23), SenseInfo('05123416-n', 15), SenseInfo('13941125-n', 23), SenseInfo('05123416-n', 15) ],
"_ultra_a_1_rel" : [ SenseInfo('01535270-a', 1) ],
"_hand_v_out_rel" : [ SenseInfo('02230772-v', 25), SenseInfo('02000133-v', 0) ],
"_confess_v_to_rel" : [ SenseInfo('00819508-v', 10), SenseInfo('00818553-v', 3), SenseInfo('00818805-v', 0), SenseInfo('00819508-v', 10), SenseInfo('00818553-v', 3), SenseInfo('00818805-v', 0) ],
"_foggy_a_1_rel" : [ SenseInfo('00875962-a', 0), SenseInfo('00781644-a', 0), SenseInfo('00461609-a', 0), SenseInfo('00433811-a', 0), SenseInfo('00875962-a', 0), SenseInfo('00781644-a', 0), SenseInfo('00461609-a', 0), SenseInfo('00433811-a', 0), SenseInfo('00875962-a', 0), SenseInfo('00781644-a', 0), SenseInfo('00461609-a', 0), SenseInfo('00433811-a', 0), SenseInfo('00875962-a', 0), SenseInfo('00781644-a', 0), SenseInfo('00461609-a', 0), SenseInfo('00433811-a', 0), SenseInfo('00875962-a', 0), SenseInfo('00781644-a', 0), SenseInfo('00461609-a', 0), SenseInfo('00433811-a', 0), SenseInfo('00875962-a', 0), SenseInfo('00781644-a', 0), SenseInfo('00461609-a', 0), SenseInfo('00433811-a', 0) ],
"_tango_n_1_rel" : [ SenseInfo('00537423-n', 2), SenseInfo('07057829-n', 0) ],
"_perilous_a_1_rel" : [ SenseInfo('02060496-a', 4) ],
"_concurrent_a_1_rel" : [ SenseInfo('02378496-a', 3), SenseInfo('02378496-a', 3) ],
"_sponsor_n_of_rel" : [ SenseInfo('10407954-n', 4), SenseInfo('10466198-n', 0) ],
"_surveyor_n_1_rel" : [ SenseInfo('10680609-n', 2), SenseInfo('10680796-n', 0) ],
"_babysitter_n_1_rel" : [ SenseInfo('09829305-n', 0) ],
"_curdle_v_1_rel" : [ SenseInfo('00457770-v', 0), SenseInfo('00443000-v', 0), SenseInfo('00442847-v', 0) ],
"_round_p_sel_rel" : [ SenseInfo('02040652-a', 12), SenseInfo('04113641-n', 6), SenseInfo('00071456-r', 3), SenseInfo('01858910-v', 3), SenseInfo('15287830-n', 2), SenseInfo('08507381-n', 1), SenseInfo('01055688-n', 1), SenseInfo('00466377-n', 1), SenseInfo('00415098-n', 1), SenseInfo('01457486-a', 1), SenseInfo('00916524-a', 1), SenseInfo('00145147-v', 1), SenseInfo('15256714-n', 0), SenseInfo('09417097-n', 0), SenseInfo('07884266-n', 0), SenseInfo('07662156-n', 0), SenseInfo('07053089-n', 0), SenseInfo('06692464-n', 0), SenseInfo('04119892-n', 0), SenseInfo('03032811-n', 0), SenseInfo('00980339-v', 0), SenseInfo('00862683-v', 0), SenseInfo('00473799-v', 0), SenseInfo('00145623-v', 0), SenseInfo('00046382-v', 0) ],
"_pretend_v_1_rel" : [ SenseInfo('00838043-v', 12), SenseInfo('01721556-v', 10), SenseInfo('02275799-v', 0), SenseInfo('00916909-v', 0), SenseInfo('00838524-v', 0), SenseInfo('00756649-v', 0), SenseInfo('00838043-v', 12), SenseInfo('01721556-v', 10), SenseInfo('02275799-v', 0), SenseInfo('00916909-v', 0), SenseInfo('00838524-v', 0), SenseInfo('00756649-v', 0), SenseInfo('00838043-v', 12), SenseInfo('01721556-v', 10), SenseInfo('02275799-v', 0), SenseInfo('00916909-v', 0), SenseInfo('00838524-v', 0), SenseInfo('00756649-v', 0) ],
"_subtle_a_1_rel" : [ SenseInfo('01717901-a', 9), SenseInfo('01745846-a', 0), SenseInfo('01162406-a', 0), SenseInfo('01717901-a', 9), SenseInfo('01745846-a', 0), SenseInfo('01162406-a', 0), SenseInfo('01717901-a', 9), SenseInfo('01745846-a', 0), SenseInfo('01162406-a', 0) ],
"_stance_n_1_rel" : [ SenseInfo('05082507-n', 1), SenseInfo('06196284-n', 0) ],
"_allergy_n_1_rel" : [ SenseInfo('14532816-n', 0) ],
"_pipe_v_down_rel" : [ SenseInfo('00914420-v', 1), SenseInfo('01950295-v', 0), SenseInfo('01727684-v', 0), SenseInfo('01670645-v', 0) ],
"_crap_n_1_rel" : [ SenseInfo('14854581-n', 0), SenseInfo('06611376-n', 0) ],
"_minimum_n_of_rel" : [ SenseInfo('13763384-n', 9), SenseInfo('08600274-n', 0) ],
"_yield_v_1_rel" : [ SenseInfo('02339171-v', 6), SenseInfo('00435103-v', 5), SenseInfo('01629000-v', 4), SenseInfo('02316649-v', 3), SenseInfo('02703289-v', 2), SenseInfo('01848465-v', 1), SenseInfo('01629403-v', 1), SenseInfo('00806049-v', 1), SenseInfo('02620466-v', 0), SenseInfo('02291708-v', 0), SenseInfo('01449796-v', 0), SenseInfo('01116447-v', 0), SenseInfo('00804476-v', 0) ],
"_sulphur_n_1_rel" : [ SenseInfo('14656219-n', 0) ],
"_radical_a_1_rel" : [ SenseInfo('01535270-a', 5), SenseInfo('01642657-a', 4), SenseInfo('01856802-a', 1), SenseInfo('02836479-a', 0), SenseInfo('00318667-a', 0), SenseInfo('01535270-a', 5), SenseInfo('01642657-a', 4), SenseInfo('01856802-a', 1), SenseInfo('02836479-a', 0), SenseInfo('00318667-a', 0) ],
"_recruit_v_1_rel" : [ SenseInfo('02471327-v', 7), SenseInfo('02240319-v', 3), SenseInfo('01098452-v', 2) ],
"_immovable_a_1_rel" : [ SenseInfo('01525320-a', 0) ],
"_ease_v_out_rel" : [ SenseInfo('01834213-v', 4), SenseInfo('00082308-v', 4), SenseInfo('00518395-v', 3), SenseInfo('01815185-v', 1) ],
"_harbor_n_1_rel" : [ SenseInfo('08639058-n', 8), SenseInfo('03492250-n', 0), SenseInfo('08639058-n', 8), SenseInfo('03492250-n', 0), SenseInfo('08639058-n', 8), SenseInfo('03492250-n', 0) ],
"_pit_v_against_rel" : [ SenseInfo('01081152-v', 1), SenseInfo('01551195-v', 0), SenseInfo('00179567-v', 0) ],
"_trail_v_off_rel" : [ SenseInfo('02058756-v', 8), SenseInfo('02001858-v', 3), SenseInfo('02059916-v', 0), SenseInfo('01542842-v', 0), SenseInfo('01453969-v', 0) ],
"_Bactine_n_1_rel" : [  ],
"_sonnet_n_1_rel" : [ SenseInfo('06381372-n', 1) ],
"_beg_v_off_rel" : [ SenseInfo('00759269-v', 11), SenseInfo('00782057-v', 5), SenseInfo('02270815-v', 2), SenseInfo('00810226-v', 0) ],
"_llama_n_1_rel" : [ SenseInfo('02437616-n', 0) ],
"_inform_v_1_rel" : [ SenseInfo('00831651-v', 46), SenseInfo('00522613-v', 2), SenseInfo('00833199-v', 1), SenseInfo('00831651-v', 46), SenseInfo('00522613-v', 2), SenseInfo('00833199-v', 1), SenseInfo('00831651-v', 46), SenseInfo('00522613-v', 2), SenseInfo('00833199-v', 1) ],
"_toast_v_1_rel" : [ SenseInfo('00322151-v', 5), SenseInfo('01175467-v', 1) ],
"_destine_v_1_rel" : [ SenseInfo('00746479-v', 4), SenseInfo('00709379-v', 2) ],
"_move_v_up_rel" : [ SenseInfo('01835496-v', 110), SenseInfo('01850315-v', 57), SenseInfo('01831531-v', 52), SenseInfo('01855606-v', 20), SenseInfo('02372605-v', 15), SenseInfo('00014549-v', 7), SenseInfo('00124442-v', 6), SenseInfo('02367363-v', 3), SenseInfo('01767949-v', 3), SenseInfo('01649999-v', 3), SenseInfo('01771390-v', 2), SenseInfo('02355959-v', 1), SenseInfo('00539110-v', 1), SenseInfo('02598863-v', 0), SenseInfo('01076615-v', 0), SenseInfo('00879356-v', 0) ],
"_premium_n_1_rel" : [ SenseInfo('13301620-n', 1), SenseInfo('13413986-n', 0), SenseInfo('13324297-n', 0), SenseInfo('13272283-n', 0), SenseInfo('13272059-n', 0) ],
"_paddy_n_1_rel" : [ SenseInfo('09715521-n', 0), SenseInfo('08614229-n', 0), SenseInfo('07804900-n', 0) ],
"_overpay_v_for_rel" : [ SenseInfo('02250077-v', 0), SenseInfo('02250077-v', 0), SenseInfo('02250077-v', 0), SenseInfo('02250077-v', 0), SenseInfo('02250077-v', 0), SenseInfo('02250077-v', 0), SenseInfo('02250077-v', 0), SenseInfo('02250077-v', 0) ],
"_modulo_p_rel" : [  ],
"_emphasize_v_to_rel" : [ SenseInfo('01013367-v', 26), SenseInfo('01014609-v', 1), SenseInfo('01013367-v', 26), SenseInfo('01014609-v', 1), SenseInfo('01013367-v', 26), SenseInfo('01014609-v', 1), SenseInfo('01013367-v', 26), SenseInfo('01014609-v', 1) ],
"_save_x_to_rel" : [ SenseInfo('02550868-v', 41), SenseInfo('02225492-v', 16), SenseInfo('02551832-v', 4), SenseInfo('02266920-v', 4), SenseInfo('02265979-v', 4), SenseInfo('00549552-v', 4), SenseInfo('02551602-v', 2), SenseInfo('02464583-v', 2), SenseInfo('02357228-v', 1), SenseInfo('02283716-v', 1), SenseInfo('01079396-n', 0), SenseInfo('00998886-v', 0) ],
"_patagonian_n_1_rel" : [  ],
"_parson_n_1_rel" : [ SenseInfo('09983572-n', 2) ],
"_sex_v_1_rel" : [ SenseInfo('01762283-v', 0), SenseInfo('00651630-v', 0) ],
"_avenge_v_1_rel" : [ SenseInfo('01153486-v', 1) ],
"_trash_v_1_rel" : [ SenseInfo('02223238-v', 0), SenseInfo('00846344-v', 0) ],
"_northward_a_2_rel" : [ SenseInfo('01600713-a', 0) ],
"_breaker_n_1_rel" : [ SenseInfo('09873604-n', 0), SenseInfo('07344233-n', 0), SenseInfo('03034244-n', 0) ],
"_lot_n_1_rel" : [ SenseInfo('13774404-n', 13), SenseInfo('08674970-n', 5), SenseInfo('08240169-n', 4), SenseInfo('14473222-n', 3), SenseInfo('03233423-n', 3), SenseInfo('07954731-n', 1), SenseInfo('10273669-n', 0) ],
"_motionless_a_1_rel" : [ SenseInfo('01564315-a', 8) ],
"_dealer_n_1_rel" : [ SenseInfo('10720453-n', 8), SenseInfo('08063446-n', 2), SenseInfo('10721470-n', 0), SenseInfo('10474446-n', 0), SenseInfo('09996636-n', 0), SenseInfo('10720453-n', 8), SenseInfo('08063446-n', 2), SenseInfo('10721470-n', 0), SenseInfo('10474446-n', 0), SenseInfo('09996636-n', 0), SenseInfo('10720453-n', 8), SenseInfo('08063446-n', 2), SenseInfo('10721470-n', 0), SenseInfo('10474446-n', 0), SenseInfo('09996636-n', 0) ],
"_prop_v_1_rel" : [ SenseInfo('01219004-v', 1) ],
"_dismissal_n_1_rel" : [ SenseInfo('01190172-n', 1), SenseInfo('07213079-n', 0), SenseInfo('06689829-n', 0), SenseInfo('00216174-n', 0) ],
"_ambassadorial_a_1_rel" : [ SenseInfo('03040846-a', 0) ],
"_krona_n_1_rel" : [ SenseInfo('13682330-n', 0), SenseInfo('13681993-n', 0), SenseInfo('13682330-n', 0), SenseInfo('13681993-n', 0), SenseInfo('13682330-n', 0), SenseInfo('13681993-n', 0), SenseInfo('13682330-n', 0), SenseInfo('13681993-n', 0) ],
"_rockface_n_1_rel" : [  ],
"_day+to+day_a_1_rel" : [ SenseInfo('01968165-a', 0), SenseInfo('01968165-a', 0), SenseInfo('01968165-a', 0), SenseInfo('01968165-a', 0), SenseInfo('01968165-a', 0), SenseInfo('01968165-a', 0), SenseInfo('01968165-a', 0), SenseInfo('01968165-a', 0), SenseInfo('01968165-a', 0) ],
"_metamorphosis_n_1_rel" : [ SenseInfo('13514880-n', 0), SenseInfo('00402308-n', 0), SenseInfo('00402128-n', 0) ],
"_frown_n_1_rel" : [ SenseInfo('06877849-n', 0) ],
"_neck_v_1_rel" : [ SenseInfo('01426153-v', 0) ],
"_munch_v_1_rel" : [ SenseInfo('01201693-v', 0) ],
"_written_a_1_rel" : [ SenseInfo('02284578-a', 9), SenseInfo('02286661-a', 0), SenseInfo('02213270-a', 0) ],
"_devotee_n_1_rel" : [ SenseInfo('10077593-n', 2) ],
"_straightway_a_1_rel" : [  ],
"_all+righty_a_1_rel" : [  ],
"_cohabitant_n_1_rel" : [  ],
"_thrice_x_deg_rel" : [ SenseInfo('00257784-r', 1) ],
"_iguana_n_1_rel" : [ SenseInfo('01677366-n', 0) ],
"_provider_n_1_rel" : [ SenseInfo('10677271-n', 0), SenseInfo('10486349-n', 0), SenseInfo('10677271-n', 0), SenseInfo('10486349-n', 0) ],
"_bulge_v_1_rel" : [ SenseInfo('00263231-v', 3), SenseInfo('02714360-v', 0), SenseInfo('02081946-v', 0), SenseInfo('00256369-v', 0) ],
"_happen_v_1_rel" : [ SenseInfo('00339934-v', 149), SenseInfo('00344643-v', 20), SenseInfo('02593912-v', 17), SenseInfo('00344174-v', 9), SenseInfo('02248465-v', 0), SenseInfo('00339934-v', 149), SenseInfo('00344643-v', 20), SenseInfo('02593912-v', 17), SenseInfo('00344174-v', 9), SenseInfo('02248465-v', 0) ],
"_gene_n_1_rel" : [ SenseInfo('05436752-n', 0) ],
"_pin_n_1_rel" : [ SenseInfo('03940713-n', 1), SenseInfo('07471371-n', 0), SenseInfo('07271791-n', 0), SenseInfo('06887441-n', 0), SenseInfo('05561707-n', 0), SenseInfo('03951971-n', 0), SenseInfo('03941013-n', 0), SenseInfo('03940894-n', 0), SenseInfo('03940256-n', 0), SenseInfo('03905730-n', 0), SenseInfo('02882647-n', 0) ],
"_brave_n_1_rel" : [ SenseInfo('09645788-n', 0), SenseInfo('07944754-n', 0) ],
"_stench_n_1_rel" : [ SenseInfo('05714894-n', 0) ],
"_discourse_n_1_rel" : [ SenseInfo('06284777-n', 2), SenseInfo('07243837-n', 0), SenseInfo('07138085-n', 0) ],
"_peruse_v_1_rel" : [ SenseInfo('02152812-v', 1) ],
"_every_x_deg_rel" : [ SenseInfo('02269794-a', 57), SenseInfo('02270186-a', 11) ],
"_LED_n_1_rel" : [ SenseInfo('03666362-n', 0) ],
"_taut_a_1_rel" : [ SenseInfo('02403505-a', 4), SenseInfo('02405959-a', 1) ],
"_false_a_of_rel" : [ SenseInfo('02461723-a', 9), SenseInfo('00633235-a', 1), SenseInfo('02500379-a', 0), SenseInfo('02182088-a', 0), SenseInfo('01942507-a', 0), SenseInfo('01573238-a', 0), SenseInfo('01224650-a', 0), SenseInfo('01164420-a', 0), SenseInfo('01116857-a', 0), SenseInfo('00584403-a', 0) ],
"_groove_n_1_rel" : [ SenseInfo('13893786-n', 1), SenseInfo('01026744-n', 1), SenseInfo('05222591-n', 0) ],
"_nonprofit_a_1_rel" : [ SenseInfo('00484680-a', 0) ],
"_bce_p_temp_rel" : [ SenseInfo('00002296-r', 0), SenseInfo('00002296-r', 0), SenseInfo('00002296-r', 0), SenseInfo('00002296-r', 0) ],
"_gorge_v_on_rel" : [ SenseInfo('01193099-v', 1), SenseInfo('01193099-v', 1) ],
"_pile_v_on_rel" : [ SenseInfo('01503404-v', 8), SenseInfo('02064131-v', 2), SenseInfo('01434822-v', 0), SenseInfo('01503404-v', 8), SenseInfo('02064131-v', 2), SenseInfo('01434822-v', 0) ],
"_firm_n_1_rel" : [ SenseInfo('08059870-n', 26) ],
"_chandelier_n_1_rel" : [ SenseInfo('03005285-n', 3) ],
"_prosecutor_n_1_rel" : [ SenseInfo('10484858-n', 4) ],
"_habitual_a_1_rel" : [ SenseInfo('00489491-a', 1), SenseInfo('00489491-a', 1) ],
"_first_a_1_rel" : [ SenseInfo('01010862-a', 232), SenseInfo('02202047-a', 61), SenseInfo('01009343-a', 4), SenseInfo('01009206-a', 4), SenseInfo('00228294-a', 3), SenseInfo('01016215-a', 0), SenseInfo('01010862-a', 232), SenseInfo('02202047-a', 61), SenseInfo('01009343-a', 4), SenseInfo('01009206-a', 4), SenseInfo('00228294-a', 3), SenseInfo('01016215-a', 0), SenseInfo('01010862-a', 232), SenseInfo('02202047-a', 61), SenseInfo('01009343-a', 4), SenseInfo('01009206-a', 4), SenseInfo('00228294-a', 3), SenseInfo('01016215-a', 0) ],
"_sodden_a_1_rel" : [ SenseInfo('02549032-a', 2) ],
"_surface_n_1_rel" : [ SenseInfo('04362025-n', 90), SenseInfo('08660339-n', 36), SenseInfo('09451517-n', 11), SenseInfo('05853449-n', 4), SenseInfo('05612809-n', 1), SenseInfo('02688443-n', 0) ],
"_humanities_n_1_rel" : [ SenseInfo('06153846-n', 0) ],
"_romp_n_1_rel" : [ SenseInfo('07475107-n', 1), SenseInfo('10715030-n', 0), SenseInfo('00511817-n', 0) ],
"_bewilder_v_1_rel" : [ SenseInfo('00622384-v', 2), SenseInfo('01791232-v', 1), SenseInfo('00622384-v', 2), SenseInfo('01791232-v', 1) ],
"_section_n_of_rel" : [ SenseInfo('06392001-n', 43), SenseInfo('09428741-n', 31), SenseInfo('08648322-n', 11), SenseInfo('04164989-n', 10), SenseInfo('08214832-n', 1), SenseInfo('05867413-n', 1), SenseInfo('13613504-n', 0), SenseInfo('08648153-n', 0), SenseInfo('08239152-n', 0), SenseInfo('08216900-n', 0), SenseInfo('08216795-n', 0), SenseInfo('08114861-n', 0), SenseInfo('07747455-n', 0), SenseInfo('00678010-n', 0), SenseInfo('06392001-n', 43), SenseInfo('09428741-n', 31), SenseInfo('08648322-n', 11), SenseInfo('04164989-n', 10), SenseInfo('08214832-n', 1), SenseInfo('05867413-n', 1), SenseInfo('13613504-n', 0), SenseInfo('08648153-n', 0), SenseInfo('08239152-n', 0), SenseInfo('08216900-n', 0), SenseInfo('08216795-n', 0), SenseInfo('08114861-n', 0), SenseInfo('07747455-n', 0), SenseInfo('00678010-n', 0), SenseInfo('06392001-n', 43), SenseInfo('09428741-n', 31), SenseInfo('08648322-n', 11), SenseInfo('04164989-n', 10), SenseInfo('08214832-n', 1), SenseInfo('05867413-n', 1), SenseInfo('13613504-n', 0), SenseInfo('08648153-n', 0), SenseInfo('08239152-n', 0), SenseInfo('08216900-n', 0), SenseInfo('08216795-n', 0), SenseInfo('08114861-n', 0), SenseInfo('07747455-n', 0), SenseInfo('00678010-n', 0), SenseInfo('06392001-n', 43), SenseInfo('09428741-n', 31), SenseInfo('08648322-n', 11), SenseInfo('04164989-n', 10), SenseInfo('08214832-n', 1), SenseInfo('05867413-n', 1), SenseInfo('13613504-n', 0), SenseInfo('08648153-n', 0), SenseInfo('08239152-n', 0), SenseInfo('08216900-n', 0), SenseInfo('08216795-n', 0), SenseInfo('08114861-n', 0), SenseInfo('07747455-n', 0), SenseInfo('00678010-n', 0), SenseInfo('06392001-n', 43), SenseInfo('09428741-n', 31), SenseInfo('08648322-n', 11), SenseInfo('04164989-n', 10), SenseInfo('08214832-n', 1), SenseInfo('05867413-n', 1), SenseInfo('13613504-n', 0), SenseInfo('08648153-n', 0), SenseInfo('08239152-n', 0), SenseInfo('08216900-n', 0), SenseInfo('08216795-n', 0), SenseInfo('08114861-n', 0), SenseInfo('07747455-n', 0), SenseInfo('00678010-n', 0) ],
"_even_v_out_rel" : [ SenseInfo('01307142-v', 0), SenseInfo('00416880-v', 0), SenseInfo('00416705-v', 0), SenseInfo('01307142-v', 0), SenseInfo('00416880-v', 0), SenseInfo('00416705-v', 0) ],
"_junkie_n_1_rel" : [ SenseInfo('10035952-n', 0), SenseInfo('09769076-n', 0) ],
"_detribalize_v_1_rel" : [ SenseInfo('00160086-v', 1), SenseInfo('00160086-v', 1) ],
"_claim_v_as_rel" : [ SenseInfo('00756338-v', 34), SenseInfo('02275365-v', 14), SenseInfo('01018352-v', 9), SenseInfo('00758333-v', 4), SenseInfo('00756076-v', 1), SenseInfo('00756338-v', 34), SenseInfo('02275365-v', 14), SenseInfo('01018352-v', 9), SenseInfo('00758333-v', 4), SenseInfo('00756076-v', 1) ],
"_lovable_a_1_rel" : [ SenseInfo('01459422-a', 0) ],
"_profitboss_n_1_rel" : [  ],
"_sour_a_on_rel" : [ SenseInfo('01054922-a', 1), SenseInfo('02368787-a', 0), SenseInfo('02399014-a', 0), SenseInfo('02369869-a', 0), SenseInfo('01164420-a', 0), SenseInfo('01137378-a', 0) ],
"_save_n_1_rel" : [ SenseInfo('01079396-n', 0) ],
"_hewn_a_1_rel" : [ SenseInfo('00663576-a', 0) ],
"_weave_v_1_rel" : [ SenseInfo('01518924-v', 3), SenseInfo('01673891-v', 2), SenseInfo('01868258-v', 1), SenseInfo('01882814-v', 0), SenseInfo('01518924-v', 3), SenseInfo('01673891-v', 2), SenseInfo('01868258-v', 1), SenseInfo('01882814-v', 0), SenseInfo('01518924-v', 3), SenseInfo('01673891-v', 2), SenseInfo('01868258-v', 1), SenseInfo('01882814-v', 0) ],
"_dump_v_on_rel" : [ SenseInfo('02225204-v', 12), SenseInfo('02224945-v', 1), SenseInfo('02350878-v', 0), SenseInfo('01977545-v', 0), SenseInfo('01977080-v', 0), SenseInfo('01412346-v', 0) ],
"_fleshy_a_1_rel" : [ SenseInfo('00987769-a', 1), SenseInfo('02729339-a', 0), SenseInfo('00987769-a', 1), SenseInfo('02729339-a', 0), SenseInfo('00987769-a', 1), SenseInfo('02729339-a', 0) ],
"_becomingly_x_deg_rel" : [ SenseInfo('00278259-r', 0) ],
"_pleasant_a_for_rel" : [ SenseInfo('01800349-a', 9), SenseInfo('01586866-a', 1), SenseInfo('01800349-a', 9), SenseInfo('01586866-a', 1), SenseInfo('01800349-a', 9), SenseInfo('01586866-a', 1) ],
"_over_p_rel" : [ SenseInfo('00226550-r', 23), SenseInfo('01003277-a', 21), SenseInfo('00226677-r', 2), SenseInfo('00226458-r', 1), SenseInfo('15258694-n', 0), SenseInfo('00226758-r', 0), SenseInfo('00198039-r', 0), SenseInfo('00226550-r', 23), SenseInfo('01003277-a', 21), SenseInfo('00226677-r', 2), SenseInfo('00226458-r', 1), SenseInfo('15258694-n', 0), SenseInfo('00226758-r', 0), SenseInfo('00198039-r', 0), SenseInfo('00226550-r', 23), SenseInfo('01003277-a', 21), SenseInfo('00226677-r', 2), SenseInfo('00226458-r', 1), SenseInfo('15258694-n', 0), SenseInfo('00226758-r', 0), SenseInfo('00198039-r', 0) ],
"_live_a_1_rel" : [ SenseInfo('01422556-a', 6), SenseInfo('00099290-a', 0), SenseInfo('00094448-a', 0), SenseInfo('02010441-a', 0), SenseInfo('01424596-a', 0), SenseInfo('00843595-a', 0), SenseInfo('00806243-a', 0), SenseInfo('00667463-a', 0), SenseInfo('00667353-a', 0), SenseInfo('00358392-a', 0), SenseInfo('00041488-a', 0) ],
"_geology_n_1_rel" : [ SenseInfo('06115701-n', 1) ],
"_band_v_together_rel" : [ SenseInfo('01304342-v', 1), SenseInfo('01297401-v', 0), SenseInfo('01304342-v', 1), SenseInfo('01297401-v', 0) ],
"_dotterel_n_1_rel" : [ SenseInfo('02024185-n', 0) ],
"_supply_n_1_rel" : [ SenseInfo('13777344-n', 21), SenseInfo('13563522-n', 4), SenseInfo('01057200-n', 2), SenseInfo('13777344-n', 21), SenseInfo('13563522-n', 4), SenseInfo('01057200-n', 2), SenseInfo('13777344-n', 21), SenseInfo('13563522-n', 4), SenseInfo('01057200-n', 2) ],
"_ray_n_1_rel" : [ SenseInfo('11428023-n', 11), SenseInfo('13131516-n', 1), SenseInfo('13913427-n', 0), SenseInfo('11428379-n', 0), SenseInfo('06868445-n', 0), SenseInfo('01900719-n', 0), SenseInfo('01495701-n', 0) ],
"_norwester_n_1_rel" : [  ],
"_range_v_1_rel" : [ SenseInfo('02727039-v', 34), SenseInfo('01881180-v', 2), SenseInfo('02741149-v', 1), SenseInfo('02690384-v', 1), SenseInfo('01474209-v', 1), SenseInfo('01576165-v', 0), SenseInfo('01204439-v', 0), SenseInfo('00658052-v', 0), SenseInfo('02727039-v', 34), SenseInfo('01881180-v', 2), SenseInfo('02741149-v', 1), SenseInfo('02690384-v', 1), SenseInfo('01474209-v', 1), SenseInfo('01576165-v', 0), SenseInfo('01204439-v', 0), SenseInfo('00658052-v', 0) ],
"_freedom_n_1_rel" : [ SenseInfo('13991823-n', 26), SenseInfo('14528873-n', 1), SenseInfo('13991823-n', 26), SenseInfo('14528873-n', 1) ],
"_ontology_n_1_rel" : [ SenseInfo('06162979-n', 0), SenseInfo('06162847-n', 0) ],
"_bible_n_1_rel" : [ SenseInfo('06431740-n', 13), SenseInfo('06422643-n', 0) ],
"_bashful_a_1_rel" : [ SenseInfo('00252130-a', 1), SenseInfo('00204249-a', 0) ],
"_wedge_v_into_rel" : [ SenseInfo('01528069-v', 1), SenseInfo('01527271-v', 0) ],
"_causal_a_1_rel" : [ SenseInfo('00323199-a', 5) ],
"_coin_v_1_rel" : [ SenseInfo('01697986-v', 3), SenseInfo('01639105-v', 0) ],
"_alternator_n_1_rel" : [ SenseInfo('02700064-n', 0) ],
"_toot_v_1_rel" : [ SenseInfo('02183175-v', 0) ],
"_gagline_n_1_rel" : [  ],
"_huckster_v_1_rel" : [ SenseInfo('02302817-v', 1), SenseInfo('02259547-v', 0) ],
"_grandmother_n_of_rel" : [ SenseInfo('10142747-n', 8) ],
"_euphony_n_1_rel" : [ SenseInfo('05718556-n', 0) ],
"_constrict_v_cause_rel" : [ SenseInfo('01387786-v', 1), SenseInfo('00304422-v', 0) ],
"_examination_n_of_rel" : [ SenseInfo('00635850-n', 15), SenseInfo('07197021-n', 1), SenseInfo('07193958-n', 1), SenseInfo('05787005-n', 0), SenseInfo('00636461-n', 0) ],
"_rear_n_1_rel" : [ SenseInfo('08482700-n', 16), SenseInfo('08629508-n', 6), SenseInfo('08625846-n', 4), SenseInfo('05559256-n', 0), SenseInfo('04059701-n', 0) ],
"_suggest_v_1_rel" : [ SenseInfo('00875394-v', 57), SenseInfo('00927430-v', 21), SenseInfo('00930806-v', 19), SenseInfo('00928232-v', 14), SenseInfo('00930368-v', 12) ],
"_crumble_v_cause_rel" : [ SenseInfo('02041877-v', 2), SenseInfo('00397405-v', 0), SenseInfo('00208836-v', 0) ],
"_chinless_a_1_rel" : [ SenseInfo('01875929-a', 2) ],
"_covert_a_1_rel" : [ SenseInfo('01705655-a', 0), SenseInfo('01885614-a', 0) ],
"_chord_n_1_rel" : [ SenseInfo('13874927-n', 2), SenseInfo('06869951-n', 2) ],
"_swipe_n_1_rel" : [ SenseInfo('00566040-n', 0) ],
"_cheetah_n_1_rel" : [ SenseInfo('02130308-n', 0) ],
"_showing_n_of_rel" : [ SenseInfo('06888345-n', 1), SenseInfo('00521209-n', 1), SenseInfo('06888345-n', 1), SenseInfo('00521209-n', 1) ],
"_cling_v_1_rel" : [ SenseInfo('01220885-v', 9), SenseInfo('01776065-v', 5), SenseInfo('01216331-v', 2) ],
"_estimate_n_of_rel" : [ SenseInfo('05803379-n', 13), SenseInfo('00875246-n', 5), SenseInfo('06528783-n', 3), SenseInfo('06783598-n', 2), SenseInfo('06207029-n', 0), SenseInfo('05803379-n', 13), SenseInfo('00875246-n', 5), SenseInfo('06528783-n', 3), SenseInfo('06783598-n', 2), SenseInfo('06207029-n', 0) ],
"_midway_a_1_rel" : [ SenseInfo('00330506-a', 2), SenseInfo('00330506-a', 2) ],
"_dishonor_n_1_rel" : [ SenseInfo('14439447-n', 1), SenseInfo('04873939-n', 0), SenseInfo('14439447-n', 1), SenseInfo('04873939-n', 0) ],
"_grow_v_cause_rel" : [ SenseInfo('00125841-v', 70), SenseInfo('00230746-v', 62), SenseInfo('00231557-v', 32), SenseInfo('00245457-v', 12), SenseInfo('00250181-v', 8), SenseInfo('02624263-v', 7), SenseInfo('01739814-v', 3), SenseInfo('00094460-v', 3), SenseInfo('00543410-v', 2), SenseInfo('00250539-v', 0) ],
"_generation_n_of_rel" : [ SenseInfo('08369406-n', 8), SenseInfo('08368907-n', 7), SenseInfo('15249636-n', 6), SenseInfo('15290930-n', 0), SenseInfo('07324380-n', 0), SenseInfo('00922144-n', 0), SenseInfo('00849982-n', 0), SenseInfo('08369406-n', 8), SenseInfo('08368907-n', 7), SenseInfo('15249636-n', 6), SenseInfo('15290930-n', 0), SenseInfo('07324380-n', 0), SenseInfo('00922144-n', 0), SenseInfo('00849982-n', 0) ],
"_gap_n_1_rel" : [ SenseInfo('04752859-n', 3), SenseInfo('09379111-n', 2), SenseInfo('03416329-n', 2), SenseInfo('09249034-n', 0), SenseInfo('07183853-n', 0), SenseInfo('00383952-n', 0) ],
"_cold+sober_a_1_rel" : [ SenseInfo('00799716-a', 1) ],
"_ram_v_1_rel" : [ SenseInfo('01575146-v', 2), SenseInfo('01516534-v', 2), SenseInfo('01561819-v', 1), SenseInfo('01524298-v', 0), SenseInfo('01575146-v', 2), SenseInfo('01516534-v', 2), SenseInfo('01561819-v', 1), SenseInfo('01524298-v', 0) ],
"_derrick_n_1_rel" : [ SenseInfo('03178538-n', 1), SenseInfo('03178430-n', 0) ],
"_exhaust_n_1_rel" : [ SenseInfo('14837364-n', 0), SenseInfo('03302938-n', 0) ],
"_null_n_1_rel" : [ SenseInfo('13740168-n', 0) ],
"_trinitarian_a_1_rel" : [ SenseInfo('10738787-n', 0) ],
"_stabilize_v_1_rel" : [ SenseInfo('00270826-v', 2), SenseInfo('01219993-v', 0), SenseInfo('00271946-v', 0), SenseInfo('00270826-v', 2), SenseInfo('01219993-v', 0), SenseInfo('00271946-v', 0) ],
"_chronological_a_1_rel" : [ SenseInfo('02956880-a', 0) ],
"_hymn_n_1_rel" : [ SenseInfo('07035870-n', 7) ],
"_rational_a_1_rel" : [ SenseInfo('01925372-a', 4), SenseInfo('01780343-a', 1), SenseInfo('02929901-a', 0), SenseInfo('01333118-a', 0) ],
"_irreconcilable_a_1_rel" : [ SenseInfo('01986926-a', 1) ],
"_isolate_v_1_rel" : [ SenseInfo('00494269-v', 12), SenseInfo('00496770-v', 3), SenseInfo('00495808-v', 2), SenseInfo('00655378-v', 0), SenseInfo('00494269-v', 12), SenseInfo('00496770-v', 3), SenseInfo('00495808-v', 2), SenseInfo('00655378-v', 0), SenseInfo('00494269-v', 12), SenseInfo('00496770-v', 3), SenseInfo('00495808-v', 2), SenseInfo('00655378-v', 0), SenseInfo('00494269-v', 12), SenseInfo('00496770-v', 3), SenseInfo('00495808-v', 2), SenseInfo('00655378-v', 0), SenseInfo('00494269-v', 12), SenseInfo('00496770-v', 3), SenseInfo('00495808-v', 2), SenseInfo('00655378-v', 0) ],
"_abduce_v_1_rel" : [ SenseInfo('01015866-v', 0) ],
"_laver_n_1_rel" : [ SenseInfo('11119634-n', 0), SenseInfo('03649288-n', 0), SenseInfo('01415524-n', 0), SenseInfo('01408743-n', 0) ],
"_compilation_n_of_rel" : [ SenseInfo('06593099-n', 0), SenseInfo('01014731-n', 0) ],
"_calculate_v_1_rel" : [ SenseInfo('00637259-v', 21), SenseInfo('00712135-v', 3), SenseInfo('02265231-v', 0), SenseInfo('00926472-v', 0), SenseInfo('00713015-v', 0), SenseInfo('00712708-v', 0), SenseInfo('00637259-v', 21), SenseInfo('00712135-v', 3), SenseInfo('02265231-v', 0), SenseInfo('00926472-v', 0), SenseInfo('00713015-v', 0), SenseInfo('00712708-v', 0), SenseInfo('00637259-v', 21), SenseInfo('00712135-v', 3), SenseInfo('02265231-v', 0), SenseInfo('00926472-v', 0), SenseInfo('00713015-v', 0), SenseInfo('00712708-v', 0), SenseInfo('00637259-v', 21), SenseInfo('00712135-v', 3), SenseInfo('02265231-v', 0), SenseInfo('00926472-v', 0), SenseInfo('00713015-v', 0), SenseInfo('00712708-v', 0) ],
"_relaxation_n_of_rel" : [ SenseInfo('13549488-n', 0), SenseInfo('13549311-n', 0), SenseInfo('07515974-n', 0), SenseInfo('07443210-n', 0), SenseInfo('01064148-n', 0), SenseInfo('00873798-n', 0), SenseInfo('00355691-n', 0) ],
"_calcium_n_1_rel" : [ SenseInfo('14632648-n', 3) ],
"_extrude_v_cause_rel" : [ SenseInfo('01675780-v', 1) ],
"_socialist_a_1_rel" : [ SenseInfo('00298041-a', 0) ],
"_anti-Semite_n_1_rel" : [ SenseInfo('09797742-n', 5), SenseInfo('09797742-n', 5), SenseInfo('09797742-n', 5) ],
"_gamester_n_1_rel" : [  ],
"_want_v_out-of_rel" : [ SenseInfo('01825237-v', 389), SenseInfo('01188725-v', 15), SenseInfo('01317064-v', 3), SenseInfo('00709205-v', 2), SenseInfo('02632567-v', 0) ],
"_aquamarine_a_1_rel" : [ SenseInfo('14767663-n', 0), SenseInfo('04969798-n', 0) ],
"_grove_n_1_rel" : [ SenseInfo('08438928-n', 6), SenseInfo('03463832-n', 2) ],
"_romanesque_a_1_rel" : [ SenseInfo('05842706-n', 0) ],
"_counterweight_n_1_rel" : [ SenseInfo('03118539-n', 0), SenseInfo('03118539-n', 0) ],
"_nematode_n_1_rel" : [ SenseInfo('01930112-n', 0) ],
"_make-work_n_1_rel" : [ SenseInfo('00581621-n', 1) ],
"_out+of+town_a_1_rel" : [ SenseInfo('00446605-a', 3), SenseInfo('00446605-a', 3) ],
"_ruminant_n_1_rel" : [ SenseInfo('02399000-n', 0) ],
"_consent_v_1_rel" : [ SenseInfo('00797697-v', 6) ],
"_tortilla_n_1_rel" : [ SenseInfo('07880583-n', 0) ],
"_striker_n_1_rel" : [ SenseInfo('10663996-n', 0), SenseInfo('10663858-n', 0), SenseInfo('10663745-n', 0), SenseInfo('10178216-n', 0), SenseInfo('04337740-n', 0) ],
"_commuter_n_1_rel" : [ SenseInfo('03078802-n', 6), SenseInfo('09945745-n', 2) ],
"_knot_v_up_rel" : [ SenseInfo('01673732-v', 1), SenseInfo('01300144-v', 1), SenseInfo('01521124-v', 0), SenseInfo('01673732-v', 1), SenseInfo('01300144-v', 1), SenseInfo('01521124-v', 0) ],
"_pitcher_n_of_rel" : [ SenseInfo('10435988-n', 15), SenseInfo('03950228-n', 2), SenseInfo('13768748-n', 1), SenseInfo('12780168-n', 0), SenseInfo('00722984-n', 0) ],
"_catch-up_n_1_rel" : [  ],
"_by-law_n_1_rel" : [ SenseInfo('06537951-n', 0), SenseInfo('06537951-n', 0) ],
"_balance-of-payments_a_1_rel" : [  ],
"_consonant_a_1_rel" : [ SenseInfo('01163320-a', 0), SenseInfo('00577122-a', 0) ],
"_carambola_n_1_rel" : [ SenseInfo('12704343-n', 0), SenseInfo('07746551-n', 0) ],
"_argentinian_n_1_rel" : [ SenseInfo('09691149-n', 0) ],
"_annotate_v_1_rel" : [ SenseInfo('01704953-v', 0), SenseInfo('00961329-v', 0) ],
"_lucid_a_1_rel" : [ SenseInfo('00429355-a', 3), SenseInfo('02073970-a', 0), SenseInfo('01925708-a', 0), SenseInfo('00431774-a', 0) ],
"_diverse_a_1_rel" : [ SenseInfo('02067719-a', 4), SenseInfo('02067491-a', 1) ],
"_highwayman_n_1_rel" : [ SenseInfo('10175507-n', 2) ],
"_heady_a_1_rel" : [ SenseInfo('01898722-a', 0), SenseInfo('00922228-a', 0), SenseInfo('00250739-a', 0), SenseInfo('01898722-a', 0), SenseInfo('00922228-a', 0), SenseInfo('00250739-a', 0), SenseInfo('01898722-a', 0), SenseInfo('00922228-a', 0), SenseInfo('00250739-a', 0) ],
"_festival_n_1_rel" : [ SenseInfo('15162388-n', 2), SenseInfo('00517728-n', 0) ],
"_adopt_v_1_rel" : [ SenseInfo('02346895-v', 34), SenseInfo('02346724-v', 6), SenseInfo('02381726-v', 2), SenseInfo('00524682-v', 2), SenseInfo('00413195-v', 2), SenseInfo('01701311-v', 0), SenseInfo('00601822-v', 0) ],
"_virginal_a_1_rel" : [ SenseInfo('02824922-a', 0), SenseInfo('01907878-a', 0), SenseInfo('00361125-a', 0) ],
"_reception_n_of_rel" : [ SenseInfo('06630852-n', 4), SenseInfo('08254331-n', 3), SenseInfo('06281040-n', 3), SenseInfo('00090253-n', 1), SenseInfo('00139919-n', 0) ],
"_mythological_a_1_rel" : [ SenseInfo('01936184-a', 12) ],
"_pawn_v_1_rel" : [ SenseInfo('02347220-v', 0) ],
"_ferret_v_out_rel" : [ SenseInfo('02003910-v', 0), SenseInfo('01144550-v', 0), SenseInfo('00722065-v', 0) ],
"_afford_v_1_rel" : [ SenseInfo('01192628-v', 24), SenseInfo('02339171-v', 13), SenseInfo('02744451-v', 0), SenseInfo('02358034-v', 0), SenseInfo('01192628-v', 24), SenseInfo('02339171-v', 13), SenseInfo('02744451-v', 0), SenseInfo('02358034-v', 0), SenseInfo('01192628-v', 24), SenseInfo('02339171-v', 13), SenseInfo('02744451-v', 0), SenseInfo('02358034-v', 0) ],
"_rave_v_1_rel" : [ SenseInfo('02492054-v', 0), SenseInfo('01051956-v', 0), SenseInfo('00882220-v', 0) ],
"_abatable_a_1_rel" : [ SenseInfo('02288022-a', 0) ],
"_trance_n_1_rel" : [ SenseInfo('14407536-n', 6), SenseInfo('05681334-n', 1) ],
"_technical_a_1_rel" : [ SenseInfo('02809220-a', 16), SenseInfo('01108716-a', 11), SenseInfo('02809692-a', 5), SenseInfo('02227946-a', 0), SenseInfo('00484070-a', 0), SenseInfo('02809220-a', 16), SenseInfo('01108716-a', 11), SenseInfo('02809692-a', 5), SenseInfo('02227946-a', 0), SenseInfo('00484070-a', 0) ],
"_grandeur_n_1_rel" : [ SenseInfo('04814238-n', 3), SenseInfo('04870340-n', 1) ],
"_airmail_n_1_rel" : [ SenseInfo('06622993-n', 0), SenseInfo('06264812-n', 0) ],
"_thrust_v_out_rel" : [ SenseInfo('01899262-v', 11), SenseInfo('02094569-v', 7), SenseInfo('02062212-v', 4), SenseInfo('00747418-v', 3), SenseInfo('01441510-v', 1), SenseInfo('02714057-v', 0), SenseInfo('02713852-v', 0), SenseInfo('01499265-v', 0) ],
"_melt_v_1_rel" : [ SenseInfo('00444629-v', 3), SenseInfo('00376106-v', 2), SenseInfo('00254486-v', 2), SenseInfo('00395841-v', 1), SenseInfo('00224651-v', 0), SenseInfo('00223928-v', 0) ],
"_inadequate_a_1_rel" : [ SenseInfo('00051696-a', 14), SenseInfo('02336904-a', 0), SenseInfo('00051696-a', 14), SenseInfo('02336904-a', 0) ],
"_redevelopment_n_of_rel" : [ SenseInfo('00265119-n', 1) ],
"_subsidy_n_of_rel" : [ SenseInfo('13267014-n', 1) ],
"_remain_v_1_rel" : [ SenseInfo('00117985-v', 128), SenseInfo('02727462-v', 38), SenseInfo('02637592-v', 34), SenseInfo('02731024-v', 9), SenseInfo('00117985-v', 128), SenseInfo('02727462-v', 38), SenseInfo('02637592-v', 34), SenseInfo('02731024-v', 9), SenseInfo('00117985-v', 128), SenseInfo('02727462-v', 38), SenseInfo('02637592-v', 34), SenseInfo('02731024-v', 9), SenseInfo('00117985-v', 128), SenseInfo('02727462-v', 38), SenseInfo('02637592-v', 34), SenseInfo('02731024-v', 9), SenseInfo('00117985-v', 128), SenseInfo('02727462-v', 38), SenseInfo('02637592-v', 34), SenseInfo('02731024-v', 9), SenseInfo('00117985-v', 128), SenseInfo('02727462-v', 38), SenseInfo('02637592-v', 34), SenseInfo('02731024-v', 9) ],
"_corduroy_n_1_rel" : [ SenseInfo('03106722-n', 1), SenseInfo('03107609-n', 0) ],
"_metric_a_1_rel" : [ SenseInfo('02995636-a', 0), SenseInfo('02020310-a', 0) ],
"_fifth+prize_n_1_rel" : [  ],
"_snobby_a_1_rel" : [ SenseInfo('01858740-a', 0) ],
"_referral_n_of_rel" : [ SenseInfo('10514255-n', 0), SenseInfo('06672040-n', 0), SenseInfo('00121904-n', 0) ],
"_negative_a_1_rel" : [ SenseInfo('01818234-a', 12), SenseInfo('00075515-a', 2), SenseInfo('01128508-a', 1), SenseInfo('01820861-a', 0), SenseInfo('01820338-a', 0), SenseInfo('01819976-a', 0), SenseInfo('00587890-a', 0), SenseInfo('00358534-a', 0), SenseInfo('00065667-a', 0), SenseInfo('01818234-a', 12), SenseInfo('00075515-a', 2), SenseInfo('01128508-a', 1), SenseInfo('01820861-a', 0), SenseInfo('01820338-a', 0), SenseInfo('01819976-a', 0), SenseInfo('00587890-a', 0), SenseInfo('00358534-a', 0), SenseInfo('00065667-a', 0) ],
"_feel-good_a_1_rel" : [  ],
"_cutback_n_1_rel" : [ SenseInfo('00353782-n', 0) ],
"_bøverdaler_n_1_rel" : [  ],
"_villain_n_1_rel" : [ SenseInfo('10753546-n', 2), SenseInfo('10753779-n', 1) ],
"_rally_n_1_rel" : [ SenseInfo('08358332-n', 2), SenseInfo('00045646-n', 1), SenseInfo('13545845-n', 0), SenseInfo('07459157-n', 0), SenseInfo('01166517-n', 0) ],
"_siphon_v_1_rel" : [ SenseInfo('01853542-v', 0), SenseInfo('01613391-v', 0) ],
"_pretty+near_x_deg_rel" : [  ],
"_dandelion_n_1_rel" : [ SenseInfo('12024176-n', 1) ],
"_jolt_v_1_rel" : [ SenseInfo('01864865-v', 1), SenseInfo('01762963-v', 0) ],
"_outside+of_p_rel" : [  ],
"_supplement_n_of_rel" : [ SenseInfo('06399631-n', 4), SenseInfo('05110772-n', 4), SenseInfo('02671421-n', 4) ],
"_benign_a_1_rel" : [ SenseInfo('02594565-a', 0), SenseInfo('00226618-a', 0), SenseInfo('01372773-a', 0) ],
"_manpower_n_1_rel" : [ SenseInfo('08212347-n', 4) ],
"_confidant_n_1_rel" : [ SenseInfo('09954639-n', 2) ],
"_nonsense_n_1_rel" : [ SenseInfo('06607339-n', 5), SenseInfo('03376438-n', 0) ],
"_select_a_1_rel" : [ SenseInfo('02342899-a', 2), SenseInfo('02342309-a', 0) ],
"_draft_n_1_rel" : [ SenseInfo('13377268-n', 1), SenseInfo('11522448-n', 1), SenseInfo('03230785-n', 1), SenseInfo('07883980-n', 0), SenseInfo('06390962-n', 0), SenseInfo('05135155-n', 0), SenseInfo('03230914-n', 0), SenseInfo('03230670-n', 0), SenseInfo('01157850-n', 0), SenseInfo('00840189-n', 0), SenseInfo('00115667-n', 0) ],
"_rest_v_up_rel" : [ SenseInfo('01545883-v', 20), SenseInfo('00779360-v', 8), SenseInfo('00779601-v', 6), SenseInfo('02731390-v', 4), SenseInfo('00014405-v', 4), SenseInfo('00117985-v', 2), SenseInfo('02664664-v', 1), SenseInfo('01610101-v', 1), SenseInfo('01543731-v', 1), SenseInfo('01502946-v', 1), SenseInfo('02595840-v', 0) ],
"_move_v_out_rel" : [ SenseInfo('01835496-v', 110), SenseInfo('01850315-v', 57), SenseInfo('01831531-v', 52), SenseInfo('01855606-v', 20), SenseInfo('02372605-v', 15), SenseInfo('00014549-v', 7), SenseInfo('00124442-v', 6), SenseInfo('02367363-v', 3), SenseInfo('01767949-v', 3), SenseInfo('01649999-v', 3), SenseInfo('01771390-v', 2), SenseInfo('02355959-v', 1), SenseInfo('00539110-v', 1), SenseInfo('02598863-v', 0), SenseInfo('01076615-v', 0), SenseInfo('00879356-v', 0), SenseInfo('01835496-v', 110), SenseInfo('01850315-v', 57), SenseInfo('01831531-v', 52), SenseInfo('01855606-v', 20), SenseInfo('02372605-v', 15), SenseInfo('00014549-v', 7), SenseInfo('00124442-v', 6), SenseInfo('02367363-v', 3), SenseInfo('01767949-v', 3), SenseInfo('01649999-v', 3), SenseInfo('01771390-v', 2), SenseInfo('02355959-v', 1), SenseInfo('00539110-v', 1), SenseInfo('02598863-v', 0), SenseInfo('01076615-v', 0), SenseInfo('00879356-v', 0) ],
"_outfit_n_1_rel" : [ SenseInfo('08274826-n', 7), SenseInfo('03859958-n', 1), SenseInfo('03619396-n', 1) ],
"_vocational_a_1_rel" : [ SenseInfo('02840478-a', 49) ],
"_scare_v_1_rel" : [ SenseInfo('01779165-v', 4), SenseInfo('01785748-v', 2), SenseInfo('01779165-v', 4), SenseInfo('01785748-v', 2) ],
"_soap_n_1_rel" : [ SenseInfo('04253437-n', 9), SenseInfo('13285101-n', 0), SenseInfo('04253751-n', 0) ],
"_dune_n_1_rel" : [ SenseInfo('09270735-n', 1) ],
"_corral_v_1_rel" : [ SenseInfo('01600478-v', 1), SenseInfo('01466198-v', 0), SenseInfo('01381796-v', 0) ],
"_cashier_n_1_rel" : [ SenseInfo('10698970-n', 0), SenseInfo('09899289-n', 0) ],
"_semester_n_1_rel" : [ SenseInfo('15225797-n', 0), SenseInfo('15204485-n', 0), SenseInfo('15225797-n', 0), SenseInfo('15204485-n', 0) ],
"_presence_n_1_rel" : [ SenseInfo('13957601-n', 30), SenseInfo('08642632-n', 6), SenseInfo('09547528-n', 2), SenseInfo('05917174-n', 2), SenseInfo('04910377-n', 1), SenseInfo('01233802-n', 0) ],
"_iron_n_1_rel" : [ SenseInfo('14642417-n', 15), SenseInfo('03585073-n', 2), SenseInfo('03585337-n', 0), SenseInfo('03584829-n', 0) ],
"_ilium_n_1_rel" : [ SenseInfo('08788887-n', 0), SenseInfo('05275315-n', 0) ],
"_mad_a_at_rel" : [ SenseInfo('00115193-a', 12), SenseInfo('02075321-a', 10), SenseInfo('02390724-a', 9), SenseInfo('02572038-a', 0) ],
"_puree_v_1_rel" : [ SenseInfo('01250474-v', 0), SenseInfo('01250474-v', 0) ],
"_preacher_n_1_rel" : [ SenseInfo('10464178-n', 8) ],
"_icing_n_1_rel" : [ SenseInfo('13485270-n', 0), SenseInfo('07620822-n', 0), SenseInfo('00558181-n', 0) ],
"_chat_v_up_rel" : [ SenseInfo('01038666-v', 2) ],
"_point_v_out-to_rel" : [ SenseInfo('00923793-v', 25), SenseInfo('02713184-v', 8), SenseInfo('01152214-v', 8), SenseInfo('01931768-v', 5), SenseInfo('00921300-v', 1), SenseInfo('01928154-v', 0), SenseInfo('01589363-v', 0), SenseInfo('01589224-v', 0), SenseInfo('01589056-v', 0), SenseInfo('01152670-v', 0), SenseInfo('01150559-v', 0), SenseInfo('00924255-v', 0), SenseInfo('00392960-v', 0), SenseInfo('00261957-v', 0), SenseInfo('00923793-v', 25), SenseInfo('02713184-v', 8), SenseInfo('01152214-v', 8), SenseInfo('01931768-v', 5), SenseInfo('00921300-v', 1), SenseInfo('01928154-v', 0), SenseInfo('01589363-v', 0), SenseInfo('01589224-v', 0), SenseInfo('01589056-v', 0), SenseInfo('01152670-v', 0), SenseInfo('01150559-v', 0), SenseInfo('00924255-v', 0), SenseInfo('00392960-v', 0), SenseInfo('00261957-v', 0), SenseInfo('00923793-v', 25), SenseInfo('02713184-v', 8), SenseInfo('01152214-v', 8), SenseInfo('01931768-v', 5), SenseInfo('00921300-v', 1), SenseInfo('01928154-v', 0), SenseInfo('01589363-v', 0), SenseInfo('01589224-v', 0), SenseInfo('01589056-v', 0), SenseInfo('01152670-v', 0), SenseInfo('01150559-v', 0), SenseInfo('00924255-v', 0), SenseInfo('00392960-v', 0), SenseInfo('00261957-v', 0) ],
"_modern_a_1_rel" : [ SenseInfo('01535709-a', 57), SenseInfo('00972902-a', 6), SenseInfo('00414354-a', 5), SenseInfo('01876261-a', 3), SenseInfo('00820975-a', 0) ],
"_suspect_n_1_rel" : [ SenseInfo('10681383-n', 1), SenseInfo('09762101-n', 0) ],
"_envious_a_1_rel" : [ SenseInfo('00888765-a', 1) ],
"_narcotic_a_1_rel" : [ SenseInfo('02863111-a', 0), SenseInfo('02308840-a', 0), SenseInfo('01346198-a', 0) ],
"_nightingale_n_1_rel" : [ SenseInfo('01560105-n', 2), SenseInfo('11207410-n', 0) ],
"_bluff_a_1_rel" : [ SenseInfo('01145422-a', 0), SenseInfo('00764301-a', 0) ],
"_toss_v_out_rel" : [ SenseInfo('01512625-v', 13), SenseInfo('01893079-v', 10), SenseInfo('01514525-v', 5), SenseInfo('01890792-v', 4), SenseInfo('02222318-v', 1), SenseInfo('01418536-v', 1) ],
"_restructure_v_cause_rel" : [ SenseInfo('00404401-v', 0) ],
"_overdue_a_1_rel" : [ SenseInfo('00137120-a', 0) ],
"_crimp_n_1_rel" : [ SenseInfo('13907415-n', 0), SenseInfo('09978566-n', 0), SenseInfo('05258299-n', 0) ],
"_stab_n_1_rel" : [ SenseInfo('07494972-n', 0), SenseInfo('01173965-n', 0), SenseInfo('00788473-n', 0) ],
"_anthropoid_a_1_rel" : [ SenseInfo('01260282-a', 0), SenseInfo('01259015-a', 0) ],
"_coercion_n_1_rel" : [ SenseInfo('01127245-n', 0), SenseInfo('00156812-n', 0) ],
"_all+the_x_deg_rel" : [  ],
"_evident_a_to_rel" : [ SenseInfo('01618376-a', 24), SenseInfo('01287486-a', 1), SenseInfo('01618376-a', 24), SenseInfo('01287486-a', 1), SenseInfo('01618376-a', 24), SenseInfo('01287486-a', 1), SenseInfo('01618376-a', 24), SenseInfo('01287486-a', 1) ],
"_racket_n_1_rel" : [ SenseInfo('07390945-n', 3), SenseInfo('00775943-n', 1), SenseInfo('05720248-n', 0), SenseInfo('04039381-n', 0) ],
"_great_a_1_rel" : [ SenseInfo('01386883-a', 114), SenseInfo('01278818-a', 38), SenseInfo('01677433-a', 18), SenseInfo('01123879-a', 7), SenseInfo('01467919-a', 0), SenseInfo('00173391-a', 0), SenseInfo('01386883-a', 114), SenseInfo('01278818-a', 38), SenseInfo('01677433-a', 18), SenseInfo('01123879-a', 7), SenseInfo('01467919-a', 0), SenseInfo('00173391-a', 0), SenseInfo('01386883-a', 114), SenseInfo('01278818-a', 38), SenseInfo('01677433-a', 18), SenseInfo('01123879-a', 7), SenseInfo('01467919-a', 0), SenseInfo('00173391-a', 0) ],
"_bring_v_forth_rel" : [ SenseInfo('02077656-v', 122), SenseInfo('01438902-v', 55), SenseInfo('01629589-v', 31), SenseInfo('01433294-v', 19), SenseInfo('00135857-v', 9), SenseInfo('01434140-v', 4), SenseInfo('01618547-v', 3), SenseInfo('02324478-v', 2), SenseInfo('02247390-v', 1), SenseInfo('01808218-v', 0), SenseInfo('00767334-v', 0) ],
"_little_n_1_rel" : [ SenseInfo('13762717-n', 12) ],
"_above_p_rel" : [ SenseInfo('00079947-r', 32), SenseInfo('00125993-a', 13), SenseInfo('00080169-r', 9), SenseInfo('06392660-n', 0), SenseInfo('00079947-r', 32), SenseInfo('00125993-a', 13), SenseInfo('00080169-r', 9), SenseInfo('06392660-n', 0), SenseInfo('00079947-r', 32), SenseInfo('00125993-a', 13), SenseInfo('00080169-r', 9), SenseInfo('06392660-n', 0) ],
"_zigzag_n_1_rel" : [ SenseInfo('13887319-n', 0), SenseInfo('13887319-n', 0) ],
"_ward_v_off_rel" : [ SenseInfo('01129337-v', 0) ],
"_arcade_n_1_rel" : [ SenseInfo('02733378-n', 0), SenseInfo('02733213-n', 0) ],
"_normal_n_1_rel" : [ SenseInfo('05667613-n', 0), SenseInfo('05667613-n', 0) ],
"_part-of-speech_n_1_rel" : [ SenseInfo('06317464-n', 1), SenseInfo('06317464-n', 1) ],
"_slug_v_down_rel" : [ SenseInfo('01415585-v', 7), SenseInfo('02417504-v', 0) ],
"_madame_n_1_rel" : [ SenseInfo('10279778-n', 0), SenseInfo('10279778-n', 0), SenseInfo('10279778-n', 0), SenseInfo('10279778-n', 0) ],
"_begotten_a_1_rel" : [ SenseInfo('01406058-a', 0) ],
"_preamble_n_1_rel" : [ SenseInfo('06398090-n', 1) ],
"_bloc_n_1_rel" : [ SenseInfo('08171094-n', 1) ],
"_buoy_v_1_rel" : [ SenseInfo('01904795-v', 0), SenseInfo('01218512-v', 0), SenseInfo('00922771-v', 0) ],
"_thrifty_a_1_rel" : [ SenseInfo('02421158-a', 2), SenseInfo('01895099-a', 0), SenseInfo('02421158-a', 2), SenseInfo('01895099-a', 0), SenseInfo('02421158-a', 2), SenseInfo('01895099-a', 0) ],
"_slipper_n_1_rel" : [ SenseInfo('04241394-n', 5), SenseInfo('10605088-n', 0) ],
"_conduct_n_1_rel" : [ SenseInfo('01220984-n', 5), SenseInfo('04897762-n', 3) ],
"_post_v_1_rel" : [ SenseInfo('01591621-v', 3), SenseInfo('00991683-v', 3), SenseInfo('02385634-v', 1), SenseInfo('01088923-v', 1), SenseInfo('00999715-v', 1), SenseInfo('02473331-v', 0), SenseInfo('02233195-v', 0), SenseInfo('01960105-v', 0), SenseInfo('01591476-v', 0), SenseInfo('01570403-v', 0), SenseInfo('01031256-v', 0), SenseInfo('01031109-v', 0), SenseInfo('01591621-v', 3), SenseInfo('00991683-v', 3), SenseInfo('02385634-v', 1), SenseInfo('01088923-v', 1), SenseInfo('00999715-v', 1), SenseInfo('02473331-v', 0), SenseInfo('02233195-v', 0), SenseInfo('01960105-v', 0), SenseInfo('01591476-v', 0), SenseInfo('01570403-v', 0), SenseInfo('01031256-v', 0), SenseInfo('01031109-v', 0) ],
"_productive_a_of_rel" : [ SenseInfo('01865197-a', 8), SenseInfo('01867295-a', 1), SenseInfo('02332604-a', 1), SenseInfo('01081340-a', 0), SenseInfo('01865197-a', 8), SenseInfo('01867295-a', 1), SenseInfo('02332604-a', 1), SenseInfo('01081340-a', 0) ],
"_healthcare_n_1_rel" : [ SenseInfo('01059900-n', 0) ],
"_apprehend_v_1_rel" : [ SenseInfo('00588221-v', 2), SenseInfo('01215137-v', 1), SenseInfo('01782432-v', 0) ],
"_purr_v_1_rel" : [ SenseInfo('02188587-v', 0), SenseInfo('01052936-v', 0), SenseInfo('02188587-v', 0), SenseInfo('01052936-v', 0) ],
"_situational_a_1_rel" : [  ],
"_handicap_v_1_rel" : [ SenseInfo('00091968-v', 1), SenseInfo('01085874-v', 0), SenseInfo('01085474-v', 0) ],
"_marshal_n_1_rel" : [ SenseInfo('10295951-n', 5), SenseInfo('10296176-n', 0) ],
"_relay_v_1_rel" : [ SenseInfo('00743082-v', 2), SenseInfo('01225576-v', 0), SenseInfo('00743082-v', 2), SenseInfo('01225576-v', 0) ],
"_badge_n_1_rel" : [ SenseInfo('06882561-n', 3), SenseInfo('05851131-n', 2) ],
"_espresso_n_1_rel" : [ SenseInfo('07920052-n', 0) ],
"_pointer_n_1_rel" : [ SenseInfo('06818121-n', 0), SenseInfo('03975232-n', 0), SenseInfo('03150795-n', 0), SenseInfo('02099997-n', 0), SenseInfo('06818121-n', 0), SenseInfo('03975232-n', 0), SenseInfo('03150795-n', 0), SenseInfo('02099997-n', 0) ],
"_periodical_a_1_rel" : [ SenseInfo('01967240-a', 0), SenseInfo('01967240-a', 0) ],
"_screech_n_of_rel" : [ SenseInfo('07393161-n', 1), SenseInfo('07123012-n', 1) ],
"_magistrate_n_1_rel" : [ SenseInfo('10280945-n', 1) ],
"_aperient_a_1_rel" : [ SenseInfo('00637979-a', 0) ],
"_consign_v_to_rel" : [ SenseInfo('02348324-v', 3), SenseInfo('02347637-v', 1), SenseInfo('02348459-v', 0) ],
"_defensive_n_1_rel" : [ SenseInfo('06195249-n', 0) ],
"_vat_n_1_rel" : [ SenseInfo('13316722-n', 0), SenseInfo('04493381-n', 0) ],
"_go_n_i_rel" : [ SenseInfo('15292069-n', 0), SenseInfo('02678738-n', 0), SenseInfo('00787061-n', 0), SenseInfo('00504325-n', 0) ],
"_union_n_of_rel" : [ SenseInfo('08233056-n', 27), SenseInfo('09052314-n', 2), SenseInfo('00847340-n', 1), SenseInfo('14418395-n', 0), SenseInfo('13963970-n', 0), SenseInfo('13571365-n', 0), SenseInfo('08304895-n', 0), SenseInfo('07998712-n', 0), SenseInfo('07373277-n', 0), SenseInfo('04509815-n', 0), SenseInfo('00381680-n', 0) ],
"_wet_v_cause_rel" : [ SenseInfo('00214951-v', 4), SenseInfo('00072730-v', 0) ],
"_divers_a_1_rel" : [ SenseInfo('02067719-a', 0) ],
"_shark_n_1_rel" : [ SenseInfo('01482330-n', 1), SenseInfo('10586674-n', 0), SenseInfo('10586557-n', 0) ],
"_drama_n_1_rel" : [ SenseInfo('07007945-n', 12), SenseInfo('07290278-n', 7), SenseInfo('06376154-n', 2), SenseInfo('04626705-n', 1) ],
"_distance_n_1_rel" : [ SenseInfo('05084201-n', 54), SenseInfo('08556386-n', 18), SenseInfo('05129565-n', 5), SenseInfo('07505871-n', 4), SenseInfo('15172212-n', 1), SenseInfo('15172423-n', 0), SenseInfo('05084201-n', 54), SenseInfo('08556386-n', 18), SenseInfo('05129565-n', 5), SenseInfo('07505871-n', 4), SenseInfo('15172212-n', 1), SenseInfo('15172423-n', 0) ],
"_primarily_x_deg_rel" : [ SenseInfo('00073897-r', 28), SenseInfo('00138410-r', 0), SenseInfo('00073897-r', 28), SenseInfo('00138410-r', 0) ],
"_reprimand_n_1_rel" : [ SenseInfo('06711855-n', 0) ],
"_pilot_v_1_rel" : [ SenseInfo('01941093-v', 1), SenseInfo('01933305-v', 1), SenseInfo('01941093-v', 1), SenseInfo('01933305-v', 1) ],
"_dancer_n_1_rel" : [ SenseInfo('09989502-n', 8), SenseInfo('09990415-n', 0) ],
"_dial-up_n_1_rel" : [  ],
"_politic_a_1_rel" : [ SenseInfo('01813400-a', 1), SenseInfo('00758800-a', 0) ],
"_reflection_n_1_rel" : [ SenseInfo('05785508-n', 8), SenseInfo('11503060-n', 4), SenseInfo('06880249-n', 4), SenseInfo('04747115-n', 2), SenseInfo('04068976-n', 2), SenseInfo('13785404-n', 0), SenseInfo('06767035-n', 0), SenseInfo('05010627-n', 0) ],
"_rocket_v_1_rel" : [ SenseInfo('01944086-v', 0), SenseInfo('01241753-v', 0) ],
"_simplest_a_for_rel" : [  ],
"_cripple_v_1_rel" : [ SenseInfo('00225832-v', 2), SenseInfo('00091647-v', 0) ],
"_fadeout_n_1_rel" : [ SenseInfo('07336214-n', 1), SenseInfo('07431369-n', 0) ],
"_melon_n_1_rel" : [ SenseInfo('07755411-n', 2), SenseInfo('12163824-n', 0) ],
"_sound_a_1_rel" : [ SenseInfo('02273326-a', 8), SenseInfo('01944088-a', 3), SenseInfo('02275209-a', 1), SenseInfo('01171213-a', 1), SenseInfo('02499511-a', 0), SenseInfo('02499148-a', 0), SenseInfo('02037152-a', 0), SenseInfo('00693020-a', 0), SenseInfo('00523786-a', 0), SenseInfo('02273326-a', 8), SenseInfo('01944088-a', 3), SenseInfo('02275209-a', 1), SenseInfo('01171213-a', 1), SenseInfo('02499511-a', 0), SenseInfo('02499148-a', 0), SenseInfo('02037152-a', 0), SenseInfo('00693020-a', 0), SenseInfo('00523786-a', 0), SenseInfo('02273326-a', 8), SenseInfo('01944088-a', 3), SenseInfo('02275209-a', 1), SenseInfo('01171213-a', 1), SenseInfo('02499511-a', 0), SenseInfo('02499148-a', 0), SenseInfo('02037152-a', 0), SenseInfo('00693020-a', 0), SenseInfo('00523786-a', 0), SenseInfo('02273326-a', 8), SenseInfo('01944088-a', 3), SenseInfo('02275209-a', 1), SenseInfo('01171213-a', 1), SenseInfo('02499511-a', 0), SenseInfo('02499148-a', 0), SenseInfo('02037152-a', 0), SenseInfo('00693020-a', 0), SenseInfo('00523786-a', 0) ],
"_dissociate_v_1_rel" : [ SenseInfo('02430580-v', 0), SenseInfo('00714273-v', 0), SenseInfo('00209598-v', 0) ],
"_anonymous_a_1_rel" : [ SenseInfo('00120574-a', 7), SenseInfo('00236652-a', 1), SenseInfo('00120574-a', 7), SenseInfo('00236652-a', 1) ],
"_cram_v_1_rel" : [ SenseInfo('01524298-v', 1), SenseInfo('01612295-v', 0), SenseInfo('00605783-v', 0), SenseInfo('00407146-v', 0), SenseInfo('01524298-v', 1), SenseInfo('01612295-v', 0), SenseInfo('00605783-v', 0), SenseInfo('00407146-v', 0), SenseInfo('01524298-v', 1), SenseInfo('01612295-v', 0), SenseInfo('00605783-v', 0), SenseInfo('00407146-v', 0) ],
"_interject_v_1_rel" : [ SenseInfo('00914769-v', 2), SenseInfo('00914769-v', 2) ],
"_left_a_for_rel" : [ SenseInfo('02032953-a', 35), SenseInfo('00926505-a', 14), SenseInfo('02029438-a', 1), SenseInfo('02030935-a', 0) ],
"_pike_n_1_rel" : [ SenseInfo('03306610-n', 1), SenseInfo('07779375-n', 0), SenseInfo('03935698-n', 0), SenseInfo('03935450-n', 0), SenseInfo('02561108-n', 0) ],
"_chocolate_a_1_rel" : [ SenseInfo('07922764-n', 1), SenseInfo('07601999-n', 0), SenseInfo('04972451-n', 0) ],
"_reduction_n_of_rel" : [ SenseInfo('00351638-n', 16), SenseInfo('13547677-n', 3), SenseInfo('00192300-n', 1) ],
"_decoction_n_1_rel" : [ SenseInfo('13457665-n', 0) ],
"_matter-of-factly_a_1_rel" : [  ],
"_possessive_n_1_rel" : [ SenseInfo('06311852-n', 0) ],
"_maid_n_1_rel" : [ SenseInfo('10282672-n', 13), SenseInfo('10282482-n', 0) ],
"_final_a_1_rel" : [ SenseInfo('01010271-a', 31), SenseInfo('01579128-a', 22), SenseInfo('00349894-a', 3), SenseInfo('01010271-a', 31), SenseInfo('01579128-a', 22), SenseInfo('00349894-a', 3), SenseInfo('01010271-a', 31), SenseInfo('01579128-a', 22), SenseInfo('00349894-a', 3), SenseInfo('01010271-a', 31), SenseInfo('01579128-a', 22), SenseInfo('00349894-a', 3) ],
"_snowplow_n_1_rel" : [ SenseInfo('04252225-n', 0) ],
"_obnoxious_a_1_rel" : [ SenseInfo('01626874-a', 2), SenseInfo('01626874-a', 2) ],
"_crash_v_cause_rel" : [ SenseInfo('01972570-v', 9), SenseInfo('02088627-v', 3), SenseInfo('01561819-v', 2), SenseInfo('02019282-v', 1), SenseInfo('01562061-v', 1), SenseInfo('02657080-v', 0), SenseInfo('02177512-v', 0), SenseInfo('02019011-v', 0), SenseInfo('01562209-v', 0), SenseInfo('01507407-v', 0), SenseInfo('00583064-v', 0), SenseInfo('00434919-v', 0), SenseInfo('00017674-v', 0) ],
"_dispense_v_with_rel" : [ SenseInfo('02294436-v', 3), SenseInfo('02534307-v', 0), SenseInfo('00081072-v', 0) ],
"_ex+spouse_n_1_rel" : [ SenseInfo('10074249-n', 0), SenseInfo('10074249-n', 0) ],
"_permit_v_1_rel" : [ SenseInfo('00802318-v', 55), SenseInfo('02423183-v', 39), SenseInfo('00802946-v', 0), SenseInfo('00802318-v', 55), SenseInfo('02423183-v', 39), SenseInfo('00802946-v', 0), SenseInfo('00802318-v', 55), SenseInfo('02423183-v', 39), SenseInfo('00802946-v', 0) ],
"_hypothesis_n_1_rel" : [ SenseInfo('07162545-n', 4), SenseInfo('05888929-n', 2), SenseInfo('06782680-n', 0), SenseInfo('07162545-n', 4), SenseInfo('05888929-n', 2), SenseInfo('06782680-n', 0) ],
"_trademark_n_1_rel" : [ SenseInfo('04732543-n', 3), SenseInfo('06851742-n', 1) ],
"_occasional_a_1_rel" : [ SenseInfo('01067415-a', 21), SenseInfo('01842468-a', 2), SenseInfo('01961205-a', 0), SenseInfo('00594004-a', 0), SenseInfo('01067415-a', 21), SenseInfo('01842468-a', 2), SenseInfo('01961205-a', 0), SenseInfo('00594004-a', 0) ],
"_gouge_v_out_rel" : [ SenseInfo('01281611-v', 3), SenseInfo('02241107-v', 2), SenseInfo('01281782-v', 2) ],
"_public_n_1_rel" : [ SenseInfo('08179689-n', 35), SenseInfo('07965817-n', 4) ],
"_sizing_n_1_rel" : [ SenseInfo('14706372-n', 0) ],
"_introspective_a_1_rel" : [ SenseInfo('01350674-a', 1) ],
"_sin_v_1_rel" : [ SenseInfo('02565687-v', 7), SenseInfo('02566227-v', 0) ],
"_prevision_n_of_rel" : [ SenseInfo('05775829-n', 5), SenseInfo('05919431-n', 0), SenseInfo('05805277-n', 0), SenseInfo('05775081-n', 0) ],
"_sentiment_n_1_rel" : [ SenseInfo('07481951-n', 7), SenseInfo('05945642-n', 6) ],
"_bartender_n_1_rel" : [ SenseInfo('09841188-n', 2) ],
"_lap_n_1_rel" : [ SenseInfo('05562595-n', 11), SenseInfo('14515041-n', 0), SenseInfo('03641947-n', 0), SenseInfo('03641706-n', 0), SenseInfo('00295172-n', 0), SenseInfo('00150591-n', 0) ],
"_apple_n_1_rel" : [ SenseInfo('07739125-n', 1), SenseInfo('12633994-n', 0) ],
"_inflame_v_1_rel" : [ SenseInfo('00063724-v', 2), SenseInfo('02761685-v', 0), SenseInfo('02761372-v', 0), SenseInfo('01761120-v', 0), SenseInfo('00063557-v', 0) ],
"_produce_n_1_rel" : [ SenseInfo('07705711-n', 2) ],
"_majesty_n_1_rel" : [ SenseInfo('04729984-n', 1) ],
"_loan_v_1_rel" : [ SenseInfo('02324182-v', 3), SenseInfo('02324182-v', 3), SenseInfo('02324182-v', 3) ],
"_cannabis_n_1_rel" : [ SenseInfo('12396924-n', 0), SenseInfo('02949691-n', 0) ],
"_entropy_n_1_rel" : [ SenseInfo('05091527-n', 0), SenseInfo('05012585-n', 0) ],
"_hunch_v_1_rel" : [ SenseInfo('02035559-v', 2) ],
"_grave_a_1_rel" : [ SenseInfo('02119213-a', 4), SenseInfo('00651039-a', 3), SenseInfo('01278423-a', 0), SenseInfo('02119213-a', 4), SenseInfo('00651039-a', 3), SenseInfo('01278423-a', 0), SenseInfo('02119213-a', 4), SenseInfo('00651039-a', 3), SenseInfo('01278423-a', 0), SenseInfo('02119213-a', 4), SenseInfo('00651039-a', 3), SenseInfo('01278423-a', 0) ],
"_plea_n_1_rel" : [ SenseInfo('07187638-n', 0), SenseInfo('06561138-n', 0), SenseInfo('01197928-n', 0) ],
"_chap_v_cause_rel" : [ SenseInfo('00337428-v', 0) ],
"_fill_v_1_rel" : [ SenseInfo('00452512-v', 61), SenseInfo('00451838-v', 12), SenseInfo('02649042-v', 8), SenseInfo('02394183-v', 5), SenseInfo('01183573-v', 5), SenseInfo('02394081-v', 1), SenseInfo('01203893-v', 1), SenseInfo('01193721-v', 1), SenseInfo('00261533-v', 1) ],
"_napalm_n_1_rel" : [ SenseInfo('14958254-n', 0) ],
"_den_n_1_rel" : [ SenseInfo('08591399-n', 0), SenseInfo('08584218-n', 0), SenseInfo('08214966-n', 0), SenseInfo('03175081-n', 0) ],
"_throw_v_out_rel" : [ SenseInfo('01508368-v', 53), SenseInfo('02097204-v', 9), SenseInfo('01513430-v', 7), SenseInfo('01499265-v', 7), SenseInfo('01060317-v', 6), SenseInfo('01510173-v', 5), SenseInfo('01632897-v', 4), SenseInfo('02097341-v', 2), SenseInfo('01791232-v', 2), SenseInfo('01067664-v', 2), SenseInfo('01733477-v', 1), SenseInfo('01663443-v', 0), SenseInfo('01527754-v', 0), SenseInfo('01437011-v', 0), SenseInfo('00621734-v', 0) ],
"_portentous_a_1_rel" : [ SenseInfo('02164165-a', 2), SenseInfo('01883106-a', 1), SenseInfo('01849960-a', 0) ],
"_sell_v_out_rel" : [ SenseInfo('02242464-v', 73), SenseInfo('02727883-v', 12), SenseInfo('00767635-v', 5), SenseInfo('02244956-v', 4), SenseInfo('02235666-v', 2), SenseInfo('02748355-v', 0), SenseInfo('02748206-v', 0), SenseInfo('02537407-v', 0), SenseInfo('02242464-v', 73), SenseInfo('02727883-v', 12), SenseInfo('00767635-v', 5), SenseInfo('02244956-v', 4), SenseInfo('02235666-v', 2), SenseInfo('02748355-v', 0), SenseInfo('02748206-v', 0), SenseInfo('02537407-v', 0) ],
"_intensely_x_rel" : [ SenseInfo('00190959-r', 3) ],
"_discontented_a_1_rel" : [ SenseInfo('00589624-a', 1) ],
"_rag_n_1_rel" : [ SenseInfo('04045941-n', 9), SenseInfo('15170786-n', 0), SenseInfo('07060844-n', 0), SenseInfo('06267893-n', 0), SenseInfo('00514658-n', 0) ],
"_clammy_a_1_rel" : [ SenseInfo('02548619-a', 2), SenseInfo('02548619-a', 2), SenseInfo('02548619-a', 2) ],
"_steer_n_1_rel" : [ SenseInfo('06651577-n', 0), SenseInfo('02403231-n', 0) ],
"_cosmopolitan_a_1_rel" : [ SenseInfo('01106614-a', 0), SenseInfo('00635955-a', 0), SenseInfo('00527188-a', 0) ],
"_right-of-center_a_1_rel" : [  ],
"_pull_v_in_rel" : [ SenseInfo('01448100-v', 44), SenseInfo('01505254-v', 8), SenseInfo('02057499-v', 6), SenseInfo('01609287-v', 3), SenseInfo('02582615-v', 2), SenseInfo('01995211-v', 2), SenseInfo('02057337-v', 1), SenseInfo('00071803-v', 1), SenseInfo('02103162-v', 0), SenseInfo('01947247-v', 0), SenseInfo('01858573-v', 0), SenseInfo('01573276-v', 0), SenseInfo('01407059-v', 0), SenseInfo('01384275-v', 0), SenseInfo('01351170-v', 0), SenseInfo('01148710-v', 0), SenseInfo('00571596-v', 0), SenseInfo('01448100-v', 44), SenseInfo('01505254-v', 8), SenseInfo('02057499-v', 6), SenseInfo('01609287-v', 3), SenseInfo('02582615-v', 2), SenseInfo('01995211-v', 2), SenseInfo('02057337-v', 1), SenseInfo('00071803-v', 1), SenseInfo('02103162-v', 0), SenseInfo('01947247-v', 0), SenseInfo('01858573-v', 0), SenseInfo('01573276-v', 0), SenseInfo('01407059-v', 0), SenseInfo('01384275-v', 0), SenseInfo('01351170-v', 0), SenseInfo('01148710-v', 0), SenseInfo('00571596-v', 0) ],
"_flight_n_1_rel" : [ SenseInfo('08220534-n', 6), SenseInfo('00302394-n', 6), SenseInfo('03363059-n', 5), SenseInfo('00058743-n', 5), SenseInfo('08220440-n', 3), SenseInfo('05625210-n', 1), SenseInfo('11481334-n', 0), SenseInfo('08220620-n', 0), SenseInfo('00301192-n', 0) ],
"_uncombined_a_1_rel" : [ SenseInfo('01330786-a', 0), SenseInfo('01330786-a', 0) ],
"_feeder_n_1_rel" : [ SenseInfo('01317813-n', 1), SenseInfo('10042300-n', 0), SenseInfo('09278997-n', 0), SenseInfo('04169707-n', 0), SenseInfo('02843553-n', 0), SenseInfo('01317916-n', 0) ],
"_strew_v_with_rel" : [ SenseInfo('01378123-v', 4), SenseInfo('01208896-v', 1) ],
"_unbalance_v_1_rel" : [ SenseInfo('02673630-v', 0), SenseInfo('01764586-v', 0), SenseInfo('02673630-v', 0), SenseInfo('01764586-v', 0) ],
"_reunification_n_of_rel" : [ SenseInfo('00382474-n', 0) ],
"_heartthrob_n_1_rel" : [ SenseInfo('10166313-n', 0) ],
"_assent_n_1_rel" : [ SenseInfo('07175575-n', 5) ],
"_scrape_v_1_rel" : [ SenseInfo('01308160-v', 4), SenseInfo('01750156-v', 1), SenseInfo('01309143-v', 1), SenseInfo('02040709-v', 0), SenseInfo('01384752-v', 0), SenseInfo('01309478-v', 0) ],
"_grandparent_n_of_rel" : [ SenseInfo('10143172-n', 1) ],
"_cord_v_1_rel" : [ SenseInfo('01503841-v', 0), SenseInfo('01286674-v', 0) ],
"_megawatt_n_of_rel" : [ SenseInfo('13644894-n', 0) ],
"_intrepid_a_1_rel" : [ SenseInfo('00250119-a', 0) ],
"_trafficking_n_1_rel" : [  ],
"_undivided_a_1_rel" : [ SenseInfo('02478383-a', 0), SenseInfo('02153359-a', 0), SenseInfo('00539389-a', 0), SenseInfo('00516360-a', 0), SenseInfo('02478383-a', 0), SenseInfo('02153359-a', 0), SenseInfo('00539389-a', 0), SenseInfo('00516360-a', 0) ],
"_enhancement_n_of_rel" : [ SenseInfo('00265992-n', 0) ],
"_supportive_a_of_rel" : [ SenseInfo('02354537-a', 5) ],
"_segmentation_n_1_rel" : [ SenseInfo('13449156-n', 0), SenseInfo('00397953-n', 0) ],
"_typological_a_1_rel" : [  ],
"_critical_a_of_rel" : [ SenseInfo('00647542-a', 7), SenseInfo('00651935-a', 5), SenseInfo('00649586-a', 5), SenseInfo('00903894-a', 3), SenseInfo('00656132-a', 2), SenseInfo('00650577-a', 1), SenseInfo('02830645-a', 0), SenseInfo('00647542-a', 7), SenseInfo('00651935-a', 5), SenseInfo('00649586-a', 5), SenseInfo('00903894-a', 3), SenseInfo('00656132-a', 2), SenseInfo('00650577-a', 1), SenseInfo('02830645-a', 0), SenseInfo('00647542-a', 7), SenseInfo('00651935-a', 5), SenseInfo('00649586-a', 5), SenseInfo('00903894-a', 3), SenseInfo('00656132-a', 2), SenseInfo('00650577-a', 1), SenseInfo('02830645-a', 0), SenseInfo('00647542-a', 7), SenseInfo('00651935-a', 5), SenseInfo('00649586-a', 5), SenseInfo('00903894-a', 3), SenseInfo('00656132-a', 2), SenseInfo('00650577-a', 1), SenseInfo('02830645-a', 0), SenseInfo('00647542-a', 7), SenseInfo('00651935-a', 5), SenseInfo('00649586-a', 5), SenseInfo('00903894-a', 3), SenseInfo('00656132-a', 2), SenseInfo('00650577-a', 1), SenseInfo('02830645-a', 0) ],
"_hostel_n_1_rel" : [ SenseInfo('03541696-n', 0), SenseInfo('03541537-n', 0), SenseInfo('03541696-n', 0), SenseInfo('03541537-n', 0) ],
"_high+tech_a_1_rel" : [ SenseInfo('01208571-a', 0), SenseInfo('01208571-a', 0) ],
"_surge_n_1_rel" : [ SenseInfo('07440240-n', 4), SenseInfo('00364787-n', 2), SenseInfo('07348545-n', 0) ],
"_bodily_a_1_rel" : [ SenseInfo('02667275-a', 0), SenseInfo('01778935-a', 0), SenseInfo('00630329-a', 0), SenseInfo('02667275-a', 0), SenseInfo('01778935-a', 0), SenseInfo('00630329-a', 0) ],
"_hobble_v_2_rel" : [ SenseInfo('01917244-v', 2), SenseInfo('02452240-v', 1), SenseInfo('01289633-v', 0) ],
"_conquest_n_1_rel" : [ SenseInfo('00089027-n', 2), SenseInfo('00065216-n', 1), SenseInfo('00160532-n', 0) ],
"_veranda_n_1_rel" : [ SenseInfo('04527648-n', 4) ],
"_horn_n_1_rel" : [ SenseInfo('03537085-n', 7), SenseInfo('01325417-n', 3), SenseInfo('07265508-n', 1), SenseInfo('03536931-n', 1), SenseInfo('03110669-n', 1), SenseInfo('01325853-n', 1), SenseInfo('14758027-n', 0), SenseInfo('03537241-n', 0), SenseInfo('03536761-n', 0), SenseInfo('03394916-n', 0), SenseInfo('02761834-n', 0) ],
"_mainmast_n_1_rel" : [ SenseInfo('03711999-n', 0) ],
"_unsolved_a_1_rel" : [ SenseInfo('02267164-a', 3), SenseInfo('02267164-a', 3) ],
"_request_v_1_rel" : [ SenseInfo('00752764-v', 11), SenseInfo('00753428-v', 7), SenseInfo('01069809-v', 0), SenseInfo('00752764-v', 11), SenseInfo('00753428-v', 7), SenseInfo('01069809-v', 0), SenseInfo('00752764-v', 11), SenseInfo('00753428-v', 7), SenseInfo('01069809-v', 0), SenseInfo('00752764-v', 11), SenseInfo('00753428-v', 7), SenseInfo('01069809-v', 0) ],
"_grounding_n_1_rel" : [ SenseInfo('05986594-n', 0), SenseInfo('00148836-n', 0) ],
"_miss_v_1_rel" : [ SenseInfo('02127853-v', 16), SenseInfo('01805523-v', 13), SenseInfo('02613672-v', 9), SenseInfo('00614999-v', 6), SenseInfo('02022659-v', 5), SenseInfo('02632353-v', 4), SenseInfo('01237901-v', 4), SenseInfo('02632838-v', 1), SenseInfo('00810557-v', 0) ],
"_anvil_n_1_rel" : [ SenseInfo('02725872-n', 1), SenseInfo('05326340-n', 0) ],
"_pellet_n_1_rel" : [ SenseInfo('13901423-n', 0), SenseInfo('04205759-n', 0) ],
"_breach-of-contract_a_1_rel" : [  ],
"_scandinavian_n_1_rel" : [ SenseInfo('09730204-n', 0), SenseInfo('06953731-n', 0) ],
"_deficit_n_of_rel" : [ SenseInfo('05114371-n', 1), SenseInfo('14449960-n', 0), SenseInfo('13595550-n', 0), SenseInfo('13396276-n', 0) ],
"_overcharge_n_1_rel" : [ SenseInfo('13307784-n', 0) ],
"_all+but_a_1_rel" : [  ],
"_womens_a_1_rel" : [  ],
"_scholarship_n_1_rel" : [ SenseInfo('13266170-n', 7), SenseInfo('05985999-n', 4) ],
"_sneak_n_1_rel" : [ SenseInfo('10616048-n', 0), SenseInfo('10486679-n', 0), SenseInfo('10091012-n', 0) ],
"_mailbox_n_1_rel" : [ SenseInfo('03710193-n', 4), SenseInfo('03989074-n', 0) ],
"_untoward_a_1_rel" : [ SenseInfo('01880918-a', 1), SenseInfo('00997036-a', 0) ],
"_jog_n_1_rel" : [ SenseInfo('13887211-n', 0), SenseInfo('00294190-n', 0), SenseInfo('00112997-n', 0) ],
"_psychiatric_a_1_rel" : [ SenseInfo('02913004-a', 1) ],
"_all-stock_a_1_rel" : [  ],
"_will_v_aux_rel" : [ SenseInfo('00746366-v', 3), SenseInfo('00698398-v', 2), SenseInfo('02229055-v', 0), SenseInfo('00746366-v', 3), SenseInfo('00698398-v', 2), SenseInfo('02229055-v', 0), SenseInfo('00746366-v', 3), SenseInfo('00698398-v', 2), SenseInfo('02229055-v', 0), SenseInfo('00746366-v', 3), SenseInfo('00698398-v', 2), SenseInfo('02229055-v', 0), SenseInfo('00746366-v', 3), SenseInfo('00698398-v', 2), SenseInfo('02229055-v', 0), SenseInfo('00746366-v', 3), SenseInfo('00698398-v', 2), SenseInfo('02229055-v', 0), SenseInfo('00746366-v', 3), SenseInfo('00698398-v', 2), SenseInfo('02229055-v', 0), SenseInfo('00746366-v', 3), SenseInfo('00698398-v', 2), SenseInfo('02229055-v', 0), SenseInfo('00746366-v', 3), SenseInfo('00698398-v', 2), SenseInfo('02229055-v', 0), SenseInfo('00746366-v', 3), SenseInfo('00698398-v', 2), SenseInfo('02229055-v', 0), SenseInfo('00746366-v', 3), SenseInfo('00698398-v', 2), SenseInfo('02229055-v', 0), SenseInfo('00746366-v', 3), SenseInfo('00698398-v', 2), SenseInfo('02229055-v', 0), SenseInfo('00746366-v', 3), SenseInfo('00698398-v', 2), SenseInfo('02229055-v', 0), SenseInfo('00746366-v', 3), SenseInfo('00698398-v', 2), SenseInfo('02229055-v', 0), SenseInfo('00746366-v', 3), SenseInfo('00698398-v', 2), SenseInfo('02229055-v', 0), SenseInfo('00746366-v', 3), SenseInfo('00698398-v', 2), SenseInfo('02229055-v', 0) ],
"_office_n_1_rel" : [ SenseInfo('03841666-n', 62), SenseInfo('08337324-n', 24), SenseInfo('00720565-n', 6), SenseInfo('13945102-n', 2), SenseInfo('08352303-n', 0), SenseInfo('01033458-n', 0), SenseInfo('00586262-n', 0) ],
"_quantitative_a_1_rel" : [ SenseInfo('01914930-a', 5), SenseInfo('02977198-a', 0), SenseInfo('02290714-a', 0), SenseInfo('01914930-a', 5), SenseInfo('02977198-a', 0), SenseInfo('02290714-a', 0) ],
"_understatement_n_1_rel" : [ SenseInfo('06759063-n', 1) ],
"_high+resolution_n_1_rel" : [  ],
"_alienate_v_1_rel" : [ SenseInfo('01823528-v', 3), SenseInfo('02221010-v', 0), SenseInfo('01823888-v', 0), SenseInfo('01823528-v', 3), SenseInfo('02221010-v', 0), SenseInfo('01823888-v', 0) ],
"_accent_n_1_rel" : [ SenseInfo('07131511-n', 5), SenseInfo('14434866-n', 1), SenseInfo('07155661-n', 0), SenseInfo('07085375-n', 0), SenseInfo('06822198-n', 0) ],
"_glare_v_1_rel" : [ SenseInfo('00033203-v', 9), SenseInfo('02765090-v', 0), SenseInfo('02162672-v', 0), SenseInfo('00033203-v', 9), SenseInfo('02765090-v', 0), SenseInfo('02162672-v', 0) ],
"_invoke_v_1_rel" : [ SenseInfo('01629958-v', 6), SenseInfo('01024864-v', 4), SenseInfo('00755447-v', 0) ],
"_shift_v_1_rel" : [ SenseInfo('00380159-v', 13), SenseInfo('01883344-v', 12), SenseInfo('02012344-v', 5), SenseInfo('01893988-v', 2), SenseInfo('00555447-v', 2), SenseInfo('00555654-v', 1), SenseInfo('00548913-v', 1), SenseInfo('01884974-v', 0), SenseInfo('01864634-v', 0), SenseInfo('01005049-v', 0), SenseInfo('00584410-v', 0), SenseInfo('00551065-v', 0), SenseInfo('00550117-v', 0), SenseInfo('00380159-v', 13), SenseInfo('01883344-v', 12), SenseInfo('02012344-v', 5), SenseInfo('01893988-v', 2), SenseInfo('00555447-v', 2), SenseInfo('00555654-v', 1), SenseInfo('00548913-v', 1), SenseInfo('01884974-v', 0), SenseInfo('01864634-v', 0), SenseInfo('01005049-v', 0), SenseInfo('00584410-v', 0), SenseInfo('00551065-v', 0), SenseInfo('00550117-v', 0) ],
"_envision_v_1_rel" : [ SenseInfo('01635432-v', 4), SenseInfo('01636221-v', 3), SenseInfo('01635432-v', 4), SenseInfo('01636221-v', 3) ],
"_far+and+wide_a_1_rel" : [  ],
"_peso_n_1_rel" : [ SenseInfo('13693349-n', 0), SenseInfo('13693084-n', 0), SenseInfo('13692822-n', 0), SenseInfo('13692559-n', 0), SenseInfo('13692278-n', 0), SenseInfo('13692014-n', 0), SenseInfo('13691764-n', 0), SenseInfo('13691509-n', 0) ],
"_con_v_out+of_rel" : [ SenseInfo('02572119-v', 1), SenseInfo('00604576-v', 0) ],
"_instance_n_of_rel" : [ SenseInfo('07308889-n', 18), SenseInfo('05820620-n', 4) ],
"_whip_v_off_rel" : [ SenseInfo('01411085-v', 8), SenseInfo('01102997-v', 4), SenseInfo('01891092-v', 3), SenseInfo('01398032-v', 3), SenseInfo('01417868-v', 0), SenseInfo('00863906-v', 0) ],
"_mallet_n_1_rel" : [ SenseInfo('03715892-n', 0), SenseInfo('03715669-n', 0), SenseInfo('03715386-n', 0) ],
"_shove_n_1_rel" : [ SenseInfo('00113726-n', 0) ],
"_aback_p_sel_rel" : [ SenseInfo('00075739-r', 0), SenseInfo('00075656-r', 0) ],
"_telephone_n_1_rel" : [ SenseInfo('04401088-n', 18), SenseInfo('06272290-n', 1), SenseInfo('04401088-n', 18), SenseInfo('06272290-n', 1), SenseInfo('04401088-n', 18), SenseInfo('06272290-n', 1), SenseInfo('04401088-n', 18), SenseInfo('06272290-n', 1), SenseInfo('04401088-n', 18), SenseInfo('06272290-n', 1), SenseInfo('04401088-n', 18), SenseInfo('06272290-n', 1), SenseInfo('04401088-n', 18), SenseInfo('06272290-n', 1), SenseInfo('04401088-n', 18), SenseInfo('06272290-n', 1), SenseInfo('04401088-n', 18), SenseInfo('06272290-n', 1) ],
"_aerial_n_1_rel" : [ SenseInfo('00561226-n', 1), SenseInfo('02715229-n', 0) ],
"_together+with_p_rel" : [ SenseInfo('00117082-r', 0) ],
"_undo_v_1_rel" : [ SenseInfo('01519977-v', 3), SenseInfo('01619231-v', 1), SenseInfo('02559199-v', 0), SenseInfo('01284908-v', 0), SenseInfo('01284271-v', 0) ],
"_crash-land_v_1_rel" : [ SenseInfo('01980766-v', 0), SenseInfo('01980766-v', 0) ],
"_chain_v_1_rel" : [ SenseInfo('01464931-v', 0), SenseInfo('01288636-v', 0) ],
"_parental_a_1_rel" : [ SenseInfo('02884085-a', 1), SenseInfo('01722529-a', 0) ],
"_formality_n_1_rel" : [ SenseInfo('07455007-n', 0), SenseInfo('04911420-n', 0), SenseInfo('01204055-n', 0) ],
"_give_v_to-i_rel" : [ SenseInfo('02316868-v', 179), SenseInfo('02339171-v', 160), SenseInfo('02199590-v', 96), SenseInfo('02235842-v', 78), SenseInfo('01060494-v', 32), SenseInfo('01733477-v', 29), SenseInfo('01060317-v', 24), SenseInfo('02200686-v', 20), SenseInfo('01629403-v', 18), SenseInfo('00732224-v', 18), SenseInfo('01629000-v', 16), SenseInfo('02296153-v', 14), SenseInfo('01647672-v', 14), SenseInfo('02200498-v', 12), SenseInfo('02562901-v', 10), SenseInfo('02343595-v', 10), SenseInfo('02230772-v', 10), SenseInfo('00887463-v', 8), SenseInfo('02309374-v', 5), SenseInfo('02309165-v', 5), SenseInfo('01060746-v', 5), SenseInfo('02317094-v', 4), SenseInfo('01848465-v', 4), SenseInfo('01178565-v', 4), SenseInfo('02308741-v', 3), SenseInfo('01989053-v', 1), SenseInfo('00673571-v', 1), SenseInfo('02564052-v', 0), SenseInfo('02359553-v', 0), SenseInfo('02358034-v', 0), SenseInfo('01716283-v', 0), SenseInfo('01716112-v', 0), SenseInfo('01449796-v', 0), SenseInfo('01175810-v', 0), SenseInfo('01069638-v', 0), SenseInfo('00944247-v', 0), SenseInfo('00888009-v', 0), SenseInfo('00878876-v', 0), SenseInfo('00771806-v', 0), SenseInfo('00748972-v', 0), SenseInfo('00748616-v', 0), SenseInfo('00341184-v', 0), SenseInfo('00108747-v', 0), SenseInfo('00108604-v', 0) ],
"_sleighride_n_1_rel" : [  ],
"_follow_v_up_rel" : [ SenseInfo('01998432-v', 74), SenseInfo('02712772-v', 50), SenseInfo('02720149-v', 26), SenseInfo('01991931-v', 20), SenseInfo('02542280-v', 18), SenseInfo('02720354-v', 17), SenseInfo('00150776-v', 13), SenseInfo('02720544-v', 12), SenseInfo('02346895-v', 9), SenseInfo('02720697-v', 8), SenseInfo('01744450-v', 8), SenseInfo('00729109-v', 4), SenseInfo('02455407-v', 3), SenseInfo('02406585-v', 2), SenseInfo('01728355-v', 1), SenseInfo('00118764-v', 1), SenseInfo('02625339-v', 0), SenseInfo('02600255-v', 0), SenseInfo('02561697-v', 0), SenseInfo('02445925-v', 0), SenseInfo('02198602-v', 0), SenseInfo('02000868-v', 0), SenseInfo('00589738-v', 0), SenseInfo('00351406-v', 0), SenseInfo('01998432-v', 74), SenseInfo('02712772-v', 50), SenseInfo('02720149-v', 26), SenseInfo('01991931-v', 20), SenseInfo('02542280-v', 18), SenseInfo('02720354-v', 17), SenseInfo('00150776-v', 13), SenseInfo('02720544-v', 12), SenseInfo('02346895-v', 9), SenseInfo('02720697-v', 8), SenseInfo('01744450-v', 8), SenseInfo('00729109-v', 4), SenseInfo('02455407-v', 3), SenseInfo('02406585-v', 2), SenseInfo('01728355-v', 1), SenseInfo('00118764-v', 1), SenseInfo('02625339-v', 0), SenseInfo('02600255-v', 0), SenseInfo('02561697-v', 0), SenseInfo('02445925-v', 0), SenseInfo('02198602-v', 0), SenseInfo('02000868-v', 0), SenseInfo('00589738-v', 0), SenseInfo('00351406-v', 0), SenseInfo('01998432-v', 74), SenseInfo('02712772-v', 50), SenseInfo('02720149-v', 26), SenseInfo('01991931-v', 20), SenseInfo('02542280-v', 18), SenseInfo('02720354-v', 17), SenseInfo('00150776-v', 13), SenseInfo('02720544-v', 12), SenseInfo('02346895-v', 9), SenseInfo('02720697-v', 8), SenseInfo('01744450-v', 8), SenseInfo('00729109-v', 4), SenseInfo('02455407-v', 3), SenseInfo('02406585-v', 2), SenseInfo('01728355-v', 1), SenseInfo('00118764-v', 1), SenseInfo('02625339-v', 0), SenseInfo('02600255-v', 0), SenseInfo('02561697-v', 0), SenseInfo('02445925-v', 0), SenseInfo('02198602-v', 0), SenseInfo('02000868-v', 0), SenseInfo('00589738-v', 0), SenseInfo('00351406-v', 0), SenseInfo('01998432-v', 74), SenseInfo('02712772-v', 50), SenseInfo('02720149-v', 26), SenseInfo('01991931-v', 20), SenseInfo('02542280-v', 18), SenseInfo('02720354-v', 17), SenseInfo('00150776-v', 13), SenseInfo('02720544-v', 12), SenseInfo('02346895-v', 9), SenseInfo('02720697-v', 8), SenseInfo('01744450-v', 8), SenseInfo('00729109-v', 4), SenseInfo('02455407-v', 3), SenseInfo('02406585-v', 2), SenseInfo('01728355-v', 1), SenseInfo('00118764-v', 1), SenseInfo('02625339-v', 0), SenseInfo('02600255-v', 0), SenseInfo('02561697-v', 0), SenseInfo('02445925-v', 0), SenseInfo('02198602-v', 0), SenseInfo('02000868-v', 0), SenseInfo('00589738-v', 0), SenseInfo('00351406-v', 0) ],
"_deposition_n_of_rel" : [ SenseInfo('13462191-n', 0), SenseInfo('07194499-n', 0), SenseInfo('00372448-n', 0), SenseInfo('00208943-n', 0), SenseInfo('13462191-n', 0), SenseInfo('07194499-n', 0), SenseInfo('00372448-n', 0), SenseInfo('00208943-n', 0) ],
"_hosiery_n_1_rel" : [ SenseInfo('03540267-n', 0) ],
"_shoo_v_away_rel" : [ SenseInfo('02003480-v', 0) ],
"_manufacture_n_of_rel" : [ SenseInfo('00923444-n', 2), SenseInfo('00924825-n', 0) ],
"_discovery_n_of_rel" : [ SenseInfo('00043195-n', 12), SenseInfo('07214432-n', 5), SenseInfo('05808218-n', 5), SenseInfo('07214642-n', 0), SenseInfo('00043195-n', 12), SenseInfo('07214432-n', 5), SenseInfo('05808218-n', 5), SenseInfo('07214642-n', 0) ],
"_attestation_n_1_rel" : [ SenseInfo('06736405-n', 0), SenseInfo('06649915-n', 0), SenseInfo('06736405-n', 0), SenseInfo('06649915-n', 0) ],
"_helm_n_1_rel" : [ SenseInfo('03512911-n', 1), SenseInfo('01256615-n', 1) ],
"_wrinkle_v_1_rel" : [ SenseInfo('01279305-v', 2), SenseInfo('01278427-v', 1), SenseInfo('01277784-v', 0), SenseInfo('00564857-v', 0) ],
"_opposite_a_of-to_rel" : [ SenseInfo('02070887-a', 9), SenseInfo('01663201-a', 4), SenseInfo('02071139-a', 4), SenseInfo('02070711-a', 3), SenseInfo('02067913-a', 3), SenseInfo('02066312-a', 1), SenseInfo('02070887-a', 9), SenseInfo('01663201-a', 4), SenseInfo('02071139-a', 4), SenseInfo('02070711-a', 3), SenseInfo('02067913-a', 3), SenseInfo('02066312-a', 1), SenseInfo('02070887-a', 9), SenseInfo('01663201-a', 4), SenseInfo('02071139-a', 4), SenseInfo('02070711-a', 3), SenseInfo('02067913-a', 3), SenseInfo('02066312-a', 1) ],
"_on+earth_x_rel" : [ SenseInfo('00508255-r', 0) ],
"_quota_n_1_rel" : [ SenseInfo('13599348-n', 1), SenseInfo('13289744-n', 0), SenseInfo('06660396-n', 0) ],
"_clam_n_1_rel" : [ SenseInfo('01956481-n', 2), SenseInfo('13395897-n', 0), SenseInfo('07786686-n', 0) ],
"_overturn_n_1_rel" : [ SenseInfo('00348312-n', 0), SenseInfo('00068170-n', 0) ],
"_elaborate_v_1_rel" : [ SenseInfo('00955601-v', 7), SenseInfo('01625343-v', 0), SenseInfo('00400883-v', 0), SenseInfo('00251463-v', 0), SenseInfo('00955601-v', 7), SenseInfo('01625343-v', 0), SenseInfo('00400883-v', 0), SenseInfo('00251463-v', 0) ],
"_sausage_n_1_rel" : [ SenseInfo('07675627-n', 1), SenseInfo('02850950-n', 0) ],
"_ecuadoran_a_1_rel" : [ SenseInfo('09700371-n', 0) ],
"_unfit_a_1_rel" : [ SenseInfo('01021301-a', 1), SenseInfo('01017738-a', 0), SenseInfo('01174222-a', 0), SenseInfo('01021301-a', 1), SenseInfo('01017738-a', 0), SenseInfo('01174222-a', 0) ],
"_roll-over_n_1_rel" : [ SenseInfo('01155722-n', 0), SenseInfo('01155722-n', 0), SenseInfo('01155722-n', 0) ],
"_informal_a_1_rel" : [ SenseInfo('01044240-a', 3), SenseInfo('01634027-a', 1), SenseInfo('01045711-a', 0), SenseInfo('01076145-a', 0), SenseInfo('01044240-a', 3), SenseInfo('01634027-a', 1), SenseInfo('01045711-a', 0), SenseInfo('01076145-a', 0) ],
"_restore_v_to_rel" : [ SenseInfo('02552449-v', 10), SenseInfo('00168588-v', 4), SenseInfo('02310482-v', 2), SenseInfo('00260648-v', 1), SenseInfo('02426799-v', 0), SenseInfo('02552449-v', 10), SenseInfo('00168588-v', 4), SenseInfo('02310482-v', 2), SenseInfo('00260648-v', 1), SenseInfo('02426799-v', 0) ],
"_efficacy_n_1_rel" : [ SenseInfo('05199869-n', 6) ],
"_erode_v_cause_rel" : [ SenseInfo('00275253-v', 1), SenseInfo('00274724-v', 1) ],
"_m500_n_1_rel" : [  ],
"_guilt_n_1_rel" : [ SenseInfo('13990675-n', 8), SenseInfo('07536245-n', 2) ],
"_improve_v_cause_rel" : [ SenseInfo('00205885-v', 66), SenseInfo('00205046-v', 12), SenseInfo('00205885-v', 66), SenseInfo('00205046-v', 12) ],
"_subject_a_to_rel" : [ SenseInfo('02361540-a', 0), SenseInfo('02329864-a', 0), SenseInfo('00071559-a', 0) ],
"_static_n_1_rel" : [ SenseInfo('07431683-n', 0), SenseInfo('06712625-n', 0) ],
"_zoology_n_1_rel" : [ SenseInfo('07993279-n', 0), SenseInfo('06083243-n', 0), SenseInfo('07993279-n', 0), SenseInfo('06083243-n', 0) ],
"_round_v_off_rel" : [ SenseInfo('01858910-v', 3), SenseInfo('00145147-v', 1), SenseInfo('00980339-v', 0), SenseInfo('00862683-v', 0), SenseInfo('00473799-v', 0), SenseInfo('00145623-v', 0), SenseInfo('00046382-v', 0) ],
"_maximal_a_1_rel" : [ SenseInfo('01495725-a', 2) ],
"_athwart_p_rel" : [ SenseInfo('00276145-r', 0), SenseInfo('00274710-r', 0), SenseInfo('00276145-r', 0), SenseInfo('00274710-r', 0), SenseInfo('00276145-r', 0), SenseInfo('00274710-r', 0) ],
"_tapeline_n_1_rel" : [ SenseInfo('04392113-n', 0) ],
"_recharge_n_of_rel" : [  ],
"_lousy_a_1_rel" : [ SenseInfo('01127782-a', 3), SenseInfo('00422374-a', 2), SenseInfo('01587474-a', 0), SenseInfo('01127782-a', 3), SenseInfo('00422374-a', 2), SenseInfo('01587474-a', 0), SenseInfo('01127782-a', 3), SenseInfo('00422374-a', 2), SenseInfo('01587474-a', 0) ],
"_mediterranean_a_1_rel" : [ SenseInfo('03085213-a', 0) ],
"_seahawk_n_1_rel" : [  ],
"_bow_v_1_rel" : [ SenseInfo('00898691-v', 11), SenseInfo('00878348-v', 3), SenseInfo('02040273-v', 1), SenseInfo('02062632-v', 0), SenseInfo('01729295-v', 0) ],
"_POS_n_1_rel" : [  ],
"_quack_v_1_rel" : [ SenseInfo('01053098-v', 1), SenseInfo('00011982-v', 0) ],
"_rinse_v_out_rel" : [ SenseInfo('01536168-v', 1), SenseInfo('01270199-v', 1), SenseInfo('00037138-v', 0) ],
"_chain_n_of_rel" : [ SenseInfo('08376250-n', 14), SenseInfo('09240621-n', 3), SenseInfo('02999410-n', 2), SenseInfo('08057816-n', 1), SenseInfo('02999936-n', 1), SenseInfo('13652994-n', 0), SenseInfo('10891029-n', 0), SenseInfo('09403734-n', 0), SenseInfo('03000021-n', 0), SenseInfo('02999757-n', 0) ],
"_junior_a_1_rel" : [ SenseInfo('02100709-a', 3), SenseInfo('01015185-a', 2), SenseInfo('01648891-a', 0) ],
"plus_c_rel" : [  ],
"_berate_v_1_rel" : [ SenseInfo('00824767-v', 2) ],
"_initiate_n_1_rel" : [ SenseInfo('10363913-n', 0), SenseInfo('10206887-n', 0), SenseInfo('07948518-n', 0) ],
"_templating_n_1_rel" : [  ],
"_give_v_back_rel" : [ SenseInfo('02316868-v', 179), SenseInfo('02339171-v', 160), SenseInfo('02199590-v', 96), SenseInfo('02235842-v', 78), SenseInfo('01060494-v', 32), SenseInfo('01733477-v', 29), SenseInfo('01060317-v', 24), SenseInfo('02200686-v', 20), SenseInfo('01629403-v', 18), SenseInfo('00732224-v', 18), SenseInfo('01629000-v', 16), SenseInfo('02296153-v', 14), SenseInfo('01647672-v', 14), SenseInfo('02200498-v', 12), SenseInfo('02562901-v', 10), SenseInfo('02343595-v', 10), SenseInfo('02230772-v', 10), SenseInfo('00887463-v', 8), SenseInfo('02309374-v', 5), SenseInfo('02309165-v', 5), SenseInfo('01060746-v', 5), SenseInfo('02317094-v', 4), SenseInfo('01848465-v', 4), SenseInfo('01178565-v', 4), SenseInfo('02308741-v', 3), SenseInfo('01989053-v', 1), SenseInfo('00673571-v', 1), SenseInfo('02564052-v', 0), SenseInfo('02359553-v', 0), SenseInfo('02358034-v', 0), SenseInfo('01716283-v', 0), SenseInfo('01716112-v', 0), SenseInfo('01449796-v', 0), SenseInfo('01175810-v', 0), SenseInfo('01069638-v', 0), SenseInfo('00944247-v', 0), SenseInfo('00888009-v', 0), SenseInfo('00878876-v', 0), SenseInfo('00771806-v', 0), SenseInfo('00748972-v', 0), SenseInfo('00748616-v', 0), SenseInfo('00341184-v', 0), SenseInfo('00108747-v', 0), SenseInfo('00108604-v', 0), SenseInfo('02316868-v', 179), SenseInfo('02339171-v', 160), SenseInfo('02199590-v', 96), SenseInfo('02235842-v', 78), SenseInfo('01060494-v', 32), SenseInfo('01733477-v', 29), SenseInfo('01060317-v', 24), SenseInfo('02200686-v', 20), SenseInfo('01629403-v', 18), SenseInfo('00732224-v', 18), SenseInfo('01629000-v', 16), SenseInfo('02296153-v', 14), SenseInfo('01647672-v', 14), SenseInfo('02200498-v', 12), SenseInfo('02562901-v', 10), SenseInfo('02343595-v', 10), SenseInfo('02230772-v', 10), SenseInfo('00887463-v', 8), SenseInfo('02309374-v', 5), SenseInfo('02309165-v', 5), SenseInfo('01060746-v', 5), SenseInfo('02317094-v', 4), SenseInfo('01848465-v', 4), SenseInfo('01178565-v', 4), SenseInfo('02308741-v', 3), SenseInfo('01989053-v', 1), SenseInfo('00673571-v', 1), SenseInfo('02564052-v', 0), SenseInfo('02359553-v', 0), SenseInfo('02358034-v', 0), SenseInfo('01716283-v', 0), SenseInfo('01716112-v', 0), SenseInfo('01449796-v', 0), SenseInfo('01175810-v', 0), SenseInfo('01069638-v', 0), SenseInfo('00944247-v', 0), SenseInfo('00888009-v', 0), SenseInfo('00878876-v', 0), SenseInfo('00771806-v', 0), SenseInfo('00748972-v', 0), SenseInfo('00748616-v', 0), SenseInfo('00341184-v', 0), SenseInfo('00108747-v', 0), SenseInfo('00108604-v', 0) ],
"_fixer_n_1_rel" : [ SenseInfo('10094046-n', 1), SenseInfo('14869327-n', 0), SenseInfo('10308732-n', 0), SenseInfo('03754014-n', 0) ],
"_go_v_state_rel" : [ SenseInfo('01835496-v', 343), SenseInfo('02372605-v', 95), SenseInfo('01848718-v', 49), SenseInfo('00149583-v', 29), SenseInfo('02653862-v', 14), SenseInfo('02721284-v', 10), SenseInfo('02685951-v', 10), SenseInfo('00341560-v', 10), SenseInfo('00359916-v', 9), SenseInfo('02618001-v', 7), SenseInfo('02176268-v', 3), SenseInfo('01525666-v', 3), SenseInfo('01192773-v', 3), SenseInfo('00539110-v', 3), SenseInfo('02618149-v', 2), SenseInfo('02617798-v', 2), SenseInfo('00358431-v', 2), SenseInfo('02737876-v', 1), SenseInfo('02729819-v', 1), SenseInfo('01864230-v', 1), SenseInfo('01076615-v', 1), SenseInfo('02700772-v', 0), SenseInfo('02700666-v', 0), SenseInfo('02700455-v', 0), SenseInfo('02686471-v', 0), SenseInfo('02659763-v', 0), SenseInfo('01318849-v', 0), SenseInfo('01192992-v', 0), SenseInfo('00676267-v', 0), SenseInfo('00434374-v', 0), SenseInfo('01835496-v', 343), SenseInfo('02372605-v', 95), SenseInfo('01848718-v', 49), SenseInfo('00149583-v', 29), SenseInfo('02653862-v', 14), SenseInfo('02721284-v', 10), SenseInfo('02685951-v', 10), SenseInfo('00341560-v', 10), SenseInfo('00359916-v', 9), SenseInfo('02618001-v', 7), SenseInfo('02176268-v', 3), SenseInfo('01525666-v', 3), SenseInfo('01192773-v', 3), SenseInfo('00539110-v', 3), SenseInfo('02618149-v', 2), SenseInfo('02617798-v', 2), SenseInfo('00358431-v', 2), SenseInfo('02737876-v', 1), SenseInfo('02729819-v', 1), SenseInfo('01864230-v', 1), SenseInfo('01076615-v', 1), SenseInfo('02700772-v', 0), SenseInfo('02700666-v', 0), SenseInfo('02700455-v', 0), SenseInfo('02686471-v', 0), SenseInfo('02659763-v', 0), SenseInfo('01318849-v', 0), SenseInfo('01192992-v', 0), SenseInfo('00676267-v', 0), SenseInfo('00434374-v', 0) ],
"_reviewer_n_1_rel" : [ SenseInfo('10526927-n', 1), SenseInfo('09942431-n', 0) ],
"_frenzied_a_1_rel" : [ SenseInfo('02391003-a', 1), SenseInfo('00086341-a', 0) ],
"_slip_v_in_rel" : [ SenseInfo('01888295-v', 11), SenseInfo('00189669-v', 7), SenseInfo('01870275-v', 6), SenseInfo('00204391-v', 4), SenseInfo('02076280-v', 2), SenseInfo('00617748-v', 1), SenseInfo('02231328-v', 0), SenseInfo('02105549-v', 0), SenseInfo('02076501-v', 0), SenseInfo('00608978-v', 0), SenseInfo('00465762-v', 0) ],
"_pc_a_1_rel" : [ SenseInfo('03918480-n', 0), SenseInfo('03918480-n', 0), SenseInfo('03918480-n', 0), SenseInfo('03918480-n', 0) ],
"_recover_v_1_rel" : [ SenseInfo('02247977-v', 9), SenseInfo('00092690-v', 4), SenseInfo('00528339-v', 3), SenseInfo('02249438-v', 0), SenseInfo('02226833-v', 0), SenseInfo('01336541-v', 0) ],
"_wildlife_n_1_rel" : [ SenseInfo('07993776-n', 3) ],
"_recollect_v_1_rel" : [ SenseInfo('00607780-v', 4), SenseInfo('00607780-v', 4) ],
"_flexibility_n_1_rel" : [ SenseInfo('05022457-n', 7), SenseInfo('04659287-n', 2), SenseInfo('04905188-n', 0) ],
"_ensue_v_1_rel" : [ SenseInfo('02634265-v', 7) ],
"_contempt_n_1_rel" : [ SenseInfo('07502980-n', 7), SenseInfo('04915687-n', 2), SenseInfo('06715927-n', 0), SenseInfo('01180200-n', 0) ],
"_absolve_v_of_rel" : [ SenseInfo('00903711-v', 0), SenseInfo('00902424-v', 0), SenseInfo('00903711-v', 0), SenseInfo('00902424-v', 0) ],
"_buddhism_n_1_rel" : [ SenseInfo('08098708-n', 0), SenseInfo('06240244-n', 0) ],
"_inhibit_v_from_rel" : [ SenseInfo('00462092-v', 6), SenseInfo('00462689-v', 1), SenseInfo('02451679-v', 0), SenseInfo('02423762-v', 0) ],
"_CA$_n_1_rel" : [  ],
"_spa_n_1_rel" : [ SenseInfo('08678615-n', 0), SenseInfo('04080705-n', 0), SenseInfo('03506370-n', 0) ],
"_pumpkin_n_1_rel" : [ SenseInfo('12158443-n', 0), SenseInfo('07735510-n', 0) ],
"_contemporary_n_1_rel" : [ SenseInfo('09960417-n', 3) ],
"_orient_v_1_rel" : [ SenseInfo('02713184-v', 2), SenseInfo('02159197-v', 2), SenseInfo('02712914-v', 1), SenseInfo('00874537-v', 0), SenseInfo('00301662-v', 0) ],
"_chief_n_1_rel" : [ SenseInfo('10162991-n', 5), SenseInfo('10104209-n', 1), SenseInfo('10164025-n', 0), SenseInfo('10162991-n', 5), SenseInfo('10104209-n', 1), SenseInfo('10164025-n', 0) ],
"_scsi_n_1_rel" : [ SenseInfo('04245218-n', 0) ],
"_accelerator_n_1_rel" : [ SenseInfo('02670683-n', 2), SenseInfo('02670186-n', 1), SenseInfo('14723628-n', 0), SenseInfo('02670382-n', 0) ],
"_wriggle_n_1_rel" : [ SenseInfo('00349705-n', 0) ],
"_successful_a_1_rel" : [ SenseInfo('02331262-a', 42), SenseInfo('02331262-a', 42) ],
"_anyways_a_1_rel" : [  ],
"_blanket_n_1_rel" : [ SenseInfo('02849154-n', 19), SenseInfo('09223725-n', 4), SenseInfo('02849419-n', 0) ],
"_rattle_v_cause_rel" : [ SenseInfo('02175057-v', 4), SenseInfo('01890626-v', 3) ],
"_dank_a_1_rel" : [ SenseInfo('02548619-a', 1), SenseInfo('02548619-a', 1), SenseInfo('02548619-a', 1) ],
"_technically_x_deg_rel" : [ SenseInfo('00126972-r', 1), SenseInfo('00126837-r', 1), SenseInfo('00127130-r', 0) ],
"_lawful_a_1_rel" : [ SenseInfo('01395617-a', 0), SenseInfo('01959807-a', 0), SenseInfo('01407267-a', 0), SenseInfo('01401224-a', 0), SenseInfo('01395617-a', 0), SenseInfo('01959807-a', 0), SenseInfo('01407267-a', 0), SenseInfo('01401224-a', 0) ],
"_roe_n_1_rel" : [ SenseInfo('07799278-n', 0), SenseInfo('02322624-n', 0), SenseInfo('01461532-n', 0), SenseInfo('01461445-n', 0) ],
"_fertilize_v_1_rel" : [ SenseInfo('00502757-v', 1), SenseInfo('00504270-v', 0), SenseInfo('00052548-v', 0) ],
"_saloon_n_1_rel" : [ SenseInfo('02796995-n', 5), SenseInfo('04018399-n', 2), SenseInfo('04166281-n', 0) ],
"_tax_n_1_rel" : [ SenseInfo('13308999-n', 44) ],
"_close_a_to_rel" : [ SenseInfo('00446921-a', 38), SenseInfo('00451510-a', 23), SenseInfo('00444519-a', 6), SenseInfo('00309945-a', 4), SenseInfo('00022219-a', 3), SenseInfo('00890622-a', 2), SenseInfo('00558738-a', 1), SenseInfo('02509484-a', 0), SenseInfo('02232739-a', 0), SenseInfo('02000298-a', 0), SenseInfo('01859368-a', 0), SenseInfo('01447937-a', 0), SenseInfo('01436567-a', 0), SenseInfo('01113225-a', 0), SenseInfo('00501004-a', 0), SenseInfo('00446921-a', 38), SenseInfo('00451510-a', 23), SenseInfo('00444519-a', 6), SenseInfo('00309945-a', 4), SenseInfo('00022219-a', 3), SenseInfo('00890622-a', 2), SenseInfo('00558738-a', 1), SenseInfo('02509484-a', 0), SenseInfo('02232739-a', 0), SenseInfo('02000298-a', 0), SenseInfo('01859368-a', 0), SenseInfo('01447937-a', 0), SenseInfo('01436567-a', 0), SenseInfo('01113225-a', 0), SenseInfo('00501004-a', 0), SenseInfo('00446921-a', 38), SenseInfo('00451510-a', 23), SenseInfo('00444519-a', 6), SenseInfo('00309945-a', 4), SenseInfo('00022219-a', 3), SenseInfo('00890622-a', 2), SenseInfo('00558738-a', 1), SenseInfo('02509484-a', 0), SenseInfo('02232739-a', 0), SenseInfo('02000298-a', 0), SenseInfo('01859368-a', 0), SenseInfo('01447937-a', 0), SenseInfo('01436567-a', 0), SenseInfo('01113225-a', 0), SenseInfo('00501004-a', 0), SenseInfo('00446921-a', 38), SenseInfo('00451510-a', 23), SenseInfo('00444519-a', 6), SenseInfo('00309945-a', 4), SenseInfo('00022219-a', 3), SenseInfo('00890622-a', 2), SenseInfo('00558738-a', 1), SenseInfo('02509484-a', 0), SenseInfo('02232739-a', 0), SenseInfo('02000298-a', 0), SenseInfo('01859368-a', 0), SenseInfo('01447937-a', 0), SenseInfo('01436567-a', 0), SenseInfo('01113225-a', 0), SenseInfo('00501004-a', 0), SenseInfo('00446921-a', 38), SenseInfo('00451510-a', 23), SenseInfo('00444519-a', 6), SenseInfo('00309945-a', 4), SenseInfo('00022219-a', 3), SenseInfo('00890622-a', 2), SenseInfo('00558738-a', 1), SenseInfo('02509484-a', 0), SenseInfo('02232739-a', 0), SenseInfo('02000298-a', 0), SenseInfo('01859368-a', 0), SenseInfo('01447937-a', 0), SenseInfo('01436567-a', 0), SenseInfo('01113225-a', 0), SenseInfo('00501004-a', 0) ],
"_going+by_p_rel" : [  ],
"_wait_v_1_rel" : [ SenseInfo('02637938-v', 100), SenseInfo('02641463-v', 49), SenseInfo('00720063-v', 33), SenseInfo('02413290-v', 2), SenseInfo('02637938-v', 100), SenseInfo('02641463-v', 49), SenseInfo('00720063-v', 33), SenseInfo('02413290-v', 2), SenseInfo('02637938-v', 100), SenseInfo('02641463-v', 49), SenseInfo('00720063-v', 33), SenseInfo('02413290-v', 2) ],
"_before_p_rel" : [ SenseInfo('00060939-r', 68), SenseInfo('00066781-r', 0), SenseInfo('00060939-r', 68), SenseInfo('00066781-r', 0), SenseInfo('00060939-r', 68), SenseInfo('00066781-r', 0) ],
"_noon_n_1_rel" : [ SenseInfo('15165490-n', 8) ],
"_far+from_x_deg_rel" : [  ],
"_swivel_n_1_rel" : [ SenseInfo('04373563-n', 0) ],
"_marinade_n_1_rel" : [ SenseInfo('07824502-n', 0) ],
"_timeline_n_1_rel" : [ SenseInfo('06504965-n', 0) ],
"_restart_v_1_rel" : [ SenseInfo('01858686-v', 0), SenseInfo('00350104-v', 0) ],
"_abstract_n_1_rel" : [ SenseInfo('05854150-n', 2), SenseInfo('06468951-n', 0) ],
"_unreasonable_a_for_rel" : [ SenseInfo('01944660-a', 0), SenseInfo('01533974-a', 0), SenseInfo('01944660-a', 0), SenseInfo('01533974-a', 0), SenseInfo('01944660-a', 0), SenseInfo('01533974-a', 0), SenseInfo('01944660-a', 0), SenseInfo('01533974-a', 0), SenseInfo('01944660-a', 0), SenseInfo('01533974-a', 0), SenseInfo('01944660-a', 0), SenseInfo('01533974-a', 0) ],
"_hereditary_a_1_rel" : [ SenseInfo('01314537-a', 0), SenseInfo('01314197-a', 0) ],
"_coil_n_1_rel" : [ SenseInfo('03065424-n', 1), SenseInfo('13875970-n', 0), SenseInfo('03066232-n', 0), SenseInfo('03066130-n', 0), SenseInfo('03066029-n', 0), SenseInfo('03065708-n', 0) ],
"_liquidity_n_1_rel" : [ SenseInfo('14480420-n', 0), SenseInfo('04937043-n', 0), SenseInfo('04737430-n', 0) ],
"_increment_v_cause_rel" : [  ],
"_deadly_a_1_rel" : [ SenseInfo('00993667-a', 6), SenseInfo('00993885-a', 1), SenseInfo('02449952-a', 0), SenseInfo('01721691-a', 0), SenseInfo('01611329-a', 0), SenseInfo('00045888-a', 0), SenseInfo('00993667-a', 6), SenseInfo('00993885-a', 1), SenseInfo('02449952-a', 0), SenseInfo('01721691-a', 0), SenseInfo('01611329-a', 0), SenseInfo('00045888-a', 0), SenseInfo('00993667-a', 6), SenseInfo('00993885-a', 1), SenseInfo('02449952-a', 0), SenseInfo('01721691-a', 0), SenseInfo('01611329-a', 0), SenseInfo('00045888-a', 0) ],
"_tear_v_open_rel" : [ SenseInfo('01573515-v', 19), SenseInfo('01556346-v', 7), SenseInfo('02055267-v', 2), SenseInfo('01384275-v', 1), SenseInfo('00066977-v', 0) ],
"_glad_a_1_rel" : [ SenseInfo('01361414-a', 11), SenseInfo('02565583-a', 1), SenseInfo('01146920-a', 1), SenseInfo('00362892-a', 0), SenseInfo('01361414-a', 11), SenseInfo('02565583-a', 1), SenseInfo('01146920-a', 1), SenseInfo('00362892-a', 0), SenseInfo('01361414-a', 11), SenseInfo('02565583-a', 1), SenseInfo('01146920-a', 1), SenseInfo('00362892-a', 0), SenseInfo('01361414-a', 11), SenseInfo('02565583-a', 1), SenseInfo('01146920-a', 1), SenseInfo('00362892-a', 0), SenseInfo('01361414-a', 11), SenseInfo('02565583-a', 1), SenseInfo('01146920-a', 1), SenseInfo('00362892-a', 0), SenseInfo('01361414-a', 11), SenseInfo('02565583-a', 1), SenseInfo('01146920-a', 1), SenseInfo('00362892-a', 0) ],
"_upstairs_n_1_rel" : [ SenseInfo('04515729-n', 0) ],
"_frosty_a_1_rel" : [ SenseInfo('01258264-a', 0), SenseInfo('01253254-a', 0), SenseInfo('01252714-a', 0) ],
"_dark_n_1_rel" : [ SenseInfo('13983515-n', 9), SenseInfo('14563564-n', 5), SenseInfo('08646306-n', 4), SenseInfo('15167027-n', 3), SenseInfo('05988498-n', 2) ],
"_glitch_n_1_rel" : [ SenseInfo('14464675-n', 0) ],
"_invert_n_1_rel" : [  ],
"_inroad_n_1_rel" : [ SenseInfo('00733753-n', 1), SenseInfo('00977132-n', 0) ],
"_died_a_abb_rel" : [  ],
"_sex_n_1_rel" : [ SenseInfo('00844254-n', 14), SenseInfo('07999291-n', 7), SenseInfo('07487695-n', 0), SenseInfo('05006898-n', 0) ],
"_sugar_v_1_rel" : [ SenseInfo('02195951-v', 1) ],
"_disclose_v_to_rel" : [ SenseInfo('00933821-v', 19), SenseInfo('02137710-v', 6), SenseInfo('00933821-v', 19), SenseInfo('02137710-v', 6) ],
"_stick_v_to_rel" : [ SenseInfo('01528069-v', 5), SenseInfo('01857392-v', 2), SenseInfo('01356750-v', 2), SenseInfo('02754032-v', 0), SenseInfo('02647798-v', 0), SenseInfo('02638845-v', 0), SenseInfo('02638630-v', 0), SenseInfo('01667969-v', 0), SenseInfo('01614581-v', 0), SenseInfo('01614426-v', 0), SenseInfo('01614235-v', 0), SenseInfo('01441993-v', 0), SenseInfo('01441793-v', 0), SenseInfo('01220885-v', 0), SenseInfo('00748084-v', 0), SenseInfo('00622384-v', 0) ],
"_thrilling_a_for_rel" : [ SenseInfo('00921866-a', 2), SenseInfo('02307199-a', 0) ],
"_delta_n_1_rel" : [ SenseInfo('09264803-n', 1), SenseInfo('13880102-n', 0), SenseInfo('06834458-n', 0) ],
"_concentrated_a_1_rel" : [ SenseInfo('00538565-a', 5), SenseInfo('00757001-a', 5), SenseInfo('01511031-a', 2), SenseInfo('01157762-a', 0), SenseInfo('00757923-a', 0) ],
"_conflict_n_1_rel" : [ SenseInfo('00958896-n', 6), SenseInfo('07483439-n', 4), SenseInfo('00953559-n', 4), SenseInfo('13980845-n', 2), SenseInfo('04714679-n', 2), SenseInfo('13855377-n', 0), SenseInfo('07181935-n', 0) ],
"_counter+to_p_rel" : [  ],
"_imperfect_a_1_rel" : [ SenseInfo('01752167-a', 2), SenseInfo('01259391-a', 1) ],
"_flagstone_n_1_rel" : [ SenseInfo('03355339-n', 0) ],
"_under-service_v_1_rel" : [  ],
"_endurance_n_1_rel" : [ SenseInfo('05032565-n', 4), SenseInfo('13962166-n', 0) ],
"_sharpen_v_1_rel" : [ SenseInfo('01246601-v', 1), SenseInfo('00392426-v', 1), SenseInfo('00392314-v', 1), SenseInfo('00314272-v', 1), SenseInfo('02190786-v', 0), SenseInfo('00393398-v', 0), SenseInfo('00392960-v', 0), SenseInfo('00392588-v', 0) ],
"_march_v_off_rel" : [ SenseInfo('01996735-v', 24), SenseInfo('02084380-v', 5), SenseInfo('01919391-v', 5), SenseInfo('02521816-v', 1), SenseInfo('01924712-v', 1), SenseInfo('02084587-v', 0), SenseInfo('01466978-v', 0) ],
"_megaslide_n_1_rel" : [  ],
"_concert_n_1_rel" : [ SenseInfo('06892775-n', 5), SenseInfo('06892775-n', 5) ],
"_contract_v_2_rel" : [ SenseInfo('00888786-v', 8), SenseInfo('02409941-v', 3), SenseInfo('01387786-v', 2), SenseInfo('00087736-v', 2), SenseInfo('00240571-v', 1), SenseInfo('01279474-v', 0), SenseInfo('00365188-v', 0), SenseInfo('00305109-v', 0), SenseInfo('00243900-v', 0) ],
"_technicality_n_1_rel" : [ SenseInfo('05820462-n', 0) ],
"_aspire_v_to_rel" : [ SenseInfo('00705517-v', 2), SenseInfo('00705517-v', 2), SenseInfo('00705517-v', 2), SenseInfo('00705517-v', 2), SenseInfo('00705517-v', 2) ],
"_roof_n_1_rel" : [ SenseInfo('04105068-n', 34), SenseInfo('04105438-n', 1), SenseInfo('09416890-n', 0), SenseInfo('06657646-n', 0) ],
"_water+ski_v_1_rel" : [ SenseInfo('01940248-v', 1) ],
"_preparatory_a_1_rel" : [ SenseInfo('00126830-a', 1) ],
"_hands+free_a_1_rel" : [  ],
"_relive_v_1_rel" : [ SenseInfo('00597216-v', 1) ],
"_presume_v_1_rel" : [ SenseInfo('00632236-v', 12), SenseInfo('02374924-v', 0), SenseInfo('01015677-v', 0), SenseInfo('00011551-v', 0), SenseInfo('00632236-v', 12), SenseInfo('02374924-v', 0), SenseInfo('01015677-v', 0), SenseInfo('00011551-v', 0), SenseInfo('00632236-v', 12), SenseInfo('02374924-v', 0), SenseInfo('01015677-v', 0), SenseInfo('00011551-v', 0), SenseInfo('00632236-v', 12), SenseInfo('02374924-v', 0), SenseInfo('01015677-v', 0), SenseInfo('00011551-v', 0), SenseInfo('00632236-v', 12), SenseInfo('02374924-v', 0), SenseInfo('01015677-v', 0), SenseInfo('00011551-v', 0) ],
"_blessed_a_1_rel" : [ SenseInfo('00670741-a', 1), SenseInfo('02054216-a', 1), SenseInfo('00669942-a', 1), SenseInfo('02054075-a', 0), SenseInfo('01451768-a', 0), SenseInfo('01148764-a', 0) ],
"_northward_a_1_rel" : [ SenseInfo('01600713-a', 0) ],
"_sum_n_of_rel" : [ SenseInfo('13331198-n', 12), SenseInfo('05861067-n', 4), SenseInfo('07959016-n', 1), SenseInfo('05921123-n', 1), SenseInfo('04353803-n', 1), SenseInfo('07998712-n', 0) ],
"_tundra_n_1_rel" : [ SenseInfo('09463226-n', 0) ],
"_wrap_v_up_rel" : [ SenseInfo('01283208-v', 5), SenseInfo('01522276-v', 4), SenseInfo('01580467-v', 1), SenseInfo('01562478-v', 0), SenseInfo('01283208-v', 5), SenseInfo('01522276-v', 4), SenseInfo('01580467-v', 1), SenseInfo('01562478-v', 0) ],
"_ganglium_n_1_rel" : [  ],
"_cough_v_up_rel" : [ SenseInfo('00005815-v', 6), SenseInfo('00005815-v', 6) ],
"_catholic_n_1_rel" : [ SenseInfo('09679925-n', 25) ],
"_futile_a_1_rel" : [ SenseInfo('02497471-a', 2), SenseInfo('01866812-a', 2) ],
"_in+the+world_x_rel" : [  ],
"_frame_v_in_rel" : [ SenseInfo('01586850-v', 4), SenseInfo('02711835-v', 3), SenseInfo('02578008-v', 1), SenseInfo('00981276-v', 1), SenseInfo('00706804-v', 1), SenseInfo('01655763-v', 0) ],
"_jump_v_up_rel" : [ SenseInfo('01963942-v', 19), SenseInfo('01910373-v', 6), SenseInfo('01121178-v', 4), SenseInfo('00155727-v', 2), SenseInfo('02674564-v', 1), SenseInfo('01082937-v', 1), SenseInfo('00155547-v', 1), SenseInfo('02105082-v', 0), SenseInfo('02011865-v', 0), SenseInfo('01968275-v', 0), SenseInfo('01965156-v', 0), SenseInfo('01859050-v', 0), SenseInfo('00616498-v', 0), SenseInfo('00560391-v', 0), SenseInfo('00121506-v', 0) ],
"_quip_v_1_rel" : [ SenseInfo('00853958-v', 1), SenseInfo('00853958-v', 1) ],
"_take_v_around_rel" : [ SenseInfo('02599636-v', 92), SenseInfo('02267989-v', 74), SenseInfo('01999798-v', 73), SenseInfo('01214265-v', 50), SenseInfo('00524682-v', 38), SenseInfo('00624476-v', 36), SenseInfo('02077656-v', 32), SenseInfo('02205272-v', 28), SenseInfo('01842690-v', 26), SenseInfo('00674607-v', 26), SenseInfo('02236124-v', 25), SenseInfo('02394183-v', 22), SenseInfo('00734054-v', 22), SenseInfo('02627934-v', 21), SenseInfo('02109045-v', 21), SenseInfo('01002740-v', 16), SenseInfo('00173338-v', 16), SenseInfo('01156834-v', 15), SenseInfo('00669762-v', 15), SenseInfo('02209936-v', 14), SenseInfo('02206619-v', 13), SenseInfo('01982395-v', 10), SenseInfo('02236624-v', 8), SenseInfo('00523095-v', 7), SenseInfo('00599992-v', 6), SenseInfo('00756076-v', 5), SenseInfo('02075857-v', 4), SenseInfo('01151110-v', 4), SenseInfo('00557404-v', 4), SenseInfo('02717102-v', 2), SenseInfo('02208537-v', 2), SenseInfo('02209745-v', 1), SenseInfo('02208118-v', 1), SenseInfo('02201138-v', 1), SenseInfo('01427127-v', 1), SenseInfo('00758333-v', 1), SenseInfo('02741546-v', 0), SenseInfo('02701210-v', 0), SenseInfo('02590253-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01100830-v', 0), SenseInfo('00087736-v', 0) ],
"_sound_v_off_rel" : [ SenseInfo('02134927-v', 38), SenseInfo('02176268-v', 14), SenseInfo('02135048-v', 9), SenseInfo('02180529-v', 1), SenseInfo('00952182-v', 1), SenseInfo('02179518-v', 0), SenseInfo('00491689-v', 0) ],
"_contented_a_1_rel" : [ SenseInfo('00588797-a', 3), SenseInfo('00588797-a', 3) ],
"_tear_v_cause_rel" : [ SenseInfo('01573515-v', 19), SenseInfo('01556346-v', 7), SenseInfo('02055267-v', 2), SenseInfo('01384275-v', 1), SenseInfo('00066977-v', 0) ],
"_breakfast_v_1_rel" : [ SenseInfo('01185740-v', 2), SenseInfo('01185875-v', 0) ],
"_secretary+general_n_of_rel" : [ SenseInfo('10573829-n', 1), SenseInfo('10573829-n', 1) ],
"_irrational_a_1_rel" : [ SenseInfo('01926376-a', 2), SenseInfo('02930083-a', 0) ],
"_tablecloth_n_1_rel" : [ SenseInfo('04380143-n', 0) ],
"_creator_n_1_rel" : [ SenseInfo('09536363-n', 3), SenseInfo('09614315-n', 1) ],
"_saying_n_1_rel" : [ SenseInfo('07151380-n', 0) ],
"_londoner_n_1_rel" : [ SenseInfo('09704630-n', 1) ],
"_thankful_a_for_rel" : [ SenseInfo('01146493-a', 0), SenseInfo('01146493-a', 0), SenseInfo('01146493-a', 0), SenseInfo('01146493-a', 0), SenseInfo('01146493-a', 0), SenseInfo('01146493-a', 0) ],
"_flabbergasted_a_1_rel" : [ SenseInfo('02358277-a', 0) ],
"_semiliterate_a_1_rel" : [ SenseInfo('00830630-a', 2), SenseInfo('01422354-a', 1), SenseInfo('01422468-a', 0) ],
"_damask_n_1_rel" : [ SenseInfo('03160894-n', 0), SenseInfo('03160740-n', 0) ],
"_percentage_n_of_rel" : [ SenseInfo('13817526-n', 26), SenseInfo('13285176-n', 6), SenseInfo('13817526-n', 26), SenseInfo('13285176-n', 6) ],
"_ripe_a_1_rel" : [ SenseInfo('01493173-a', 6), SenseInfo('01931807-a', 1), SenseInfo('01661289-a', 0), SenseInfo('01492257-a', 0), SenseInfo('00816839-a', 0), SenseInfo('01493173-a', 6), SenseInfo('01931807-a', 1), SenseInfo('01661289-a', 0), SenseInfo('01492257-a', 0), SenseInfo('00816839-a', 0), SenseInfo('01493173-a', 6), SenseInfo('01931807-a', 1), SenseInfo('01661289-a', 0), SenseInfo('01492257-a', 0), SenseInfo('00816839-a', 0) ],
"_crane_n_1_rel" : [ SenseInfo('10914447-n', 0), SenseInfo('10914331-n', 0), SenseInfo('09295455-n', 0), SenseInfo('03126707-n', 0), SenseInfo('02012849-n', 0) ],
"_carton_n_of_rel" : [ SenseInfo('13766337-n', 1), SenseInfo('02971356-n', 0) ],
"_assurance_n_1_rel" : [ SenseInfo('05697363-n', 11), SenseInfo('07227772-n', 1), SenseInfo('07227406-n', 1), SenseInfo('13345286-n', 0), SenseInfo('05697363-n', 11), SenseInfo('07227772-n', 1), SenseInfo('07227406-n', 1), SenseInfo('13345286-n', 0) ],
"_ranch_n_1_rel" : [ SenseInfo('04052442-n', 4) ],
"_vocabulary_n_1_rel" : [ SenseInfo('06420678-n', 6), SenseInfo('05651242-n', 3), SenseInfo('05663275-n', 1) ],
"_patsy_n_1_rel" : [ SenseInfo('09921409-n', 0) ],
"_hilly_a_1_rel" : [ SenseInfo('02240490-a', 0), SenseInfo('02240490-a', 0), SenseInfo('02240490-a', 0) ],
"_ward_n_1_rel" : [ SenseInfo('10767020-n', 3), SenseInfo('08672397-n', 2), SenseInfo('04549919-n', 1), SenseInfo('11374281-n', 0), SenseInfo('11374085-n', 0), SenseInfo('11373897-n', 0), SenseInfo('02992032-n', 0) ],
"_creamy_a_1_rel" : [ SenseInfo('00373811-a', 1), SenseInfo('02416285-a', 0), SenseInfo('00373811-a', 1), SenseInfo('02416285-a', 0), SenseInfo('00373811-a', 1), SenseInfo('02416285-a', 0) ],
"_rooftop_n_1_rel" : [ SenseInfo('08663774-n', 2) ],
"_ampa_n_1_rel" : [  ],
"_wrinkle_v_cause_rel" : [ SenseInfo('01279305-v', 2), SenseInfo('01278427-v', 1), SenseInfo('01277784-v', 0), SenseInfo('00564857-v', 0) ],
"_darling_n_1_rel" : [ SenseInfo('09991867-n', 3), SenseInfo('09263479-n', 0) ],
"_sponsorship_n_of_rel" : [ SenseInfo('01215036-n', 3) ],
"_look_v_1_rel" : [ SenseInfo('02130524-v', 274), SenseInfo('02133435-v', 126), SenseInfo('00033599-v', 25), SenseInfo('02153709-v', 8), SenseInfo('02693319-v', 1), SenseInfo('02549581-v', 1), SenseInfo('00929362-v', 1), SenseInfo('00720063-v', 1), SenseInfo('02658447-v', 0), SenseInfo('00712708-v', 0), SenseInfo('02130524-v', 274), SenseInfo('02133435-v', 126), SenseInfo('00033599-v', 25), SenseInfo('02153709-v', 8), SenseInfo('02693319-v', 1), SenseInfo('02549581-v', 1), SenseInfo('00929362-v', 1), SenseInfo('00720063-v', 1), SenseInfo('02658447-v', 0), SenseInfo('00712708-v', 0), SenseInfo('02130524-v', 274), SenseInfo('02133435-v', 126), SenseInfo('00033599-v', 25), SenseInfo('02153709-v', 8), SenseInfo('02693319-v', 1), SenseInfo('02549581-v', 1), SenseInfo('00929362-v', 1), SenseInfo('00720063-v', 1), SenseInfo('02658447-v', 0), SenseInfo('00712708-v', 0), SenseInfo('02130524-v', 274), SenseInfo('02133435-v', 126), SenseInfo('00033599-v', 25), SenseInfo('02153709-v', 8), SenseInfo('02693319-v', 1), SenseInfo('02549581-v', 1), SenseInfo('00929362-v', 1), SenseInfo('00720063-v', 1), SenseInfo('02658447-v', 0), SenseInfo('00712708-v', 0), SenseInfo('02130524-v', 274), SenseInfo('02133435-v', 126), SenseInfo('00033599-v', 25), SenseInfo('02153709-v', 8), SenseInfo('02693319-v', 1), SenseInfo('02549581-v', 1), SenseInfo('00929362-v', 1), SenseInfo('00720063-v', 1), SenseInfo('02658447-v', 0), SenseInfo('00712708-v', 0), SenseInfo('02130524-v', 274), SenseInfo('02133435-v', 126), SenseInfo('00033599-v', 25), SenseInfo('02153709-v', 8), SenseInfo('02693319-v', 1), SenseInfo('02549581-v', 1), SenseInfo('00929362-v', 1), SenseInfo('00720063-v', 1), SenseInfo('02658447-v', 0), SenseInfo('00712708-v', 0), SenseInfo('02130524-v', 274), SenseInfo('02133435-v', 126), SenseInfo('00033599-v', 25), SenseInfo('02153709-v', 8), SenseInfo('02693319-v', 1), SenseInfo('02549581-v', 1), SenseInfo('00929362-v', 1), SenseInfo('00720063-v', 1), SenseInfo('02658447-v', 0), SenseInfo('00712708-v', 0), SenseInfo('02130524-v', 274), SenseInfo('02133435-v', 126), SenseInfo('00033599-v', 25), SenseInfo('02153709-v', 8), SenseInfo('02693319-v', 1), SenseInfo('02549581-v', 1), SenseInfo('00929362-v', 1), SenseInfo('00720063-v', 1), SenseInfo('02658447-v', 0), SenseInfo('00712708-v', 0) ],
"_naughty_a_1_rel" : [ SenseInfo('02132224-a', 0), SenseInfo('01128406-a', 0), SenseInfo('02132224-a', 0), SenseInfo('01128406-a', 0), SenseInfo('02132224-a', 0), SenseInfo('01128406-a', 0) ],
"_catholic_a_1_rel" : [ SenseInfo('02920951-a', 25), SenseInfo('00287128-a', 0) ],
"_individualist_a_1_rel" : [ SenseInfo('00494027-a', 0) ],
"_leak_n_1_rel" : [ SenseInfo('09337048-n', 1), SenseInfo('14284581-n', 0), SenseInfo('13506727-n', 0), SenseInfo('07436661-n', 0), SenseInfo('07215185-n', 0) ],
"_total_v_1_rel" : [ SenseInfo('02645007-v', 16), SenseInfo('00949288-v', 2), SenseInfo('00259382-v', 0) ],
"_tolerate_v_1_rel" : [ SenseInfo('00668099-v', 7), SenseInfo('02457585-v', 0), SenseInfo('02109404-v', 0), SenseInfo('00802946-v', 0) ],
"_rewrite_n_1_rel" : [ SenseInfo('06364149-n', 0) ],
"_academic_a_1_rel" : [ SenseInfo('02599939-a', 18), SenseInfo('00862718-a', 3), SenseInfo('02083908-a', 2), SenseInfo('02599939-a', 18), SenseInfo('00862718-a', 3), SenseInfo('02083908-a', 2) ],
"_great_n_1_rel" : [ SenseInfo('10145081-n', 0) ],
"_calibre_n_1_rel" : [ SenseInfo('04728068-n', 1), SenseInfo('05103283-n', 0) ],
"_crossroads_n_1_rel" : [ SenseInfo('08226978-n', 4), SenseInfo('14033185-n', 1), SenseInfo('05764613-n', 1) ],
"_distinguish_v_between_rel" : [ SenseInfo('00650353-v', 15), SenseInfo('02193194-v', 6), SenseInfo('00651991-v', 3), SenseInfo('00922438-v', 0), SenseInfo('00652346-v', 0) ],
"_capsule_n_1_rel" : [ SenseInfo('02957755-n', 2), SenseInfo('02957586-n', 2), SenseInfo('11685179-n', 0), SenseInfo('06468123-n', 0), SenseInfo('05317191-n', 0), SenseInfo('04264765-n', 0), SenseInfo('03267468-n', 0) ],
"_want_v_in_rel" : [ SenseInfo('01825237-v', 389), SenseInfo('01188725-v', 15), SenseInfo('01317064-v', 3), SenseInfo('00709205-v', 2), SenseInfo('02632567-v', 0) ],
"_endpoint_n_1_rel" : [ SenseInfo('08566554-n', 1) ],
"_concede_v_to_rel" : [ SenseInfo('00818553-v', 10), SenseInfo('00806049-v', 6), SenseInfo('02316649-v', 4), SenseInfo('01117609-v', 0), SenseInfo('00818553-v', 10), SenseInfo('00806049-v', 6), SenseInfo('02316649-v', 4), SenseInfo('01117609-v', 0), SenseInfo('00818553-v', 10), SenseInfo('00806049-v', 6), SenseInfo('02316649-v', 4), SenseInfo('01117609-v', 0) ],
"_cluttered_a_1_rel" : [ SenseInfo('02424949-a', 3) ],
"_pyramid_n_1_rel" : [ SenseInfo('13914837-n', 0), SenseInfo('13343284-n', 0), SenseInfo('04029125-n', 0) ],
"_kbps_n_1_rel" : [  ],
"_frigid_a_1_rel" : [ SenseInfo('01466775-a', 2), SenseInfo('01252151-a', 1), SenseInfo('01258264-a', 0), SenseInfo('01466775-a', 2), SenseInfo('01252151-a', 1), SenseInfo('01258264-a', 0) ],
"_lag_v_1_rel" : [ SenseInfo('01997862-v', 7), SenseInfo('02494356-v', 0), SenseInfo('01513045-v', 0), SenseInfo('01339050-v', 0) ],
"_trademark_v_1_rel" : [ SenseInfo('01588876-v', 0), SenseInfo('01002161-v', 0) ],
"_uncut_a_1_rel" : [ SenseInfo('02455069-a', 0), SenseInfo('01566288-a', 0), SenseInfo('00664167-a', 0), SenseInfo('00663104-a', 0), SenseInfo('00662687-a', 0), SenseInfo('01319583-a', 0), SenseInfo('00005107-a', 0), SenseInfo('02455069-a', 0), SenseInfo('01566288-a', 0), SenseInfo('00664167-a', 0), SenseInfo('00663104-a', 0), SenseInfo('00662687-a', 0), SenseInfo('01319583-a', 0), SenseInfo('00005107-a', 0) ],
"_summary_n_1_rel" : [ SenseInfo('06467007-n', 5) ],
"_speechless_a_1_rel" : [ SenseInfo('00152629-a', 0) ],
"_jerk_n_1_rel" : [ SenseInfo('10221040-n', 2), SenseInfo('00335988-n', 1), SenseInfo('15279480-n', 0), SenseInfo('07664770-n', 0), SenseInfo('00626423-n', 0), SenseInfo('00115500-n', 0) ],
"_pledge_n_1_rel" : [ SenseInfo('13350702-n', 0), SenseInfo('10441410-n', 0), SenseInfo('07884413-n', 0), SenseInfo('07227772-n', 0), SenseInfo('13350702-n', 0), SenseInfo('10441410-n', 0), SenseInfo('07884413-n', 0), SenseInfo('07227772-n', 0), SenseInfo('13350702-n', 0), SenseInfo('10441410-n', 0), SenseInfo('07884413-n', 0), SenseInfo('07227772-n', 0), SenseInfo('13350702-n', 0), SenseInfo('10441410-n', 0), SenseInfo('07884413-n', 0), SenseInfo('07227772-n', 0) ],
"_ridiculous_a_1_rel" : [ SenseInfo('00752847-a', 4), SenseInfo('02570643-a', 3), SenseInfo('01266397-a', 0), SenseInfo('00752847-a', 4), SenseInfo('02570643-a', 3), SenseInfo('01266397-a', 0) ],
"_jingle_v_1_rel" : [ SenseInfo('02172683-v', 1), SenseInfo('02172683-v', 1) ],
"_compost_n_1_rel" : [ SenseInfo('14818101-n', 3) ],
"_whimper_v_1_rel" : [ SenseInfo('00066025-v', 1), SenseInfo('00066025-v', 1) ],
"_gnat_n_1_rel" : [ SenseInfo('02202287-n', 0), SenseInfo('02200630-n', 0) ],
"_telnet_v_1_rel" : [  ],
"_bouldering_n_1_rel" : [  ],
"_predicted_a_1_rel" : [  ],
"_refund_v_1_rel" : [ SenseInfo('02284951-v', 1), SenseInfo('02284951-v', 1), SenseInfo('02284951-v', 1) ],
"_gift+wrap_v_1_rel" : [ SenseInfo('01284160-v', 0), SenseInfo('01284160-v', 0) ],
"_envelop_v_1_rel" : [ SenseInfo('01580467-v', 3) ],
"_phobia_n_1_rel" : [ SenseInfo('14381416-n', 0) ],
"_count_v_1_rel" : [ SenseInfo('00948071-v', 23), SenseInfo('02645839-v', 7), SenseInfo('00950431-v', 4), SenseInfo('00947857-v', 3), SenseInfo('02731632-v', 2), SenseInfo('00685081-v', 2), SenseInfo('02747140-v', 0), SenseInfo('00712708-v', 0), SenseInfo('00712556-v', 0), SenseInfo('00948071-v', 23), SenseInfo('02645839-v', 7), SenseInfo('00950431-v', 4), SenseInfo('00947857-v', 3), SenseInfo('02731632-v', 2), SenseInfo('00685081-v', 2), SenseInfo('02747140-v', 0), SenseInfo('00712708-v', 0), SenseInfo('00712556-v', 0), SenseInfo('00948071-v', 23), SenseInfo('02645839-v', 7), SenseInfo('00950431-v', 4), SenseInfo('00947857-v', 3), SenseInfo('02731632-v', 2), SenseInfo('00685081-v', 2), SenseInfo('02747140-v', 0), SenseInfo('00712708-v', 0), SenseInfo('00712556-v', 0) ],
"_tactic_n_1_rel" : [ SenseInfo('05905152-n', 4) ],
"_yippee_a_1_rel" : [  ],
"_euro_n_1_rel" : [ SenseInfo('13661820-n', 0), SenseInfo('13661820-n', 0), SenseInfo('13661820-n', 0), SenseInfo('13661820-n', 0) ],
"_radiator_n_1_rel" : [ SenseInfo('09403211-n', 1), SenseInfo('04041069-n', 0), SenseInfo('04040759-n', 0) ],
"_guestbook_n_1_rel" : [  ],
"_a+mite_x_deg_rel" : [  ],
"_lucky_a_1_rel" : [ SenseInfo('01049210-a', 11), SenseInfo('01468097-a', 1), SenseInfo('00177547-a', 0), SenseInfo('01049210-a', 11), SenseInfo('01468097-a', 1), SenseInfo('00177547-a', 0), SenseInfo('01049210-a', 11), SenseInfo('01468097-a', 1), SenseInfo('00177547-a', 0), SenseInfo('01049210-a', 11), SenseInfo('01468097-a', 1), SenseInfo('00177547-a', 0), SenseInfo('01049210-a', 11), SenseInfo('01468097-a', 1), SenseInfo('00177547-a', 0), SenseInfo('01049210-a', 11), SenseInfo('01468097-a', 1), SenseInfo('00177547-a', 0), SenseInfo('01049210-a', 11), SenseInfo('01468097-a', 1), SenseInfo('00177547-a', 0), SenseInfo('01049210-a', 11), SenseInfo('01468097-a', 1), SenseInfo('00177547-a', 0), SenseInfo('01049210-a', 11), SenseInfo('01468097-a', 1), SenseInfo('00177547-a', 0), SenseInfo('01049210-a', 11), SenseInfo('01468097-a', 1), SenseInfo('00177547-a', 0), SenseInfo('01049210-a', 11), SenseInfo('01468097-a', 1), SenseInfo('00177547-a', 0) ],
"_characterize_v_1_rel" : [ SenseInfo('00956687-v', 9), SenseInfo('02697950-v', 8), SenseInfo('00956687-v', 9), SenseInfo('02697950-v', 8) ],
"_necessity_n_1_rel" : [ SenseInfo('14450691-n', 11), SenseInfo('09367203-n', 7), SenseInfo('14450691-n', 11), SenseInfo('09367203-n', 7), SenseInfo('14450691-n', 11), SenseInfo('09367203-n', 7) ],
"_aforethought_v_1_rel" : [  ],
"_forward_v_1_rel" : [ SenseInfo('01955508-v', 3), SenseInfo('01955508-v', 3) ],
"_alligator_v_1_rel" : [ SenseInfo('00337700-v', 0) ],
"_croak_n_1_rel" : [ SenseInfo('07125367-n', 0) ],
"_cobblestone_n_1_rel" : [ SenseInfo('03059528-n', 0), SenseInfo('03059528-n', 0) ],
"_party_v_1_rel" : [ SenseInfo('02491851-v', 0) ],
"_descant_n_1_rel" : [ SenseInfo('07032026-n', 0) ],
"person_rel" : [  ],
"_clamp_v_1_rel" : [ SenseInfo('01343610-v', 7), SenseInfo('00747932-v', 1) ],
"_better+yet_a_1_rel" : [  ],
"_lighten_v_cause_rel" : [ SenseInfo('01814074-v', 1), SenseInfo('01487573-v', 0), SenseInfo('00860136-v', 0), SenseInfo('00312815-v', 0), SenseInfo('00280930-v', 0), SenseInfo('00199067-v', 0) ],
"_unappeal_v_to_rel" : [  ],
"_mod_a_1_rel" : [ SenseInfo('00972902-a', 0) ],
"_outcome_n_1_rel" : [ SenseInfo('07292694-n', 16), SenseInfo('11410625-n', 2) ],
"_pagoda_n_1_rel" : [ SenseInfo('03874965-n', 0) ],
"_spool_v_cause_rel" : [ SenseInfo('02233533-v', 0), SenseInfo('01522878-v', 0) ],
"_sop_v_up_rel" : [ SenseInfo('02284429-v', 0), SenseInfo('01605692-v', 0), SenseInfo('01577513-v', 0), SenseInfo('00216216-v', 0) ],
"_blotch_v_1_rel" : [ SenseInfo('01696135-v', 0) ],
"_imaginings_n_1_rel" : [  ],
"_blunt_a_1_rel" : [ SenseInfo('01811683-a', 1), SenseInfo('00800464-a', 1), SenseInfo('00764484-a', 1), SenseInfo('00556881-a', 0), SenseInfo('01811683-a', 1), SenseInfo('00800464-a', 1), SenseInfo('00764484-a', 1), SenseInfo('00556881-a', 0), SenseInfo('01811683-a', 1), SenseInfo('00800464-a', 1), SenseInfo('00764484-a', 1), SenseInfo('00556881-a', 0) ],
"_pressure_n_1_rel" : [ SenseInfo('11495041-n', 65), SenseInfo('05195362-n', 29), SenseInfo('00113113-n', 4), SenseInfo('14451349-n', 3), SenseInfo('05724475-n', 2), SenseInfo('14477076-n', 0), SenseInfo('11429458-n', 0), SenseInfo('11495041-n', 65), SenseInfo('05195362-n', 29), SenseInfo('00113113-n', 4), SenseInfo('14451349-n', 3), SenseInfo('05724475-n', 2), SenseInfo('14477076-n', 0), SenseInfo('11429458-n', 0) ],
"_mountain+lodge_n_1_rel" : [  ],
"_hear_v_back-from_rel" : [ SenseInfo('02169702-v', 275), SenseInfo('00598954-v', 60), SenseInfo('02500902-v', 12), SenseInfo('02107442-v', 8), SenseInfo('02171039-v', 0) ],
"_confederate_n_1_rel" : [ SenseInfo('09953615-n', 1), SenseInfo('09953483-n', 0), SenseInfo('09761068-n', 0) ],
"_hurtle_v_1_rel" : [ SenseInfo('02092183-v', 3), SenseInfo('02062212-v', 2), SenseInfo('01507143-v', 0) ],
"_know_v_about_rel" : [ SenseInfo('00594621-v', 585), SenseInfo('00595935-v', 142), SenseInfo('00595630-v', 123), SenseInfo('00594337-v', 76), SenseInfo('00596644-v', 17), SenseInfo('00592883-v', 10), SenseInfo('00596132-v', 1), SenseInfo('01426397-v', 0), SenseInfo('00608670-v', 0), SenseInfo('00608502-v', 0), SenseInfo('00608372-v', 0) ],
"_middle_n_of_rel" : [ SenseInfo('08523483-n', 10), SenseInfo('05868272-n', 2), SenseInfo('05555473-n', 2), SenseInfo('15266685-n', 1) ],
"_pm_x_rel" : [ SenseInfo('00141396-n', 1), SenseInfo('14651479-n', 0), SenseInfo('09907196-n', 0), SenseInfo('06281848-n', 0), SenseInfo('00141396-n', 1), SenseInfo('14651479-n', 0), SenseInfo('09907196-n', 0), SenseInfo('06281848-n', 0), SenseInfo('00141396-n', 1), SenseInfo('14651479-n', 0), SenseInfo('09907196-n', 0), SenseInfo('06281848-n', 0), SenseInfo('00141396-n', 1), SenseInfo('14651479-n', 0), SenseInfo('09907196-n', 0), SenseInfo('06281848-n', 0), SenseInfo('00141396-n', 1), SenseInfo('14651479-n', 0), SenseInfo('09907196-n', 0), SenseInfo('06281848-n', 0), SenseInfo('00141396-n', 1), SenseInfo('14651479-n', 0), SenseInfo('09907196-n', 0), SenseInfo('06281848-n', 0), SenseInfo('00141396-n', 1), SenseInfo('14651479-n', 0), SenseInfo('09907196-n', 0), SenseInfo('06281848-n', 0), SenseInfo('00141396-n', 1), SenseInfo('14651479-n', 0), SenseInfo('09907196-n', 0), SenseInfo('06281848-n', 0), SenseInfo('00141396-n', 1), SenseInfo('14651479-n', 0), SenseInfo('09907196-n', 0), SenseInfo('06281848-n', 0) ],
"_nok_n_1_rel" : [  ],
"_artistic_a_1_rel" : [ SenseInfo('02991122-a', 18), SenseInfo('00069948-a', 3), SenseInfo('02393086-a', 0) ],
"_squarely_a_1_rel" : [  ],
"_buttermilk_n_1_rel" : [ SenseInfo('07847047-n', 0) ],
"_pivot_v_cause_rel" : [ SenseInfo('02046572-v', 1) ],
"_po_n_1_rel" : [ SenseInfo('14650556-n', 0), SenseInfo('10420809-n', 0), SenseInfo('09396150-n', 0), SenseInfo('08145277-n', 0) ],
"_erroneous_a_1_rel" : [ SenseInfo('00632949-a', 1), SenseInfo('00632949-a', 1) ],
"_fore+and+aft_a_1_rel" : [ SenseInfo('01445320-a', 0), SenseInfo('01445320-a', 0), SenseInfo('01445320-a', 0) ],
"_ulcer_n_1_rel" : [ SenseInfo('14211609-n', 4) ],
"_brat_n_1_rel" : [ SenseInfo('10702483-n', 0), SenseInfo('07677982-n', 0) ],
"_break_v_cause_rel" : [ SenseInfo('00364064-v', 15), SenseInfo('00334186-v', 13), SenseInfo('00258665-v', 9), SenseInfo('01369758-v', 8), SenseInfo('00334996-v', 8), SenseInfo('02566528-v', 5), SenseInfo('02073233-v', 4), SenseInfo('02029369-v', 4), SenseInfo('01785395-v', 4), SenseInfo('00362348-v', 4), SenseInfo('02570684-v', 3), SenseInfo('00202569-v', 3), SenseInfo('02668523-v', 2), SenseInfo('01106864-v', 2), SenseInfo('00933821-v', 2), SenseInfo('00558536-v', 2), SenseInfo('00434374-v', 2), SenseInfo('02535716-v', 1), SenseInfo('02030764-v', 1), SenseInfo('01972976-v', 1), SenseInfo('00390215-v', 1), SenseInfo('00202784-v', 1), SenseInfo('02746617-v', 0), SenseInfo('02746449-v', 0), SenseInfo('02681639-v', 0), SenseInfo('02681524-v', 0), SenseInfo('02625187-v', 0), SenseInfo('02600082-v', 0), SenseInfo('02559395-v', 0), SenseInfo('02478469-v', 0), SenseInfo('02431320-v', 0), SenseInfo('02399331-v', 0), SenseInfo('02318165-v', 0), SenseInfo('02101373-v', 0), SenseInfo('01991347-v', 0), SenseInfo('01989053-v', 0), SenseInfo('01896484-v', 0), SenseInfo('01610666-v', 0), SenseInfo('01610463-v', 0), SenseInfo('01597995-v', 0), SenseInfo('01557646-v', 0), SenseInfo('01369346-v', 0), SenseInfo('01298931-v', 0), SenseInfo('01228524-v', 0), SenseInfo('01228396-v', 0), SenseInfo('00935987-v', 0), SenseInfo('00779061-v', 0), SenseInfo('00778745-v', 0), SenseInfo('00744439-v', 0), SenseInfo('00738440-v', 0), SenseInfo('00738314-v', 0), SenseInfo('00551412-v', 0), SenseInfo('00339464-v', 0), SenseInfo('00336260-v', 0), SenseInfo('00258366-v', 0), SenseInfo('00155046-v', 0), SenseInfo('00107739-v', 0), SenseInfo('00107604-v', 0), SenseInfo('00030463-v', 0) ],
"_bounce_n_1_rel" : [ SenseInfo('05020981-n', 2), SenseInfo('00120202-n', 1), SenseInfo('07350401-n', 0) ],
"_slate_v_1_rel" : [ SenseInfo('00709844-v', 2), SenseInfo('02397106-v', 0), SenseInfo('01338368-v', 0), SenseInfo('00709844-v', 2), SenseInfo('02397106-v', 0), SenseInfo('01338368-v', 0) ],
"_prophet_n_1_rel" : [ SenseInfo('10483530-n', 3), SenseInfo('10483890-n', 1) ],
"_flop_n_1_rel" : [ SenseInfo('13481994-n', 0), SenseInfo('10097477-n', 0), SenseInfo('07365024-n', 0), SenseInfo('00327510-n', 0) ],
"_radical_n_1_rel" : [ SenseInfo('14621446-n', 4), SenseInfo('14874196-n', 3), SenseInfo('10503452-n', 1), SenseInfo('13731530-n', 0), SenseInfo('06841159-n', 0), SenseInfo('06300193-n', 0) ],
"_opportune_a_1_rel" : [ SenseInfo('01660994-a', 0), SenseInfo('01660994-a', 0) ],
"_on-campus_a_1_rel" : [  ],
"_demographic_n_1_rel" : [ SenseInfo('06022076-n', 0) ],
"_tyne_n_1_rel" : [ SenseInfo('09464805-n', 0) ],
"_launch_v_cause_rel" : [ SenseInfo('02427103-v', 10), SenseInfo('01514655-v', 6), SenseInfo('01515415-v', 4), SenseInfo('00347918-v', 2), SenseInfo('01515196-v', 0), SenseInfo('01253363-v', 0) ],
"_trustee_n_1_rel" : [ SenseInfo('10732314-n', 6), SenseInfo('10516294-n', 1) ],
"_demand_v_1_rel" : [ SenseInfo('00754942-v', 47), SenseInfo('02627934-v', 22), SenseInfo('01017826-v', 7), SenseInfo('01069090-v', 0), SenseInfo('01068985-v', 0), SenseInfo('01018065-v', 0) ],
"_disguise_v_1_rel" : [ SenseInfo('02158587-v', 1) ],
"_excursion_n_1_rel" : [ SenseInfo('00311809-n', 1), SenseInfo('00310201-n', 0) ],
"_valley_n_of_rel" : [ SenseInfo('09468604-n', 27), SenseInfo('09468604-n', 27) ],
"_unacceptable_a_1_rel" : [ SenseInfo('02083053-a', 1), SenseInfo('00018584-a', 0), SenseInfo('02436025-a', 0), SenseInfo('02298766-a', 0), SenseInfo('02083053-a', 1), SenseInfo('00018584-a', 0), SenseInfo('02436025-a', 0), SenseInfo('02298766-a', 0), SenseInfo('02083053-a', 1), SenseInfo('00018584-a', 0), SenseInfo('02436025-a', 0), SenseInfo('02298766-a', 0) ],
"_invade_v_1_rel" : [ SenseInfo('01126360-v', 7), SenseInfo('02019716-v', 4), SenseInfo('02654686-v', 0), SenseInfo('01227488-v', 0) ],
"_gem_n_1_rel" : [ SenseInfo('03432972-n', 1), SenseInfo('14699752-n', 0), SenseInfo('10221656-n', 0), SenseInfo('07690273-n', 0), SenseInfo('03596787-n', 0) ],
"_license_v_1_rel" : [ SenseInfo('02444662-v', 2), SenseInfo('02444662-v', 2) ],
"_lie_v_1_rel" : [ SenseInfo('02690708-v', 88), SenseInfo('01547001-v', 58), SenseInfo('02653381-v', 15), SenseInfo('02734338-v', 14), SenseInfo('00834259-v', 9), SenseInfo('02731390-v', 4), SenseInfo('01985029-v', 4), SenseInfo('02690708-v', 88), SenseInfo('01547001-v', 58), SenseInfo('02653381-v', 15), SenseInfo('02734338-v', 14), SenseInfo('00834259-v', 9), SenseInfo('02731390-v', 4), SenseInfo('01985029-v', 4) ],
"_neon_n_1_rel" : [ SenseInfo('14646152-n', 0) ],
"_west_n_of_rel" : [ SenseInfo('08682575-n', 19), SenseInfo('13834399-n', 10), SenseInfo('08682819-n', 6), SenseInfo('13836136-n', 0), SenseInfo('11382398-n', 0), SenseInfo('11382278-n', 0), SenseInfo('11382112-n', 0), SenseInfo('08561835-n', 0) ],
"_stiffen_v_up_rel" : [ SenseInfo('00418563-v', 11), SenseInfo('00417596-v', 2), SenseInfo('00418765-v', 0), SenseInfo('00418563-v', 11), SenseInfo('00417596-v', 2), SenseInfo('00418765-v', 0) ],
"_slam_v_1_rel" : [ SenseInfo('01242832-v', 8), SenseInfo('01242391-v', 8), SenseInfo('01897885-v', 0), SenseInfo('01242689-v', 0), SenseInfo('01242832-v', 8), SenseInfo('01242391-v', 8), SenseInfo('01897885-v', 0), SenseInfo('01242689-v', 0), SenseInfo('01242832-v', 8), SenseInfo('01242391-v', 8), SenseInfo('01897885-v', 0), SenseInfo('01242689-v', 0) ],
"_location_n_1_rel" : [ SenseInfo('00027167-n', 992), SenseInfo('01051331-n', 2), SenseInfo('00155487-n', 2), SenseInfo('03682189-n', 0), SenseInfo('00027167-n', 992), SenseInfo('01051331-n', 2), SenseInfo('00155487-n', 2), SenseInfo('03682189-n', 0) ],
"_accordance_n_with_rel" : [ SenseInfo('07176804-n', 8), SenseInfo('01086572-n', 0) ],
"_telesales_n_1_rel" : [  ],
"_observation_n_of_rel" : [ SenseInfo('01002956-n', 26), SenseInfo('00879759-n', 6), SenseInfo('06767035-n', 1), SenseInfo('05818741-n', 1), SenseInfo('05703429-n', 1), SenseInfo('01002956-n', 26), SenseInfo('00879759-n', 6), SenseInfo('06767035-n', 1), SenseInfo('05818741-n', 1), SenseInfo('05703429-n', 1), SenseInfo('01002956-n', 26), SenseInfo('00879759-n', 6), SenseInfo('06767035-n', 1), SenseInfo('05818741-n', 1), SenseInfo('05703429-n', 1) ],
"_pun_v_1_rel" : [ SenseInfo('01702331-v', 0) ],
"_compass_n_1_rel" : [ SenseInfo('03080497-n', 3), SenseInfo('05125377-n', 2), SenseInfo('05623628-n', 0), SenseInfo('03080633-n', 0) ],
"_cabbage_n_1_rel" : [ SenseInfo('07713895-n', 1), SenseInfo('13385216-n', 0), SenseInfo('11875691-n', 0) ],
"_unquestionable_a_1_rel" : [ SenseInfo('01918184-a', 0), SenseInfo('01115635-a', 0), SenseInfo('00897363-a', 0) ],
"_fry_n_1_rel" : [ SenseInfo('10984257-n', 0), SenseInfo('10984126-n', 0), SenseInfo('09917593-n', 0) ],
"_periodic_a_1_rel" : [ SenseInfo('01967240-a', 5), SenseInfo('00594004-a', 0) ],
"_deregulate_v_1_rel" : [ SenseInfo('02512005-v', 0) ],
"_nostril_n_1_rel" : [ SenseInfo('05600109-n', 0) ],
"_daresay_v_1_rel" : [  ],
"_convincing_a_1_rel" : [ SenseInfo('00614990-a', 4), SenseInfo('00614990-a', 4) ],
"_slacken_v_1_rel" : [ SenseInfo('00440580-v', 4), SenseInfo('00441212-v', 1), SenseInfo('00421408-v', 0), SenseInfo('00421125-v', 0) ],
"_oxygen_n_1_rel" : [ SenseInfo('14648100-n', 39) ],
"_considerably_x_rel" : [ SenseInfo('00014285-r', 19) ],
"_restful_a_1_rel" : [ SenseInfo('01922227-a', 0), SenseInfo('01922227-a', 0) ],
"_guide_v_to_rel" : [ SenseInfo('01931768-v', 12), SenseInfo('01999798-v', 11), SenseInfo('02439732-v', 8), SenseInfo('02159427-v', 0), SenseInfo('01212230-v', 0), SenseInfo('01931768-v', 12), SenseInfo('01999798-v', 11), SenseInfo('02439732-v', 8), SenseInfo('02159427-v', 0), SenseInfo('01212230-v', 0) ],
"_hybrid_n_1_rel" : [ SenseInfo('06293229-n', 0), SenseInfo('05870615-n', 0), SenseInfo('01327322-n', 0) ],
"_observatory_n_1_rel" : [ SenseInfo('03839671-n', 0), SenseInfo('03688943-n', 0) ],
"_provincial_n_1_rel" : [ SenseInfo('10458834-n', 0), SenseInfo('10410668-n', 0) ],
"_subsistence_n_1_rel" : [ SenseInfo('13366537-n', 3), SenseInfo('13962360-n', 1), SenseInfo('13957493-n', 0) ],
"_vague_a_1_rel" : [ SenseInfo('00431004-a', 18), SenseInfo('00697389-a', 8), SenseInfo('00782216-a', 1), SenseInfo('00431004-a', 18), SenseInfo('00697389-a', 8), SenseInfo('00782216-a', 1), SenseInfo('00431004-a', 18), SenseInfo('00697389-a', 8), SenseInfo('00782216-a', 1), SenseInfo('00431004-a', 18), SenseInfo('00697389-a', 8), SenseInfo('00782216-a', 1) ],
"_abdication_n_1_rel" : [ SenseInfo('07254456-n', 0), SenseInfo('06511762-n', 0) ],
"_moss_n_1_rel" : [ SenseInfo('11537506-n', 1) ],
"_wireless_n_1_rel" : [ SenseInfo('06277135-n', 0), SenseInfo('06275353-n', 0), SenseInfo('04043733-n', 0), SenseInfo('04041544-n', 0) ],
"_reimburse_v_for_rel" : [ SenseInfo('02285205-v', 1), SenseInfo('02249591-v', 0), SenseInfo('02285205-v', 1), SenseInfo('02249591-v', 0) ],
"_wish_v_1_rel" : [ SenseInfo('01824339-v', 48), SenseInfo('01824736-v', 31), SenseInfo('00903212-v', 12), SenseInfo('01824532-v', 5), SenseInfo('00903098-v', 2), SenseInfo('00902932-v', 2), SenseInfo('01824339-v', 48), SenseInfo('01824736-v', 31), SenseInfo('00903212-v', 12), SenseInfo('01824532-v', 5), SenseInfo('00903098-v', 2), SenseInfo('00902932-v', 2), SenseInfo('01824339-v', 48), SenseInfo('01824736-v', 31), SenseInfo('00903212-v', 12), SenseInfo('01824532-v', 5), SenseInfo('00903098-v', 2), SenseInfo('00902932-v', 2), SenseInfo('01824339-v', 48), SenseInfo('01824736-v', 31), SenseInfo('00903212-v', 12), SenseInfo('01824532-v', 5), SenseInfo('00903098-v', 2), SenseInfo('00902932-v', 2), SenseInfo('01824339-v', 48), SenseInfo('01824736-v', 31), SenseInfo('00903212-v', 12), SenseInfo('01824532-v', 5), SenseInfo('00903098-v', 2), SenseInfo('00902932-v', 2), SenseInfo('01824339-v', 48), SenseInfo('01824736-v', 31), SenseInfo('00903212-v', 12), SenseInfo('01824532-v', 5), SenseInfo('00903098-v', 2), SenseInfo('00902932-v', 2) ],
"_regression_n_1_rel" : [ SenseInfo('14503354-n', 0), SenseInfo('13548931-n', 0), SenseInfo('06027264-n', 0), SenseInfo('00235208-n', 0) ],
"_showy_a_1_rel" : [ SenseInfo('01848701-a', 1), SenseInfo('00796591-a', 0), SenseInfo('00407420-a', 0), SenseInfo('00168039-a', 0), SenseInfo('01848701-a', 1), SenseInfo('00796591-a', 0), SenseInfo('00407420-a', 0), SenseInfo('00168039-a', 0), SenseInfo('01848701-a', 1), SenseInfo('00796591-a', 0), SenseInfo('00407420-a', 0), SenseInfo('00168039-a', 0) ],
"_underestimate_n_1_rel" : [ SenseInfo('05804491-n', 0) ],
"_enigma_n_1_rel" : [ SenseInfo('05685538-n', 1), SenseInfo('06785223-n', 0) ],
"_after+school_a_1_rel" : [ SenseInfo('01693189-a', 1), SenseInfo('01693189-a', 1) ],
"_headlands_n_1_rel" : [ SenseInfo('09399592-n', 2), SenseInfo('09399592-n', 2) ],
"_grenade_n_1_rel" : [ SenseInfo('03458271-n', 5) ],
"_grind_n_1_rel" : [ SenseInfo('10684630-n', 0), SenseInfo('05094424-n', 0), SenseInfo('00621476-n', 0), SenseInfo('00358290-n', 0) ],
"_simplicity_n_1_rel" : [ SenseInfo('04766059-n', 4), SenseInfo('04881369-n', 1), SenseInfo('04786490-n', 0), SenseInfo('04708113-n', 0), SenseInfo('04697442-n', 0) ],
"_arm_v_1_rel" : [ SenseInfo('01087197-v', 4), SenseInfo('02334867-v', 1) ],
"_medicine_n_1_rel" : [ SenseInfo('06043075-n', 5), SenseInfo('03740161-n', 3), SenseInfo('00612160-n', 3), SenseInfo('01162529-n', 0) ],
"_appalling_a_1_rel" : [ SenseInfo('00193367-a', 4) ],
"_circumnavigate_v_1_rel" : [ SenseInfo('01911526-v', 0) ],
"_octogon_n_1_rel" : [  ],
"_fireworks_n_1_rel" : [ SenseInfo('03348454-n', 2) ],
"_input_v_1_rel" : [ SenseInfo('01422539-v', 0), SenseInfo('01422539-v', 0) ],
"_group_n_of_rel" : [ SenseInfo('00031264-n', 1345), SenseInfo('14621446-n', 1), SenseInfo('06016853-n', 0), SenseInfo('00031264-n', 1345), SenseInfo('14621446-n', 1), SenseInfo('06016853-n', 0), SenseInfo('00031264-n', 1345), SenseInfo('14621446-n', 1), SenseInfo('06016853-n', 0) ],
"_untie_v_1_rel" : [ SenseInfo('01284461-v', 3), SenseInfo('01284908-v', 0) ],
"_campfire_n_1_rel" : [ SenseInfo('07303585-n', 3) ],
"_parametric_a_1_rel" : [ SenseInfo('02911346-a', 2) ],
"_design_n_of_rel" : [ SenseInfo('00928077-n', 13), SenseInfo('05728678-n', 12), SenseInfo('05902327-n', 3), SenseInfo('03178782-n', 2), SenseInfo('05982152-n', 1), SenseInfo('03179318-n', 1), SenseInfo('05633385-n', 0) ],
"_wake_n_1_rel" : [ SenseInfo('11411610-n', 4), SenseInfo('08838556-n', 0), SenseInfo('07344368-n', 0), SenseInfo('01029883-n', 0) ],
"_stencil_v_1_rel" : [ SenseInfo('01749660-v', 0) ],
"_photosensitization_n_1_rel" : [  ],
"_nip_n_of_rel" : [ SenseInfo('13773250-n', 0), SenseInfo('09718652-n', 0), SenseInfo('05715864-n', 0), SenseInfo('05015678-n', 0), SenseInfo('04993108-n', 0), SenseInfo('00842281-n', 0) ],
"_heavy_a_1_rel" : [ SenseInfo('01184932-a', 32), SenseInfo('01190683-a', 10), SenseInfo('01193373-a', 5), SenseInfo('01188762-a', 2), SenseInfo('00987769-a', 1), SenseInfo('00502487-a', 1), SenseInfo('00462409-a', 1), SenseInfo('01191618-a', 0), SenseInfo('01191227-a', 0), SenseInfo('02514239-a', 0), SenseInfo('02416390-a', 0), SenseInfo('02411559-a', 0), SenseInfo('02411447-a', 0), SenseInfo('02402439-a', 0), SenseInfo('01457692-a', 0), SenseInfo('01299173-a', 0), SenseInfo('01278423-a', 0), SenseInfo('01192786-a', 0), SenseInfo('01188491-a', 0), SenseInfo('01183114-a', 0), SenseInfo('01145639-a', 0), SenseInfo('01085268-a', 0), SenseInfo('00837415-a', 0), SenseInfo('00836544-a', 0), SenseInfo('00807667-a', 0), SenseInfo('00693020-a', 0), SenseInfo('00173391-a', 0), SenseInfo('01184932-a', 32), SenseInfo('01190683-a', 10), SenseInfo('01193373-a', 5), SenseInfo('01188762-a', 2), SenseInfo('00987769-a', 1), SenseInfo('00502487-a', 1), SenseInfo('00462409-a', 1), SenseInfo('01191618-a', 0), SenseInfo('01191227-a', 0), SenseInfo('02514239-a', 0), SenseInfo('02416390-a', 0), SenseInfo('02411559-a', 0), SenseInfo('02411447-a', 0), SenseInfo('02402439-a', 0), SenseInfo('01457692-a', 0), SenseInfo('01299173-a', 0), SenseInfo('01278423-a', 0), SenseInfo('01192786-a', 0), SenseInfo('01188491-a', 0), SenseInfo('01183114-a', 0), SenseInfo('01145639-a', 0), SenseInfo('01085268-a', 0), SenseInfo('00837415-a', 0), SenseInfo('00836544-a', 0), SenseInfo('00807667-a', 0), SenseInfo('00693020-a', 0), SenseInfo('00173391-a', 0), SenseInfo('01184932-a', 32), SenseInfo('01190683-a', 10), SenseInfo('01193373-a', 5), SenseInfo('01188762-a', 2), SenseInfo('00987769-a', 1), SenseInfo('00502487-a', 1), SenseInfo('00462409-a', 1), SenseInfo('01191618-a', 0), SenseInfo('01191227-a', 0), SenseInfo('02514239-a', 0), SenseInfo('02416390-a', 0), SenseInfo('02411559-a', 0), SenseInfo('02411447-a', 0), SenseInfo('02402439-a', 0), SenseInfo('01457692-a', 0), SenseInfo('01299173-a', 0), SenseInfo('01278423-a', 0), SenseInfo('01192786-a', 0), SenseInfo('01188491-a', 0), SenseInfo('01183114-a', 0), SenseInfo('01145639-a', 0), SenseInfo('01085268-a', 0), SenseInfo('00837415-a', 0), SenseInfo('00836544-a', 0), SenseInfo('00807667-a', 0), SenseInfo('00693020-a', 0), SenseInfo('00173391-a', 0), SenseInfo('01184932-a', 32), SenseInfo('01190683-a', 10), SenseInfo('01193373-a', 5), SenseInfo('01188762-a', 2), SenseInfo('00987769-a', 1), SenseInfo('00502487-a', 1), SenseInfo('00462409-a', 1), SenseInfo('01191618-a', 0), SenseInfo('01191227-a', 0), SenseInfo('02514239-a', 0), SenseInfo('02416390-a', 0), SenseInfo('02411559-a', 0), SenseInfo('02411447-a', 0), SenseInfo('02402439-a', 0), SenseInfo('01457692-a', 0), SenseInfo('01299173-a', 0), SenseInfo('01278423-a', 0), SenseInfo('01192786-a', 0), SenseInfo('01188491-a', 0), SenseInfo('01183114-a', 0), SenseInfo('01145639-a', 0), SenseInfo('01085268-a', 0), SenseInfo('00837415-a', 0), SenseInfo('00836544-a', 0), SenseInfo('00807667-a', 0), SenseInfo('00693020-a', 0), SenseInfo('00173391-a', 0) ],
"_think_v_through_rel" : [ SenseInfo('00689344-v', 274), SenseInfo('00631737-v', 188), SenseInfo('00628491-v', 111), SenseInfo('00607780-v', 8), SenseInfo('01637166-v', 4), SenseInfo('00723056-v', 3), SenseInfo('00708538-v', 2), SenseInfo('00739340-v', 0), SenseInfo('00739082-v', 0), SenseInfo('00689809-v', 0), SenseInfo('00629738-v', 0), SenseInfo('00608808-v', 0), SenseInfo('00561887-v', 0) ],
"_jug_n_1_rel" : [ SenseInfo('03603722-n', 1), SenseInfo('13767956-n', 0) ],
"_chink_v_1_rel" : [ SenseInfo('02186506-v', 0), SenseInfo('01423506-v', 0), SenseInfo('00336539-v', 0) ],
"_prerequisite_n_1_rel" : [ SenseInfo('05892427-n', 1) ],
"_proprietary_a_1_rel" : [ SenseInfo('01109914-a', 0) ],
"_crack_v_up_rel" : [ SenseInfo('00336260-v', 6), SenseInfo('02183024-v', 4), SenseInfo('02182851-v', 2), SenseInfo('01401955-v', 2), SenseInfo('00539770-v', 2), SenseInfo('00337234-v', 1), SenseInfo('00337065-v', 1), SenseInfo('02571067-v', 0), SenseInfo('01785579-v', 0), SenseInfo('00953923-v', 0), SenseInfo('00336718-v', 0), SenseInfo('00238542-v', 0), SenseInfo('00238372-v', 0), SenseInfo('00336260-v', 6), SenseInfo('02183024-v', 4), SenseInfo('02182851-v', 2), SenseInfo('01401955-v', 2), SenseInfo('00539770-v', 2), SenseInfo('00337234-v', 1), SenseInfo('00337065-v', 1), SenseInfo('02571067-v', 0), SenseInfo('01785579-v', 0), SenseInfo('00953923-v', 0), SenseInfo('00336718-v', 0), SenseInfo('00238542-v', 0), SenseInfo('00238372-v', 0) ],
"_illegal_a_for_rel" : [ SenseInfo('01401854-a', 3), SenseInfo('01401854-a', 3), SenseInfo('01401854-a', 3) ],
"_hah+hah_a_1_rel" : [  ],
"_loan_v_out_rel" : [ SenseInfo('02324182-v', 3) ],
"_always_x_deg_rel" : [ SenseInfo('00019339-r', 196), SenseInfo('00020476-r', 0), SenseInfo('00020280-r', 0), SenseInfo('00019757-r', 0), SenseInfo('00019609-r', 0) ],
"_subpoena_v_1_rel" : [ SenseInfo('00793418-v', 1) ],
"_kernel_n_1_rel" : [ SenseInfo('13137010-n', 0), SenseInfo('12157056-n', 0), SenseInfo('05921123-n', 0) ],
"_gum_v_1_rel" : [ SenseInfo('01364019-v', 0), SenseInfo('01175224-v', 0), SenseInfo('00586387-v', 0), SenseInfo('00069166-v', 0) ],
"_let_v_up_rel" : [ SenseInfo('02423183-v', 219), SenseInfo('00771490-v', 15), SenseInfo('00802318-v', 2), SenseInfo('00120796-v', 2), SenseInfo('00496673-v', 1), SenseInfo('02208903-v', 0), SenseInfo('02423183-v', 219), SenseInfo('00771490-v', 15), SenseInfo('00802318-v', 2), SenseInfo('00120796-v', 2), SenseInfo('00496673-v', 1), SenseInfo('02208903-v', 0) ],
"_institute_n_of_rel" : [ SenseInfo('08407330-n', 1), SenseInfo('08407330-n', 1) ],
"_aft_p_rel" : [ SenseInfo('00275409-r', 1), SenseInfo('01033371-a', 0) ],
"_tbah_n_1_rel" : [  ],
"_conscious_a_of_rel" : [ SenseInfo('01337767-a', 7), SenseInfo('00570590-a', 6), SenseInfo('00190960-a', 6), SenseInfo('01337767-a', 7), SenseInfo('00570590-a', 6), SenseInfo('00190960-a', 6) ],
"_childlike_a_1_rel" : [ SenseInfo('01648491-a', 2), SenseInfo('02272047-a', 1) ],
"_carry-forward_n_1_rel" : [ SenseInfo('13409647-n', 0), SenseInfo('13409647-n', 0) ],
"_pug_n_1_rel" : [ SenseInfo('02110958-n', 0) ],
"_blind_n_1_rel" : [ SenseInfo('07944408-n', 5), SenseInfo('02851384-n', 1), SenseInfo('02851099-n', 1), SenseInfo('06760508-n', 0) ],
"_moose_n_1_rel" : [ SenseInfo('02432983-n', 0) ],
"_validation_n_of_rel" : [ SenseInfo('00153961-n', 1), SenseInfo('05826291-n', 0), SenseInfo('00153961-n', 1), SenseInfo('05826291-n', 0) ],
"_counsel_n_1_rel" : [ SenseInfo('09775663-n', 5), SenseInfo('06650701-n', 0) ],
"_pare_v_down_rel" : [ SenseInfo('00233089-v', 1), SenseInfo('01552219-v', 0), SenseInfo('01262936-v', 0), SenseInfo('01262564-v', 0) ],
"_monumental_a_1_rel" : [ SenseInfo('02864165-a', 1), SenseInfo('02163468-a', 0), SenseInfo('01389170-a', 0) ],
"_eclipse_n_1_rel" : [ SenseInfo('07368646-n', 2) ],
"comp_so_rel" : [  ],
"_awfully_x_deg_rel" : [ SenseInfo('00054950-r', 5), SenseInfo('00056340-r', 0), SenseInfo('00055101-r', 0) ],
"_drug_n_1_rel" : [ SenseInfo('03247620-n', 30) ],
"_tecra_n_1_rel" : [  ],
"_familiarize_v_1_rel" : [ SenseInfo('00874175-v', 0) ],
"_Gila+monster_n_1_rel" : [  ],
"_mend_v_cause_rel" : [ SenseInfo('00260648-v', 5), SenseInfo('00270561-v', 1) ],
"_conspicuous_a_1_rel" : [ SenseInfo('00579084-a', 2), SenseInfo('02090567-a', 0) ],
"_charming_a_1_rel" : [ SenseInfo('01807799-a', 8), SenseInfo('01576071-a', 0) ],
"_marriage_n_1_rel" : [ SenseInfo('13963970-n', 26), SenseInfo('07989373-n', 10), SenseInfo('01036996-n', 2), SenseInfo('14421585-n', 0) ],
"_telescope_v_1_rel" : [ SenseInfo('01594782-v', 1), SenseInfo('00244923-v', 0), SenseInfo('01594782-v', 1), SenseInfo('00244923-v', 0) ],
"_danger_n_1_rel" : [ SenseInfo('14540765-n', 18), SenseInfo('00802238-n', 8), SenseInfo('14541044-n', 6), SenseInfo('08644213-n', 1), SenseInfo('14540765-n', 18), SenseInfo('00802238-n', 8), SenseInfo('14541044-n', 6), SenseInfo('08644213-n', 1) ],
"_picture_v_as_rel" : [ SenseInfo('01635432-v', 5), SenseInfo('01686956-v', 4), SenseInfo('01635432-v', 5), SenseInfo('01686956-v', 4) ],
"_whistle_v_up_rel" : [ SenseInfo('02183626-v', 3), SenseInfo('02093088-v', 2), SenseInfo('01043441-v', 2), SenseInfo('02093234-v', 1), SenseInfo('01043887-v', 1), SenseInfo('01043612-v', 0) ],
"_equal_a_to_rel" : [ SenseInfo('00889831-a', 31), SenseInfo('00051045-a', 0), SenseInfo('00889831-a', 31), SenseInfo('00051045-a', 0), SenseInfo('00889831-a', 31), SenseInfo('00051045-a', 0) ],
"_daytrip_n_1_rel" : [  ],
"_termite_n_1_rel" : [ SenseInfo('02223266-n', 0) ],
"_haunt_v_1_rel" : [ SenseInfo('02004009-v', 3), SenseInfo('01783214-v', 3), SenseInfo('01844431-v', 0), SenseInfo('02004009-v', 3), SenseInfo('01783214-v', 3), SenseInfo('01844431-v', 0), SenseInfo('02004009-v', 3), SenseInfo('01783214-v', 3), SenseInfo('01844431-v', 0) ],
"_lonesome_a_1_rel" : [ SenseInfo('02214736-a', 0), SenseInfo('00704360-a', 0) ],
"_labored_a_1_rel" : [ SenseInfo('01141468-a', 0), SenseInfo('00837415-a', 0) ],
"_desultory_a_1_rel" : [ SenseInfo('01910819-a', 1) ],
"_obedience_n_1_rel" : [ SenseInfo('01167146-n', 3), SenseInfo('04906273-n', 0), SenseInfo('01132864-n', 0) ],
"_scot+free_a_1_rel" : [  ],
"_strap_v_up_rel" : [ SenseInfo('01289492-v', 1), SenseInfo('01411085-v', 0), SenseInfo('00392860-v', 0), SenseInfo('00083523-v', 0) ],
"_of_p_comp_rel" : [  ],
"_bleed_n_1_rel" : [  ],
"_brief_v_on_rel" : [ SenseInfo('00831273-v', 1), SenseInfo('00831273-v', 1) ],
"_coordination_n_of_rel" : [ SenseInfo('05641556-n', 1), SenseInfo('00807273-n', 1), SenseInfo('13800539-n', 0), SenseInfo('05641432-n', 0) ],
"_advisable_a_1_rel" : [ SenseInfo('00067038-a', 1), SenseInfo('00067038-a', 1) ],
"_transporter_n_1_rel" : [ SenseInfo('04474035-n', 0), SenseInfo('04473884-n', 0), SenseInfo('03100897-n', 0) ],
"_barman_n_1_rel" : [ SenseInfo('09841188-n', 0) ],
"_molecular_a_1_rel" : [ SenseInfo('02900700-a', 6), SenseInfo('01542252-a', 0) ],
"_work_v_1_rel" : [ SenseInfo('02413480-v', 74), SenseInfo('02410855-v', 62), SenseInfo('02525447-v', 32), SenseInfo('01525666-v', 20), SenseInfo('01668603-v', 9), SenseInfo('00100551-v', 9), SenseInfo('02051031-v', 5), SenseInfo('02594979-v', 4), SenseInfo('02373015-v', 3), SenseInfo('01852468-v', 3), SenseInfo('01629589-v', 3), SenseInfo('02407987-v', 2), SenseInfo('01741446-v', 2), SenseInfo('02751271-v', 0), SenseInfo('02536557-v', 0), SenseInfo('02444159-v', 0), SenseInfo('02436963-v', 0), SenseInfo('02116980-v', 0), SenseInfo('01817574-v', 0), SenseInfo('01659248-v', 0), SenseInfo('01541231-v', 0), SenseInfo('01235355-v', 0), SenseInfo('01162754-v', 0), SenseInfo('00634906-v', 0), SenseInfo('00458754-v', 0), SenseInfo('00458471-v', 0), SenseInfo('00150096-v', 0) ],
"_label_v_1_rel" : [ SenseInfo('01029852-v', 8), SenseInfo('01588493-v', 3), SenseInfo('00971650-v', 3), SenseInfo('00651480-v', 1), SenseInfo('00650932-v', 0), SenseInfo('01029852-v', 8), SenseInfo('01588493-v', 3), SenseInfo('00971650-v', 3), SenseInfo('00651480-v', 1), SenseInfo('00650932-v', 0) ],
"_come_v_i_rel" : [ SenseInfo('01849221-v', 276), SenseInfo('02005948-v', 235), SenseInfo('00341917-v', 147), SenseInfo('00542120-v', 41), SenseInfo('02625339-v', 40), SenseInfo('00342812-v', 11), SenseInfo('02743921-v', 9), SenseInfo('02743214-v', 7), SenseInfo('02686805-v', 6), SenseInfo('02743565-v', 3), SenseInfo('01839690-v', 3), SenseInfo('02729963-v', 2), SenseInfo('00344886-v', 2), SenseInfo('02645007-v', 1), SenseInfo('02627363-v', 1), SenseInfo('02006709-v', 1), SenseInfo('00723349-v', 1), SenseInfo('02737187-v', 0), SenseInfo('02617567-v', 0), SenseInfo('02197360-v', 0), SenseInfo('00659984-v', 0) ],
"_vertebrate_a_1_rel" : [ SenseInfo('02510062-a', 0) ],
"_cable_v_1_rel" : [ SenseInfo('01007222-v', 1), SenseInfo('01288921-v', 0) ],
"_peasant_n_1_rel" : [ SenseInfo('10410668-n', 6), SenseInfo('10410996-n', 1), SenseInfo('10410815-n', 0) ],
"_honor_n_1_rel" : [ SenseInfo('06696483-n', 11), SenseInfo('14436875-n', 3), SenseInfo('04869106-n', 3), SenseInfo('04849972-n', 0), SenseInfo('06696483-n', 11), SenseInfo('14436875-n', 3), SenseInfo('04869106-n', 3), SenseInfo('04849972-n', 0), SenseInfo('06696483-n', 11), SenseInfo('14436875-n', 3), SenseInfo('04869106-n', 3), SenseInfo('04849972-n', 0), SenseInfo('06696483-n', 11), SenseInfo('14436875-n', 3), SenseInfo('04869106-n', 3), SenseInfo('04849972-n', 0) ],
"_estuary_n_1_rel" : [ SenseInfo('09274500-n', 1) ],
"_van_n_1_rel" : [ SenseInfo('08465558-n', 0), SenseInfo('08215495-n', 0), SenseInfo('04520480-n', 0), SenseInfo('04520382-n', 0), SenseInfo('04520170-n', 0) ],
"_worsen_v_1_rel" : [ SenseInfo('00203866-v', 1), SenseInfo('00208210-v', 0) ],
"_imperfective_n_1_rel" : [ SenseInfo('13805020-n', 0) ],
"_feel_n_of_rel" : [ SenseInfo('05677340-n', 5), SenseInfo('14526182-n', 1), SenseInfo('04946553-n', 1), SenseInfo('00854538-n', 0) ],
"_alliance_n_1_rel" : [ SenseInfo('14418822-n', 0), SenseInfo('13792183-n', 0), SenseInfo('08293982-n', 0), SenseInfo('06773684-n', 0), SenseInfo('01081456-n', 0) ],
"_raucous_a_1_rel" : [ SenseInfo('00300359-a', 2), SenseInfo('01667110-a', 1), SenseInfo('00300359-a', 2), SenseInfo('01667110-a', 1) ],
"_duty_n_1_rel" : [ SenseInfo('01129920-n', 13), SenseInfo('00719494-n', 12), SenseInfo('13315999-n', 2), SenseInfo('01129920-n', 13), SenseInfo('00719494-n', 12), SenseInfo('13315999-n', 2) ],
"_affirm_v_1_rel" : [ SenseInfo('00665886-v', 9), SenseInfo('01011031-v', 3), SenseInfo('01011725-v', 2), SenseInfo('00665886-v', 9), SenseInfo('01011031-v', 3), SenseInfo('01011725-v', 2), SenseInfo('00665886-v', 9), SenseInfo('01011031-v', 3), SenseInfo('01011725-v', 2) ],
"_inventor_n_of_rel" : [ SenseInfo('10214637-n', 1) ],
"_home+run_n_1_rel" : [ SenseInfo('00132355-n', 13), SenseInfo('00064789-n', 0) ],
"_theorize_v_1_rel" : [ SenseInfo('00633443-v', 2), SenseInfo('00633094-v', 0), SenseInfo('00632931-v', 0), SenseInfo('00633443-v', 2), SenseInfo('00633094-v', 0), SenseInfo('00632931-v', 0), SenseInfo('00633443-v', 2), SenseInfo('00633094-v', 0), SenseInfo('00632931-v', 0), SenseInfo('00633443-v', 2), SenseInfo('00633094-v', 0), SenseInfo('00632931-v', 0) ],
"_complete_a_with_rel" : [ SenseInfo('00520214-a', 67), SenseInfo('01750386-a', 4), SenseInfo('02226028-a', 0), SenseInfo('01520091-a', 0), SenseInfo('01003277-a', 0) ],
"_gymnasium_n_1_rel" : [ SenseInfo('08284481-n', 0), SenseInfo('03472112-n', 0) ],
"_newspaper_n_of_rel" : [ SenseInfo('06267145-n', 31), SenseInfo('08062970-n', 13), SenseInfo('03822171-n', 2), SenseInfo('14961722-n', 0) ],
"_precipitate_n_1_rel" : [ SenseInfo('14591635-n', 1) ],
"_excrement_n_1_rel" : [ SenseInfo('14853947-n', 0) ],
"_salami_n_1_rel" : [ SenseInfo('07677747-n', 0) ],
"_bobby+pin_n_1_rel" : [ SenseInfo('02860640-n', 1) ],
"_disinherit_v_1_rel" : [ SenseInfo('02316097-v', 0) ],
"_carry_v_in_rel" : [ SenseInfo('01449974-v', 72), SenseInfo('02717102-v', 36), SenseInfo('02079933-v', 8), SenseInfo('01061017-v', 8), SenseInfo('01218084-v', 6), SenseInfo('01601234-v', 5), SenseInfo('02700867-v', 4), SenseInfo('02561168-v', 4), SenseInfo('00235110-v', 3), SenseInfo('02636325-v', 2), SenseInfo('01101416-v', 2), SenseInfo('00738951-v', 2), SenseInfo('02518161-v', 1), SenseInfo('02285392-v', 1), SenseInfo('01746359-v', 1), SenseInfo('01408760-v', 1), SenseInfo('01061320-v', 1), SenseInfo('02746735-v', 0), SenseInfo('02741357-v', 0), SenseInfo('02682954-v', 0), SenseInfo('02636516-v', 0), SenseInfo('02630734-v', 0), SenseInfo('02586121-v', 0), SenseInfo('02556537-v', 0), SenseInfo('02555684-v', 0), SenseInfo('02359228-v', 0), SenseInfo('02303878-v', 0), SenseInfo('02233195-v', 0), SenseInfo('02012725-v', 0), SenseInfo('02001699-v', 0), SenseInfo('01740320-v', 0), SenseInfo('01241881-v', 0), SenseInfo('01205153-v', 0), SenseInfo('01203074-v', 0), SenseInfo('01123609-v', 0), SenseInfo('01123415-v', 0), SenseInfo('01101571-v', 0), SenseInfo('01100672-v', 0), SenseInfo('01049606-v', 0), SenseInfo('00059019-v', 0) ],
"_cluster_v_cause_rel" : [ SenseInfo('02025009-v', 4), SenseInfo('01484392-v', 2) ],
"_somehow_a_1_rel" : [  ],
"_no+matter_p_rel" : [ SenseInfo('00118531-r', 10) ],
"_let_v_down_rel" : [ SenseInfo('02423183-v', 219), SenseInfo('00771490-v', 15), SenseInfo('00802318-v', 2), SenseInfo('00120796-v', 2), SenseInfo('00496673-v', 1), SenseInfo('02208903-v', 0) ],
"_phenomenal_a_1_rel" : [ SenseInfo('02859708-a', 0), SenseInfo('01676993-a', 0) ],
"_sprawl_n_1_rel" : [ SenseInfo('08539717-n', 0), SenseInfo('05082337-n', 0) ],
"_rush_n_1_rel" : [ SenseInfo('00555648-n', 8), SenseInfo('07440240-n', 2), SenseInfo('11743294-n', 0), SenseInfo('11274269-n', 0), SenseInfo('07528470-n', 0), SenseInfo('07436352-n', 0), SenseInfo('00560293-n', 0) ],
"_dang_a_1_rel" : [  ],
"_disadvantaged_a_1_rel" : [ SenseInfo('01864666-a', 0), SenseInfo('01864666-a', 0) ],
"_videotape_v_1_rel" : [ SenseInfo('01003049-v', 0) ],
"_preserve_n_1_rel" : [ SenseInfo('14515463-n', 1), SenseInfo('08587439-n', 0), SenseInfo('07642471-n', 0), SenseInfo('14515463-n', 1), SenseInfo('08587439-n', 0), SenseInfo('07642471-n', 0) ],
"_roost_v_1_rel" : [ SenseInfo('01543731-v', 1), SenseInfo('00415635-v', 0) ],
"_civility_n_1_rel" : [ SenseInfo('04914133-n', 0), SenseInfo('01227908-n', 0) ],
"_footing_n_1_rel" : [ SenseInfo('13953936-n', 1), SenseInfo('13790912-n', 0), SenseInfo('03379989-n', 0) ],
"_loss_n_of_rel" : [ SenseInfo('13327676-n', 16), SenseInfo('13509196-n', 12), SenseInfo('00067526-n', 6), SenseInfo('05162985-n', 4), SenseInfo('07287472-n', 3), SenseInfo('13327231-n', 2), SenseInfo('07340725-n', 2), SenseInfo('07333649-n', 0) ],
"_among_p_sel_rel" : [  ],
"_size_v_up_rel" : [ SenseInfo('01610278-v', 0), SenseInfo('00655987-v', 0), SenseInfo('00319214-v', 0) ],
"_excess_n_1_rel" : [ SenseInfo('05119714-n', 4), SenseInfo('05118437-n', 2), SenseInfo('14452294-n', 0), SenseInfo('01073655-n', 0) ],
"_frisian_n_1_rel" : [ SenseInfo('09699918-n', 0), SenseInfo('06955242-n', 0) ],
"_pin_v_up_rel" : [ SenseInfo('01207149-v', 2), SenseInfo('01368264-v', 1), SenseInfo('01444723-v', 0), SenseInfo('01121621-v', 0) ],
"_regulation_n_of_rel" : [ SenseInfo('06664051-n', 10), SenseInfo('05846054-n', 2), SenseInfo('14443434-n', 0), SenseInfo('13549105-n', 0), SenseInfo('00806902-n', 0), SenseInfo('00805034-n', 0), SenseInfo('06664051-n', 10), SenseInfo('05846054-n', 2), SenseInfo('14443434-n', 0), SenseInfo('13549105-n', 0), SenseInfo('00806902-n', 0), SenseInfo('00805034-n', 0) ],
"_lichen_n_1_rel" : [ SenseInfo('14229403-n', 0), SenseInfo('12987056-n', 0) ],
"_mendacious_a_1_rel" : [ SenseInfo('01226129-a', 1), SenseInfo('02462089-a', 0) ],
"_doric_a_1_rel" : [ SenseInfo('02847370-a', 0) ],
"_ellipsis_n_1_rel" : [ SenseInfo('13473716-n', 0) ],
"_lets+see_a_1_rel" : [  ],
"_rf_n_1_rel" : [ SenseInfo('15023294-n', 0), SenseInfo('14653416-n', 0), SenseInfo('05502090-n', 0) ],
"_propaganda_n_1_rel" : [ SenseInfo('06674542-n', 4) ],
"_deviate_a_1_rel" : [ SenseInfo('01596122-a', 0) ],
"_fireside_n_1_rel" : [ SenseInfo('08581699-n', 1), SenseInfo('03507241-n', 0) ],
"_speculation_n_about_rel" : [ SenseInfo('06782680-n', 2), SenseInfo('05891783-n', 2), SenseInfo('13342692-n', 1), SenseInfo('05785885-n', 0), SenseInfo('06782680-n', 2), SenseInfo('05891783-n', 2), SenseInfo('13342692-n', 1), SenseInfo('05785885-n', 0) ],
"_expenditure_n_of_rel" : [ SenseInfo('13275288-n', 20), SenseInfo('01122601-n', 3), SenseInfo('00356367-n', 0) ],
"_want_v_out_rel" : [ SenseInfo('01825237-v', 389), SenseInfo('01188725-v', 15), SenseInfo('01317064-v', 3), SenseInfo('00709205-v', 2), SenseInfo('02632567-v', 0) ],
"_seashell_n_1_rel" : [ SenseInfo('01956764-n', 0) ],
"_beat_v_up_rel" : [ SenseInfo('01101913-v', 18), SenseInfo('01397210-v', 9), SenseInfo('01398919-v', 8), SenseInfo('01880113-v', 4), SenseInfo('01624897-v', 3), SenseInfo('02174830-v', 2), SenseInfo('02162815-v', 1), SenseInfo('02093610-v', 1), SenseInfo('01945938-v', 1), SenseInfo('01418179-v', 1), SenseInfo('01399576-v', 1), SenseInfo('02746140-v', 0), SenseInfo('02573853-v', 0), SenseInfo('02175578-v', 0), SenseInfo('02093390-v', 0), SenseInfo('01880673-v', 0), SenseInfo('01879579-v', 0), SenseInfo('01756006-v', 0), SenseInfo('01726879-v', 0), SenseInfo('01399450-v', 0), SenseInfo('01104852-v', 0), SenseInfo('00622384-v', 0), SenseInfo('00075421-v', 0) ],
"_silky_a_1_rel" : [ SenseInfo('00282675-a', 0) ],
"_megahertz_n_1_rel" : [ SenseInfo('15279957-n', 0), SenseInfo('15279957-n', 0), SenseInfo('15279957-n', 0) ],
"_clumsy_a_1_rel" : [ SenseInfo('01140896-a', 4), SenseInfo('01001180-a', 1), SenseInfo('02564023-a', 0), SenseInfo('02229324-a', 0), SenseInfo('01140896-a', 4), SenseInfo('01001180-a', 1), SenseInfo('02564023-a', 0), SenseInfo('02229324-a', 0), SenseInfo('01140896-a', 4), SenseInfo('01001180-a', 1), SenseInfo('02564023-a', 0), SenseInfo('02229324-a', 0), SenseInfo('01140896-a', 4), SenseInfo('01001180-a', 1), SenseInfo('02564023-a', 0), SenseInfo('02229324-a', 0) ],
"_hell_a_1_rel" : [ SenseInfo('08582837-n', 6), SenseInfo('07305907-n', 0), SenseInfo('05629682-n', 0), SenseInfo('05629381-n', 0), SenseInfo('01260731-n', 0), SenseInfo('00736786-n', 0), SenseInfo('08582837-n', 6), SenseInfo('07305907-n', 0), SenseInfo('05629682-n', 0), SenseInfo('05629381-n', 0), SenseInfo('01260731-n', 0), SenseInfo('00736786-n', 0) ],
"_traffic_v_in_rel" : [ SenseInfo('02261123-v', 0), SenseInfo('02260770-v', 0) ],
"_polka_n_1_rel" : [ SenseInfo('07056504-n', 1), SenseInfo('00538144-n', 0) ],
"_wretched_a_1_rel" : [ SenseInfo('02347086-a', 2), SenseInfo('00478872-a', 2), SenseInfo('01150205-a', 0), SenseInfo('01133017-a', 0), SenseInfo('01050890-a', 0) ],
"_dear_a_1_rel" : [ SenseInfo('01462324-a', 8), SenseInfo('00452883-a', 1), SenseInfo('02179968-a', 0), SenseInfo('00933599-a', 0), SenseInfo('01462324-a', 8), SenseInfo('00452883-a', 1), SenseInfo('02179968-a', 0), SenseInfo('00933599-a', 0), SenseInfo('01462324-a', 8), SenseInfo('00452883-a', 1), SenseInfo('02179968-a', 0), SenseInfo('00933599-a', 0) ],
"_gossiper_n_1_rel" : [ SenseInfo('10139347-n', 0) ],
"_treasurer_n_1_rel" : [ SenseInfo('10727256-n', 3), SenseInfo('10727256-n', 3), SenseInfo('10727256-n', 3) ],
"_socialize_v_1_rel" : [ SenseInfo('02388950-v', 1), SenseInfo('02386845-v', 0), SenseInfo('00406053-v', 0), SenseInfo('00405853-v', 0), SenseInfo('02388950-v', 1), SenseInfo('02386845-v', 0), SenseInfo('00406053-v', 0), SenseInfo('00405853-v', 0) ],
"_ping+pong_n_1_rel" : [ SenseInfo('00499263-n', 1), SenseInfo('00499263-n', 1) ],
"_antiquated_a_1_rel" : [ SenseInfo('01639230-a', 0) ],
"_martian_a_1_rel" : [ SenseInfo('02939406-a', 5) ],
"_research_v_1_rel" : [ SenseInfo('00877327-v', 1), SenseInfo('00648224-v', 0), SenseInfo('00877327-v', 1), SenseInfo('00648224-v', 0) ],
"_endow_v_1_rel" : [ SenseInfo('02474239-v', 3), SenseInfo('02201268-v', 1) ],
"_floral_a_1_rel" : [ SenseInfo('01788705-a', 1), SenseInfo('02847786-a', 0), SenseInfo('02847619-a', 0) ],
"_oversimplify_v_1_rel" : [ SenseInfo('02569235-v', 0), SenseInfo('00400741-v', 0), SenseInfo('02569235-v', 0), SenseInfo('00400741-v', 0) ],
"_cap_v_at_rel" : [ SenseInfo('02693168-v', 3), SenseInfo('00236104-v', 0), SenseInfo('02693168-v', 3), SenseInfo('00236104-v', 0) ],
"_thrive_v_on_rel" : [ SenseInfo('00310386-v', 3), SenseInfo('02342800-v', 1) ],
"_indignation_n_1_rel" : [ SenseInfo('07517737-n', 8) ],
"_gondola_n_1_rel" : [ SenseInfo('03447593-n', 0), SenseInfo('03447447-n', 0), SenseInfo('02960501-n', 0) ],
"_granite_n_1_rel" : [ SenseInfo('14890286-n', 1), SenseInfo('04778114-n', 1) ],
"_puree_n_1_rel" : [ SenseInfo('07651025-n', 0), SenseInfo('07651025-n', 0) ],
"_advise_v_against_rel" : [ SenseInfo('00872886-v', 11), SenseInfo('00873682-v', 10), SenseInfo('00875394-v', 4) ],
"_conjugal_a_1_rel" : [ SenseInfo('02872066-a', 2) ],
"_byte_n_1_rel" : [ SenseInfo('13626013-n', 0) ],
"_advisory_n_1_rel" : [ SenseInfo('06747008-n', 0) ],
"_sunrise_n_1_rel" : [ SenseInfo('15168790-n', 0), SenseInfo('11517656-n', 0), SenseInfo('07343910-n', 0) ],
"_perceptible_a_1_rel" : [ SenseInfo('01746605-a', 1), SenseInfo('01717471-a', 0), SenseInfo('01287282-a', 0) ],
"_sulky_a_1_rel" : [ SenseInfo('01137994-a', 1), SenseInfo('00981703-a', 0), SenseInfo('00275764-a', 0), SenseInfo('01137994-a', 1), SenseInfo('00981703-a', 0), SenseInfo('00275764-a', 0), SenseInfo('01137994-a', 1), SenseInfo('00981703-a', 0), SenseInfo('00275764-a', 0) ],
"_over-the-top_a_1_rel" : [ SenseInfo('01534648-a', 0), SenseInfo('01534648-a', 0), SenseInfo('01534648-a', 0) ],
"_enthusiasm_n_1_rel" : [ SenseInfo('07555014-n', 5), SenseInfo('04634540-n', 5), SenseInfo('05670343-n', 3) ],
"_rather_x_deg_rel" : [ SenseInfo('00098714-r', 59), SenseInfo('00018302-r', 53), SenseInfo('00115554-r', 6), SenseInfo('00018781-r', 0) ],
"_a+bit_q_rel" : [  ],
"_doorpost_n_1_rel" : [ SenseInfo('03222857-n', 0) ],
"_stop_v_prd_rel" : [ SenseInfo('01860795-v', 57), SenseInfo('02680814-v', 56), SenseInfo('02559752-v', 25), SenseInfo('01862918-v', 7), SenseInfo('01859221-v', 7), SenseInfo('00362348-v', 4), SenseInfo('01131473-v', 3), SenseInfo('01440378-v', 2), SenseInfo('02609764-v', 1), SenseInfo('01478002-v', 0), SenseInfo('00362610-v', 0) ],
"_absorption_n_of_rel" : [ SenseInfo('13423922-n', 4), SenseInfo('13424183-n', 3), SenseInfo('13434878-n', 0), SenseInfo('13434688-n', 0), SenseInfo('05704266-n', 0), SenseInfo('05700087-n', 0) ],
"_distinguish_v_from_rel" : [ SenseInfo('00650353-v', 15), SenseInfo('02193194-v', 6), SenseInfo('00651991-v', 3), SenseInfo('00922438-v', 0), SenseInfo('00652346-v', 0), SenseInfo('00650353-v', 15), SenseInfo('02193194-v', 6), SenseInfo('00651991-v', 3), SenseInfo('00922438-v', 0), SenseInfo('00652346-v', 0) ],
"_airy_a_1_rel" : [ SenseInfo('02508917-a', 4), SenseInfo('02498213-a', 0), SenseInfo('01186913-a', 0), SenseInfo('00626136-a', 0) ],
"_head_v_1_rel" : [ SenseInfo('01935233-v', 29), SenseInfo('02440244-v', 19), SenseInfo('01999423-v', 3), SenseInfo('02729023-v', 2), SenseInfo('01931768-v', 2), SenseInfo('02754463-v', 0), SenseInfo('02694287-v', 0), SenseInfo('02624128-v', 0), SenseInfo('01590915-v', 0), SenseInfo('01935233-v', 29), SenseInfo('02440244-v', 19), SenseInfo('01999423-v', 3), SenseInfo('02729023-v', 2), SenseInfo('01931768-v', 2), SenseInfo('02754463-v', 0), SenseInfo('02694287-v', 0), SenseInfo('02624128-v', 0), SenseInfo('01590915-v', 0) ],
"_waist_n_1_rel" : [ SenseInfo('05555688-n', 4), SenseInfo('04183663-n', 0) ],
"_expound_v_1_rel" : [ SenseInfo('00955601-v', 3), SenseInfo('01001294-v', 0), SenseInfo('00955601-v', 3), SenseInfo('01001294-v', 0) ],
"_explosion_n_of_rel" : [ SenseInfo('07308563-n', 6), SenseInfo('00377364-n', 2), SenseInfo('07414068-n', 0), SenseInfo('07383696-n', 0), SenseInfo('07116443-n', 0), SenseInfo('07014854-n', 0), SenseInfo('00572706-n', 0) ],
"_popularity_n_1_rel" : [ SenseInfo('04808639-n', 6) ],
"_sink_v_1_rel" : [ SenseInfo('01985923-v', 8), SenseInfo('01986869-v', 5), SenseInfo('01972131-v', 4), SenseInfo('01989873-v', 3), SenseInfo('01971929-v', 3), SenseInfo('02039679-v', 2), SenseInfo('00432839-v', 2), SenseInfo('01988886-v', 1), SenseInfo('01530098-v', 1) ],
"_genus_n_1_rel" : [ SenseInfo('05845013-n', 2), SenseInfo('08108972-n', 1) ],
"_carrot_n_1_rel" : [ SenseInfo('12937678-n', 0), SenseInfo('12937388-n', 0), SenseInfo('07730207-n', 0), SenseInfo('01219722-n', 0) ],
"_perseverance_n_1_rel" : [ SenseInfo('04864515-n', 0), SenseInfo('01021579-n', 0) ],
"_separatory_a_1_rel" : [  ],
"_liability_n_1_rel" : [ SenseInfo('14530403-n', 1), SenseInfo('14490319-n', 0), SenseInfo('05161436-n', 0) ],
"_blotch_n_1_rel" : [ SenseInfo('04694809-n', 1) ],
"_fashionable_a_1_rel" : [ SenseInfo('00971075-a', 3), SenseInfo('00975171-a', 0), SenseInfo('01816305-a', 0) ],
"_polarize_v_1_rel" : [ SenseInfo('00487554-v', 2), SenseInfo('00487350-v', 1), SenseInfo('00487182-v', 1) ],
"_earring_n_1_rel" : [ SenseInfo('03262349-n', 0) ],
"_preside_v_over_rel" : [ SenseInfo('02443609-v', 3) ],
"_charge_v_1_rel" : [ SenseInfo('01121719-v', 16), SenseInfo('00843468-v', 10), SenseInfo('02320374-v', 7), SenseInfo('02055267-v', 6), SenseInfo('02475922-v', 4), SenseInfo('00869931-v', 3), SenseInfo('00843959-v', 3), SenseInfo('01488956-v', 2), SenseInfo('02321046-v', 1), SenseInfo('02348568-v', 0), SenseInfo('02347637-v', 0), SenseInfo('02317289-v', 0), SenseInfo('01985424-v', 0), SenseInfo('01762528-v', 0), SenseInfo('01685960-v', 0), SenseInfo('01490336-v', 0), SenseInfo('01152214-v', 0), SenseInfo('00750532-v', 0), SenseInfo('00750345-v', 0), SenseInfo('00750172-v', 0), SenseInfo('00727991-v', 0), SenseInfo('00700517-v', 0), SenseInfo('00518115-v', 0), SenseInfo('00517847-v', 0), SenseInfo('00498016-v', 0), SenseInfo('01121719-v', 16), SenseInfo('00843468-v', 10), SenseInfo('02320374-v', 7), SenseInfo('02055267-v', 6), SenseInfo('02475922-v', 4), SenseInfo('00869931-v', 3), SenseInfo('00843959-v', 3), SenseInfo('01488956-v', 2), SenseInfo('02321046-v', 1), SenseInfo('02348568-v', 0), SenseInfo('02347637-v', 0), SenseInfo('02317289-v', 0), SenseInfo('01985424-v', 0), SenseInfo('01762528-v', 0), SenseInfo('01685960-v', 0), SenseInfo('01490336-v', 0), SenseInfo('01152214-v', 0), SenseInfo('00750532-v', 0), SenseInfo('00750345-v', 0), SenseInfo('00750172-v', 0), SenseInfo('00727991-v', 0), SenseInfo('00700517-v', 0), SenseInfo('00518115-v', 0), SenseInfo('00517847-v', 0), SenseInfo('00498016-v', 0), SenseInfo('01121719-v', 16), SenseInfo('00843468-v', 10), SenseInfo('02320374-v', 7), SenseInfo('02055267-v', 6), SenseInfo('02475922-v', 4), SenseInfo('00869931-v', 3), SenseInfo('00843959-v', 3), SenseInfo('01488956-v', 2), SenseInfo('02321046-v', 1), SenseInfo('02348568-v', 0), SenseInfo('02347637-v', 0), SenseInfo('02317289-v', 0), SenseInfo('01985424-v', 0), SenseInfo('01762528-v', 0), SenseInfo('01685960-v', 0), SenseInfo('01490336-v', 0), SenseInfo('01152214-v', 0), SenseInfo('00750532-v', 0), SenseInfo('00750345-v', 0), SenseInfo('00750172-v', 0), SenseInfo('00727991-v', 0), SenseInfo('00700517-v', 0), SenseInfo('00518115-v', 0), SenseInfo('00517847-v', 0), SenseInfo('00498016-v', 0) ],
"_rope_v_1_rel" : [ SenseInfo('01604251-v', 0), SenseInfo('01289155-v', 0), SenseInfo('01604251-v', 0), SenseInfo('01289155-v', 0) ],
"_solvent_n_1_rel" : [ SenseInfo('15047313-n', 1), SenseInfo('06743506-n', 0) ],
"_clap_v_1_rel" : [ SenseInfo('01607590-v', 2), SenseInfo('02094299-v', 1), SenseInfo('00861929-v', 1), SenseInfo('00034115-v', 1), SenseInfo('02094172-v', 0), SenseInfo('01237599-v', 0), SenseInfo('01237398-v', 0) ],
"_cirrus_a_1_rel" : [ SenseInfo('13102946-n', 0), SenseInfo('09245964-n', 0), SenseInfo('01900341-n', 0) ],
"_entanglement_n_1_rel" : [ SenseInfo('04568557-n', 2) ],
"_not+well+off_a_1_rel" : [  ],
"_longitudinal_a_1_rel" : [ SenseInfo('02830345-a', 0), SenseInfo('01445558-a', 0), SenseInfo('01440776-a', 0), SenseInfo('02830345-a', 0), SenseInfo('01445558-a', 0), SenseInfo('01440776-a', 0) ],
"_skate_n_1_rel" : [ SenseInfo('04225729-n', 0), SenseInfo('01501160-n', 0) ],
"_note_n_signif_rel" : [ SenseInfo('06504462-n', 14), SenseInfo('06626286-n', 13), SenseInfo('06865345-n', 4), SenseInfo('07082819-n', 3), SenseInfo('04727694-n', 2), SenseInfo('13393762-n', 1), SenseInfo('06763273-n', 1), SenseInfo('14435445-n', 0), SenseInfo('13398469-n', 0) ],
"_cable_n_1_rel" : [ SenseInfo('06275095-n', 2), SenseInfo('02934168-n', 1), SenseInfo('02933842-n', 1), SenseInfo('13652886-n', 0), SenseInfo('06278338-n', 0), SenseInfo('02933990-n', 0) ],
"_syntax_n_1_rel" : [ SenseInfo('06176107-n', 2), SenseInfo('08436203-n', 1), SenseInfo('06176322-n', 0) ],
"_scanty_a_1_rel" : [ SenseInfo('00106821-a', 1), SenseInfo('00106821-a', 1), SenseInfo('00106821-a', 1), SenseInfo('00106821-a', 1) ],
"_sesame_n_1_rel" : [ SenseInfo('12874783-n', 0) ],
"_urine_n_1_rel" : [ SenseInfo('14855724-n', 1) ],
"_promotional_a_1_rel" : [ SenseInfo('03103815-a', 2), SenseInfo('03103932-a', 0) ],
"_daily_a_1_rel" : [ SenseInfo('01968165-a', 0), SenseInfo('01044557-a', 0), SenseInfo('01968165-a', 0), SenseInfo('01044557-a', 0) ],
"_undemanded_a_1_rel" : [  ],
"_downtown_a_1_rel" : [ SenseInfo('02494716-a', 13) ],
"_icebox_n_1_rel" : [ SenseInfo('04070727-n', 3) ],
"_treacherous_a_1_rel" : [ SenseInfo('02061126-a', 1), SenseInfo('00960094-a', 0) ],
"_supervisor_n_of_rel" : [ SenseInfo('10676877-n', 3), SenseInfo('06580351-n', 0) ],
"_near_a_to_rel" : [ SenseInfo('00444519-a', 44), SenseInfo('02033556-a', 0), SenseInfo('01573762-a', 0), SenseInfo('01113225-a', 0), SenseInfo('00452883-a', 0), SenseInfo('00451872-a', 0), SenseInfo('00444519-a', 44), SenseInfo('02033556-a', 0), SenseInfo('01573762-a', 0), SenseInfo('01113225-a', 0), SenseInfo('00452883-a', 0), SenseInfo('00451872-a', 0), SenseInfo('00444519-a', 44), SenseInfo('02033556-a', 0), SenseInfo('01573762-a', 0), SenseInfo('01113225-a', 0), SenseInfo('00452883-a', 0), SenseInfo('00451872-a', 0), SenseInfo('00444519-a', 44), SenseInfo('02033556-a', 0), SenseInfo('01573762-a', 0), SenseInfo('01113225-a', 0), SenseInfo('00452883-a', 0), SenseInfo('00451872-a', 0), SenseInfo('00444519-a', 44), SenseInfo('02033556-a', 0), SenseInfo('01573762-a', 0), SenseInfo('01113225-a', 0), SenseInfo('00452883-a', 0), SenseInfo('00451872-a', 0), SenseInfo('00444519-a', 44), SenseInfo('02033556-a', 0), SenseInfo('01573762-a', 0), SenseInfo('01113225-a', 0), SenseInfo('00452883-a', 0), SenseInfo('00451872-a', 0) ],
"_pc_n_1_rel" : [ SenseInfo('03918480-n', 0), SenseInfo('03918480-n', 0), SenseInfo('03918480-n', 0), SenseInfo('03918480-n', 0) ],
"_lust_v_for_rel" : [ SenseInfo('01188485-v', 0), SenseInfo('01188485-v', 0) ],
"_rise_n_1_rel" : [ SenseInfo('07324917-n', 8), SenseInfo('00324384-n', 3), SenseInfo('09206985-n', 1), SenseInfo('07445480-n', 1), SenseInfo('05110185-n', 1), SenseInfo('05068918-n', 1), SenseInfo('07348399-n', 0), SenseInfo('07327288-n', 0), SenseInfo('05110408-n', 0), SenseInfo('00364260-n', 0) ],
"_toil_n_1_rel" : [ SenseInfo('00620752-n', 0) ],
"_patch_v_up_rel" : [ SenseInfo('01590171-v', 2), SenseInfo('02357693-v', 1), SenseInfo('00262703-v', 0), SenseInfo('00261705-v', 0) ],
"_glisten_v_1_rel" : [ SenseInfo('02162947-v', 3) ],
"_license_v_to_rel" : [ SenseInfo('02444662-v', 2), SenseInfo('02444662-v', 2) ],
"_emulsion_n_1_rel" : [ SenseInfo('14674584-n', 0), SenseInfo('03284482-n', 0) ],
"_entrust_v_to-with_rel" : [ SenseInfo('02349212-v', 3), SenseInfo('02356230-v', 0), SenseInfo('02349212-v', 3), SenseInfo('02356230-v', 0) ],
"_elderly_a_1_rel" : [ SenseInfo('01644225-a', 6) ],
"_unwieldy_a_for_rel" : [ SenseInfo('02563727-a', 0), SenseInfo('01837605-a', 0), SenseInfo('01140896-a', 0), SenseInfo('02563727-a', 0), SenseInfo('01837605-a', 0), SenseInfo('01140896-a', 0) ],
"_entreaty_n_1_rel" : [ SenseInfo('07186828-n', 0) ],
"_soothe_v_1_rel" : [ SenseInfo('01814815-v', 1), SenseInfo('00063916-v', 1), SenseInfo('01814815-v', 1), SenseInfo('00063916-v', 1), SenseInfo('01814815-v', 1), SenseInfo('00063916-v', 1), SenseInfo('01814815-v', 1), SenseInfo('00063916-v', 1), SenseInfo('01814815-v', 1), SenseInfo('00063916-v', 1) ],
"_pm_n_1_rel" : [ SenseInfo('00141396-n', 1), SenseInfo('14651479-n', 0), SenseInfo('09907196-n', 0), SenseInfo('06281848-n', 0) ],
"_multiplication_n_of_rel" : [ SenseInfo('00849982-n', 1), SenseInfo('13517843-n', 0), SenseInfo('00871576-n', 0) ],
"_electron_n_1_rel" : [ SenseInfo('09271904-n', 12) ],
"_delight_n_1_rel" : [ SenseInfo('07491038-n', 9), SenseInfo('05829782-n', 0), SenseInfo('07491038-n', 9), SenseInfo('05829782-n', 0), SenseInfo('07491038-n', 9), SenseInfo('05829782-n', 0), SenseInfo('07491038-n', 9), SenseInfo('05829782-n', 0) ],
"_all+the+while_p_rel" : [  ],
"_chisel_v_1_rel" : [ SenseInfo('02574516-v', 0), SenseInfo('02573275-v', 0), SenseInfo('01259328-v', 0) ],
"_awake_v_1_rel" : [ SenseInfo('00018526-v', 7) ],
"_batting_n_1_rel" : [ SenseInfo('00126584-n', 2), SenseInfo('02810930-n', 0) ],
"_fast+asleep_a_1_rel" : [ SenseInfo('00188738-a', 0) ],
"_colonial_n_1_rel" : [ SenseInfo('09937688-n', 1) ],
"_periodical_n_1_rel" : [ SenseInfo('06593296-n', 4) ],
"_gambler_n_1_rel" : [ SenseInfo('10118844-n', 1), SenseInfo('10119200-n', 0) ],
"_broadcasting_n_of_rel" : [ SenseInfo('06264176-n', 2), SenseInfo('06276697-n', 0) ],
"_treat_v_as_rel" : [ SenseInfo('02514187-v', 30), SenseInfo('00515154-v', 23), SenseInfo('00078760-v', 17), SenseInfo('01033527-v', 10), SenseInfo('02261642-v', 3), SenseInfo('01176232-v', 0), SenseInfo('00762720-v', 0), SenseInfo('00651145-v', 0), SenseInfo('02514187-v', 30), SenseInfo('00515154-v', 23), SenseInfo('00078760-v', 17), SenseInfo('01033527-v', 10), SenseInfo('02261642-v', 3), SenseInfo('01176232-v', 0), SenseInfo('00762720-v', 0), SenseInfo('00651145-v', 0) ],
"_carbonate_n_1_rel" : [ SenseInfo('14798450-n', 1) ],
"_traverse_v_1_rel" : [ SenseInfo('01912159-v', 4), SenseInfo('02685390-v', 1), SenseInfo('01068380-v', 1), SenseInfo('01912159-v', 4), SenseInfo('02685390-v', 1), SenseInfo('01068380-v', 1) ],
"_decapitate_v_1_rel" : [ SenseInfo('01571354-v', 0) ],
"_dealership_n_1_rel" : [ SenseInfo('08060193-n', 0) ],
"_subscription_n_to_rel" : [ SenseInfo('13281130-n', 1), SenseInfo('07179820-n', 1), SenseInfo('01090018-n', 0), SenseInfo('00615659-n', 0) ],
"_wrack_n_1_rel" : [ SenseInfo('01397778-n', 1), SenseInfo('07335581-n', 0), SenseInfo('01398064-n', 0) ],
"_rave_v_on_rel" : [ SenseInfo('02492054-v', 0), SenseInfo('01051956-v', 0), SenseInfo('00882220-v', 0), SenseInfo('02492054-v', 0), SenseInfo('01051956-v', 0), SenseInfo('00882220-v', 0) ],
"_flixweed_n_1_rel" : [  ],
"_mummy_n_1_rel" : [ SenseInfo('10278128-n', 0), SenseInfo('05218630-n', 0) ],
"_clear_v_from_rel" : [ SenseInfo('00181664-v', 16), SenseInfo('00195617-v', 5), SenseInfo('02771169-v', 2), SenseInfo('00803325-v', 2), SenseInfo('00195342-v', 2), SenseInfo('02523351-v', 1), SenseInfo('02289134-v', 1), SenseInfo('02156844-v', 1), SenseInfo('02081178-v', 1), SenseInfo('00621058-v', 1), SenseInfo('02422409-v', 0), SenseInfo('02350440-v', 0), SenseInfo('02291548-v', 0), SenseInfo('02291258-v', 0), SenseInfo('02289295-v', 0), SenseInfo('02208409-v', 0), SenseInfo('02053490-v', 0), SenseInfo('00904046-v', 0), SenseInfo('00761454-v', 0), SenseInfo('00549217-v', 0), SenseInfo('00450863-v', 0), SenseInfo('00450691-v', 0), SenseInfo('00450565-v', 0), SenseInfo('00178235-v', 0) ],
"_audible_a_1_rel" : [ SenseInfo('00173764-a', 2) ],
"_sopping_a_1_rel" : [  ],
"_char_v_1_rel" : [ SenseInfo('02771997-v', 0), SenseInfo('00379440-v', 0) ],
"_right_v_1_rel" : [ SenseInfo('02519991-v', 0), SenseInfo('01984734-v', 0), SenseInfo('01984574-v', 0), SenseInfo('00199659-v', 0) ],
"_whole_n_1_rel" : [ SenseInfo('05869584-n', 8), SenseInfo('00003553-n', 0) ],
"_inertia_n_1_rel" : [ SenseInfo('04635631-n', 1), SenseInfo('11468763-n', 0) ],
"_fanatic_n_1_rel" : [ SenseInfo('10077879-n', 1) ],
"_entablature_n_1_rel" : [ SenseInfo('03290195-n', 0) ],
"_adjacent_a_1_rel" : [ SenseInfo('00447472-a', 4), SenseInfo('00566342-a', 2), SenseInfo('00444984-a', 1) ],
"_gleam_v_with_rel" : [ SenseInfo('02162947-v', 3), SenseInfo('02160779-v', 3), SenseInfo('00423575-v', 1) ],
"_vulnerable_a_to_rel" : [ SenseInfo('02523275-a', 8), SenseInfo('02363166-a', 0), SenseInfo('02326482-a', 0) ],
"_playful_a_1_rel" : [ SenseInfo('02121859-a', 1) ],
"_if+yes_a_1_rel" : [  ],
"_impel_v_1_rel" : [ SenseInfo('01650425-v', 1), SenseInfo('01511706-v', 0), SenseInfo('01650425-v', 1), SenseInfo('01511706-v', 0) ],
"_more+so_a_1_rel" : [  ],
"_brood_v_1_rel" : [ SenseInfo('00704249-v', 5), SenseInfo('02744061-v', 1), SenseInfo('02719016-v', 0), SenseInfo('01805384-v', 0), SenseInfo('00060185-v', 0) ],
"_generosity_n_1_rel" : [ SenseInfo('04831727-n', 1), SenseInfo('01085937-n', 0) ],
"_micron-size_n_1_rel" : [  ],
"_sock_v_1_rel" : [ SenseInfo('01397088-v', 2) ],
"_substitute_v_1_rel" : [ SenseInfo('02257767-v', 13), SenseInfo('02258617-v', 5), SenseInfo('02394662-v', 0) ],
"_courtier_n_1_rel" : [ SenseInfo('09971839-n', 2) ],
"_second+prize_n_1_rel" : [  ],
"_pottery_n_1_rel" : [ SenseInfo('03992703-n', 10), SenseInfo('00609868-n', 1), SenseInfo('03992888-n', 0) ],
"_refer_v_to_rel" : [ SenseInfo('01024190-v', 21), SenseInfo('02676054-v', 18), SenseInfo('00655555-v', 12), SenseInfo('01952898-v', 6), SenseInfo('00877083-v', 4), SenseInfo('00931467-v', 3), SenseInfo('01028294-v', 0), SenseInfo('01024190-v', 21), SenseInfo('02676054-v', 18), SenseInfo('00655555-v', 12), SenseInfo('01952898-v', 6), SenseInfo('00877083-v', 4), SenseInfo('00931467-v', 3), SenseInfo('01028294-v', 0) ],
"_wasteland_n_1_rel" : [ SenseInfo('08504594-n', 2) ],
"_harrow_v_1_rel" : [ SenseInfo('01742415-v', 2) ],
"_reconstruction_n_of_rel" : [ SenseInfo('15261658-n', 2), SenseInfo('00269258-n', 1), SenseInfo('07174138-n', 0), SenseInfo('05762258-n', 0) ],
"_toil_v_1_rel" : [ SenseInfo('02419773-v', 2) ],
"_obliterate_v_1_rel" : [ SenseInfo('00478830-v', 1), SenseInfo('00313987-v', 1), SenseInfo('00311338-v', 1), SenseInfo('00472230-v', 0) ],
"_ornithological_a_1_rel" : [ SenseInfo('03094928-a', 0) ],
"_fate_v_1_rel" : [ SenseInfo('00746479-v', 0) ],
"_drinkable_a_1_rel" : [ SenseInfo('00797113-a', 0) ],
"_quiz_v_1_rel" : [ SenseInfo('00786458-v', 0) ],
"_wag_v_cause_rel" : [ SenseInfo('01898592-v', 3) ],
"_ceremonial_a_1_rel" : [ SenseInfo('01042491-a', 0) ],
"_nip_v_1_rel" : [ SenseInfo('01456771-v', 1), SenseInfo('01446569-v', 1), SenseInfo('01456463-v', 0) ],
"_flavorless_a_1_rel" : [ SenseInfo('02399595-a', 0), SenseInfo('02399595-a', 0) ],
"_vigorous_a_1_rel" : [ SenseInfo('00875422-a', 13), SenseInfo('02039845-a', 1), SenseInfo('00875422-a', 13), SenseInfo('02039845-a', 1) ],
"_rare_a_1_rel" : [ SenseInfo('00488561-a', 6), SenseInfo('01067538-a', 2), SenseInfo('00017024-a', 2), SenseInfo('02417725-a', 0), SenseInfo('01678112-a', 0), SenseInfo('00619691-a', 0), SenseInfo('00488561-a', 6), SenseInfo('01067538-a', 2), SenseInfo('00017024-a', 2), SenseInfo('02417725-a', 0), SenseInfo('01678112-a', 0), SenseInfo('00619691-a', 0), SenseInfo('00488561-a', 6), SenseInfo('01067538-a', 2), SenseInfo('00017024-a', 2), SenseInfo('02417725-a', 0), SenseInfo('01678112-a', 0), SenseInfo('00619691-a', 0), SenseInfo('00488561-a', 6), SenseInfo('01067538-a', 2), SenseInfo('00017024-a', 2), SenseInfo('02417725-a', 0), SenseInfo('01678112-a', 0), SenseInfo('00619691-a', 0), SenseInfo('00488561-a', 6), SenseInfo('01067538-a', 2), SenseInfo('00017024-a', 2), SenseInfo('02417725-a', 0), SenseInfo('01678112-a', 0), SenseInfo('00619691-a', 0) ],
"_nomenklatura_n_1_rel" : [ SenseInfo('01154083-n', 0) ],
"_place_n_of_rel" : [ SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1), SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1) ],
"_slurp_n_1_rel" : [  ],
"_rap_v_1_rel" : [ SenseInfo('01414288-v', 5), SenseInfo('02185373-v', 0), SenseInfo('01715997-v', 0), SenseInfo('01042432-v', 0) ],
"_root_v_around_rel" : [ SenseInfo('00358135-v', 2), SenseInfo('02623731-v', 0), SenseInfo('01529194-v', 0), SenseInfo('01282413-v', 0), SenseInfo('00415398-v', 0), SenseInfo('00358314-v', 0) ],
"_defensive_a_1_rel" : [ SenseInfo('01630117-a', 9), SenseInfo('01632066-a', 1) ],
"_harmonious_a_1_rel" : [ SenseInfo('01163083-a', 1), SenseInfo('00894029-a', 1), SenseInfo('00562308-a', 0), SenseInfo('00508036-a', 0) ],
"_have_v_prd_rel" : [ SenseInfo('02203362-v', 1202), SenseInfo('02630189-v', 377), SenseInfo('02108026-v', 220), SenseInfo('02204692-v', 143), SenseInfo('00120796-v', 64), SenseInfo('01156834-v', 42), SenseInfo('02378453-v', 31), SenseInfo('01733477-v', 30), SenseInfo('02205098-v', 28), SenseInfo('02740745-v', 25), SenseInfo('00121046-v', 25), SenseInfo('00065370-v', 11), SenseInfo('00770437-v', 8), SenseInfo('02236124-v', 7), SenseInfo('02210119-v', 7), SenseInfo('00065639-v', 5), SenseInfo('02355596-v', 3), SenseInfo('00056930-v', 3), SenseInfo('01427127-v', 2), SenseInfo('02203362-v', 1202), SenseInfo('02630189-v', 377), SenseInfo('02108026-v', 220), SenseInfo('02204692-v', 143), SenseInfo('00120796-v', 64), SenseInfo('01156834-v', 42), SenseInfo('02378453-v', 31), SenseInfo('01733477-v', 30), SenseInfo('02205098-v', 28), SenseInfo('02740745-v', 25), SenseInfo('00121046-v', 25), SenseInfo('00065370-v', 11), SenseInfo('00770437-v', 8), SenseInfo('02236124-v', 7), SenseInfo('02210119-v', 7), SenseInfo('00065639-v', 5), SenseInfo('02355596-v', 3), SenseInfo('00056930-v', 3), SenseInfo('01427127-v', 2) ],
"_meddle_v_1_rel" : [ SenseInfo('02539101-v', 1) ],
"_lefthand_a_1_rel" : [  ],
"_clear_a_of_rel" : [ SenseInfo('00428404-a', 55), SenseInfo('00435190-a', 8), SenseInfo('01622505-a', 6), SenseInfo('00431447-a', 4), SenseInfo('01062938-a', 3), SenseInfo('02459667-a', 1), SenseInfo('01906464-a', 1), SenseInfo('00869253-a', 1), SenseInfo('00780011-a', 1), SenseInfo('00697923-a', 0), SenseInfo('00460735-a', 0), SenseInfo('01914108-a', 0), SenseInfo('01750073-a', 0), SenseInfo('01582598-a', 0), SenseInfo('01405047-a', 0), SenseInfo('01320184-a', 0), SenseInfo('00771616-a', 0), SenseInfo('00428404-a', 55), SenseInfo('00435190-a', 8), SenseInfo('01622505-a', 6), SenseInfo('00431447-a', 4), SenseInfo('01062938-a', 3), SenseInfo('02459667-a', 1), SenseInfo('01906464-a', 1), SenseInfo('00869253-a', 1), SenseInfo('00780011-a', 1), SenseInfo('00697923-a', 0), SenseInfo('00460735-a', 0), SenseInfo('01914108-a', 0), SenseInfo('01750073-a', 0), SenseInfo('01582598-a', 0), SenseInfo('01405047-a', 0), SenseInfo('01320184-a', 0), SenseInfo('00771616-a', 0), SenseInfo('00428404-a', 55), SenseInfo('00435190-a', 8), SenseInfo('01622505-a', 6), SenseInfo('00431447-a', 4), SenseInfo('01062938-a', 3), SenseInfo('02459667-a', 1), SenseInfo('01906464-a', 1), SenseInfo('00869253-a', 1), SenseInfo('00780011-a', 1), SenseInfo('00697923-a', 0), SenseInfo('00460735-a', 0), SenseInfo('01914108-a', 0), SenseInfo('01750073-a', 0), SenseInfo('01582598-a', 0), SenseInfo('01405047-a', 0), SenseInfo('01320184-a', 0), SenseInfo('00771616-a', 0), SenseInfo('00428404-a', 55), SenseInfo('00435190-a', 8), SenseInfo('01622505-a', 6), SenseInfo('00431447-a', 4), SenseInfo('01062938-a', 3), SenseInfo('02459667-a', 1), SenseInfo('01906464-a', 1), SenseInfo('00869253-a', 1), SenseInfo('00780011-a', 1), SenseInfo('00697923-a', 0), SenseInfo('00460735-a', 0), SenseInfo('01914108-a', 0), SenseInfo('01750073-a', 0), SenseInfo('01582598-a', 0), SenseInfo('01405047-a', 0), SenseInfo('01320184-a', 0), SenseInfo('00771616-a', 0), SenseInfo('00428404-a', 55), SenseInfo('00435190-a', 8), SenseInfo('01622505-a', 6), SenseInfo('00431447-a', 4), SenseInfo('01062938-a', 3), SenseInfo('02459667-a', 1), SenseInfo('01906464-a', 1), SenseInfo('00869253-a', 1), SenseInfo('00780011-a', 1), SenseInfo('00697923-a', 0), SenseInfo('00460735-a', 0), SenseInfo('01914108-a', 0), SenseInfo('01750073-a', 0), SenseInfo('01582598-a', 0), SenseInfo('01405047-a', 0), SenseInfo('01320184-a', 0), SenseInfo('00771616-a', 0), SenseInfo('00428404-a', 55), SenseInfo('00435190-a', 8), SenseInfo('01622505-a', 6), SenseInfo('00431447-a', 4), SenseInfo('01062938-a', 3), SenseInfo('02459667-a', 1), SenseInfo('01906464-a', 1), SenseInfo('00869253-a', 1), SenseInfo('00780011-a', 1), SenseInfo('00697923-a', 0), SenseInfo('00460735-a', 0), SenseInfo('01914108-a', 0), SenseInfo('01750073-a', 0), SenseInfo('01582598-a', 0), SenseInfo('01405047-a', 0), SenseInfo('01320184-a', 0), SenseInfo('00771616-a', 0), SenseInfo('00428404-a', 55), SenseInfo('00435190-a', 8), SenseInfo('01622505-a', 6), SenseInfo('00431447-a', 4), SenseInfo('01062938-a', 3), SenseInfo('02459667-a', 1), SenseInfo('01906464-a', 1), SenseInfo('00869253-a', 1), SenseInfo('00780011-a', 1), SenseInfo('00697923-a', 0), SenseInfo('00460735-a', 0), SenseInfo('01914108-a', 0), SenseInfo('01750073-a', 0), SenseInfo('01582598-a', 0), SenseInfo('01405047-a', 0), SenseInfo('01320184-a', 0), SenseInfo('00771616-a', 0), SenseInfo('00428404-a', 55), SenseInfo('00435190-a', 8), SenseInfo('01622505-a', 6), SenseInfo('00431447-a', 4), SenseInfo('01062938-a', 3), SenseInfo('02459667-a', 1), SenseInfo('01906464-a', 1), SenseInfo('00869253-a', 1), SenseInfo('00780011-a', 1), SenseInfo('00697923-a', 0), SenseInfo('00460735-a', 0), SenseInfo('01914108-a', 0), SenseInfo('01750073-a', 0), SenseInfo('01582598-a', 0), SenseInfo('01405047-a', 0), SenseInfo('01320184-a', 0), SenseInfo('00771616-a', 0), SenseInfo('00428404-a', 55), SenseInfo('00435190-a', 8), SenseInfo('01622505-a', 6), SenseInfo('00431447-a', 4), SenseInfo('01062938-a', 3), SenseInfo('02459667-a', 1), SenseInfo('01906464-a', 1), SenseInfo('00869253-a', 1), SenseInfo('00780011-a', 1), SenseInfo('00697923-a', 0), SenseInfo('00460735-a', 0), SenseInfo('01914108-a', 0), SenseInfo('01750073-a', 0), SenseInfo('01582598-a', 0), SenseInfo('01405047-a', 0), SenseInfo('01320184-a', 0), SenseInfo('00771616-a', 0), SenseInfo('00428404-a', 55), SenseInfo('00435190-a', 8), SenseInfo('01622505-a', 6), SenseInfo('00431447-a', 4), SenseInfo('01062938-a', 3), SenseInfo('02459667-a', 1), SenseInfo('01906464-a', 1), SenseInfo('00869253-a', 1), SenseInfo('00780011-a', 1), SenseInfo('00697923-a', 0), SenseInfo('00460735-a', 0), SenseInfo('01914108-a', 0), SenseInfo('01750073-a', 0), SenseInfo('01582598-a', 0), SenseInfo('01405047-a', 0), SenseInfo('01320184-a', 0), SenseInfo('00771616-a', 0) ],
"_scan_v_1_rel" : [ SenseInfo('02152504-v', 9), SenseInfo('02152278-v', 6), SenseInfo('01318659-v', 1), SenseInfo('02661142-v', 0), SenseInfo('01855447-v', 0), SenseInfo('01051828-v', 0), SenseInfo('00627520-v', 0) ],
"_3+R+s_n_1_rel" : [  ],
"_majestic_a_1_rel" : [ SenseInfo('02339791-a', 1), SenseInfo('01285136-a', 1), SenseInfo('01591394-a', 0), SenseInfo('02339791-a', 1), SenseInfo('01285136-a', 1), SenseInfo('01591394-a', 0) ],
"_meditate_v_on_rel" : [ SenseInfo('00630380-v', 4), SenseInfo('00704388-v', 0) ],
"_parole_n_1_rel" : [ SenseInfo('07227301-n', 0), SenseInfo('06674188-n', 0), SenseInfo('01257701-n', 0) ],
"_remind_v_of_rel" : [ SenseInfo('00610538-v', 22), SenseInfo('00877848-v', 13) ],
"_branch_v_1_rel" : [ SenseInfo('00329244-v', 0), SenseInfo('00328802-v', 0) ],
"_risk_v_1_rel" : [ SenseInfo('02545578-v', 8), SenseInfo('02544348-v', 2) ],
"_recuperate_v_from_rel" : [ SenseInfo('02249438-v', 0), SenseInfo('00528339-v', 0), SenseInfo('00093163-v', 0), SenseInfo('00092690-v', 0), SenseInfo('02249438-v', 0), SenseInfo('00528339-v', 0), SenseInfo('00093163-v', 0), SenseInfo('00092690-v', 0) ],
"_bolster_v_1_rel" : [ SenseInfo('00223374-v', 3), SenseInfo('01219282-v', 0), SenseInfo('00321486-v', 0) ],
"_amazement_n_at_rel" : [ SenseInfo('07509572-n', 13) ],
"_cowardice_n_1_rel" : [ SenseInfo('04860065-n', 2) ],
"_gamble_v_away_rel" : [ SenseInfo('02544348-v', 2), SenseInfo('01138523-v', 0) ],
"_retraction_n_of_rel" : [ SenseInfo('07206096-n', 0), SenseInfo('00341695-n', 0) ],
"_boost_n_1_rel" : [ SenseInfo('01211019-n', 3), SenseInfo('05110408-n', 1), SenseInfo('01211339-n', 0) ],
"_southeastward_a_1_rel" : [ SenseInfo('01603789-a', 0), SenseInfo('01603789-a', 0) ],
"_amphipod_n_1_rel" : [ SenseInfo('01992773-n', 0) ],
"_satellite_n_1_rel" : [ SenseInfo('04137444-n', 4), SenseInfo('10552639-n', 0), SenseInfo('09424270-n', 0) ],
"_mist_v_1_rel" : [ SenseInfo('00361495-v', 1), SenseInfo('02157731-v', 0), SenseInfo('01373303-v', 0) ],
"_gig_v_1_rel" : [  ],
"_escalate_v_1_rel" : [ SenseInfo('00290302-v', 0) ],
"_hart_n_1_rel" : [ SenseInfo('11032700-n', 0), SenseInfo('11032541-n', 0), SenseInfo('02431337-n', 0) ],
"_communication_n_of_rel" : [ SenseInfo('06252138-n', 26), SenseInfo('00033020-n', 9), SenseInfo('13792842-n', 1), SenseInfo('06252138-n', 26), SenseInfo('00033020-n', 9), SenseInfo('13792842-n', 1), SenseInfo('06252138-n', 26), SenseInfo('00033020-n', 9), SenseInfo('13792842-n', 1), SenseInfo('06252138-n', 26), SenseInfo('00033020-n', 9), SenseInfo('13792842-n', 1) ],
"_update_n_of_rel" : [ SenseInfo('06643303-n', 0) ],
"_Rep_n_abb_rel" : [ SenseInfo('09955944-n', 0), SenseInfo('04075813-n', 0), SenseInfo('09955944-n', 0), SenseInfo('04075813-n', 0) ],
"_ex+wife_n_1_rel" : [ SenseInfo('10020533-n', 0), SenseInfo('10020533-n', 0) ],
"_check_v_out-of_rel" : [ SenseInfo('00661824-v', 27), SenseInfo('02533282-v', 7), SenseInfo('00662589-v', 6), SenseInfo('02510337-v', 5), SenseInfo('01861403-v', 1), SenseInfo('00662182-v', 1), SenseInfo('00440286-v', 1), SenseInfo('02658283-v', 0), SenseInfo('02657219-v', 0), SenseInfo('02557638-v', 0), SenseInfo('02553697-v', 0), SenseInfo('02347905-v', 0), SenseInfo('02347447-v', 0), SenseInfo('01861767-v', 0), SenseInfo('01861622-v', 0), SenseInfo('01692978-v', 0), SenseInfo('01139756-v', 0), SenseInfo('01131473-v', 0), SenseInfo('01114764-v', 0), SenseInfo('01064999-v', 0), SenseInfo('00920336-v', 0), SenseInfo('00663353-v', 0), SenseInfo('00354634-v', 0), SenseInfo('00336539-v', 0), SenseInfo('00336260-v', 0) ],
"_viewable_a_by_rel" : [ SenseInfo('02517169-a', 0) ],
"_ionize_v_1_rel" : [ SenseInfo('00267041-v', 0), SenseInfo('00266798-v', 0) ],
"_sunglasses_n_pair_rel" : [ SenseInfo('04355933-n', 0), SenseInfo('04355933-n', 0) ],
"_unequal_a_1_rel" : [ SenseInfo('00892379-a', 0), SenseInfo('00051696-a', 0), SenseInfo('00892379-a', 0), SenseInfo('00051696-a', 0), SenseInfo('00892379-a', 0), SenseInfo('00051696-a', 0) ],
"_rest_v_1_rel" : [ SenseInfo('01545883-v', 20), SenseInfo('00779360-v', 8), SenseInfo('00779601-v', 6), SenseInfo('02731390-v', 4), SenseInfo('00014405-v', 4), SenseInfo('00117985-v', 2), SenseInfo('02664664-v', 1), SenseInfo('01610101-v', 1), SenseInfo('01543731-v', 1), SenseInfo('01502946-v', 1), SenseInfo('02595840-v', 0) ],
"_spectacular_a_1_rel" : [ SenseInfo('01284212-a', 4), SenseInfo('00795246-a', 1), SenseInfo('00580805-a', 0) ],
"_imaginative_a_1_rel" : [ SenseInfo('00643863-a', 3) ],
"_brush_v_aside_rel" : [ SenseInfo('01243809-v', 11), SenseInfo('01240720-v', 10), SenseInfo('01243982-v', 5), SenseInfo('01870043-v', 2), SenseInfo('00555780-v', 1), SenseInfo('01373718-v', 0) ],
"_nuptials_n_1_rel" : [ SenseInfo('07452074-n', 0), SenseInfo('07452074-n', 0) ],
"_fountain_n_1_rel" : [ SenseInfo('03388043-n', 2), SenseInfo('09443453-n', 0), SenseInfo('03387926-n', 0), SenseInfo('03387815-n', 0) ],
"_dip_v_cause_rel" : [ SenseInfo('01577093-v', 2), SenseInfo('01192312-v', 1), SenseInfo('00432061-v', 1), SenseInfo('00286483-v', 1), SenseInfo('02311857-v', 0), SenseInfo('02162310-v', 0), SenseInfo('02041109-v', 0), SenseInfo('02039679-v', 0), SenseInfo('02038145-v', 0), SenseInfo('01976220-v', 0), SenseInfo('01660976-v', 0), SenseInfo('01578124-v', 0), SenseInfo('01577966-v', 0), SenseInfo('01312657-v', 0), SenseInfo('01577093-v', 2), SenseInfo('01192312-v', 1), SenseInfo('00432061-v', 1), SenseInfo('00286483-v', 1), SenseInfo('02311857-v', 0), SenseInfo('02162310-v', 0), SenseInfo('02041109-v', 0), SenseInfo('02039679-v', 0), SenseInfo('02038145-v', 0), SenseInfo('01976220-v', 0), SenseInfo('01660976-v', 0), SenseInfo('01578124-v', 0), SenseInfo('01577966-v', 0), SenseInfo('01312657-v', 0) ],
"_revolutionary_n_1_rel" : [ SenseInfo('10527334-n', 0) ],
"_substantiate_v_1_rel" : [ SenseInfo('00665886-v', 2), SenseInfo('02698443-v', 0), SenseInfo('01644746-v', 0), SenseInfo('00221413-v', 0) ],
"_dodecahedron_n_1_rel" : [ SenseInfo('13915784-n', 0), SenseInfo('13915784-n', 0) ],
"_bestial_a_1_rel" : [ SenseInfo('01263445-a', 1) ],
"_horseplay_n_1_rel" : [ SenseInfo('00513761-n', 0) ],
"_hoist_v_1_rel" : [ SenseInfo('01455184-v', 1), SenseInfo('01611359-v', 0), SenseInfo('01455754-v', 0), SenseInfo('01455184-v', 1), SenseInfo('01611359-v', 0), SenseInfo('01455754-v', 0) ],
"_greatness_n_1_rel" : [ SenseInfo('05169601-n', 4), SenseInfo('05104548-n', 0) ],
"_battle_v_with_rel" : [ SenseInfo('01092366-v', 6) ],
"_dual_n_1_rel" : [ SenseInfo('02217452-a', 3), SenseInfo('02217799-a', 0), SenseInfo('02183135-a', 0) ],
"_converse_v_about_rel" : [ SenseInfo('00964694-v', 5) ],
"_sightseeing_n_1_rel" : [ SenseInfo('00879607-n', 2), SenseInfo('00879607-n', 2) ],
"_dreamer_n_1_rel" : [ SenseInfo('10032987-n', 1), SenseInfo('10196965-n', 0), SenseInfo('10062996-n', 0) ],
"_spin_v_off_rel" : [ SenseInfo('02046755-v', 11), SenseInfo('02068062-v', 5), SenseInfo('02048051-v', 0), SenseInfo('01639500-v', 0), SenseInfo('01639364-v', 0), SenseInfo('01518772-v', 0), SenseInfo('00953700-v', 0), SenseInfo('00318706-v', 0), SenseInfo('02046755-v', 11), SenseInfo('02068062-v', 5), SenseInfo('02048051-v', 0), SenseInfo('01639500-v', 0), SenseInfo('01639364-v', 0), SenseInfo('01518772-v', 0), SenseInfo('00953700-v', 0), SenseInfo('00318706-v', 0) ],
"_teutonic_a_1_rel" : [ SenseInfo('02958126-a', 1) ],
"_endanger_v_1_rel" : [ SenseInfo('02697120-v', 3), SenseInfo('01036319-v', 2) ],
"_vegetable_n_1_rel" : [ SenseInfo('07707451-n', 5), SenseInfo('12212361-n', 0) ],
"_smoker_n_of_rel" : [ SenseInfo('10614976-n', 0), SenseInfo('08256005-n', 0), SenseInfo('04246855-n', 0) ],
"_annihilation_n_of_rel" : [ SenseInfo('00218208-n', 2), SenseInfo('07330828-n', 1) ],
"_pattern_v_1_rel" : [ SenseInfo('01743784-v', 4), SenseInfo('02712243-v', 0), SenseInfo('01743784-v', 4), SenseInfo('02712243-v', 0) ],
"_rhubarb_n_1_rel" : [ SenseInfo('07713267-n', 2), SenseInfo('12602980-n', 0) ],
"_statistician_n_1_rel" : [ SenseInfo('10653238-n', 1), SenseInfo('10652954-n', 0) ],
"_chiefly_x_deg_rel" : [ SenseInfo('00073897-r', 11), SenseInfo('00073897-r', 11) ],
"_irrational_a_for_rel" : [ SenseInfo('01926376-a', 2), SenseInfo('02930083-a', 0), SenseInfo('01926376-a', 2), SenseInfo('02930083-a', 0), SenseInfo('01926376-a', 2), SenseInfo('02930083-a', 0) ],
"_swanky_a_1_rel" : [ SenseInfo('00973434-a', 0), SenseInfo('00973434-a', 0), SenseInfo('00973434-a', 0) ],
"_band_v_1_rel" : [ SenseInfo('01304342-v', 1), SenseInfo('01297401-v', 0) ],
"_cave-in_n_1_rel" : [ SenseInfo('07361416-n', 0), SenseInfo('07361416-n', 0) ],
"_trumpet_n_1_rel" : [ SenseInfo('03110669-n', 1) ],
"_medium_x_deg_rel" : [ SenseInfo('06254669-n', 5), SenseInfo('01531957-a', 5), SenseInfo('08568142-n', 4), SenseInfo('06254475-n', 2), SenseInfo('14899328-n', 1), SenseInfo('14899888-n', 0), SenseInfo('14899530-n', 0), SenseInfo('14899152-n', 0), SenseInfo('13920169-n', 0), SenseInfo('10306279-n', 0), SenseInfo('06261586-n', 0), SenseInfo('00610222-n', 0), SenseInfo('00617752-a', 0) ],
"_sync_n_1_rel" : [  ],
"_tally_v_1_rel" : [ SenseInfo('02657219-v', 0), SenseInfo('01111816-v', 0), SenseInfo('00949841-v', 0), SenseInfo('00949288-v', 0) ],
"_yell_n_of_rel" : [ SenseInfo('07120524-n', 7), SenseInfo('07121157-n', 4) ],
"_parasol_n_1_rel" : [ SenseInfo('03889871-n', 0) ],
"_exceed_v_1_rel" : [ SenseInfo('02669477-v', 21), SenseInfo('02669081-v', 8), SenseInfo('01105639-v', 4) ],
"_leverage_v_1_rel" : [ SenseInfo('02359839-v', 0), SenseInfo('02359690-v', 0) ],
"_um_a_1_rel" : [  ],
"_mount_v_1_rel" : [ SenseInfo('01343204-v', 10), SenseInfo('00433232-v', 8), SenseInfo('00407633-v', 6), SenseInfo('01649124-v', 4), SenseInfo('01923414-v', 3), SenseInfo('01921964-v', 3), SenseInfo('01649251-v', 0), SenseInfo('01429322-v', 0) ],
"_neighbor_n_1_rel" : [ SenseInfo('10352299-n', 23), SenseInfo('09368224-n', 0), SenseInfo('10352299-n', 23), SenseInfo('09368224-n', 0) ],
"_optimal_a_1_rel" : [ SenseInfo('00228645-a', 3), SenseInfo('00228645-a', 3) ],
"_skeptic_n_1_rel" : [ SenseInfo('10604634-n', 3) ],
"_wealthy_n_1_rel" : [ SenseInfo('02022167-a', 3) ],
"_cute_a_1_rel" : [ SenseInfo('00167278-a', 1), SenseInfo('00148642-a', 1), SenseInfo('00167278-a', 1), SenseInfo('00148642-a', 1), SenseInfo('00167278-a', 1), SenseInfo('00148642-a', 1) ],
"_vineyard_n_1_rel" : [ SenseInfo('04536038-n', 1) ],
"_ay_a_1_rel" : [  ],
"_pant_v_1_rel" : [ SenseInfo('00005526-v', 9), SenseInfo('00986173-v', 1), SenseInfo('00005526-v', 9), SenseInfo('00986173-v', 1) ],
"_compatible_n_1_rel" : [ SenseInfo('00507464-a', 6), SenseInfo('00509039-a', 0), SenseInfo('00509576-a', 0) ],
"_overnighter_n_1_rel" : [ SenseInfo('10388647-n', 3), SenseInfo('03865371-n', 0) ],
"polite_rel" : [  ],
"_tin_n_1_rel" : [ SenseInfo('14658855-n', 5), SenseInfo('04438897-n', 0), SenseInfo('02949542-n', 0), SenseInfo('02946921-n', 0) ],
"_convey_v_to_rel" : [ SenseInfo('00928630-v', 9), SenseInfo('01061017-v', 8), SenseInfo('02231661-v', 0), SenseInfo('02221454-v', 0), SenseInfo('02079933-v', 0), SenseInfo('02077656-v', 0), SenseInfo('01433294-v', 0) ],
"_replacement_n_of_rel" : [ SenseInfo('00197772-n', 4), SenseInfo('10680153-n', 2), SenseInfo('07443761-n', 2), SenseInfo('05696425-n', 1), SenseInfo('13547925-n', 0), SenseInfo('10671736-n', 0) ],
"_petunia_n_1_rel" : [ SenseInfo('12909421-n', 0), SenseInfo('12909252-n', 0) ],
"_expose_v_as_rel" : [ SenseInfo('02112029-v', 14), SenseInfo('00933821-v', 7), SenseInfo('02140033-v', 4), SenseInfo('01339505-v', 3), SenseInfo('02137710-v', 2), SenseInfo('01036319-v', 1), SenseInfo('02113430-v', 0), SenseInfo('00853195-v', 0), SenseInfo('00614444-v', 0), SenseInfo('02112029-v', 14), SenseInfo('00933821-v', 7), SenseInfo('02140033-v', 4), SenseInfo('01339505-v', 3), SenseInfo('02137710-v', 2), SenseInfo('01036319-v', 1), SenseInfo('02113430-v', 0), SenseInfo('00853195-v', 0), SenseInfo('00614444-v', 0) ],
"_subsection_n_1_rel" : [ SenseInfo('04348548-n', 12) ],
"_signify_v_1_rel" : [ SenseInfo('00931852-v', 3), SenseInfo('00932324-v', 1), SenseInfo('01039854-v', 0), SenseInfo('00931852-v', 3), SenseInfo('00932324-v', 1), SenseInfo('01039854-v', 0), SenseInfo('00931852-v', 3), SenseInfo('00932324-v', 1), SenseInfo('01039854-v', 0), SenseInfo('00931852-v', 3), SenseInfo('00932324-v', 1), SenseInfo('01039854-v', 0) ],
"_outnumber_v_1_rel" : [ SenseInfo('02644905-v', 2) ],
"_comfort_v_1_rel" : [ SenseInfo('01814815-v', 4), SenseInfo('00082308-v', 1), SenseInfo('01814815-v', 4), SenseInfo('00082308-v', 1), SenseInfo('01814815-v', 4), SenseInfo('00082308-v', 1), SenseInfo('01814815-v', 4), SenseInfo('00082308-v', 1), SenseInfo('01814815-v', 4), SenseInfo('00082308-v', 1), SenseInfo('01814815-v', 4), SenseInfo('00082308-v', 1) ],
"_doweling_n_1_rel" : [ SenseInfo('00148762-n', 1) ],
"_vista_n_1_rel" : [ SenseInfo('05933246-n', 1) ],
"_last_v_out_rel" : [ SenseInfo('02704928-v', 19), SenseInfo('02618149-v', 7) ],
"_consensus_n_1_rel" : [ SenseInfo('13971901-n', 3), SenseInfo('13971901-n', 3) ],
"_serving_n_1_rel" : [ SenseInfo('07578363-n', 0), SenseInfo('00318391-n', 0) ],
"_writers_a_1_rel" : [  ],
"_roar_v_at_rel" : [ SenseInfo('01046059-v', 15), SenseInfo('00915605-v', 7), SenseInfo('01046932-v', 6), SenseInfo('01996188-v', 1), SenseInfo('01048718-v', 1), SenseInfo('00029836-v', 0) ],
"_facade_n_1_rel" : [ SenseInfo('03313333-n', 3), SenseInfo('06758698-n', 0) ],
"_illusion_n_1_rel" : [ SenseInfo('05939636-n', 23), SenseInfo('05896059-n', 6), SenseInfo('00754767-n', 1), SenseInfo('00099951-n', 0), SenseInfo('05939636-n', 23), SenseInfo('05896059-n', 6), SenseInfo('00754767-n', 1), SenseInfo('00099951-n', 0) ],
"_psychologist_n_1_rel" : [ SenseInfo('10488865-n', 16) ],
"_score_n_1_rel" : [ SenseInfo('05737153-n', 18), SenseInfo('06815714-n', 8), SenseInfo('13594585-n', 4), SenseInfo('08272652-n', 4), SenseInfo('09179382-n', 1), SenseInfo('05819338-n', 1), SenseInfo('14491034-n', 0), SenseInfo('13905405-n', 0), SenseInfo('07549536-n', 0), SenseInfo('00186634-n', 0), SenseInfo('00160688-n', 0) ],
"_lesson_n_1_rel" : [ SenseInfo('00889472-n', 6), SenseInfo('06672752-n', 4), SenseInfo('06606044-n', 4), SenseInfo('00729285-n', 3) ],
"_not_x_deg_rel" : [ SenseInfo('00024073-r', 1837) ],
"_peculiarity_n_1_rel" : [ SenseInfo('05852125-n', 1), SenseInfo('04763925-n', 1), SenseInfo('03149951-n', 0) ],
"_rosy_a_1_rel" : [ SenseInfo('01664156-a', 1), SenseInfo('01170823-a', 1), SenseInfo('00371611-a', 1), SenseInfo('00176676-a', 0), SenseInfo('01664156-a', 1), SenseInfo('01170823-a', 1), SenseInfo('00371611-a', 1), SenseInfo('00176676-a', 0), SenseInfo('01664156-a', 1), SenseInfo('01170823-a', 1), SenseInfo('00371611-a', 1), SenseInfo('00176676-a', 0), SenseInfo('01664156-a', 1), SenseInfo('01170823-a', 1), SenseInfo('00371611-a', 1), SenseInfo('00176676-a', 0) ],
"_barley_n_1_rel" : [ SenseInfo('07803093-n', 2), SenseInfo('12123244-n', 0) ],
"_appear_v_to_rel" : [ SenseInfo('02133435-v', 121), SenseInfo('00422090-v', 102), SenseInfo('00425967-v', 22), SenseInfo('02134672-v', 14), SenseInfo('00425071-v', 7), SenseInfo('01721169-v', 2), SenseInfo('02597762-v', 1), SenseInfo('02133435-v', 121), SenseInfo('00422090-v', 102), SenseInfo('00425967-v', 22), SenseInfo('02134672-v', 14), SenseInfo('00425071-v', 7), SenseInfo('01721169-v', 2), SenseInfo('02597762-v', 1), SenseInfo('02133435-v', 121), SenseInfo('00422090-v', 102), SenseInfo('00425967-v', 22), SenseInfo('02134672-v', 14), SenseInfo('00425071-v', 7), SenseInfo('01721169-v', 2), SenseInfo('02597762-v', 1) ],
"_moorland_n_1_rel" : [ SenseInfo('09358751-n', 0) ],
"_thereby_a_1_rel" : [  ],
"_betters_n_1_rel" : [ SenseInfo('05143558-n', 1), SenseInfo('09851876-n', 0), SenseInfo('09851719-n', 0), SenseInfo('05143690-n', 0), SenseInfo('05143558-n', 1), SenseInfo('09851876-n', 0), SenseInfo('09851719-n', 0), SenseInfo('05143690-n', 0) ],
"_silly_a_1_rel" : [ SenseInfo('02571536-a', 7), SenseInfo('02120828-a', 1), SenseInfo('00752847-a', 0), SenseInfo('00437223-a', 0), SenseInfo('02571536-a', 7), SenseInfo('02120828-a', 1), SenseInfo('00752847-a', 0), SenseInfo('00437223-a', 0), SenseInfo('02571536-a', 7), SenseInfo('02120828-a', 1), SenseInfo('00752847-a', 0), SenseInfo('00437223-a', 0), SenseInfo('02571536-a', 7), SenseInfo('02120828-a', 1), SenseInfo('00752847-a', 0), SenseInfo('00437223-a', 0) ],
"_admit_v_to_rel" : [ SenseInfo('00817311-v', 64), SenseInfo('02502536-v', 11), SenseInfo('02449847-v', 1), SenseInfo('02236624-v', 1), SenseInfo('02745486-v', 0), SenseInfo('02741682-v', 0), SenseInfo('02732798-v', 0), SenseInfo('02671279-v', 0), SenseInfo('00817311-v', 64), SenseInfo('02502536-v', 11), SenseInfo('02449847-v', 1), SenseInfo('02236624-v', 1), SenseInfo('02745486-v', 0), SenseInfo('02741682-v', 0), SenseInfo('02732798-v', 0), SenseInfo('02671279-v', 0), SenseInfo('00817311-v', 64), SenseInfo('02502536-v', 11), SenseInfo('02449847-v', 1), SenseInfo('02236624-v', 1), SenseInfo('02745486-v', 0), SenseInfo('02741682-v', 0), SenseInfo('02732798-v', 0), SenseInfo('02671279-v', 0), SenseInfo('00817311-v', 64), SenseInfo('02502536-v', 11), SenseInfo('02449847-v', 1), SenseInfo('02236624-v', 1), SenseInfo('02745486-v', 0), SenseInfo('02741682-v', 0), SenseInfo('02732798-v', 0), SenseInfo('02671279-v', 0) ],
"_dungeon_n_1_rel" : [ SenseInfo('03610098-n', 3), SenseInfo('03256928-n', 0) ],
"_corrosive_n_1_rel" : [ SenseInfo('14823788-n', 0) ],
"_puzzlement_n_1_rel" : [ SenseInfo('05685030-n', 1), SenseInfo('05685030-n', 1) ],
"_cutting_a_1_rel" : [ SenseInfo('01374004-a', 0), SenseInfo('01252399-a', 0), SenseInfo('00803432-a', 0) ],
"_transplanter_n_1_rel" : [ SenseInfo('10725613-n', 0) ],
"_mass-produce_v_1_rel" : [ SenseInfo('01625891-v', 0), SenseInfo('01625891-v', 0) ],
"_clear_v_out_rel" : [ SenseInfo('00181664-v', 16), SenseInfo('00195617-v', 5), SenseInfo('02771169-v', 2), SenseInfo('00803325-v', 2), SenseInfo('00195342-v', 2), SenseInfo('02523351-v', 1), SenseInfo('02289134-v', 1), SenseInfo('02156844-v', 1), SenseInfo('02081178-v', 1), SenseInfo('00621058-v', 1), SenseInfo('02422409-v', 0), SenseInfo('02350440-v', 0), SenseInfo('02291548-v', 0), SenseInfo('02291258-v', 0), SenseInfo('02289295-v', 0), SenseInfo('02208409-v', 0), SenseInfo('02053490-v', 0), SenseInfo('00904046-v', 0), SenseInfo('00761454-v', 0), SenseInfo('00549217-v', 0), SenseInfo('00450863-v', 0), SenseInfo('00450691-v', 0), SenseInfo('00450565-v', 0), SenseInfo('00178235-v', 0), SenseInfo('00181664-v', 16), SenseInfo('00195617-v', 5), SenseInfo('02771169-v', 2), SenseInfo('00803325-v', 2), SenseInfo('00195342-v', 2), SenseInfo('02523351-v', 1), SenseInfo('02289134-v', 1), SenseInfo('02156844-v', 1), SenseInfo('02081178-v', 1), SenseInfo('00621058-v', 1), SenseInfo('02422409-v', 0), SenseInfo('02350440-v', 0), SenseInfo('02291548-v', 0), SenseInfo('02291258-v', 0), SenseInfo('02289295-v', 0), SenseInfo('02208409-v', 0), SenseInfo('02053490-v', 0), SenseInfo('00904046-v', 0), SenseInfo('00761454-v', 0), SenseInfo('00549217-v', 0), SenseInfo('00450863-v', 0), SenseInfo('00450691-v', 0), SenseInfo('00450565-v', 0), SenseInfo('00178235-v', 0) ],
"_close_v_up_rel" : [ SenseInfo('01345109-v', 32), SenseInfo('01346978-v', 20), SenseInfo('02426395-v', 18), SenseInfo('02425913-v', 13), SenseInfo('02610628-v', 2), SenseInfo('00763831-v', 1), SenseInfo('02754276-v', 0), SenseInfo('02375619-v', 0), SenseInfo('02140781-v', 0), SenseInfo('02104503-v', 0), SenseInfo('02054541-v', 0), SenseInfo('02054382-v', 0), SenseInfo('01607288-v', 0), SenseInfo('01478423-v', 0), SenseInfo('01423285-v', 0), SenseInfo('01291941-v', 0), SenseInfo('00352137-v', 0), SenseInfo('01345109-v', 32), SenseInfo('01346978-v', 20), SenseInfo('02426395-v', 18), SenseInfo('02425913-v', 13), SenseInfo('02610628-v', 2), SenseInfo('00763831-v', 1), SenseInfo('02754276-v', 0), SenseInfo('02375619-v', 0), SenseInfo('02140781-v', 0), SenseInfo('02104503-v', 0), SenseInfo('02054541-v', 0), SenseInfo('02054382-v', 0), SenseInfo('01607288-v', 0), SenseInfo('01478423-v', 0), SenseInfo('01423285-v', 0), SenseInfo('01291941-v', 0), SenseInfo('00352137-v', 0) ],
"_clarinet_n_1_rel" : [ SenseInfo('03037709-n', 0) ],
"_rid_v_of_rel" : [ SenseInfo('02350175-v', 5) ],
"_gel_v_1_rel" : [ SenseInfo('00113728-v', 0), SenseInfo('00039950-v', 0) ],
"_intactible_a_1_rel" : [  ],
"_owner_n_of_rel" : [ SenseInfo('10388924-n', 15), SenseInfo('10389398-n', 9) ],
"_captain_n_of_rel" : [ SenseInfo('09893191-n', 16), SenseInfo('09892831-n', 14), SenseInfo('09893015-n', 7), SenseInfo('10298912-n', 6), SenseInfo('09893344-n', 2), SenseInfo('09892693-n', 0), SenseInfo('09892513-n', 0), SenseInfo('09893191-n', 16), SenseInfo('09892831-n', 14), SenseInfo('09893015-n', 7), SenseInfo('10298912-n', 6), SenseInfo('09893344-n', 2), SenseInfo('09892693-n', 0), SenseInfo('09892513-n', 0) ],
"_snowhill_n_1_rel" : [  ],
"_captain_v_1_rel" : [ SenseInfo('02440486-v', 0) ],
"_triangle_n_1_rel" : [ SenseInfo('13879320-n', 2), SenseInfo('13879634-n', 0), SenseInfo('09461724-n', 0), SenseInfo('04480995-n', 0), SenseInfo('04480853-n', 0) ],
"_watch_v_out_rel" : [ SenseInfo('02150510-v', 77), SenseInfo('02455407-v', 64), SenseInfo('02150948-v', 24), SenseInfo('02128653-v', 10), SenseInfo('02151966-v', 1), SenseInfo('02131963-v', 0), SenseInfo('00920336-v', 0), SenseInfo('02150510-v', 77), SenseInfo('02455407-v', 64), SenseInfo('02150948-v', 24), SenseInfo('02128653-v', 10), SenseInfo('02151966-v', 1), SenseInfo('02131963-v', 0), SenseInfo('00920336-v', 0), SenseInfo('02150510-v', 77), SenseInfo('02455407-v', 64), SenseInfo('02150948-v', 24), SenseInfo('02128653-v', 10), SenseInfo('02151966-v', 1), SenseInfo('02131963-v', 0), SenseInfo('00920336-v', 0) ],
"_treat_v_1_rel" : [ SenseInfo('02514187-v', 30), SenseInfo('00515154-v', 23), SenseInfo('00078760-v', 17), SenseInfo('01033527-v', 10), SenseInfo('02261642-v', 3), SenseInfo('01176232-v', 0), SenseInfo('00762720-v', 0), SenseInfo('00651145-v', 0) ],
"_pay_v_up_rel" : [ SenseInfo('02251743-v', 138), SenseInfo('01060494-v', 26), SenseInfo('02252931-v', 12), SenseInfo('02291708-v', 6), SenseInfo('02253456-v', 6), SenseInfo('00732224-v', 4), SenseInfo('02732292-v', 3), SenseInfo('02488056-v', 1), SenseInfo('00737884-v', 1), SenseInfo('02344243-v', 0), SenseInfo('02253154-v', 0) ],
"_supervise_v_1_rel" : [ SenseInfo('02443049-v', 11), SenseInfo('02163301-v', 0) ],
"_savings_n_1_rel" : [ SenseInfo('00192613-n', 6), SenseInfo('00093483-n', 1), SenseInfo('00819024-n', 0), SenseInfo('00192613-n', 6), SenseInfo('00093483-n', 1), SenseInfo('00819024-n', 0), SenseInfo('00192613-n', 6), SenseInfo('00093483-n', 1), SenseInfo('00819024-n', 0), SenseInfo('00192613-n', 6), SenseInfo('00093483-n', 1), SenseInfo('00819024-n', 0) ],
"_luggage_n_1_rel" : [ SenseInfo('02774630-n', 6) ],
"_semblance_n_1_rel" : [ SenseInfo('04677952-n', 1), SenseInfo('05939636-n', 0), SenseInfo('03668642-n', 0) ],
"_shell_v_1_rel" : [ SenseInfo('01135922-v', 1), SenseInfo('01759021-v', 0), SenseInfo('01513710-v', 0), SenseInfo('01406195-v', 0), SenseInfo('01316813-v', 0), SenseInfo('01101913-v', 0), SenseInfo('00197744-v', 0), SenseInfo('00181258-v', 0) ],
"_adult_n_1_rel" : [ SenseInfo('09605289-n', 5), SenseInfo('01321456-n', 5) ],
"_toast_n_1_rel" : [ SenseInfo('07686873-n', 5), SenseInfo('10713367-n', 0), SenseInfo('10137936-n', 0), SenseInfo('07884413-n', 0) ],
"_anti-diarrhoeic_a_1_rel" : [  ],
"_latch_v_1_rel" : [ SenseInfo('01286777-v', 2) ],
"_minus_n_1_rel" : [ SenseInfo('00871862-n', 0) ],
"_hug_n_1_rel" : [ SenseInfo('00417859-n', 0) ],
"_convention_n_1_rel" : [ SenseInfo('08309086-n', 4), SenseInfo('05667613-n', 4), SenseInfo('06774316-n', 0), SenseInfo('04801532-n', 0), SenseInfo('01231819-n', 0) ],
"_hospitalize_v_1_rel" : [ SenseInfo('02348927-v', 0) ],
"_risky_a_for_rel" : [ SenseInfo('02059811-a', 1), SenseInfo('02274537-a', 0), SenseInfo('02059811-a', 1), SenseInfo('02274537-a', 0), SenseInfo('02059811-a', 1), SenseInfo('02274537-a', 0), SenseInfo('02059811-a', 1), SenseInfo('02274537-a', 0) ],
"_frivolous_a_1_rel" : [ SenseInfo('02120458-a', 3) ],
"_despair_v_of_rel" : [ SenseInfo('01810933-v', 3) ],
"_groceries_n_1_rel" : [ SenseInfo('03461385-n', 1), SenseInfo('03461119-n', 0), SenseInfo('03461385-n', 1), SenseInfo('03461119-n', 0) ],
"_fumble_v_for_rel" : [ SenseInfo('01314738-v', 4), SenseInfo('02051547-v', 1), SenseInfo('01211019-v', 1), SenseInfo('02527651-v', 0), SenseInfo('01075327-v', 0) ],
"_describe_v_as_rel" : [ SenseInfo('00987071-v', 77), SenseInfo('00965035-v', 52), SenseInfo('01582645-v', 1), SenseInfo('00652346-v', 1), SenseInfo('00987071-v', 77), SenseInfo('00965035-v', 52), SenseInfo('01582645-v', 1), SenseInfo('00652346-v', 1) ],
"_falsify_v_1_rel" : [ SenseInfo('00835903-v', 3), SenseInfo('02576921-v', 0), SenseInfo('00667942-v', 0), SenseInfo('00202236-v', 0), SenseInfo('00201407-v', 0) ],
"_multivalve_n_1_rel" : [  ],
"_sushi_n_1_rel" : [ SenseInfo('07879450-n', 1) ],
"_paint_v_1_rel" : [ SenseInfo('01684899-v', 17), SenseInfo('01362736-v', 13), SenseInfo('01684663-v', 11), SenseInfo('01363482-v', 0), SenseInfo('01684899-v', 17), SenseInfo('01362736-v', 13), SenseInfo('01684663-v', 11), SenseInfo('01363482-v', 0) ],
"_quantify_v_1_rel" : [ SenseInfo('00492095-v', 0), SenseInfo('00489837-v', 0) ],
"_imprint_v_1_rel" : [ SenseInfo('02430922-v', 2), SenseInfo('01531742-v', 0) ],
"_acrophobia_n_1_rel" : [ SenseInfo('14382766-n', 0) ],
"_stay_v_over_rel" : [ SenseInfo('00117985-v', 43), SenseInfo('01857392-v', 32), SenseInfo('02637202-v', 22), SenseInfo('02727462-v', 17), SenseInfo('02009200-v', 7), SenseInfo('00460900-v', 3), SenseInfo('02731024-v', 0), SenseInfo('02619122-v', 0), SenseInfo('02560021-v', 0), SenseInfo('01344643-v', 0), SenseInfo('01194114-v', 0) ],
"_apostle_n_1_rel" : [ SenseInfo('09799461-n', 0), SenseInfo('09799213-n', 0), SenseInfo('09798811-n', 0) ],
"_tumbler_n_1_rel" : [ SenseInfo('10732967-n', 1), SenseInfo('04496872-n', 1), SenseInfo('04497005-n', 0), SenseInfo('01814755-n', 0) ],
"_magical_a_1_rel" : [ SenseInfo('01576071-a', 2) ],
"_ptolemaic_a_1_rel" : [ SenseInfo('03033522-a', 0), SenseInfo('01118673-a', 0) ],
"_portion_n_of_rel" : [ SenseInfo('13809207-n', 31), SenseInfo('03892891-n', 4), SenseInfo('01085098-n', 4), SenseInfo('13285176-n', 2), SenseInfo('14473222-n', 0), SenseInfo('13265425-n', 0), SenseInfo('07578363-n', 0) ],
"_blessing_n_1_rel" : [ SenseInfo('01215392-n', 1), SenseInfo('14474264-n', 0), SenseInfo('07190039-n', 0), SenseInfo('07189411-n', 0), SenseInfo('01043693-n', 0) ],
"_answer_n_to_rel" : [ SenseInfo('06746005-n', 29), SenseInfo('06743506-n', 21), SenseInfo('07200527-n', 12), SenseInfo('06560254-n', 0), SenseInfo('01234952-n', 0), SenseInfo('06746005-n', 29), SenseInfo('06743506-n', 21), SenseInfo('07200527-n', 12), SenseInfo('06560254-n', 0), SenseInfo('01234952-n', 0), SenseInfo('06746005-n', 29), SenseInfo('06743506-n', 21), SenseInfo('07200527-n', 12), SenseInfo('06560254-n', 0), SenseInfo('01234952-n', 0) ],
"_vitreous_a_1_rel" : [ SenseInfo('02825213-a', 0), SenseInfo('02825060-a', 0), SenseInfo('01119661-a', 0) ],
"_dose_n_1_rel" : [ SenseInfo('03225238-n', 4), SenseInfo('13772106-n', 2), SenseInfo('14133159-n', 0), SenseInfo('02675657-n', 0) ],
"_escape_v_1_rel" : [ SenseInfo('02074677-v', 22), SenseInfo('00810557-v', 8), SenseInfo('00810729-v', 7), SenseInfo('02723232-v', 2), SenseInfo('02599004-v', 0), SenseInfo('02075049-v', 0), SenseInfo('00530017-v', 0) ],
"_floodwater_n_1_rel" : [  ],
"_conditional_a_1_rel" : [ SenseInfo('01913413-a', 1), SenseInfo('00555325-a', 0) ],
"_handwritten_a_1_rel" : [ SenseInfo('02285407-a', 1) ],
"_urging_n_1_rel" : [ SenseInfo('07252378-n', 1), SenseInfo('01214746-n', 1), SenseInfo('07188385-n', 0), SenseInfo('07252378-n', 1), SenseInfo('01214746-n', 1), SenseInfo('07188385-n', 0), SenseInfo('07252378-n', 1), SenseInfo('01214746-n', 1), SenseInfo('07188385-n', 0) ],
"_duckling_n_1_rel" : [ SenseInfo('07646718-n', 0), SenseInfo('01847170-n', 0) ],
"_newsletter_n_1_rel" : [ SenseInfo('06681976-n', 2) ],
"_hardiness_n_1_rel" : [ SenseInfo('05031012-n', 0), SenseInfo('04858785-n', 0) ],
"_cotton_v_on_rel" : [ SenseInfo('01777107-v', 0), SenseInfo('01777107-v', 0) ],
"_policy_n_of-on_rel" : [ SenseInfo('05901508-n', 33), SenseInfo('06656408-n', 25), SenseInfo('06523641-n', 2), SenseInfo('05901508-n', 33), SenseInfo('06656408-n', 25), SenseInfo('06523641-n', 2), SenseInfo('05901508-n', 33), SenseInfo('06656408-n', 25), SenseInfo('06523641-n', 2), SenseInfo('05901508-n', 33), SenseInfo('06656408-n', 25), SenseInfo('06523641-n', 2), SenseInfo('05901508-n', 33), SenseInfo('06656408-n', 25), SenseInfo('06523641-n', 2) ],
"_bunch_n_of_rel" : [ SenseInfo('07959943-n', 6), SenseInfo('08273843-n', 3), SenseInfo('07954731-n', 1), SenseInfo('07959943-n', 6), SenseInfo('08273843-n', 3), SenseInfo('07954731-n', 1) ],
"_adjudge_v_1_rel" : [ SenseInfo('00822367-v', 0), SenseInfo('00822367-v', 0), SenseInfo('00822367-v', 0), SenseInfo('00822367-v', 0) ],
"_condescend_v_1_rel" : [ SenseInfo('02591455-v', 0), SenseInfo('02591312-v', 0), SenseInfo('02517827-v', 0), SenseInfo('00908977-v', 0) ],
"_bone_v_up_rel" : [ SenseInfo('00605783-v', 0), SenseInfo('00197423-v', 0), SenseInfo('00605783-v', 0), SenseInfo('00197423-v', 0), SenseInfo('00605783-v', 0), SenseInfo('00197423-v', 0) ],
"_maiden_n_1_rel" : [ SenseInfo('10282482-n', 3), SenseInfo('15258945-n', 0) ],
"_thriller_n_1_rel" : [ SenseInfo('06370403-n', 1) ],
"_timeout_n_1_rel" : [  ],
"_scarecrowish_a_1_rel" : [ SenseInfo('00990053-a', 1) ],
"_dwell_v_on_rel" : [ SenseInfo('00704249-v', 4), SenseInfo('02653381-v', 3), SenseInfo('02649830-v', 3), SenseInfo('02755773-v', 0), SenseInfo('00959367-v', 0) ],
"_clay_n_1_rel" : [ SenseInfo('14813182-n', 11), SenseInfo('14956325-n', 0), SenseInfo('10900146-n', 0), SenseInfo('10899951-n', 0), SenseInfo('05218119-n', 0) ],
"_woody_a_1_rel" : [ SenseInfo('02575330-a', 0), SenseInfo('02573192-a', 0), SenseInfo('01152189-a', 0) ],
"_psycholinguistics_n_1_rel" : [ SenseInfo('06140587-n', 0) ],
"_change_v_1_rel" : [ SenseInfo('00126264-v', 57), SenseInfo('00109660-v', 54), SenseInfo('00123170-v', 13), SenseInfo('00550117-v', 7), SenseInfo('00169458-v', 6), SenseInfo('00161225-v', 5), SenseInfo('02257370-v', 3), SenseInfo('02088241-v', 3), SenseInfo('00551210-v', 0), SenseInfo('00163251-v', 0), SenseInfo('00126264-v', 57), SenseInfo('00109660-v', 54), SenseInfo('00123170-v', 13), SenseInfo('00550117-v', 7), SenseInfo('00169458-v', 6), SenseInfo('00161225-v', 5), SenseInfo('02257370-v', 3), SenseInfo('02088241-v', 3), SenseInfo('00551210-v', 0), SenseInfo('00163251-v', 0) ],
"_clad_v_in-as_rel" : [  ],
"_lower_v_1_rel" : [ SenseInfo('01973125-v', 15), SenseInfo('00531489-v', 6), SenseInfo('00267855-v', 1), SenseInfo('01574923-v', 0), SenseInfo('00032981-v', 0) ],
"_digestion_n_of_rel" : [ SenseInfo('13465998-n', 0), SenseInfo('13465809-n', 0), SenseInfo('05753379-n', 0) ],
"_clairvoyance_n_1_rel" : [ SenseInfo('07256695-n', 1) ],
"_inclose_v_1_rel" : [ SenseInfo('01587062-v', 1), SenseInfo('00187526-v', 0) ],
"_turning_n_1_rel" : [ SenseInfo('00350030-n', 2), SenseInfo('00195415-n', 2), SenseInfo('09464098-n', 0), SenseInfo('07351612-n', 0), SenseInfo('04500504-n', 0), SenseInfo('00926179-n', 0) ],
"_address_n_1_rel" : [ SenseInfo('06356515-n', 21), SenseInfo('08491027-n', 5), SenseInfo('07238694-n', 3), SenseInfo('07067591-n', 1), SenseInfo('06794216-n', 0), SenseInfo('06787150-n', 0), SenseInfo('05082648-n', 0), SenseInfo('04842232-n', 0) ],
"_satisfying_a_1_rel" : [ SenseInfo('02558528-a', 0), SenseInfo('02081563-a', 0) ],
"_superclass_n_1_rel" : [ SenseInfo('08106798-n', 0) ],
"_overeager_a_1_rel" : [ SenseInfo('00811707-a', 0) ],
"_hook_v_up_rel" : [ SenseInfo('01365549-v', 2), SenseInfo('02319050-v', 1), SenseInfo('01672490-v', 1), SenseInfo('01409177-v', 1), SenseInfo('02322230-v', 0), SenseInfo('02276866-v', 0), SenseInfo('01396790-v', 0), SenseInfo('01365709-v', 0), SenseInfo('01165290-v', 0), SenseInfo('01080883-v', 0), SenseInfo('00783042-v', 0), SenseInfo('00781652-v', 0), SenseInfo('01365549-v', 2), SenseInfo('02319050-v', 1), SenseInfo('01672490-v', 1), SenseInfo('01409177-v', 1), SenseInfo('02322230-v', 0), SenseInfo('02276866-v', 0), SenseInfo('01396790-v', 0), SenseInfo('01365709-v', 0), SenseInfo('01165290-v', 0), SenseInfo('01080883-v', 0), SenseInfo('00783042-v', 0), SenseInfo('00781652-v', 0), SenseInfo('01365549-v', 2), SenseInfo('02319050-v', 1), SenseInfo('01672490-v', 1), SenseInfo('01409177-v', 1), SenseInfo('02322230-v', 0), SenseInfo('02276866-v', 0), SenseInfo('01396790-v', 0), SenseInfo('01365709-v', 0), SenseInfo('01165290-v', 0), SenseInfo('01080883-v', 0), SenseInfo('00783042-v', 0), SenseInfo('00781652-v', 0) ],
"_coolant_n_1_rel" : [ SenseInfo('14822141-n', 2) ],
"_compromise_n_1_rel" : [ SenseInfo('01205564-n', 4), SenseInfo('07179342-n', 1) ],
"_crash_v_out_rel" : [ SenseInfo('01972570-v', 9), SenseInfo('02088627-v', 3), SenseInfo('01561819-v', 2), SenseInfo('02019282-v', 1), SenseInfo('01562061-v', 1), SenseInfo('02657080-v', 0), SenseInfo('02177512-v', 0), SenseInfo('02019011-v', 0), SenseInfo('01562209-v', 0), SenseInfo('01507407-v', 0), SenseInfo('00583064-v', 0), SenseInfo('00434919-v', 0), SenseInfo('00017674-v', 0) ],
"_place_n_i_rel" : [ SenseInfo('08664443-n', 77), SenseInfo('08513718-n', 38), SenseInfo('05611822-n', 22), SenseInfo('08642037-n', 17), SenseInfo('00721431-n', 9), SenseInfo('13926786-n', 7), SenseInfo('08559508-n', 6), SenseInfo('00586262-n', 4), SenseInfo('08621598-n', 3), SenseInfo('13947645-n', 2), SenseInfo('08647616-n', 2), SenseInfo('06401107-n', 2), SenseInfo('13947867-n', 1), SenseInfo('08619795-n', 1), SenseInfo('06483454-n', 1), SenseInfo('06389553-n', 1) ],
"_appearance_n_of_rel" : [ SenseInfo('04673965-n', 19), SenseInfo('07321772-n', 4), SenseInfo('01233627-n', 2), SenseInfo('05939432-n', 1), SenseInfo('00050195-n', 1), SenseInfo('00755277-n', 0) ],
"_transportation_n_1_rel" : [ SenseInfo('04473432-n', 7), SenseInfo('00315986-n', 5), SenseInfo('13308147-n', 0), SenseInfo('08143653-n', 0), SenseInfo('01105259-n', 0), SenseInfo('00207761-n', 0) ],
"_lingo_n_1_rel" : [ SenseInfo('07157273-n', 0) ],
"_wetlands_n_1_rel" : [ SenseInfo('09477890-n', 0), SenseInfo('09477890-n', 0) ],
"_inception_n_1_rel" : [ SenseInfo('07323922-n', 2) ],
"_abdicate_v_1_rel" : [ SenseInfo('02379198-v', 0) ],
"_scuttle_v_1_rel" : [ SenseInfo('01902405-v', 3), SenseInfo('01902405-v', 3) ],
"_totem_n_1_rel" : [ SenseInfo('08372574-n', 0), SenseInfo('04458409-n', 0) ],
"_trip_n_of_rel" : [ SenseInfo('00308370-n', 31), SenseInfo('14378311-n', 0), SenseInfo('07317519-n', 0), SenseInfo('07288385-n', 0), SenseInfo('04485226-n', 0), SenseInfo('00286240-n', 0), SenseInfo('00076563-n', 0) ],
"_po+box_n_1_rel" : [ SenseInfo('03990210-n', 0) ],
"_fat_a_1_rel" : [ SenseInfo('00986027-a', 22), SenseInfo('02411224-a', 2), SenseInfo('00991838-a', 0), SenseInfo('01871349-a', 0), SenseInfo('01081340-a', 0), SenseInfo('00986027-a', 22), SenseInfo('02411224-a', 2), SenseInfo('00991838-a', 0), SenseInfo('01871349-a', 0), SenseInfo('01081340-a', 0), SenseInfo('00986027-a', 22), SenseInfo('02411224-a', 2), SenseInfo('00991838-a', 0), SenseInfo('01871349-a', 0), SenseInfo('01081340-a', 0) ],
"_glue_v_on_rel" : [ SenseInfo('01332205-v', 15), SenseInfo('00486850-v', 2) ],
"_bookworm_n_1_rel" : [ SenseInfo('10411356-n', 0), SenseInfo('09866559-n', 0) ],
"_tornado_n_1_rel" : [ SenseInfo('11519450-n', 1), SenseInfo('03125184-n', 0) ],
"_cannon_n_1_rel" : [ SenseInfo('02950256-n', 11), SenseInfo('02950826-n', 0), SenseInfo('02950632-n', 0), SenseInfo('02950482-n', 0), SenseInfo('02462828-n', 0), SenseInfo('00500449-n', 0) ],
"_sforzando_a_1_rel" : [ SenseInfo('06869742-n', 1), SenseInfo('06869428-n', 0) ],
"_draw_v_1_rel" : [ SenseInfo('01448100-v', 13), SenseInfo('02293148-v', 10), SenseInfo('01582645-v', 10), SenseInfo('00730758-v', 10), SenseInfo('01995211-v', 9), SenseInfo('01690294-v', 7), SenseInfo('01854132-v', 6), SenseInfo('00987071-v', 6), SenseInfo('00675901-v', 6), SenseInfo('01760300-v', 5), SenseInfo('01199009-v', 5), SenseInfo('02088107-v', 4), SenseInfo('02311387-v', 3), SenseInfo('01078050-v', 3), SenseInfo('01643297-v', 2), SenseInfo('00556593-v', 2), SenseInfo('02097800-v', 1), SenseInfo('01690816-v', 1), SenseInfo('01643464-v', 1), SenseInfo('01243148-v', 1), SenseInfo('02742107-v', 0), SenseInfo('02628832-v', 0), SenseInfo('02483564-v', 0), SenseInfo('02103162-v', 0), SenseInfo('01539063-v', 0), SenseInfo('01505254-v', 0), SenseInfo('01359432-v', 0), SenseInfo('01243298-v', 0), SenseInfo('01212230-v', 0), SenseInfo('01115190-v', 0), SenseInfo('00476965-v', 0), SenseInfo('00430808-v', 0), SenseInfo('00327982-v', 0), SenseInfo('00197590-v', 0), SenseInfo('00143338-v', 0), SenseInfo('00097029-v', 0), SenseInfo('01448100-v', 13), SenseInfo('02293148-v', 10), SenseInfo('01582645-v', 10), SenseInfo('00730758-v', 10), SenseInfo('01995211-v', 9), SenseInfo('01690294-v', 7), SenseInfo('01854132-v', 6), SenseInfo('00987071-v', 6), SenseInfo('00675901-v', 6), SenseInfo('01760300-v', 5), SenseInfo('01199009-v', 5), SenseInfo('02088107-v', 4), SenseInfo('02311387-v', 3), SenseInfo('01078050-v', 3), SenseInfo('01643297-v', 2), SenseInfo('00556593-v', 2), SenseInfo('02097800-v', 1), SenseInfo('01690816-v', 1), SenseInfo('01643464-v', 1), SenseInfo('01243148-v', 1), SenseInfo('02742107-v', 0), SenseInfo('02628832-v', 0), SenseInfo('02483564-v', 0), SenseInfo('02103162-v', 0), SenseInfo('01539063-v', 0), SenseInfo('01505254-v', 0), SenseInfo('01359432-v', 0), SenseInfo('01243298-v', 0), SenseInfo('01212230-v', 0), SenseInfo('01115190-v', 0), SenseInfo('00476965-v', 0), SenseInfo('00430808-v', 0), SenseInfo('00327982-v', 0), SenseInfo('00197590-v', 0), SenseInfo('00143338-v', 0), SenseInfo('00097029-v', 0), SenseInfo('01448100-v', 13), SenseInfo('02293148-v', 10), SenseInfo('01582645-v', 10), SenseInfo('00730758-v', 10), SenseInfo('01995211-v', 9), SenseInfo('01690294-v', 7), SenseInfo('01854132-v', 6), SenseInfo('00987071-v', 6), SenseInfo('00675901-v', 6), SenseInfo('01760300-v', 5), SenseInfo('01199009-v', 5), SenseInfo('02088107-v', 4), SenseInfo('02311387-v', 3), SenseInfo('01078050-v', 3), SenseInfo('01643297-v', 2), SenseInfo('00556593-v', 2), SenseInfo('02097800-v', 1), SenseInfo('01690816-v', 1), SenseInfo('01643464-v', 1), SenseInfo('01243148-v', 1), SenseInfo('02742107-v', 0), SenseInfo('02628832-v', 0), SenseInfo('02483564-v', 0), SenseInfo('02103162-v', 0), SenseInfo('01539063-v', 0), SenseInfo('01505254-v', 0), SenseInfo('01359432-v', 0), SenseInfo('01243298-v', 0), SenseInfo('01212230-v', 0), SenseInfo('01115190-v', 0), SenseInfo('00476965-v', 0), SenseInfo('00430808-v', 0), SenseInfo('00327982-v', 0), SenseInfo('00197590-v', 0), SenseInfo('00143338-v', 0), SenseInfo('00097029-v', 0) ],
"_bold_n_1_rel" : [ SenseInfo('06827219-n', 0), SenseInfo('06827219-n', 0) ],
"_wagon_n_1_rel" : [ SenseInfo('04543158-n', 24), SenseInfo('03977966-n', 1), SenseInfo('09219858-n', 0), SenseInfo('04543509-n', 0), SenseInfo('02814533-n', 0) ],
"_self-service_n_1_rel" : [ SenseInfo('00098939-n', 0) ],
"_reek_v_of_rel" : [ SenseInfo('02194723-v', 1), SenseInfo('02124106-v', 1), SenseInfo('00068627-v', 1), SenseInfo('02768120-v', 0), SenseInfo('02194723-v', 1), SenseInfo('02124106-v', 1), SenseInfo('00068627-v', 1), SenseInfo('02768120-v', 0) ],
"_jump_n_1_rel" : [ SenseInfo('07414222-n', 0), SenseInfo('07358985-n', 0), SenseInfo('06618427-n', 0), SenseInfo('00867357-n', 0), SenseInfo('00303849-n', 0), SenseInfo('00119568-n', 0) ],
"_detach_v_1_rel" : [ SenseInfo('01298668-v', 3), SenseInfo('02031622-v', 1), SenseInfo('01299758-v', 0) ],
"_presumption_n_1_rel" : [ SenseInfo('05893356-n', 3), SenseInfo('05781347-n', 0), SenseInfo('04838727-n', 0), SenseInfo('01225562-n', 0), SenseInfo('05893356-n', 3), SenseInfo('05781347-n', 0), SenseInfo('04838727-n', 0), SenseInfo('01225562-n', 0) ],
"_assign_v_1_rel" : [ SenseInfo('02391803-v', 15), SenseInfo('02228698-v', 15), SenseInfo('00726300-v', 7), SenseInfo('00677683-v', 7), SenseInfo('01160370-v', 1), SenseInfo('02276746-v', 0), SenseInfo('02228531-v', 0), SenseInfo('00740053-v', 0), SenseInfo('02391803-v', 15), SenseInfo('02228698-v', 15), SenseInfo('00726300-v', 7), SenseInfo('00677683-v', 7), SenseInfo('01160370-v', 1), SenseInfo('02276746-v', 0), SenseInfo('02228531-v', 0), SenseInfo('00740053-v', 0) ],
"_affect_v_x_rel" : [ SenseInfo('00137313-v', 43), SenseInfo('00019448-v', 11), SenseInfo('02677097-v', 4), SenseInfo('00838043-v', 4), SenseInfo('01767949-v', 0) ],
"_counterpart_n_to_rel" : [ SenseInfo('05695806-n', 12), SenseInfo('03117939-n', 1), SenseInfo('05695806-n', 12), SenseInfo('03117939-n', 1), SenseInfo('05695806-n', 12), SenseInfo('03117939-n', 1), SenseInfo('05695806-n', 12), SenseInfo('03117939-n', 1) ],
"_lay_v_up_rel" : [ SenseInfo('01494310-v', 24), SenseInfo('01544692-v', 11), SenseInfo('01651972-v', 5), SenseInfo('01545079-v', 4), SenseInfo('02307261-v', 1), SenseInfo('01494310-v', 24), SenseInfo('01544692-v', 11), SenseInfo('01651972-v', 5), SenseInfo('01545079-v', 4), SenseInfo('02307261-v', 1) ],
"_sodium_n_1_rel" : [ SenseInfo('14655371-n', 1) ],
"_wonderful_a_for_rel" : [ SenseInfo('01676517-a', 14), SenseInfo('01676517-a', 14), SenseInfo('01676517-a', 14), SenseInfo('01676517-a', 14), SenseInfo('01676517-a', 14), SenseInfo('01676517-a', 14) ],
"_bathroom_n_1_rel" : [ SenseInfo('02807731-n', 6), SenseInfo('04446276-n', 0) ],
"_trim_v_1_rel" : [ SenseInfo('01262564-v', 8), SenseInfo('01679806-v', 1), SenseInfo('00429060-v', 1), SenseInfo('02752107-v', 0), SenseInfo('02751952-v', 0), SenseInfo('01679433-v', 0), SenseInfo('01321002-v', 0), SenseInfo('01248782-v', 0), SenseInfo('00297193-v', 0) ],
"_slate_n_1_rel" : [ SenseInfo('04234670-n', 1), SenseInfo('15043002-n', 0), SenseInfo('14700162-n', 0), SenseInfo('06495948-n', 0) ],
"_nest_v_1_rel" : [ SenseInfo('02654947-v', 4), SenseInfo('01529766-v', 2), SenseInfo('01424948-v', 0), SenseInfo('01383393-v', 0), SenseInfo('02654947-v', 4), SenseInfo('01529766-v', 2), SenseInfo('01424948-v', 0), SenseInfo('01383393-v', 0) ],
"_pith_n_1_rel" : [ SenseInfo('13096159-n', 1), SenseInfo('05921123-n', 0) ],
"_sit_v_1_rel" : [ SenseInfo('01543123-v', 134), SenseInfo('02692882-v', 33), SenseInfo('01984902-v', 10), SenseInfo('02024874-v', 6), SenseInfo('02142775-v', 1), SenseInfo('01957529-v', 1), SenseInfo('02691214-v', 0), SenseInfo('02456270-v', 0), SenseInfo('01543998-v', 0), SenseInfo('01095581-v', 0), SenseInfo('01543123-v', 134), SenseInfo('02692882-v', 33), SenseInfo('01984902-v', 10), SenseInfo('02024874-v', 6), SenseInfo('02142775-v', 1), SenseInfo('01957529-v', 1), SenseInfo('02691214-v', 0), SenseInfo('02456270-v', 0), SenseInfo('01543998-v', 0), SenseInfo('01095581-v', 0) ],
"_pawn_n_1_rel" : [ SenseInfo('13350875-n', 0), SenseInfo('10209616-n', 0), SenseInfo('03901750-n', 0), SenseInfo('01111236-n', 0) ],
"_genital_n_1_rel" : [ SenseInfo('02881567-a', 0) ],
"_butter_n_1_rel" : [ SenseInfo('07848338-n', 3), SenseInfo('09884815-n', 0) ],
"_blonde_a_1_rel" : [ SenseInfo('00243606-a', 1) ],
"_scotch_a_1_rel" : [ SenseInfo('03024647-a', 0), SenseInfo('02421364-a', 0) ],
"_delirious_a_1_rel" : [ SenseInfo('02543823-a', 0), SenseInfo('02390724-a', 0) ],
"_interesting_a_for_rel" : [ SenseInfo('01343918-a', 27), SenseInfo('01343918-a', 27), SenseInfo('01343918-a', 27), SenseInfo('01343918-a', 27) ],
"_subscriber_n_to_rel" : [ SenseInfo('10670668-n', 0), SenseInfo('10670483-n', 0), SenseInfo('10670310-n', 0) ],
"_axe_v_1_rel" : [ SenseInfo('01257953-v', 0), SenseInfo('00354317-v', 0) ],
"_play_v_up_rel" : [ SenseInfo('01072949-v', 70), SenseInfo('02370650-v', 37), SenseInfo('01725051-v', 29), SenseInfo('01719302-v', 27), SenseInfo('02418686-v', 23), SenseInfo('01724459-v', 14), SenseInfo('01726172-v', 8), SenseInfo('00013615-v', 6), SenseInfo('01903385-v', 5), SenseInfo('01138911-v', 5), SenseInfo('02418421-v', 4), SenseInfo('01722077-v', 4), SenseInfo('01717436-v', 3), SenseInfo('01716619-v', 2), SenseInfo('01149470-v', 2), SenseInfo('00013328-v', 2), SenseInfo('02597601-v', 1), SenseInfo('01717169-v', 1), SenseInfo('01586278-v', 1), SenseInfo('01163355-v', 1), SenseInfo('00711932-v', 1), SenseInfo('02722449-v', 0), SenseInfo('02437465-v', 0), SenseInfo('01903562-v', 0), SenseInfo('01719921-v', 0), SenseInfo('01716882-v', 0), SenseInfo('01629589-v', 0), SenseInfo('01377239-v', 0), SenseInfo('01156115-v', 0), SenseInfo('01155687-v', 0), SenseInfo('01080691-v', 0), SenseInfo('01080064-v', 0), SenseInfo('01079873-v', 0), SenseInfo('01079480-v', 0), SenseInfo('00075875-v', 0) ],
"_improbable_a_1_rel" : [ SenseInfo('01413871-a', 1), SenseInfo('01800169-a', 0), SenseInfo('00646117-a', 0) ],
"_hawser_n_1_rel" : [ SenseInfo('03500209-n', 0) ],
"_blast_v_away_rel" : [ SenseInfo('02182479-v', 3), SenseInfo('01401772-v', 2), SenseInfo('01135922-v', 1), SenseInfo('02101216-v', 0), SenseInfo('01759021-v', 0), SenseInfo('01758276-v', 0), SenseInfo('01134781-v', 0), SenseInfo('00823827-v', 0), SenseInfo('00336158-v', 0), SenseInfo('00241924-v', 0) ],
"_narrow_a_1_rel" : [ SenseInfo('02561888-a', 19), SenseInfo('01415480-a', 2), SenseInfo('00287640-a', 1), SenseInfo('02563310-a', 0), SenseInfo('00310716-a', 0), SenseInfo('02561888-a', 19), SenseInfo('01415480-a', 2), SenseInfo('00287640-a', 1), SenseInfo('02563310-a', 0), SenseInfo('00310716-a', 0), SenseInfo('02561888-a', 19), SenseInfo('01415480-a', 2), SenseInfo('00287640-a', 1), SenseInfo('02563310-a', 0), SenseInfo('00310716-a', 0), SenseInfo('02561888-a', 19), SenseInfo('01415480-a', 2), SenseInfo('00287640-a', 1), SenseInfo('02563310-a', 0), SenseInfo('00310716-a', 0) ],
"_woolen_a_1_rel" : [ SenseInfo('03130689-a', 1) ],
"_product_n_1_rel" : [ SenseInfo('03748886-n', 52), SenseInfo('04007894-n', 25), SenseInfo('05859630-n', 8), SenseInfo('14997699-n', 2), SenseInfo('11415842-n', 0), SenseInfo('07999068-n', 0), SenseInfo('03748886-n', 52), SenseInfo('04007894-n', 25), SenseInfo('05859630-n', 8), SenseInfo('14997699-n', 2), SenseInfo('11415842-n', 0), SenseInfo('07999068-n', 0), SenseInfo('03748886-n', 52), SenseInfo('04007894-n', 25), SenseInfo('05859630-n', 8), SenseInfo('14997699-n', 2), SenseInfo('11415842-n', 0), SenseInfo('07999068-n', 0) ],
"_hindsight_n_1_rel" : [ SenseInfo('05807147-n', 0) ],
"_competent_a_1_rel" : [ SenseInfo('00510050-a', 7), SenseInfo('00051571-a', 3), SenseInfo('00512130-a', 0), SenseInfo('00510050-a', 7), SenseInfo('00051571-a', 3), SenseInfo('00512130-a', 0), SenseInfo('00510050-a', 7), SenseInfo('00051571-a', 3), SenseInfo('00512130-a', 0) ],
"_kilocalorie_n_1_rel" : [ SenseInfo('13726562-n', 0), SenseInfo('13726562-n', 0) ],
"_mold_v_cause_rel" : [ SenseInfo('01697027-v', 4), SenseInfo('00210738-v', 1), SenseInfo('01662771-v', 0), SenseInfo('01659248-v', 0), SenseInfo('01221405-v', 0), SenseInfo('00701040-v', 0), SenseInfo('01697027-v', 4), SenseInfo('00210738-v', 1), SenseInfo('01662771-v', 0), SenseInfo('01659248-v', 0), SenseInfo('01221405-v', 0), SenseInfo('00701040-v', 0) ],
"_appealing_a_to_rel" : [ SenseInfo('00170358-a', 3), SenseInfo('02376277-a', 1) ],
"_sterile_a_1_rel" : [ SenseInfo('01002377-a', 0), SenseInfo('02115759-a', 0), SenseInfo('00644560-a', 0) ],
"_redress_n_1_rel" : [ SenseInfo('13290676-n', 1), SenseInfo('00259177-n', 0) ],
"_indicator_n_of_rel" : [ SenseInfo('06639674-n', 9), SenseInfo('07262579-n', 2), SenseInfo('03568117-n', 2), SenseInfo('14917208-n', 0), SenseInfo('06639674-n', 9), SenseInfo('07262579-n', 2), SenseInfo('03568117-n', 2), SenseInfo('14917208-n', 0), SenseInfo('06639674-n', 9), SenseInfo('07262579-n', 2), SenseInfo('03568117-n', 2), SenseInfo('14917208-n', 0) ],
"_blaze_n_1_rel" : [ SenseInfo('13439088-n', 4), SenseInfo('07305907-n', 3), SenseInfo('00736786-n', 1), SenseInfo('04952570-n', 0), SenseInfo('04681058-n', 0) ],
"_silt_v_up_rel" : [ SenseInfo('01479545-v', 0) ],
"_whaler_n_1_rel" : [ SenseInfo('10775128-n', 0), SenseInfo('04574471-n', 0) ],
"_work_v_in_rel" : [ SenseInfo('02413480-v', 74), SenseInfo('02410855-v', 62), SenseInfo('02525447-v', 32), SenseInfo('01525666-v', 20), SenseInfo('01668603-v', 9), SenseInfo('00100551-v', 9), SenseInfo('02051031-v', 5), SenseInfo('02594979-v', 4), SenseInfo('02373015-v', 3), SenseInfo('01852468-v', 3), SenseInfo('01629589-v', 3), SenseInfo('02407987-v', 2), SenseInfo('01741446-v', 2), SenseInfo('02751271-v', 0), SenseInfo('02536557-v', 0), SenseInfo('02444159-v', 0), SenseInfo('02436963-v', 0), SenseInfo('02116980-v', 0), SenseInfo('01817574-v', 0), SenseInfo('01659248-v', 0), SenseInfo('01541231-v', 0), SenseInfo('01235355-v', 0), SenseInfo('01162754-v', 0), SenseInfo('00634906-v', 0), SenseInfo('00458754-v', 0), SenseInfo('00458471-v', 0), SenseInfo('00150096-v', 0) ],
"_determined_a_1_rel" : [ SenseInfo('01990373-a', 10), SenseInfo('01610339-a', 0), SenseInfo('02328108-a', 0), SenseInfo('02129908-a', 0), SenseInfo('00104699-a', 0), SenseInfo('01990373-a', 10), SenseInfo('01610339-a', 0), SenseInfo('02328108-a', 0), SenseInfo('02129908-a', 0), SenseInfo('00104699-a', 0) ],
"_falsehood_n_1_rel" : [ SenseInfo('06756407-n', 0), SenseInfo('00750890-n', 0) ],
"_deli_n_1_rel" : [ SenseInfo('03173387-n', 0) ],
"_stock_v_up_rel" : [ SenseInfo('02285392-v', 2), SenseInfo('02329883-v', 0), SenseInfo('02329733-v', 0), SenseInfo('02329578-v', 0), SenseInfo('02323286-v', 0), SenseInfo('02323059-v', 0), SenseInfo('00095377-v', 0), SenseInfo('02285392-v', 2), SenseInfo('02329883-v', 0), SenseInfo('02329733-v', 0), SenseInfo('02329578-v', 0), SenseInfo('02323286-v', 0), SenseInfo('02323059-v', 0), SenseInfo('00095377-v', 0), SenseInfo('02285392-v', 2), SenseInfo('02329883-v', 0), SenseInfo('02329733-v', 0), SenseInfo('02329578-v', 0), SenseInfo('02323286-v', 0), SenseInfo('02323059-v', 0), SenseInfo('00095377-v', 0) ],
"_mizzenmast_n_1_rel" : [ SenseInfo('03775847-n', 0) ],
"_spirit_v_away_rel" : [ SenseInfo('00193130-v', 0) ],
"_first+prize_n_1_rel" : [  ],
"_grate_v_on_rel" : [ SenseInfo('02330583-v', 0), SenseInfo('01773825-v', 0), SenseInfo('01574077-v', 0), SenseInfo('01394464-v', 0), SenseInfo('01308160-v', 0) ],
"_switch_n_1_rel" : [ SenseInfo('04372370-n', 4), SenseInfo('07443761-n', 1), SenseInfo('04372948-n', 0), SenseInfo('04372756-n', 0), SenseInfo('04372171-n', 0), SenseInfo('00563823-n', 0), SenseInfo('00196084-n', 0) ],
"_mischief_n_1_rel" : [ SenseInfo('00736375-n', 3), SenseInfo('04846533-n', 0) ],
"_strict_a_1_rel" : [ SenseInfo('00915556-a', 3), SenseInfo('02506267-a', 2), SenseInfo('01299888-a', 0), SenseInfo('02436995-a', 0), SenseInfo('00711308-a', 0), SenseInfo('00915556-a', 3), SenseInfo('02506267-a', 2), SenseInfo('01299888-a', 0), SenseInfo('02436995-a', 0), SenseInfo('00711308-a', 0), SenseInfo('00915556-a', 3), SenseInfo('02506267-a', 2), SenseInfo('01299888-a', 0), SenseInfo('02436995-a', 0), SenseInfo('00711308-a', 0), SenseInfo('00915556-a', 3), SenseInfo('02506267-a', 2), SenseInfo('01299888-a', 0), SenseInfo('02436995-a', 0), SenseInfo('00711308-a', 0) ],
"_suffering_n_1_rel" : [ SenseInfo('14324274-n', 11), SenseInfo('14448910-n', 8), SenseInfo('07496463-n', 7), SenseInfo('07495327-n', 2) ],
"_businessman_n_1_rel" : [ SenseInfo('09882007-n', 10) ],
"_short-hand_n_1_rel" : [ SenseInfo('06350127-n', 0), SenseInfo('06350127-n', 0), SenseInfo('06350127-n', 0) ],
"_trespass_v_1_rel" : [ SenseInfo('02571251-v', 2), SenseInfo('02570062-v', 0), SenseInfo('02567422-v', 0), SenseInfo('02565687-v', 0), SenseInfo('02019574-v', 0) ],
"_profile_n_1_rel" : [ SenseInfo('07002599-n', 10), SenseInfo('08613202-n', 3), SenseInfo('06516404-n', 1), SenseInfo('14434329-n', 0), SenseInfo('08548415-n', 0), SenseInfo('07002599-n', 10), SenseInfo('08613202-n', 3), SenseInfo('06516404-n', 1), SenseInfo('14434329-n', 0), SenseInfo('08548415-n', 0), SenseInfo('07002599-n', 10), SenseInfo('08613202-n', 3), SenseInfo('06516404-n', 1), SenseInfo('14434329-n', 0), SenseInfo('08548415-n', 0) ],
"_damp_n_1_rel" : [ SenseInfo('14535905-n', 0) ],
"_progenitor_n_1_rel" : [ SenseInfo('10126806-n', 0) ],
"_gradation_n_1_rel" : [ SenseInfo('14429608-n', 0), SenseInfo('07112282-n', 0), SenseInfo('01003729-n', 0) ],
"_read_v_1_rel" : [ SenseInfo('00625119-v', 115), SenseInfo('02730813-v', 17), SenseInfo('00626428-v', 15), SenseInfo('00627520-v', 5), SenseInfo('00627091-v', 5), SenseInfo('00624476-v', 5), SenseInfo('00599992-v', 4), SenseInfo('00922867-v', 3), SenseInfo('01718755-v', 0), SenseInfo('00620239-v', 0), SenseInfo('00593852-v', 0), SenseInfo('00625119-v', 115), SenseInfo('02730813-v', 17), SenseInfo('00626428-v', 15), SenseInfo('00627520-v', 5), SenseInfo('00627091-v', 5), SenseInfo('00624476-v', 5), SenseInfo('00599992-v', 4), SenseInfo('00922867-v', 3), SenseInfo('01718755-v', 0), SenseInfo('00620239-v', 0), SenseInfo('00593852-v', 0), SenseInfo('00625119-v', 115), SenseInfo('02730813-v', 17), SenseInfo('00626428-v', 15), SenseInfo('00627520-v', 5), SenseInfo('00627091-v', 5), SenseInfo('00624476-v', 5), SenseInfo('00599992-v', 4), SenseInfo('00922867-v', 3), SenseInfo('01718755-v', 0), SenseInfo('00620239-v', 0), SenseInfo('00593852-v', 0) ],
"_solstice_n_1_rel" : [ SenseInfo('15221818-n', 0) ],
"_willow_n_1_rel" : [ SenseInfo('12724942-n', 8), SenseInfo('04584794-n', 0) ],
"_dispensation_n_1_rel" : [ SenseInfo('01142014-n', 1), SenseInfo('13285714-n', 0), SenseInfo('01083504-n', 0) ],
"_might_v_modal_rel" : [ SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0) ],
"_blister_v_cause_rel" : [ SenseInfo('00379774-v', 2), SenseInfo('00863906-v', 0), SenseInfo('00379996-v', 0) ],
"_peddle_v_1_rel" : [ SenseInfo('02302817-v', 2) ],
"_allotment_n_1_rel" : [ SenseInfo('13289467-n', 44), SenseInfo('01083645-n', 1) ],
"_armed+forces_n_1_rel" : [ SenseInfo('08199025-n', 6), SenseInfo('08199025-n', 6) ],
"_rightful_a_1_rel" : [ SenseInfo('01370475-a', 1), SenseInfo('01407267-a', 0), SenseInfo('01370475-a', 1), SenseInfo('01407267-a', 0), SenseInfo('01370475-a', 1), SenseInfo('01407267-a', 0), SenseInfo('01370475-a', 1), SenseInfo('01407267-a', 0) ],
"_lewdness_n_1_rel" : [ SenseInfo('04903368-n', 0) ],
"_scout_v_out_rel" : [ SenseInfo('02167571-v', 2) ],
"_greatcoat_n_1_rel" : [ SenseInfo('03456665-n', 5) ],
"_happening_n_1_rel" : [ SenseInfo('07283608-n', 2) ],
"_switch_v_cause_rel" : [ SenseInfo('00140751-v', 5), SenseInfo('02259005-v', 3), SenseInfo('00550117-v', 2), SenseInfo('00380159-v', 1), SenseInfo('01510173-v', 0), SenseInfo('01411630-v', 0), SenseInfo('00121678-v', 0) ],
"_ad_p_temp_rel" : [ SenseInfo('07248801-n', 6), SenseInfo('00001837-r', 0), SenseInfo('07248801-n', 6), SenseInfo('00001837-r', 0), SenseInfo('07248801-n', 6), SenseInfo('00001837-r', 0), SenseInfo('07248801-n', 6), SenseInfo('00001837-r', 0), SenseInfo('07248801-n', 6), SenseInfo('00001837-r', 0) ],
"_locate_v_1_rel" : [ SenseInfo('02286204-v', 16), SenseInfo('02694933-v', 12), SenseInfo('02333689-v', 4), SenseInfo('00413876-v', 4), SenseInfo('02286204-v', 16), SenseInfo('02694933-v', 12), SenseInfo('02333689-v', 4), SenseInfo('00413876-v', 4) ],
"_steady_v_cause_rel" : [ SenseInfo('00416571-v', 2), SenseInfo('01219993-v', 1), SenseInfo('00416571-v', 2), SenseInfo('01219993-v', 1) ],
"_benefit_v_from_rel" : [ SenseInfo('02290461-v', 15), SenseInfo('02290956-v', 7) ],
"_budgerigar_n_1_rel" : [ SenseInfo('01821869-n', 0) ],
"_increment_n_1_rel" : [ SenseInfo('13497135-n', 0), SenseInfo('05108947-n', 0) ],
"_beige_a_1_rel" : [ SenseInfo('00370501-a', 0) ],
"_strawberry_n_1_rel" : [ SenseInfo('07745940-n', 1), SenseInfo('12630144-n', 0), SenseInfo('04696316-n', 0) ],
"_fog_v_up_rel" : [ SenseInfo('02157731-v', 0) ],
"_pick_n_of_rel" : [ SenseInfo('05790242-n', 1), SenseInfo('13759558-n', 0), SenseInfo('08387035-n', 0), SenseInfo('04598965-n', 0), SenseInfo('03929660-n', 0), SenseInfo('03929443-n', 0), SenseInfo('03929202-n', 0), SenseInfo('00563665-n', 0), SenseInfo('00161243-n', 0) ],
"_off-off_a_1_rel" : [  ],
"_foul_v_1_rel" : [ SenseInfo('01147855-v', 1), SenseInfo('00492706-v', 1), SenseInfo('01478603-v', 0), SenseInfo('01147709-v', 0), SenseInfo('00492410-v', 0), SenseInfo('00492310-v', 0), SenseInfo('00492225-v', 0) ],
"_demographic_a_1_rel" : [ SenseInfo('02906351-a', 0) ],
"_fjordscape_n_1_rel" : [  ],
"_president_n_of_rel" : [ SenseInfo('10468559-n', 14), SenseInfo('10467395-n', 5), SenseInfo('10467179-n', 5), SenseInfo('10468962-n', 3), SenseInfo('10468750-n', 3), SenseInfo('00597265-n', 1), SenseInfo('10468559-n', 14), SenseInfo('10467395-n', 5), SenseInfo('10467179-n', 5), SenseInfo('10468962-n', 3), SenseInfo('10468750-n', 3), SenseInfo('00597265-n', 1), SenseInfo('10468559-n', 14), SenseInfo('10467395-n', 5), SenseInfo('10467179-n', 5), SenseInfo('10468962-n', 3), SenseInfo('10468750-n', 3), SenseInfo('00597265-n', 1), SenseInfo('10468559-n', 14), SenseInfo('10467395-n', 5), SenseInfo('10467179-n', 5), SenseInfo('10468962-n', 3), SenseInfo('10468750-n', 3), SenseInfo('00597265-n', 1) ],
"_border_v_on_rel" : [ SenseInfo('01467370-v', 3), SenseInfo('02710673-v', 1), SenseInfo('01586850-v', 1), SenseInfo('02361600-v', 0), SenseInfo('01466978-v', 0) ],
"_garrison_v_1_rel" : [ SenseInfo('01089137-v', 1) ],
"_plug-in_n_1_rel" : [ SenseInfo('03033986-n', 0), SenseInfo('03033986-n', 0), SenseInfo('03033986-n', 0) ],
"_humble_a_1_rel" : [ SenseInfo('02340458-a', 3), SenseInfo('01892953-a', 1), SenseInfo('02229961-a', 0), SenseInfo('01592857-a', 0), SenseInfo('02340458-a', 3), SenseInfo('01892953-a', 1), SenseInfo('02229961-a', 0), SenseInfo('01592857-a', 0), SenseInfo('02340458-a', 3), SenseInfo('01892953-a', 1), SenseInfo('02229961-a', 0), SenseInfo('01592857-a', 0) ],
"_stuff_v_1_rel" : [ SenseInfo('01524871-v', 5), SenseInfo('02094569-v', 4), SenseInfo('01479333-v', 0), SenseInfo('01193099-v', 0), SenseInfo('00497555-v', 0), SenseInfo('00321148-v', 0), SenseInfo('00320681-v', 0) ],
"_slimy_a_1_rel" : [ SenseInfo('02235826-a', 0), SenseInfo('01133017-a', 0), SenseInfo('02235826-a', 0), SenseInfo('01133017-a', 0), SenseInfo('02235826-a', 0), SenseInfo('01133017-a', 0) ],
"_ground_n_1_rel" : [ SenseInfo('09334396-n', 86), SenseInfo('09178999-n', 11), SenseInfo('14842992-n', 7), SenseInfo('13790912-n', 1), SenseInfo('08580134-n', 1), SenseInfo('05933834-n', 1), SenseInfo('09335240-n', 0), SenseInfo('05930574-n', 0), SenseInfo('03462747-n', 0), SenseInfo('03462594-n', 0), SenseInfo('03360845-n', 0), SenseInfo('09334396-n', 86), SenseInfo('09178999-n', 11), SenseInfo('14842992-n', 7), SenseInfo('13790912-n', 1), SenseInfo('08580134-n', 1), SenseInfo('05933834-n', 1), SenseInfo('09335240-n', 0), SenseInfo('05930574-n', 0), SenseInfo('03462747-n', 0), SenseInfo('03462594-n', 0), SenseInfo('03360845-n', 0) ],
"_ease_n_1_rel" : [ SenseInfo('04708113-n', 1), SenseInfo('14491889-n', 0), SenseInfo('14445749-n', 0), SenseInfo('04786994-n', 0), SenseInfo('01064148-n', 0), SenseInfo('04708113-n', 1), SenseInfo('14491889-n', 0), SenseInfo('14445749-n', 0), SenseInfo('04786994-n', 0), SenseInfo('01064148-n', 0) ],
"_annular_a_1_rel" : [ SenseInfo('02044860-a', 0) ],
"_toad_n_1_rel" : [ SenseInfo('01639765-n', 4) ],
"_prudent_a_for_rel" : [ SenseInfo('01898129-a', 0), SenseInfo('01898129-a', 0), SenseInfo('01898129-a', 0) ],
"_budge_v_1_rel" : [ SenseInfo('01893988-v', 3) ],
"_nibble_v_1_rel" : [ SenseInfo('01446729-v', 0), SenseInfo('01446420-v', 0), SenseInfo('01174294-v', 0) ],
"_shiny_a_1_rel" : [ SenseInfo('00281657-a', 2), SenseInfo('01119421-a', 0), SenseInfo('01812237-a', 0), SenseInfo('00281657-a', 2), SenseInfo('01119421-a', 0), SenseInfo('01812237-a', 0), SenseInfo('00281657-a', 2), SenseInfo('01119421-a', 0), SenseInfo('01812237-a', 0) ],
"_so+much+so+that_x_rel" : [  ],
"_mean_v_1_rel" : [ SenseInfo('00955148-v', 93), SenseInfo('02635189-v', 89), SenseInfo('00931852-v', 43), SenseInfo('00708538-v', 27), SenseInfo('02742482-v', 9), SenseInfo('00730052-v', 8), SenseInfo('00708840-v', 0), SenseInfo('00955148-v', 93), SenseInfo('02635189-v', 89), SenseInfo('00931852-v', 43), SenseInfo('00708538-v', 27), SenseInfo('02742482-v', 9), SenseInfo('00730052-v', 8), SenseInfo('00708840-v', 0), SenseInfo('00955148-v', 93), SenseInfo('02635189-v', 89), SenseInfo('00931852-v', 43), SenseInfo('00708538-v', 27), SenseInfo('02742482-v', 9), SenseInfo('00730052-v', 8), SenseInfo('00708840-v', 0), SenseInfo('00955148-v', 93), SenseInfo('02635189-v', 89), SenseInfo('00931852-v', 43), SenseInfo('00708538-v', 27), SenseInfo('02742482-v', 9), SenseInfo('00730052-v', 8), SenseInfo('00708840-v', 0), SenseInfo('00955148-v', 93), SenseInfo('02635189-v', 89), SenseInfo('00931852-v', 43), SenseInfo('00708538-v', 27), SenseInfo('02742482-v', 9), SenseInfo('00730052-v', 8), SenseInfo('00708840-v', 0), SenseInfo('00955148-v', 93), SenseInfo('02635189-v', 89), SenseInfo('00931852-v', 43), SenseInfo('00708538-v', 27), SenseInfo('02742482-v', 9), SenseInfo('00730052-v', 8), SenseInfo('00708840-v', 0), SenseInfo('00955148-v', 93), SenseInfo('02635189-v', 89), SenseInfo('00931852-v', 43), SenseInfo('00708538-v', 27), SenseInfo('02742482-v', 9), SenseInfo('00730052-v', 8), SenseInfo('00708840-v', 0) ],
"_provide_v_for_rel" : [ SenseInfo('02327200-v', 270), SenseInfo('01182709-v', 25), SenseInfo('01063188-v', 14), SenseInfo('02376289-v', 2), SenseInfo('02721438-v', 0), SenseInfo('02219442-v', 0), SenseInfo('00406963-v', 0) ],
"_academic_n_1_rel" : [ SenseInfo('09759069-n', 2) ],
"_integrity_n_1_rel" : [ SenseInfo('14460565-n', 3), SenseInfo('04869569-n', 1) ],
"_livestock_n_1_rel" : [ SenseInfo('01887474-n', 8) ],
"_psyche_v_out_rel" : [  ],
"_shoe_v_1_rel" : [ SenseInfo('00049770-v', 0) ],
"_chortle_v_to_rel" : [ SenseInfo('00031663-v', 4), SenseInfo('00031663-v', 4) ],
"_faker_n_1_rel" : [ SenseInfo('10201535-n', 1) ],
"_eye_n_1_rel" : [ SenseInfo('05311054-n', 263), SenseInfo('05614476-n', 8), SenseInfo('05703307-n', 6), SenseInfo('08523483-n', 0), SenseInfo('03308297-n', 0) ],
"_marking_n_1_rel" : [ SenseInfo('07270179-n', 1), SenseInfo('04680285-n', 1), SenseInfo('00874977-n', 0), SenseInfo('00263642-n', 0) ],
"_complement_v_1_rel" : [ SenseInfo('00455919-v', 3) ],
"_code_v_up_rel" : [ SenseInfo('01589723-v', 1), SenseInfo('00994076-v', 0) ],
"_node_n_1_rel" : [ SenseInfo('13911045-n', 0), SenseInfo('13895986-n', 0), SenseInfo('13154190-n', 0), SenseInfo('08498580-n', 0), SenseInfo('08498424-n', 0), SenseInfo('05430095-n', 0), SenseInfo('05264913-n', 0), SenseInfo('03827107-n', 0) ],
"_part-of_a_1_rel" : [  ],
"_money+market_n_1_rel" : [ SenseInfo('08073601-n', 0), SenseInfo('08073601-n', 0), SenseInfo('08073601-n', 0) ],
"_flattery_n_1_rel" : [ SenseInfo('06695579-n', 2) ],
"_retire_v_1_rel" : [ SenseInfo('02379753-v', 18), SenseInfo('02380009-v', 7), SenseInfo('01994442-v', 2), SenseInfo('02480448-v', 1), SenseInfo('02428487-v', 1), SenseInfo('02380251-v', 1), SenseInfo('02225342-v', 1), SenseInfo('01766952-v', 0), SenseInfo('01615457-v', 0), SenseInfo('01154175-v', 0), SenseInfo('00017865-v', 0) ],
"_insane_a_1_rel" : [ SenseInfo('02074092-a', 11), SenseInfo('02572038-a', 1), SenseInfo('02074092-a', 11), SenseInfo('02572038-a', 1), SenseInfo('02074092-a', 11), SenseInfo('02572038-a', 1) ],
"_part-time_a_1_rel" : [ SenseInfo('01089369-a', 21), SenseInfo('01089369-a', 21), SenseInfo('01089369-a', 21), SenseInfo('01089369-a', 21), SenseInfo('01089369-a', 21), SenseInfo('01089369-a', 21) ],
"_limpidity_n_1_rel" : [ SenseInfo('04820258-n', 0), SenseInfo('04701943-n', 0) ],
"_anti-Semitic_a_1_rel" : [ SenseInfo('03043482-a', 4), SenseInfo('03043482-a', 4) ],
"_embolden_v_1_rel" : [ SenseInfo('01817938-v', 1) ],
"_zip_v_1_rel" : [ SenseInfo('01353670-v', 1), SenseInfo('02055649-v', 0), SenseInfo('01353670-v', 1), SenseInfo('02055649-v', 0) ],
"_ask_v_in_rel" : [ SenseInfo('00784342-v', 244), SenseInfo('00752493-v', 165), SenseInfo('00784727-v', 16), SenseInfo('00755745-v', 2), SenseInfo('00897746-v', 1), SenseInfo('02627934-v', 0), SenseInfo('01068565-v', 0) ],
"_banker_n_1_rel" : [ SenseInfo('09837824-n', 9), SenseInfo('09837720-n', 0) ],
"_archeology_n_1_rel" : [ SenseInfo('06144081-n', 0) ],
"_solmization_n_1_rel" : [ SenseInfo('06867675-n', 0), SenseInfo('01255935-n', 0) ],
"_british_n_1_rel" : [ SenseInfo('09732544-n', 3), SenseInfo('09732544-n', 3), SenseInfo('09732544-n', 3) ],
"_live_v_up2_rel" : [ SenseInfo('02649830-v', 129), SenseInfo('02614387-v', 51), SenseInfo('02618149-v', 29), SenseInfo('02616713-v', 16), SenseInfo('02614181-v', 14), SenseInfo('00596644-v', 1), SenseInfo('02614970-v', 0), SenseInfo('02649830-v', 129), SenseInfo('02614387-v', 51), SenseInfo('02618149-v', 29), SenseInfo('02616713-v', 16), SenseInfo('02614181-v', 14), SenseInfo('00596644-v', 1), SenseInfo('02614970-v', 0) ],
"_drown_v_out_rel" : [ SenseInfo('01339294-v', 3), SenseInfo('00472532-v', 2), SenseInfo('00360501-v', 2), SenseInfo('00479060-v', 1), SenseInfo('02755911-v', 0) ],
"_boil_v_over_rel" : [ SenseInfo('00375021-v', 4), SenseInfo('00328128-v', 4), SenseInfo('00374668-v', 3), SenseInfo('01885430-v', 0), SenseInfo('01767612-v', 0) ],
"_reform_v_1_rel" : [ SenseInfo('00265386-v', 1), SenseInfo('00384620-v', 0), SenseInfo('00266081-v', 0), SenseInfo('00265941-v', 0), SenseInfo('00265673-v', 0), SenseInfo('00167934-v', 0) ],
"_bare_a_of_rel" : [ SenseInfo('00457998-a', 2), SenseInfo('00106821-a', 2), SenseInfo('02155524-a', 0), SenseInfo('01698400-a', 0), SenseInfo('02563466-a', 0), SenseInfo('01792573-a', 0), SenseInfo('01714157-a', 0), SenseInfo('01242750-a', 0), SenseInfo('01086915-a', 0), SenseInfo('00060605-a', 0) ],
"_applicability_n_1_rel" : [ SenseInfo('13795180-n', 2) ],
"_upside_n_1_rel" : [ SenseInfo('08663354-n', 0) ],
"_complex_n_of_rel" : [ SenseInfo('05870365-n', 6), SenseInfo('14817592-n', 1), SenseInfo('07482521-n', 0), SenseInfo('02914991-n', 0) ],
"_scowl_n_1_rel" : [ SenseInfo('06877849-n', 1) ],
"_setter_n_1_rel" : [ SenseInfo('09949946-n', 0), SenseInfo('02100399-n', 0) ],
"_employee_n_of_rel" : [ SenseInfo('10053808-n', 57) ],
"_every+so+often_a_1_rel" : [  ],
"_spore_n_1_rel" : [ SenseInfo('11547855-n', 2) ],
"_droplet_n_1_rel" : [ SenseInfo('13771828-n', 3) ],
"_kanji_n_1_rel" : [  ],
"_pick_v_on_rel" : [ SenseInfo('00676450-v', 13), SenseInfo('01382083-v', 4), SenseInfo('00842772-v', 2), SenseInfo('01647131-v', 1), SenseInfo('00178102-v', 1), SenseInfo('00177714-v', 1), SenseInfo('02321648-v', 0), SenseInfo('02287209-v', 0), SenseInfo('01452546-v', 0), SenseInfo('01442578-v', 0), SenseInfo('01243474-v', 0), SenseInfo('01174294-v', 0) ],
"_flax_n_1_rel" : [ SenseInfo('14869829-n', 0), SenseInfo('12486574-n', 0) ],
"_banana_n_1_rel" : [ SenseInfo('12352287-n', 1), SenseInfo('07753592-n', 1) ],
"_solidarity_n_1_rel" : [ SenseInfo('04765038-n', 5) ],
"_sour_v_cause_rel" : [ SenseInfo('00458471-v', 2), SenseInfo('02196690-v', 1) ],
"_motive_n_1_rel" : [ SenseInfo('00023773-n', 18), SenseInfo('07029682-n', 0), SenseInfo('03789014-n', 0) ],
"_gong_n_1_rel" : [ SenseInfo('03447721-n', 0), SenseInfo('03017168-n', 0) ],
"_ageing_n_1_rel" : [ SenseInfo('13551965-n', 0), SenseInfo('13429006-n', 0) ],
"_dust-up_n_1_rel" : [ SenseInfo('07184149-n', 0) ],
"_eat_v_1_rel" : [ SenseInfo('01168468-v', 61), SenseInfo('01166351-v', 13), SenseInfo('01179865-v', 4), SenseInfo('01766273-v', 0), SenseInfo('01157517-v', 0), SenseInfo('00274283-v', 0) ],
"_dense_a_1_rel" : [ SenseInfo('02416390-a', 4), SenseInfo('01771839-a', 1), SenseInfo('01185264-a', 1), SenseInfo('00440579-a', 0), SenseInfo('02416390-a', 4), SenseInfo('01771839-a', 1), SenseInfo('01185264-a', 1), SenseInfo('00440579-a', 0), SenseInfo('02416390-a', 4), SenseInfo('01771839-a', 1), SenseInfo('01185264-a', 1), SenseInfo('00440579-a', 0), SenseInfo('02416390-a', 4), SenseInfo('01771839-a', 1), SenseInfo('01185264-a', 1), SenseInfo('00440579-a', 0) ],
"_minor_n_1_rel" : [ SenseInfo('09917593-n', 2) ],
"_flavor_n_1_rel" : [ SenseInfo('14526182-n', 3), SenseInfo('05715864-n', 3), SenseInfo('05844282-n', 0) ],
"_phase_n_of_rel" : [ SenseInfo('15290337-n', 24), SenseInfo('14480065-n', 22), SenseInfo('15290132-n', 1), SenseInfo('04676540-n', 0) ],
"_savor_v_1_rel" : [ SenseInfo('01820302-v', 4), SenseInfo('02194286-v', 1), SenseInfo('02193974-v', 1), SenseInfo('02194138-v', 0), SenseInfo('01820302-v', 4), SenseInfo('02194286-v', 1), SenseInfo('02193974-v', 1), SenseInfo('02194138-v', 0), SenseInfo('01820302-v', 4), SenseInfo('02194286-v', 1), SenseInfo('02193974-v', 1), SenseInfo('02194138-v', 0) ],
"_knee_n_1_rel" : [ SenseInfo('05573602-n', 51), SenseInfo('02464065-n', 3), SenseInfo('03622698-n', 1) ],
"_mouth-up_a_1_rel" : [  ],
"_greater+than_x_rel" : [  ],
"_generalize_v_cause_rel" : [ SenseInfo('01022420-v', 6), SenseInfo('01022906-v', 0), SenseInfo('00970215-v', 0), SenseInfo('00104465-v', 0) ],
"_reciprocal_a_1_rel" : [ SenseInfo('01945550-a', 7), SenseInfo('00769761-a', 0), SenseInfo('01945550-a', 7), SenseInfo('00769761-a', 0) ],
"_factor_v_in_rel" : [ SenseInfo('00640385-v', 2), SenseInfo('02324901-v', 0), SenseInfo('00640650-v', 0), SenseInfo('00640385-v', 2), SenseInfo('02324901-v', 0), SenseInfo('00640650-v', 0) ],
"_prune_v_1_rel" : [ SenseInfo('01321002-v', 0), SenseInfo('00473322-v', 0) ],
"_swipe_v_1_rel" : [ SenseInfo('01394200-v', 1), SenseInfo('02276866-v', 0) ],
"_brownish_a_1_rel" : [ SenseInfo('00372111-a', 1) ],
"_inductive_a_1_rel" : [ SenseInfo('02748421-a', 0), SenseInfo('01296270-a', 0), SenseInfo('00324013-a', 0), SenseInfo('02748421-a', 0), SenseInfo('01296270-a', 0), SenseInfo('00324013-a', 0) ],
"_high-yield_a_1_rel" : [ SenseInfo('01081917-a', 0), SenseInfo('01081917-a', 0) ],
"_inverse_n_1_rel" : [ SenseInfo('13858833-n', 0) ],
"_nun_n_1_rel" : [ SenseInfo('10368009-n', 3), SenseInfo('07266879-n', 0), SenseInfo('06838112-n', 0) ],
"_liquid_n_1_rel" : [ SenseInfo('14940386-n', 6), SenseInfo('14480420-n', 5), SenseInfo('14940100-n', 4), SenseInfo('07119643-n', 0) ],
"_best+of+all_a_1_rel" : [  ],
"_breed_v_1_rel" : [ SenseInfo('01649024-v', 1), SenseInfo('01430447-v', 1), SenseInfo('01429455-v', 0), SenseInfo('00056334-v', 0) ],
"_bridge_n_1_rel" : [ SenseInfo('02898711-n', 4), SenseInfo('02899808-n', 3), SenseInfo('13793330-n', 2), SenseInfo('05599203-n', 1), SenseInfo('00490569-n', 1), SenseInfo('02899694-n', 0), SenseInfo('02899569-n', 0), SenseInfo('02899439-n', 0), SenseInfo('02899257-n', 0), SenseInfo('02898711-n', 4), SenseInfo('02899808-n', 3), SenseInfo('13793330-n', 2), SenseInfo('05599203-n', 1), SenseInfo('00490569-n', 1), SenseInfo('02899694-n', 0), SenseInfo('02899569-n', 0), SenseInfo('02899439-n', 0), SenseInfo('02899257-n', 0) ],
"_mob_n_1_rel" : [ SenseInfo('08184600-n', 11), SenseInfo('08246302-n', 1), SenseInfo('08244062-n', 0) ],
"_unendurable_a_1_rel" : [ SenseInfo('02435671-a', 0), SenseInfo('02435671-a', 0) ],
"_tire_v_of_rel" : [ SenseInfo('00076114-v', 3), SenseInfo('00075021-v', 3), SenseInfo('02280869-v', 0), SenseInfo('01821884-v', 0) ],
"_up+to_x_deg_rel" : [ SenseInfo('00294056-a', 3), SenseInfo('00051373-a', 2), SenseInfo('00294056-a', 3), SenseInfo('00051373-a', 2) ],
"_tuberculosis_n_1_rel" : [ SenseInfo('14143415-n', 4) ],
"_unseasonable_a_1_rel" : [ SenseInfo('01494740-a', 0), SenseInfo('01662119-a', 0), SenseInfo('01494740-a', 0), SenseInfo('01662119-a', 0), SenseInfo('01494740-a', 0), SenseInfo('01662119-a', 0) ],
"_bazaar_n_1_rel" : [ SenseInfo('02813544-n', 1), SenseInfo('02813645-n', 0), SenseInfo('01118182-n', 0), SenseInfo('02813544-n', 1), SenseInfo('02813645-n', 0), SenseInfo('01118182-n', 0) ],
"_manacle_v_1_rel" : [ SenseInfo('01288201-v', 0) ],
"_plead_v_with-for_rel" : [ SenseInfo('00759501-v', 10), SenseInfo('00894365-v', 4), SenseInfo('00760576-v', 4), SenseInfo('01016316-v', 1), SenseInfo('00759501-v', 10), SenseInfo('00894365-v', 4), SenseInfo('00760576-v', 4), SenseInfo('01016316-v', 1), SenseInfo('00759501-v', 10), SenseInfo('00894365-v', 4), SenseInfo('00760576-v', 4), SenseInfo('01016316-v', 1), SenseInfo('00759501-v', 10), SenseInfo('00894365-v', 4), SenseInfo('00760576-v', 4), SenseInfo('01016316-v', 1), SenseInfo('00759501-v', 10), SenseInfo('00894365-v', 4), SenseInfo('00760576-v', 4), SenseInfo('01016316-v', 1) ],
"_driver_n_of_rel" : [ SenseInfo('10034906-n', 17), SenseInfo('10035430-n', 0), SenseInfo('10035314-n', 0), SenseInfo('06574473-n', 0), SenseInfo('03244047-n', 0) ],
"_onto_p_sel_rel" : [  ],
"_much_x_deg_rel" : [ SenseInfo('01553629-a', 137), SenseInfo('00059086-r', 95), SenseInfo('13776621-n', 54), SenseInfo('00032803-r', 17), SenseInfo('00059171-r', 10), SenseInfo('00022829-r', 9), SenseInfo('00059413-r', 6), SenseInfo('01553629-a', 137), SenseInfo('00059086-r', 95), SenseInfo('13776621-n', 54), SenseInfo('00032803-r', 17), SenseInfo('00059171-r', 10), SenseInfo('00022829-r', 9), SenseInfo('00059413-r', 6) ],
"_redouble_v_1_rel" : [ SenseInfo('00290581-v', 2), SenseInfo('00246475-v', 0), SenseInfo('00227042-v', 0) ],
"_polymerize_v_1_rel" : [ SenseInfo('00266586-v', 0), SenseInfo('00266197-v', 0) ],
"_imply_v_1_rel" : [ SenseInfo('00929839-v', 17), SenseInfo('00930599-v', 14), SenseInfo('02635189-v', 1), SenseInfo('02636921-v', 0), SenseInfo('02636132-v', 0), SenseInfo('00929839-v', 17), SenseInfo('00930599-v', 14), SenseInfo('02635189-v', 1), SenseInfo('02636921-v', 0), SenseInfo('02636132-v', 0), SenseInfo('00929839-v', 17), SenseInfo('00930599-v', 14), SenseInfo('02635189-v', 1), SenseInfo('02636921-v', 0), SenseInfo('02636132-v', 0) ],
"_ashamed_a_of_rel" : [ SenseInfo('00153898-a', 5), SenseInfo('00153898-a', 5), SenseInfo('00153898-a', 5) ],
"_for+example_a_1_rel" : [  ],
"_slip_v_2_rel" : [ SenseInfo('01888295-v', 11), SenseInfo('00189669-v', 7), SenseInfo('01870275-v', 6), SenseInfo('00204391-v', 4), SenseInfo('02076280-v', 2), SenseInfo('00617748-v', 1), SenseInfo('02231328-v', 0), SenseInfo('02105549-v', 0), SenseInfo('02076501-v', 0), SenseInfo('00608978-v', 0), SenseInfo('00465762-v', 0) ],
"_adjust_v_1_rel" : [ SenseInfo('00296178-v', 19), SenseInfo('00464321-v', 6), SenseInfo('00150287-v', 6), SenseInfo('00298067-v', 2), SenseInfo('00699334-v', 0) ],
"_assembly_n_of_rel" : [ SenseInfo('02749790-n', 3), SenseInfo('00912001-n', 3), SenseInfo('03386420-n', 1), SenseInfo('08163792-n', 0), SenseInfo('02749953-n', 0), SenseInfo('01229938-n', 0) ],
"_floss_v_1_rel" : [ SenseInfo('00041866-v', 0) ],
"_wreak_v_1_rel" : [ SenseInfo('01629589-v', 1) ],
"_blank_a_1_rel" : [ SenseInfo('01087093-a', 1), SenseInfo('00500889-a', 1), SenseInfo('01425056-a', 0), SenseInfo('01087093-a', 1), SenseInfo('00500889-a', 1), SenseInfo('01425056-a', 0), SenseInfo('01087093-a', 1), SenseInfo('00500889-a', 1), SenseInfo('01425056-a', 0) ],
"_although_p_rel" : [  ],
"_nester_n_1_rel" : [ SenseInfo('10643218-n', 0), SenseInfo('01514926-n', 0) ],
"_overheat_v_1_rel" : [ SenseInfo('00370263-v', 1), SenseInfo('00372501-v', 0), SenseInfo('00370263-v', 1), SenseInfo('00372501-v', 0) ],
"_comprehensive_a_1_rel" : [ SenseInfo('00525453-a', 8), SenseInfo('01863970-a', 0) ],
"_strew_v_1_rel" : [ SenseInfo('01378123-v', 4), SenseInfo('01208896-v', 1) ],
"_diversion_n_of_rel" : [ SenseInfo('00426928-n', 2), SenseInfo('00350380-n', 2), SenseInfo('00975270-n', 1) ],
"_goddamn_a_1_rel" : [ SenseInfo('00670530-a', 4), SenseInfo('00669942-a', 0) ],
"_medal_n_for_rel" : [ SenseInfo('06706676-n', 4) ],
"_mouth_v_1_rel" : [ SenseInfo('00941990-v', 3), SenseInfo('01040707-v', 1), SenseInfo('01432474-v', 0) ],
"_annal_n_1_rel" : [  ],
"_swath_n_1_rel" : [ SenseInfo('13778907-n', 0), SenseInfo('09452653-n', 0) ],
"_fuck_a_1_rel" : [ SenseInfo('00846021-n', 0), SenseInfo('00846021-n', 0) ],
"_broker_n_1_rel" : [ SenseInfo('09777012-n', 1) ],
"_alert_n_1_rel" : [ SenseInfo('14031660-n', 0), SenseInfo('07224774-n', 0), SenseInfo('06803157-n', 0) ],
"_cry_v_to_rel" : [ SenseInfo('00913065-v', 17), SenseInfo('00066191-v', 12), SenseInfo('00912048-v', 11), SenseInfo('00974786-v', 2), SenseInfo('01188987-v', 0), SenseInfo('00985464-v', 0), SenseInfo('00066685-v', 0), SenseInfo('00913065-v', 17), SenseInfo('00066191-v', 12), SenseInfo('00912048-v', 11), SenseInfo('00974786-v', 2), SenseInfo('01188987-v', 0), SenseInfo('00985464-v', 0), SenseInfo('00066685-v', 0) ],
"_alcohol_n_1_rel" : [ SenseInfo('07884567-n', 3), SenseInfo('14708720-n', 0) ],
"_summarize_v_1_rel" : [ SenseInfo('01007924-v', 9), SenseInfo('02752695-v', 0), SenseInfo('01007924-v', 9), SenseInfo('02752695-v', 0) ],
"_on-again_a_1_rel" : [  ],
"_lightning_n_1_rel" : [ SenseInfo('11475279-n', 8), SenseInfo('07412993-n', 3) ],
"_settle_v_in_rel" : [ SenseInfo('01988458-v', 16), SenseInfo('00698855-v', 10), SenseInfo('00763399-v', 8), SenseInfo('00413876-v', 7), SenseInfo('00764902-v', 5), SenseInfo('01989873-v', 4), SenseInfo('00415398-v', 3), SenseInfo('00558673-v', 2), SenseInfo('00539338-v', 2), SenseInfo('01987058-v', 1), SenseInfo('01465921-v', 1), SenseInfo('00798091-v', 1), SenseInfo('00764032-v', 1), SenseInfo('02254258-v', 0), SenseInfo('01986715-v', 0), SenseInfo('01986551-v', 0), SenseInfo('01986185-v', 0), SenseInfo('01493619-v', 0), SenseInfo('01092128-v', 0), SenseInfo('00481941-v', 0), SenseInfo('00415044-v', 0), SenseInfo('00342164-v', 0) ],
"_cowbell_n_1_rel" : [ SenseInfo('03123917-n', 0) ],
"_mutate_v_1_rel" : [ SenseInfo('00119873-v', 0) ],
"_diarrhoea_n_1_rel" : [ SenseInfo('14371913-n', 3) ],
"_vein_n_1_rel" : [ SenseInfo('05418717-n', 8), SenseInfo('07089622-n', 5), SenseInfo('13098186-n', 0), SenseInfo('09470222-n', 0), SenseInfo('02468735-n', 0) ],
"_strangle_v_1_rel" : [ SenseInfo('01570935-v', 4), SenseInfo('01568630-v', 0), SenseInfo('00359405-v', 0), SenseInfo('00236289-v', 0), SenseInfo('00077950-v', 0), SenseInfo('00077698-v', 0) ],
"_hungarian_n_1_rel" : [ SenseInfo('09713985-n', 0), SenseInfo('06958836-n', 0) ],
"_lotion_n_1_rel" : [ SenseInfo('03690938-n', 1), SenseInfo('03691128-n', 0) ],
"_frugal_a_1_rel" : [ SenseInfo('02421364-a', 0), SenseInfo('02421364-a', 0) ],
"_certain_a_about_rel" : [ SenseInfo('00700884-a', 131), SenseInfo('00336831-a', 16), SenseInfo('00335421-a', 8), SenseInfo('00340239-a', 4), SenseInfo('02087342-a', 0), SenseInfo('00724397-a', 0), SenseInfo('00309740-a', 0) ],
"_draw_v_forth_rel" : [ SenseInfo('01448100-v', 13), SenseInfo('02293148-v', 10), SenseInfo('01582645-v', 10), SenseInfo('00730758-v', 10), SenseInfo('01995211-v', 9), SenseInfo('01690294-v', 7), SenseInfo('01854132-v', 6), SenseInfo('00987071-v', 6), SenseInfo('00675901-v', 6), SenseInfo('01760300-v', 5), SenseInfo('01199009-v', 5), SenseInfo('02088107-v', 4), SenseInfo('02311387-v', 3), SenseInfo('01078050-v', 3), SenseInfo('01643297-v', 2), SenseInfo('00556593-v', 2), SenseInfo('02097800-v', 1), SenseInfo('01690816-v', 1), SenseInfo('01643464-v', 1), SenseInfo('01243148-v', 1), SenseInfo('02742107-v', 0), SenseInfo('02628832-v', 0), SenseInfo('02483564-v', 0), SenseInfo('02103162-v', 0), SenseInfo('01539063-v', 0), SenseInfo('01505254-v', 0), SenseInfo('01359432-v', 0), SenseInfo('01243298-v', 0), SenseInfo('01212230-v', 0), SenseInfo('01115190-v', 0), SenseInfo('00476965-v', 0), SenseInfo('00430808-v', 0), SenseInfo('00327982-v', 0), SenseInfo('00197590-v', 0), SenseInfo('00143338-v', 0), SenseInfo('00097029-v', 0) ],
"_year-earlier_a_1_rel" : [  ],
"_absence_n_1_rel" : [ SenseInfo('13960974-n', 25), SenseInfo('01234345-n', 8), SenseInfo('15270862-n', 0), SenseInfo('14088412-n', 0) ],
"_pantomime_n_1_rel" : [ SenseInfo('00550016-n', 1) ],
"_quarantine_v_1_rel" : [ SenseInfo('00496266-v', 0) ],
"_manipulate_v_1_rel" : [ SenseInfo('02536329-v', 5), SenseInfo('01211699-v', 3), SenseInfo('02576921-v', 0), SenseInfo('02351239-v', 0), SenseInfo('01803936-v', 0), SenseInfo('00080929-v', 0) ],
"_altogether_x_rel" : [ SenseInfo('00008007-r', 11), SenseInfo('00063630-r', 1), SenseInfo('14456586-n', 0), SenseInfo('00151755-r', 0) ],
"_all+and+sundry_n_1_rel" : [  ],
"_grandma_n_1_rel" : [ SenseInfo('10142747-n', 2) ],
"_threaten_v_1_rel" : [ SenseInfo('02697120-v', 23), SenseInfo('00871405-v', 21), SenseInfo('00871781-v', 10), SenseInfo('02697120-v', 23), SenseInfo('00871405-v', 21), SenseInfo('00871781-v', 10), SenseInfo('02697120-v', 23), SenseInfo('00871405-v', 21), SenseInfo('00871781-v', 10) ],
"_go_v_along_rel" : [ SenseInfo('01835496-v', 343), SenseInfo('02372605-v', 95), SenseInfo('01848718-v', 49), SenseInfo('00149583-v', 29), SenseInfo('02653862-v', 14), SenseInfo('02721284-v', 10), SenseInfo('02685951-v', 10), SenseInfo('00341560-v', 10), SenseInfo('00359916-v', 9), SenseInfo('02618001-v', 7), SenseInfo('02176268-v', 3), SenseInfo('01525666-v', 3), SenseInfo('01192773-v', 3), SenseInfo('00539110-v', 3), SenseInfo('02618149-v', 2), SenseInfo('02617798-v', 2), SenseInfo('00358431-v', 2), SenseInfo('02737876-v', 1), SenseInfo('02729819-v', 1), SenseInfo('01864230-v', 1), SenseInfo('01076615-v', 1), SenseInfo('02700772-v', 0), SenseInfo('02700666-v', 0), SenseInfo('02700455-v', 0), SenseInfo('02686471-v', 0), SenseInfo('02659763-v', 0), SenseInfo('01318849-v', 0), SenseInfo('01192992-v', 0), SenseInfo('00676267-v', 0), SenseInfo('00434374-v', 0) ],
"_arena_n_1_rel" : [ SenseInfo('14514039-n', 1), SenseInfo('08497107-n', 0), SenseInfo('04295881-n', 0), SenseInfo('02736511-n', 0), SenseInfo('14514039-n', 1), SenseInfo('08497107-n', 0), SenseInfo('04295881-n', 0), SenseInfo('02736511-n', 0) ],
"_equities_n_1_rel" : [ SenseInfo('13333696-n', 1), SenseInfo('13333420-n', 0), SenseInfo('04839154-n', 0) ],
"_all+too_x_deg_rel" : [ SenseInfo('00250258-r', 8) ],
"_brazilian_n_1_rel" : [ SenseInfo('09694894-n', 0) ],
"_gauge_n_1_rel" : [ SenseInfo('03429288-n', 1), SenseInfo('13854101-n', 0), SenseInfo('05130028-n', 0), SenseInfo('05103430-n', 0), SenseInfo('05103283-n', 0) ],
"_sluggish_a_1_rel" : [ SenseInfo('00981703-a', 2), SenseInfo('00036998-a', 0), SenseInfo('00034322-a', 0), SenseInfo('00981703-a', 2), SenseInfo('00036998-a', 0), SenseInfo('00034322-a', 0) ],
"_declination_n_1_rel" : [ SenseInfo('14422488-n', 0), SenseInfo('09265620-n', 0), SenseInfo('08632894-n', 0), SenseInfo('06634239-n', 0) ],
"_cool_n_of_rel" : [ SenseInfo('05016001-n', 0), SenseInfo('04904162-n', 0), SenseInfo('05016001-n', 0), SenseInfo('04904162-n', 0) ],
"_density_n_1_rel" : [ SenseInfo('04941453-n', 15), SenseInfo('05088804-n', 2) ],
"_banking_n_1_rel" : [ SenseInfo('01100658-n', 0), SenseInfo('01100273-n', 0) ],
"_tip_n_1_rel" : [ SenseInfo('08663156-n', 9), SenseInfo('13298701-n', 3), SenseInfo('06651577-n', 3), SenseInfo('13902482-n', 0), SenseInfo('08617963-n', 0), SenseInfo('08663156-n', 9), SenseInfo('13298701-n', 3), SenseInfo('06651577-n', 3), SenseInfo('13902482-n', 0), SenseInfo('08617963-n', 0) ],
"_mycosis_n_1_rel" : [ SenseInfo('14176895-n', 0) ],
"_short+sleeved_a_1_rel" : [  ],
"_partnership_n_1_rel" : [ SenseInfo('08060694-n', 5), SenseInfo('13781348-n', 0), SenseInfo('06526291-n', 0) ],
"_child_n_1_rel" : [ SenseInfo('09917593-n', 148), SenseInfo('09918248-n', 65), SenseInfo('09918554-n', 1), SenseInfo('09918762-n', 0) ],
"_cleric_n_1_rel" : [ SenseInfo('09928136-n', 1) ],
"_parade_n_of_rel" : [ SenseInfo('08428485-n', 3), SenseInfo('08460395-n', 1), SenseInfo('00521085-n', 0), SenseInfo('08428485-n', 3), SenseInfo('08460395-n', 1), SenseInfo('00521085-n', 0) ],
"_ford_n_1_rel" : [ SenseInfo('10975304-n', 0), SenseInfo('10975202-n', 0), SenseInfo('10975101-n', 0), SenseInfo('10974971-n', 0), SenseInfo('10974740-n', 0), SenseInfo('10974592-n', 0), SenseInfo('09283623-n', 0), SenseInfo('00297657-n', 0) ],
"_irish_a_1_rel" : [ SenseInfo('03003744-a', 14) ],
"_clockwise_a_1_rel" : [ SenseInfo('00441781-a', 1) ],
"_bring_v_out_rel" : [ SenseInfo('02077656-v', 122), SenseInfo('01438902-v', 55), SenseInfo('01629589-v', 31), SenseInfo('01433294-v', 19), SenseInfo('00135857-v', 9), SenseInfo('01434140-v', 4), SenseInfo('01618547-v', 3), SenseInfo('02324478-v', 2), SenseInfo('02247390-v', 1), SenseInfo('01808218-v', 0), SenseInfo('00767334-v', 0) ],
"_rustic_a_1_rel" : [ SenseInfo('02051616-a', 1), SenseInfo('00636891-a', 1), SenseInfo('02051013-a', 0) ],
"_overgrowth_n_1_rel" : [ SenseInfo('14368288-n', 0), SenseInfo('05116486-n', 0) ],
"_market_v_1_rel" : [ SenseInfo('02298160-v', 3), SenseInfo('02326198-v', 0), SenseInfo('02298471-v', 0), SenseInfo('00470386-v', 0) ],
"_in+favor_a_of_rel" : [  ],
"_correlate_v_1_rel" : [ SenseInfo('02658979-v', 4), SenseInfo('00713996-v', 0) ],
"_breve_n_1_rel" : [ SenseInfo('06822831-n', 0) ],
"_pull_v_up_rel" : [ SenseInfo('01448100-v', 44), SenseInfo('01505254-v', 8), SenseInfo('02057499-v', 6), SenseInfo('01609287-v', 3), SenseInfo('02582615-v', 2), SenseInfo('01995211-v', 2), SenseInfo('02057337-v', 1), SenseInfo('00071803-v', 1), SenseInfo('02103162-v', 0), SenseInfo('01947247-v', 0), SenseInfo('01858573-v', 0), SenseInfo('01573276-v', 0), SenseInfo('01407059-v', 0), SenseInfo('01384275-v', 0), SenseInfo('01351170-v', 0), SenseInfo('01148710-v', 0), SenseInfo('00571596-v', 0), SenseInfo('01448100-v', 44), SenseInfo('01505254-v', 8), SenseInfo('02057499-v', 6), SenseInfo('01609287-v', 3), SenseInfo('02582615-v', 2), SenseInfo('01995211-v', 2), SenseInfo('02057337-v', 1), SenseInfo('00071803-v', 1), SenseInfo('02103162-v', 0), SenseInfo('01947247-v', 0), SenseInfo('01858573-v', 0), SenseInfo('01573276-v', 0), SenseInfo('01407059-v', 0), SenseInfo('01384275-v', 0), SenseInfo('01351170-v', 0), SenseInfo('01148710-v', 0), SenseInfo('00571596-v', 0) ],
"_clean_a_of_rel" : [ SenseInfo('00417413-a', 17), SenseInfo('01914108-a', 2), SenseInfo('01906464-a', 1), SenseInfo('01906320-a', 1), SenseInfo('01749915-a', 1), SenseInfo('00427331-a', 0), SenseInfo('00426347-a', 0), SenseInfo('00424008-a', 0), SenseInfo('02116473-a', 0), SenseInfo('01548808-a', 0), SenseInfo('01404898-a', 0), SenseInfo('01087093-a', 0), SenseInfo('00956733-a', 0), SenseInfo('00749947-a', 0), SenseInfo('00522101-a', 0), SenseInfo('00143294-a', 0), SenseInfo('00061664-a', 0), SenseInfo('00047653-a', 0), SenseInfo('00417413-a', 17), SenseInfo('01914108-a', 2), SenseInfo('01906464-a', 1), SenseInfo('01906320-a', 1), SenseInfo('01749915-a', 1), SenseInfo('00427331-a', 0), SenseInfo('00426347-a', 0), SenseInfo('00424008-a', 0), SenseInfo('02116473-a', 0), SenseInfo('01548808-a', 0), SenseInfo('01404898-a', 0), SenseInfo('01087093-a', 0), SenseInfo('00956733-a', 0), SenseInfo('00749947-a', 0), SenseInfo('00522101-a', 0), SenseInfo('00143294-a', 0), SenseInfo('00061664-a', 0), SenseInfo('00047653-a', 0), SenseInfo('00417413-a', 17), SenseInfo('01914108-a', 2), SenseInfo('01906464-a', 1), SenseInfo('01906320-a', 1), SenseInfo('01749915-a', 1), SenseInfo('00427331-a', 0), SenseInfo('00426347-a', 0), SenseInfo('00424008-a', 0), SenseInfo('02116473-a', 0), SenseInfo('01548808-a', 0), SenseInfo('01404898-a', 0), SenseInfo('01087093-a', 0), SenseInfo('00956733-a', 0), SenseInfo('00749947-a', 0), SenseInfo('00522101-a', 0), SenseInfo('00143294-a', 0), SenseInfo('00061664-a', 0), SenseInfo('00047653-a', 0), SenseInfo('00417413-a', 17), SenseInfo('01914108-a', 2), SenseInfo('01906464-a', 1), SenseInfo('01906320-a', 1), SenseInfo('01749915-a', 1), SenseInfo('00427331-a', 0), SenseInfo('00426347-a', 0), SenseInfo('00424008-a', 0), SenseInfo('02116473-a', 0), SenseInfo('01548808-a', 0), SenseInfo('01404898-a', 0), SenseInfo('01087093-a', 0), SenseInfo('00956733-a', 0), SenseInfo('00749947-a', 0), SenseInfo('00522101-a', 0), SenseInfo('00143294-a', 0), SenseInfo('00061664-a', 0), SenseInfo('00047653-a', 0), SenseInfo('00417413-a', 17), SenseInfo('01914108-a', 2), SenseInfo('01906464-a', 1), SenseInfo('01906320-a', 1), SenseInfo('01749915-a', 1), SenseInfo('00427331-a', 0), SenseInfo('00426347-a', 0), SenseInfo('00424008-a', 0), SenseInfo('02116473-a', 0), SenseInfo('01548808-a', 0), SenseInfo('01404898-a', 0), SenseInfo('01087093-a', 0), SenseInfo('00956733-a', 0), SenseInfo('00749947-a', 0), SenseInfo('00522101-a', 0), SenseInfo('00143294-a', 0), SenseInfo('00061664-a', 0), SenseInfo('00047653-a', 0), SenseInfo('00417413-a', 17), SenseInfo('01914108-a', 2), SenseInfo('01906464-a', 1), SenseInfo('01906320-a', 1), SenseInfo('01749915-a', 1), SenseInfo('00427331-a', 0), SenseInfo('00426347-a', 0), SenseInfo('00424008-a', 0), SenseInfo('02116473-a', 0), SenseInfo('01548808-a', 0), SenseInfo('01404898-a', 0), SenseInfo('01087093-a', 0), SenseInfo('00956733-a', 0), SenseInfo('00749947-a', 0), SenseInfo('00522101-a', 0), SenseInfo('00143294-a', 0), SenseInfo('00061664-a', 0), SenseInfo('00047653-a', 0) ],
"_authoritarian_a_1_rel" : [ SenseInfo('00717684-a', 2), SenseInfo('00787357-a', 0) ],
"_cola_n_1_rel" : [ SenseInfo('12197211-n', 0), SenseInfo('07927931-n', 0) ],
"_real+estate_n_1_rel" : [ SenseInfo('13246475-n', 5), SenseInfo('13246475-n', 5) ],
"_some_a_1_rel" : [ SenseInfo('02267308-a', 130), SenseInfo('01554063-a', 7), SenseInfo('01552634-a', 7), SenseInfo('01678586-a', 0), SenseInfo('02267308-a', 130), SenseInfo('01554063-a', 7), SenseInfo('01552634-a', 7), SenseInfo('01678586-a', 0) ],
"_feat_n_1_rel" : [ SenseInfo('00036762-n', 6) ],
"_first+place_n_1_rel" : [  ],
"_electrical_a_1_rel" : [ SenseInfo('02826701-a', 16), SenseInfo('02826877-a', 0), SenseInfo('02826701-a', 16), SenseInfo('02826877-a', 0) ],
"_perpendicular_n_1_rel" : [ SenseInfo('13870680-n', 0), SenseInfo('05843236-n', 0), SenseInfo('03969627-n', 0), SenseInfo('03917973-n', 0) ],
"_how+about_x_rel" : [  ],
"_tap-dance_v_1_rel" : [ SenseInfo('01710048-v', 0), SenseInfo('01710048-v', 0) ],
"_fumble_n_1_rel" : [ SenseInfo('00075912-n', 1) ],
"_kDa_n_1_rel" : [  ],
"_prefer_v_to_rel" : [ SenseInfo('01826498-v', 22), SenseInfo('00679389-v', 16), SenseInfo('02400037-v', 1), SenseInfo('02400251-v', 0), SenseInfo('01826498-v', 22), SenseInfo('00679389-v', 16), SenseInfo('02400037-v', 1), SenseInfo('02400251-v', 0), SenseInfo('01826498-v', 22), SenseInfo('00679389-v', 16), SenseInfo('02400037-v', 1), SenseInfo('02400251-v', 0), SenseInfo('01826498-v', 22), SenseInfo('00679389-v', 16), SenseInfo('02400037-v', 1), SenseInfo('02400251-v', 0), SenseInfo('01826498-v', 22), SenseInfo('00679389-v', 16), SenseInfo('02400037-v', 1), SenseInfo('02400251-v', 0), SenseInfo('01826498-v', 22), SenseInfo('00679389-v', 16), SenseInfo('02400037-v', 1), SenseInfo('02400251-v', 0) ],
"_justify_v_to_rel" : [ SenseInfo('00896803-v', 17), SenseInfo('00896141-v', 9), SenseInfo('00894738-v', 2), SenseInfo('00902424-v', 0), SenseInfo('00489699-v', 0), SenseInfo('00896803-v', 17), SenseInfo('00896141-v', 9), SenseInfo('00894738-v', 2), SenseInfo('00902424-v', 0), SenseInfo('00489699-v', 0), SenseInfo('00896803-v', 17), SenseInfo('00896141-v', 9), SenseInfo('00894738-v', 2), SenseInfo('00902424-v', 0), SenseInfo('00489699-v', 0) ],
"_aye_n_1_rel" : [  ],
"_creep_n_1_rel" : [ SenseInfo('09976917-n', 0), SenseInfo('07312503-n', 0), SenseInfo('03129944-n', 0), SenseInfo('00294868-n', 0) ],
"_albeit_p_1_rel" : [  ],
"_run_v_around_rel" : [ SenseInfo('01926311-v', 106), SenseInfo('02075049-v', 38), SenseInfo('02685951-v', 21), SenseInfo('02443849-v', 20), SenseInfo('02721284-v', 10), SenseInfo('02066939-v', 9), SenseInfo('01525666-v', 8), SenseInfo('02727039-v', 7), SenseInfo('01094086-v', 7), SenseInfo('01717169-v', 5), SenseInfo('02099829-v', 4), SenseInfo('02719399-v', 3), SenseInfo('01526290-v', 3), SenseInfo('00549063-v', 3), SenseInfo('00517529-v', 3), SenseInfo('02720904-v', 2), SenseInfo('02647497-v', 2), SenseInfo('02612234-v', 2), SenseInfo('02563327-v', 2), SenseInfo('01746359-v', 2), SenseInfo('01641545-v', 2), SenseInfo('01212230-v', 2), SenseInfo('02686625-v', 1), SenseInfo('02525312-v', 1), SenseInfo('02242256-v', 1), SenseInfo('02092309-v', 1), SenseInfo('02060792-v', 1), SenseInfo('01927903-v', 1), SenseInfo('01914947-v', 1), SenseInfo('02648110-v', 0), SenseInfo('02421921-v', 0), SenseInfo('01927747-v', 0), SenseInfo('01927447-v', 0), SenseInfo('01926984-v', 0), SenseInfo('01864038-v', 0), SenseInfo('01143838-v', 0), SenseInfo('01086103-v', 0), SenseInfo('00539110-v', 0), SenseInfo('00444629-v', 0), SenseInfo('00334803-v', 0), SenseInfo('00332672-v', 0) ],
"_strange_a_1_rel" : [ SenseInfo('00967129-a', 41), SenseInfo('00966753-a', 15), SenseInfo('01034457-a', 0), SenseInfo('00967129-a', 41), SenseInfo('00966753-a', 15), SenseInfo('01034457-a', 0), SenseInfo('00967129-a', 41), SenseInfo('00966753-a', 15), SenseInfo('01034457-a', 0) ],
"_scorn_v_1_rel" : [ SenseInfo('01774799-v', 2), SenseInfo('00796976-v', 1) ],
"_dude_n_1_rel" : [ SenseInfo('10083358-n', 0), SenseInfo('09991026-n', 0) ],
"_design_v_1_rel" : [ SenseInfo('01638368-v', 31), SenseInfo('00709625-v', 28), SenseInfo('01640550-v', 19), SenseInfo('01639714-v', 8), SenseInfo('01753596-v', 0), SenseInfo('01633825-v', 0), SenseInfo('00698572-v', 0), SenseInfo('01638368-v', 31), SenseInfo('00709625-v', 28), SenseInfo('01640550-v', 19), SenseInfo('01639714-v', 8), SenseInfo('01753596-v', 0), SenseInfo('01633825-v', 0), SenseInfo('00698572-v', 0) ],
"_modulate_v_1_rel" : [ SenseInfo('01729142-v', 0), SenseInfo('00982293-v', 0), SenseInfo('00299341-v', 0), SenseInfo('00171458-v', 0), SenseInfo('00123894-v', 0) ],
"_dark_a_1_rel" : [ SenseInfo('00273082-a', 49), SenseInfo('00409440-a', 27), SenseInfo('00245200-a', 13), SenseInfo('01131935-a', 5), SenseInfo('02088883-a', 0), SenseInfo('01137378-a', 0), SenseInfo('00884501-a', 0), SenseInfo('00534250-a', 0), SenseInfo('00364881-a', 0), SenseInfo('00242575-a', 0), SenseInfo('00036763-a', 0), SenseInfo('00273082-a', 49), SenseInfo('00409440-a', 27), SenseInfo('00245200-a', 13), SenseInfo('01131935-a', 5), SenseInfo('02088883-a', 0), SenseInfo('01137378-a', 0), SenseInfo('00884501-a', 0), SenseInfo('00534250-a', 0), SenseInfo('00364881-a', 0), SenseInfo('00242575-a', 0), SenseInfo('00036763-a', 0), SenseInfo('00273082-a', 49), SenseInfo('00409440-a', 27), SenseInfo('00245200-a', 13), SenseInfo('01131935-a', 5), SenseInfo('02088883-a', 0), SenseInfo('01137378-a', 0), SenseInfo('00884501-a', 0), SenseInfo('00534250-a', 0), SenseInfo('00364881-a', 0), SenseInfo('00242575-a', 0), SenseInfo('00036763-a', 0), SenseInfo('00273082-a', 49), SenseInfo('00409440-a', 27), SenseInfo('00245200-a', 13), SenseInfo('01131935-a', 5), SenseInfo('02088883-a', 0), SenseInfo('01137378-a', 0), SenseInfo('00884501-a', 0), SenseInfo('00534250-a', 0), SenseInfo('00364881-a', 0), SenseInfo('00242575-a', 0), SenseInfo('00036763-a', 0) ],
"_abbot_n_1_rel" : [ SenseInfo('09754404-n', 2) ],
"_accent_v_1_rel" : [ SenseInfo('01013367-v', 0), SenseInfo('00983333-v', 0) ],
"_write_v_off_rel" : [ SenseInfo('01698271-v', 112), SenseInfo('00993014-v', 94), SenseInfo('01744611-v', 33), SenseInfo('01007027-v', 15), SenseInfo('01031966-v', 10), SenseInfo('01705494-v', 9), SenseInfo('01691057-v', 8), SenseInfo('00998886-v', 4), SenseInfo('01699896-v', 1), SenseInfo('01692834-v', 0) ],
"_mode_n_1_rel" : [ SenseInfo('04928903-n', 13), SenseInfo('13923929-n', 0), SenseInfo('13802634-n', 0), SenseInfo('13801424-n', 0), SenseInfo('06861630-n', 0), SenseInfo('06023675-n', 0), SenseInfo('04928903-n', 13), SenseInfo('13923929-n', 0), SenseInfo('13802634-n', 0), SenseInfo('13801424-n', 0), SenseInfo('06861630-n', 0), SenseInfo('06023675-n', 0) ],
"_reinforce_v_1_rel" : [ SenseInfo('00222472-v', 11), SenseInfo('00787660-v', 1), SenseInfo('00222472-v', 11), SenseInfo('00787660-v', 1), SenseInfo('00222472-v', 11), SenseInfo('00787660-v', 1) ],
"_reassurance_n_of_rel" : [ SenseInfo('01215719-n', 4) ],
"_pony_n_1_rel" : [ SenseInfo('02380335-n', 2), SenseInfo('02385098-n', 1), SenseInfo('06347225-n', 0), SenseInfo('04206225-n', 0), SenseInfo('02382437-n', 0) ],
"_shift_n_1_rel" : [ SenseInfo('07444668-n', 5), SenseInfo('07359599-n', 5), SenseInfo('15291801-n', 3), SenseInfo('00196084-n', 3), SenseInfo('00331655-n', 2), SenseInfo('09278537-n', 0), SenseInfo('08218393-n', 0), SenseInfo('04193377-n', 0), SenseInfo('03013580-n', 0), SenseInfo('03013438-n', 0) ],
"_keep_v_i_rel" : [ SenseInfo('02681795-v', 206), SenseInfo('02684924-v', 39), SenseInfo('02202384-v', 32), SenseInfo('02450505-v', 22), SenseInfo('02578872-v', 10), SenseInfo('00732552-v', 9), SenseInfo('02202928-v', 8), SenseInfo('01065877-v', 4), SenseInfo('02651853-v', 3), SenseInfo('02410175-v', 3), SenseInfo('01184625-v', 3), SenseInfo('02734800-v', 2), SenseInfo('02578510-v', 2), SenseInfo('02422663-v', 2), SenseInfo('02733122-v', 1), SenseInfo('02652016-v', 0), SenseInfo('02283716-v', 0), SenseInfo('02204094-v', 0), SenseInfo('02203844-v', 0), SenseInfo('02203168-v', 0), SenseInfo('01302019-v', 0), SenseInfo('00212414-v', 0), SenseInfo('02681795-v', 206), SenseInfo('02684924-v', 39), SenseInfo('02202384-v', 32), SenseInfo('02450505-v', 22), SenseInfo('02578872-v', 10), SenseInfo('00732552-v', 9), SenseInfo('02202928-v', 8), SenseInfo('01065877-v', 4), SenseInfo('02651853-v', 3), SenseInfo('02410175-v', 3), SenseInfo('01184625-v', 3), SenseInfo('02734800-v', 2), SenseInfo('02578510-v', 2), SenseInfo('02422663-v', 2), SenseInfo('02733122-v', 1), SenseInfo('02652016-v', 0), SenseInfo('02283716-v', 0), SenseInfo('02204094-v', 0), SenseInfo('02203844-v', 0), SenseInfo('02203168-v', 0), SenseInfo('01302019-v', 0), SenseInfo('00212414-v', 0), SenseInfo('02681795-v', 206), SenseInfo('02684924-v', 39), SenseInfo('02202384-v', 32), SenseInfo('02450505-v', 22), SenseInfo('02578872-v', 10), SenseInfo('00732552-v', 9), SenseInfo('02202928-v', 8), SenseInfo('01065877-v', 4), SenseInfo('02651853-v', 3), SenseInfo('02410175-v', 3), SenseInfo('01184625-v', 3), SenseInfo('02734800-v', 2), SenseInfo('02578510-v', 2), SenseInfo('02422663-v', 2), SenseInfo('02733122-v', 1), SenseInfo('02652016-v', 0), SenseInfo('02283716-v', 0), SenseInfo('02204094-v', 0), SenseInfo('02203844-v', 0), SenseInfo('02203168-v', 0), SenseInfo('01302019-v', 0), SenseInfo('00212414-v', 0) ],
"_phoenix_n_1_rel" : [ SenseInfo('09058376-n', 1), SenseInfo('12593826-n', 0), SenseInfo('09500936-n', 0), SenseInfo('09390967-n', 0) ],
"_come_v_around_rel" : [ SenseInfo('01849221-v', 276), SenseInfo('02005948-v', 235), SenseInfo('00341917-v', 147), SenseInfo('00542120-v', 41), SenseInfo('02625339-v', 40), SenseInfo('00342812-v', 11), SenseInfo('02743921-v', 9), SenseInfo('02743214-v', 7), SenseInfo('02686805-v', 6), SenseInfo('02743565-v', 3), SenseInfo('01839690-v', 3), SenseInfo('02729963-v', 2), SenseInfo('00344886-v', 2), SenseInfo('02645007-v', 1), SenseInfo('02627363-v', 1), SenseInfo('02006709-v', 1), SenseInfo('00723349-v', 1), SenseInfo('02737187-v', 0), SenseInfo('02617567-v', 0), SenseInfo('02197360-v', 0), SenseInfo('00659984-v', 0) ],
"_paradoxical_a_1_rel" : [ SenseInfo('00939895-a', 2), SenseInfo('00939895-a', 2) ],
"_cross_v_1_rel" : [ SenseInfo('01912159-v', 47), SenseInfo('02023396-v', 7), SenseInfo('02558172-v', 1), SenseInfo('01914657-v', 1), SenseInfo('02685390-v', 0), SenseInfo('01913997-v', 0), SenseInfo('01691798-v', 0), SenseInfo('01429953-v', 0), SenseInfo('01912159-v', 47), SenseInfo('02023396-v', 7), SenseInfo('02558172-v', 1), SenseInfo('01914657-v', 1), SenseInfo('02685390-v', 0), SenseInfo('01913997-v', 0), SenseInfo('01691798-v', 0), SenseInfo('01429953-v', 0) ],
"_fitness_n_1_rel" : [ SenseInfo('04716864-n', 3), SenseInfo('14546432-n', 1), SenseInfo('14547036-n', 0), SenseInfo('05153795-n', 0) ],
"_money_n_1_rel" : [ SenseInfo('13384557-n', 77), SenseInfo('13250542-n', 15), SenseInfo('13384877-n', 0) ],
"_ingress_n_1_rel" : [ SenseInfo('07322341-n', 0), SenseInfo('00049003-n', 0) ],
"_porcupine_n_1_rel" : [ SenseInfo('02346627-n', 1) ],
"_hold_v_1_rel" : [ SenseInfo('02681795-v', 79), SenseInfo('01216670-v', 65), SenseInfo('01733477-v', 62), SenseInfo('02203362-v', 26), SenseInfo('00693780-v', 20), SenseInfo('01773130-v', 17), SenseInfo('01301410-v', 17), SenseInfo('02283324-v', 14), SenseInfo('02302220-v', 9), SenseInfo('01217043-v', 9), SenseInfo('02700867-v', 7), SenseInfo('02732798-v', 3), SenseInfo('02683489-v', 3), SenseInfo('01601234-v', 3), SenseInfo('02648502-v', 2), SenseInfo('00683771-v', 2), SenseInfo('02746275-v', 1), SenseInfo('02701210-v', 1), SenseInfo('02498320-v', 1), SenseInfo('01129876-v', 1), SenseInfo('00885217-v', 1), SenseInfo('00736586-v', 1), SenseInfo('00607000-v', 1), SenseInfo('02706816-v', 0), SenseInfo('02676789-v', 0), SenseInfo('02643574-v', 0), SenseInfo('02510337-v', 0), SenseInfo('02450989-v', 0), SenseInfo('02441897-v', 0), SenseInfo('01859586-v', 0), SenseInfo('01334744-v', 0), SenseInfo('01205153-v', 0), SenseInfo('01151753-v', 0), SenseInfo('00822367-v', 0), SenseInfo('00805376-v', 0), SenseInfo('00004492-v', 0), SenseInfo('02681795-v', 79), SenseInfo('01216670-v', 65), SenseInfo('01733477-v', 62), SenseInfo('02203362-v', 26), SenseInfo('00693780-v', 20), SenseInfo('01773130-v', 17), SenseInfo('01301410-v', 17), SenseInfo('02283324-v', 14), SenseInfo('02302220-v', 9), SenseInfo('01217043-v', 9), SenseInfo('02700867-v', 7), SenseInfo('02732798-v', 3), SenseInfo('02683489-v', 3), SenseInfo('01601234-v', 3), SenseInfo('02648502-v', 2), SenseInfo('00683771-v', 2), SenseInfo('02746275-v', 1), SenseInfo('02701210-v', 1), SenseInfo('02498320-v', 1), SenseInfo('01129876-v', 1), SenseInfo('00885217-v', 1), SenseInfo('00736586-v', 1), SenseInfo('00607000-v', 1), SenseInfo('02706816-v', 0), SenseInfo('02676789-v', 0), SenseInfo('02643574-v', 0), SenseInfo('02510337-v', 0), SenseInfo('02450989-v', 0), SenseInfo('02441897-v', 0), SenseInfo('01859586-v', 0), SenseInfo('01334744-v', 0), SenseInfo('01205153-v', 0), SenseInfo('01151753-v', 0), SenseInfo('00822367-v', 0), SenseInfo('00805376-v', 0), SenseInfo('00004492-v', 0), SenseInfo('02681795-v', 79), SenseInfo('01216670-v', 65), SenseInfo('01733477-v', 62), SenseInfo('02203362-v', 26), SenseInfo('00693780-v', 20), SenseInfo('01773130-v', 17), SenseInfo('01301410-v', 17), SenseInfo('02283324-v', 14), SenseInfo('02302220-v', 9), SenseInfo('01217043-v', 9), SenseInfo('02700867-v', 7), SenseInfo('02732798-v', 3), SenseInfo('02683489-v', 3), SenseInfo('01601234-v', 3), SenseInfo('02648502-v', 2), SenseInfo('00683771-v', 2), SenseInfo('02746275-v', 1), SenseInfo('02701210-v', 1), SenseInfo('02498320-v', 1), SenseInfo('01129876-v', 1), SenseInfo('00885217-v', 1), SenseInfo('00736586-v', 1), SenseInfo('00607000-v', 1), SenseInfo('02706816-v', 0), SenseInfo('02676789-v', 0), SenseInfo('02643574-v', 0), SenseInfo('02510337-v', 0), SenseInfo('02450989-v', 0), SenseInfo('02441897-v', 0), SenseInfo('01859586-v', 0), SenseInfo('01334744-v', 0), SenseInfo('01205153-v', 0), SenseInfo('01151753-v', 0), SenseInfo('00822367-v', 0), SenseInfo('00805376-v', 0), SenseInfo('00004492-v', 0), SenseInfo('02681795-v', 79), SenseInfo('01216670-v', 65), SenseInfo('01733477-v', 62), SenseInfo('02203362-v', 26), SenseInfo('00693780-v', 20), SenseInfo('01773130-v', 17), SenseInfo('01301410-v', 17), SenseInfo('02283324-v', 14), SenseInfo('02302220-v', 9), SenseInfo('01217043-v', 9), SenseInfo('02700867-v', 7), SenseInfo('02732798-v', 3), SenseInfo('02683489-v', 3), SenseInfo('01601234-v', 3), SenseInfo('02648502-v', 2), SenseInfo('00683771-v', 2), SenseInfo('02746275-v', 1), SenseInfo('02701210-v', 1), SenseInfo('02498320-v', 1), SenseInfo('01129876-v', 1), SenseInfo('00885217-v', 1), SenseInfo('00736586-v', 1), SenseInfo('00607000-v', 1), SenseInfo('02706816-v', 0), SenseInfo('02676789-v', 0), SenseInfo('02643574-v', 0), SenseInfo('02510337-v', 0), SenseInfo('02450989-v', 0), SenseInfo('02441897-v', 0), SenseInfo('01859586-v', 0), SenseInfo('01334744-v', 0), SenseInfo('01205153-v', 0), SenseInfo('01151753-v', 0), SenseInfo('00822367-v', 0), SenseInfo('00805376-v', 0), SenseInfo('00004492-v', 0) ],
"_reach_v_1_rel" : [ SenseInfo('02020590-v', 103), SenseInfo('02006834-v', 39), SenseInfo('01440139-v', 29), SenseInfo('00743344-v', 22), SenseInfo('02526085-v', 18), SenseInfo('02685665-v', 13), SenseInfo('02022162-v', 9), SenseInfo('02230772-v', 1), SenseInfo('01146051-v', 0) ],
"_reserve_v_1_rel" : [ SenseInfo('02214485-v', 7), SenseInfo('00724150-v', 6), SenseInfo('00795632-v', 1), SenseInfo('02498320-v', 0) ],
"_rhyme_v_cause_rel" : [ SenseInfo('01701858-v', 1), SenseInfo('02750432-v', 0) ],
"_qualify_v_for_rel" : [ SenseInfo('02679012-v', 14), SenseInfo('00972191-v', 3), SenseInfo('00199309-v', 2), SenseInfo('00300761-v', 1), SenseInfo('01018928-v', 0), SenseInfo('00956687-v', 0), SenseInfo('00171127-v', 0), SenseInfo('02679012-v', 14), SenseInfo('00972191-v', 3), SenseInfo('00199309-v', 2), SenseInfo('00300761-v', 1), SenseInfo('01018928-v', 0), SenseInfo('00956687-v', 0), SenseInfo('00171127-v', 0), SenseInfo('02679012-v', 14), SenseInfo('00972191-v', 3), SenseInfo('00199309-v', 2), SenseInfo('00300761-v', 1), SenseInfo('01018928-v', 0), SenseInfo('00956687-v', 0), SenseInfo('00171127-v', 0) ],
"_steamboat_n_1_rel" : [ SenseInfo('04308807-n', 1) ],
"_chickadee_n_1_rel" : [ SenseInfo('01592084-n', 0) ],
"_study_v_1_rel" : [ SenseInfo('00644583-v', 73), SenseInfo('00607405-v', 17), SenseInfo('02166460-v', 15), SenseInfo('00599992-v', 13), SenseInfo('00607114-v', 5), SenseInfo('00704388-v', 2), SenseInfo('00644583-v', 73), SenseInfo('00607405-v', 17), SenseInfo('02166460-v', 15), SenseInfo('00599992-v', 13), SenseInfo('00607114-v', 5), SenseInfo('00704388-v', 2) ],
"_think_v_of-as_rel" : [ SenseInfo('00689344-v', 274), SenseInfo('00631737-v', 188), SenseInfo('00628491-v', 111), SenseInfo('00607780-v', 8), SenseInfo('01637166-v', 4), SenseInfo('00723056-v', 3), SenseInfo('00708538-v', 2), SenseInfo('00739340-v', 0), SenseInfo('00739082-v', 0), SenseInfo('00689809-v', 0), SenseInfo('00629738-v', 0), SenseInfo('00608808-v', 0), SenseInfo('00561887-v', 0) ],
"_rumble_n_1_rel" : [ SenseInfo('07392483-n', 4), SenseInfo('04119091-n', 0), SenseInfo('01176649-n', 0) ],
"_save_p_rel" : [ SenseInfo('02550868-v', 41), SenseInfo('02225492-v', 16), SenseInfo('02551832-v', 4), SenseInfo('02266920-v', 4), SenseInfo('02265979-v', 4), SenseInfo('00549552-v', 4), SenseInfo('02551602-v', 2), SenseInfo('02464583-v', 2), SenseInfo('02357228-v', 1), SenseInfo('02283716-v', 1), SenseInfo('01079396-n', 0), SenseInfo('00998886-v', 0) ],
"_swear_v_in_rel" : [ SenseInfo('00865387-v', 20), SenseInfo('01011031-v', 8), SenseInfo('00889947-v', 2), SenseInfo('01013040-v', 1), SenseInfo('00688377-v', 0) ],
"_golf_v_1_rel" : [ SenseInfo('01146793-v', 0) ],
"_inflow_n_1_rel" : [ SenseInfo('13499782-n', 1) ],
"_hope_v_1_rel" : [ SenseInfo('01826723-v', 60), SenseInfo('01811441-v', 37), SenseInfo('00706047-v', 23), SenseInfo('01826723-v', 60), SenseInfo('01811441-v', 37), SenseInfo('00706047-v', 23), SenseInfo('01826723-v', 60), SenseInfo('01811441-v', 37), SenseInfo('00706047-v', 23) ],
"_retread_n_of_rel" : [ SenseInfo('04083942-n', 0) ],
"_equate_v_with_rel" : [ SenseInfo('00653620-v', 8), SenseInfo('02633534-v', 1), SenseInfo('00417001-v', 0), SenseInfo('00653620-v', 8), SenseInfo('02633534-v', 1), SenseInfo('00417001-v', 0) ],
"_increase_v_1_rel" : [ SenseInfo('00156601-v', 86), SenseInfo('00153263-v', 61) ],
"_abreast_a_of_rel" : [ SenseInfo('01306645-a', 0) ],
"_quintessential_a_1_rel" : [ SenseInfo('02998269-a', 0) ],
"_landslide_n_1_rel" : [ SenseInfo('07474185-n', 1), SenseInfo('07405411-n', 1), SenseInfo('07474185-n', 1), SenseInfo('07405411-n', 1) ],
"_wiper_n_1_rel" : [ SenseInfo('10783646-n', 0), SenseInfo('04593866-n', 0), SenseInfo('04590746-n', 0) ],
"_proliferation_n_of_rel" : [ SenseInfo('13541975-n', 3), SenseInfo('13542114-n', 0) ],
"_ragtime_n_1_rel" : [ SenseInfo('07060844-n', 0) ],
"_intersperse_v_1_rel" : [ SenseInfo('01376620-v', 0), SenseInfo('00189189-v', 0) ],
"_bargain_v_1_rel" : [ SenseInfo('02259829-v', 1), SenseInfo('00764782-v', 0), SenseInfo('02259829-v', 1), SenseInfo('00764782-v', 0) ],
"_archive_n_1_rel" : [ SenseInfo('02735086-n', 0) ],
"_conformable_a_1_rel" : [ SenseInfo('01612878-a', 0), SenseInfo('00696828-a', 0), SenseInfo('00577122-a', 0) ],
"_lull_n_1_rel" : [ SenseInfo('15274441-n', 4), SenseInfo('14522956-n', 0) ],
"_instrument_n_1_rel" : [ SenseInfo('03574816-n', 23), SenseInfo('00173761-n', 4), SenseInfo('10209616-n', 1), SenseInfo('06479665-n', 0), SenseInfo('06332731-n', 0), SenseInfo('03800933-n', 0), SenseInfo('03574816-n', 23), SenseInfo('00173761-n', 4), SenseInfo('10209616-n', 1), SenseInfo('06479665-n', 0), SenseInfo('06332731-n', 0), SenseInfo('03800933-n', 0) ],
"_chair_n_1_rel" : [ SenseInfo('03001627-n', 35), SenseInfo('00598056-n', 2), SenseInfo('10468962-n', 0), SenseInfo('03271030-n', 0), SenseInfo('03002096-n', 0) ],
"_non+smoking_n_1_rel" : [  ],
"_altogether_x_deg_rel" : [ SenseInfo('00008007-r', 11), SenseInfo('00063630-r', 1), SenseInfo('14456586-n', 0), SenseInfo('00151755-r', 0) ],
"_feature_n_1_rel" : [ SenseInfo('05849789-n', 42), SenseInfo('05601758-n', 18), SenseInfo('06615026-n', 2), SenseInfo('06268784-n', 0), SenseInfo('05850212-n', 0), SenseInfo('03325769-n', 0), SenseInfo('05849789-n', 42), SenseInfo('05601758-n', 18), SenseInfo('06615026-n', 2), SenseInfo('06268784-n', 0), SenseInfo('05850212-n', 0), SenseInfo('03325769-n', 0), SenseInfo('05849789-n', 42), SenseInfo('05601758-n', 18), SenseInfo('06615026-n', 2), SenseInfo('06268784-n', 0), SenseInfo('05850212-n', 0), SenseInfo('03325769-n', 0) ],
"_plan_v_on_rel" : [ SenseInfo('00705227-v', 44), SenseInfo('00704690-v', 27), SenseInfo('01638368-v', 17), SenseInfo('01639714-v', 2), SenseInfo('00705227-v', 44), SenseInfo('00704690-v', 27), SenseInfo('01638368-v', 17), SenseInfo('01639714-v', 2) ],
"_plaintiff_n_1_rel" : [ SenseInfo('10437852-n', 0) ],
"_bike_n_1_rel" : [ SenseInfo('03790512-n', 0), SenseInfo('02834778-n', 0) ],
"_networking_n_1_rel" : [  ],
"_heedless_a_1_rel" : [ SenseInfo('01193714-a', 4), SenseInfo('00312757-a', 0) ],
"_roll_v_down_rel" : [ SenseInfo('01866192-v', 22), SenseInfo('01887020-v', 10), SenseInfo('02687251-v', 7), SenseInfo('01391280-v', 6), SenseInfo('02198014-v', 2), SenseInfo('01522276-v', 2), SenseInfo('01526139-v', 1), SenseInfo('00143204-v', 1), SenseInfo('00100410-v', 1), SenseInfo('02322596-v', 0), SenseInfo('01901783-v', 0), SenseInfo('01881180-v', 0), SenseInfo('01875684-v', 0), SenseInfo('01866610-v', 0), SenseInfo('01055978-v', 0), SenseInfo('00324427-v', 0), SenseInfo('00125289-v', 0), SenseInfo('00125078-v', 0) ],
"_cut_v_1_rel" : [ SenseInfo('01552519-v', 58), SenseInfo('00429060-v', 18), SenseInfo('02033295-v', 3), SenseInfo('01610834-v', 2), SenseInfo('02422283-v', 1), SenseInfo('01754915-v', 1), SenseInfo('01666717-v', 1), SenseInfo('01413917-v', 1), SenseInfo('01064799-v', 1), SenseInfo('00201722-v', 1), SenseInfo('02613860-v', 0), SenseInfo('02588280-v', 0), SenseInfo('02134232-v', 0), SenseInfo('02101649-v', 0), SenseInfo('01915865-v', 0), SenseInfo('01915730-v', 0), SenseInfo('01860107-v', 0), SenseInfo('01859995-v', 0), SenseInfo('01756563-v', 0), SenseInfo('01756416-v', 0), SenseInfo('01756277-v', 0), SenseInfo('01754737-v', 0), SenseInfo('01713491-v', 0), SenseInfo('01611123-v', 0), SenseInfo('01610990-v', 0), SenseInfo('01555437-v', 0), SenseInfo('01510576-v', 0), SenseInfo('01320424-v', 0), SenseInfo('01319738-v', 0), SenseInfo('01227088-v', 0), SenseInfo('01059564-v', 0), SenseInfo('00561090-v', 0), SenseInfo('00473322-v', 0), SenseInfo('00447654-v', 0), SenseInfo('00429968-v', 0), SenseInfo('00292507-v', 0), SenseInfo('00243900-v', 0), SenseInfo('00226071-v', 0), SenseInfo('00108475-v', 0), SenseInfo('00096136-v', 0), SenseInfo('00061219-v', 0), SenseInfo('01552519-v', 58), SenseInfo('00429060-v', 18), SenseInfo('02033295-v', 3), SenseInfo('01610834-v', 2), SenseInfo('02422283-v', 1), SenseInfo('01754915-v', 1), SenseInfo('01666717-v', 1), SenseInfo('01413917-v', 1), SenseInfo('01064799-v', 1), SenseInfo('00201722-v', 1), SenseInfo('02613860-v', 0), SenseInfo('02588280-v', 0), SenseInfo('02134232-v', 0), SenseInfo('02101649-v', 0), SenseInfo('01915865-v', 0), SenseInfo('01915730-v', 0), SenseInfo('01860107-v', 0), SenseInfo('01859995-v', 0), SenseInfo('01756563-v', 0), SenseInfo('01756416-v', 0), SenseInfo('01756277-v', 0), SenseInfo('01754737-v', 0), SenseInfo('01713491-v', 0), SenseInfo('01611123-v', 0), SenseInfo('01610990-v', 0), SenseInfo('01555437-v', 0), SenseInfo('01510576-v', 0), SenseInfo('01320424-v', 0), SenseInfo('01319738-v', 0), SenseInfo('01227088-v', 0), SenseInfo('01059564-v', 0), SenseInfo('00561090-v', 0), SenseInfo('00473322-v', 0), SenseInfo('00447654-v', 0), SenseInfo('00429968-v', 0), SenseInfo('00292507-v', 0), SenseInfo('00243900-v', 0), SenseInfo('00226071-v', 0), SenseInfo('00108475-v', 0), SenseInfo('00096136-v', 0), SenseInfo('00061219-v', 0), SenseInfo('01552519-v', 58), SenseInfo('00429060-v', 18), SenseInfo('02033295-v', 3), SenseInfo('01610834-v', 2), SenseInfo('02422283-v', 1), SenseInfo('01754915-v', 1), SenseInfo('01666717-v', 1), SenseInfo('01413917-v', 1), SenseInfo('01064799-v', 1), SenseInfo('00201722-v', 1), SenseInfo('02613860-v', 0), SenseInfo('02588280-v', 0), SenseInfo('02134232-v', 0), SenseInfo('02101649-v', 0), SenseInfo('01915865-v', 0), SenseInfo('01915730-v', 0), SenseInfo('01860107-v', 0), SenseInfo('01859995-v', 0), SenseInfo('01756563-v', 0), SenseInfo('01756416-v', 0), SenseInfo('01756277-v', 0), SenseInfo('01754737-v', 0), SenseInfo('01713491-v', 0), SenseInfo('01611123-v', 0), SenseInfo('01610990-v', 0), SenseInfo('01555437-v', 0), SenseInfo('01510576-v', 0), SenseInfo('01320424-v', 0), SenseInfo('01319738-v', 0), SenseInfo('01227088-v', 0), SenseInfo('01059564-v', 0), SenseInfo('00561090-v', 0), SenseInfo('00473322-v', 0), SenseInfo('00447654-v', 0), SenseInfo('00429968-v', 0), SenseInfo('00292507-v', 0), SenseInfo('00243900-v', 0), SenseInfo('00226071-v', 0), SenseInfo('00108475-v', 0), SenseInfo('00096136-v', 0), SenseInfo('00061219-v', 0), SenseInfo('01552519-v', 58), SenseInfo('00429060-v', 18), SenseInfo('02033295-v', 3), SenseInfo('01610834-v', 2), SenseInfo('02422283-v', 1), SenseInfo('01754915-v', 1), SenseInfo('01666717-v', 1), SenseInfo('01413917-v', 1), SenseInfo('01064799-v', 1), SenseInfo('00201722-v', 1), SenseInfo('02613860-v', 0), SenseInfo('02588280-v', 0), SenseInfo('02134232-v', 0), SenseInfo('02101649-v', 0), SenseInfo('01915865-v', 0), SenseInfo('01915730-v', 0), SenseInfo('01860107-v', 0), SenseInfo('01859995-v', 0), SenseInfo('01756563-v', 0), SenseInfo('01756416-v', 0), SenseInfo('01756277-v', 0), SenseInfo('01754737-v', 0), SenseInfo('01713491-v', 0), SenseInfo('01611123-v', 0), SenseInfo('01610990-v', 0), SenseInfo('01555437-v', 0), SenseInfo('01510576-v', 0), SenseInfo('01320424-v', 0), SenseInfo('01319738-v', 0), SenseInfo('01227088-v', 0), SenseInfo('01059564-v', 0), SenseInfo('00561090-v', 0), SenseInfo('00473322-v', 0), SenseInfo('00447654-v', 0), SenseInfo('00429968-v', 0), SenseInfo('00292507-v', 0), SenseInfo('00243900-v', 0), SenseInfo('00226071-v', 0), SenseInfo('00108475-v', 0), SenseInfo('00096136-v', 0), SenseInfo('00061219-v', 0), SenseInfo('01552519-v', 58), SenseInfo('00429060-v', 18), SenseInfo('02033295-v', 3), SenseInfo('01610834-v', 2), SenseInfo('02422283-v', 1), SenseInfo('01754915-v', 1), SenseInfo('01666717-v', 1), SenseInfo('01413917-v', 1), SenseInfo('01064799-v', 1), SenseInfo('00201722-v', 1), SenseInfo('02613860-v', 0), SenseInfo('02588280-v', 0), SenseInfo('02134232-v', 0), SenseInfo('02101649-v', 0), SenseInfo('01915865-v', 0), SenseInfo('01915730-v', 0), SenseInfo('01860107-v', 0), SenseInfo('01859995-v', 0), SenseInfo('01756563-v', 0), SenseInfo('01756416-v', 0), SenseInfo('01756277-v', 0), SenseInfo('01754737-v', 0), SenseInfo('01713491-v', 0), SenseInfo('01611123-v', 0), SenseInfo('01610990-v', 0), SenseInfo('01555437-v', 0), SenseInfo('01510576-v', 0), SenseInfo('01320424-v', 0), SenseInfo('01319738-v', 0), SenseInfo('01227088-v', 0), SenseInfo('01059564-v', 0), SenseInfo('00561090-v', 0), SenseInfo('00473322-v', 0), SenseInfo('00447654-v', 0), SenseInfo('00429968-v', 0), SenseInfo('00292507-v', 0), SenseInfo('00243900-v', 0), SenseInfo('00226071-v', 0), SenseInfo('00108475-v', 0), SenseInfo('00096136-v', 0), SenseInfo('00061219-v', 0) ],
"_ground_v_1_rel" : [ SenseInfo('01304944-v', 2), SenseInfo('01502762-v', 1), SenseInfo('01502654-v', 1), SenseInfo('00830648-v', 1), SenseInfo('02022486-v', 0), SenseInfo('02022359-v', 0), SenseInfo('01406684-v', 0), SenseInfo('01406512-v', 0), SenseInfo('01406356-v', 0), SenseInfo('01365355-v', 0), SenseInfo('01292534-v', 0), SenseInfo('00636888-v', 0) ],
"_timepiece_n_1_rel" : [ SenseInfo('04437953-n', 1) ],
"_hard+put_a_1_rel" : [ SenseInfo('02457558-a', 1) ],
"_disposition_n_of_rel" : [ SenseInfo('04623612-n', 2), SenseInfo('00043609-n', 1), SenseInfo('06196584-n', 0), SenseInfo('04942869-n', 0), SenseInfo('04623612-n', 2), SenseInfo('00043609-n', 1), SenseInfo('06196584-n', 0), SenseInfo('04942869-n', 0) ],
"_customization_n_1_rel" : [  ],
"_pin_v_on_rel" : [ SenseInfo('01207149-v', 2), SenseInfo('01368264-v', 1), SenseInfo('01444723-v', 0), SenseInfo('01121621-v', 0) ],
"_replay_n_of_rel" : [ SenseInfo('07343195-n', 0), SenseInfo('01020117-n', 0) ],
"_recruit_n_1_rel" : [ SenseInfo('10512372-n', 2), SenseInfo('10512201-n', 2) ],
"_southeast_n_of_rel" : [ SenseInfo('13832841-n', 1), SenseInfo('08563478-n', 1), SenseInfo('13835781-n', 0), SenseInfo('08561462-n', 0), SenseInfo('13832841-n', 1), SenseInfo('08563478-n', 1), SenseInfo('13835781-n', 0), SenseInfo('08561462-n', 0), SenseInfo('13832841-n', 1), SenseInfo('08563478-n', 1), SenseInfo('13835781-n', 0), SenseInfo('08561462-n', 0), SenseInfo('13832841-n', 1), SenseInfo('08563478-n', 1), SenseInfo('13835781-n', 0), SenseInfo('08561462-n', 0), SenseInfo('13832841-n', 1), SenseInfo('08563478-n', 1), SenseInfo('13835781-n', 0), SenseInfo('08561462-n', 0), SenseInfo('13832841-n', 1), SenseInfo('08563478-n', 1), SenseInfo('13835781-n', 0), SenseInfo('08561462-n', 0), SenseInfo('13832841-n', 1), SenseInfo('08563478-n', 1), SenseInfo('13835781-n', 0), SenseInfo('08561462-n', 0) ],
"_flagpole_n_1_rel" : [ SenseInfo('04053767-n', 0), SenseInfo('03355925-n', 0) ],
"_roller+skate_n_1_rel" : [ SenseInfo('04102618-n', 1) ],
"_nay_n_1_rel" : [ SenseInfo('07205210-n', 1) ],
"_cancel_v_out_rel" : [ SenseInfo('02477755-v', 9), SenseInfo('02717831-v', 0), SenseInfo('02477334-v', 0), SenseInfo('01549187-v', 0), SenseInfo('00800460-v', 0), SenseInfo('02477755-v', 9), SenseInfo('02717831-v', 0), SenseInfo('02477334-v', 0), SenseInfo('01549187-v', 0), SenseInfo('00800460-v', 0) ],
"_society_n_of_rel" : [ SenseInfo('07966140-n', 88), SenseInfo('08227214-n', 6), SenseInfo('13929588-n', 0), SenseInfo('08387930-n', 0) ],
"_piling_n_1_rel" : [ SenseInfo('03936269-n', 0) ],
"_rose_a_1_rel" : [ SenseInfo('00382173-a', 1) ],
"_rebel_v_against_rel" : [ SenseInfo('02583139-v', 5), SenseInfo('02583379-v', 2), SenseInfo('02583139-v', 5), SenseInfo('02583379-v', 2) ],
"_paddle_n_1_rel" : [ SenseInfo('03873848-n', 0), SenseInfo('03873699-n', 0), SenseInfo('03873574-n', 0), SenseInfo('03873416-n', 0) ],
"_field_v_1_rel" : [ SenseInfo('01082290-v', 1), SenseInfo('01081852-v', 1), SenseInfo('00815539-v', 0), SenseInfo('00675592-v', 0) ],
"_schedule_n_1_rel" : [ SenseInfo('05910940-n', 11), SenseInfo('06495328-n', 6), SenseInfo('05910940-n', 11), SenseInfo('06495328-n', 6) ],
"_spurn_v_1_rel" : [ SenseInfo('00796976-v', 2) ],
"_mountaintop_n_1_rel" : [  ],
"_AS_n_abb_rel" : [ SenseInfo('14629149-n', 0), SenseInfo('08991878-n', 0), SenseInfo('14629149-n', 0), SenseInfo('08991878-n', 0) ],
"_unto_p_rel" : [  ],
"_warp_n_1_rel" : [ SenseInfo('14504726-n', 0), SenseInfo('13885700-n', 0), SenseInfo('07434102-n', 0), SenseInfo('04551950-n', 0) ],
"_gratify_v_1_rel" : [ SenseInfo('01816431-v', 2), SenseInfo('01182293-v', 0), SenseInfo('01816431-v', 2), SenseInfo('01182293-v', 0), SenseInfo('01816431-v', 2), SenseInfo('01182293-v', 0), SenseInfo('01816431-v', 2), SenseInfo('01182293-v', 0), SenseInfo('01816431-v', 2), SenseInfo('01182293-v', 0), SenseInfo('01816431-v', 2), SenseInfo('01182293-v', 0) ],
"_comment_v_to_rel" : [ SenseInfo('01058574-v', 23), SenseInfo('01033189-v', 1), SenseInfo('00961329-v', 0) ],
"_coupling_n_1_rel" : [ SenseInfo('04613158-n', 2), SenseInfo('03119510-n', 0), SenseInfo('00847340-n', 0) ],
"_token_a_1_rel" : [ SenseInfo('01496592-a', 0) ],
"_cc_v_1_rel" : [  ],
"_wounded_n_1_rel" : [ SenseInfo('07950786-n', 1) ],
"_gingerly_a_1_rel" : [ SenseInfo('00325995-a', 1), SenseInfo('00325995-a', 1) ],
"_saline_n_1_rel" : [ SenseInfo('14590293-n', 27) ],
"_outraged_a_1_rel" : [ SenseInfo('00115494-a', 1), SenseInfo('00115494-a', 1) ],
"_carapace_n_1_rel" : [ SenseInfo('01903756-n', 0) ],
"_unappetizing_a_1_rel" : [ SenseInfo('00133851-a', 0), SenseInfo('00133851-a', 0) ],
"_axis_n_1_rel" : [ SenseInfo('06008609-n', 6), SenseInfo('13128771-n', 0), SenseInfo('08171792-n', 0), SenseInfo('08171094-n', 0), SenseInfo('05588840-n', 0), SenseInfo('02764614-n', 0) ],
"_advance_v_2_rel" : [ SenseInfo('01992503-v', 7), SenseInfo('00875806-v', 6), SenseInfo('00497061-v', 5), SenseInfo('02554922-v', 4), SenseInfo('01993926-v', 4), SenseInfo('01111028-v', 3), SenseInfo('00248659-v', 2), SenseInfo('00558371-v', 1), SenseInfo('02397637-v', 0), SenseInfo('02283949-v', 0), SenseInfo('01994288-v', 0), SenseInfo('00158222-v', 0) ],
"_happen_v_on_rel" : [ SenseInfo('00339934-v', 149), SenseInfo('00344643-v', 20), SenseInfo('02593912-v', 17), SenseInfo('00344174-v', 9), SenseInfo('02248465-v', 0) ],
"_package_n_of_rel" : [ SenseInfo('08008017-n', 3), SenseInfo('03871083-n', 3), SenseInfo('06566077-n', 0) ],
"_angle_v_1_rel" : [ SenseInfo('02044866-v', 2), SenseInfo('02038357-v', 0), SenseInfo('01319346-v', 0), SenseInfo('01141612-v', 0), SenseInfo('00680485-v', 0) ],
"_idyllic_a_1_rel" : [ SenseInfo('01751465-a', 2), SenseInfo('01801446-a', 0) ],
"_strake_n_1_rel" : [ SenseInfo('04544805-n', 0) ],
"_luscious_a_1_rel" : [ SenseInfo('02132967-a', 1), SenseInfo('02396720-a', 0) ],
"_twin_v_1_rel" : [ SenseInfo('02659358-v', 0), SenseInfo('01292885-v', 0), SenseInfo('00246125-v', 0), SenseInfo('00057665-v', 0) ],
"_move_v_from-to_rel" : [ SenseInfo('01835496-v', 110), SenseInfo('01850315-v', 57), SenseInfo('01831531-v', 52), SenseInfo('01855606-v', 20), SenseInfo('02372605-v', 15), SenseInfo('00014549-v', 7), SenseInfo('00124442-v', 6), SenseInfo('02367363-v', 3), SenseInfo('01767949-v', 3), SenseInfo('01649999-v', 3), SenseInfo('01771390-v', 2), SenseInfo('02355959-v', 1), SenseInfo('00539110-v', 1), SenseInfo('02598863-v', 0), SenseInfo('01076615-v', 0), SenseInfo('00879356-v', 0) ],
"_wicket_n_1_rel" : [ SenseInfo('04582869-n', 0), SenseInfo('04582771-n', 0), SenseInfo('04582625-n', 0), SenseInfo('04582454-n', 0) ],
"_matt_a_1_rel" : [ SenseInfo('00283972-a', 0) ],
"_glaze_n_1_rel" : [ SenseInfo('07621001-n', 0), SenseInfo('04955554-n', 0), SenseInfo('04701039-n', 0) ],
"_pit_n_1_rel" : [ SenseInfo('09393108-n', 5), SenseInfo('13872211-n', 0), SenseInfo('11684739-n', 0), SenseInfo('05629682-n', 0), SenseInfo('03950113-n', 0), SenseInfo('03949924-n', 0), SenseInfo('03949761-n', 0), SenseInfo('03949663-n', 0), SenseInfo('03949442-n', 0), SenseInfo('03853291-n', 0), SenseInfo('03070396-n', 0) ],
"_fetch_v_1_rel" : [ SenseInfo('01433294-v', 3), SenseInfo('02247390-v', 0), SenseInfo('01433674-v', 0), SenseInfo('01433294-v', 3), SenseInfo('02247390-v', 0), SenseInfo('01433674-v', 0) ],
"_export_v_1_rel" : [ SenseInfo('02346409-v', 4), SenseInfo('02232877-v', 0), SenseInfo('01379097-v', 0) ],
"_strop_n_1_rel" : [ SenseInfo('04341288-n', 0) ],
"_thin_a_1_rel" : [ SenseInfo('02412164-a', 16), SenseInfo('00988232-a', 15), SenseInfo('02562566-a', 7), SenseInfo('00542359-a', 2), SenseInfo('02417301-a', 1), SenseInfo('01458054-a', 0), SenseInfo('02282277-a', 0), SenseInfo('02164913-a', 0), SenseInfo('02412164-a', 16), SenseInfo('00988232-a', 15), SenseInfo('02562566-a', 7), SenseInfo('00542359-a', 2), SenseInfo('02417301-a', 1), SenseInfo('01458054-a', 0), SenseInfo('02282277-a', 0), SenseInfo('02164913-a', 0), SenseInfo('02412164-a', 16), SenseInfo('00988232-a', 15), SenseInfo('02562566-a', 7), SenseInfo('00542359-a', 2), SenseInfo('02417301-a', 1), SenseInfo('01458054-a', 0), SenseInfo('02282277-a', 0), SenseInfo('02164913-a', 0) ],
"_treble_v_cause_rel" : [ SenseInfo('01051271-v', 0), SenseInfo('00246746-v', 0) ],
"_physiotherapist_n_1_rel" : [ SenseInfo('10427764-n', 0) ],
"_indent_v_1_rel" : [ SenseInfo('01745377-v', 0), SenseInfo('01279833-v', 0), SenseInfo('01279631-v', 0), SenseInfo('01277173-v', 0), SenseInfo('00885569-v', 0) ],
"_treasury_n_1_rel" : [ SenseInfo('13356985-n', 7), SenseInfo('08120235-n', 2), SenseInfo('13394326-n', 0), SenseInfo('10727458-n', 0), SenseInfo('08139795-n', 0), SenseInfo('04477825-n', 0) ],
"_precocious_a_1_rel" : [ SenseInfo('01839829-a', 1), SenseInfo('00819051-a', 0) ],
"_perch_v_1_rel" : [ SenseInfo('01543731-v', 6), SenseInfo('01978700-v', 0), SenseInfo('01611240-v', 0), SenseInfo('01543731-v', 6), SenseInfo('01978700-v', 0), SenseInfo('01611240-v', 0) ],
"_sampling_n_of_rel" : [ SenseInfo('00161888-n', 4), SenseInfo('06026635-n', 0), SenseInfo('01004775-n', 0) ],
"_passageway_n_1_rel" : [ SenseInfo('03895585-n', 2), SenseInfo('05248181-n', 1) ],
"_roost_n_1_rel" : [ SenseInfo('04107984-n', 0), SenseInfo('04107870-n', 0) ],
"_mourner_n_1_rel" : [ SenseInfo('10335246-n', 2) ],
"_hump_n_1_rel" : [ SenseInfo('13894434-n', 0) ],
"_act_v_out_rel" : [ SenseInfo('02367363-v', 35), SenseInfo('00010435-v', 22), SenseInfo('01719302-v', 7), SenseInfo('01095899-v', 4), SenseInfo('00013615-v', 1), SenseInfo('02744977-v', 0), SenseInfo('02525447-v', 0), SenseInfo('02419073-v', 0), SenseInfo('01721556-v', 0), SenseInfo('01719921-v', 0) ],
"_scented_a_1_rel" : [ SenseInfo('01058179-a', 2), SenseInfo('01052888-a', 1), SenseInfo('01052611-a', 1), SenseInfo('01057103-a', 0) ],
"_coax_v_1_rel" : [ SenseInfo('00768778-v', 5), SenseInfo('00768778-v', 5), SenseInfo('00768778-v', 5) ],
"_marxist_n_1_rel" : [ SenseInfo('10297140-n', 0), SenseInfo('09863749-n', 0) ],
"_mink_n_1_rel" : [ SenseInfo('14765497-n', 0), SenseInfo('03770954-n', 0), SenseInfo('02442845-n', 0), SenseInfo('14765497-n', 0), SenseInfo('03770954-n', 0), SenseInfo('02442845-n', 0) ],
"_degree_n_fht_rel" : [ SenseInfo('05093890-n', 25), SenseInfo('13939892-n', 17), SenseInfo('06697331-n', 13), SenseInfo('13611207-n', 7), SenseInfo('05861317-n', 6), SenseInfo('13714184-n', 1), SenseInfo('05094565-n', 0), SenseInfo('05093890-n', 25), SenseInfo('13939892-n', 17), SenseInfo('06697331-n', 13), SenseInfo('13611207-n', 7), SenseInfo('05861317-n', 6), SenseInfo('13714184-n', 1), SenseInfo('05094565-n', 0), SenseInfo('05093890-n', 25), SenseInfo('13939892-n', 17), SenseInfo('06697331-n', 13), SenseInfo('13611207-n', 7), SenseInfo('05861317-n', 6), SenseInfo('13714184-n', 1), SenseInfo('05094565-n', 0), SenseInfo('05093890-n', 25), SenseInfo('13939892-n', 17), SenseInfo('06697331-n', 13), SenseInfo('13611207-n', 7), SenseInfo('05861317-n', 6), SenseInfo('13714184-n', 1), SenseInfo('05094565-n', 0), SenseInfo('05093890-n', 25), SenseInfo('13939892-n', 17), SenseInfo('06697331-n', 13), SenseInfo('13611207-n', 7), SenseInfo('05861317-n', 6), SenseInfo('13714184-n', 1), SenseInfo('05094565-n', 0), SenseInfo('05093890-n', 25), SenseInfo('13939892-n', 17), SenseInfo('06697331-n', 13), SenseInfo('13611207-n', 7), SenseInfo('05861317-n', 6), SenseInfo('13714184-n', 1), SenseInfo('05094565-n', 0), SenseInfo('05093890-n', 25), SenseInfo('13939892-n', 17), SenseInfo('06697331-n', 13), SenseInfo('13611207-n', 7), SenseInfo('05861317-n', 6), SenseInfo('13714184-n', 1), SenseInfo('05094565-n', 0), SenseInfo('05093890-n', 25), SenseInfo('13939892-n', 17), SenseInfo('06697331-n', 13), SenseInfo('13611207-n', 7), SenseInfo('05861317-n', 6), SenseInfo('13714184-n', 1), SenseInfo('05094565-n', 0) ],
"_infuriate_v_1_rel" : [ SenseInfo('01786906-v', 3), SenseInfo('01786906-v', 3), SenseInfo('01786906-v', 3), SenseInfo('01786906-v', 3), SenseInfo('01786906-v', 3) ],
"_so-called_a_1_rel" : [ SenseInfo('01916555-a', 13), SenseInfo('01916555-a', 13) ],
"_crummy_a_1_rel" : [ SenseInfo('02346013-a', 2), SenseInfo('02346013-a', 2), SenseInfo('02346013-a', 2) ],
"_tomfoolery_n_1_rel" : [ SenseInfo('00512843-n', 0) ],
"_geodesic_a_1_rel" : [ SenseInfo('02993362-a', 0) ],
"_patterning_n_1_rel" : [  ],
"_splint_v_1_rel" : [ SenseInfo('00083661-v', 0) ],
"_steer_v_1_rel" : [ SenseInfo('01931768-v', 4), SenseInfo('01935104-v', 3), SenseInfo('02439732-v', 1) ],
"_withhold_v_from_rel" : [ SenseInfo('02213690-v', 8), SenseInfo('02215001-v', 1) ],
"_battery_n_of_rel" : [ SenseInfo('08389572-n', 21), SenseInfo('02810471-n', 9), SenseInfo('07953827-n', 2), SenseInfo('08077177-n', 0), SenseInfo('02810782-n', 0), SenseInfo('00987863-n', 0), SenseInfo('00768203-n', 0), SenseInfo('08389572-n', 21), SenseInfo('02810471-n', 9), SenseInfo('07953827-n', 2), SenseInfo('08077177-n', 0), SenseInfo('02810782-n', 0), SenseInfo('00987863-n', 0), SenseInfo('00768203-n', 0) ],
"_educator_n_1_rel" : [ SenseInfo('10045713-n', 9) ],
"_greenery_n_1_rel" : [ SenseInfo('13153633-n', 0) ],
"_surprise_n_1_rel" : [ SenseInfo('07510348-n', 16), SenseInfo('07298154-n', 5), SenseInfo('00553655-n', 0), SenseInfo('07510348-n', 16), SenseInfo('07298154-n', 5), SenseInfo('00553655-n', 0) ],
"_fantastical_n_1_rel" : [ SenseInfo('01936778-a', 0), SenseInfo('00967646-a', 0) ],
"_cloister_n_1_rel" : [ SenseInfo('04073948-n', 0), SenseInfo('03047941-n', 0) ],
"_muster_v_1_rel" : [ SenseInfo('01381549-v', 4), SenseInfo('00793271-v', 2) ],
"_snatch_n_1_rel" : [ SenseInfo('07009042-n', 0), SenseInfo('05521514-n', 0), SenseInfo('00775702-n', 0), SenseInfo('00627196-n', 0), SenseInfo('00138956-n', 0) ],
"_forestry_n_1_rel" : [ SenseInfo('06071934-n', 0) ],
"_throughout_p_rel" : [ SenseInfo('00103087-r', 3), SenseInfo('00257106-r', 0), SenseInfo('00103087-r', 3), SenseInfo('00257106-r', 0) ],
"_bouillon_n_1_rel" : [ SenseInfo('07584938-n', 0) ],
"_steep_v_cause_rel" : [ SenseInfo('00601043-v', 2), SenseInfo('00327362-v', 0) ],
"_hack_n_1_rel" : [ SenseInfo('10154601-n', 1), SenseInfo('10278805-n', 0), SenseInfo('10154740-n', 0), SenseInfo('03474467-n', 0), SenseInfo('02930766-n', 0), SenseInfo('02382204-n', 0), SenseInfo('02382132-n', 0), SenseInfo('02378969-n', 0) ],
"_countrypeople_n_1_rel" : [  ],
"_stud_n_1_rel" : [ SenseInfo('10665587-n', 0), SenseInfo('04343346-n', 0), SenseInfo('04143365-n', 0), SenseInfo('02377291-n', 0), SenseInfo('00498220-n', 0) ],
"_site-selective_a_1_rel" : [  ],
"_adaptable_a_1_rel" : [ SenseInfo('01027263-a', 1) ],
"_rock-andn-roll_n_1_rel" : [  ],
"_threadlike_a_1_rel" : [ SenseInfo('02413851-a', 0) ],
"_rust_v_in_rel" : [ SenseInfo('00273963-v', 2), SenseInfo('00274283-v', 0), SenseInfo('00239614-v', 0) ],
"_deviation_n_from_rel" : [ SenseInfo('07366289-n', 2), SenseInfo('06022291-n', 1), SenseInfo('04802776-n', 0), SenseInfo('00737399-n', 0), SenseInfo('00350380-n', 0) ],
"_indeed_a_1_rel" : [  ],
"_trousers_n_1_rel" : [ SenseInfo('04489008-n', 3), SenseInfo('04488530-n', 0), SenseInfo('04489008-n', 3), SenseInfo('04488530-n', 0) ],
"_hayfield_n_1_rel" : [ SenseInfo('08570634-n', 1) ],
"_accessory_n_1_rel" : [ SenseInfo('02671780-n', 1), SenseInfo('02671421-n', 1), SenseInfo('09759875-n', 0), SenseInfo('02671780-n', 1), SenseInfo('02671421-n', 1), SenseInfo('09759875-n', 0), SenseInfo('02671780-n', 1), SenseInfo('02671421-n', 1), SenseInfo('09759875-n', 0) ],
"_world_n_of_rel" : [ SenseInfo('09466280-n', 49), SenseInfo('07965937-n', 34), SenseInfo('05809878-n', 31), SenseInfo('09270894-n', 26), SenseInfo('08179689-n', 16), SenseInfo('09480809-n', 6), SenseInfo('05670972-n', 5), SenseInfo('02472987-n', 0) ],
"_constraint_n_1_rel" : [ SenseInfo('13998781-n', 0), SenseInfo('04081844-n', 0), SenseInfo('01149621-n', 0), SenseInfo('13998781-n', 0), SenseInfo('04081844-n', 0), SenseInfo('01149621-n', 0) ],
"_ink_v_1_rel" : [ SenseInfo('00997020-v', 0), SenseInfo('00509100-v', 0), SenseInfo('00453680-v', 0) ],
"_hoof_n_1_rel" : [ SenseInfo('02153959-n', 7), SenseInfo('02154133-n', 0) ],
"_capital_a_1_rel" : [ SenseInfo('02342778-a', 0), SenseInfo('01852548-a', 0), SenseInfo('01467919-a', 0) ],
"_hexagonal_a_1_rel" : [ SenseInfo('02741797-a', 0), SenseInfo('02741797-a', 0) ],
"_grass_n_1_rel" : [ SenseInfo('12102133-n', 41), SenseInfo('11012153-n', 0), SenseInfo('10675481-n', 0), SenseInfo('07801091-n', 0), SenseInfo('03990834-n', 0) ],
"_recap_v_1_rel" : [ SenseInfo('01008903-v', 0) ],
"_ssn_n_1_rel" : [  ],
"_inner_a_1_rel" : [ SenseInfo('00951831-a', 16), SenseInfo('00950272-a', 5), SenseInfo('01348835-a', 3), SenseInfo('01863066-a', 2), SenseInfo('01862891-a', 0), SenseInfo('00948985-a', 0), SenseInfo('00951831-a', 16), SenseInfo('00950272-a', 5), SenseInfo('01348835-a', 3), SenseInfo('01863066-a', 2), SenseInfo('01862891-a', 0), SenseInfo('00948985-a', 0) ],
"_last_v_1_rel" : [ SenseInfo('02704928-v', 19), SenseInfo('02618149-v', 7), SenseInfo('02704928-v', 19), SenseInfo('02618149-v', 7), SenseInfo('02704928-v', 19), SenseInfo('02618149-v', 7) ],
"_hassle_v_1_rel" : [ SenseInfo('01789514-v', 0) ],
"_mail_n_1_rel" : [ SenseInfo('06275634-n', 2), SenseInfo('06264398-n', 2), SenseInfo('03709644-n', 1), SenseInfo('08463063-n', 0), SenseInfo('03000247-n', 0) ],
"_bum_n_1_rel" : [ SenseInfo('10539715-n', 2), SenseInfo('10723300-n', 1), SenseInfo('10197967-n', 0), SenseInfo('05559256-n', 0) ],
"_lock_v_down_rel" : [ SenseInfo('01348174-v', 8), SenseInfo('01510827-v', 7), SenseInfo('00219775-v', 4), SenseInfo('01606736-v', 2), SenseInfo('01606018-v', 2), SenseInfo('01810320-v', 1), SenseInfo('01347678-v', 1), SenseInfo('02050865-v', 0), SenseInfo('01655347-v', 0) ],
"_darn+near_x_deg_rel" : [  ],
"_electron+volt_n_1_rel" : [ SenseInfo('13725902-n', 0) ],
"_double_v_up_rel" : [ SenseInfo('00246217-v', 12), SenseInfo('01409523-v', 2), SenseInfo('02063309-v', 1), SenseInfo('01525505-v', 1), SenseInfo('02300425-v', 0), SenseInfo('01734502-v', 0), SenseInfo('00246217-v', 12), SenseInfo('01409523-v', 2), SenseInfo('02063309-v', 1), SenseInfo('01525505-v', 1), SenseInfo('02300425-v', 0), SenseInfo('01734502-v', 0) ],
"_hold_v_i_rel" : [ SenseInfo('02681795-v', 79), SenseInfo('01216670-v', 65), SenseInfo('01733477-v', 62), SenseInfo('02203362-v', 26), SenseInfo('00693780-v', 20), SenseInfo('01773130-v', 17), SenseInfo('01301410-v', 17), SenseInfo('02283324-v', 14), SenseInfo('02302220-v', 9), SenseInfo('01217043-v', 9), SenseInfo('02700867-v', 7), SenseInfo('02732798-v', 3), SenseInfo('02683489-v', 3), SenseInfo('01601234-v', 3), SenseInfo('02648502-v', 2), SenseInfo('00683771-v', 2), SenseInfo('02746275-v', 1), SenseInfo('02701210-v', 1), SenseInfo('02498320-v', 1), SenseInfo('01129876-v', 1), SenseInfo('00885217-v', 1), SenseInfo('00736586-v', 1), SenseInfo('00607000-v', 1), SenseInfo('02706816-v', 0), SenseInfo('02676789-v', 0), SenseInfo('02643574-v', 0), SenseInfo('02510337-v', 0), SenseInfo('02450989-v', 0), SenseInfo('02441897-v', 0), SenseInfo('01859586-v', 0), SenseInfo('01334744-v', 0), SenseInfo('01205153-v', 0), SenseInfo('01151753-v', 0), SenseInfo('00822367-v', 0), SenseInfo('00805376-v', 0), SenseInfo('00004492-v', 0) ],
"_troublesome_a_1_rel" : [ SenseInfo('00748795-a', 3) ],
"_torture_v_1_rel" : [ SenseInfo('01802689-v', 3), SenseInfo('00071178-v', 1) ],
"_ivory_n_1_rel" : [ SenseInfo('14757547-n', 6), SenseInfo('04961331-n', 2) ],
"_invalidate_v_1_rel" : [ SenseInfo('02478059-v', 1), SenseInfo('00800460-v', 0), SenseInfo('00667102-v', 0), SenseInfo('00448440-v', 0) ],
"_widespread_a_1_rel" : [ SenseInfo('01102876-a', 9), SenseInfo('00541614-a', 3) ],
"_lyophilize_v_1_rel" : [ SenseInfo('00212236-v', 1) ],
"_energy-intensive_a_1_rel" : [  ],
"_guerrilla_n_1_rel" : [ SenseInfo('10150556-n', 3) ],
"_determination_n_of_rel" : [ SenseInfo('00151497-n', 7), SenseInfo('04864200-n', 3), SenseInfo('05838176-n', 1), SenseInfo('05788552-n', 0), SenseInfo('00162632-n', 0), SenseInfo('00151497-n', 7), SenseInfo('04864200-n', 3), SenseInfo('05838176-n', 1), SenseInfo('05788552-n', 0), SenseInfo('00162632-n', 0), SenseInfo('00151497-n', 7), SenseInfo('04864200-n', 3), SenseInfo('05838176-n', 1), SenseInfo('05788552-n', 0), SenseInfo('00162632-n', 0) ],
"_burble_v_1_rel" : [ SenseInfo('02187922-v', 0), SenseInfo('02187922-v', 0) ],
"_smooth_v_over_rel" : [ SenseInfo('01252971-v', 7), SenseInfo('01245637-v', 1), SenseInfo('02313098-v', 0) ],
"_leftwing_a_1_rel" : [  ],
"_passion_n_for_rel" : [ SenseInfo('07480896-n', 4), SenseInfo('04628192-n', 3), SenseInfo('14039179-n', 1), SenseInfo('09181557-n', 1), SenseInfo('07488788-n', 1), SenseInfo('05813229-n', 1), SenseInfo('14325220-n', 0) ],
"_erupt_v_to_rel" : [ SenseInfo('00345508-v', 6), SenseInfo('00307785-v', 2), SenseInfo('02760622-v', 1), SenseInfo('00548266-v', 1), SenseInfo('00307568-v', 1), SenseInfo('01785395-v', 0), SenseInfo('00422899-v', 0), SenseInfo('00309074-v', 0) ],
"_subjection_n_of_rel" : [ SenseInfo('13996300-n', 0), SenseInfo('00089027-n', 0) ],
"_constitutional_a_1_rel" : [ SenseInfo('02702332-a', 0), SenseInfo('00179925-a', 0), SenseInfo('01348528-a', 0), SenseInfo('00901345-a', 0) ],
"_total_n_of_rel" : [ SenseInfo('04353803-n', 13), SenseInfo('05861067-n', 6), SenseInfo('04353803-n', 13), SenseInfo('05861067-n', 6), SenseInfo('04353803-n', 13), SenseInfo('05861067-n', 6) ],
"_commentator_n_1_rel" : [ SenseInfo('10369528-n', 2), SenseInfo('09942431-n', 0) ],
"_naprapath_n_1_rel" : [ SenseInfo('09625309-n', 1) ],
"_lever_n_1_rel" : [ SenseInfo('03659292-n', 1), SenseInfo('03659809-n', 0), SenseInfo('03659686-n', 0) ],
"_tense_v_1_rel" : [ SenseInfo('01572728-v', 0), SenseInfo('00536304-v', 0), SenseInfo('00026153-v', 0), SenseInfo('00025203-v', 0) ],
"_mire_n_1_rel" : [ SenseInfo('09355850-n', 1), SenseInfo('14956523-n', 0), SenseInfo('14410365-n', 0) ],
"_halt_v_1_rel" : [ SenseInfo('01859586-v', 8), SenseInfo('01860795-v', 7), SenseInfo('02559752-v', 4), SenseInfo('00354452-v', 0) ],
"_sail_v_cause_rel" : [ SenseInfo('01846658-v', 13), SenseInfo('01869563-v', 3), SenseInfo('01945516-v', 1), SenseInfo('01846320-v', 0) ],
"_emphatic_a_1_rel" : [ SenseInfo('02319765-a', 1), SenseInfo('00842041-a', 0), SenseInfo('00156575-a', 0), SenseInfo('02319765-a', 1), SenseInfo('00842041-a', 0), SenseInfo('00156575-a', 0) ],
"_noxious_a_1_rel" : [ SenseInfo('01611067-a', 0) ],
"_concerto_n_1_rel" : [ SenseInfo('07043275-n', 3) ],
"_prompting_n_1_rel" : [ SenseInfo('07246582-n', 0), SenseInfo('07011803-n', 0) ],
"_firmly_x_deg_rel" : [ SenseInfo('00050817-r', 11), SenseInfo('00224700-r', 5), SenseInfo('00091964-r', 2) ],
"_generalize_v_about_rel" : [ SenseInfo('01022420-v', 6), SenseInfo('01022906-v', 0), SenseInfo('00970215-v', 0), SenseInfo('00104465-v', 0) ],
"_gaussian_a_1_rel" : [ SenseInfo('03028005-a', 0) ],
"_timetable_n_of_rel" : [ SenseInfo('06496499-n', 1), SenseInfo('06496397-n', 0) ],
"_worrying_a_1_rel" : [ SenseInfo('01189386-a', 0), SenseInfo('01189386-a', 0) ],
"_haircut_n_1_rel" : [ SenseInfo('05257593-n', 2), SenseInfo('00359822-n', 0) ],
"_expense_v_1_rel" : [ SenseInfo('00315956-v', 0) ],
"_glow_n_1_rel" : [ SenseInfo('14051056-n', 3), SenseInfo('05018785-n', 3), SenseInfo('11467786-n', 1), SenseInfo('07480521-n', 1), SenseInfo('11463544-n', 0), SenseInfo('11463371-n', 0), SenseInfo('04954534-n', 0) ],
"_synonymous_a_1_rel" : [ SenseInfo('02381302-a', 1) ],
"_peeved_a_1_rel" : [ SenseInfo('01806106-a', 0) ],
"_marital_a_1_rel" : [ SenseInfo('02852920-a', 2) ],
"_profound_a_1_rel" : [ SenseInfo('01872745-a', 12), SenseInfo('01512645-a', 8), SenseInfo('02162934-a', 0), SenseInfo('00693237-a', 0), SenseInfo('00693020-a', 0), SenseInfo('00691141-a', 0), SenseInfo('01872745-a', 12), SenseInfo('01512645-a', 8), SenseInfo('02162934-a', 0), SenseInfo('00693237-a', 0), SenseInfo('00693020-a', 0), SenseInfo('00691141-a', 0), SenseInfo('01872745-a', 12), SenseInfo('01512645-a', 8), SenseInfo('02162934-a', 0), SenseInfo('00693237-a', 0), SenseInfo('00693020-a', 0), SenseInfo('00691141-a', 0), SenseInfo('01872745-a', 12), SenseInfo('01512645-a', 8), SenseInfo('02162934-a', 0), SenseInfo('00693237-a', 0), SenseInfo('00693020-a', 0), SenseInfo('00691141-a', 0) ],
"_fire_v_on_rel" : [ SenseInfo('01135783-v', 30), SenseInfo('01133825-v', 16), SenseInfo('00320536-v', 10), SenseInfo('02402825-v', 7), SenseInfo('01134238-v', 5), SenseInfo('02002410-v', 1), SenseInfo('01759326-v', 1), SenseInfo('00378664-v', 1), SenseInfo('02356420-v', 0) ],
"_obscenity_n_1_rel" : [ SenseInfo('04903368-n', 1), SenseInfo('07124340-n', 0), SenseInfo('00738697-n', 0) ],
"_morphology_n_1_rel" : [ SenseInfo('06078327-n', 1), SenseInfo('06178042-n', 0), SenseInfo('06177729-n', 0), SenseInfo('06117855-n', 0) ],
"_phase+out_n_1_rel" : [ SenseInfo('01023138-n', 0), SenseInfo('01023138-n', 0) ],
"_intoxication_n_1_rel" : [ SenseInfo('14509712-n', 0), SenseInfo('14018567-n', 0), SenseInfo('07528807-n', 0) ],
"_peter_v_out_rel" : [  ],
"_nearness_n_1_rel" : [ SenseInfo('05085572-n', 1) ],
"_fly_n_1_rel" : [ SenseInfo('02190166-n', 6), SenseInfo('04412097-n', 1), SenseInfo('03373060-n', 1), SenseInfo('00128638-n', 1), SenseInfo('03373237-n', 0) ],
"_reservation_n_of_rel" : [ SenseInfo('08587174-n', 5), SenseInfo('06762380-n', 1), SenseInfo('05698620-n', 1), SenseInfo('01218327-n', 1), SenseInfo('07177772-n', 0), SenseInfo('05795460-n', 0), SenseInfo('00820091-n', 0), SenseInfo('08587174-n', 5), SenseInfo('06762380-n', 1), SenseInfo('05698620-n', 1), SenseInfo('01218327-n', 1), SenseInfo('07177772-n', 0), SenseInfo('05795460-n', 0), SenseInfo('00820091-n', 0), SenseInfo('08587174-n', 5), SenseInfo('06762380-n', 1), SenseInfo('05698620-n', 1), SenseInfo('01218327-n', 1), SenseInfo('07177772-n', 0), SenseInfo('05795460-n', 0), SenseInfo('00820091-n', 0) ],
"_laud_v_1_rel" : [ SenseInfo('00860620-v', 0) ],
"_stranding_n_1_rel" : [  ],
"_scourge_n_1_rel" : [ SenseInfo('04149968-n', 1), SenseInfo('14445226-n', 0), SenseInfo('10702615-n', 0) ],
"_locomotive_n_1_rel" : [ SenseInfo('03684823-n', 0) ],
"_sabotage_n_1_rel" : [ SenseInfo('01244895-n', 2) ],
"_macaroni_n_1_rel" : [ SenseInfo('10278263-n', 0), SenseInfo('07700964-n', 0) ],
"_rectangular_a_1_rel" : [ SenseInfo('02048977-a', 1), SenseInfo('01720642-a', 1) ],
"_proprietor_n_1_rel" : [ SenseInfo('10388924-n', 11) ],
"_presario_n_1_rel" : [  ],
"_obliteration_n_of_rel" : [ SenseInfo('00218208-n', 2), SenseInfo('07331013-n', 0) ],
"_bring_v_off_rel" : [ SenseInfo('02077656-v', 122), SenseInfo('01438902-v', 55), SenseInfo('01629589-v', 31), SenseInfo('01433294-v', 19), SenseInfo('00135857-v', 9), SenseInfo('01434140-v', 4), SenseInfo('01618547-v', 3), SenseInfo('02324478-v', 2), SenseInfo('02247390-v', 1), SenseInfo('01808218-v', 0), SenseInfo('00767334-v', 0) ],
"_sanipractor_n_1_rel" : [  ],
"_allusion_n_1_rel" : [ SenseInfo('06766544-n', 7) ],
"_crest_v_1_rel" : [ SenseInfo('02693168-v', 0), SenseInfo('02007777-v', 0) ],
"_accommodate_v_1_rel" : [ SenseInfo('02702830-v', 5), SenseInfo('00299580-v', 5), SenseInfo('01184453-v', 3), SenseInfo('02732798-v', 2), SenseInfo('02651424-v', 0), SenseInfo('00885925-v', 0), SenseInfo('00482893-v', 0), SenseInfo('02702830-v', 5), SenseInfo('00299580-v', 5), SenseInfo('01184453-v', 3), SenseInfo('02732798-v', 2), SenseInfo('02651424-v', 0), SenseInfo('00885925-v', 0), SenseInfo('00482893-v', 0), SenseInfo('02702830-v', 5), SenseInfo('00299580-v', 5), SenseInfo('01184453-v', 3), SenseInfo('02732798-v', 2), SenseInfo('02651424-v', 0), SenseInfo('00885925-v', 0), SenseInfo('00482893-v', 0) ],
"_masonry_n_1_rel" : [ SenseInfo('03725717-n', 2), SenseInfo('08235513-n', 0), SenseInfo('00608896-n', 0) ],
"_manufacturer_n_of_rel" : [ SenseInfo('08060446-n', 16), SenseInfo('10292316-n', 4) ],
"_doe_n_1_rel" : [ SenseInfo('08132955-n', 0), SenseInfo('01888411-n', 0) ],
"_tent_n_1_rel" : [ SenseInfo('04411264-n', 17), SenseInfo('09455910-n', 0) ],
"_success_n_1_rel" : [ SenseInfo('07319103-n', 36), SenseInfo('00063652-n', 23), SenseInfo('14474894-n', 10), SenseInfo('09762821-n', 3) ],
"_menial_a_1_rel" : [ SenseInfo('02229961-a', 1) ],
"_object_v_1_rel" : [ SenseInfo('00807461-v', 19), SenseInfo('02753865-v', 0), SenseInfo('00807461-v', 19), SenseInfo('02753865-v', 0) ],
"_barren_a_1_rel" : [ SenseInfo('01242750-a', 0), SenseInfo('01002664-a', 0), SenseInfo('00927978-a', 0) ],
"_discourage_v_from_rel" : [ SenseInfo('00908099-v', 12), SenseInfo('01819147-v', 3), SenseInfo('00870577-v', 2) ],
"_brew_v_1_rel" : [ SenseInfo('01663920-v', 0), SenseInfo('00327813-v', 0) ],
"_sail_n_i_rel" : [ SenseInfo('04127904-n', 1), SenseInfo('00312932-n', 1), SenseInfo('04128413-n', 0) ],
"_taper_n_1_rel" : [ SenseInfo('13902793-n', 0), SenseInfo('05071368-n', 0), SenseInfo('04581829-n', 0), SenseInfo('02948072-n', 0) ],
"_drachma_n_1_rel" : [ SenseInfo('13722340-n', 0), SenseInfo('13675218-n', 0), SenseInfo('13722340-n', 0), SenseInfo('13675218-n', 0), SenseInfo('13722340-n', 0), SenseInfo('13675218-n', 0), SenseInfo('13722340-n', 0), SenseInfo('13675218-n', 0) ],
"_native_a_1_rel" : [ SenseInfo('01036083-a', 5), SenseInfo('01033996-a', 2), SenseInfo('01037148-a', 1), SenseInfo('01906975-a', 0), SenseInfo('01036083-a', 5), SenseInfo('01033996-a', 2), SenseInfo('01037148-a', 1), SenseInfo('01906975-a', 0) ],
"_experiment_v_with_rel" : [ SenseInfo('02532595-v', 17), SenseInfo('02532886-v', 0) ],
"_bore_n_1_rel" : [ SenseInfo('09867437-n', 0), SenseInfo('07403920-n', 0), SenseInfo('05103283-n', 0), SenseInfo('02875233-n', 0) ],
"_carnivorous_a_1_rel" : [ SenseInfo('02680580-a', 0), SenseInfo('00313387-a', 0) ],
"_hail_n_1_rel" : [ SenseInfo('11465530-n', 3), SenseInfo('09300905-n', 0), SenseInfo('06631050-n', 0) ],
"_kick_v_up_rel" : [ SenseInfo('01371756-v', 11), SenseInfo('01936233-v', 9), SenseInfo('01370561-v', 7), SenseInfo('02048511-v', 0), SenseInfo('01371454-v', 0), SenseInfo('01196524-v', 0), SenseInfo('01112979-v', 0), SenseInfo('00907147-v', 0), SenseInfo('01371756-v', 11), SenseInfo('01936233-v', 9), SenseInfo('01370561-v', 7), SenseInfo('02048511-v', 0), SenseInfo('01371454-v', 0), SenseInfo('01196524-v', 0), SenseInfo('01112979-v', 0), SenseInfo('00907147-v', 0) ],
"_ruffle_v_cause_rel" : [ SenseInfo('02040054-v', 1), SenseInfo('01789047-v', 1), SenseInfo('01916634-v', 0), SenseInfo('01790538-v', 0), SenseInfo('01591357-v', 0), SenseInfo('01418667-v', 0), SenseInfo('01391806-v', 0), SenseInfo('01387493-v', 0), SenseInfo('01387301-v', 0) ],
"_split_v_1_rel" : [ SenseInfo('02467662-v', 4), SenseInfo('01556572-v', 3), SenseInfo('02431320-v', 2), SenseInfo('02030158-v', 2), SenseInfo('00309310-v', 2), SenseInfo('02467662-v', 4), SenseInfo('01556572-v', 3), SenseInfo('02431320-v', 2), SenseInfo('02030158-v', 2), SenseInfo('00309310-v', 2), SenseInfo('02467662-v', 4), SenseInfo('01556572-v', 3), SenseInfo('02431320-v', 2), SenseInfo('02030158-v', 2), SenseInfo('00309310-v', 2), SenseInfo('02467662-v', 4), SenseInfo('01556572-v', 3), SenseInfo('02431320-v', 2), SenseInfo('02030158-v', 2), SenseInfo('00309310-v', 2) ],
"_prim_a_1_rel" : [ SenseInfo('01948092-a', 0), SenseInfo('01880163-a', 0), SenseInfo('01948092-a', 0), SenseInfo('01880163-a', 0), SenseInfo('01948092-a', 0), SenseInfo('01880163-a', 0), SenseInfo('01948092-a', 0), SenseInfo('01880163-a', 0) ],
"_last+will_n_1_rel" : [  ],
"_scuba_n_1_rel" : [ SenseInfo('02731629-n', 0) ],
"_self-serve_a_1_rel" : [  ],
"_pad_n_1_rel" : [ SenseInfo('14973133-n', 1), SenseInfo('13154586-n', 0), SenseInfo('03872885-n', 0), SenseInfo('03872495-n', 0), SenseInfo('03647691-n', 0), SenseInfo('03195485-n', 0), SenseInfo('02440523-n', 0) ],
"_lining_n_1_rel" : [ SenseInfo('03673767-n', 0), SenseInfo('03673270-n', 0), SenseInfo('00827379-n', 0), SenseInfo('00827240-n', 0) ],
"_stay_v_prd_rel" : [ SenseInfo('00117985-v', 43), SenseInfo('01857392-v', 32), SenseInfo('02637202-v', 22), SenseInfo('02727462-v', 17), SenseInfo('02009200-v', 7), SenseInfo('00460900-v', 3), SenseInfo('02731024-v', 0), SenseInfo('02619122-v', 0), SenseInfo('02560021-v', 0), SenseInfo('01344643-v', 0), SenseInfo('01194114-v', 0) ],
"_hygiene_n_1_rel" : [ SenseInfo('14495080-n', 0), SenseInfo('06051380-n', 0) ],
"_text_n_of_rel" : [ SenseInfo('06387980-n', 53), SenseInfo('07172557-n', 0), SenseInfo('06414372-n', 0), SenseInfo('06388579-n', 0) ],
"_toy_v_with_rel" : [ SenseInfo('02437465-v', 0), SenseInfo('01586278-v', 0), SenseInfo('00013328-v', 0) ],
"_accomplishment_n_1_rel" : [ SenseInfo('00035189-n', 7), SenseInfo('05637558-n', 0) ],
"_distress_n_1_rel" : [ SenseInfo('07496463-n', 4), SenseInfo('14476852-n', 3), SenseInfo('14326072-n', 0), SenseInfo('00085829-n', 0) ],
"_dizzy_a_1_rel" : [ SenseInfo('02544048-a', 1), SenseInfo('02120828-a', 1), SenseInfo('02544048-a', 1), SenseInfo('02120828-a', 1), SenseInfo('02544048-a', 1), SenseInfo('02120828-a', 1), SenseInfo('02544048-a', 1), SenseInfo('02120828-a', 1) ],
"_entertainer_n_1_rel" : [ SenseInfo('09616922-n', 1) ],
"_cycle_n_1_rel" : [ SenseInfo('15287830-n', 4), SenseInfo('08377332-n', 2), SenseInfo('07342495-n', 2), SenseInfo('15279104-n', 1), SenseInfo('07341038-n', 1), SenseInfo('02834778-n', 0) ],
"_conform_v_1_rel" : [ SenseInfo('02662979-v', 1), SenseInfo('00150287-v', 1) ],
"_loin_n_1_rel" : [ SenseInfo('07658678-n', 0), SenseInfo('02463403-n', 0) ],
"_residential_a_1_rel" : [ SenseInfo('00485044-a', 13), SenseInfo('03109795-a', 5) ],
"_Chinese-American_a_1_rel" : [  ],
"_sigh_n_1_rel" : [ SenseInfo('07129602-n', 6), SenseInfo('07393756-n', 0) ],
"_cry_v_for_rel" : [ SenseInfo('00913065-v', 17), SenseInfo('00066191-v', 12), SenseInfo('00912048-v', 11), SenseInfo('00974786-v', 2), SenseInfo('01188987-v', 0), SenseInfo('00985464-v', 0), SenseInfo('00066685-v', 0) ],
"_bilateral_a_1_rel" : [ SenseInfo('02372118-a', 1), SenseInfo('01946012-a', 0), SenseInfo('00237788-a', 0) ],
"_coexistent_a_1_rel" : [ SenseInfo('02378347-a', 1), SenseInfo('02378347-a', 1) ],
"_sod_n_1_rel" : [ SenseInfo('09463919-n', 4), SenseInfo('15065025-n', 0), SenseInfo('10621514-n', 0), SenseInfo('10621140-n', 0) ],
"_takeover_n_of_rel" : [ SenseInfo('01145015-n', 1), SenseInfo('00789906-n', 0) ],
"_road+east_n_1_rel" : [  ],
"_heave_v_1_rel" : [ SenseInfo('00986586-v', 5), SenseInfo('01507792-v', 3), SenseInfo('02041206-v', 2), SenseInfo('01455866-v', 2), SenseInfo('02088470-v', 1), SenseInfo('00005526-v', 1), SenseInfo('00356954-v', 0), SenseInfo('00077458-v', 0), SenseInfo('00986586-v', 5), SenseInfo('01507792-v', 3), SenseInfo('02041206-v', 2), SenseInfo('01455866-v', 2), SenseInfo('02088470-v', 1), SenseInfo('00005526-v', 1), SenseInfo('00356954-v', 0), SenseInfo('00077458-v', 0) ],
"_loch_n_1_rel" : [ SenseInfo('09341987-n', 0), SenseInfo('09341874-n', 0) ],
"_fighter_n_1_rel" : [ SenseInfo('09939313-n', 6), SenseInfo('03335030-n', 3), SenseInfo('09906538-n', 1) ],
"_pursuer_n_1_rel" : [ SenseInfo('10494935-n', 3), SenseInfo('10495167-n', 0) ],
"_mhmm_a_1_rel" : [  ],
"_guild_n_1_rel" : [ SenseInfo('08227214-n', 0) ],
"_gas_v_up_rel" : [ SenseInfo('01125373-v', 1), SenseInfo('00883226-v', 0), SenseInfo('01125373-v', 1), SenseInfo('00883226-v', 0) ],
"_frontier_n_1_rel" : [ SenseInfo('08505402-n', 1), SenseInfo('08501114-n', 0), SenseInfo('05998052-n', 0) ],
"_fly_v_1_rel" : [ SenseInfo('01940403-v', 33), SenseInfo('01842068-v', 9), SenseInfo('01941093-v', 5), SenseInfo('01451842-v', 3), SenseInfo('01848058-v', 2), SenseInfo('01839404-v', 2), SenseInfo('00545292-v', 2), SenseInfo('02073065-v', 1), SenseInfo('01840238-v', 1), SenseInfo('02140965-v', 0), SenseInfo('02075462-v', 0), SenseInfo('01847845-v', 0), SenseInfo('01402765-v', 0), SenseInfo('00153061-v', 0) ],
"_flipper_n_1_rel" : [ SenseInfo('03364156-n', 0), SenseInfo('02465084-n', 0) ],
"_scarlet_n_1_rel" : [ SenseInfo('04964977-n', 0) ],
"_announce_v_to_rel" : [ SenseInfo('00974367-v', 74), SenseInfo('00965871-v', 13), SenseInfo('00975427-v', 2), SenseInfo('00974173-v', 2), SenseInfo('00974367-v', 74), SenseInfo('00965871-v', 13), SenseInfo('00975427-v', 2), SenseInfo('00974173-v', 2) ],
"_defender_n_of_rel" : [ SenseInfo('09614684-n', 3), SenseInfo('09615211-n', 0) ],
"_stand-out_n_1_rel" : [  ],
"_approximation_n_of_rel" : [ SenseInfo('05803379-n', 3), SenseInfo('04744032-n', 1), SenseInfo('06783442-n', 0), SenseInfo('00146277-n', 0) ],
"_vulgar_n_1_rel" : [ SenseInfo('01950198-a', 2), SenseInfo('01593079-a', 0), SenseInfo('01046226-a', 0), SenseInfo('00683531-a', 0) ],
"_less_a_1_rel" : [ SenseInfo('01555416-a', 39), SenseInfo('02347371-a', 0), SenseInfo('01556913-a', 0), SenseInfo('01555416-a', 39), SenseInfo('02347371-a', 0), SenseInfo('01556913-a', 0), SenseInfo('01555416-a', 39), SenseInfo('02347371-a', 0), SenseInfo('01556913-a', 0) ],
"_haul_v_up_rel" : [ SenseInfo('01454810-v', 7), SenseInfo('01452255-v', 5) ],
"_nosedive_n_1_rel" : [ SenseInfo('13523088-n', 0), SenseInfo('00326677-n', 0) ],
"_godmother_n_1_rel" : [ SenseInfo('10134870-n', 0) ],
"_grocer_n_1_rel" : [ SenseInfo('10147710-n', 5) ],
"_lao_a_1_rel" : [ SenseInfo('03079803-a', 3) ],
"_plug_n_of_rel" : [ SenseInfo('03967942-n', 15), SenseInfo('07579399-n', 0), SenseInfo('07248507-n', 0), SenseInfo('04269270-n', 0), SenseInfo('03968293-n', 0), SenseInfo('03346898-n', 0), SenseInfo('02382204-n', 0) ],
"_drown_v_cause_rel" : [ SenseInfo('01339294-v', 3), SenseInfo('00472532-v', 2), SenseInfo('00360501-v', 2), SenseInfo('00479060-v', 1), SenseInfo('02755911-v', 0) ],
"_snowpatrol_n_1_rel" : [  ],
"_gamut_n_1_rel" : [ SenseInfo('05128096-n', 2), SenseInfo('06857487-n', 0) ],
"_shaky_a_1_rel" : [ SenseInfo('02292797-a', 1), SenseInfo('02304565-a', 0), SenseInfo('02095037-a', 0), SenseInfo('02292797-a', 1), SenseInfo('02304565-a', 0), SenseInfo('02095037-a', 0), SenseInfo('02292797-a', 1), SenseInfo('02304565-a', 0), SenseInfo('02095037-a', 0) ],
"_how+long_x_rel" : [  ],
"_implication_n_of_rel" : [ SenseInfo('05780885-n', 9), SenseInfo('05920791-n', 6), SenseInfo('07238102-n', 1), SenseInfo('13860281-n', 0), SenseInfo('13793776-n', 0), SenseInfo('05780885-n', 9), SenseInfo('05920791-n', 6), SenseInfo('07238102-n', 1), SenseInfo('13860281-n', 0), SenseInfo('13793776-n', 0) ],
"_implicit_n_1_rel" : [ SenseInfo('00941485-a', 3), SenseInfo('00005599-a', 0) ],
"_second-guess_v_1_rel" : [ SenseInfo('00917651-v', 0), SenseInfo('00917537-v', 0), SenseInfo('00917651-v', 0), SenseInfo('00917537-v', 0) ],
"_impetuous_a_1_rel" : [ SenseInfo('00326608-a', 2), SenseInfo('00842704-a', 0) ],
"_delighted_a_1_rel" : [ SenseInfo('01805730-a', 3), SenseInfo('00865620-a', 0), SenseInfo('01805730-a', 3), SenseInfo('00865620-a', 0) ],
"_interfere_v_1_rel" : [ SenseInfo('02451912-v', 11), SenseInfo('02538765-v', 3) ],
"_hydropower_n_1_rel" : [  ],
"_banish_v_from_rel" : [ SenseInfo('02504017-v', 3), SenseInfo('02504280-v', 1), SenseInfo('02503803-v', 1), SenseInfo('02003359-v', 1), SenseInfo('02504017-v', 3), SenseInfo('02504280-v', 1), SenseInfo('02503803-v', 1), SenseInfo('02003359-v', 1) ],
"_notwithstanding_p_rel" : [ SenseInfo('00027384-r', 1), SenseInfo('00027384-r', 1) ],
"_workbook_n_1_rel" : [ SenseInfo('06415791-n', 0) ],
"_trader_n_1_rel" : [ SenseInfo('10720453-n', 5) ],
"_thus+far_a_1_rel" : [  ],
"_weather_n_1_rel" : [ SenseInfo('11524662-n', 20) ],
"_junebug_n_1_rel" : [  ],
"_reason_n_for_rel" : [ SenseInfo('09178999-n', 76), SenseInfo('06739990-n', 29), SenseInfo('05651680-n', 3), SenseInfo('14379829-n', 1), SenseInfo('06740402-n', 1), SenseInfo('05819149-n', 0), SenseInfo('09178999-n', 76), SenseInfo('06739990-n', 29), SenseInfo('05651680-n', 3), SenseInfo('14379829-n', 1), SenseInfo('06740402-n', 1), SenseInfo('05819149-n', 0), SenseInfo('09178999-n', 76), SenseInfo('06739990-n', 29), SenseInfo('05651680-n', 3), SenseInfo('14379829-n', 1), SenseInfo('06740402-n', 1), SenseInfo('05819149-n', 0), SenseInfo('09178999-n', 76), SenseInfo('06739990-n', 29), SenseInfo('05651680-n', 3), SenseInfo('14379829-n', 1), SenseInfo('06740402-n', 1), SenseInfo('05819149-n', 0) ],
"_pipe_v_up_rel" : [ SenseInfo('00914420-v', 1), SenseInfo('01950295-v', 0), SenseInfo('01727684-v', 0), SenseInfo('01670645-v', 0) ],
"_nobleness_n_1_rel" : [ SenseInfo('04870340-n', 0) ],
"_or+vice+versa_a_1_rel" : [  ],
"_insanity_n_1_rel" : [ SenseInfo('14395018-n', 1) ],
"_tearjerker_n_1_rel" : [ SenseInfo('06374148-n', 0) ],
"_convenience_n_1_rel" : [ SenseInfo('14446493-n', 5), SenseInfo('04718563-n', 1), SenseInfo('04018667-n', 0), SenseInfo('02729965-n', 0) ],
"_chalk_v_up_rel" : [ SenseInfo('01690163-v', 0), SenseInfo('01690163-v', 0) ],
"_enlightenment_n_1_rel" : [ SenseInfo('05986395-n', 1), SenseInfo('13988224-n', 0), SenseInfo('08472590-n', 0) ],
"_trot_v_1_rel" : [ SenseInfo('01901447-v', 10), SenseInfo('01960779-v', 2), SenseInfo('01901660-v', 0) ],
"_drool_v_1_rel" : [ SenseInfo('01827425-v', 0), SenseInfo('00102974-v', 0) ],
"_put_v_together-of_rel" : [ SenseInfo('01494310-v', 138), SenseInfo('01493741-v', 98), SenseInfo('00981276-v', 28), SenseInfo('01160370-v', 6), SenseInfo('02271137-v', 3), SenseInfo('00673448-v', 2), SenseInfo('02111499-v', 0), SenseInfo('01706375-v', 0), SenseInfo('00735571-v', 0), SenseInfo('01494310-v', 138), SenseInfo('01493741-v', 98), SenseInfo('00981276-v', 28), SenseInfo('01160370-v', 6), SenseInfo('02271137-v', 3), SenseInfo('00673448-v', 2), SenseInfo('02111499-v', 0), SenseInfo('01706375-v', 0), SenseInfo('00735571-v', 0) ],
"_braid_v_cause_rel" : [ SenseInfo('01674717-v', 1), SenseInfo('01519727-v', 0), SenseInfo('01519569-v', 0) ],
"_abasement_n_1_rel" : [ SenseInfo('14440623-n', 1), SenseInfo('00273449-n', 0) ],
"_torment_v_1_rel" : [ SenseInfo('01802689-v', 1), SenseInfo('01803003-v', 0), SenseInfo('00071178-v', 0) ],
"_index_n_1_rel" : [ SenseInfo('13851067-n', 1), SenseInfo('06639674-n', 1), SenseInfo('06812417-n', 0), SenseInfo('06491786-n', 0), SenseInfo('05567381-n', 0) ],
"_nonesuch_n_1_rel" : [ SenseInfo('10325243-n', 0) ],
"_sober_a_1_rel" : [ SenseInfo('00799517-a', 5), SenseInfo('02119213-a', 5), SenseInfo('00405179-a', 1), SenseInfo('02123314-a', 0), SenseInfo('00799517-a', 5), SenseInfo('02119213-a', 5), SenseInfo('00405179-a', 1), SenseInfo('02123314-a', 0), SenseInfo('00799517-a', 5), SenseInfo('02119213-a', 5), SenseInfo('00405179-a', 1), SenseInfo('02123314-a', 0) ],
"_man_a_1_rel" : [ SenseInfo('10287213-n', 749), SenseInfo('10582746-n', 346), SenseInfo('10289039-n', 87), SenseInfo('02472293-n', 29), SenseInfo('10289176-n', 4), SenseInfo('10288763-n', 3), SenseInfo('10745332-n', 0), SenseInfo('10288516-n', 0), SenseInfo('08887716-n', 0), SenseInfo('03716327-n', 0), SenseInfo('02472987-n', 0), SenseInfo('10287213-n', 749), SenseInfo('10582746-n', 346), SenseInfo('10289039-n', 87), SenseInfo('02472293-n', 29), SenseInfo('10289176-n', 4), SenseInfo('10288763-n', 3), SenseInfo('10745332-n', 0), SenseInfo('10288516-n', 0), SenseInfo('08887716-n', 0), SenseInfo('03716327-n', 0), SenseInfo('02472987-n', 0) ],
"_sarcophagus_n_1_rel" : [ SenseInfo('04136045-n', 0) ],
"_commend_v_to_rel" : [ SenseInfo('00882395-v', 10), SenseInfo('01689169-v', 1), SenseInfo('00883112-v', 1), SenseInfo('00882948-v', 0), SenseInfo('00882523-v', 0) ],
"_annoyed_a_with_rel" : [ SenseInfo('01806106-a', 3), SenseInfo('02455845-a', 0) ],
"_reason_v_about_rel" : [ SenseInfo('00634472-v', 3), SenseInfo('00772189-v', 2), SenseInfo('00632627-v', 1) ],
"_barricade_n_1_rel" : [ SenseInfo('04096848-n', 2), SenseInfo('02796412-n', 1) ],
"_ppm_n_1_rel" : [  ],
"_all_x_deg_rel" : [ SenseInfo('02269286-a', 247), SenseInfo('00008007-r', 26), SenseInfo('00521584-a', 3) ],
"_madcap_a_1_rel" : [ SenseInfo('00326608-a', 0) ],
"_perfume_v_1_rel" : [ SenseInfo('02126382-v', 0), SenseInfo('00043480-v', 0) ],
"_curie_n_1_rel" : [ SenseInfo('13645599-n', 0), SenseInfo('10917999-n', 0), SenseInfo('10917703-n', 0) ],
"_pokey_a_1_rel" : [ SenseInfo('00981067-a', 0), SenseInfo('00637455-a', 0) ],
"_show_v_up_rel" : [ SenseInfo('02148788-v', 136), SenseInfo('00664788-v', 63), SenseInfo('01015244-v', 57), SenseInfo('02137132-v', 43), SenseInfo('01686956-v', 32), SenseInfo('00943837-v', 24), SenseInfo('00923793-v', 24), SenseInfo('02139544-v', 11), SenseInfo('00922867-v', 7), SenseInfo('00923307-v', 6), SenseInfo('02000547-v', 2), SenseInfo('01086549-v', 0), SenseInfo('02148788-v', 136), SenseInfo('00664788-v', 63), SenseInfo('01015244-v', 57), SenseInfo('02137132-v', 43), SenseInfo('01686956-v', 32), SenseInfo('00943837-v', 24), SenseInfo('00923793-v', 24), SenseInfo('02139544-v', 11), SenseInfo('00922867-v', 7), SenseInfo('00923307-v', 6), SenseInfo('02000547-v', 2), SenseInfo('01086549-v', 0) ],
"_humble_v_1_rel" : [ SenseInfo('01801697-v', 1), SenseInfo('01799794-v', 1), SenseInfo('01801697-v', 1), SenseInfo('01799794-v', 1), SenseInfo('01801697-v', 1), SenseInfo('01799794-v', 1), SenseInfo('01801697-v', 1), SenseInfo('01799794-v', 1), SenseInfo('01801697-v', 1), SenseInfo('01799794-v', 1) ],
"_historian_n_1_rel" : [ SenseInfo('10177150-n', 20) ],
"_nick_v_1_rel" : [ SenseInfo('01259141-v', 0), SenseInfo('01259005-v', 0), SenseInfo('00511318-v', 0), SenseInfo('00054535-v', 0) ],
"_clover_n_1_rel" : [ SenseInfo('11752578-n', 1) ],
"_gossip_n_1_rel" : [ SenseInfo('07135080-n', 3), SenseInfo('07223170-n', 2), SenseInfo('10139347-n', 0) ],
"_callosity_a_1_rel" : [ SenseInfo('14364566-n', 0), SenseInfo('04844625-n', 0) ],
"_centipede_n_1_rel" : [ SenseInfo('01784675-n', 0) ],
"_plasma_n_1_rel" : [ SenseInfo('05403427-n', 5), SenseInfo('14992165-n', 0), SenseInfo('14481511-n', 0) ],
"_immortal_n_1_rel" : [ SenseInfo('10199644-n', 0), SenseInfo('09505418-n', 0) ],
"_disapprove_v_of_rel" : [ SenseInfo('00674340-v', 5), SenseInfo('00807178-v', 2), SenseInfo('00674340-v', 5), SenseInfo('00807178-v', 2) ],
"_maker_n_of_rel" : [ SenseInfo('10284064-n', 8), SenseInfo('09536363-n', 0), SenseInfo('08060446-n', 0) ],
"_cross+country_n_1_rel" : [ SenseInfo('07460793-n', 0), SenseInfo('07460793-n', 0), SenseInfo('07460793-n', 0) ],
"_cupcake_n_1_rel" : [ SenseInfo('07631023-n', 0) ],
"_close_v_in_rel" : [ SenseInfo('01345109-v', 32), SenseInfo('01346978-v', 20), SenseInfo('02426395-v', 18), SenseInfo('02425913-v', 13), SenseInfo('02610628-v', 2), SenseInfo('00763831-v', 1), SenseInfo('02754276-v', 0), SenseInfo('02375619-v', 0), SenseInfo('02140781-v', 0), SenseInfo('02104503-v', 0), SenseInfo('02054541-v', 0), SenseInfo('02054382-v', 0), SenseInfo('01607288-v', 0), SenseInfo('01478423-v', 0), SenseInfo('01423285-v', 0), SenseInfo('01291941-v', 0), SenseInfo('00352137-v', 0), SenseInfo('01345109-v', 32), SenseInfo('01346978-v', 20), SenseInfo('02426395-v', 18), SenseInfo('02425913-v', 13), SenseInfo('02610628-v', 2), SenseInfo('00763831-v', 1), SenseInfo('02754276-v', 0), SenseInfo('02375619-v', 0), SenseInfo('02140781-v', 0), SenseInfo('02104503-v', 0), SenseInfo('02054541-v', 0), SenseInfo('02054382-v', 0), SenseInfo('01607288-v', 0), SenseInfo('01478423-v', 0), SenseInfo('01423285-v', 0), SenseInfo('01291941-v', 0), SenseInfo('00352137-v', 0) ],
"_hang_v_onto_rel" : [ SenseInfo('01482075-v', 35), SenseInfo('01481360-v', 12), SenseInfo('02485451-v', 11), SenseInfo('01977962-v', 6), SenseInfo('01542668-v', 5), SenseInfo('02734952-v', 2), SenseInfo('02170427-v', 1), SenseInfo('01481957-v', 1), SenseInfo('01216331-v', 1), SenseInfo('02741003-v', 0), SenseInfo('02557790-v', 0), SenseInfo('01677716-v', 0), SenseInfo('01481819-v', 0), SenseInfo('01481647-v', 0), SenseInfo('00210110-v', 0) ],
"_certain_a_1_rel" : [ SenseInfo('00700884-a', 131), SenseInfo('00336831-a', 16), SenseInfo('00335421-a', 8), SenseInfo('00340239-a', 4), SenseInfo('02087342-a', 0), SenseInfo('00724397-a', 0), SenseInfo('00309740-a', 0), SenseInfo('00700884-a', 131), SenseInfo('00336831-a', 16), SenseInfo('00335421-a', 8), SenseInfo('00340239-a', 4), SenseInfo('02087342-a', 0), SenseInfo('00724397-a', 0), SenseInfo('00309740-a', 0), SenseInfo('00700884-a', 131), SenseInfo('00336831-a', 16), SenseInfo('00335421-a', 8), SenseInfo('00340239-a', 4), SenseInfo('02087342-a', 0), SenseInfo('00724397-a', 0), SenseInfo('00309740-a', 0), SenseInfo('00700884-a', 131), SenseInfo('00336831-a', 16), SenseInfo('00335421-a', 8), SenseInfo('00340239-a', 4), SenseInfo('02087342-a', 0), SenseInfo('00724397-a', 0), SenseInfo('00309740-a', 0), SenseInfo('00700884-a', 131), SenseInfo('00336831-a', 16), SenseInfo('00335421-a', 8), SenseInfo('00340239-a', 4), SenseInfo('02087342-a', 0), SenseInfo('00724397-a', 0), SenseInfo('00309740-a', 0) ],
"_modern_n_1_rel" : [ SenseInfo('10326551-n', 2), SenseInfo('06826726-n', 0) ],
"_infirmity_n_1_rel" : [ SenseInfo('14547643-n', 1) ],
"_baggage+check_n_1_rel" : [  ],
"_refreshment_n_1_rel" : [ SenseInfo('07574504-n', 0), SenseInfo('00401783-n', 0) ],
"_district_n_1_rel" : [ SenseInfo('08552138-n', 38) ],
"_clean_v_out_rel" : [ SenseInfo('01532589-v', 16), SenseInfo('00177714-v', 3), SenseInfo('01533442-v', 2), SenseInfo('00035758-v', 1), SenseInfo('02741960-v', 0), SenseInfo('01608951-v', 0), SenseInfo('01608706-v', 0), SenseInfo('01532434-v', 0), SenseInfo('00180837-v', 0), SenseInfo('00177861-v', 0) ],
"_chivy_v_1_rel" : [ SenseInfo('01789514-v', 1) ],
"_look_v_into_rel" : [ SenseInfo('02130524-v', 274), SenseInfo('02133435-v', 126), SenseInfo('00033599-v', 25), SenseInfo('02153709-v', 8), SenseInfo('02693319-v', 1), SenseInfo('02549581-v', 1), SenseInfo('00929362-v', 1), SenseInfo('00720063-v', 1), SenseInfo('02658447-v', 0), SenseInfo('00712708-v', 0) ],
"_nameplate_n_1_rel" : [ SenseInfo('03806652-n', 0) ],
"_crane_v_1_rel" : [ SenseInfo('00028167-v', 2) ],
"_snare_n_1_rel" : [ SenseInfo('05837370-n', 1), SenseInfo('04249415-n', 0), SenseInfo('04249204-n', 0), SenseInfo('04249029-n', 0), SenseInfo('04248851-n', 0) ],
"_sevenfold_a_1_rel" : [ SenseInfo('02219876-a', 0), SenseInfo('02219876-a', 0) ],
"_entirely_x_rel" : [ SenseInfo('00008007-r', 43), SenseInfo('00008600-r', 2) ],
"_the+heck_x_rel" : [  ],
"_stuck+out_a_1_rel" : [  ],
"_apply_v_for_rel" : [ SenseInfo('01158872-v', 45), SenseInfo('02676789-v', 29), SenseInfo('00765396-v', 13), SenseInfo('01363648-v', 11), SenseInfo('02707429-v', 4), SenseInfo('02309165-v', 2), SenseInfo('02561332-v', 1), SenseInfo('02560164-v', 1), SenseInfo('01026558-v', 1), SenseInfo('02595523-v', 0) ],
"_showroom_n_1_rel" : [ SenseInfo('04209811-n', 1) ],
"_just+plain_a_1_rel" : [  ],
"_corroborate_v_1_rel" : [ SenseInfo('00665886-v', 3), SenseInfo('01012561-v', 1), SenseInfo('02663340-v', 0) ],
"_bronze_a_1_rel" : [ SenseInfo('00371945-a', 1), SenseInfo('01528644-a', 0) ],
"_skid_v_1_rel" : [ SenseInfo('01870867-v', 3), SenseInfo('01975121-v', 0), SenseInfo('01871217-v', 0), SenseInfo('01870275-v', 0), SenseInfo('01870867-v', 3), SenseInfo('01975121-v', 0), SenseInfo('01871217-v', 0), SenseInfo('01870275-v', 0) ],
"_overhaul_n_1_rel" : [ SenseInfo('00268112-n', 0), SenseInfo('00265119-n', 0) ],
"_strip_v_of_rel" : [ SenseInfo('02314275-v', 7), SenseInfo('00049900-v', 2), SenseInfo('01263479-v', 1), SenseInfo('00488617-v', 1), SenseInfo('00194912-v', 1), SenseInfo('02344568-v', 0), SenseInfo('01608706-v', 0), SenseInfo('01263659-v', 0), SenseInfo('00194812-v', 0), SenseInfo('00194696-v', 0), SenseInfo('00194534-v', 0), SenseInfo('00194079-v', 0), SenseInfo('00177243-v', 0) ],
"_italian_n_1_rel" : [ SenseInfo('09716047-n', 1), SenseInfo('06964247-n', 1) ],
"_quantity_n_of_rel" : [ SenseInfo('00033615-n', 15), SenseInfo('05108740-n', 7), SenseInfo('05855125-n', 0), SenseInfo('00033615-n', 15), SenseInfo('05108740-n', 7), SenseInfo('05855125-n', 0) ],
"_chapbook_n_1_rel" : [  ],
"_plane_n_1_rel" : [ SenseInfo('02691156-n', 21), SenseInfo('13861050-n', 16), SenseInfo('13941806-n', 3), SenseInfo('03955296-n', 0), SenseInfo('03954731-n', 0) ],
"_bleed_v_1_rel" : [ SenseInfo('00074834-v', 10), SenseInfo('00086077-v', 2), SenseInfo('02360003-v', 0), SenseInfo('02060792-v', 0), SenseInfo('00449153-v', 0) ],
"_paradigm_n_1_rel" : [ SenseInfo('13804375-n', 4), SenseInfo('05937524-n', 1), SenseInfo('06309684-n', 0), SenseInfo('06210171-n', 0) ],
"_baseline_n_1_rel" : [ SenseInfo('13854318-n', 1), SenseInfo('08650919-n', 0), SenseInfo('08573140-n', 0), SenseInfo('13854318-n', 1), SenseInfo('08650919-n', 0), SenseInfo('08573140-n', 0) ],
"_benefit_n_of_rel" : [ SenseInfo('13296899-n', 16), SenseInfo('05142641-n', 15), SenseInfo('06892534-n', 1), SenseInfo('13296899-n', 16), SenseInfo('05142641-n', 15), SenseInfo('06892534-n', 1), SenseInfo('13296899-n', 16), SenseInfo('05142641-n', 15), SenseInfo('06892534-n', 1), SenseInfo('13296899-n', 16), SenseInfo('05142641-n', 15), SenseInfo('06892534-n', 1) ],
"_depict_v_as_rel" : [ SenseInfo('01686956-v', 6), SenseInfo('00987071-v', 6), SenseInfo('01688256-v', 2), SenseInfo('01686956-v', 6), SenseInfo('00987071-v', 6), SenseInfo('01688256-v', 2), SenseInfo('01686956-v', 6), SenseInfo('00987071-v', 6), SenseInfo('01688256-v', 2), SenseInfo('01686956-v', 6), SenseInfo('00987071-v', 6), SenseInfo('01688256-v', 2) ],
"_think_v_of_rel" : [ SenseInfo('00689344-v', 274), SenseInfo('00631737-v', 188), SenseInfo('00628491-v', 111), SenseInfo('00607780-v', 8), SenseInfo('01637166-v', 4), SenseInfo('00723056-v', 3), SenseInfo('00708538-v', 2), SenseInfo('00739340-v', 0), SenseInfo('00739082-v', 0), SenseInfo('00689809-v', 0), SenseInfo('00629738-v', 0), SenseInfo('00608808-v', 0), SenseInfo('00561887-v', 0) ],
"_strict_a_with_rel" : [ SenseInfo('00915556-a', 3), SenseInfo('02506267-a', 2), SenseInfo('01299888-a', 0), SenseInfo('02436995-a', 0), SenseInfo('00711308-a', 0), SenseInfo('00915556-a', 3), SenseInfo('02506267-a', 2), SenseInfo('01299888-a', 0), SenseInfo('02436995-a', 0), SenseInfo('00711308-a', 0), SenseInfo('00915556-a', 3), SenseInfo('02506267-a', 2), SenseInfo('01299888-a', 0), SenseInfo('02436995-a', 0), SenseInfo('00711308-a', 0), SenseInfo('00915556-a', 3), SenseInfo('02506267-a', 2), SenseInfo('01299888-a', 0), SenseInfo('02436995-a', 0), SenseInfo('00711308-a', 0) ],
"_border_n_1_rel" : [ SenseInfo('08512736-n', 5), SenseInfo('13903387-n', 1), SenseInfo('08565701-n', 1), SenseInfo('03780247-n', 0), SenseInfo('02875013-n', 0) ],
"_understandable_a_1_rel" : [ SenseInfo('00533452-a', 6), SenseInfo('00533452-a', 6) ],
"_annoying_a_1_rel" : [ SenseInfo('00089550-a', 1), SenseInfo('00089550-a', 1) ],
"_ask_n_1_rel" : [  ],
"_annoyance_n_1_rel" : [ SenseInfo('14406573-n', 3), SenseInfo('07518261-n', 1), SenseInfo('09778537-n', 0), SenseInfo('05830059-n', 0), SenseInfo('00418394-n', 0) ],
"_cigar_n_1_rel" : [ SenseInfo('03030035-n', 7) ],
"_tap_n_of_rel" : [ SenseInfo('07388987-n', 3), SenseInfo('07410021-n', 0), SenseInfo('04559451-n', 0), SenseInfo('04391276-n', 0), SenseInfo('04391158-n', 0), SenseInfo('04390977-n', 0), SenseInfo('00654400-n', 0), SenseInfo('00125436-n', 0) ],
"_dig_v_in_rel" : [ SenseInfo('01309701-v', 9), SenseInfo('01311103-v', 5), SenseInfo('02419773-v', 0), SenseInfo('02143756-v', 0), SenseInfo('01899557-v', 0), SenseInfo('01310660-v', 0), SenseInfo('01229976-v', 0), SenseInfo('00588221-v', 0) ],
"_alive_a_1_rel" : [ SenseInfo('00094448-a', 14), SenseInfo('00805115-a', 3), SenseInfo('00118567-a', 0), SenseInfo('02106366-a', 0), SenseInfo('00927373-a', 0), SenseInfo('00190653-a', 0), SenseInfo('00041488-a', 0) ],
"_specify_v_1_rel" : [ SenseInfo('01018928-v', 6), SenseInfo('00947077-v', 4), SenseInfo('02611630-v', 3), SenseInfo('01021973-v', 2), SenseInfo('00715541-v', 1), SenseInfo('00709379-v', 0), SenseInfo('00677683-v', 0), SenseInfo('01018928-v', 6), SenseInfo('00947077-v', 4), SenseInfo('02611630-v', 3), SenseInfo('01021973-v', 2), SenseInfo('00715541-v', 1), SenseInfo('00709379-v', 0), SenseInfo('00677683-v', 0), SenseInfo('01018928-v', 6), SenseInfo('00947077-v', 4), SenseInfo('02611630-v', 3), SenseInfo('01021973-v', 2), SenseInfo('00715541-v', 1), SenseInfo('00709379-v', 0), SenseInfo('00677683-v', 0), SenseInfo('01018928-v', 6), SenseInfo('00947077-v', 4), SenseInfo('02611630-v', 3), SenseInfo('01021973-v', 2), SenseInfo('00715541-v', 1), SenseInfo('00709379-v', 0), SenseInfo('00677683-v', 0) ],
"_trim_n_1_rel" : [ SenseInfo('14497511-n', 1), SenseInfo('04484160-n', 1), SenseInfo('13828520-n', 0), SenseInfo('00359903-n', 0) ],
"_jobless_n_1_rel" : [ SenseInfo('00865007-a', 0) ],
"_moldy_a_1_rel" : [ SenseInfo('01070088-a', 0), SenseInfo('01070088-a', 0), SenseInfo('01070088-a', 0) ],
"_sickish_a_1_rel" : [ SenseInfo('02545689-a', 1) ],
"_exchange_v_for_rel" : [ SenseInfo('02257370-v', 10), SenseInfo('00161225-v', 2), SenseInfo('00140751-v', 1), SenseInfo('02393489-v', 0), SenseInfo('02257767-v', 0), SenseInfo('00161987-v', 0), SenseInfo('02257370-v', 10), SenseInfo('00161225-v', 2), SenseInfo('00140751-v', 1), SenseInfo('02393489-v', 0), SenseInfo('02257767-v', 0), SenseInfo('00161987-v', 0) ],
"_delay_n_1_rel" : [ SenseInfo('15272029-n', 2), SenseInfo('01066163-n', 2) ],
"_brave_v_1_rel" : [ SenseInfo('02707251-v', 1) ],
"_hefty_a_1_rel" : [ SenseInfo('02321809-a', 1), SenseInfo('01185775-a', 0), SenseInfo('00624576-a', 0), SenseInfo('02321809-a', 1), SenseInfo('01185775-a', 0), SenseInfo('00624576-a', 0), SenseInfo('02321809-a', 1), SenseInfo('01185775-a', 0), SenseInfo('00624576-a', 0) ],
"_exodus_n_1_rel" : [ SenseInfo('00060414-n', 1), SenseInfo('06432715-n', 0) ],
"_caffeine_n_1_rel" : [ SenseInfo('14761122-n', 0) ],
"_relent_v_1_rel" : [ SenseInfo('02703289-v', 3) ],
"_cypress_n_1_rel" : [ SenseInfo('11630890-n', 0), SenseInfo('11630489-n', 0) ],
"_in-depth_a_1_rel" : [  ],
"_spectroscopic_a_1_rel" : [ SenseInfo('02918271-a', 0) ],
"_grasshopper_n_1_rel" : [ SenseInfo('02226429-n', 4), SenseInfo('07915213-n', 0) ],
"_dismal_a_1_rel" : [ SenseInfo('00364881-a', 0), SenseInfo('00364881-a', 0) ],
"_sham_n_1_rel" : [ SenseInfo('03318438-n', 2), SenseInfo('10201535-n', 0) ],
"_subsidiary_n_1_rel" : [ SenseInfo('10669991-n', 0), SenseInfo('08003935-n', 0) ],
"_snow_v_2_rel" : [ SenseInfo('02758977-v', 10), SenseInfo('00839194-v', 0) ],
"_nearsightedness_n_1_rel" : [ SenseInfo('14553290-n', 0) ],
"_cite_v_for_rel" : [ SenseInfo('01024190-v', 13), SenseInfo('01023071-v', 4), SenseInfo('01705257-v', 3), SenseInfo('01023259-v', 2), SenseInfo('01023574-v', 0), SenseInfo('01015866-v', 0), SenseInfo('00791134-v', 0), SenseInfo('01024190-v', 13), SenseInfo('01023071-v', 4), SenseInfo('01705257-v', 3), SenseInfo('01023259-v', 2), SenseInfo('01023574-v', 0), SenseInfo('01015866-v', 0), SenseInfo('00791134-v', 0) ],
"_independent_a_of_rel" : [ SenseInfo('00727564-a', 26), SenseInfo('01062393-a', 2), SenseInfo('00730215-a', 0), SenseInfo('00731606-a', 0), SenseInfo('00727564-a', 26), SenseInfo('01062393-a', 2), SenseInfo('00730215-a', 0), SenseInfo('00731606-a', 0) ],
"_handicapped_a_1_rel" : [ SenseInfo('01019283-a', 2) ],
"_crack_v_down_rel" : [ SenseInfo('00336260-v', 6), SenseInfo('02183024-v', 4), SenseInfo('02182851-v', 2), SenseInfo('01401955-v', 2), SenseInfo('00539770-v', 2), SenseInfo('00337234-v', 1), SenseInfo('00337065-v', 1), SenseInfo('02571067-v', 0), SenseInfo('01785579-v', 0), SenseInfo('00953923-v', 0), SenseInfo('00336718-v', 0), SenseInfo('00238542-v', 0), SenseInfo('00238372-v', 0), SenseInfo('00336260-v', 6), SenseInfo('02183024-v', 4), SenseInfo('02182851-v', 2), SenseInfo('01401955-v', 2), SenseInfo('00539770-v', 2), SenseInfo('00337234-v', 1), SenseInfo('00337065-v', 1), SenseInfo('02571067-v', 0), SenseInfo('01785579-v', 0), SenseInfo('00953923-v', 0), SenseInfo('00336718-v', 0), SenseInfo('00238542-v', 0), SenseInfo('00238372-v', 0) ],
"_strike_v_out_rel" : [ SenseInfo('01410223-v', 18), SenseInfo('01767949-v', 16), SenseInfo('01236164-v', 14), SenseInfo('01123887-v', 7), SenseInfo('00923622-v', 5), SenseInfo('01209135-v', 4), SenseInfo('02412647-v', 3), SenseInfo('02611976-v', 2), SenseInfo('02526811-v', 2), SenseInfo('01209426-v', 2), SenseInfo('00143540-v', 2), SenseInfo('02286687-v', 1), SenseInfo('01675073-v', 1), SenseInfo('01549420-v', 1), SenseInfo('02108791-v', 0), SenseInfo('02104161-v', 0), SenseInfo('01982395-v', 0), SenseInfo('01639105-v', 0), SenseInfo('01308008-v', 0), SenseInfo('01228235-v', 0), SenseInfo('00635904-v', 0), SenseInfo('01410223-v', 18), SenseInfo('01767949-v', 16), SenseInfo('01236164-v', 14), SenseInfo('01123887-v', 7), SenseInfo('00923622-v', 5), SenseInfo('01209135-v', 4), SenseInfo('02412647-v', 3), SenseInfo('02611976-v', 2), SenseInfo('02526811-v', 2), SenseInfo('01209426-v', 2), SenseInfo('00143540-v', 2), SenseInfo('02286687-v', 1), SenseInfo('01675073-v', 1), SenseInfo('01549420-v', 1), SenseInfo('02108791-v', 0), SenseInfo('02104161-v', 0), SenseInfo('01982395-v', 0), SenseInfo('01639105-v', 0), SenseInfo('01308008-v', 0), SenseInfo('01228235-v', 0), SenseInfo('00635904-v', 0) ],
"_tomb_n_1_rel" : [ SenseInfo('03455033-n', 6) ],
"_caption_v_1_rel" : [ SenseInfo('02323870-v', 0) ],
"_simmer_v_1_rel" : [ SenseInfo('00324231-v', 5) ],
"_mod_p_rel" : [ SenseInfo('10324357-n', 0), SenseInfo('00972902-a', 0), SenseInfo('10324357-n', 0), SenseInfo('00972902-a', 0) ],
"_calender_n_1_rel" : [ SenseInfo('02939565-n', 0) ],
"_headline_n_1_rel" : [ SenseInfo('06344461-n', 3) ],
"_appurtenance_n_1_rel" : [ SenseInfo('03430959-n', 0), SenseInfo('02671421-n', 0) ],
"_chignon_n_1_rel" : [ SenseInfo('05259726-n', 1) ],
"_look_v_on_rel" : [ SenseInfo('02130524-v', 274), SenseInfo('02133435-v', 126), SenseInfo('00033599-v', 25), SenseInfo('02153709-v', 8), SenseInfo('02693319-v', 1), SenseInfo('02549581-v', 1), SenseInfo('00929362-v', 1), SenseInfo('00720063-v', 1), SenseInfo('02658447-v', 0), SenseInfo('00712708-v', 0) ],
"_taint_n_1_rel" : [ SenseInfo('14487731-n', 1) ],
"_limit_n_of_rel" : [ SenseInfo('05124057-n', 24), SenseInfo('15268857-n', 3), SenseInfo('08593130-n', 1), SenseInfo('08592656-n', 1), SenseInfo('13758556-n', 0), SenseInfo('13758296-n', 0) ],
"_mine_n_of_rel" : [ SenseInfo('03768346-n', 12), SenseInfo('03768132-n', 5) ],
"_hasp_n_1_rel" : [ SenseInfo('03497352-n', 1) ],
"_interviewer_n_of_rel" : [ SenseInfo('10213319-n', 2) ],
"_overseer_n_of_rel" : [ SenseInfo('10388732-n', 0) ],
"_addict_v_to_rel" : [ SenseInfo('01165290-v', 0) ],
"_search_v_for_rel" : [ SenseInfo('01315613-v', 13), SenseInfo('02153709-v', 11), SenseInfo('00648224-v', 3), SenseInfo('01317723-v', 2), SenseInfo('01315613-v', 13), SenseInfo('02153709-v', 11), SenseInfo('00648224-v', 3), SenseInfo('01317723-v', 2) ],
"_drop_v_cause_rel" : [ SenseInfo('01977701-v', 36), SenseInfo('01976841-v', 21), SenseInfo('00432683-v', 12), SenseInfo('01985923-v', 7), SenseInfo('02403920-v', 6), SenseInfo('00941446-v', 6), SenseInfo('00363110-v', 5), SenseInfo('01489465-v', 3), SenseInfo('01258302-v', 2), SenseInfo('01100008-v', 2), SenseInfo('02267060-v', 1), SenseInfo('00393534-v', 1), SenseInfo('02717472-v', 0), SenseInfo('02465939-v', 0), SenseInfo('01611516-v', 0), SenseInfo('01513430-v', 0), SenseInfo('01200661-v', 0), SenseInfo('00615615-v', 0), SenseInfo('00614999-v', 0), SenseInfo('00548616-v', 0), SenseInfo('00148341-v', 0), SenseInfo('00092293-v', 0), SenseInfo('00057764-v', 0), SenseInfo('01977701-v', 36), SenseInfo('01976841-v', 21), SenseInfo('00432683-v', 12), SenseInfo('01985923-v', 7), SenseInfo('02403920-v', 6), SenseInfo('00941446-v', 6), SenseInfo('00363110-v', 5), SenseInfo('01489465-v', 3), SenseInfo('01258302-v', 2), SenseInfo('01100008-v', 2), SenseInfo('02267060-v', 1), SenseInfo('00393534-v', 1), SenseInfo('02717472-v', 0), SenseInfo('02465939-v', 0), SenseInfo('01611516-v', 0), SenseInfo('01513430-v', 0), SenseInfo('01200661-v', 0), SenseInfo('00615615-v', 0), SenseInfo('00614999-v', 0), SenseInfo('00548616-v', 0), SenseInfo('00148341-v', 0), SenseInfo('00092293-v', 0), SenseInfo('00057764-v', 0) ],
"_write_v_down_rel" : [ SenseInfo('01698271-v', 112), SenseInfo('00993014-v', 94), SenseInfo('01744611-v', 33), SenseInfo('01007027-v', 15), SenseInfo('01031966-v', 10), SenseInfo('01705494-v', 9), SenseInfo('01691057-v', 8), SenseInfo('00998886-v', 4), SenseInfo('01699896-v', 1), SenseInfo('01692834-v', 0) ],
"_salute_n_1_rel" : [ SenseInfo('06688913-n', 0), SenseInfo('06633041-n', 0), SenseInfo('06632358-n', 0) ],
"_mist_v_cause_rel" : [ SenseInfo('00361495-v', 1), SenseInfo('02157731-v', 0), SenseInfo('01373303-v', 0) ],
"_revenge_n_1_rel" : [ SenseInfo('01235258-n', 8) ],
"_exclude_v_1_rel" : [ SenseInfo('00615774-v', 15), SenseInfo('02449340-v', 7), SenseInfo('02633714-v', 3), SenseInfo('00796588-v', 2), SenseInfo('01468576-v', 0) ],
"_substratum_n_1_rel" : [ SenseInfo('08660146-n', 0), SenseInfo('08657887-n', 0), SenseInfo('06903699-n', 0) ],
"_recital_n_1_rel" : [ SenseInfo('07220773-n', 1), SenseInfo('06893441-n', 1), SenseInfo('07234881-n', 0), SenseInfo('07234735-n', 0), SenseInfo('07221756-n', 0) ],
"_rustle_v_cause_rel" : [ SenseInfo('02182662-v', 7), SenseInfo('02277138-v', 3), SenseInfo('02270090-v', 0) ],
"_mince_n_1_rel" : [ SenseInfo('07650903-n', 0) ],
"_hang_v_out-2_rel" : [ SenseInfo('01482075-v', 35), SenseInfo('01481360-v', 12), SenseInfo('02485451-v', 11), SenseInfo('01977962-v', 6), SenseInfo('01542668-v', 5), SenseInfo('02734952-v', 2), SenseInfo('02170427-v', 1), SenseInfo('01481957-v', 1), SenseInfo('01216331-v', 1), SenseInfo('02741003-v', 0), SenseInfo('02557790-v', 0), SenseInfo('01677716-v', 0), SenseInfo('01481819-v', 0), SenseInfo('01481647-v', 0), SenseInfo('00210110-v', 0) ],
"_walkway_n_1_rel" : [ SenseInfo('04544979-n', 0) ],
"_subsequent_a_1_rel" : [ SenseInfo('00122626-a', 5), SenseInfo('00122626-a', 5) ],
"_flawed_a_1_rel" : [ SenseInfo('01752553-a', 0) ],
"_outright_a_1_rel" : [ SenseInfo('01914407-a', 1), SenseInfo('01914407-a', 1) ],
"_cud_n_1_rel" : [ SenseInfo('07805478-n', 1), SenseInfo('07579399-n', 0) ],
"_sunshiny_a_1_rel" : [  ],
"_back_v_out-of_rel" : [ SenseInfo('02453889-v', 7), SenseInfo('01997119-v', 6), SenseInfo('02556817-v', 4), SenseInfo('01997512-v', 4), SenseInfo('02217695-v', 2), SenseInfo('02693965-v', 0), SenseInfo('01139104-v', 0), SenseInfo('00560628-v', 0), SenseInfo('00223109-v', 0), SenseInfo('00185857-v', 0) ],
"_dearth_n_1_rel" : [ SenseInfo('14449865-n', 0), SenseInfo('05117140-n', 0) ],
"_academical_a_1_rel" : [  ],
"_conform_v_to_rel" : [ SenseInfo('02662979-v', 1), SenseInfo('00150287-v', 1) ],
"_coral_a_1_rel" : [ SenseInfo('00373621-a', 0) ],
"_talkative_a_1_rel" : [ SenseInfo('02384077-a', 1), SenseInfo('00773299-a', 0), SenseInfo('00496938-a', 0) ],
"_ballet_n_1_rel" : [ SenseInfo('00528667-n', 4), SenseInfo('07054336-n', 1) ],
"_write_v_to_rel" : [ SenseInfo('01698271-v', 112), SenseInfo('00993014-v', 94), SenseInfo('01744611-v', 33), SenseInfo('01007027-v', 15), SenseInfo('01031966-v', 10), SenseInfo('01705494-v', 9), SenseInfo('01691057-v', 8), SenseInfo('00998886-v', 4), SenseInfo('01699896-v', 1), SenseInfo('01692834-v', 0), SenseInfo('01698271-v', 112), SenseInfo('00993014-v', 94), SenseInfo('01744611-v', 33), SenseInfo('01007027-v', 15), SenseInfo('01031966-v', 10), SenseInfo('01705494-v', 9), SenseInfo('01691057-v', 8), SenseInfo('00998886-v', 4), SenseInfo('01699896-v', 1), SenseInfo('01692834-v', 0), SenseInfo('01698271-v', 112), SenseInfo('00993014-v', 94), SenseInfo('01744611-v', 33), SenseInfo('01007027-v', 15), SenseInfo('01031966-v', 10), SenseInfo('01705494-v', 9), SenseInfo('01691057-v', 8), SenseInfo('00998886-v', 4), SenseInfo('01699896-v', 1), SenseInfo('01692834-v', 0), SenseInfo('01698271-v', 112), SenseInfo('00993014-v', 94), SenseInfo('01744611-v', 33), SenseInfo('01007027-v', 15), SenseInfo('01031966-v', 10), SenseInfo('01705494-v', 9), SenseInfo('01691057-v', 8), SenseInfo('00998886-v', 4), SenseInfo('01699896-v', 1), SenseInfo('01692834-v', 0), SenseInfo('01698271-v', 112), SenseInfo('00993014-v', 94), SenseInfo('01744611-v', 33), SenseInfo('01007027-v', 15), SenseInfo('01031966-v', 10), SenseInfo('01705494-v', 9), SenseInfo('01691057-v', 8), SenseInfo('00998886-v', 4), SenseInfo('01699896-v', 1), SenseInfo('01692834-v', 0), SenseInfo('01698271-v', 112), SenseInfo('00993014-v', 94), SenseInfo('01744611-v', 33), SenseInfo('01007027-v', 15), SenseInfo('01031966-v', 10), SenseInfo('01705494-v', 9), SenseInfo('01691057-v', 8), SenseInfo('00998886-v', 4), SenseInfo('01699896-v', 1), SenseInfo('01692834-v', 0), SenseInfo('01698271-v', 112), SenseInfo('00993014-v', 94), SenseInfo('01744611-v', 33), SenseInfo('01007027-v', 15), SenseInfo('01031966-v', 10), SenseInfo('01705494-v', 9), SenseInfo('01691057-v', 8), SenseInfo('00998886-v', 4), SenseInfo('01699896-v', 1), SenseInfo('01692834-v', 0), SenseInfo('01698271-v', 112), SenseInfo('00993014-v', 94), SenseInfo('01744611-v', 33), SenseInfo('01007027-v', 15), SenseInfo('01031966-v', 10), SenseInfo('01705494-v', 9), SenseInfo('01691057-v', 8), SenseInfo('00998886-v', 4), SenseInfo('01699896-v', 1), SenseInfo('01692834-v', 0), SenseInfo('01698271-v', 112), SenseInfo('00993014-v', 94), SenseInfo('01744611-v', 33), SenseInfo('01007027-v', 15), SenseInfo('01031966-v', 10), SenseInfo('01705494-v', 9), SenseInfo('01691057-v', 8), SenseInfo('00998886-v', 4), SenseInfo('01699896-v', 1), SenseInfo('01692834-v', 0) ],
"_elaborate_a_1_rel" : [ SenseInfo('01795933-a', 9), SenseInfo('00310433-a', 4), SenseInfo('01795933-a', 9), SenseInfo('00310433-a', 4) ],
"_interlock_v_cause_rel" : [ SenseInfo('00405079-v', 1), SenseInfo('01606736-v', 0), SenseInfo('01606018-v', 0) ],
"_amble_v_1_rel" : [ SenseInfo('01918183-v', 2) ],
"_fluid_a_1_rel" : [ SenseInfo('00345494-a', 1), SenseInfo('02261746-a', 0), SenseInfo('01139832-a', 0), SenseInfo('00778017-a', 0), SenseInfo('00345694-a', 0), SenseInfo('00345494-a', 1), SenseInfo('02261746-a', 0), SenseInfo('01139832-a', 0), SenseInfo('00778017-a', 0), SenseInfo('00345694-a', 0) ],
"_orange_n_1_rel" : [ SenseInfo('07747607-n', 4), SenseInfo('04965179-n', 3), SenseInfo('12708293-n', 1), SenseInfo('14991210-n', 0), SenseInfo('09379705-n', 0) ],
"_finn_n_1_rel" : [ SenseInfo('09706029-n', 1) ],
"_duff_a_1_rel" : [ SenseInfo('07618119-n', 0) ],
"_ltq_n_1_rel" : [  ],
"_biological_a_1_rel" : [ SenseInfo('02665803-a', 11), SenseInfo('01405904-a', 0), SenseInfo('02665803-a', 11), SenseInfo('01405904-a', 0) ],
"_goral_n_1_rel" : [ SenseInfo('02418770-n', 0) ],
"_get_v_around-to_rel" : [ SenseInfo('02210855-v', 235), SenseInfo('00149583-v', 157), SenseInfo('00120796-v', 82), SenseInfo('00522751-v', 64), SenseInfo('02005948-v', 58), SenseInfo('01433294-v', 45), SenseInfo('02108026-v', 36), SenseInfo('01153947-v', 14), SenseInfo('02355596-v', 9), SenseInfo('00770437-v', 7), SenseInfo('01215421-v', 4), SenseInfo('00094460-v', 4), SenseInfo('00087736-v', 4), SenseInfo('01066036-v', 3), SenseInfo('00120316-v', 3), SenseInfo('01026975-v', 2), SenseInfo('00589904-v', 2), SenseInfo('01505958-v', 1), SenseInfo('01401115-v', 1), SenseInfo('00639849-v', 1), SenseInfo('02359340-v', 0), SenseInfo('02208265-v', 0), SenseInfo('02189398-v', 0), SenseInfo('02109645-v', 0), SenseInfo('02108654-v', 0), SenseInfo('02010864-v', 0), SenseInfo('02006573-v', 0), SenseInfo('01771194-v', 0), SenseInfo('01771039-v', 0), SenseInfo('01738107-v', 0), SenseInfo('01643297-v', 0), SenseInfo('01565211-v', 0), SenseInfo('00622384-v', 0), SenseInfo('00345761-v', 0), SenseInfo('00065639-v', 0), SenseInfo('00054628-v', 0) ],
"_for+free_a_1_rel" : [  ],
"_deplete_v_of_rel" : [ SenseInfo('01157517-v', 0), SenseInfo('01157517-v', 0) ],
"_edentate_n_1_rel" : [ SenseInfo('02453611-n', 0), SenseInfo('02453611-n', 0), SenseInfo('02453611-n', 0) ],
"_overkill_n_1_rel" : [ SenseInfo('05204316-n', 0), SenseInfo('00633479-n', 0) ],
"_caledonian_a_1_rel" : [  ],
"_boiler_n_1_rel" : [ SenseInfo('02863750-n', 1), SenseInfo('03612814-n', 0) ],
"_journal_v_1_rel" : [  ],
"_anabaptist_n_1_rel" : [ SenseInfo('09677427-n', 2) ],
"_vacant_a_1_rel" : [ SenseInfo('01088164-a', 2), SenseInfo('01087977-a', 1) ],
"_continue_v_1_rel" : [ SenseInfo('02684924-v', 146), SenseInfo('00781000-v', 39), SenseInfo('02679899-v', 22), SenseInfo('01995549-v', 5), SenseInfo('02410175-v', 2), SenseInfo('02747922-v', 1), SenseInfo('02747709-v', 0), SenseInfo('02727462-v', 0), SenseInfo('02687916-v', 0), SenseInfo('00118523-v', 0) ],
"_haughtiness_n_1_rel" : [ SenseInfo('04887912-n', 0) ],
"_generalization_n_1_rel" : [ SenseInfo('05774415-n', 2), SenseInfo('05913275-n', 1), SenseInfo('05780104-n', 1), SenseInfo('05756414-n', 0), SenseInfo('05774415-n', 2), SenseInfo('05913275-n', 1), SenseInfo('05780104-n', 1), SenseInfo('05756414-n', 0), SenseInfo('05774415-n', 2), SenseInfo('05913275-n', 1), SenseInfo('05780104-n', 1), SenseInfo('05756414-n', 0), SenseInfo('05774415-n', 2), SenseInfo('05913275-n', 1), SenseInfo('05780104-n', 1), SenseInfo('05756414-n', 0) ],
"_swabian_n_1_rel" : [  ],
"_windsurfing_n_1_rel" : [  ],
"_horde_n_of_rel" : [ SenseInfo('08182962-n', 3), SenseInfo('08250889-n', 0), SenseInfo('08184217-n', 0), SenseInfo('08182962-n', 3), SenseInfo('08250889-n', 0), SenseInfo('08184217-n', 0) ],
"_vote_n_1_rel" : [ SenseInfo('00183505-n', 13), SenseInfo('00182213-n', 3), SenseInfo('05186306-n', 1), SenseInfo('08480662-n', 0), SenseInfo('05857165-n', 0), SenseInfo('00183505-n', 13), SenseInfo('00182213-n', 3), SenseInfo('05186306-n', 1), SenseInfo('08480662-n', 0), SenseInfo('05857165-n', 0), SenseInfo('00183505-n', 13), SenseInfo('00182213-n', 3), SenseInfo('05186306-n', 1), SenseInfo('08480662-n', 0), SenseInfo('05857165-n', 0) ],
"_ironstone_n_1_rel" : [  ],
"_highpoint_n_1_rel" : [  ],
"_inscription_n_1_rel" : [ SenseInfo('06405699-n', 3), SenseInfo('06406317-n', 0), SenseInfo('00615011-n', 0) ],
"_payrise_n_1_rel" : [  ],
"_parachute_v_1_rel" : [ SenseInfo('01968275-v', 0), SenseInfo('01968275-v', 0) ],
"_gall_n_1_rel" : [ SenseInfo('14275240-n', 0), SenseInfo('14184390-n', 0), SenseInfo('13099586-n', 0), SenseInfo('07548978-n', 0), SenseInfo('05406570-n', 0), SenseInfo('04915866-n', 0) ],
"_storyteller_n_1_rel" : [ SenseInfo('10345804-n', 2), SenseInfo('10660333-n', 0) ],
"_maul_v_1_rel" : [ SenseInfo('01232272-v', 0), SenseInfo('01232098-v', 0) ],
"_ascertain_v_1_rel" : [ SenseInfo('00918872-v', 4), SenseInfo('00662589-v', 1), SenseInfo('00920336-v', 0), SenseInfo('00721302-v', 0), SenseInfo('00918872-v', 4), SenseInfo('00662589-v', 1), SenseInfo('00920336-v', 0), SenseInfo('00721302-v', 0) ],
"_shameful_a_1_rel" : [ SenseInfo('01227546-a', 2), SenseInfo('01549964-a', 0) ],
"_as+of_p_rel" : [  ],
"_track_n_1_rel" : [ SenseInfo('09387222-n', 6), SenseInfo('05826914-n', 1), SenseInfo('04463983-n', 1), SenseInfo('04037625-n', 1), SenseInfo('06612865-n', 0), SenseInfo('04464418-n', 0), SenseInfo('04464211-n', 0), SenseInfo('04464125-n', 0), SenseInfo('04463679-n', 0), SenseInfo('04463510-n', 0), SenseInfo('00440039-n', 0), SenseInfo('09387222-n', 6), SenseInfo('05826914-n', 1), SenseInfo('04463983-n', 1), SenseInfo('04037625-n', 1), SenseInfo('06612865-n', 0), SenseInfo('04464418-n', 0), SenseInfo('04464211-n', 0), SenseInfo('04464125-n', 0), SenseInfo('04463679-n', 0), SenseInfo('04463510-n', 0), SenseInfo('00440039-n', 0), SenseInfo('09387222-n', 6), SenseInfo('05826914-n', 1), SenseInfo('04463983-n', 1), SenseInfo('04037625-n', 1), SenseInfo('06612865-n', 0), SenseInfo('04464418-n', 0), SenseInfo('04464211-n', 0), SenseInfo('04464125-n', 0), SenseInfo('04463679-n', 0), SenseInfo('04463510-n', 0), SenseInfo('00440039-n', 0) ],
"_brilliant_a_1_rel" : [ SenseInfo('02342608-a', 11), SenseInfo('01335156-a', 7), SenseInfo('01285376-a', 2), SenseInfo('00402855-a', 2), SenseInfo('00281173-a', 2), SenseInfo('02009688-a', 1), SenseInfo('02342608-a', 11), SenseInfo('01335156-a', 7), SenseInfo('01285376-a', 2), SenseInfo('00402855-a', 2), SenseInfo('00281173-a', 2), SenseInfo('02009688-a', 1) ],
"_sunder_v_1_rel" : [ SenseInfo('00335814-v', 1) ],
"_slice_v_up_rel" : [ SenseInfo('01559055-v', 2), SenseInfo('01408958-v', 1), SenseInfo('01254477-v', 1), SenseInfo('01124389-v', 1) ],
"_hair_n_1_rel" : [ SenseInfo('05254795-n', 59), SenseInfo('13761603-n', 0), SenseInfo('13090091-n', 0), SenseInfo('05254393-n', 0), SenseInfo('03475674-n', 0), SenseInfo('01900150-n', 0) ],
"_liaison_n_with_rel" : [ SenseInfo('13931889-n', 1), SenseInfo('06261260-n', 1) ],
"_northeastward_a_1_rel" : [ SenseInfo('01601901-a', 0), SenseInfo('01601901-a', 0) ],
"_oh_a_1_rel" : [ SenseInfo('09130076-n', 0), SenseInfo('09130076-n', 0) ],
"_tune_v_in_rel" : [ SenseInfo('00295966-v', 1), SenseInfo('00295346-v', 0), SenseInfo('00295966-v', 1), SenseInfo('00295346-v', 0) ],
"_mobile_n_1_rel" : [ SenseInfo('09356639-n', 0), SenseInfo('09054480-n', 0), SenseInfo('03776291-n', 0) ],
"_ticker_n_1_rel" : [ SenseInfo('05388805-n', 0), SenseInfo('04555897-n', 0), SenseInfo('04432393-n', 0) ],
"_remind_v_1_rel" : [ SenseInfo('00610538-v', 22), SenseInfo('00877848-v', 13), SenseInfo('00610538-v', 22), SenseInfo('00877848-v', 13), SenseInfo('00610538-v', 22), SenseInfo('00877848-v', 13) ],
"_verge_n_1_rel" : [ SenseInfo('13903738-n', 1), SenseInfo('05125193-n', 1), SenseInfo('07267573-n', 0), SenseInfo('04528256-n', 0) ],
"_as+regards_p_rel" : [  ],
"_up-_a_1_rel" : [ SenseInfo('02490170-a', 8), SenseInfo('00186925-a', 5), SenseInfo('02487108-a', 1), SenseInfo('02485488-a', 1), SenseInfo('01845002-a', 0), SenseInfo('01208146-a', 0), SenseInfo('01091995-a', 0), SenseInfo('01004245-a', 0) ],
"_tie_v_on_rel" : [ SenseInfo('01285440-v', 13), SenseInfo('01115190-v', 5), SenseInfo('00234217-v', 4), SenseInfo('01354673-v', 2), SenseInfo('00141632-v', 1), SenseInfo('02538086-v', 0), SenseInfo('02489456-v', 0), SenseInfo('01658444-v', 0), SenseInfo('01355411-v', 0) ],
"_concerning_p_rel" : [  ],
"_excuse_v_1_rel" : [ SenseInfo('00905852-v', 2), SenseInfo('00893878-v', 2), SenseInfo('00893435-v', 2), SenseInfo('00894738-v', 1), SenseInfo('00894221-v', 0), SenseInfo('00893167-v', 0) ],
"_burl_n_1_rel" : [ SenseInfo('13166191-n', 0), SenseInfo('13166044-n', 0), SenseInfo('04948905-n', 0) ],
"_obtain_v_1_rel" : [ SenseInfo('02238085-v', 116), SenseInfo('00522751-v', 17), SenseInfo('02648502-v', 1) ],
"_consul_n_1_rel" : [ SenseInfo('09959797-n', 0) ],
"_universe_n_of_rel" : [ SenseInfo('09466280-n', 12), SenseInfo('06026276-n', 0), SenseInfo('05814162-n', 0) ],
"_out+of_p_sel_rel" : [ SenseInfo('00233573-r', 0) ],
"_either_q_rel" : [  ],
"_precondition_n_1_rel" : [ SenseInfo('06755568-n', 0), SenseInfo('05893356-n', 0), SenseInfo('05892880-n', 0) ],
"_swish_n_1_rel" : [ SenseInfo('07396414-n', 0) ],
"_mumble_n_1_rel" : [ SenseInfo('07127252-n', 0) ],
"_power_v_up_rel" : [ SenseInfo('01181559-v', 3), SenseInfo('01181559-v', 3) ],
"_cousin_n_of_rel" : [ SenseInfo('09972010-n', 5) ],
"_inaudible_a_1_rel" : [ SenseInfo('00174379-a', 2) ],
"_bronze_v_cause_rel" : [ SenseInfo('00281913-v', 0), SenseInfo('00103875-v', 0) ],
"_hasten_v_1_rel" : [ SenseInfo('00459498-v', 7), SenseInfo('02058994-v', 6), SenseInfo('02548893-v', 2), SenseInfo('01644522-v', 1), SenseInfo('00459498-v', 7), SenseInfo('02058994-v', 6), SenseInfo('02548893-v', 2), SenseInfo('01644522-v', 1), SenseInfo('00459498-v', 7), SenseInfo('02058994-v', 6), SenseInfo('02548893-v', 2), SenseInfo('01644522-v', 1) ],
"_gorge_n_1_rel" : [ SenseInfo('09290444-n', 0), SenseInfo('09263912-n', 0), SenseInfo('05533948-n', 0), SenseInfo('09290444-n', 0), SenseInfo('09263912-n', 0), SenseInfo('05533948-n', 0) ],
"_parallel_n_to_rel" : [ SenseInfo('04746430-n', 5), SenseInfo('08595720-n', 1), SenseInfo('13880994-n', 0) ],
"_pasture_v_1_rel" : [ SenseInfo('01576478-v', 0), SenseInfo('01576165-v', 0) ],
"_militant_a_1_rel" : [ SenseInfo('01742715-a', 1), SenseInfo('00083003-a', 1), SenseInfo('01742537-a', 0) ],
"_allomorphy_n_1_rel" : [  ],
"_address_v_to_rel" : [ SenseInfo('00897564-v', 16), SenseInfo('00989201-v', 5), SenseInfo('00990812-v', 4), SenseInfo('01150981-v', 2), SenseInfo('01160899-v', 1), SenseInfo('02601456-v', 0), SenseInfo('02249018-v', 0), SenseInfo('01033527-v', 0), SenseInfo('00990655-v', 0), SenseInfo('00464687-v', 0) ],
"_sift_v_1_rel" : [ SenseInfo('02098827-v', 1), SenseInfo('01460029-v', 1), SenseInfo('01460594-v', 0), SenseInfo('00675768-v', 0), SenseInfo('02098827-v', 1), SenseInfo('01460029-v', 1), SenseInfo('01460594-v', 0), SenseInfo('00675768-v', 0) ],
"_altercation_n_1_rel" : [ SenseInfo('07184545-n', 5) ],
"_deduce_v_1_rel" : [ SenseInfo('00636574-v', 7), SenseInfo('00944924-v', 2) ],
"_a+lot_a_1_rel" : [  ],
"_rider_n_1_rel" : [ SenseInfo('10529965-n', 11), SenseInfo('06394564-n', 2), SenseInfo('10530150-n', 0), SenseInfo('10403876-n', 0) ],
"_republic_n_of_rel" : [ SenseInfo('08361329-n', 7), SenseInfo('08362917-n', 0) ],
"_canoeist_n_1_rel" : [ SenseInfo('09891470-n', 0) ],
"_image_v_1_rel" : [ SenseInfo('02151603-v', 0), SenseInfo('01635432-v', 0), SenseInfo('02151603-v', 0), SenseInfo('01635432-v', 0) ],
"_fitting_n_1_rel" : [ SenseInfo('07369604-n', 0), SenseInfo('03353616-n', 0), SenseInfo('02730568-n', 0), SenseInfo('00795008-n', 0) ],
"_STFU_v_1_rel" : [  ],
"all+too_rel" : [  ],
"_roundabout_n_1_rel" : [ SenseInfo('04465933-n', 0), SenseInfo('02966193-n', 0) ],
"_jordanian_a_1_rel" : [ SenseInfo('03077235-a', 0) ],
"_elevate_v_cause_rel" : [ SenseInfo('02397637-v', 3), SenseInfo('01974062-v', 2), SenseInfo('00544549-v', 2) ],
"_solfeggio_n_1_rel" : [ SenseInfo('01255935-n', 0), SenseInfo('01255808-n', 0) ],
"_undertaking_n_1_rel" : [ SenseInfo('00795720-n', 1), SenseInfo('01120259-n', 0), SenseInfo('00795720-n', 1), SenseInfo('01120259-n', 0) ],
"_defend_v_against_rel" : [ SenseInfo('00895304-v', 19), SenseInfo('01127795-v', 14), SenseInfo('01129876-v', 3), SenseInfo('01091427-v', 2), SenseInfo('01149138-v', 1), SenseInfo('02581675-v', 0), SenseInfo('01017643-v', 0) ],
"_rule_n_of_rel" : [ SenseInfo('05846054-n', 15), SenseInfo('05667613-n', 15), SenseInfo('06652242-n', 10), SenseInfo('07259772-n', 7), SenseInfo('05913538-n', 3), SenseInfo('15295416-n', 0), SenseInfo('14442933-n', 0), SenseInfo('06788897-n', 0), SenseInfo('06652064-n', 0), SenseInfo('05874232-n', 0), SenseInfo('05846932-n', 0), SenseInfo('04118776-n', 0), SenseInfo('05846054-n', 15), SenseInfo('05667613-n', 15), SenseInfo('06652242-n', 10), SenseInfo('07259772-n', 7), SenseInfo('05913538-n', 3), SenseInfo('15295416-n', 0), SenseInfo('14442933-n', 0), SenseInfo('06788897-n', 0), SenseInfo('06652064-n', 0), SenseInfo('05874232-n', 0), SenseInfo('05846932-n', 0), SenseInfo('04118776-n', 0), SenseInfo('05846054-n', 15), SenseInfo('05667613-n', 15), SenseInfo('06652242-n', 10), SenseInfo('07259772-n', 7), SenseInfo('05913538-n', 3), SenseInfo('15295416-n', 0), SenseInfo('14442933-n', 0), SenseInfo('06788897-n', 0), SenseInfo('06652064-n', 0), SenseInfo('05874232-n', 0), SenseInfo('05846932-n', 0), SenseInfo('04118776-n', 0), SenseInfo('05846054-n', 15), SenseInfo('05667613-n', 15), SenseInfo('06652242-n', 10), SenseInfo('07259772-n', 7), SenseInfo('05913538-n', 3), SenseInfo('15295416-n', 0), SenseInfo('14442933-n', 0), SenseInfo('06788897-n', 0), SenseInfo('06652064-n', 0), SenseInfo('05874232-n', 0), SenseInfo('05846932-n', 0), SenseInfo('04118776-n', 0), SenseInfo('05846054-n', 15), SenseInfo('05667613-n', 15), SenseInfo('06652242-n', 10), SenseInfo('07259772-n', 7), SenseInfo('05913538-n', 3), SenseInfo('15295416-n', 0), SenseInfo('14442933-n', 0), SenseInfo('06788897-n', 0), SenseInfo('06652064-n', 0), SenseInfo('05874232-n', 0), SenseInfo('05846932-n', 0), SenseInfo('04118776-n', 0) ],
"_tea+time_n_1_rel" : [ SenseInfo('07575510-n', 0) ],
"_barony_n_1_rel" : [ SenseInfo('13251906-n', 1), SenseInfo('14432623-n', 0), SenseInfo('08557057-n', 0) ],
"_upscale_a_1_rel" : [ SenseInfo('02488304-a', 0) ],
"_hearth_n_1_rel" : [ SenseInfo('03346455-n', 2), SenseInfo('03507241-n', 1), SenseInfo('08581699-n', 0) ],
"_just+now_a_1_rel" : [  ],
"_video_n_of_rel" : [ SenseInfo('06277803-n', 1), SenseInfo('04534127-n', 1), SenseInfo('06277992-n', 0), SenseInfo('06277280-n', 0) ],
"_co-opt_v_1_rel" : [ SenseInfo('02401051-v', 1), SenseInfo('02536098-v', 0), SenseInfo('02397266-v', 0), SenseInfo('02362460-v', 0), SenseInfo('02401051-v', 1), SenseInfo('02536098-v', 0), SenseInfo('02397266-v', 0), SenseInfo('02362460-v', 0), SenseInfo('02401051-v', 1), SenseInfo('02536098-v', 0), SenseInfo('02397266-v', 0), SenseInfo('02362460-v', 0), SenseInfo('02401051-v', 1), SenseInfo('02536098-v', 0), SenseInfo('02397266-v', 0), SenseInfo('02362460-v', 0), SenseInfo('02401051-v', 1), SenseInfo('02536098-v', 0), SenseInfo('02397266-v', 0), SenseInfo('02362460-v', 0), SenseInfo('02401051-v', 1), SenseInfo('02536098-v', 0), SenseInfo('02397266-v', 0), SenseInfo('02362460-v', 0) ],
"_per+diem_n_1_rel" : [ SenseInfo('13293752-n', 0) ],
"_knock_v_out_rel" : [ SenseInfo('01238640-v', 7), SenseInfo('01414467-v', 6), SenseInfo('01239619-v', 4), SenseInfo('02185373-v', 0), SenseInfo('02178866-v', 0), SenseInfo('00826509-v', 0) ],
"_weaver_n_1_rel" : [ SenseInfo('10772190-n', 0), SenseInfo('01542786-n', 0) ],
"_pee_n_1_rel" : [ SenseInfo('14855724-n', 0), SenseInfo('13533886-n', 0) ],
"_yield_v_up_rel" : [ SenseInfo('02339171-v', 6), SenseInfo('00435103-v', 5), SenseInfo('01629000-v', 4), SenseInfo('02316649-v', 3), SenseInfo('02703289-v', 2), SenseInfo('01848465-v', 1), SenseInfo('01629403-v', 1), SenseInfo('00806049-v', 1), SenseInfo('02620466-v', 0), SenseInfo('02291708-v', 0), SenseInfo('01449796-v', 0), SenseInfo('01116447-v', 0), SenseInfo('00804476-v', 0) ],
"_tremor_n_1_rel" : [ SenseInfo('00348801-n', 2), SenseInfo('07429484-n', 1), SenseInfo('14005137-n', 0) ],
"_bat_v_away_rel" : [ SenseInfo('01413173-v', 11), SenseInfo('00008195-v', 2), SenseInfo('01413561-v', 0), SenseInfo('01413436-v', 0), SenseInfo('01412912-v', 0) ],
"_constituency_n_1_rel" : [ SenseInfo('08238156-n', 0) ],
"_all-fired_a_1_rel" : [ SenseInfo('01533659-a', 1), SenseInfo('01533659-a', 1), SenseInfo('01533659-a', 1) ],
"_westward_a_2_rel" : [ SenseInfo('00824509-a', 0) ],
"_abashed_a_1_rel" : [ SenseInfo('00531628-a', 1) ],
"_transfer_v_1_rel" : [ SenseInfo('02393086-v', 6), SenseInfo('02232190-v', 6), SenseInfo('01855155-v', 6), SenseInfo('02012344-v', 5), SenseInfo('02220461-v', 1), SenseInfo('02088241-v', 1), SenseInfo('01435380-v', 1), SenseInfo('02086458-v', 0), SenseInfo('00555240-v', 0) ],
"_trekker_n_1_rel" : [ SenseInfo('10727944-n', 0) ],
"_standard_a_1_rel" : [ SenseInfo('02295998-a', 12), SenseInfo('00487525-a', 5), SenseInfo('02294777-a', 2), SenseInfo('02297664-a', 0), SenseInfo('01960076-a', 0) ],
"_HTML_n_1_rel" : [ SenseInfo('06788262-n', 0) ],
"_pus_n_1_rel" : [ SenseInfo('15220985-n', 0), SenseInfo('05417472-n', 0) ],
"_affirmative_a_1_rel" : [ SenseInfo('00075135-a', 0), SenseInfo('01817908-a', 0), SenseInfo('00996089-a', 0) ],
"_rinse_n_1_rel" : [ SenseInfo('14988854-n', 0), SenseInfo('00396642-n', 0), SenseInfo('00256407-n', 0), SenseInfo('00256309-n', 0) ],
"_where_x_subord_rel" : [  ],
"_many_x_deg_rel" : [ SenseInfo('01551633-a', 347) ],
"_residual_a_1_rel" : [ SenseInfo('02835654-a', 1) ],
"_respect_v_1_rel" : [ SenseInfo('00694068-v', 12), SenseInfo('02457233-v', 4) ],
"_holding_n_1_rel" : [ SenseInfo('00810598-n', 1), SenseInfo('13244109-n', 0) ],
"_plausible_a_1_rel" : [ SenseInfo('01799457-a', 2), SenseInfo('02182728-a', 0), SenseInfo('01799457-a', 2), SenseInfo('02182728-a', 0) ],
"_stonepile_n_1_rel" : [  ],
"_never+mind_a_1_rel" : [  ],
"_deport_v_1_rel" : [ SenseInfo('02518161-v', 0), SenseInfo('02503365-v', 0), SenseInfo('02499312-v', 0) ],
"_unwind_v_cause_rel" : [ SenseInfo('01523654-v', 1), SenseInfo('01523823-v', 0), SenseInfo('00026385-v', 0), SenseInfo('00025654-v', 0) ],
"_chill_v_out_rel" : [ SenseInfo('01818972-v', 2), SenseInfo('00370412-v', 1), SenseInfo('00369864-v', 0) ],
"_slot_n_1_rel" : [ SenseInfo('06284573-n', 3), SenseInfo('04243370-n', 1), SenseInfo('15270245-n', 0), SenseInfo('14579623-n', 0), SenseInfo('09437887-n', 0), SenseInfo('04243727-n', 0), SenseInfo('04243546-n', 0) ],
"_support_v_1_rel" : [ SenseInfo('02556126-v', 26), SenseInfo('02219094-v', 16), SenseInfo('02453889-v', 14), SenseInfo('01217043-v', 14), SenseInfo('00665886-v', 6), SenseInfo('00806314-v', 3), SenseInfo('02663340-v', 2), SenseInfo('00895304-v', 2), SenseInfo('01720773-v', 0), SenseInfo('00908621-v', 0), SenseInfo('00668099-v', 0) ],
"_knoll_n_1_rel" : [ SenseInfo('09326662-n', 1) ],
"_badger_n_1_rel" : [ SenseInfo('09746536-n', 0), SenseInfo('02447366-n', 0) ],
"_plastic_a_1_rel" : [ SenseInfo('00844461-a', 1), SenseInfo('02364954-a', 0), SenseInfo('00585398-a', 0), SenseInfo('00844461-a', 1), SenseInfo('02364954-a', 0), SenseInfo('00585398-a', 0) ],
"_humanitarian_a_1_rel" : [ SenseInfo('01262284-a', 1), SenseInfo('02993702-a', 0) ],
"_downstream_a_1_rel" : [ SenseInfo('02494499-a', 0), SenseInfo('02494499-a', 0) ],
"_analogue_a_1_rel" : [ SenseInfo('00110497-a', 0) ],
"_willing_a_1_rel" : [ SenseInfo('02564986-a', 22), SenseInfo('02521036-a', 0), SenseInfo('02564986-a', 22), SenseInfo('02521036-a', 0), SenseInfo('02564986-a', 22), SenseInfo('02521036-a', 0) ],
"_colorful_a_1_rel" : [ SenseInfo('00402419-a', 6), SenseInfo('00406867-a', 3), SenseInfo('00394562-a', 0), SenseInfo('00402419-a', 6), SenseInfo('00406867-a', 3), SenseInfo('00394562-a', 0) ],
"_personate_v_1_rel" : [ SenseInfo('00837288-v', 0), SenseInfo('00727573-v', 0) ],
"_employer_n_1_rel" : [ SenseInfo('10054657-n', 14) ],
"_absorb_v_1_rel" : [ SenseInfo('01539633-v', 8), SenseInfo('00602255-v', 5), SenseInfo('02216560-v', 4), SenseInfo('01539063-v', 4), SenseInfo('00395698-v', 2), SenseInfo('02765464-v', 1), SenseInfo('00601043-v', 1), SenseInfo('01470524-v', 0), SenseInfo('00600370-v', 0), SenseInfo('01539633-v', 8), SenseInfo('00602255-v', 5), SenseInfo('02216560-v', 4), SenseInfo('01539063-v', 4), SenseInfo('00395698-v', 2), SenseInfo('02765464-v', 1), SenseInfo('00601043-v', 1), SenseInfo('01470524-v', 0), SenseInfo('00600370-v', 0), SenseInfo('01539633-v', 8), SenseInfo('00602255-v', 5), SenseInfo('02216560-v', 4), SenseInfo('01539063-v', 4), SenseInfo('00395698-v', 2), SenseInfo('02765464-v', 1), SenseInfo('00601043-v', 1), SenseInfo('01470524-v', 0), SenseInfo('00600370-v', 0) ],
"_adulthood_n_1_rel" : [ SenseInfo('15152817-n', 1), SenseInfo('14425103-n', 0) ],
"_unserviced_a_1_rel" : [  ],
"_symmetry_n_1_rel" : [ SenseInfo('05064827-n', 5), SenseInfo('13898315-n', 1), SenseInfo('04917439-n', 0) ],
"_malign_v_1_rel" : [ SenseInfo('00848169-v', 0) ],
"_gyp_v_1_rel" : [ SenseInfo('02572119-v', 0) ],
"_rescue_v_1_rel" : [ SenseInfo('02551144-v', 11), SenseInfo('02206920-v', 0) ],
"_salvadoran_a_1_rel" : [ SenseInfo('02969375-a', 0) ],
"_riverine_a_1_rel" : [  ],
"_gaunt_a_1_rel" : [ SenseInfo('00988988-a', 9) ],
"_fixing_n_1_rel" : [ SenseInfo('00266806-n', 1), SenseInfo('03323703-n', 0), SenseInfo('00692506-n', 0), SenseInfo('00276342-n', 0) ],
"_greed_n_1_rel" : [ SenseInfo('04945530-n', 1), SenseInfo('00758525-n', 0) ],
"_sustain_v_1_rel" : [ SenseInfo('02679530-v', 8), SenseInfo('00065639-v', 3), SenseInfo('01202728-v', 2), SenseInfo('01184625-v', 2), SenseInfo('01217043-v', 1), SenseInfo('00818422-v', 1), SenseInfo('00665886-v', 0), SenseInfo('02679530-v', 8), SenseInfo('00065639-v', 3), SenseInfo('01202728-v', 2), SenseInfo('01184625-v', 2), SenseInfo('01217043-v', 1), SenseInfo('00818422-v', 1), SenseInfo('00665886-v', 0), SenseInfo('02679530-v', 8), SenseInfo('00065639-v', 3), SenseInfo('01202728-v', 2), SenseInfo('01184625-v', 2), SenseInfo('01217043-v', 1), SenseInfo('00818422-v', 1), SenseInfo('00665886-v', 0) ],
"_delicious_a_1_rel" : [ SenseInfo('01807964-a', 2), SenseInfo('02396720-a', 0), SenseInfo('01807964-a', 2), SenseInfo('02396720-a', 0) ],
"_bi_a_1_rel" : [ SenseInfo('14631502-n', 0) ],
"_supremacy_n_1_rel" : [ SenseInfo('14442530-n', 4) ],
"_offering_n_of_rel" : [ SenseInfo('07164546-n', 1), SenseInfo('13270373-n', 0), SenseInfo('07185076-n', 0), SenseInfo('01041498-n', 0) ],
"_conventioneer_n_1_rel" : [ SenseInfo('09961889-n', 0) ],
"_nv_n_1_rel" : [ SenseInfo('09110422-n', 0), SenseInfo('09110422-n', 0), SenseInfo('09110422-n', 0), SenseInfo('09110422-n', 0), SenseInfo('09110422-n', 0), SenseInfo('09110422-n', 0) ],
"_outward_a_2_rel" : [ SenseInfo('00950706-a', 3), SenseInfo('01295660-a', 0), SenseInfo('00950706-a', 3), SenseInfo('01295660-a', 0) ],
"_measurement_n_1_rel" : [ SenseInfo('00996969-n', 19) ],
"_recommended_a_1_rel" : [  ],
"_warehouse_v_1_rel" : [ SenseInfo('02282365-v', 0) ],
"_already_a_1_rel" : [  ],
"_eventual_a_1_rel" : [ SenseInfo('01578856-a', 3), SenseInfo('01578856-a', 3) ],
"_divide_v_off_rel" : [ SenseInfo('02467662-v', 20), SenseInfo('00642098-v', 11), SenseInfo('02621853-v', 4), SenseInfo('01557774-v', 2), SenseInfo('02031158-v', 1), SenseInfo('01556921-v', 1), SenseInfo('02467662-v', 20), SenseInfo('00642098-v', 11), SenseInfo('02621853-v', 4), SenseInfo('01557774-v', 2), SenseInfo('02031158-v', 1), SenseInfo('01556921-v', 1) ],
"_slip_v_off_rel" : [ SenseInfo('01888295-v', 11), SenseInfo('00189669-v', 7), SenseInfo('01870275-v', 6), SenseInfo('00204391-v', 4), SenseInfo('02076280-v', 2), SenseInfo('00617748-v', 1), SenseInfo('02231328-v', 0), SenseInfo('02105549-v', 0), SenseInfo('02076501-v', 0), SenseInfo('00608978-v', 0), SenseInfo('00465762-v', 0) ],
"_blot_v_out_rel" : [ SenseInfo('01538928-v', 0), SenseInfo('01531998-v', 0) ],
"_repeal_v_1_rel" : [ SenseInfo('00799798-v', 3) ],
"_representative_a_of_rel" : [ SenseInfo('02469407-a', 3), SenseInfo('01981699-a', 1), SenseInfo('00716562-a', 0) ],
"_delusion_n_of_rel" : [ SenseInfo('14376855-n', 0), SenseInfo('05896733-n', 0), SenseInfo('00754767-n', 0), SenseInfo('14376855-n', 0), SenseInfo('05896733-n', 0), SenseInfo('00754767-n', 0) ],
"_standing-room-only_a_1_rel" : [  ],
"_addict_n_1_rel" : [ SenseInfo('09769076-n', 0), SenseInfo('09768830-n', 0) ],
"_ware_n_1_rel" : [ SenseInfo('04550840-n', 0), SenseInfo('03748886-n', 0) ],
"_ammunition_n_1_rel" : [ SenseInfo('02703275-n', 11), SenseInfo('14585808-n', 0), SenseInfo('06484696-n', 0) ],
"_get_v_back_rel" : [ SenseInfo('02210855-v', 235), SenseInfo('00149583-v', 157), SenseInfo('00120796-v', 82), SenseInfo('00522751-v', 64), SenseInfo('02005948-v', 58), SenseInfo('01433294-v', 45), SenseInfo('02108026-v', 36), SenseInfo('01153947-v', 14), SenseInfo('02355596-v', 9), SenseInfo('00770437-v', 7), SenseInfo('01215421-v', 4), SenseInfo('00094460-v', 4), SenseInfo('00087736-v', 4), SenseInfo('01066036-v', 3), SenseInfo('00120316-v', 3), SenseInfo('01026975-v', 2), SenseInfo('00589904-v', 2), SenseInfo('01505958-v', 1), SenseInfo('01401115-v', 1), SenseInfo('00639849-v', 1), SenseInfo('02359340-v', 0), SenseInfo('02208265-v', 0), SenseInfo('02189398-v', 0), SenseInfo('02109645-v', 0), SenseInfo('02108654-v', 0), SenseInfo('02010864-v', 0), SenseInfo('02006573-v', 0), SenseInfo('01771194-v', 0), SenseInfo('01771039-v', 0), SenseInfo('01738107-v', 0), SenseInfo('01643297-v', 0), SenseInfo('01565211-v', 0), SenseInfo('00622384-v', 0), SenseInfo('00345761-v', 0), SenseInfo('00065639-v', 0), SenseInfo('00054628-v', 0), SenseInfo('02210855-v', 235), SenseInfo('00149583-v', 157), SenseInfo('00120796-v', 82), SenseInfo('00522751-v', 64), SenseInfo('02005948-v', 58), SenseInfo('01433294-v', 45), SenseInfo('02108026-v', 36), SenseInfo('01153947-v', 14), SenseInfo('02355596-v', 9), SenseInfo('00770437-v', 7), SenseInfo('01215421-v', 4), SenseInfo('00094460-v', 4), SenseInfo('00087736-v', 4), SenseInfo('01066036-v', 3), SenseInfo('00120316-v', 3), SenseInfo('01026975-v', 2), SenseInfo('00589904-v', 2), SenseInfo('01505958-v', 1), SenseInfo('01401115-v', 1), SenseInfo('00639849-v', 1), SenseInfo('02359340-v', 0), SenseInfo('02208265-v', 0), SenseInfo('02189398-v', 0), SenseInfo('02109645-v', 0), SenseInfo('02108654-v', 0), SenseInfo('02010864-v', 0), SenseInfo('02006573-v', 0), SenseInfo('01771194-v', 0), SenseInfo('01771039-v', 0), SenseInfo('01738107-v', 0), SenseInfo('01643297-v', 0), SenseInfo('01565211-v', 0), SenseInfo('00622384-v', 0), SenseInfo('00345761-v', 0), SenseInfo('00065639-v', 0), SenseInfo('00054628-v', 0) ],
"_budgetary_a_1_rel" : [ SenseInfo('03022593-a', 1) ],
"_negotiable_a_1_rel" : [ SenseInfo('01724916-a', 0), SenseInfo('01024400-a', 0), SenseInfo('00093556-a', 0), SenseInfo('01724916-a', 0), SenseInfo('01024400-a', 0), SenseInfo('00093556-a', 0) ],
"_sigma_n_1_rel" : [ SenseInfo('06835951-n', 0) ],
"_shout_v_1_rel" : [ SenseInfo('00912473-v', 39), SenseInfo('00913065-v', 18), SenseInfo('00912048-v', 2), SenseInfo('00845299-v', 0), SenseInfo('00912473-v', 39), SenseInfo('00913065-v', 18), SenseInfo('00912048-v', 2), SenseInfo('00845299-v', 0) ],
"_toss_v_away_rel" : [ SenseInfo('01512625-v', 13), SenseInfo('01893079-v', 10), SenseInfo('01514525-v', 5), SenseInfo('01890792-v', 4), SenseInfo('02222318-v', 1), SenseInfo('01418536-v', 1) ],
"_nunnery_n_1_rel" : [ SenseInfo('03835853-n', 0) ],
"_as_p_comp_rel" : [ SenseInfo('13658027-n', 6), SenseInfo('15089803-n', 0), SenseInfo('14829565-n', 0), SenseInfo('14706889-n', 0), SenseInfo('13637376-n', 0), SenseInfo('06831177-n', 0), SenseInfo('05400860-n', 0), SenseInfo('13658027-n', 6), SenseInfo('15089803-n', 0), SenseInfo('14829565-n', 0), SenseInfo('14706889-n', 0), SenseInfo('13637376-n', 0), SenseInfo('06831177-n', 0), SenseInfo('05400860-n', 0), SenseInfo('13658027-n', 6), SenseInfo('15089803-n', 0), SenseInfo('14829565-n', 0), SenseInfo('14706889-n', 0), SenseInfo('13637376-n', 0), SenseInfo('06831177-n', 0), SenseInfo('05400860-n', 0), SenseInfo('13658027-n', 6), SenseInfo('15089803-n', 0), SenseInfo('14829565-n', 0), SenseInfo('14706889-n', 0), SenseInfo('13637376-n', 0), SenseInfo('06831177-n', 0), SenseInfo('05400860-n', 0), SenseInfo('13658027-n', 6), SenseInfo('15089803-n', 0), SenseInfo('14829565-n', 0), SenseInfo('14706889-n', 0), SenseInfo('13637376-n', 0), SenseInfo('06831177-n', 0), SenseInfo('05400860-n', 0), SenseInfo('13658027-n', 6), SenseInfo('15089803-n', 0), SenseInfo('14829565-n', 0), SenseInfo('14706889-n', 0), SenseInfo('13637376-n', 0), SenseInfo('06831177-n', 0), SenseInfo('05400860-n', 0) ],
"_cross-examine_v_1_rel" : [ SenseInfo('00787049-v', 0), SenseInfo('00787049-v', 0), SenseInfo('00787049-v', 0), SenseInfo('00787049-v', 0) ],
"_flesh_v_out_rel" : [ SenseInfo('02365692-v', 0) ],
"_gay_a_1_rel" : [ SenseInfo('00363938-a', 9), SenseInfo('01367651-a', 3), SenseInfo('01298708-a', 3), SenseInfo('00407151-a', 3), SenseInfo('01367431-a', 1), SenseInfo('01201937-a', 1), SenseInfo('00363938-a', 9), SenseInfo('01367651-a', 3), SenseInfo('01298708-a', 3), SenseInfo('00407151-a', 3), SenseInfo('01367431-a', 1), SenseInfo('01201937-a', 1), SenseInfo('00363938-a', 9), SenseInfo('01367651-a', 3), SenseInfo('01298708-a', 3), SenseInfo('00407151-a', 3), SenseInfo('01367431-a', 1), SenseInfo('01201937-a', 1), SenseInfo('00363938-a', 9), SenseInfo('01367651-a', 3), SenseInfo('01298708-a', 3), SenseInfo('00407151-a', 3), SenseInfo('01367431-a', 1), SenseInfo('01201937-a', 1) ],
"_remain_v_expl_rel" : [ SenseInfo('00117985-v', 128), SenseInfo('02727462-v', 38), SenseInfo('02637592-v', 34), SenseInfo('02731024-v', 9) ],
"_nether_a_1_rel" : [ SenseInfo('02441132-a', 0), SenseInfo('01303946-a', 0), SenseInfo('01207546-a', 0) ],
"_tracery_n_1_rel" : [ SenseInfo('04463141-n', 0) ],
"_alderman_n_1_rel" : [ SenseInfo('09782397-n', 1) ],
"_mister_n_1_rel" : [ SenseInfo('06341340-n', 0), SenseInfo('06341340-n', 0), SenseInfo('06341340-n', 0), SenseInfo('06341340-n', 0), SenseInfo('06341340-n', 0), SenseInfo('06341340-n', 0), SenseInfo('06341340-n', 0), SenseInfo('06341340-n', 0), SenseInfo('06341340-n', 0), SenseInfo('06341340-n', 0), SenseInfo('06341340-n', 0), SenseInfo('06341340-n', 0) ],
"_gosh_a_1_rel" : [  ],
"_had+best_v_qmodal_rel" : [ SenseInfo('02723564-v', 0), SenseInfo('02723564-v', 0), SenseInfo('02723564-v', 0), SenseInfo('02723564-v', 0) ],
"_insinuate_v_1_rel" : [ SenseInfo('02078855-v', 0), SenseInfo('00927711-v', 0), SenseInfo('02078855-v', 0), SenseInfo('00927711-v', 0) ],
"_refine_v_1_rel" : [ SenseInfo('00474017-v', 2), SenseInfo('00400883-v', 1), SenseInfo('00474762-v', 0), SenseInfo('00474492-v', 0), SenseInfo('00401906-v', 0), SenseInfo('00401688-v', 0) ],
"_sleigh_n_1_rel" : [ SenseInfo('04235291-n', 0) ],
"_allocation_n_of_rel" : [ SenseInfo('13289467-n', 1), SenseInfo('01083645-n', 1), SenseInfo('00164579-n', 0) ],
"_sandstone_n_1_rel" : [ SenseInfo('14995541-n', 0) ],
"_ersatz_a_1_rel" : [ SenseInfo('01572974-a', 1) ],
"_overlap_v_with_rel" : [ SenseInfo('02660631-v', 5), SenseInfo('02688794-v', 1) ],
"_blockage_n_1_rel" : [ SenseInfo('14507951-n', 0), SenseInfo('02853449-n', 0), SenseInfo('01074694-n', 0) ],
"_cubicle_n_1_rel" : [ SenseInfo('02991555-n', 0), SenseInfo('02968333-n', 0), SenseInfo('02873839-n', 0) ],
"_ease_v_1_rel" : [ SenseInfo('01834213-v', 4), SenseInfo('00082308-v', 4), SenseInfo('00518395-v', 3), SenseInfo('01815185-v', 1), SenseInfo('01834213-v', 4), SenseInfo('00082308-v', 4), SenseInfo('00518395-v', 3), SenseInfo('01815185-v', 1) ],
"_ketchup_n_1_rel" : [ SenseInfo('07822197-n', 0) ],
"_retreat_v_1_rel" : [ SenseInfo('01994442-v', 10), SenseInfo('02092476-v', 0), SenseInfo('01994846-v', 0), SenseInfo('00799383-v', 0) ],
"_scout_v_for_rel" : [ SenseInfo('02167571-v', 2) ],
"_traumatize_v_1_rel" : [ SenseInfo('00090186-v', 0) ],
"_paralyze_v_1_rel" : [ SenseInfo('00268796-v', 1), SenseInfo('00268477-v', 1), SenseInfo('00268796-v', 1), SenseInfo('00268477-v', 1), SenseInfo('00268796-v', 1), SenseInfo('00268477-v', 1), SenseInfo('00268796-v', 1), SenseInfo('00268477-v', 1) ],
"_abscess_n_1_rel" : [ SenseInfo('14312172-n', 3) ],
"_slosh_n_1_rel" : [  ],
"_gecko_n_1_rel" : [ SenseInfo('01674990-n', 0) ],
"_slovenly_a_1_rel" : [ SenseInfo('02425749-a', 3), SenseInfo('02425749-a', 3), SenseInfo('02425749-a', 3) ],
"_tap_v_1_rel" : [ SenseInfo('01403314-v', 6), SenseInfo('02312318-v', 3), SenseInfo('01247804-v', 3), SenseInfo('01164273-v', 3), SenseInfo('02188848-v', 1), SenseInfo('02360274-v', 0), SenseInfo('02185373-v', 0), SenseInfo('01901021-v', 0), SenseInfo('01895757-v', 0), SenseInfo('01854519-v', 0), SenseInfo('01613732-v', 0), SenseInfo('00782057-v', 0), SenseInfo('01403314-v', 6), SenseInfo('02312318-v', 3), SenseInfo('01247804-v', 3), SenseInfo('01164273-v', 3), SenseInfo('02188848-v', 1), SenseInfo('02360274-v', 0), SenseInfo('02185373-v', 0), SenseInfo('01901021-v', 0), SenseInfo('01895757-v', 0), SenseInfo('01854519-v', 0), SenseInfo('01613732-v', 0), SenseInfo('00782057-v', 0) ],
"_deem_v_1_rel" : [ SenseInfo('00693780-v', 13), SenseInfo('00693780-v', 13) ],
"_representative_n_1_rel" : [ SenseInfo('10522035-n', 8), SenseInfo('10638385-n', 4), SenseInfo('09955781-n', 4), SenseInfo('05820620-n', 0), SenseInfo('10522035-n', 8), SenseInfo('10638385-n', 4), SenseInfo('09955781-n', 4), SenseInfo('05820620-n', 0), SenseInfo('10522035-n', 8), SenseInfo('10638385-n', 4), SenseInfo('09955781-n', 4), SenseInfo('05820620-n', 0) ],
"_ambler_n_1_rel" : [ SenseInfo('10553235-n', 0) ],
"_lifeless_a_1_rel" : [ SenseInfo('00097768-a', 2), SenseInfo('01087557-a', 1), SenseInfo('00119533-a', 0), SenseInfo('00100373-a', 0) ],
"_numerical_a_1_rel" : [ SenseInfo('01915586-a', 4), SenseInfo('02769933-a', 1), SenseInfo('02230795-a', 0), SenseInfo('01915586-a', 4), SenseInfo('02769933-a', 1), SenseInfo('02230795-a', 0) ],
"_should_v_modal_rel" : [ SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0) ],
"_overvoltage_n_1_rel" : [  ],
"_diploma_n_1_rel" : [ SenseInfo('06478582-n', 0) ],
"_counterclockwise_p_rel" : [ SenseInfo('00442057-a', 0), SenseInfo('00254059-r', 0) ],
"_yet_a_1_rel" : [  ],
"_throw_v_in_rel" : [ SenseInfo('01508368-v', 53), SenseInfo('02097204-v', 9), SenseInfo('01513430-v', 7), SenseInfo('01499265-v', 7), SenseInfo('01060317-v', 6), SenseInfo('01510173-v', 5), SenseInfo('01632897-v', 4), SenseInfo('02097341-v', 2), SenseInfo('01791232-v', 2), SenseInfo('01067664-v', 2), SenseInfo('01733477-v', 1), SenseInfo('01663443-v', 0), SenseInfo('01527754-v', 0), SenseInfo('01437011-v', 0), SenseInfo('00621734-v', 0), SenseInfo('01508368-v', 53), SenseInfo('02097204-v', 9), SenseInfo('01513430-v', 7), SenseInfo('01499265-v', 7), SenseInfo('01060317-v', 6), SenseInfo('01510173-v', 5), SenseInfo('01632897-v', 4), SenseInfo('02097341-v', 2), SenseInfo('01791232-v', 2), SenseInfo('01067664-v', 2), SenseInfo('01733477-v', 1), SenseInfo('01663443-v', 0), SenseInfo('01527754-v', 0), SenseInfo('01437011-v', 0), SenseInfo('00621734-v', 0) ],
"_northwestern_a_1_rel" : [ SenseInfo('01601981-a', 0), SenseInfo('00826658-a', 0), SenseInfo('01601981-a', 0), SenseInfo('00826658-a', 0) ],
"_webpage_n_1_rel" : [ SenseInfo('06358900-n', 0) ],
"_cliff_n_1_rel" : [ SenseInfo('09246464-n', 3) ],
"_remake_n_of_rel" : [ SenseInfo('04074329-n', 0) ],
"_swear_v_1_rel" : [ SenseInfo('00865387-v', 20), SenseInfo('01011031-v', 8), SenseInfo('00889947-v', 2), SenseInfo('01013040-v', 1), SenseInfo('00688377-v', 0), SenseInfo('00865387-v', 20), SenseInfo('01011031-v', 8), SenseInfo('00889947-v', 2), SenseInfo('01013040-v', 1), SenseInfo('00688377-v', 0) ],
"_clever_a_1_rel" : [ SenseInfo('00439252-a', 2), SenseInfo('01334958-a', 1), SenseInfo('00061885-a', 0), SenseInfo('00439252-a', 2), SenseInfo('01334958-a', 1), SenseInfo('00061885-a', 0), SenseInfo('00439252-a', 2), SenseInfo('01334958-a', 1), SenseInfo('00061885-a', 0), SenseInfo('00439252-a', 2), SenseInfo('01334958-a', 1), SenseInfo('00061885-a', 0) ],
"_mucosal_a_1_rel" : [ SenseInfo('02867505-a', 0) ],
"_gateway_n_1_rel" : [ SenseInfo('03428477-n', 1) ],
"_expressionless_a_1_rel" : [ SenseInfo('00501313-a', 2) ],
"_goose_n_1_rel" : [ SenseInfo('01855672-n', 3), SenseInfo('10157744-n', 0), SenseInfo('07646821-n', 0) ],
"_thai_n_1_rel" : [ SenseInfo('09734294-n', 0), SenseInfo('06936149-n', 0) ],
"_open_v_1_rel" : [ SenseInfo('01346003-v', 66), SenseInfo('02426171-v', 45), SenseInfo('01346804-v', 17), SenseInfo('02425462-v', 14), SenseInfo('01579813-v', 4), SenseInfo('00539936-v', 4), SenseInfo('00540101-v', 2), SenseInfo('02744651-v', 1), SenseInfo('01077887-v', 1), SenseInfo('02358034-v', 0), SenseInfo('02140630-v', 0) ],
"_dump_n_1_rel" : [ SenseInfo('13555775-n', 0), SenseInfo('08560027-n', 0), SenseInfo('06390227-n', 0), SenseInfo('03255790-n', 0) ],
"_designate_n_1_rel" : [ SenseInfo('01294756-a', 0) ],
"_incident_n_1_rel" : [ SenseInfo('07307477-n', 22), SenseInfo('13978033-n', 0), SenseInfo('07307477-n', 22), SenseInfo('13978033-n', 0), SenseInfo('07307477-n', 22), SenseInfo('13978033-n', 0) ],
"_reorg_n_1_rel" : [  ],
"_confidentiality_n_1_rel" : [ SenseInfo('14416668-n', 1), SenseInfo('05615749-n', 0) ],
"_untrue_a_1_rel" : [ SenseInfo('02462489-a', 1), SenseInfo('00960481-a', 0), SenseInfo('00912637-a', 0), SenseInfo('00584403-a', 0), SenseInfo('02462489-a', 1), SenseInfo('00960481-a', 0), SenseInfo('00912637-a', 0), SenseInfo('00584403-a', 0) ],
"_rot_v_1_rel" : [ SenseInfo('00209837-v', 3), SenseInfo('00093775-v', 0) ],
"_physical_n_1_rel" : [ SenseInfo('01778212-a', 29), SenseInfo('02779774-a', 5), SenseInfo('00627004-a', 5), SenseInfo('01574259-a', 3), SenseInfo('00874092-a', 2), SenseInfo('00842324-a', 0), SenseInfo('00627204-a', 0) ],
"_sire_a_1_rel" : [ SenseInfo('10601725-n', 0), SenseInfo('10102800-n', 0), SenseInfo('01323355-n', 0) ],
"_duvet_n_1_rel" : [ SenseInfo('03266749-n', 0) ],
"_same_a_as_rel" : [ SenseInfo('02068476-a', 129), SenseInfo('02062670-a', 80), SenseInfo('01411065-a', 20), SenseInfo('00355611-a', 17) ],
"_unfasten_v_1_rel" : [ SenseInfo('01344293-v', 1), SenseInfo('01344140-v', 0) ],
"_south_n_of_rel" : [ SenseInfo('09050730-n', 37), SenseInfo('09050244-n', 5), SenseInfo('13833375-n', 2), SenseInfo('08561583-n', 2), SenseInfo('13835899-n', 0) ],
"_simplify_v_1_rel" : [ SenseInfo('00400427-v', 3), SenseInfo('00400427-v', 3) ],
"_steam_v_open_rel" : [ SenseInfo('01944976-v', 2), SenseInfo('02768579-v', 1), SenseInfo('01970272-v', 0), SenseInfo('01787319-v', 0), SenseInfo('01245325-v', 0), SenseInfo('00327145-v', 0) ],
"_endeavor_n_1_rel" : [ SenseInfo('00796886-n', 5), SenseInfo('00786195-n', 3), SenseInfo('00796886-n', 5), SenseInfo('00786195-n', 3), SenseInfo('00796886-n', 5), SenseInfo('00786195-n', 3), SenseInfo('00796886-n', 5), SenseInfo('00786195-n', 3) ],
"_pull_v_over_rel" : [ SenseInfo('01448100-v', 44), SenseInfo('01505254-v', 8), SenseInfo('02057499-v', 6), SenseInfo('01609287-v', 3), SenseInfo('02582615-v', 2), SenseInfo('01995211-v', 2), SenseInfo('02057337-v', 1), SenseInfo('00071803-v', 1), SenseInfo('02103162-v', 0), SenseInfo('01947247-v', 0), SenseInfo('01858573-v', 0), SenseInfo('01573276-v', 0), SenseInfo('01407059-v', 0), SenseInfo('01384275-v', 0), SenseInfo('01351170-v', 0), SenseInfo('01148710-v', 0), SenseInfo('00571596-v', 0), SenseInfo('01448100-v', 44), SenseInfo('01505254-v', 8), SenseInfo('02057499-v', 6), SenseInfo('01609287-v', 3), SenseInfo('02582615-v', 2), SenseInfo('01995211-v', 2), SenseInfo('02057337-v', 1), SenseInfo('00071803-v', 1), SenseInfo('02103162-v', 0), SenseInfo('01947247-v', 0), SenseInfo('01858573-v', 0), SenseInfo('01573276-v', 0), SenseInfo('01407059-v', 0), SenseInfo('01384275-v', 0), SenseInfo('01351170-v', 0), SenseInfo('01148710-v', 0), SenseInfo('00571596-v', 0) ],
"_therefrom_p_rel" : [ SenseInfo('00043794-r', 3), SenseInfo('00043608-r', 1) ],
"_correct_v_for_rel" : [ SenseInfo('00199659-v', 13), SenseInfo('02519991-v', 5), SenseInfo('00824292-v', 1), SenseInfo('02672540-v', 0), SenseInfo('02553428-v', 0), SenseInfo('01971603-v', 0), SenseInfo('00296178-v', 0), SenseInfo('00079470-v', 0) ],
"_hard-earned_a_1_rel" : [  ],
"_inmate_n_1_rel" : [ SenseInfo('10207370-n', 2), SenseInfo('10207681-n', 1), SenseInfo('09962966-n', 1) ],
"_separate_v_out_rel" : [ SenseInfo('02621853-v', 18), SenseInfo('01556921-v', 8), SenseInfo('00650353-v', 7), SenseInfo('02467662-v', 6), SenseInfo('01458973-v', 3), SenseInfo('00654625-v', 3), SenseInfo('02031158-v', 2), SenseInfo('02431320-v', 1), SenseInfo('02030158-v', 1), SenseInfo('00334186-v', 1), SenseInfo('02512305-v', 0), SenseInfo('01557774-v', 0), SenseInfo('00328802-v', 0) ],
"_mart_n_1_rel" : [ SenseInfo('03722288-n', 0) ],
"_semantic_a_1_rel" : [ SenseInfo('02842042-a', 3), SenseInfo('02842042-a', 3) ],
"_italian_a_1_rel" : [ SenseInfo('02957066-a', 8) ],
"_snatch_v_up_rel" : [ SenseInfo('01439745-v', 13), SenseInfo('01213146-v', 1), SenseInfo('01471043-v', 0) ],
"_nonmetal_n_1_rel" : [ SenseInfo('14627246-n', 0) ],
"_bombproof_a_1_rel" : [ SenseInfo('02525732-a', 0) ],
"_dyer_n_1_rel" : [ SenseInfo('10040515-n', 0) ],
"_dsl_n_1_rel" : [ SenseInfo('03196990-n', 0) ],
"_slap_v_down_rel" : [ SenseInfo('01416871-v', 15) ],
"_pitchfork_v_1_rel" : [ SenseInfo('01579340-v', 0) ],
"_wag_v_1_rel" : [ SenseInfo('01898592-v', 3) ],
"_spry_a_1_rel" : [ SenseInfo('00032733-a', 0), SenseInfo('00032733-a', 0), SenseInfo('00032733-a', 0) ],
"_distrust_v_1_rel" : [ SenseInfo('00687926-v', 3) ],
"_maintainable_a_1_rel" : [ SenseInfo('01963688-a', 0), SenseInfo('01963688-a', 0) ],
"_hypostasis_n_1_rel" : [ SenseInfo('13495507-n', 0), SenseInfo('13495413-n', 0), SenseInfo('09538021-n', 0), SenseInfo('05921868-n', 0) ],
"_pull_v_back_rel" : [ SenseInfo('01448100-v', 44), SenseInfo('01505254-v', 8), SenseInfo('02057499-v', 6), SenseInfo('01609287-v', 3), SenseInfo('02582615-v', 2), SenseInfo('01995211-v', 2), SenseInfo('02057337-v', 1), SenseInfo('00071803-v', 1), SenseInfo('02103162-v', 0), SenseInfo('01947247-v', 0), SenseInfo('01858573-v', 0), SenseInfo('01573276-v', 0), SenseInfo('01407059-v', 0), SenseInfo('01384275-v', 0), SenseInfo('01351170-v', 0), SenseInfo('01148710-v', 0), SenseInfo('00571596-v', 0), SenseInfo('01448100-v', 44), SenseInfo('01505254-v', 8), SenseInfo('02057499-v', 6), SenseInfo('01609287-v', 3), SenseInfo('02582615-v', 2), SenseInfo('01995211-v', 2), SenseInfo('02057337-v', 1), SenseInfo('00071803-v', 1), SenseInfo('02103162-v', 0), SenseInfo('01947247-v', 0), SenseInfo('01858573-v', 0), SenseInfo('01573276-v', 0), SenseInfo('01407059-v', 0), SenseInfo('01384275-v', 0), SenseInfo('01351170-v', 0), SenseInfo('01148710-v', 0), SenseInfo('00571596-v', 0) ],
"_health_n_1_rel" : [ SenseInfo('14447908-n', 21), SenseInfo('13923779-n', 0) ],
"_extravagance_n_1_rel" : [ SenseInfo('05118862-n', 0), SenseInfo('04894807-n', 0), SenseInfo('00743641-n', 0) ],
"_bottom_v_1_rel" : [ SenseInfo('02337699-v', 0), SenseInfo('01238358-v', 0), SenseInfo('00728954-v', 0) ],
"_pg_n_1_rel" : [  ],
"_slab_n_1_rel" : [ SenseInfo('04233405-n', 3) ],
"_press_v_1_rel" : [ SenseInfo('01447257-v', 32), SenseInfo('00765649-v', 7), SenseInfo('02646064-v', 2), SenseInfo('01390616-v', 2), SenseInfo('01387786-v', 2), SenseInfo('02024367-v', 1), SenseInfo('01754105-v', 1), SenseInfo('02722782-v', 0), SenseInfo('02589576-v', 0), SenseInfo('01662614-v', 0), SenseInfo('01447632-v', 0), SenseInfo('01390833-v', 0), SenseInfo('01150370-v', 0), SenseInfo('00759657-v', 0), SenseInfo('01447257-v', 32), SenseInfo('00765649-v', 7), SenseInfo('02646064-v', 2), SenseInfo('01390616-v', 2), SenseInfo('01387786-v', 2), SenseInfo('02024367-v', 1), SenseInfo('01754105-v', 1), SenseInfo('02722782-v', 0), SenseInfo('02589576-v', 0), SenseInfo('01662614-v', 0), SenseInfo('01447632-v', 0), SenseInfo('01390833-v', 0), SenseInfo('01150370-v', 0), SenseInfo('00759657-v', 0), SenseInfo('01447257-v', 32), SenseInfo('00765649-v', 7), SenseInfo('02646064-v', 2), SenseInfo('01390616-v', 2), SenseInfo('01387786-v', 2), SenseInfo('02024367-v', 1), SenseInfo('01754105-v', 1), SenseInfo('02722782-v', 0), SenseInfo('02589576-v', 0), SenseInfo('01662614-v', 0), SenseInfo('01447632-v', 0), SenseInfo('01390833-v', 0), SenseInfo('01150370-v', 0), SenseInfo('00759657-v', 0) ],
"_palmtop_n_1_rel" : [  ],
"loc_nonsp_rel" : [  ],
"_flexiday_n_1_rel" : [  ],
"_mynah_n_1_rel" : [ SenseInfo('01577659-n', 0) ],
"_outside_n_of_rel" : [ SenseInfo('08613593-n', 7), SenseInfo('08613472-n', 1) ],
"_hydride_n_1_rel" : [ SenseInfo('14910748-n', 4) ],
"_curiosity_n_1_rel" : [ SenseInfo('05682570-n', 19), SenseInfo('03149951-n', 0) ],
"_url_n_1_rel" : [ SenseInfo('06358747-n', 0) ],
"_zinc_n_1_rel" : [ SenseInfo('14661977-n', 6) ],
"_consort_v_with_rel" : [ SenseInfo('02589245-v', 2), SenseInfo('02700104-v', 0), SenseInfo('01927747-v', 0) ],
"_service_v_1_rel" : [ SenseInfo('02541251-v', 3), SenseInfo('00456937-v', 1), SenseInfo('01428011-v', 0) ],
"_washing_n_1_rel" : [ SenseInfo('00255710-n', 14), SenseInfo('03648219-n', 0) ],
"_sleek_a_1_rel" : [ SenseInfo('02427981-a', 0), SenseInfo('02238128-a', 0), SenseInfo('00282675-a', 0), SenseInfo('02427981-a', 0), SenseInfo('02238128-a', 0), SenseInfo('00282675-a', 0), SenseInfo('02427981-a', 0), SenseInfo('02238128-a', 0), SenseInfo('00282675-a', 0) ],
"_frolic_n_1_rel" : [ SenseInfo('00511817-n', 1) ],
"_drive_n_1_rel" : [ SenseInfo('00103834-n', 6), SenseInfo('03242995-n', 5), SenseInfo('00798245-n', 4), SenseInfo('03244388-n', 3), SenseInfo('04835724-n', 1), SenseInfo('00572489-n', 1), SenseInfo('00317594-n', 1), SenseInfo('00307631-n', 1), SenseInfo('14035298-n', 0), SenseInfo('03243218-n', 0), SenseInfo('03242713-n', 0), SenseInfo('00567044-n', 0), SenseInfo('00103834-n', 6), SenseInfo('03242995-n', 5), SenseInfo('00798245-n', 4), SenseInfo('03244388-n', 3), SenseInfo('04835724-n', 1), SenseInfo('00572489-n', 1), SenseInfo('00317594-n', 1), SenseInfo('00307631-n', 1), SenseInfo('14035298-n', 0), SenseInfo('03243218-n', 0), SenseInfo('03242713-n', 0), SenseInfo('00567044-n', 0) ],
"_scrape_n_1_rel" : [ SenseInfo('07392982-n', 2), SenseInfo('14286549-n', 0), SenseInfo('07275489-n', 0), SenseInfo('04693900-n', 0) ],
"_why_a_1_rel" : [ SenseInfo('09179606-n', 0) ],
"_waiver_n_of_rel" : [ SenseInfo('00213694-n', 0) ],
"_hence_a_1_rel" : [  ],
"_topography_n_1_rel" : [ SenseInfo('05064541-n', 3), SenseInfo('06122578-n', 0) ],
"_ambulance_n_1_rel" : [ SenseInfo('02701002-n', 3) ],
"_real_x_deg_rel" : [ SenseInfo('01932973-a', 54), SenseInfo('01937994-a', 14), SenseInfo('00031899-r', 8), SenseInfo('02119716-a', 4), SenseInfo('00013662-a', 3), SenseInfo('02460964-a', 1), SenseInfo('01939596-a', 0), SenseInfo('00625393-a', 0), SenseInfo('13729902-n', 0), SenseInfo('13667908-n', 0), SenseInfo('13389577-n', 0), SenseInfo('02392406-a', 0), SenseInfo('01941604-a', 0) ],
"_grab_v_at_rel" : [ SenseInfo('01439190-v', 27), SenseInfo('02304648-v', 4), SenseInfo('02099239-v', 1), SenseInfo('02358217-v', 0), SenseInfo('01350283-v', 0), SenseInfo('00737476-v', 0) ],
"_gain_v_on_rel" : [ SenseInfo('02292125-v', 27), SenseInfo('02288295-v', 13), SenseInfo('02290461-v', 7), SenseInfo('02020590-v', 5), SenseInfo('01111028-v', 2), SenseInfo('00158222-v', 2), SenseInfo('00157462-v', 2), SenseInfo('02289295-v', 1), SenseInfo('00046151-v', 0) ],
"_blandness_n_1_rel" : [ SenseInfo('04629417-n', 1), SenseInfo('04997282-n', 0), SenseInfo('04913322-n', 0) ],
"_insurrection_n_1_rel" : [ SenseInfo('00962129-n', 2) ],
"_naturopath_n_1_rel" : [ SenseInfo('10347110-n', 1) ],
"_exist_v_expl_rel" : [ SenseInfo('02603699-v', 100), SenseInfo('02616713-v', 5) ],
"_one-upsmanship_n_1_rel" : [  ],
"_attempt_v_1_rel" : [ SenseInfo('02530167-v', 50), SenseInfo('01651293-v', 15), SenseInfo('02530167-v', 50), SenseInfo('01651293-v', 15) ],
"_pair_v_up_rel" : [ SenseInfo('02490430-v', 3), SenseInfo('01292885-v', 2), SenseInfo('01465365-v', 0), SenseInfo('01465218-v', 0), SenseInfo('01428853-v', 0), SenseInfo('02490430-v', 3), SenseInfo('01292885-v', 2), SenseInfo('01465365-v', 0), SenseInfo('01465218-v', 0), SenseInfo('01428853-v', 0) ],
"_so_a_1_rel" : [ SenseInfo('06868844-n', 0), SenseInfo('06868844-n', 0), SenseInfo('06868844-n', 0) ],
"_incense_n_1_rel" : [ SenseInfo('14918994-n', 1), SenseInfo('05714745-n', 0) ],
"_stand_n_1_rel" : [ SenseInfo('02797692-n', 4), SenseInfo('08653706-n', 2), SenseInfo('08438384-n', 2), SenseInfo('04301000-n', 2), SenseInfo('04038440-n', 2), SenseInfo('07366145-n', 1), SenseInfo('06210363-n', 1), SenseInfo('04299215-n', 1), SenseInfo('01057053-n', 1), SenseInfo('04300741-n', 0), SenseInfo('02786984-n', 0), SenseInfo('00960851-n', 0), SenseInfo('02797692-n', 4), SenseInfo('08653706-n', 2), SenseInfo('08438384-n', 2), SenseInfo('04301000-n', 2), SenseInfo('04038440-n', 2), SenseInfo('07366145-n', 1), SenseInfo('06210363-n', 1), SenseInfo('04299215-n', 1), SenseInfo('01057053-n', 1), SenseInfo('04300741-n', 0), SenseInfo('02786984-n', 0), SenseInfo('00960851-n', 0) ],
"_unheard+of_a_1_rel" : [ SenseInfo('01377933-a', 0), SenseInfo('01377933-a', 0) ],
"_widow_v_1_rel" : [ SenseInfo('00360337-v', 0) ],
"_eighth_n_of_rel" : [ SenseInfo('13847616-n', 0), SenseInfo('13738140-n', 0), SenseInfo('13847616-n', 0), SenseInfo('13738140-n', 0), SenseInfo('13847616-n', 0), SenseInfo('13738140-n', 0) ],
"_growl_v_at_rel" : [ SenseInfo('01045719-v', 4) ],
"_diatom_n_1_rel" : [ SenseInfo('01401106-n', 1) ],
"_detective_n_1_rel" : [ SenseInfo('10009276-n', 27), SenseInfo('10009484-n', 1) ],
"_tadpole_n_1_rel" : [ SenseInfo('02469472-n', 1) ],
"_sticker_n_1_rel" : [ SenseInfo('13089631-n', 0), SenseInfo('07272545-n', 0), SenseInfo('06785367-n', 0), SenseInfo('03158885-n', 0) ],
"_crack_v_cause_rel" : [ SenseInfo('00336260-v', 6), SenseInfo('02183024-v', 4), SenseInfo('02182851-v', 2), SenseInfo('01401955-v', 2), SenseInfo('00539770-v', 2), SenseInfo('00337234-v', 1), SenseInfo('00337065-v', 1), SenseInfo('02571067-v', 0), SenseInfo('01785579-v', 0), SenseInfo('00953923-v', 0), SenseInfo('00336718-v', 0), SenseInfo('00238542-v', 0), SenseInfo('00238372-v', 0) ],
"_notation_n_1_rel" : [ SenseInfo('06808493-n', 2), SenseInfo('06763273-n', 0), SenseInfo('00615182-n', 0) ],
"_fertile_a_1_rel" : [ SenseInfo('01001689-a', 1), SenseInfo('01865967-a', 1), SenseInfo('01082115-a', 0), SenseInfo('01081340-a', 0) ],
"_slender_a_1_rel" : [ SenseInfo('00990855-a', 6), SenseInfo('02562566-a', 3), SenseInfo('02415025-a', 1), SenseInfo('01394744-a', 1), SenseInfo('01140290-a', 1), SenseInfo('00990855-a', 6), SenseInfo('02562566-a', 3), SenseInfo('02415025-a', 1), SenseInfo('01394744-a', 1), SenseInfo('01140290-a', 1), SenseInfo('00990855-a', 6), SenseInfo('02562566-a', 3), SenseInfo('02415025-a', 1), SenseInfo('01394744-a', 1), SenseInfo('01140290-a', 1) ],
"_lifeform_n_1_rel" : [  ],
"_whitewash_v_1_rel" : [ SenseInfo('02148109-v', 0), SenseInfo('01269702-v', 0), SenseInfo('00904878-v', 0) ],
"_mini_n_1_rel" : [ SenseInfo('03770439-n', 0) ],
"_deliver_v_from_rel" : [ SenseInfo('00989602-v', 21), SenseInfo('01438304-v', 15), SenseInfo('02293321-v', 6), SenseInfo('02551144-v', 3), SenseInfo('02503365-v', 2), SenseInfo('01062253-v', 1), SenseInfo('00989869-v', 1), SenseInfo('02551602-v', 0), SenseInfo('02358327-v', 0), SenseInfo('02235229-v', 0), SenseInfo('01509079-v', 0), SenseInfo('00056930-v', 0) ],
"_tablespoon_n_1_rel" : [ SenseInfo('13770310-n', 0), SenseInfo('04381073-n', 0) ],
"_send_v_1_rel" : [ SenseInfo('01951480-v', 79), SenseInfo('01437254-v', 20), SenseInfo('01031256-v', 20), SenseInfo('01950798-v', 14), SenseInfo('01088923-v', 5), SenseInfo('01062555-v', 5), SenseInfo('02348568-v', 3), SenseInfo('00973056-v', 2), SenseInfo('01951480-v', 79), SenseInfo('01437254-v', 20), SenseInfo('01031256-v', 20), SenseInfo('01950798-v', 14), SenseInfo('01088923-v', 5), SenseInfo('01062555-v', 5), SenseInfo('02348568-v', 3), SenseInfo('00973056-v', 2), SenseInfo('01951480-v', 79), SenseInfo('01437254-v', 20), SenseInfo('01031256-v', 20), SenseInfo('01950798-v', 14), SenseInfo('01088923-v', 5), SenseInfo('01062555-v', 5), SenseInfo('02348568-v', 3), SenseInfo('00973056-v', 2), SenseInfo('01951480-v', 79), SenseInfo('01437254-v', 20), SenseInfo('01031256-v', 20), SenseInfo('01950798-v', 14), SenseInfo('01088923-v', 5), SenseInfo('01062555-v', 5), SenseInfo('02348568-v', 3), SenseInfo('00973056-v', 2), SenseInfo('01951480-v', 79), SenseInfo('01437254-v', 20), SenseInfo('01031256-v', 20), SenseInfo('01950798-v', 14), SenseInfo('01088923-v', 5), SenseInfo('01062555-v', 5), SenseInfo('02348568-v', 3), SenseInfo('00973056-v', 2), SenseInfo('01951480-v', 79), SenseInfo('01437254-v', 20), SenseInfo('01031256-v', 20), SenseInfo('01950798-v', 14), SenseInfo('01088923-v', 5), SenseInfo('01062555-v', 5), SenseInfo('02348568-v', 3), SenseInfo('00973056-v', 2) ],
"_amber_n_1_rel" : [ SenseInfo('04966240-n', 1), SenseInfo('14894880-n', 0) ],
"_concomitant_a_1_rel" : [ SenseInfo('00122844-a', 0) ],
"_revenge_v_on_rel" : [ SenseInfo('01153486-v', 1), SenseInfo('01153486-v', 1) ],
"_climax_n_1_rel" : [ SenseInfo('07417043-n', 2), SenseInfo('06373747-n', 2), SenseInfo('00062133-n', 1), SenseInfo('14568516-n', 0), SenseInfo('07102373-n', 0) ],
"_local_n_1_rel" : [ SenseInfo('03680942-n', 2), SenseInfo('03681148-n', 0) ],
"_furnish_v_with_rel" : [ SenseInfo('02327200-v', 28), SenseInfo('02336483-v', 3) ],
"_statistical_a_1_rel" : [ SenseInfo('02911627-a', 5), SenseInfo('02911627-a', 5) ],
"_manifest_v_1_rel" : [ SenseInfo('00820976-v', 9), SenseInfo('01000878-v', 0), SenseInfo('00423075-v', 0) ],
"_dislocate_v_1_rel" : [ SenseInfo('00465762-v', 0), SenseInfo('00414823-v', 0) ],
"_leak_v_cause_rel" : [ SenseInfo('00937023-v', 1), SenseInfo('00936169-v', 0), SenseInfo('00529759-v', 0), SenseInfo('00258109-v', 0) ],
"_at+first_a_1_rel" : [  ],
"_vulva_n_1_rel" : [ SenseInfo('05521636-n', 0) ],
"_like_p_rel" : [ SenseInfo('01824736-v', 76), SenseInfo('01777210-v', 73), SenseInfo('01409581-a', 30), SenseInfo('01776952-v', 19), SenseInfo('00691665-v', 2), SenseInfo('01411065-a', 1), SenseInfo('01410606-a', 1), SenseInfo('01825962-v', 1), SenseInfo('05845888-n', 0), SenseInfo('05845419-n', 0), SenseInfo('02063554-a', 0), SenseInfo('01824736-v', 76), SenseInfo('01777210-v', 73), SenseInfo('01409581-a', 30), SenseInfo('01776952-v', 19), SenseInfo('00691665-v', 2), SenseInfo('01411065-a', 1), SenseInfo('01410606-a', 1), SenseInfo('01825962-v', 1), SenseInfo('05845888-n', 0), SenseInfo('05845419-n', 0), SenseInfo('02063554-a', 0) ],
"_thermal_a_1_rel" : [ SenseInfo('02814453-a', 27), SenseInfo('02814352-a', 0), SenseInfo('01250565-a', 0) ],
"_install_n_of_rel" : [  ],
"_emotional_a_1_rel" : [ SenseInfo('01927279-a', 19), SenseInfo('00853776-a', 7), SenseInfo('02983577-a', 2), SenseInfo('00085630-a', 0), SenseInfo('01927279-a', 19), SenseInfo('00853776-a', 7), SenseInfo('02983577-a', 2), SenseInfo('00085630-a', 0) ],
"_less_x_comp_rel" : [ SenseInfo('14221138-n', 0), SenseInfo('14221138-n', 0) ],
"_in-room_a_1_rel" : [  ],
"_burden_n_1_rel" : [ SenseInfo('05832745-n', 7), SenseInfo('03679986-n', 2), SenseInfo('06604066-n', 0), SenseInfo('05920159-n', 0) ],
"_expect_v_1_rel" : [ SenseInfo('00719734-v', 204), SenseInfo('00755745-v', 30), SenseInfo('00720063-v', 12), SenseInfo('00592702-v', 0), SenseInfo('00059376-v', 0), SenseInfo('00059019-v', 0), SenseInfo('00719734-v', 204), SenseInfo('00755745-v', 30), SenseInfo('00720063-v', 12), SenseInfo('00592702-v', 0), SenseInfo('00059376-v', 0), SenseInfo('00059019-v', 0), SenseInfo('00719734-v', 204), SenseInfo('00755745-v', 30), SenseInfo('00720063-v', 12), SenseInfo('00592702-v', 0), SenseInfo('00059376-v', 0), SenseInfo('00059019-v', 0), SenseInfo('00719734-v', 204), SenseInfo('00755745-v', 30), SenseInfo('00720063-v', 12), SenseInfo('00592702-v', 0), SenseInfo('00059376-v', 0), SenseInfo('00059019-v', 0), SenseInfo('00719734-v', 204), SenseInfo('00755745-v', 30), SenseInfo('00720063-v', 12), SenseInfo('00592702-v', 0), SenseInfo('00059376-v', 0), SenseInfo('00059019-v', 0), SenseInfo('00719734-v', 204), SenseInfo('00755745-v', 30), SenseInfo('00720063-v', 12), SenseInfo('00592702-v', 0), SenseInfo('00059376-v', 0), SenseInfo('00059019-v', 0), SenseInfo('00719734-v', 204), SenseInfo('00755745-v', 30), SenseInfo('00720063-v', 12), SenseInfo('00592702-v', 0), SenseInfo('00059376-v', 0), SenseInfo('00059019-v', 0) ],
"_prompt_n_1_rel" : [ SenseInfo('07011803-n', 0), SenseInfo('06280604-n', 0) ],
"_princess_n_of_rel" : [ SenseInfo('10474064-n', 0) ],
"_take-home_a_1_rel" : [ SenseInfo('01582698-a', 0), SenseInfo('01582698-a', 0) ],
"_imagination_n_1_rel" : [ SenseInfo('05625465-n', 16), SenseInfo('05767733-n', 9), SenseInfo('05633860-n', 4) ],
"_patrol_v_1_rel" : [ SenseInfo('02454939-v', 5) ],
"_sing_v_1_rel" : [ SenseInfo('01731031-v', 46), SenseInfo('01729431-v', 35), SenseInfo('01067816-v', 3), SenseInfo('01043887-v', 1), SenseInfo('00937208-v', 1), SenseInfo('01731031-v', 46), SenseInfo('01729431-v', 35), SenseInfo('01067816-v', 3), SenseInfo('01043887-v', 1), SenseInfo('00937208-v', 1), SenseInfo('01731031-v', 46), SenseInfo('01729431-v', 35), SenseInfo('01067816-v', 3), SenseInfo('01043887-v', 1), SenseInfo('00937208-v', 1) ],
"_deploy_v_1_rel" : [ SenseInfo('01149327-v', 2), SenseInfo('01379600-v', 0) ],
"_assess_v_1_rel" : [ SenseInfo('00681429-v', 14), SenseInfo('02308552-v', 0), SenseInfo('02308389-v', 0), SenseInfo('00682230-v', 0), SenseInfo('00681429-v', 14), SenseInfo('02308552-v', 0), SenseInfo('02308389-v', 0), SenseInfo('00682230-v', 0), SenseInfo('00681429-v', 14), SenseInfo('02308552-v', 0), SenseInfo('02308389-v', 0), SenseInfo('00682230-v', 0), SenseInfo('00681429-v', 14), SenseInfo('02308552-v', 0), SenseInfo('02308389-v', 0), SenseInfo('00682230-v', 0) ],
"_presidential_a_1_rel" : [ SenseInfo('02984104-a', 8), SenseInfo('00753504-a', 0) ],
"_therapist_n_1_rel" : [ SenseInfo('10707233-n', 9) ],
"_country_n_of_rel" : [ SenseInfo('08168978-n', 68), SenseInfo('08544813-n', 29), SenseInfo('08166552-n', 12), SenseInfo('08644722-n', 11), SenseInfo('08497294-n', 3) ],
"_cider_n_1_rel" : [ SenseInfo('07921455-n', 0) ],
"_convertible_n_1_rel" : [ SenseInfo('03100240-n', 2), SenseInfo('13419325-n', 0), SenseInfo('03100346-n', 0) ],
"_commensality_n_1_rel" : [  ],
"_leave_n_1_rel" : [ SenseInfo('15139130-n', 2), SenseInfo('06690114-n', 1), SenseInfo('00053097-n', 0), SenseInfo('15139130-n', 2), SenseInfo('06690114-n', 1), SenseInfo('00053097-n', 0) ],
"_weigh_v_up_rel" : [ SenseInfo('02704818-v', 17), SenseInfo('00950431-v', 4), SenseInfo('02704617-v', 2), SenseInfo('02645839-v', 1), SenseInfo('02646064-v', 0) ],
"_camber_n_1_rel" : [ SenseInfo('13864423-n', 0), SenseInfo('09213828-n', 0), SenseInfo('01001344-n', 0) ],
"_spot-weld_v_1_rel" : [ SenseInfo('01596056-v', 0), SenseInfo('01596056-v', 0) ],
"_wisdom_n_1_rel" : [ SenseInfo('05926236-n', 5), SenseInfo('04890112-n', 3), SenseInfo('05617107-n', 2), SenseInfo('05159948-n', 1), SenseInfo('06460524-n', 0) ],
"_spectrometry_n_1_rel" : [ SenseInfo('00649482-n', 0) ],
"_miss_v_out_rel" : [ SenseInfo('02127853-v', 16), SenseInfo('01805523-v', 13), SenseInfo('02613672-v', 9), SenseInfo('00614999-v', 6), SenseInfo('02022659-v', 5), SenseInfo('02632353-v', 4), SenseInfo('01237901-v', 4), SenseInfo('02632838-v', 1), SenseInfo('00810557-v', 0), SenseInfo('02127853-v', 16), SenseInfo('01805523-v', 13), SenseInfo('02613672-v', 9), SenseInfo('00614999-v', 6), SenseInfo('02022659-v', 5), SenseInfo('02632353-v', 4), SenseInfo('01237901-v', 4), SenseInfo('02632838-v', 1), SenseInfo('00810557-v', 0), SenseInfo('02127853-v', 16), SenseInfo('01805523-v', 13), SenseInfo('02613672-v', 9), SenseInfo('00614999-v', 6), SenseInfo('02022659-v', 5), SenseInfo('02632353-v', 4), SenseInfo('01237901-v', 4), SenseInfo('02632838-v', 1), SenseInfo('00810557-v', 0) ],
"_hunt_v_1_rel" : [ SenseInfo('01143838-v', 4), SenseInfo('02003601-v', 2), SenseInfo('02056691-v', 0), SenseInfo('02034147-v', 0), SenseInfo('01878376-v', 0), SenseInfo('01316401-v', 0), SenseInfo('01144657-v', 0) ],
"_savage_v_1_rel" : [ SenseInfo('01120900-v', 0), SenseInfo('00823827-v', 0) ],
"_exercise_n_1_rel" : [ SenseInfo('00624738-n', 26), SenseInfo('00947128-n', 3), SenseInfo('00894552-n', 2), SenseInfo('00729919-n', 2), SenseInfo('07454452-n', 0) ],
"_walnut_n_1_rel" : [ SenseInfo('07771212-n', 1), SenseInfo('12318615-n', 0), SenseInfo('12318378-n', 0) ],
"_foster_v_1_rel" : [ SenseInfo('02554422-v', 13), SenseInfo('02540569-v', 0), SenseInfo('00908351-v', 0) ],
"_traffic_v_1_rel" : [ SenseInfo('02261123-v', 0), SenseInfo('02260770-v', 0), SenseInfo('02261123-v', 0), SenseInfo('02260770-v', 0), SenseInfo('02261123-v', 0), SenseInfo('02260770-v', 0) ],
"_screenwriter_n_1_rel" : [ SenseInfo('10564400-n', 0) ],
"_ageless_a_1_rel" : [ SenseInfo('01755024-a', 0) ],
"_bristle_v_1_rel" : [ SenseInfo('02715595-v', 3), SenseInfo('01983597-v', 2), SenseInfo('02715456-v', 0), SenseInfo('00651298-v', 0) ],
"_fern_n_1_rel" : [ SenseInfo('11545714-n', 0) ],
"_crispbread_n_1_rel" : [  ],
"_nail_n_1_rel" : [ SenseInfo('05581693-n', 3), SenseInfo('03804744-n', 3), SenseInfo('13652335-n', 0) ],
"_saxifrage_n_1_rel" : [ SenseInfo('12793015-n', 0), SenseInfo('12793015-n', 0) ],
"_reclusive_a_1_rel" : [ SenseInfo('02250691-a', 0), SenseInfo('01859055-a', 0) ],
"_ail_v_cause_rel" : [ SenseInfo('00078665-v', 0), SenseInfo('00070816-v', 0) ],
"_testicle_n_1_rel" : [ SenseInfo('05524615-n', 2) ],
"_find_v_out-about_rel" : [ SenseInfo('02248465-v', 159), SenseInfo('02154508-v', 141), SenseInfo('02285629-v', 86), SenseInfo('00918872-v', 57), SenseInfo('00715239-v', 57), SenseInfo('02128873-v', 45), SenseInfo('02213336-v', 41), SenseInfo('01637982-v', 34), SenseInfo('00721437-v', 29), SenseInfo('02212275-v', 16), SenseInfo('00971999-v', 16), SenseInfo('00522751-v', 13), SenseInfo('02197781-v', 11), SenseInfo('02247977-v', 0), SenseInfo('02021653-v', 0), SenseInfo('00250691-v', 0) ],
"_backup_n_1_rel" : [ SenseInfo('13437181-n', 0), SenseInfo('10648237-n', 0), SenseInfo('07031752-n', 0), SenseInfo('02771840-n', 0), SenseInfo('01213886-n', 0), SenseInfo('13437181-n', 0), SenseInfo('10648237-n', 0), SenseInfo('07031752-n', 0), SenseInfo('02771840-n', 0), SenseInfo('01213886-n', 0), SenseInfo('13437181-n', 0), SenseInfo('10648237-n', 0), SenseInfo('07031752-n', 0), SenseInfo('02771840-n', 0), SenseInfo('01213886-n', 0) ],
"_correct_v_1_rel" : [ SenseInfo('00199659-v', 13), SenseInfo('02519991-v', 5), SenseInfo('00824292-v', 1), SenseInfo('02672540-v', 0), SenseInfo('02553428-v', 0), SenseInfo('01971603-v', 0), SenseInfo('00296178-v', 0), SenseInfo('00079470-v', 0) ],
"_vibrant_a_1_rel" : [ SenseInfo('02280969-a', 2), SenseInfo('02011002-a', 0), SenseInfo('00404110-a', 0) ],
"_intrigue_n_1_rel" : [ SenseInfo('05908520-n', 1), SenseInfo('13931356-n', 0) ],
"_guatemalan_n_1_rel" : [ SenseInfo('09712195-n', 0) ],
"_twig_n_1_rel" : [ SenseInfo('13163991-n', 1) ],
"_bunk_v_1_rel" : [ SenseInfo('02573853-v', 0), SenseInfo('02337230-v', 0), SenseInfo('02075049-v', 0) ],
"_cat_n_1_rel" : [ SenseInfo('02121620-n', 18), SenseInfo('10153414-n', 0), SenseInfo('09900153-n', 0), SenseInfo('03608870-n', 0), SenseInfo('02985606-n', 0), SenseInfo('02983507-n', 0), SenseInfo('02127808-n', 0), SenseInfo('00901476-n', 0) ],
"_toss_v_up_rel" : [ SenseInfo('01512625-v', 13), SenseInfo('01893079-v', 10), SenseInfo('01514525-v', 5), SenseInfo('01890792-v', 4), SenseInfo('02222318-v', 1), SenseInfo('01418536-v', 1) ],
"_wrinkly_a_1_rel" : [ SenseInfo('01360413-a', 0) ],
"_misunderstanding_n_of_rel" : [ SenseInfo('07174433-n', 1), SenseInfo('05895723-n', 0), SenseInfo('07174433-n', 1), SenseInfo('05895723-n', 0) ],
"_cast_v_with-i_rel" : [ SenseInfo('01632897-v', 15), SenseInfo('02236023-v', 3), SenseInfo('01710481-v', 2), SenseInfo('01507143-v', 1), SenseInfo('02385813-v', 0), SenseInfo('01881180-v', 0), SenseInfo('01662771-v', 0), SenseInfo('01513430-v', 0), SenseInfo('01078050-v', 0), SenseInfo('00981276-v', 0), SenseInfo('00076400-v', 0) ],
"_article_n_of_rel" : [ SenseInfo('06268096-n', 14), SenseInfo('00022903-n', 6), SenseInfo('06392935-n', 1), SenseInfo('06324669-n', 0) ],
"_sceptical_a_1_rel" : [ SenseInfo('02463847-a', 0), SenseInfo('00647247-a', 0), SenseInfo('02463847-a', 0), SenseInfo('00647247-a', 0) ],
"_flat_x_deg_rel" : [ SenseInfo('00910101-a', 11), SenseInfo('00659259-a', 5), SenseInfo('09281411-n', 2), SenseInfo('01913931-a', 2), SenseInfo('01239040-a', 2), SenseInfo('01021794-a', 1), SenseInfo('03360038-n', 1), SenseInfo('01578152-a', 0), SenseInfo('06866919-n', 0), SenseInfo('03360731-n', 0), SenseInfo('03359950-n', 0), SenseInfo('03359755-n', 0), SenseInfo('02726305-n', 0), SenseInfo('00341227-r', 0), SenseInfo('00058128-r', 0), SenseInfo('02413037-a', 0), SenseInfo('02399595-a', 0), SenseInfo('02307563-a', 0), SenseInfo('02277078-a', 0), SenseInfo('01541828-a', 0), SenseInfo('01233020-a', 0), SenseInfo('00660551-a', 0), SenseInfo('00283972-a', 0), SenseInfo('00038119-a', 0) ],
"_insult_v_1_rel" : [ SenseInfo('00848420-v', 3), SenseInfo('00848420-v', 3), SenseInfo('00848420-v', 3), SenseInfo('00848420-v', 3), SenseInfo('00848420-v', 3) ],
"_shamble_v_1_rel" : [ SenseInfo('01917549-v', 2), SenseInfo('01917549-v', 2) ],
"_basis_n_of_rel" : [ SenseInfo('13790912-n', 38), SenseInfo('05793554-n', 28), SenseInfo('13809769-n', 0) ],
"_pipit_n_1_rel" : [ SenseInfo('01528654-n', 0), SenseInfo('01528654-n', 0) ],
"_app_n_1_rel" : [  ],
"_inelegant_a_1_rel" : [ SenseInfo('00851103-a', 0) ],
"_wrack_v_i_rel" : [ SenseInfo('01566185-v', 1), SenseInfo('01566185-v', 1) ],
"_operational_a_1_rel" : [ SenseInfo('03014288-a', 7), SenseInfo('02124253-a', 4), SenseInfo('01660267-a', 2), SenseInfo('00833018-a', 1) ],
"_plateful_n_1_rel" : [ SenseInfo('13768850-n', 0) ],
"_orbit_v_1_rel" : [ SenseInfo('02043982-v', 2) ],
"_atmospheric_a_1_rel" : [ SenseInfo('02831736-a', 1) ],
"_exemplify_v_1_rel" : [ SenseInfo('02723733-v', 2), SenseInfo('01021128-v', 2) ],
"_chair_n_of_rel" : [ SenseInfo('03001627-n', 35), SenseInfo('00598056-n', 2), SenseInfo('10468962-n', 0), SenseInfo('03271030-n', 0), SenseInfo('03002096-n', 0) ],
"_pose_n_1_rel" : [ SenseInfo('04788011-n', 1), SenseInfo('05081300-n', 0), SenseInfo('00755673-n', 0) ],
"_hillbilly_n_1_rel" : [ SenseInfo('10176357-n', 1) ],
"_abatement_n_1_rel" : [ SenseInfo('07368256-n', 0), SenseInfo('00361333-n', 0) ],
"_vacation_n_1_rel" : [ SenseInfo('15137890-n', 23), SenseInfo('01253665-n', 0) ],
"_orientate_v_to_rel" : [ SenseInfo('02159197-v', 0), SenseInfo('02159197-v', 0) ],
"_shake_v_1_rel" : [ SenseInfo('01889610-v', 42), SenseInfo('00014034-v', 14), SenseInfo('01891638-v', 8), SenseInfo('01875295-v', 6), SenseInfo('00167385-v', 6), SenseInfo('01761706-v', 2), SenseInfo('02073545-v', 1), SenseInfo('00559556-v', 1), SenseInfo('00992518-v', 0), SenseInfo('01889610-v', 42), SenseInfo('00014034-v', 14), SenseInfo('01891638-v', 8), SenseInfo('01875295-v', 6), SenseInfo('00167385-v', 6), SenseInfo('01761706-v', 2), SenseInfo('02073545-v', 1), SenseInfo('00559556-v', 1), SenseInfo('00992518-v', 0) ],
"_bam_a_1_rel" : [ SenseInfo('08911726-n', 0), SenseInfo('07376257-n', 0), SenseInfo('08911726-n', 0), SenseInfo('07376257-n', 0) ],
"_cake_n_1_rel" : [ SenseInfo('02937469-n', 2), SenseInfo('07663899-n', 0), SenseInfo('07628870-n', 0) ],
"_throat_n_1_rel" : [ SenseInfo('05547508-n', 34), SenseInfo('04428920-n', 2), SenseInfo('04428763-n', 2), SenseInfo('01514549-n', 0) ],
"_technician_n_1_rel" : [ SenseInfo('10696251-n', 3), SenseInfo('10696508-n', 0) ],
"_session_n_1_rel" : [ SenseInfo('07145508-n', 13), SenseInfo('15225249-n', 6), SenseInfo('01232091-n', 4), SenseInfo('08417920-n', 0), SenseInfo('07145508-n', 13), SenseInfo('15225249-n', 6), SenseInfo('01232091-n', 4), SenseInfo('08417920-n', 0) ],
"_healthful_a_1_rel" : [ SenseInfo('01164763-a', 2), SenseInfo('02112976-a', 0) ],
"_bail_v_1_rel" : [ SenseInfo('02421749-v', 0), SenseInfo('02293732-v', 0), SenseInfo('00890403-v', 0), SenseInfo('00177136-v', 0), SenseInfo('00177011-v', 0) ],
"_proton_n_1_rel" : [ SenseInfo('09400037-n', 1) ],
"_overlay_n_1_rel" : [ SenseInfo('04187233-n', 0), SenseInfo('03864834-n', 0) ],
"_idle_v_cause_rel" : [ SenseInfo('01526483-v', 2), SenseInfo('02417504-v', 1) ],
"_coop_v_up_rel" : [  ],
"_rigamarole_n_1_rel" : [ SenseInfo('06609672-n', 0), SenseInfo('01026316-n', 0) ],
"_pipeline_n_1_rel" : [ SenseInfo('07223635-n', 0), SenseInfo('03946325-n', 0) ],
"_cerebral_a_1_rel" : [ SenseInfo('01927455-a', 2), SenseInfo('02688974-a', 1) ],
"_jackass_n_1_rel" : [ SenseInfo('10157744-n', 3), SenseInfo('02389943-n', 0) ],
"_undeliverable_a_1_rel" : [  ],
"_schoolyard_n_1_rel" : [ SenseInfo('08647264-n', 0) ],
"_emigrate_v_1_rel" : [ SenseInfo('00416135-v', 2) ],
"_perfect_a_1_rel" : [ SenseInfo('01749320-a', 17), SenseInfo('01520091-a', 0), SenseInfo('00915321-a', 0), SenseInfo('01749320-a', 17), SenseInfo('01520091-a', 0), SenseInfo('00915321-a', 0) ],
"_search_v_1_rel" : [ SenseInfo('01315613-v', 13), SenseInfo('02153709-v', 11), SenseInfo('00648224-v', 3), SenseInfo('01317723-v', 2) ],
"_lubricate_n_1_rel" : [  ],
"_relinquish_v_1_rel" : [ SenseInfo('02316304-v', 9), SenseInfo('02534062-v', 0), SenseInfo('02227487-v', 0), SenseInfo('01474550-v', 0) ],
"_primer_n_1_rel" : [ SenseInfo('06414948-n', 1), SenseInfo('03407122-n', 0), SenseInfo('03360845-n', 0) ],
"_bike_v_1_rel" : [ SenseInfo('01935476-v', 0) ],
"_underscore_n_1_rel" : [ SenseInfo('06801418-n', 0) ],
"_supper_n_1_rel" : [ SenseInfo('07575984-n', 14), SenseInfo('08256567-n', 0), SenseInfo('07575984-n', 14), SenseInfo('08256567-n', 0) ],
"_snow_v_1_rel" : [ SenseInfo('02758977-v', 10), SenseInfo('00839194-v', 0) ],
"_novel_n_of_rel" : [ SenseInfo('06367879-n', 17), SenseInfo('03833065-n', 0) ],
"_outside_a_1_rel" : [ SenseInfo('01692969-a', 5), SenseInfo('01350225-a', 5), SenseInfo('00948514-a', 4), SenseInfo('01692222-a', 3), SenseInfo('01347749-a', 3), SenseInfo('00952761-a', 3), SenseInfo('01037885-a', 2), SenseInfo('01413084-a', 0), SenseInfo('00950002-a', 0), SenseInfo('00023655-a', 0) ],
"_save+for_p_rel" : [  ],
"_sawtooth_n_1_rel" : [ SenseInfo('04140976-n', 0) ],
"_swallow_v_up_rel" : [ SenseInfo('01201856-v', 12), SenseInfo('01083769-v', 4), SenseInfo('01582409-v', 2), SenseInfo('00941037-v', 0), SenseInfo('00799076-v', 0), SenseInfo('00737352-v', 0), SenseInfo('00668805-v', 0), SenseInfo('00601659-v', 0) ],
"_speak_v_up_rel" : [ SenseInfo('00941990-v', 86), SenseInfo('00962447-v', 53), SenseInfo('00963570-v', 23), SenseInfo('00989201-v', 11), SenseInfo('02135607-v', 3) ],
"_potato_n_1_rel" : [ SenseInfo('07710616-n', 2), SenseInfo('12897493-n', 0) ],
"_plug_v_1_rel" : [ SenseInfo('01422886-v', 2), SenseInfo('00351266-v', 1), SenseInfo('01415285-v', 0), SenseInfo('00976487-v', 0), SenseInfo('00188137-v', 0), SenseInfo('00188000-v', 0), SenseInfo('01422886-v', 2), SenseInfo('00351266-v', 1), SenseInfo('01415285-v', 0), SenseInfo('00976487-v', 0), SenseInfo('00188137-v', 0), SenseInfo('00188000-v', 0), SenseInfo('01422886-v', 2), SenseInfo('00351266-v', 1), SenseInfo('01415285-v', 0), SenseInfo('00976487-v', 0), SenseInfo('00188137-v', 0), SenseInfo('00188000-v', 0), SenseInfo('01422886-v', 2), SenseInfo('00351266-v', 1), SenseInfo('01415285-v', 0), SenseInfo('00976487-v', 0), SenseInfo('00188137-v', 0), SenseInfo('00188000-v', 0) ],
"_bunting_n_1_rel" : [ SenseInfo('02921195-n', 0), SenseInfo('01537134-n', 0) ],
"_a+great+deal_x_rel" : [ SenseInfo('00059171-r', 1), SenseInfo('00059413-r', 0) ],
"_ooze_n_1_rel" : [ SenseInfo('14956661-n', 0), SenseInfo('07432119-n', 0) ],
"_tetherball_n_1_rel" : [ SenseInfo('00464277-n', 0) ],
"_primitive_n_1_rel" : [ SenseInfo('09627462-n', 0), SenseInfo('06295113-n', 0), SenseInfo('06294941-n', 0) ],
"_evening_n_of_rel" : [ SenseInfo('15166462-n', 38), SenseInfo('15268094-n', 0), SenseInfo('15167906-n', 0), SenseInfo('15166462-n', 38), SenseInfo('15268094-n', 0), SenseInfo('15167906-n', 0), SenseInfo('15166462-n', 38), SenseInfo('15268094-n', 0), SenseInfo('15167906-n', 0), SenseInfo('15166462-n', 38), SenseInfo('15268094-n', 0), SenseInfo('15167906-n', 0), SenseInfo('15166462-n', 38), SenseInfo('15268094-n', 0), SenseInfo('15167906-n', 0) ],
"_surgeon_n_1_rel" : [ SenseInfo('10679174-n', 9) ],
"_jump_v_to_rel" : [ SenseInfo('01963942-v', 19), SenseInfo('01910373-v', 6), SenseInfo('01121178-v', 4), SenseInfo('00155727-v', 2), SenseInfo('02674564-v', 1), SenseInfo('01082937-v', 1), SenseInfo('00155547-v', 1), SenseInfo('02105082-v', 0), SenseInfo('02011865-v', 0), SenseInfo('01968275-v', 0), SenseInfo('01965156-v', 0), SenseInfo('01859050-v', 0), SenseInfo('00616498-v', 0), SenseInfo('00560391-v', 0), SenseInfo('00121506-v', 0) ],
"_upon_p_sel_rel" : [  ],
"_exigence_n_1_rel" : [  ],
"_devour_v_1_rel" : [ SenseInfo('01565360-v', 1), SenseInfo('01820798-v', 0), SenseInfo('01197014-v', 0), SenseInfo('01196653-v', 0) ],
"_anterior_a_1_rel" : [ SenseInfo('00130778-a', 3), SenseInfo('00122128-a', 0) ],
"_pre-and_a_1_rel" : [  ],
"_and+vice+versa_a_1_rel" : [  ],
"_circumstance_n_1_rel" : [ SenseInfo('13942875-n', 39), SenseInfo('14512817-n', 8), SenseInfo('05822746-n', 3), SenseInfo('07451338-n', 0), SenseInfo('13942875-n', 39), SenseInfo('14512817-n', 8), SenseInfo('05822746-n', 3), SenseInfo('07451338-n', 0) ],
"_slip_v_1_rel" : [ SenseInfo('01888295-v', 11), SenseInfo('00189669-v', 7), SenseInfo('01870275-v', 6), SenseInfo('00204391-v', 4), SenseInfo('02076280-v', 2), SenseInfo('00617748-v', 1), SenseInfo('02231328-v', 0), SenseInfo('02105549-v', 0), SenseInfo('02076501-v', 0), SenseInfo('00608978-v', 0), SenseInfo('00465762-v', 0), SenseInfo('01888295-v', 11), SenseInfo('00189669-v', 7), SenseInfo('01870275-v', 6), SenseInfo('00204391-v', 4), SenseInfo('02076280-v', 2), SenseInfo('00617748-v', 1), SenseInfo('02231328-v', 0), SenseInfo('02105549-v', 0), SenseInfo('02076501-v', 0), SenseInfo('00608978-v', 0), SenseInfo('00465762-v', 0), SenseInfo('01888295-v', 11), SenseInfo('00189669-v', 7), SenseInfo('01870275-v', 6), SenseInfo('00204391-v', 4), SenseInfo('02076280-v', 2), SenseInfo('00617748-v', 1), SenseInfo('02231328-v', 0), SenseInfo('02105549-v', 0), SenseInfo('02076501-v', 0), SenseInfo('00608978-v', 0), SenseInfo('00465762-v', 0) ],
"_premiere_v_1_rel" : [ SenseInfo('01718331-v', 0), SenseInfo('01718185-v', 0) ],
"_shut_v_up_rel" : [ SenseInfo('01345109-v', 10), SenseInfo('01346978-v', 2), SenseInfo('02449340-v', 1), SenseInfo('01345109-v', 10), SenseInfo('01346978-v', 2), SenseInfo('02449340-v', 1) ],
"_mounting_n_1_rel" : [ SenseInfo('07370410-n', 0), SenseInfo('03793186-n', 0) ],
"_nomad_n_1_rel" : [ SenseInfo('10359759-n', 0) ],
"_lumbering_n_1_rel" : [ SenseInfo('00608789-n', 0) ],
"_east_n_of_rel" : [ SenseInfo('13832355-n', 6), SenseInfo('08562620-n', 4), SenseInfo('08563180-n', 2), SenseInfo('13835664-n', 0), SenseInfo('08561351-n', 0) ],
"_out+loud_a_1_rel" : [  ],
"_troubleshoot_v_1_rel" : [ SenseInfo('00262549-v', 0) ],
"_for+certain_a_1_rel" : [  ],
"_seldom_a_1_rel" : [  ],
"_determinable_a_1_rel" : [ SenseInfo('00738593-a', 1) ],
"_itinerary_n_1_rel" : [ SenseInfo('08616311-n', 0), SenseInfo('06423378-n', 0), SenseInfo('05905706-n', 0) ],
"_drivable_a_1_rel" : [  ],
"_entrance_v_1_rel" : [ SenseInfo('01806505-v', 0), SenseInfo('00020926-v', 0) ],
"_cuckoo_a_1_rel" : [ SenseInfo('10157744-n', 0), SenseInfo('01823013-n', 0) ],
"_longitude_n_1_rel" : [ SenseInfo('08596668-n', 1) ],
"_piper_n_1_rel" : [ SenseInfo('10435041-n', 1), SenseInfo('13149039-n', 0) ],
"_strip_n_of_rel" : [ SenseInfo('09449510-n', 8), SenseInfo('04339291-n', 6), SenseInfo('02693070-n', 4), SenseInfo('07003352-n', 1), SenseInfo('04339638-n', 0), SenseInfo('00531490-n', 0) ],
"_canadian_n_1_rel" : [ SenseInfo('09696585-n', 0), SenseInfo('09231890-n', 0) ],
"_doc_n_1_rel" : [ SenseInfo('10020890-n', 0), SenseInfo('08129268-n', 0) ],
"_implement_v_1_rel" : [ SenseInfo('02408965-v', 3), SenseInfo('02560164-v', 2), SenseInfo('00486018-v', 2) ],
"_bancorp_n_1_rel" : [  ],
"_inasmuch+as_x_subord_rel" : [  ],
"_flair_n_1_rel" : [ SenseInfo('05624461-n', 2), SenseInfo('04812871-n', 1), SenseInfo('13862644-n', 0) ],
"_monogram_n_1_rel" : [ SenseInfo('06824041-n', 0), SenseInfo('06824041-n', 0) ],
"_match_v_1_rel" : [ SenseInfo('02657219-v', 16), SenseInfo('02332627-v', 12), SenseInfo('01292885-v', 6), SenseInfo('02672187-v', 5), SenseInfo('00456740-v', 3), SenseInfo('02594674-v', 0), SenseInfo('01293389-v', 0), SenseInfo('01081152-v', 0), SenseInfo('00456596-v', 0), SenseInfo('00417001-v', 0) ],
"_cornmeal_n_1_rel" : [ SenseInfo('07568095-n', 1) ],
"_appliance_n_1_rel" : [ SenseInfo('02729965-n', 0), SenseInfo('02729837-n', 0), SenseInfo('02729965-n', 0), SenseInfo('02729837-n', 0), SenseInfo('02729965-n', 0), SenseInfo('02729837-n', 0) ],
"_newsgroup_n_1_rel" : [  ],
"_quell_v_1_rel" : [ SenseInfo('00463234-v', 3), SenseInfo('01194114-v', 0) ],
"_partition_n_1_rel" : [ SenseInfo('03894379-n', 2), SenseInfo('13627114-n', 0), SenseInfo('05222790-n', 0), SenseInfo('00397953-n', 0) ],
"_compositor_n_1_rel" : [ SenseInfo('09949946-n', 0) ],
"_friendship_n_1_rel" : [ SenseInfo('13931145-n', 3) ],
"_notch_n_1_rel" : [ SenseInfo('13905275-n', 1), SenseInfo('09386842-n', 0), SenseInfo('03832405-n', 0), SenseInfo('00387897-n', 0) ],
"_syrup_n_1_rel" : [ SenseInfo('07859583-n', 0) ],
"_haul_v_away_rel" : [ SenseInfo('01454810-v', 7), SenseInfo('01452255-v', 5) ],
"_file_v_for_rel" : [ SenseInfo('01001857-v', 50), SenseInfo('01387022-v', 10), SenseInfo('01920048-v', 3), SenseInfo('00869931-v', 2), SenseInfo('01001643-v', 1) ],
"_tingle_v_1_rel" : [ SenseInfo('02122983-v', 3) ],
"_one-on-one_a_1_rel" : [ SenseInfo('01860465-a', 0), SenseInfo('00494198-a', 0), SenseInfo('01860465-a', 0), SenseInfo('00494198-a', 0) ],
"_individualize_v_1_rel" : [ SenseInfo('00651759-v', 0), SenseInfo('00388065-v', 0) ],
"_root_n_1_rel" : [ SenseInfo('13125117-n', 11), SenseInfo('08507558-n', 2), SenseInfo('06300193-n', 2), SenseInfo('13731669-n', 1), SenseInfo('08005954-n', 1), SenseInfo('09792555-n', 0), SenseInfo('06300445-n', 0), SenseInfo('05308310-n', 0) ],
"_interloper_n_1_rel" : [ SenseInfo('10213652-n', 0) ],
"_detailed_a_1_rel" : [ SenseInfo('00310433-a', 26) ],
"_cascade_n_1_rel" : [ SenseInfo('09236957-n', 0), SenseInfo('08460152-n', 0), SenseInfo('07363668-n', 0) ],
"_nose_n_1_rel" : [ SenseInfo('05598147-n', 28), SenseInfo('03830835-n', 3), SenseInfo('03831062-n', 1), SenseInfo('13762458-n', 0), SenseInfo('06807056-n', 0), SenseInfo('05658826-n', 0), SenseInfo('05637106-n', 0), SenseInfo('03833564-n', 0) ],
"_often_a_1_rel" : [  ],
"_riffle_v_cause_rel" : [ SenseInfo('01591357-v', 1), SenseInfo('02153023-v', 0), SenseInfo('02040054-v', 0), SenseInfo('01419160-v', 0) ],
"_for+profit_a_1_rel" : [  ],
"_reorder_n_1_rel" : [ SenseInfo('06530255-n', 0) ],
"_freak_v_out_rel" : [ SenseInfo('01784148-v', 0), SenseInfo('01784148-v', 0) ],
"_trail_v_1_rel" : [ SenseInfo('02058756-v', 8), SenseInfo('02001858-v', 3), SenseInfo('02059916-v', 0), SenseInfo('01542842-v', 0), SenseInfo('01453969-v', 0) ],
"_look_v_around_rel" : [ SenseInfo('02130524-v', 274), SenseInfo('02133435-v', 126), SenseInfo('00033599-v', 25), SenseInfo('02153709-v', 8), SenseInfo('02693319-v', 1), SenseInfo('02549581-v', 1), SenseInfo('00929362-v', 1), SenseInfo('00720063-v', 1), SenseInfo('02658447-v', 0), SenseInfo('00712708-v', 0), SenseInfo('02130524-v', 274), SenseInfo('02133435-v', 126), SenseInfo('00033599-v', 25), SenseInfo('02153709-v', 8), SenseInfo('02693319-v', 1), SenseInfo('02549581-v', 1), SenseInfo('00929362-v', 1), SenseInfo('00720063-v', 1), SenseInfo('02658447-v', 0), SenseInfo('00712708-v', 0) ],
"_blade_n_1_rel" : [ SenseInfo('13131883-n', 4), SenseInfo('09859285-n', 1), SenseInfo('09223591-n', 1), SenseInfo('04373894-n', 1), SenseInfo('07661165-n', 0), SenseInfo('05236029-n', 0), SenseInfo('02848806-n', 0), SenseInfo('02848523-n', 0), SenseInfo('02848216-n', 0) ],
"_usefulness_n_1_rel" : [ SenseInfo('05148699-n', 5) ],
"_conduct_v_1_rel" : [ SenseInfo('02445509-v', 44), SenseInfo('01732921-v', 30), SenseInfo('02518161-v', 2), SenseInfo('01999798-v', 2), SenseInfo('02079933-v', 1), SenseInfo('01733213-v', 0) ],
"_rubber-stamp_v_1_rel" : [ SenseInfo('01273632-v', 0), SenseInfo('00674517-v', 0), SenseInfo('01273632-v', 0), SenseInfo('00674517-v', 0) ],
"_plainness_n_1_rel" : [ SenseInfo('14487026-n', 0), SenseInfo('04821615-n', 0), SenseInfo('04697267-n', 0), SenseInfo('04691651-n', 0) ],
"_unify_v_1_rel" : [ SenseInfo('00367685-v', 5), SenseInfo('01462005-v', 2), SenseInfo('02603056-v', 0), SenseInfo('02469835-v', 0), SenseInfo('00243124-v', 0), SenseInfo('00367685-v', 5), SenseInfo('01462005-v', 2), SenseInfo('02603056-v', 0), SenseInfo('02469835-v', 0), SenseInfo('00243124-v', 0) ],
"_abduct_v_1_rel" : [ SenseInfo('01471043-v', 0), SenseInfo('01449427-v', 0) ],
"_natural_a_for_rel" : [ SenseInfo('01569965-a', 22), SenseInfo('01570892-a', 15), SenseInfo('01574036-a', 4), SenseInfo('01595050-a', 2), SenseInfo('01577771-a', 0), SenseInfo('02282985-a', 0), SenseInfo('01952643-a', 0), SenseInfo('01406180-a', 0), SenseInfo('01335708-a', 0), SenseInfo('00074594-a', 0), SenseInfo('01569965-a', 22), SenseInfo('01570892-a', 15), SenseInfo('01574036-a', 4), SenseInfo('01595050-a', 2), SenseInfo('01577771-a', 0), SenseInfo('02282985-a', 0), SenseInfo('01952643-a', 0), SenseInfo('01406180-a', 0), SenseInfo('01335708-a', 0), SenseInfo('00074594-a', 0), SenseInfo('01569965-a', 22), SenseInfo('01570892-a', 15), SenseInfo('01574036-a', 4), SenseInfo('01595050-a', 2), SenseInfo('01577771-a', 0), SenseInfo('02282985-a', 0), SenseInfo('01952643-a', 0), SenseInfo('01406180-a', 0), SenseInfo('01335708-a', 0), SenseInfo('00074594-a', 0), SenseInfo('01569965-a', 22), SenseInfo('01570892-a', 15), SenseInfo('01574036-a', 4), SenseInfo('01595050-a', 2), SenseInfo('01577771-a', 0), SenseInfo('02282985-a', 0), SenseInfo('01952643-a', 0), SenseInfo('01406180-a', 0), SenseInfo('01335708-a', 0), SenseInfo('00074594-a', 0), SenseInfo('01569965-a', 22), SenseInfo('01570892-a', 15), SenseInfo('01574036-a', 4), SenseInfo('01595050-a', 2), SenseInfo('01577771-a', 0), SenseInfo('02282985-a', 0), SenseInfo('01952643-a', 0), SenseInfo('01406180-a', 0), SenseInfo('01335708-a', 0), SenseInfo('00074594-a', 0) ],
"_dynamic_n_1_rel" : [ SenseInfo('09179962-n', 0) ],
"_pop-up_a_1_rel" : [ SenseInfo('06413260-n', 0), SenseInfo('00128976-n', 0), SenseInfo('06413260-n', 0), SenseInfo('00128976-n', 0) ],
"_protest_v_1_rel" : [ SenseInfo('00910135-v', 13), SenseInfo('02521410-v', 8), SenseInfo('01011542-v', 1), SenseInfo('00910135-v', 13), SenseInfo('02521410-v', 8), SenseInfo('01011542-v', 1), SenseInfo('00910135-v', 13), SenseInfo('02521410-v', 8), SenseInfo('01011542-v', 1), SenseInfo('00910135-v', 13), SenseInfo('02521410-v', 8), SenseInfo('01011542-v', 1) ],
"_nutritious_a_1_rel" : [ SenseInfo('02557719-a', 0) ],
"_bicker_v_1_rel" : [ SenseInfo('00774056-v', 1) ],
"_digestive_a_1_rel" : [ SenseInfo('03060385-a', 1) ],
"_backbone_n_1_rel" : [ SenseInfo('05694232-n', 1), SenseInfo('05032351-n', 1), SenseInfo('05588174-n', 0), SenseInfo('04277980-n', 0), SenseInfo('02768433-n', 0) ],
"_manageable_a_1_rel" : [ SenseInfo('01474513-a', 0), SenseInfo('01821690-a', 0), SenseInfo('01474513-a', 0), SenseInfo('01821690-a', 0) ],
"_aba_n_1_rel" : [ SenseInfo('02666079-n', 0), SenseInfo('02665985-n', 0) ],
"_tilt_v_cause_rel" : [ SenseInfo('02038357-v', 9), SenseInfo('01884577-v', 1), SenseInfo('01884974-v', 0), SenseInfo('01122906-v', 0) ],
"_edge_v_1_rel" : [ SenseInfo('02072501-v', 3), SenseInfo('02361600-v', 0), SenseInfo('01466978-v', 0), SenseInfo('01246843-v', 0), SenseInfo('02072501-v', 3), SenseInfo('02361600-v', 0), SenseInfo('01466978-v', 0), SenseInfo('01246843-v', 0) ],
"_visual_n_1_rel" : [ SenseInfo('02869563-a', 27), SenseInfo('02516148-a', 0) ],
"_sleeve_n_1_rel" : [ SenseInfo('04236377-n', 5), SenseInfo('04236702-n', 0) ],
"_amateur_n_1_rel" : [ SenseInfo('09786585-n', 11), SenseInfo('09786760-n', 0) ],
"_masseuse_n_1_rel" : [ SenseInfo('10298271-n', 0) ],
"_plural_n_1_rel" : [ SenseInfo('06295235-n', 0), SenseInfo('06295235-n', 0), SenseInfo('06295235-n', 0) ],
"_midland_a_1_rel" : [ SenseInfo('00463917-a', 0) ],
"_deal_v_in_rel" : [ SenseInfo('01033527-v', 34), SenseInfo('00734054-v', 15), SenseInfo('02370987-v', 14), SenseInfo('02587532-v', 9), SenseInfo('02294436-v', 5), SenseInfo('02244956-v', 4), SenseInfo('02436349-v', 3), SenseInfo('02377764-v', 3), SenseInfo('02246456-v', 2), SenseInfo('02445509-v', 0), SenseInfo('02294179-v', 0), SenseInfo('02246686-v', 0), SenseInfo('02245993-v', 0) ],
"_cafeteria_n_1_rel" : [ SenseInfo('02935891-n', 13) ],
"_vehicle_n_1_rel" : [ SenseInfo('04524313-n', 9), SenseInfo('06255081-n', 6), SenseInfo('15112086-n', 0), SenseInfo('09283193-n', 0) ],
"_monotonous_a_1_rel" : [ SenseInfo('00807817-a', 2), SenseInfo('01541828-a', 0) ],
"_mad_a_1_rel" : [ SenseInfo('00115193-a', 12), SenseInfo('02075321-a', 10), SenseInfo('02390724-a', 9), SenseInfo('02572038-a', 0), SenseInfo('00115193-a', 12), SenseInfo('02075321-a', 10), SenseInfo('02390724-a', 9), SenseInfo('02572038-a', 0), SenseInfo('00115193-a', 12), SenseInfo('02075321-a', 10), SenseInfo('02390724-a', 9), SenseInfo('02572038-a', 0), SenseInfo('00115193-a', 12), SenseInfo('02075321-a', 10), SenseInfo('02390724-a', 9), SenseInfo('02572038-a', 0) ],
"_sett_n_1_rel" : [ SenseInfo('03059528-n', 0) ],
"_mouse_n_1_rel" : [ SenseInfo('02330245-n', 14), SenseInfo('14289387-n', 0), SenseInfo('10335563-n', 0), SenseInfo('03793489-n', 0) ],
"_leadership_n_1_rel" : [ SenseInfo('01256417-n', 9), SenseInfo('08381436-n', 6), SenseInfo('14433361-n', 4), SenseInfo('05617310-n', 3) ],
"_counterclockwise_a_1_rel" : [ SenseInfo('00442057-a', 0) ],
"_similitude_n_1_rel" : [ SenseInfo('04744814-n', 6), SenseInfo('03117939-n', 0) ],
"_hypoallergenic_a_1_rel" : [  ],
"_racketeer_n_1_rel" : [ SenseInfo('10503247-n', 3) ],
"_cwa_n_1_rel" : [  ],
"_nary_x_deg_rel" : [ SenseInfo('02268882-a', 0) ],
"_wholesome_a_1_rel" : [ SenseInfo('02557357-a', 2), SenseInfo('01172692-a', 0) ],
"_chop_v_down_rel" : [ SenseInfo('01258091-v', 2), SenseInfo('01871471-v', 0), SenseInfo('01758410-v', 0), SenseInfo('01415454-v', 0), SenseInfo('01257173-v', 0), SenseInfo('01124535-v', 0) ],
"_home_a_sel_rel" : [ SenseInfo('01219827-a', 7), SenseInfo('02742844-a', 3), SenseInfo('01038332-a', 0) ],
"_going+to_v_qmodal_rel" : [ SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0), SenseInfo('01594811-a', 2), SenseInfo('02864551-a', 0), SenseInfo('02864400-a', 0) ],
"_strategic_a_1_rel" : [ SenseInfo('02950711-a', 3), SenseInfo('01279735-a', 1) ],
"_underwater_a_1_rel" : [ SenseInfo('02472252-a', 2), SenseInfo('00124685-a', 0) ],
"_gale_n_1_rel" : [ SenseInfo('11461825-n', 0) ],
"_consummate_v_1_rel" : [ SenseInfo('01641751-v', 2), SenseInfo('01641632-v', 1) ],
"_eclipse_v_1_rel" : [ SenseInfo('02744280-v', 1), SenseInfo('02158340-v', 1) ],
"_recognizer_n_1_rel" : [  ],
"_eat_v_out_rel" : [ SenseInfo('01168468-v', 61), SenseInfo('01166351-v', 13), SenseInfo('01179865-v', 4), SenseInfo('01766273-v', 0), SenseInfo('01157517-v', 0), SenseInfo('00274283-v', 0) ],
"_wander_v_off_rel" : [ SenseInfo('01881180-v', 18), SenseInfo('02576503-v', 1), SenseInfo('02102840-v', 0), SenseInfo('01882814-v', 0), SenseInfo('00780575-v', 0) ],
"_grind_v_1_rel" : [ SenseInfo('01594978-v', 4), SenseInfo('01394464-v', 3), SenseInfo('02419773-v', 1), SenseInfo('02048682-v', 1), SenseInfo('00331082-v', 1), SenseInfo('01624449-v', 0), SenseInfo('01624321-v', 0) ],
"_facial_a_1_rel" : [ SenseInfo('02877704-a', 0), SenseInfo('02725058-a', 0) ],
"_nostalgia_n_1_rel" : [ SenseInfo('07487375-n', 2) ],
"_germination_n_1_rel" : [ SenseInfo('13487207-n', 0), SenseInfo('07324235-n', 0) ],
"_insectivor_n_1_rel" : [  ],
"_romanian_a_1_rel" : [ SenseInfo('02962272-a', 0) ],
"_carsick_a_1_rel" : [ SenseInfo('02542675-a', 0) ],
"_price_n_of_rel" : [ SenseInfo('05145118-n', 56), SenseInfo('13303315-n', 9), SenseInfo('05163807-n', 2), SenseInfo('05141683-n', 2), SenseInfo('07167041-n', 1), SenseInfo('13303759-n', 0), SenseInfo('11246408-n', 0), SenseInfo('05145118-n', 56), SenseInfo('13303315-n', 9), SenseInfo('05163807-n', 2), SenseInfo('05141683-n', 2), SenseInfo('07167041-n', 1), SenseInfo('13303759-n', 0), SenseInfo('11246408-n', 0) ],
"_payback_n_1_rel" : [ SenseInfo('13296460-n', 0), SenseInfo('01235463-n', 0), SenseInfo('13296460-n', 0), SenseInfo('01235463-n', 0) ],
"_blackfly_n_1_rel" : [ SenseInfo('02252972-n', 0), SenseInfo('02205673-n', 0) ],
"_cleave_v_to_rel" : [ SenseInfo('01556572-v', 1), SenseInfo('01558681-v', 0), SenseInfo('01220885-v', 0) ],
"_demur_v_1_rel" : [ SenseInfo('00807941-v', 1), SenseInfo('01016626-v', 0) ],
"_commissioner_n_1_rel" : [ SenseInfo('09943811-n', 5), SenseInfo('09944022-n', 0) ],
"_corrugation_n_1_rel" : [ SenseInfo('13902229-n', 0), SenseInfo('00406485-n', 0) ],
"_crucifix_n_1_rel" : [ SenseInfo('03140292-n', 1), SenseInfo('00434844-n', 0) ],
"_encumber_v_with_rel" : [ SenseInfo('01301051-v', 0), SenseInfo('01301051-v', 0) ],
"_in+between_p_rel" : [ SenseInfo('01014953-a', 0), SenseInfo('01014953-a', 0) ],
"_surrender_n_1_rel" : [ SenseInfo('07542433-n', 1), SenseInfo('07255027-n', 1), SenseInfo('00213343-n', 0), SenseInfo('00067707-n', 0) ],
"_out_p_rel" : [ SenseInfo('00232862-r', 5), SenseInfo('02061487-a', 3), SenseInfo('00100213-a', 2), SenseInfo('01823948-a', 1), SenseInfo('00129527-n', 0), SenseInfo('00233413-r', 0), SenseInfo('00233295-r', 0), SenseInfo('02334973-a', 0), SenseInfo('01761375-a', 0), SenseInfo('01295946-a', 0), SenseInfo('00974908-a', 0), SenseInfo('00952653-a', 0), SenseInfo('00949797-a', 0), SenseInfo('00572714-a', 0), SenseInfo('00935456-v', 0), SenseInfo('00935264-v', 0), SenseInfo('00935141-v', 0), SenseInfo('00232862-r', 5), SenseInfo('02061487-a', 3), SenseInfo('00100213-a', 2), SenseInfo('01823948-a', 1), SenseInfo('00129527-n', 0), SenseInfo('00233413-r', 0), SenseInfo('00233295-r', 0), SenseInfo('02334973-a', 0), SenseInfo('01761375-a', 0), SenseInfo('01295946-a', 0), SenseInfo('00974908-a', 0), SenseInfo('00952653-a', 0), SenseInfo('00949797-a', 0), SenseInfo('00572714-a', 0), SenseInfo('00935456-v', 0), SenseInfo('00935264-v', 0), SenseInfo('00935141-v', 0), SenseInfo('00232862-r', 5), SenseInfo('02061487-a', 3), SenseInfo('00100213-a', 2), SenseInfo('01823948-a', 1), SenseInfo('00129527-n', 0), SenseInfo('00233413-r', 0), SenseInfo('00233295-r', 0), SenseInfo('02334973-a', 0), SenseInfo('01761375-a', 0), SenseInfo('01295946-a', 0), SenseInfo('00974908-a', 0), SenseInfo('00952653-a', 0), SenseInfo('00949797-a', 0), SenseInfo('00572714-a', 0), SenseInfo('00935456-v', 0), SenseInfo('00935264-v', 0), SenseInfo('00935141-v', 0) ],
"_spectral_a_1_rel" : [ SenseInfo('02800132-a', 4), SenseInfo('01574925-a', 2) ],
"_able_a_1_rel" : [ SenseInfo('00001740-a', 70), SenseInfo('00510348-a', 7), SenseInfo('00306663-a', 4), SenseInfo('01017439-a', 0), SenseInfo('00001740-a', 70), SenseInfo('00510348-a', 7), SenseInfo('00306663-a', 4), SenseInfo('01017439-a', 0) ],
"_break_v_into_rel" : [ SenseInfo('00364064-v', 15), SenseInfo('00334186-v', 13), SenseInfo('00258665-v', 9), SenseInfo('01369758-v', 8), SenseInfo('00334996-v', 8), SenseInfo('02566528-v', 5), SenseInfo('02073233-v', 4), SenseInfo('02029369-v', 4), SenseInfo('01785395-v', 4), SenseInfo('00362348-v', 4), SenseInfo('02570684-v', 3), SenseInfo('00202569-v', 3), SenseInfo('02668523-v', 2), SenseInfo('01106864-v', 2), SenseInfo('00933821-v', 2), SenseInfo('00558536-v', 2), SenseInfo('00434374-v', 2), SenseInfo('02535716-v', 1), SenseInfo('02030764-v', 1), SenseInfo('01972976-v', 1), SenseInfo('00390215-v', 1), SenseInfo('00202784-v', 1), SenseInfo('02746617-v', 0), SenseInfo('02746449-v', 0), SenseInfo('02681639-v', 0), SenseInfo('02681524-v', 0), SenseInfo('02625187-v', 0), SenseInfo('02600082-v', 0), SenseInfo('02559395-v', 0), SenseInfo('02478469-v', 0), SenseInfo('02431320-v', 0), SenseInfo('02399331-v', 0), SenseInfo('02318165-v', 0), SenseInfo('02101373-v', 0), SenseInfo('01991347-v', 0), SenseInfo('01989053-v', 0), SenseInfo('01896484-v', 0), SenseInfo('01610666-v', 0), SenseInfo('01610463-v', 0), SenseInfo('01597995-v', 0), SenseInfo('01557646-v', 0), SenseInfo('01369346-v', 0), SenseInfo('01298931-v', 0), SenseInfo('01228524-v', 0), SenseInfo('01228396-v', 0), SenseInfo('00935987-v', 0), SenseInfo('00779061-v', 0), SenseInfo('00778745-v', 0), SenseInfo('00744439-v', 0), SenseInfo('00738440-v', 0), SenseInfo('00738314-v', 0), SenseInfo('00551412-v', 0), SenseInfo('00339464-v', 0), SenseInfo('00336260-v', 0), SenseInfo('00258366-v', 0), SenseInfo('00155046-v', 0), SenseInfo('00107739-v', 0), SenseInfo('00107604-v', 0), SenseInfo('00030463-v', 0) ],
"_sanctify_v_1_rel" : [ SenseInfo('00866702-v', 0), SenseInfo('00475819-v', 0) ],
"_neurode_n_1_rel" : [  ],
"_watch_v_for_rel" : [ SenseInfo('02150510-v', 77), SenseInfo('02455407-v', 64), SenseInfo('02150948-v', 24), SenseInfo('02128653-v', 10), SenseInfo('02151966-v', 1), SenseInfo('02131963-v', 0), SenseInfo('00920336-v', 0) ],
"_squadron_n_1_rel" : [ SenseInfo('08220089-n', 1), SenseInfo('08219768-n', 1), SenseInfo('08220228-n', 0), SenseInfo('08220089-n', 1), SenseInfo('08219768-n', 1), SenseInfo('08220228-n', 0) ],
"_notification_n_of_rel" : [ SenseInfo('01187463-n', 1), SenseInfo('07212424-n', 0), SenseInfo('07185668-n', 0), SenseInfo('01187463-n', 1), SenseInfo('07212424-n', 0), SenseInfo('07185668-n', 0) ],
"_inning_n_1_rel" : [ SenseInfo('15255804-n', 16) ],
"_tan_a_1_rel" : [ SenseInfo('00384533-a', 0) ],
"_systematical_a_1_rel" : [  ],
"_wanton_a_1_rel" : [ SenseInfo('01559270-a', 0), SenseInfo('00361837-a', 0) ],
"_whirl_v_cause_rel" : [ SenseInfo('02048891-v', 6), SenseInfo('02048051-v', 2), SenseInfo('02047650-v', 1), SenseInfo('02046755-v', 1), SenseInfo('02047857-v', 0) ],
"_midsection_n_1_rel" : [ SenseInfo('05555473-n', 1) ],
"_pale_v_1_rel" : [ SenseInfo('00103619-v', 1) ],
"_scrabble_n_1_rel" : [ SenseInfo('04155310-n', 0), SenseInfo('00502161-n', 0) ],
"_chinese_n_1_rel" : [ SenseInfo('06929742-n', 1), SenseInfo('09698108-n', 0), SenseInfo('06929742-n', 1), SenseInfo('09698108-n', 0), SenseInfo('06929742-n', 1), SenseInfo('09698108-n', 0) ],
"_crosstree_n_1_rel" : [  ],
"_undershirt_n_1_rel" : [ SenseInfo('04223299-n', 3) ],
"_pop_n_1_rel" : [ SenseInfo('09988063-n', 1), SenseInfo('07927512-n', 0), SenseInfo('07390400-n', 0), SenseInfo('07059962-n', 0) ],
"_sienna_a_1_rel" : [ SenseInfo('14843493-n', 0) ],
"_bribe_n_1_rel" : [ SenseInfo('13284562-n', 1) ],
"_thermostated_a_1_rel" : [  ],
"_out_n_1_rel" : [ SenseInfo('00129527-n', 0) ],
"_hometown_n_1_rel" : [ SenseInfo('08671644-n', 1), SenseInfo('08671644-n', 1) ],
"_hab_n_1_rel" : [  ],
"_nearby_a_1_rel" : [ SenseInfo('00445169-a', 8) ],
"_fault_n_1_rel" : [ SenseInfo('00070965-n', 8), SenseInfo('14464203-n', 4), SenseInfo('05139094-n', 1), SenseInfo('09278537-n', 0), SenseInfo('07422244-n', 0), SenseInfo('04669692-n', 0), SenseInfo('00568813-n', 0), SenseInfo('00070965-n', 8), SenseInfo('14464203-n', 4), SenseInfo('05139094-n', 1), SenseInfo('09278537-n', 0), SenseInfo('07422244-n', 0), SenseInfo('04669692-n', 0), SenseInfo('00568813-n', 0) ],
"_ebb_n_1_rel" : [ SenseInfo('13470491-n', 0), SenseInfo('07402147-n', 0) ],
"_receptacle_n_1_rel" : [ SenseInfo('04060904-n', 1), SenseInfo('13130161-n', 0), SenseInfo('04061442-n', 0) ],
"_unborn_a_1_rel" : [ SenseInfo('01733661-a', 1), SenseInfo('01733661-a', 1) ],
"_watchman_n_1_rel" : [ SenseInfo('10770059-n', 1) ],
"_orchid_n_1_rel" : [ SenseInfo('12041446-n', 1), SenseInfo('12041446-n', 1) ],
"_reputation_n_1_rel" : [ SenseInfo('14438125-n', 5), SenseInfo('14439294-n', 4), SenseInfo('06207199-n', 0) ],
"_morality_n_1_rel" : [ SenseInfo('04846770-n', 8), SenseInfo('09183693-n', 5) ],
"_onto_p_rel" : [  ],
"_fiddler_n_1_rel" : [ SenseInfo('10754578-n', 0), SenseInfo('10734235-n', 0), SenseInfo('10712229-n', 0) ],
"_abound_v_1_rel" : [ SenseInfo('02715279-v', 2), SenseInfo('02715595-v', 0) ],
"_farmer_n_1_rel" : [ SenseInfo('10078806-n', 29), SenseInfo('10966665-n', 0), SenseInfo('10966496-n', 0) ],
"_sustenance_n_1_rel" : [ SenseInfo('07570720-n', 2), SenseInfo('13365286-n', 0), SenseInfo('01216191-n', 0) ],
"_tenor_n_1_rel" : [ SenseInfo('06872676-n', 1), SenseInfo('04986054-n', 1), SenseInfo('10701783-n', 0), SenseInfo('06197503-n', 0), SenseInfo('05922450-n', 0) ],
"_grainy_a_1_rel" : [ SenseInfo('02231502-a', 0), SenseInfo('02231502-a', 0), SenseInfo('02231502-a', 0) ],
"_chi-chi_a_1_rel" : [ SenseInfo('00975692-a', 0), SenseInfo('00975692-a', 0) ],
"_rifle_v_1_rel" : [ SenseInfo('02344568-v', 1), SenseInfo('01318849-v', 0) ],
"_casement_n_1_rel" : [ SenseInfo('02976350-n', 0) ],
"_tear_v_off_rel" : [ SenseInfo('01573515-v', 19), SenseInfo('01556346-v', 7), SenseInfo('02055267-v', 2), SenseInfo('01384275-v', 1), SenseInfo('00066977-v', 0), SenseInfo('01573515-v', 19), SenseInfo('01556346-v', 7), SenseInfo('02055267-v', 2), SenseInfo('01384275-v', 1), SenseInfo('00066977-v', 0) ],
"_thumbnail_n_1_rel" : [ SenseInfo('05584390-n', 1) ],
"_freshness_n_1_rel" : [ SenseInfo('04926728-n', 1), SenseInfo('04800596-n', 1), SenseInfo('14051056-n', 0), SenseInfo('05635055-n', 0), SenseInfo('04915866-n', 0) ],
"_consequent_a_1_rel" : [ SenseInfo('00122844-a', 4), SenseInfo('00122844-a', 4), SenseInfo('00122844-a', 4) ],
"_subjective_a_1_rel" : [ SenseInfo('01615925-a', 10), SenseInfo('01273910-a', 0), SenseInfo('01615925-a', 10), SenseInfo('01273910-a', 0) ],
"_feel_v_seem-to_rel" : [ SenseInfo('01771535-v', 181), SenseInfo('00715239-v', 150), SenseInfo('02106006-v', 66), SenseInfo('00105958-v', 39), SenseInfo('00690305-v', 37), SenseInfo('02110552-v', 34), SenseInfo('02730471-v', 14), SenseInfo('02127613-v', 5), SenseInfo('01209678-v', 4), SenseInfo('01210352-v', 3), SenseInfo('02286027-v', 1), SenseInfo('02134350-v', 0), SenseInfo('01210152-v', 0) ],
"_dentists_a_1_rel" : [  ],
"_dc_n_1_rel" : [ SenseInfo('09070487-n', 7), SenseInfo('11447153-n', 1) ],
"_pave_v_1_rel" : [ SenseInfo('01267098-v', 0) ],
"_overflow_n_1_rel" : [ SenseInfo('00329819-n', 1), SenseInfo('07407272-n', 0) ],
"_military_a_1_rel" : [ SenseInfo('02764251-a', 37), SenseInfo('01518386-a', 12), SenseInfo('01517081-a', 3) ],
"_audition_v_1_rel" : [ SenseInfo('01718535-v', 2) ],
"_meerkat_n_1_rel" : [ SenseInfo('02138441-n', 0) ],
"_campus_n_1_rel" : [ SenseInfo('08518374-n', 2), SenseInfo('08518374-n', 2) ],
"_browser_n_1_rel" : [ SenseInfo('09877587-n', 0), SenseInfo('06571301-n', 0) ],
"_bat_n_1_rel" : [ SenseInfo('02139199-n', 2), SenseInfo('00458456-n', 1), SenseInfo('04292414-n', 0), SenseInfo('03132076-n', 0), SenseInfo('02806379-n', 0), SenseInfo('02139199-n', 2), SenseInfo('00458456-n', 1), SenseInfo('04292414-n', 0), SenseInfo('03132076-n', 0), SenseInfo('02806379-n', 0) ],
"_yummy_a_1_rel" : [ SenseInfo('02396720-a', 0), SenseInfo('02396720-a', 0), SenseInfo('02396720-a', 0) ],
"_berth_n_1_rel" : [ SenseInfo('00586262-n', 2), SenseInfo('08640111-n', 0), SenseInfo('02831724-n', 0) ],
"_bulky_a_1_rel" : [ SenseInfo('01384438-a', 4), SenseInfo('01384438-a', 4), SenseInfo('01384438-a', 4) ],
"_feasible_a_for_rel" : [ SenseInfo('01822563-a', 4), SenseInfo('01822563-a', 4), SenseInfo('01822563-a', 4) ],
"_thong_n_1_rel" : [ SenseInfo('03643907-n', 1), SenseInfo('04426427-n', 0), SenseInfo('04426316-n', 0), SenseInfo('03464053-n', 0), SenseInfo('03364008-n', 0) ],
"_solitude_n_1_rel" : [ SenseInfo('14415072-n', 1), SenseInfo('14414980-n', 0), SenseInfo('08652480-n', 0) ],
"_dribble_v_cause_rel" : [ SenseInfo('02070874-v', 2), SenseInfo('01611516-v', 0), SenseInfo('01408760-v', 0), SenseInfo('00102974-v', 0), SenseInfo('02070874-v', 2), SenseInfo('01611516-v', 0), SenseInfo('01408760-v', 0), SenseInfo('00102974-v', 0) ],
"_archegonium_n_1_rel" : [ SenseInfo('11689054-n', 0) ],
"_fortress_n_1_rel" : [ SenseInfo('03386011-n', 3), SenseInfo('03386011-n', 3) ],
"_affectionate_a_1_rel" : [ SenseInfo('01464700-a', 2) ],
"_contrary_n_1_rel" : [ SenseInfo('13858604-n', 3), SenseInfo('13858270-n', 0), SenseInfo('13783421-n', 0) ],
"_collinearity_n_1_rel" : [  ],
"_parish_n_1_rel" : [ SenseInfo('08223688-n', 3), SenseInfo('08615001-n', 0) ],
"_shortly_x_deg_rel" : [ SenseInfo('00034189-r', 6), SenseInfo('00033922-r', 3), SenseInfo('00297319-r', 2), SenseInfo('00289860-r', 0), SenseInfo('00034308-r', 0) ],
"_supporter_n_of_rel" : [ SenseInfo('10677713-n', 1), SenseInfo('10407954-n', 0), SenseInfo('09815790-n', 0), SenseInfo('03421117-n', 0), SenseInfo('02752615-n', 0) ],
"_of+interest_a_to_rel" : [  ],
"_allowance_n_1_rel" : [ SenseInfo('13286254-n', 2), SenseInfo('13293377-n', 1), SenseInfo('13274092-n', 1), SenseInfo('04749991-n', 1), SenseInfo('13370215-n', 0), SenseInfo('01141841-n', 0), SenseInfo('13286254-n', 2), SenseInfo('13293377-n', 1), SenseInfo('13274092-n', 1), SenseInfo('04749991-n', 1), SenseInfo('13370215-n', 0), SenseInfo('01141841-n', 0) ],
"_microsecond_n_1_rel" : [ SenseInfo('15236176-n', 4) ],
"_demonstrative_n_1_rel" : [ SenseInfo('06325678-n', 1) ],
"_distressing_a_for_rel" : [ SenseInfo('01189386-a', 3), SenseInfo('01126841-a', 0), SenseInfo('01189386-a', 3), SenseInfo('01126841-a', 0), SenseInfo('01189386-a', 3), SenseInfo('01126841-a', 0) ],
"_overweight_n_1_rel" : [ SenseInfo('05000537-n', 0) ],
"_yell_v_at_rel" : [ SenseInfo('00913065-v', 18), SenseInfo('00912833-v', 6) ],
"_honest_a_1_rel" : [ SenseInfo('01222360-a', 10), SenseInfo('02180157-a', 5), SenseInfo('02465519-a', 2), SenseInfo('01851795-a', 0), SenseInfo('01225643-a', 0), SenseInfo('01116026-a', 0), SenseInfo('00958475-a', 0), SenseInfo('01222360-a', 10), SenseInfo('02180157-a', 5), SenseInfo('02465519-a', 2), SenseInfo('01851795-a', 0), SenseInfo('01225643-a', 0), SenseInfo('01116026-a', 0), SenseInfo('00958475-a', 0), SenseInfo('01222360-a', 10), SenseInfo('02180157-a', 5), SenseInfo('02465519-a', 2), SenseInfo('01851795-a', 0), SenseInfo('01225643-a', 0), SenseInfo('01116026-a', 0), SenseInfo('00958475-a', 0) ],
"_foreclose_v_on_rel" : [ SenseInfo('02452885-v', 1), SenseInfo('02276568-v', 1) ],
"_bind_v_to_rel" : [ SenseInfo('01356750-v', 8), SenseInfo('02538086-v', 4), SenseInfo('01303242-v', 4), SenseInfo('01303547-v', 3), SenseInfo('01286913-v', 1), SenseInfo('00885217-v', 1), SenseInfo('01335804-v', 0), SenseInfo('01285440-v', 0), SenseInfo('00567291-v', 0), SenseInfo('00074558-v', 0), SenseInfo('01356750-v', 8), SenseInfo('02538086-v', 4), SenseInfo('01303242-v', 4), SenseInfo('01303547-v', 3), SenseInfo('01286913-v', 1), SenseInfo('00885217-v', 1), SenseInfo('01335804-v', 0), SenseInfo('01285440-v', 0), SenseInfo('00567291-v', 0), SenseInfo('00074558-v', 0) ],
"_aver_v_1_rel" : [ SenseInfo('01016002-v', 0), SenseInfo('01011031-v', 0) ],
"_deeper_a_1_rel" : [  ],
"_fumble_v_around_rel" : [ SenseInfo('01314738-v', 4), SenseInfo('02051547-v', 1), SenseInfo('01211019-v', 1), SenseInfo('02527651-v', 0), SenseInfo('01075327-v', 0) ],
"_cling_v_to_rel" : [ SenseInfo('01220885-v', 9), SenseInfo('01776065-v', 5), SenseInfo('01216331-v', 2) ],
"_coach_v_1_rel" : [ SenseInfo('00833702-v', 2), SenseInfo('01931262-v', 1) ],
"_sailor_n_1_rel" : [ SenseInfo('10546633-n', 3), SenseInfo('09861395-n', 1), SenseInfo('02859184-n', 0) ],
"_sicilian_a_1_rel" : [ SenseInfo('02959224-a', 2) ],
"_shank_n_1_rel" : [ SenseInfo('07657068-n', 0), SenseInfo('05562756-n', 0), SenseInfo('04184095-n', 0), SenseInfo('04183957-n', 0), SenseInfo('04183819-n', 0), SenseInfo('04183663-n', 0), SenseInfo('02462828-n', 0), SenseInfo('00573945-n', 0) ],
"_part_v_1_rel" : [ SenseInfo('02030158-v', 4), SenseInfo('02431320-v', 1), SenseInfo('02014165-v', 0), SenseInfo('01557774-v', 0), SenseInfo('01556921-v', 0) ],
"_cargo_n_1_rel" : [ SenseInfo('02964389-n', 3) ],
"_participial_a_1_rel" : [ SenseInfo('03097103-a', 0) ],
"_acclimitization_n_1_rel" : [  ],
"_intervene_v_1_rel" : [ SenseInfo('02538765-v', 4), SenseInfo('02691489-v', 0), SenseInfo('00340846-v', 0) ],
"_josh_v_1_rel" : [ SenseInfo('00855295-v', 0) ],
"_date_v_1_rel" : [ SenseInfo('02485844-v', 1), SenseInfo('00735389-v', 1), SenseInfo('00619183-v', 1), SenseInfo('02486232-v', 0), SenseInfo('00734927-v', 0), SenseInfo('02485844-v', 1), SenseInfo('00735389-v', 1), SenseInfo('00619183-v', 1), SenseInfo('02486232-v', 0), SenseInfo('00734927-v', 0) ],
"_sail_v_1_rel" : [ SenseInfo('01846658-v', 13), SenseInfo('01869563-v', 3), SenseInfo('01945516-v', 1), SenseInfo('01846320-v', 0) ],
"_frame_v_1_rel" : [ SenseInfo('01586850-v', 4), SenseInfo('02711835-v', 3), SenseInfo('02578008-v', 1), SenseInfo('00981276-v', 1), SenseInfo('00706804-v', 1), SenseInfo('01655763-v', 0) ],
"_gritty_a_1_rel" : [ SenseInfo('02231502-a', 1), SenseInfo('00263994-a', 0), SenseInfo('02231502-a', 1), SenseInfo('00263994-a', 0), SenseInfo('02231502-a', 1), SenseInfo('00263994-a', 0) ],
"_sheet_v_1_rel" : [ SenseInfo('02758262-v', 0), SenseInfo('01338501-v', 0) ],
"_lawnmower_n_1_rel" : [  ],
"_talk_v_over_rel" : [ SenseInfo('00962447-v', 108), SenseInfo('00941990-v', 26), SenseInfo('00963570-v', 8), SenseInfo('00952841-v', 4), SenseInfo('00937208-v', 2), SenseInfo('00830761-v', 0) ],
"_asphodel_n_1_rel" : [ SenseInfo('12441958-n', 0) ],
"_reflective_a_1_rel" : [ SenseInfo('02419434-a', 3), SenseInfo('02007882-a', 0), SenseInfo('01333331-a', 0) ],
"_overanxious_a_1_rel" : [ SenseInfo('02093703-a', 0) ],
"_promiscuity_n_1_rel" : [ SenseInfo('00856342-n', 0) ],
"_safer_a_for_rel" : [  ],
"_spammer_n_1_rel" : [ SenseInfo('10629545-n', 0) ],
"_intuition_n_1_rel" : [ SenseInfo('05707495-n', 4), SenseInfo('05919034-n', 1), SenseInfo('05707495-n', 4), SenseInfo('05919034-n', 1) ],
"_arabian_a_1_rel" : [ SenseInfo('03044566-a', 0), SenseInfo('03044462-a', 0) ],
"_faithful_a_1_rel" : [ SenseInfo('00958880-a', 5), SenseInfo('00022219-a', 1), SenseInfo('00960629-a', 0) ],
"_ntt_a_1_rel" : [  ],
"_preload_n_1_rel" : [  ],
"_acoustics_n_1_rel" : [ SenseInfo('02675987-n', 0) ],
"_seafarer_n_1_rel" : [ SenseInfo('10294602-n', 1) ],
"_fire_v_up_rel" : [ SenseInfo('01135783-v', 30), SenseInfo('01133825-v', 16), SenseInfo('00320536-v', 10), SenseInfo('02402825-v', 7), SenseInfo('01134238-v', 5), SenseInfo('02002410-v', 1), SenseInfo('01759326-v', 1), SenseInfo('00378664-v', 1), SenseInfo('02356420-v', 0) ],
"_swing_v_in_rel" : [ SenseInfo('02087745-v', 35), SenseInfo('01877355-v', 15), SenseInfo('01877620-v', 6), SenseInfo('02537238-v', 4), SenseInfo('01593763-v', 4), SenseInfo('02717472-v', 2), SenseInfo('01152040-v', 2), SenseInfo('00557216-v', 2), SenseInfo('02615140-v', 1), SenseInfo('02752277-v', 0), SenseInfo('02389815-v', 0), SenseInfo('01725375-v', 0), SenseInfo('01427483-v', 0) ],
"_internal_a_1_rel" : [ SenseInfo('00948670-a', 10), SenseInfo('01346978-a', 1), SenseInfo('01038332-a', 1), SenseInfo('00951831-a', 1), SenseInfo('01348835-a', 0), SenseInfo('00948670-a', 10), SenseInfo('01346978-a', 1), SenseInfo('01038332-a', 1), SenseInfo('00951831-a', 1), SenseInfo('01348835-a', 0) ],
"_insured_n_1_rel" : [ SenseInfo('10209888-n', 0) ],
"_unity_n_1_rel" : [ SenseInfo('14460565-n', 19), SenseInfo('13742573-n', 3), SenseInfo('04743370-n', 2) ],
"_share-alike_a_1_rel" : [  ],
"_biathlon_n_1_rel" : [  ],
"_mature_v_1_rel" : [ SenseInfo('00250181-v', 5), SenseInfo('00926156-v', 0), SenseInfo('00577998-v', 0), SenseInfo('00249969-v', 0), SenseInfo('00248026-v', 0), SenseInfo('00097179-v', 0) ],
"_brisk_a_1_rel" : [ SenseInfo('00874226-a', 2), SenseInfo('01357027-a', 1), SenseInfo('00035779-a', 0), SenseInfo('00874226-a', 2), SenseInfo('01357027-a', 1), SenseInfo('00035779-a', 0), SenseInfo('00874226-a', 2), SenseInfo('01357027-a', 1), SenseInfo('00035779-a', 0), SenseInfo('00874226-a', 2), SenseInfo('01357027-a', 1), SenseInfo('00035779-a', 0) ],
"_fyi_a_1_rel" : [  ],
"_palm_v_off_rel" : [ SenseInfo('01210737-v', 1) ],
"_survey_v_1_rel" : [ SenseInfo('00646542-v', 6), SenseInfo('02150328-v', 5), SenseInfo('02198602-v', 0), SenseInfo('00696700-v', 0), SenseInfo('00647929-v', 0), SenseInfo('00646738-v', 0) ],
"_individual_n_1_rel" : [ SenseInfo('00007846-n', 51), SenseInfo('10203839-n', 14) ],
"_wrath_n_1_rel" : [ SenseInfo('07516905-n', 8), SenseInfo('00758972-n', 0) ],
"_audacity_n_1_rel" : [ SenseInfo('04859449-n', 1), SenseInfo('04838510-n', 1) ],
"_gc_n_1_rel" : [ SenseInfo('15278691-n', 0) ],
"_inquest_n_1_rel" : [ SenseInfo('00637810-n', 1) ],
"_triangular_a_1_rel" : [ SenseInfo('02049428-a', 1), SenseInfo('00239847-a', 0) ],
"_squirrel_v_away_rel" : [  ],
"_ergonomics_n_1_rel" : [ SenseInfo('06126523-n', 0) ],
"_accomplish_v_1_rel" : [ SenseInfo('01640855-v', 29), SenseInfo('02526085-v', 13) ],
"_ice_v_over_rel" : [ SenseInfo('01517175-v', 0), SenseInfo('00375579-v', 0), SenseInfo('00370921-v', 0) ],
"_chocolate_n_1_rel" : [ SenseInfo('07922764-n', 1), SenseInfo('07601999-n', 0), SenseInfo('04972451-n', 0) ],
"_half-mile_n_1_rel" : [ SenseInfo('13651804-n', 3), SenseInfo('13651804-n', 3) ],
"_cool_v_cause_rel" : [ SenseInfo('00370412-v', 15), SenseInfo('00369864-v', 1), SenseInfo('00370126-v', 0), SenseInfo('00370412-v', 15), SenseInfo('00369864-v', 1), SenseInfo('00370126-v', 0) ],
"_uruguayan_a_1_rel" : [ SenseInfo('02967333-a', 0) ],
"_insurmountable_a_1_rel" : [ SenseInfo('02357115-a', 1), SenseInfo('00570225-a', 0) ],
"_shutter_v_1_rel" : [ SenseInfo('01242996-v', 0) ],
"_in_p_sel_rel" : [ SenseInfo('00501990-r', 19), SenseInfo('13649791-n', 3), SenseInfo('14641223-n', 0), SenseInfo('09084750-n', 0), SenseInfo('02332204-a', 0), SenseInfo('01295143-a', 0), SenseInfo('00972501-a', 0) ],
"_banner_n_1_rel" : [ SenseInfo('02788021-n', 4), SenseInfo('06345878-n', 0), SenseInfo('04301140-n', 0) ],
"_revulsion_n_1_rel" : [ SenseInfo('07503987-n', 3) ],
"_zeal_n_1_rel" : [ SenseInfo('07555402-n', 2), SenseInfo('07481785-n', 2), SenseInfo('04644719-n', 0) ],
"_polio_n_1_rel" : [ SenseInfo('14140176-n', 1) ],
"_until_p_rel" : [  ],
"_enjoy_v_1_rel" : [ SenseInfo('01820302-v', 52), SenseInfo('01192510-v', 15), SenseInfo('01828736-v', 10), SenseInfo('02110793-v', 9), SenseInfo('01190948-v', 6), SenseInfo('01820302-v', 52), SenseInfo('01192510-v', 15), SenseInfo('01828736-v', 10), SenseInfo('02110793-v', 9), SenseInfo('01190948-v', 6), SenseInfo('01820302-v', 52), SenseInfo('01192510-v', 15), SenseInfo('01828736-v', 10), SenseInfo('02110793-v', 9), SenseInfo('01190948-v', 6) ],
"_keychain_n_1_rel" : [  ],
"_freshen_v_up_rel" : [ SenseInfo('00164444-v', 0), SenseInfo('00024814-v', 0), SenseInfo('00024649-v', 0), SenseInfo('00164444-v', 0), SenseInfo('00024814-v', 0), SenseInfo('00024649-v', 0) ],
"_accumulate_v_1_rel" : [ SenseInfo('02304982-v', 4), SenseInfo('00158804-v', 4) ],
"_distill_v_1_rel" : [ SenseInfo('00475183-v', 3), SenseInfo('00229026-v', 3), SenseInfo('00229280-v', 1), SenseInfo('00364868-v', 0), SenseInfo('00068467-v', 0) ],
"_stray_v_1_rel" : [ SenseInfo('01881180-v', 2), SenseInfo('01925694-v', 1), SenseInfo('00780575-v', 0) ],
"_chuck+wagon_n_1_rel" : [ SenseInfo('03027505-n', 1) ],
"_femme+de+chambre_n_1_rel" : [  ],
"_depend_v_on-upon_rel" : [ SenseInfo('02664234-v', 10), SenseInfo('00712708-v', 0), SenseInfo('02664234-v', 10), SenseInfo('00712708-v', 0) ],
"_chela_n_1_rel" : [ SenseInfo('09685006-n', 1), SenseInfo('02156532-n', 0) ],
"_procreative_a_1_rel" : [ SenseInfo('01081592-a', 1) ],
"_emerald_a_1_rel" : [ SenseInfo('14849655-n', 0), SenseInfo('13372665-n', 0), SenseInfo('04968056-n', 0) ],
"_prostitute_v_1_rel" : [ SenseInfo('02554066-v', 0) ],
"_reuse_v_1_rel" : [ SenseInfo('01162425-v', 1) ],
"_cavalier_n_1_rel" : [ SenseInfo('09902256-n', 0), SenseInfo('09902128-n', 0) ],
"_side-step_v_1_rel" : [ SenseInfo('00809654-v', 3), SenseInfo('00809654-v', 3), SenseInfo('00809654-v', 3) ],
"_sioux_n_1_rel" : [ SenseInfo('09669125-n', 3) ],
"_feature_v_1_rel" : [ SenseInfo('02630189-v', 16), SenseInfo('02631659-v', 3) ],
"_devil_n_1_rel" : [ SenseInfo('09543353-n', 12), SenseInfo('09542339-n', 5), SenseInfo('07125786-n', 3), SenseInfo('10169419-n', 1), SenseInfo('10329945-n', 0) ],
"_result_v_1_rel" : [ SenseInfo('02634265-v', 45), SenseInfo('02635659-v', 38), SenseInfo('00340704-v', 0) ],
"_gastric_a_1_rel" : [ SenseInfo('02733187-a', 0) ],
"_frothy_a_1_rel" : [ SenseInfo('02276305-a', 0), SenseInfo('00805810-a', 0), SenseInfo('02276305-a', 0), SenseInfo('00805810-a', 0), SenseInfo('02276305-a', 0), SenseInfo('00805810-a', 0) ],
"_complicated_a_for_rel" : [ SenseInfo('02177584-a', 11), SenseInfo('02177584-a', 11) ],
"_whereby_x_rel" : [  ],
"_gross_n_1_rel" : [ SenseInfo('13750504-n', 0), SenseInfo('13256691-n', 0) ],
"_eloquence_n_1_rel" : [ SenseInfo('07069210-n', 0) ],
"_seatbelt_n_1_rel" : [ SenseInfo('04162706-n', 0) ],
"_de+facto_a_1_rel" : [ SenseInfo('00693743-a', 0) ],
"_chase_n_1_rel" : [ SenseInfo('00319939-n', 5), SenseInfo('10893606-n', 0), SenseInfo('03010283-n', 0) ],
"_take_v_of-i_rel" : [ SenseInfo('02599636-v', 92), SenseInfo('02267989-v', 74), SenseInfo('01999798-v', 73), SenseInfo('01214265-v', 50), SenseInfo('00524682-v', 38), SenseInfo('00624476-v', 36), SenseInfo('02077656-v', 32), SenseInfo('02205272-v', 28), SenseInfo('01842690-v', 26), SenseInfo('00674607-v', 26), SenseInfo('02236124-v', 25), SenseInfo('02394183-v', 22), SenseInfo('00734054-v', 22), SenseInfo('02627934-v', 21), SenseInfo('02109045-v', 21), SenseInfo('01002740-v', 16), SenseInfo('00173338-v', 16), SenseInfo('01156834-v', 15), SenseInfo('00669762-v', 15), SenseInfo('02209936-v', 14), SenseInfo('02206619-v', 13), SenseInfo('01982395-v', 10), SenseInfo('02236624-v', 8), SenseInfo('00523095-v', 7), SenseInfo('00599992-v', 6), SenseInfo('00756076-v', 5), SenseInfo('02075857-v', 4), SenseInfo('01151110-v', 4), SenseInfo('00557404-v', 4), SenseInfo('02717102-v', 2), SenseInfo('02208537-v', 2), SenseInfo('02209745-v', 1), SenseInfo('02208118-v', 1), SenseInfo('02201138-v', 1), SenseInfo('01427127-v', 1), SenseInfo('00758333-v', 1), SenseInfo('02741546-v', 0), SenseInfo('02701210-v', 0), SenseInfo('02590253-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01100830-v', 0), SenseInfo('00087736-v', 0), SenseInfo('02599636-v', 92), SenseInfo('02267989-v', 74), SenseInfo('01999798-v', 73), SenseInfo('01214265-v', 50), SenseInfo('00524682-v', 38), SenseInfo('00624476-v', 36), SenseInfo('02077656-v', 32), SenseInfo('02205272-v', 28), SenseInfo('01842690-v', 26), SenseInfo('00674607-v', 26), SenseInfo('02236124-v', 25), SenseInfo('02394183-v', 22), SenseInfo('00734054-v', 22), SenseInfo('02627934-v', 21), SenseInfo('02109045-v', 21), SenseInfo('01002740-v', 16), SenseInfo('00173338-v', 16), SenseInfo('01156834-v', 15), SenseInfo('00669762-v', 15), SenseInfo('02209936-v', 14), SenseInfo('02206619-v', 13), SenseInfo('01982395-v', 10), SenseInfo('02236624-v', 8), SenseInfo('00523095-v', 7), SenseInfo('00599992-v', 6), SenseInfo('00756076-v', 5), SenseInfo('02075857-v', 4), SenseInfo('01151110-v', 4), SenseInfo('00557404-v', 4), SenseInfo('02717102-v', 2), SenseInfo('02208537-v', 2), SenseInfo('02209745-v', 1), SenseInfo('02208118-v', 1), SenseInfo('02201138-v', 1), SenseInfo('01427127-v', 1), SenseInfo('00758333-v', 1), SenseInfo('02741546-v', 0), SenseInfo('02701210-v', 0), SenseInfo('02590253-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01100830-v', 0), SenseInfo('00087736-v', 0) ],
"_congruous_a_with_rel" : [ SenseInfo('00562116-a', 0), SenseInfo('00507912-a', 0) ],
"_adieu_n_1_rel" : [ SenseInfo('06629610-n', 1) ],
"_numerable_a_1_rel" : [ SenseInfo('00301589-a', 0) ],
"_make_v_for_rel" : [ SenseInfo('02560585-v', 508), SenseInfo('00120316-v', 459), SenseInfo('01617192-v', 243), SenseInfo('00770437-v', 85), SenseInfo('01645601-v', 78), SenseInfo('01621555-v', 52), SenseInfo('00730758-v', 33), SenseInfo('01646075-v', 17), SenseInfo('01640207-v', 16), SenseInfo('02289295-v', 14), SenseInfo('01619014-v', 14), SenseInfo('02621395-v', 12), SenseInfo('02022162-v', 12), SenseInfo('02674708-v', 10), SenseInfo('01653873-v', 9), SenseInfo('01755816-v', 8), SenseInfo('01654628-v', 5), SenseInfo('00556855-v', 5), SenseInfo('00012267-v', 5), SenseInfo('02396716-v', 4), SenseInfo('02355596-v', 4), SenseInfo('02020590-v', 4), SenseInfo('00665476-v', 4), SenseInfo('02582921-v', 3), SenseInfo('02598483-v', 2), SenseInfo('01733477-v', 2), SenseInfo('00276068-v', 2), SenseInfo('02075857-v', 1), SenseInfo('00074038-v', 1), SenseInfo('02748759-v', 0), SenseInfo('02748627-v', 0), SenseInfo('02745332-v', 0), SenseInfo('02665124-v', 0), SenseInfo('02621133-v', 0), SenseInfo('02134050-v', 0), SenseInfo('02051031-v', 0), SenseInfo('02021532-v', 0), SenseInfo('01755504-v', 0), SenseInfo('01664172-v', 0), SenseInfo('01428578-v', 0), SenseInfo('00891038-v', 0), SenseInfo('00838524-v', 0), SenseInfo('00698256-v', 0), SenseInfo('00698104-v', 0), SenseInfo('00562182-v', 0), SenseInfo('00562067-v', 0), SenseInfo('00545953-v', 0), SenseInfo('00107369-v', 0), SenseInfo('00072012-v', 0) ],
"_sleight_n_of_rel" : [ SenseInfo('05642815-n', 0) ],
"_desktop_n_1_rel" : [ SenseInfo('08663703-n', 0), SenseInfo('02769075-n', 0) ],
"_differentiation_n_of_rel" : [ SenseInfo('05748285-n', 5), SenseInfo('00870640-n', 1), SenseInfo('13559782-n', 0) ],
"_nucleus_n_1_rel" : [ SenseInfo('05434927-n', 10), SenseInfo('09375085-n', 3), SenseInfo('08242223-n', 3), SenseInfo('09375223-n', 0), SenseInfo('05501932-n', 0), SenseInfo('05320764-n', 0) ],
"_as+if_p_rel" : [  ],
"_percolator_n_1_rel" : [ SenseInfo('03915118-n', 1) ],
"_chock_n_1_rel" : [ SenseInfo('03023878-n', 1) ],
"_ample_a_1_rel" : [ SenseInfo('00105746-a', 8), SenseInfo('00014490-a', 2), SenseInfo('01383394-a', 0), SenseInfo('00105746-a', 8), SenseInfo('00014490-a', 2), SenseInfo('01383394-a', 0) ],
"_lauryl_n_1_rel" : [  ],
"_adapt_v_1_rel" : [ SenseInfo('00299580-v', 7), SenseInfo('00150287-v', 3) ],
"_edict_n_1_rel" : [ SenseInfo('06726671-n', 0), SenseInfo('06539770-n', 0) ],
"_skateboard_v_1_rel" : [ SenseInfo('01937795-v', 0) ],
"_counter-intelligence_n_1_rel" : [ SenseInfo('00986275-n', 0), SenseInfo('00986275-n', 0), SenseInfo('00986275-n', 0), SenseInfo('00986275-n', 0), SenseInfo('00986275-n', 0), SenseInfo('00986275-n', 0) ],
"_wrong_n_1_rel" : [ SenseInfo('04854604-n', 3), SenseInfo('00744131-n', 2) ],
"_trefoil_n_1_rel" : [ SenseInfo('12548280-n', 0), SenseInfo('11752578-n', 0), SenseInfo('04478257-n', 0) ],
"_bug_n_1_rel" : [ SenseInfo('02236355-n', 1), SenseInfo('14464675-n', 0), SenseInfo('02912440-n', 0), SenseInfo('02236896-n', 0), SenseInfo('01384491-n', 0) ],
"_elapse_v_1_rel" : [ SenseInfo('02072849-v', 5) ],
"_progression_n_1_rel" : [ SenseInfo('08458912-n', 2), SenseInfo('07445265-n', 1), SenseInfo('00282050-n', 1) ],
"_cape_n_1_rel" : [ SenseInfo('09233715-n', 2), SenseInfo('02955767-n', 1) ],
"_exclusion_n_of_rel" : [ SenseInfo('13935227-n', 1), SenseInfo('14413993-n', 0), SenseInfo('05707269-n', 0), SenseInfo('00206927-n', 0) ],
"_saviour_n_1_rel" : [ SenseInfo('11083656-n', 0), SenseInfo('10553805-n', 0) ],
"_rigid_a_1_rel" : [ SenseInfo('01023706-a', 5), SenseInfo('02436995-a', 2), SenseInfo('01029151-a', 2), SenseInfo('01026721-a', 0), SenseInfo('01564603-a', 0) ],
"_counterclaim_n_1_rel" : [ SenseInfo('01184407-n', 0), SenseInfo('01184407-n', 0), SenseInfo('01184407-n', 0), SenseInfo('01184407-n', 0), SenseInfo('01184407-n', 0), SenseInfo('01184407-n', 0), SenseInfo('01184407-n', 0), SenseInfo('01184407-n', 0) ],
"_ask_v_up_rel" : [ SenseInfo('00784342-v', 244), SenseInfo('00752493-v', 165), SenseInfo('00784727-v', 16), SenseInfo('00755745-v', 2), SenseInfo('00897746-v', 1), SenseInfo('02627934-v', 0), SenseInfo('01068565-v', 0) ],
"_cigarette_n_1_rel" : [ SenseInfo('03030663-n', 16) ],
"_get_v_up_rel" : [ SenseInfo('02210855-v', 235), SenseInfo('00149583-v', 157), SenseInfo('00120796-v', 82), SenseInfo('00522751-v', 64), SenseInfo('02005948-v', 58), SenseInfo('01433294-v', 45), SenseInfo('02108026-v', 36), SenseInfo('01153947-v', 14), SenseInfo('02355596-v', 9), SenseInfo('00770437-v', 7), SenseInfo('01215421-v', 4), SenseInfo('00094460-v', 4), SenseInfo('00087736-v', 4), SenseInfo('01066036-v', 3), SenseInfo('00120316-v', 3), SenseInfo('01026975-v', 2), SenseInfo('00589904-v', 2), SenseInfo('01505958-v', 1), SenseInfo('01401115-v', 1), SenseInfo('00639849-v', 1), SenseInfo('02359340-v', 0), SenseInfo('02208265-v', 0), SenseInfo('02189398-v', 0), SenseInfo('02109645-v', 0), SenseInfo('02108654-v', 0), SenseInfo('02010864-v', 0), SenseInfo('02006573-v', 0), SenseInfo('01771194-v', 0), SenseInfo('01771039-v', 0), SenseInfo('01738107-v', 0), SenseInfo('01643297-v', 0), SenseInfo('01565211-v', 0), SenseInfo('00622384-v', 0), SenseInfo('00345761-v', 0), SenseInfo('00065639-v', 0), SenseInfo('00054628-v', 0) ],
"_diagnose_v_with_rel" : [ SenseInfo('00645552-v', 4), SenseInfo('00645771-v', 1), SenseInfo('00645552-v', 4), SenseInfo('00645771-v', 1) ],
"_portend_v_1_rel" : [ SenseInfo('00871942-v', 1) ],
"_witchcraft_n_1_rel" : [ SenseInfo('05979350-n', 0) ],
"_tootle_v_1_rel" : [ SenseInfo('02183442-v', 0) ],
"_kick_v_i_rel" : [ SenseInfo('01371756-v', 11), SenseInfo('01936233-v', 9), SenseInfo('01370561-v', 7), SenseInfo('02048511-v', 0), SenseInfo('01371454-v', 0), SenseInfo('01196524-v', 0), SenseInfo('01112979-v', 0), SenseInfo('00907147-v', 0) ],
"_iBook_n_1_rel" : [  ],
"_onset_n_of_rel" : [ SenseInfo('07325990-n', 42), SenseInfo('00972621-n', 0) ],
"_semitrance_n_1_rel" : [ SenseInfo('05681543-n', 1) ],
"_to_p_nb-sel_rel" : [  ],
"_unthaw_v_1_rel" : [ SenseInfo('00376106-v', 1), SenseInfo('00376106-v', 1) ],
"_omen_n_1_rel" : [ SenseInfo('07286368-n', 3) ],
"_rotary_a_1_rel" : [ SenseInfo('02998561-a', 1), SenseInfo('00676271-a', 0) ],
"_mount_n_1_rel" : [ SenseInfo('02377703-n', 4), SenseInfo('00325110-n', 1), SenseInfo('09359803-n', 0), SenseInfo('03792526-n', 0), SenseInfo('02769460-n', 0), SenseInfo('02377703-n', 4), SenseInfo('00325110-n', 1), SenseInfo('09359803-n', 0), SenseInfo('03792526-n', 0), SenseInfo('02769460-n', 0), SenseInfo('02377703-n', 4), SenseInfo('00325110-n', 1), SenseInfo('09359803-n', 0), SenseInfo('03792526-n', 0), SenseInfo('02769460-n', 0) ],
"_proposal_n_1_rel" : [ SenseInfo('07162194-n', 17), SenseInfo('07161741-n', 1), SenseInfo('07161429-n', 0), SenseInfo('07162194-n', 17), SenseInfo('07161741-n', 1), SenseInfo('07161429-n', 0), SenseInfo('07162194-n', 17), SenseInfo('07161741-n', 1), SenseInfo('07161429-n', 0), SenseInfo('07162194-n', 17), SenseInfo('07161741-n', 1), SenseInfo('07161429-n', 0) ],
"_liberating_a_for_rel" : [  ],
"_develop_v_cause_rel" : [ SenseInfo('01738774-v', 44), SenseInfo('01738597-v', 44), SenseInfo('00545557-v', 41), SenseInfo('00094460-v', 19), SenseInfo('02624263-v', 15), SenseInfo('00171852-v', 12), SenseInfo('00925873-v', 6), SenseInfo('00603298-v', 5), SenseInfo('00342980-v', 4), SenseInfo('00252019-v', 4), SenseInfo('00411020-v', 3), SenseInfo('00253761-v', 3), SenseInfo('01627947-v', 1), SenseInfo('00543410-v', 1), SenseInfo('02138766-v', 0), SenseInfo('01469623-v', 0), SenseInfo('01074701-v', 0), SenseInfo('01074509-v', 0), SenseInfo('00402130-v', 0), SenseInfo('00339464-v', 0), SenseInfo('00234057-v', 0) ],
"_yarn_n_1_rel" : [ SenseInfo('07220773-n', 0), SenseInfo('04426788-n', 0) ],
"_scare_v_off_rel" : [ SenseInfo('01779165-v', 4), SenseInfo('01785748-v', 2) ],
"_hone_v_1_rel" : [ SenseInfo('01247181-v', 0), SenseInfo('00473572-v', 0) ],
"_rook_n_1_rel" : [ SenseInfo('02980625-n', 0), SenseInfo('01579410-n', 0) ],
"_mensa_n_1_rel" : [ SenseInfo('09351086-n', 0) ],
"_piste_n_1_rel" : [ SenseInfo('03948347-n', 0), SenseInfo('03948242-n', 0) ],
"_hem_v_out_rel" : [ SenseInfo('01329732-v', 0), SenseInfo('01061799-v', 0) ],
"_command_v_1_rel" : [ SenseInfo('00751887-v', 10), SenseInfo('00751567-v', 8), SenseInfo('01018177-v', 6), SenseInfo('02696129-v', 1), SenseInfo('02441022-v', 1), SenseInfo('00751887-v', 10), SenseInfo('00751567-v', 8), SenseInfo('01018177-v', 6), SenseInfo('02696129-v', 1), SenseInfo('02441022-v', 1), SenseInfo('00751887-v', 10), SenseInfo('00751567-v', 8), SenseInfo('01018177-v', 6), SenseInfo('02696129-v', 1), SenseInfo('02441022-v', 1) ],
"_claim_n_of_rel" : [ SenseInfo('06729864-n', 26), SenseInfo('06730563-n', 11), SenseInfo('01061945-n', 6), SenseInfo('05175904-n', 3), SenseInfo('05181199-n', 2), SenseInfo('07192129-n', 0), SenseInfo('06729864-n', 26), SenseInfo('06730563-n', 11), SenseInfo('01061945-n', 6), SenseInfo('05175904-n', 3), SenseInfo('05181199-n', 2), SenseInfo('07192129-n', 0) ],
"_sketch_v_1_rel" : [ SenseInfo('01697628-v', 4), SenseInfo('01006421-v', 1) ],
"_charlatan_n_1_rel" : [ SenseInfo('10334782-n', 1) ],
"_deluge_n_of_rel" : [ SenseInfo('13775706-n', 1), SenseInfo('11502102-n', 0), SenseInfo('11454591-n', 0) ],
"_acidify_v_1_rel" : [ SenseInfo('02196690-v', 0), SenseInfo('00264875-v', 0) ],
"_plat_n_1_rel" : [ SenseInfo('03959350-n', 0) ],
"_format_n_1_rel" : [ SenseInfo('06636806-n', 0), SenseInfo('04677385-n', 0) ],
"_lace_v_up_rel" : [ SenseInfo('01517662-v', 1), SenseInfo('01674717-v', 0), SenseInfo('01674375-v', 0), SenseInfo('01521603-v', 0), SenseInfo('00222135-v', 0) ],
"_seasoning_n_1_rel" : [ SenseInfo('07809368-n', 0), SenseInfo('00248368-n', 0) ],
"_sick_a_of_rel" : [ SenseInfo('02541302-a', 8), SenseInfo('02545689-a', 7), SenseInfo('02075321-a', 1), SenseInfo('01806677-a', 1), SenseInfo('02325984-a', 0), SenseInfo('01560165-a', 0), SenseInfo('00195684-a', 0) ],
"_condenser_n_of_rel" : [ SenseInfo('02955247-n', 1), SenseInfo('03087643-n', 0), SenseInfo('03087521-n', 0), SenseInfo('03087366-n', 0) ],
"_effort_n_1_rel" : [ SenseInfo('00786195-n', 84), SenseInfo('00621627-n', 12), SenseInfo('00036762-n', 2), SenseInfo('00798245-n', 0), SenseInfo('00786195-n', 84), SenseInfo('00621627-n', 12), SenseInfo('00036762-n', 2), SenseInfo('00798245-n', 0) ],
"_inflammatory_a_1_rel" : [ SenseInfo('01177246-a', 1), SenseInfo('01897378-a', 0) ],
"_pasturage_n_1_rel" : [ SenseInfo('12104501-n', 0), SenseInfo('07801091-n', 0) ],
"_instrumental_a_1_rel" : [ SenseInfo('02825770-a', 2), SenseInfo('01196775-a', 0) ],
"_indigo_a_1_rel" : [ SenseInfo('00398373-a', 0) ],
"_round_n_of_rel" : [ SenseInfo('04113641-n', 6), SenseInfo('15287830-n', 2), SenseInfo('08507381-n', 1), SenseInfo('01055688-n', 1), SenseInfo('00466377-n', 1), SenseInfo('00415098-n', 1), SenseInfo('15256714-n', 0), SenseInfo('09417097-n', 0), SenseInfo('07884266-n', 0), SenseInfo('07662156-n', 0), SenseInfo('07053089-n', 0), SenseInfo('06692464-n', 0), SenseInfo('04119892-n', 0), SenseInfo('03032811-n', 0) ],
"_guard_n_i_rel" : [ SenseInfo('10150071-n', 15), SenseInfo('10149720-n', 2), SenseInfo('03464467-n', 2), SenseInfo('05082222-n', 1), SenseInfo('10150281-n', 0), SenseInfo('08215603-n', 0), SenseInfo('00822970-n', 0), SenseInfo('00730538-n', 0), SenseInfo('00727743-n', 0), SenseInfo('00725673-n', 0) ],
"_factory_n_1_rel" : [ SenseInfo('03316406-n', 18), SenseInfo('03316406-n', 18) ],
"_residue_n_of_rel" : [ SenseInfo('15004501-n', 2), SenseInfo('13810818-n', 1) ],
"_ponder_v_1_rel" : [ SenseInfo('00630380-v', 9), SenseInfo('00630380-v', 9) ],
"_sand+castle_n_1_rel" : [  ],
"_richness_n_1_rel" : [ SenseInfo('05115804-n', 3), SenseInfo('14491625-n', 1), SenseInfo('04989015-n', 1), SenseInfo('05164101-n', 0), SenseInfo('05147586-n', 0), SenseInfo('04958460-n', 0), SenseInfo('04729328-n', 0) ],
"_exempt_a_from_rel" : [ SenseInfo('02365397-a', 2), SenseInfo('02400929-a', 0) ],
"_shy_v_away_rel" : [ SenseInfo('01910680-v', 1), SenseInfo('01509492-v', 0), SenseInfo('01910680-v', 1), SenseInfo('01509492-v', 0), SenseInfo('01910680-v', 1), SenseInfo('01509492-v', 0) ],
"_for+instance_p_rel" : [ SenseInfo('00159040-r', 21), SenseInfo('00159040-r', 21), SenseInfo('00159040-r', 21) ],
"_filament_n_1_rel" : [ SenseInfo('14867858-n', 0), SenseInfo('11678123-n', 0), SenseInfo('05229468-n', 0), SenseInfo('03336575-n', 0) ],
"_ambience_n_1_rel" : [ SenseInfo('14524849-n', 0), SenseInfo('08494133-n', 0) ],
"_sub-_a_1_rel" : [  ],
"_difficulty_n_1_rel" : [ SenseInfo('00623862-n', 18), SenseInfo('05686955-n', 13), SenseInfo('14408086-n', 11), SenseInfo('04709253-n', 6) ],
"_hover_v_1_rel" : [ SenseInfo('02706046-v', 2), SenseInfo('02640906-v', 2), SenseInfo('01943448-v', 2), SenseInfo('01944252-v', 1), SenseInfo('02744061-v', 0) ],
"_bangladeshi_n_1_rel" : [ SenseInfo('09691994-n', 0) ],
"_sunny_a_1_rel" : [ SenseInfo('00363938-a', 2), SenseInfo('00363938-a', 2), SenseInfo('00363938-a', 2), SenseInfo('00363938-a', 2), SenseInfo('00363938-a', 2), SenseInfo('00363938-a', 2), SenseInfo('00363938-a', 2) ],
"_skate_v_1_rel" : [ SenseInfo('01936753-v', 0) ],
"_disappear_v_1_rel" : [ SenseInfo('00426958-v', 40), SenseInfo('02156546-v', 0), SenseInfo('00427397-v', 0), SenseInfo('00223928-v', 0) ],
"_outdoorsman_n_1_rel" : [ SenseInfo('10386618-n', 0) ],
"_freak_v_1_rel" : [ SenseInfo('01784148-v', 0) ],
"_recur_v_1_rel" : [ SenseInfo('00343334-v', 5), SenseInfo('00959714-v', 1), SenseInfo('02590072-v', 0) ],
"_contour_n_1_rel" : [ SenseInfo('06801580-n', 6), SenseInfo('05064037-n', 2), SenseInfo('05851517-n', 0) ],
"_sire_v_1_rel" : [ SenseInfo('00054628-v', 3) ],
"_bureaucracy_n_1_rel" : [ SenseInfo('08456727-n', 6), SenseInfo('08051565-n', 0), SenseInfo('08009659-n', 0) ],
"_memorandum_n_1_rel" : [ SenseInfo('06506191-n', 2) ],
"_tsunami_n_1_rel" : [ SenseInfo('07349299-n', 22) ],
"_arranging_n_1_rel" : [ SenseInfo('00939628-n', 0) ],
"_cucumber_n_1_rel" : [ SenseInfo('12165384-n', 0), SenseInfo('07718472-n', 0) ],
"_lance_v_1_rel" : [ SenseInfo('02085158-v', 0), SenseInfo('01604119-v', 0), SenseInfo('01603885-v', 0) ],
"_3+R_n_1_rel" : [  ],
"_fish_v_out_rel" : [ SenseInfo('01319346-v', 2), SenseInfo('01140794-v', 1) ],
"_underscore_v_1_rel" : [ SenseInfo('01014609-v', 3), SenseInfo('01004235-v', 0), SenseInfo('01014609-v', 3), SenseInfo('01004235-v', 0), SenseInfo('01014609-v', 3), SenseInfo('01004235-v', 0) ],
"_tart_a_1_rel" : [ SenseInfo('02369460-a', 1), SenseInfo('01804728-a', 0), SenseInfo('02369460-a', 1), SenseInfo('01804728-a', 0), SenseInfo('02369460-a', 1), SenseInfo('01804728-a', 0) ],
"_state_v_to_rel" : [ SenseInfo('01009240-v', 73), SenseInfo('00878136-v', 15), SenseInfo('01061481-v', 2), SenseInfo('01009240-v', 73), SenseInfo('00878136-v', 15), SenseInfo('01061481-v', 2) ],
"_pity_n_1_rel" : [ SenseInfo('07553964-n', 6), SenseInfo('07305098-n', 3), SenseInfo('04829550-n', 0) ],
"_inferior_a_1_rel" : [ SenseInfo('02340213-a', 2), SenseInfo('02345272-a', 1), SenseInfo('02349852-a', 0), SenseInfo('02348678-a', 0), SenseInfo('02440996-a', 0), SenseInfo('02297409-a', 0) ],
"_buzz_v_2_rel" : [ SenseInfo('02182109-v', 4), SenseInfo('01924267-v', 3), SenseInfo('02706605-v', 2), SenseInfo('00792304-v', 0) ],
"_breathtaking_a_1_rel" : [ SenseInfo('00921369-a', 0) ],
"_tidal_a_1_rel" : [ SenseInfo('02815241-a', 0) ],
"_chance_v_upon_rel" : [ SenseInfo('02594102-v', 2), SenseInfo('02544348-v', 1), SenseInfo('02248465-v', 0) ],
"_puddle_v_1_rel" : [ SenseInfo('01916471-v', 0), SenseInfo('01624743-v', 0), SenseInfo('01529292-v', 0), SenseInfo('01484267-v', 0), SenseInfo('01473729-v', 0), SenseInfo('01419867-v', 0), SenseInfo('01374465-v', 0), SenseInfo('00620532-v', 0), SenseInfo('00072012-v', 0) ],
"_plump_v_1_rel" : [ SenseInfo('01978199-v', 0), SenseInfo('01500572-v', 0), SenseInfo('01194938-v', 0), SenseInfo('00676267-v', 0) ],
"_diffuse_v_1_rel" : [ SenseInfo('02060141-v', 1), SenseInfo('01229071-v', 1), SenseInfo('00968211-v', 1) ],
"_so+to+speak_a_1_rel" : [  ],
"_bondage_n_1_rel" : [ SenseInfo('13997529-n', 0), SenseInfo('13997253-n', 0), SenseInfo('00843681-n', 0) ],
"_adjunct_n_1_rel" : [ SenseInfo('09188229-n', 5), SenseInfo('09769803-n', 0), SenseInfo('06312767-n', 0) ],
"_go_p_sel_rel" : [ SenseInfo('01835496-v', 343), SenseInfo('02372605-v', 95), SenseInfo('01848718-v', 49), SenseInfo('00149583-v', 29), SenseInfo('02653862-v', 14), SenseInfo('02721284-v', 10), SenseInfo('02685951-v', 10), SenseInfo('00341560-v', 10), SenseInfo('00359916-v', 9), SenseInfo('02618001-v', 7), SenseInfo('02176268-v', 3), SenseInfo('01525666-v', 3), SenseInfo('01192773-v', 3), SenseInfo('00539110-v', 3), SenseInfo('02618149-v', 2), SenseInfo('02617798-v', 2), SenseInfo('00358431-v', 2), SenseInfo('02737876-v', 1), SenseInfo('02729819-v', 1), SenseInfo('01864230-v', 1), SenseInfo('01076615-v', 1), SenseInfo('01122776-a', 0), SenseInfo('15292069-n', 0), SenseInfo('02678738-n', 0), SenseInfo('00787061-n', 0), SenseInfo('00504325-n', 0), SenseInfo('02700772-v', 0), SenseInfo('02700666-v', 0), SenseInfo('02700455-v', 0), SenseInfo('02686471-v', 0), SenseInfo('02659763-v', 0), SenseInfo('01318849-v', 0), SenseInfo('01192992-v', 0), SenseInfo('00676267-v', 0), SenseInfo('00434374-v', 0) ],
"_dame_n_1_rel" : [ SenseInfo('09989045-n', 1), SenseInfo('09989290-n', 0) ],
"_fuss_n_1_rel" : [ SenseInfo('14403772-n', 1), SenseInfo('07372565-n', 0), SenseInfo('07184735-n', 0), SenseInfo('00555138-n', 0) ],
"_calculous_a_1_rel" : [ SenseInfo('02674642-a', 0) ],
"_revue_n_1_rel" : [ SenseInfo('07019866-n', 0) ],
"_mores_n_1_rel" : [ SenseInfo('11190183-n', 0), SenseInfo('11190183-n', 0) ],
"_IRA_n_1_rel" : [ SenseInfo('08024732-n', 0), SenseInfo('05912012-n', 0), SenseInfo('00758972-n', 0) ],
"_abrasive_n_1_rel" : [ SenseInfo('14799244-n', 0), SenseInfo('14799244-n', 0), SenseInfo('14799244-n', 0) ],
"_overjoyed_a_1_rel" : [ SenseInfo('01363936-a', 0), SenseInfo('01363936-a', 0), SenseInfo('01363936-a', 0) ],
"_load_n_of_rel" : [ SenseInfo('03679986-n', 9), SenseInfo('13772468-n', 3), SenseInfo('02964389-n', 2), SenseInfo('13772313-n', 1), SenseInfo('11449561-n', 1), SenseInfo('05832745-n', 1), SenseInfo('11446067-n', 0), SenseInfo('04551375-n', 0), SenseInfo('03680248-n', 0) ],
"_put_v_adv_rel" : [ SenseInfo('01494310-v', 138), SenseInfo('01493741-v', 98), SenseInfo('00981276-v', 28), SenseInfo('01160370-v', 6), SenseInfo('02271137-v', 3), SenseInfo('00673448-v', 2), SenseInfo('02111499-v', 0), SenseInfo('01706375-v', 0), SenseInfo('00735571-v', 0) ],
"_unearth_v_1_rel" : [ SenseInfo('02286550-v', 2), SenseInfo('02143539-v', 0) ],
"_picnic_v_1_rel" : [ SenseInfo('01168259-v', 1) ],
"_everyday_a_1_rel" : [ SenseInfo('01674242-a', 7), SenseInfo('01044557-a', 0), SenseInfo('00970947-a', 0) ],
"_norse_a_1_rel" : [ SenseInfo('02960130-a', 0), SenseInfo('02959912-a', 0) ],
"_inhibit_v_1_rel" : [ SenseInfo('00462092-v', 6), SenseInfo('00462689-v', 1), SenseInfo('02451679-v', 0), SenseInfo('02423762-v', 0), SenseInfo('00462092-v', 6), SenseInfo('00462689-v', 1), SenseInfo('02451679-v', 0), SenseInfo('02423762-v', 0) ],
"_announce_v_1_rel" : [ SenseInfo('00974367-v', 74), SenseInfo('00965871-v', 13), SenseInfo('00975427-v', 2), SenseInfo('00974173-v', 2) ],
"_ring_n_1_rel" : [ SenseInfo('04981658-n', 4), SenseInfo('13875392-n', 2), SenseInfo('03533972-n', 2), SenseInfo('09246883-n', 0), SenseInfo('08244062-n', 0), SenseInfo('07391863-n', 0), SenseInfo('04092959-n', 0), SenseInfo('04092609-n', 0), SenseInfo('02785191-n', 0) ],
"_ache_v_with_rel" : [ SenseInfo('02121511-v', 3), SenseInfo('01805684-v', 3), SenseInfo('02122164-v', 2) ],
"_menace_n_1_rel" : [ SenseInfo('14543231-n', 8), SenseInfo('06733782-n', 1) ],
"_twitch_n_1_rel" : [ SenseInfo('14361664-n', 0) ],
"_bob_v_1_rel" : [ SenseInfo('01865383-v', 6), SenseInfo('01939811-v', 0), SenseInfo('01556178-v', 0), SenseInfo('00899352-v', 0), SenseInfo('00039121-v', 0) ],
"_catchy_a_1_rel" : [ SenseInfo('00746819-a', 0), SenseInfo('00170717-a', 0), SenseInfo('00746819-a', 0), SenseInfo('00170717-a', 0), SenseInfo('00746819-a', 0), SenseInfo('00170717-a', 0) ],
"_plasterer_n_1_rel" : [ SenseInfo('10438842-n', 1) ],
"_circumference_n_1_rel" : [ SenseInfo('05101261-n', 1), SenseInfo('08514592-n', 0), SenseInfo('05101675-n', 0) ],
"_dross_n_1_rel" : [ SenseInfo('14583670-n', 1), SenseInfo('15042856-n', 0) ],
"_deep_x_deg_rel" : [ SenseInfo('00692762-a', 16), SenseInfo('01873163-a', 12), SenseInfo('00690058-a', 11), SenseInfo('00445937-a', 7), SenseInfo('01511292-a', 6), SenseInfo('01215935-a', 5), SenseInfo('00305570-r', 3), SenseInfo('00403385-a', 3), SenseInfo('02410983-a', 2), SenseInfo('15267373-n', 0), SenseInfo('09461315-n', 0), SenseInfo('09263811-n', 0), SenseInfo('00305821-r', 0), SenseInfo('00305683-r', 0), SenseInfo('02561391-a', 0), SenseInfo('01513776-a', 0), SenseInfo('01385046-a', 0), SenseInfo('01206916-a', 0), SenseInfo('00939444-a', 0), SenseInfo('00899226-a', 0), SenseInfo('00149120-a', 0) ],
"_delegate_v_to_rel" : [ SenseInfo('02395395-v', 5), SenseInfo('02391803-v', 1), SenseInfo('02395395-v', 5), SenseInfo('02391803-v', 1), SenseInfo('02395395-v', 5), SenseInfo('02391803-v', 1) ],
"_nucleic_a_1_rel" : [  ],
"_flop_v_1_rel" : [ SenseInfo('01972849-v', 4), SenseInfo('01972753-v', 2), SenseInfo('02530003-v', 0), SenseInfo('01972849-v', 4), SenseInfo('01972753-v', 2), SenseInfo('02530003-v', 0) ],
"_negligence_n_of_rel" : [ SenseInfo('00739270-n', 2), SenseInfo('04665813-n', 0) ],
"_emerald_n_1_rel" : [ SenseInfo('14849655-n', 0), SenseInfo('13372665-n', 0), SenseInfo('04968056-n', 0) ],
"_flue_n_1_rel" : [ SenseInfo('03369640-n', 0), SenseInfo('03369011-n', 0), SenseInfo('03368878-n', 0) ],
"_imminent_a_1_rel" : [ SenseInfo('00448314-a', 1) ],
"_spill_n_1_rel" : [ SenseInfo('15049594-n', 0), SenseInfo('04277034-n', 0), SenseInfo('00329619-n', 0), SenseInfo('00076884-n', 0) ],
"_recommendation_n_1_rel" : [ SenseInfo('06671637-n', 25), SenseInfo('06694540-n', 1), SenseInfo('04673668-n', 0), SenseInfo('06671637-n', 25), SenseInfo('06694540-n', 1), SenseInfo('04673668-n', 0), SenseInfo('06671637-n', 25), SenseInfo('06694540-n', 1), SenseInfo('04673668-n', 0) ],
"_japanese_n_1_rel" : [ SenseInfo('09718217-n', 1), SenseInfo('06929279-n', 1), SenseInfo('09718217-n', 1), SenseInfo('06929279-n', 1), SenseInfo('09718217-n', 1), SenseInfo('06929279-n', 1), SenseInfo('09718217-n', 1), SenseInfo('06929279-n', 1) ],
"_stocky_a_1_rel" : [ SenseInfo('02387413-a', 0), SenseInfo('02387413-a', 0), SenseInfo('02387413-a', 0) ],
"_fray_v_cause_rel" : [ SenseInfo('01369204-v', 0), SenseInfo('01250908-v', 0) ],
"_gravelly_a_1_rel" : [ SenseInfo('02242223-a', 0), SenseInfo('00299476-a', 0) ],
"_epic_n_1_rel" : [ SenseInfo('06379721-n', 3) ],
"_rig_v_1_rel" : [ SenseInfo('02573127-v', 1), SenseInfo('02351239-v', 1), SenseInfo('01286151-v', 1), SenseInfo('00408085-v', 0) ],
"_volition_n_1_rel" : [ SenseInfo('05652593-n', 1), SenseInfo('00163047-n', 0) ],
"_cylinder_n_1_rel" : [ SenseInfo('13865298-n', 1), SenseInfo('13899804-n', 0), SenseInfo('03156405-n', 0), SenseInfo('03156279-n', 0) ],
"_thieve_v_1_rel" : [ SenseInfo('02322230-v', 0) ],
"_twirl_n_1_rel" : [ SenseInfo('13877918-n', 0), SenseInfo('00343249-n', 0) ],
"_frail_a_1_rel" : [ SenseInfo('02040049-a', 4), SenseInfo('01259391-a', 0), SenseInfo('00709215-a', 0), SenseInfo('02040049-a', 4), SenseInfo('01259391-a', 0), SenseInfo('00709215-a', 0), SenseInfo('02040049-a', 4), SenseInfo('01259391-a', 0), SenseInfo('00709215-a', 0) ],
"_reptile_n_1_rel" : [ SenseInfo('01661091-n', 1) ],
"_prefer_v_loc_rel" : [ SenseInfo('01826498-v', 22), SenseInfo('00679389-v', 16), SenseInfo('02400037-v', 1), SenseInfo('02400251-v', 0) ],
"_persist_v_1_rel" : [ SenseInfo('02647497-v', 11), SenseInfo('00350461-v', 8), SenseInfo('02731024-v', 1), SenseInfo('02647497-v', 11), SenseInfo('00350461-v', 8), SenseInfo('02731024-v', 1) ],
"_bone_n_1_rel" : [ SenseInfo('05269901-n', 10), SenseInfo('14757848-n', 3), SenseInfo('04961331-n', 0) ],
"_perk_v_up_rel" : [ SenseInfo('00023473-v', 0), SenseInfo('00023473-v', 0) ],
"_box_v_up_rel" : [ SenseInfo('01485158-v', 1), SenseInfo('01420765-v', 0), SenseInfo('01419982-v', 0) ],
"_stick_v_around_rel" : [ SenseInfo('01528069-v', 5), SenseInfo('01857392-v', 2), SenseInfo('01356750-v', 2), SenseInfo('02754032-v', 0), SenseInfo('02647798-v', 0), SenseInfo('02638845-v', 0), SenseInfo('02638630-v', 0), SenseInfo('01667969-v', 0), SenseInfo('01614581-v', 0), SenseInfo('01614426-v', 0), SenseInfo('01614235-v', 0), SenseInfo('01441993-v', 0), SenseInfo('01441793-v', 0), SenseInfo('01220885-v', 0), SenseInfo('00748084-v', 0), SenseInfo('00622384-v', 0) ],
"_game_n_of_rel" : [ SenseInfo('00455599-n', 38), SenseInfo('00456199-n', 26), SenseInfo('00430606-n', 14), SenseInfo('02152991-n', 7), SenseInfo('15256567-n', 0), SenseInfo('13596235-n', 0), SenseInfo('07650449-n', 0), SenseInfo('05907682-n', 0), SenseInfo('03413828-n', 0), SenseInfo('00583089-n', 0), SenseInfo('00513089-n', 0), SenseInfo('00455599-n', 38), SenseInfo('00456199-n', 26), SenseInfo('00430606-n', 14), SenseInfo('02152991-n', 7), SenseInfo('15256567-n', 0), SenseInfo('13596235-n', 0), SenseInfo('07650449-n', 0), SenseInfo('05907682-n', 0), SenseInfo('03413828-n', 0), SenseInfo('00583089-n', 0), SenseInfo('00513089-n', 0) ],
"_caricature_v_1_rel" : [ SenseInfo('00849592-v', 1) ],
"_swim_v_1_rel" : [ SenseInfo('01960911-v', 12), SenseInfo('01904293-v', 1), SenseInfo('02756063-v', 0), SenseInfo('02755911-v', 0), SenseInfo('01904649-v', 0), SenseInfo('01960911-v', 12), SenseInfo('01904293-v', 1), SenseInfo('02756063-v', 0), SenseInfo('02755911-v', 0), SenseInfo('01904649-v', 0) ],
"_flemish_a_1_rel" : [ SenseInfo('03066448-a', 0) ],
"_absent_v_1_rel" : [ SenseInfo('00421535-v', 2), SenseInfo('00421535-v', 2) ],
"_nanometer-scale_n_1_rel" : [  ],
"_user_n_of_rel" : [ SenseInfo('10741590-n', 3), SenseInfo('10072546-n', 1), SenseInfo('10036266-n', 0) ],
"_state_n_of_rel" : [ SenseInfo('08654360-n', 108), SenseInfo('00024720-n', 39), SenseInfo('08178547-n', 24), SenseInfo('08168978-n', 21), SenseInfo('14479615-n', 0), SenseInfo('13988498-n', 0), SenseInfo('08544813-n', 0), SenseInfo('08137738-n', 0), SenseInfo('08654360-n', 108), SenseInfo('00024720-n', 39), SenseInfo('08178547-n', 24), SenseInfo('08168978-n', 21), SenseInfo('14479615-n', 0), SenseInfo('13988498-n', 0), SenseInfo('08544813-n', 0), SenseInfo('08137738-n', 0) ],
"_snowcapped_a_1_rel" : [  ],
"_store_n_1_rel" : [ SenseInfo('04202417-n', 25), SenseInfo('13367070-n', 5), SenseInfo('03744276-n', 1), SenseInfo('04329190-n', 0), SenseInfo('04202417-n', 25), SenseInfo('13367070-n', 5), SenseInfo('03744276-n', 1), SenseInfo('04329190-n', 0) ],
"_in+kind_a_1_rel" : [  ],
"_weatherwise_a_1_rel" : [  ],
"_mud+flats_n_1_rel" : [  ],
"_multiply_v_cause_rel" : [ SenseInfo('00641672-v', 18), SenseInfo('00247390-v', 7), SenseInfo('00056334-v', 1), SenseInfo('00055142-v', 0) ],
"_gestation_n_1_rel" : [ SenseInfo('15226214-n', 0), SenseInfo('14046202-n', 0), SenseInfo('05772215-n', 0) ],
"_park_v_1_rel" : [ SenseInfo('01493380-v', 11), SenseInfo('01934427-v', 3) ],
"_scree_n_1_rel" : [ SenseInfo('09454153-n', 0) ],
"_footpath_n_1_rel" : [ SenseInfo('03899533-n', 1) ],
"_bedground_n_1_rel" : [ SenseInfo('08499357-n', 1) ],
"_heathen_n_1_rel" : [ SenseInfo('10166394-n', 0) ],
"_instigate_v_1_rel" : [ SenseInfo('00851239-v', 2), SenseInfo('00771961-v', 0) ],
"_c-_n_1_rel" : [ SenseInfo('13714491-n', 21), SenseInfo('15284285-n', 0), SenseInfo('15093298-n', 0), SenseInfo('14829765-n', 0), SenseInfo('14828511-n', 0), SenseInfo('14633206-n', 0), SenseInfo('13750415-n', 0), SenseInfo('13636648-n', 0), SenseInfo('06902696-n', 0), SenseInfo('06866332-n', 0), SenseInfo('06831391-n', 0), SenseInfo('03066743-n', 0) ],
"_spiritual_a_1_rel" : [ SenseInfo('02056265-a', 7), SenseInfo('02579136-a', 1), SenseInfo('00631193-a', 1), SenseInfo('01574925-a', 0) ],
"_flutter_v_cause_rel" : [ SenseInfo('01899891-v', 1), SenseInfo('01878719-v', 1), SenseInfo('01900255-v', 0), SenseInfo('01879928-v', 0), SenseInfo('00008195-v', 0) ],
"_lapse_n_of_rel" : [ SenseInfo('00074524-n', 3), SenseInfo('15271417-n', 1), SenseInfo('00068333-n', 1) ],
"_sand_n_1_rel" : [ SenseInfo('15019030-n', 10), SenseInfo('11280013-n', 0), SenseInfo('05032351-n', 0), SenseInfo('15019030-n', 10), SenseInfo('11280013-n', 0), SenseInfo('05032351-n', 0), SenseInfo('15019030-n', 10), SenseInfo('11280013-n', 0), SenseInfo('05032351-n', 0) ],
"_pedestal_n_1_rel" : [ SenseInfo('02797692-n', 1), SenseInfo('14432389-n', 0), SenseInfo('03903868-n', 0) ],
"_betake_v_1_rel" : [  ],
"_oil_v_1_rel" : [ SenseInfo('01268571-v', 1), SenseInfo('00085626-v', 0) ],
"_vhs_n_1_rel" : [  ],
"_scrub_v_1_rel" : [ SenseInfo('01251228-v', 4), SenseInfo('00036780-v', 1), SenseInfo('02477755-v', 0), SenseInfo('01251228-v', 4), SenseInfo('00036780-v', 1), SenseInfo('02477755-v', 0) ],
"_minute_a_1_rel" : [ SenseInfo('01393483-a', 5), SenseInfo('00310716-a', 0) ],
"_wet_a_1_rel" : [ SenseInfo('02547317-a', 23), SenseInfo('02555126-a', 0), SenseInfo('02554752-a', 0), SenseInfo('02554267-a', 0), SenseInfo('01159405-a', 0), SenseInfo('00798103-a', 0), SenseInfo('02547317-a', 23), SenseInfo('02555126-a', 0), SenseInfo('02554752-a', 0), SenseInfo('02554267-a', 0), SenseInfo('01159405-a', 0), SenseInfo('00798103-a', 0), SenseInfo('02547317-a', 23), SenseInfo('02555126-a', 0), SenseInfo('02554752-a', 0), SenseInfo('02554267-a', 0), SenseInfo('01159405-a', 0), SenseInfo('00798103-a', 0), SenseInfo('02547317-a', 23), SenseInfo('02555126-a', 0), SenseInfo('02554752-a', 0), SenseInfo('02554267-a', 0), SenseInfo('01159405-a', 0), SenseInfo('00798103-a', 0), SenseInfo('02547317-a', 23), SenseInfo('02555126-a', 0), SenseInfo('02554752-a', 0), SenseInfo('02554267-a', 0), SenseInfo('01159405-a', 0), SenseInfo('00798103-a', 0), SenseInfo('02547317-a', 23), SenseInfo('02555126-a', 0), SenseInfo('02554752-a', 0), SenseInfo('02554267-a', 0), SenseInfo('01159405-a', 0), SenseInfo('00798103-a', 0) ],
"_expressway_n_1_rel" : [ SenseInfo('03306610-n', 0) ],
"_distress_v_for_rel" : [ SenseInfo('02603424-v', 0), SenseInfo('01798100-v', 0), SenseInfo('02603424-v', 0), SenseInfo('01798100-v', 0), SenseInfo('02603424-v', 0), SenseInfo('01798100-v', 0) ],
"_the+least_q_rel" : [  ],
"_depict_v_1_rel" : [ SenseInfo('01686956-v', 6), SenseInfo('00987071-v', 6), SenseInfo('01688256-v', 2) ],
"_moan_n_1_rel" : [ SenseInfo('07126383-n', 1) ],
"_soviet_n_1_rel" : [ SenseInfo('08320201-n', 0) ],
"_part_n_1_rel" : [ SenseInfo('13809207-n', 113), SenseInfo('03892891-n', 24), SenseInfo('09385911-n', 19), SenseInfo('05671974-n', 19), SenseInfo('08630039-n', 15), SenseInfo('00720565-n', 13), SenseInfo('05929008-n', 9), SenseInfo('13285176-n', 8), SenseInfo('05867413-n', 7), SenseInfo('05256358-n', 3), SenseInfo('07030718-n', 2), SenseInfo('00787465-n', 2), SenseInfo('13809207-n', 113), SenseInfo('03892891-n', 24), SenseInfo('09385911-n', 19), SenseInfo('05671974-n', 19), SenseInfo('08630039-n', 15), SenseInfo('00720565-n', 13), SenseInfo('05929008-n', 9), SenseInfo('13285176-n', 8), SenseInfo('05867413-n', 7), SenseInfo('05256358-n', 3), SenseInfo('07030718-n', 2), SenseInfo('00787465-n', 2), SenseInfo('13809207-n', 113), SenseInfo('03892891-n', 24), SenseInfo('09385911-n', 19), SenseInfo('05671974-n', 19), SenseInfo('08630039-n', 15), SenseInfo('00720565-n', 13), SenseInfo('05929008-n', 9), SenseInfo('13285176-n', 8), SenseInfo('05867413-n', 7), SenseInfo('05256358-n', 3), SenseInfo('07030718-n', 2), SenseInfo('00787465-n', 2), SenseInfo('13809207-n', 113), SenseInfo('03892891-n', 24), SenseInfo('09385911-n', 19), SenseInfo('05671974-n', 19), SenseInfo('08630039-n', 15), SenseInfo('00720565-n', 13), SenseInfo('05929008-n', 9), SenseInfo('13285176-n', 8), SenseInfo('05867413-n', 7), SenseInfo('05256358-n', 3), SenseInfo('07030718-n', 2), SenseInfo('00787465-n', 2) ],
"_soil_v_1_rel" : [ SenseInfo('01534147-v', 1), SenseInfo('01534147-v', 1) ],
"_crampon_n_1_rel" : [ SenseInfo('03126580-n', 0), SenseInfo('03126385-n', 0) ],
"_sway_n_1_rel" : [ SenseInfo('05194043-n', 1), SenseInfo('00348008-n', 0) ],
"_indict_v_1_rel" : [ SenseInfo('02521284-v', 2) ],
"_remark_v_to_rel" : [ SenseInfo('01020005-v', 41), SenseInfo('01058574-v', 0), SenseInfo('01020005-v', 41), SenseInfo('01058574-v', 0) ],
"_pent-up_a_1_rel" : [ SenseInfo('01316467-a', 0), SenseInfo('01316467-a', 0) ],
"_stick_v_up_rel" : [ SenseInfo('01528069-v', 5), SenseInfo('01857392-v', 2), SenseInfo('01356750-v', 2), SenseInfo('02754032-v', 0), SenseInfo('02647798-v', 0), SenseInfo('02638845-v', 0), SenseInfo('02638630-v', 0), SenseInfo('01667969-v', 0), SenseInfo('01614581-v', 0), SenseInfo('01614426-v', 0), SenseInfo('01614235-v', 0), SenseInfo('01441993-v', 0), SenseInfo('01441793-v', 0), SenseInfo('01220885-v', 0), SenseInfo('00748084-v', 0), SenseInfo('00622384-v', 0), SenseInfo('01528069-v', 5), SenseInfo('01857392-v', 2), SenseInfo('01356750-v', 2), SenseInfo('02754032-v', 0), SenseInfo('02647798-v', 0), SenseInfo('02638845-v', 0), SenseInfo('02638630-v', 0), SenseInfo('01667969-v', 0), SenseInfo('01614581-v', 0), SenseInfo('01614426-v', 0), SenseInfo('01614235-v', 0), SenseInfo('01441993-v', 0), SenseInfo('01441793-v', 0), SenseInfo('01220885-v', 0), SenseInfo('00748084-v', 0), SenseInfo('00622384-v', 0) ],
"_humiliation_n_of_rel" : [ SenseInfo('14440488-n', 2), SenseInfo('07507742-n', 2), SenseInfo('07309223-n', 0), SenseInfo('00273449-n', 0) ],
"_mammalia_n_1_rel" : [ SenseInfo('01861465-n', 0) ],
"_vertebrate_n_1_rel" : [ SenseInfo('01471682-n', 1) ],
"_dropper_n_1_rel" : [ SenseInfo('03247083-n', 0) ],
"_bully_v_into_rel" : [ SenseInfo('01781520-v', 0), SenseInfo('01035199-v', 0), SenseInfo('01781520-v', 0), SenseInfo('01035199-v', 0) ],
"_mutter_n_1_rel" : [ SenseInfo('07386920-n', 0), SenseInfo('07211092-n', 0) ],
"_meantime_p_rel" : [ SenseInfo('15272887-n', 0), SenseInfo('00064946-r', 0) ],
"_box_v_1_rel" : [ SenseInfo('01485158-v', 1), SenseInfo('01420765-v', 0), SenseInfo('01419982-v', 0) ],
"_commune_v_with_rel" : [ SenseInfo('00760187-v', 2), SenseInfo('00760402-v', 0) ],
"_sterling_n_1_rel" : [ SenseInfo('13385080-n', 0) ],
"_suit_n_i_rel" : [ SenseInfo('04350905-n', 13), SenseInfo('01182654-n', 3), SenseInfo('10673946-n', 0), SenseInfo('07188685-n', 0), SenseInfo('07188570-n', 0), SenseInfo('04351233-n', 0) ],
"_innovate_v_1_rel" : [ SenseInfo('01642437-v', 1), SenseInfo('01642437-v', 1), SenseInfo('01642437-v', 1) ],
"_charge_n_i_rel" : [ SenseInfo('00974762-n', 16), SenseInfo('06561942-n', 13), SenseInfo('13306870-n', 4), SenseInfo('11435028-n', 3), SenseInfo('00829378-n', 2), SenseInfo('00731222-n', 2), SenseInfo('09909760-n', 1), SenseInfo('13400798-n', 0), SenseInfo('09185612-n', 0), SenseInfo('07528470-n', 0), SenseInfo('07190941-n', 0), SenseInfo('07169480-n', 0), SenseInfo('06730780-n', 0), SenseInfo('03008565-n', 0), SenseInfo('03008275-n', 0) ],
"_wee_a_1_rel" : [ SenseInfo('01392633-a', 3), SenseInfo('00815849-a', 0) ],
"_growth_n_of_rel" : [ SenseInfo('13489037-n', 37), SenseInfo('13490343-n', 20), SenseInfo('13497135-n', 3), SenseInfo('08438067-n', 3), SenseInfo('07324673-n', 1), SenseInfo('14234074-n', 0), SenseInfo('09295338-n', 0) ],
"_coset_n_1_rel" : [  ],
"_fine_v_1_rel" : [ SenseInfo('02498716-v', 0), SenseInfo('02498716-v', 0) ],
"_size_v_1_rel" : [ SenseInfo('01610278-v', 0), SenseInfo('00655987-v', 0), SenseInfo('00319214-v', 0) ],
"_lotto_n_1_rel" : [ SenseInfo('00504660-n', 0) ],
"_peg_v_cause_rel" : [ SenseInfo('02524897-v', 0), SenseInfo('01442203-v', 0), SenseInfo('01340283-v', 0), SenseInfo('00271201-v', 0) ],
"_perch_n_1_rel" : [ SenseInfo('03914919-n', 1), SenseInfo('13650921-n', 0), SenseInfo('13614679-n', 0), SenseInfo('08626758-n', 0), SenseInfo('07780173-n', 0), SenseInfo('02556846-n', 0), SenseInfo('02555863-n', 0) ],
"_honduran_a_1_rel" : [ SenseInfo('02969241-a', 0) ],
"_actress_n_1_rel" : [ SenseInfo('09767700-n', 3) ],
"_serpent_n_1_rel" : [ SenseInfo('01726692-n', 5), SenseInfo('04174596-n', 0), SenseInfo('04174500-n', 0) ],
"_momma_n_1_rel" : [ SenseInfo('10278128-n', 0) ],
"_wolf_n_1_rel" : [ SenseInfo('02114100-n', 1), SenseInfo('11394398-n', 0), SenseInfo('11394214-n', 0), SenseInfo('10787197-n', 0), SenseInfo('09845589-n', 0) ],
"_guitarist_n_1_rel" : [ SenseInfo('10151760-n', 0) ],
"_bad_a_1_rel" : [ SenseInfo('01125429-a', 51), SenseInfo('01510444-a', 3), SenseInfo('00478311-a', 3), SenseInfo('01069283-a', 1), SenseInfo('01150475-a', 0), SenseInfo('02500050-a', 0), SenseInfo('02345713-a', 0), SenseInfo('02298642-a', 0), SenseInfo('02274537-a', 0), SenseInfo('01174222-a', 0), SenseInfo('01160775-a', 0), SenseInfo('01131803-a', 0), SenseInfo('01117226-a', 0), SenseInfo('01092572-a', 0), SenseInfo('01125429-a', 51), SenseInfo('01510444-a', 3), SenseInfo('00478311-a', 3), SenseInfo('01069283-a', 1), SenseInfo('01150475-a', 0), SenseInfo('02500050-a', 0), SenseInfo('02345713-a', 0), SenseInfo('02298642-a', 0), SenseInfo('02274537-a', 0), SenseInfo('01174222-a', 0), SenseInfo('01160775-a', 0), SenseInfo('01131803-a', 0), SenseInfo('01117226-a', 0), SenseInfo('01092572-a', 0), SenseInfo('01125429-a', 51), SenseInfo('01510444-a', 3), SenseInfo('00478311-a', 3), SenseInfo('01069283-a', 1), SenseInfo('01150475-a', 0), SenseInfo('02500050-a', 0), SenseInfo('02345713-a', 0), SenseInfo('02298642-a', 0), SenseInfo('02274537-a', 0), SenseInfo('01174222-a', 0), SenseInfo('01160775-a', 0), SenseInfo('01131803-a', 0), SenseInfo('01117226-a', 0), SenseInfo('01092572-a', 0), SenseInfo('01125429-a', 51), SenseInfo('01510444-a', 3), SenseInfo('00478311-a', 3), SenseInfo('01069283-a', 1), SenseInfo('01150475-a', 0), SenseInfo('02500050-a', 0), SenseInfo('02345713-a', 0), SenseInfo('02298642-a', 0), SenseInfo('02274537-a', 0), SenseInfo('01174222-a', 0), SenseInfo('01160775-a', 0), SenseInfo('01131803-a', 0), SenseInfo('01117226-a', 0), SenseInfo('01092572-a', 0), SenseInfo('01125429-a', 51), SenseInfo('01510444-a', 3), SenseInfo('00478311-a', 3), SenseInfo('01069283-a', 1), SenseInfo('01150475-a', 0), SenseInfo('02500050-a', 0), SenseInfo('02345713-a', 0), SenseInfo('02298642-a', 0), SenseInfo('02274537-a', 0), SenseInfo('01174222-a', 0), SenseInfo('01160775-a', 0), SenseInfo('01131803-a', 0), SenseInfo('01117226-a', 0), SenseInfo('01092572-a', 0), SenseInfo('01125429-a', 51), SenseInfo('01510444-a', 3), SenseInfo('00478311-a', 3), SenseInfo('01069283-a', 1), SenseInfo('01150475-a', 0), SenseInfo('02500050-a', 0), SenseInfo('02345713-a', 0), SenseInfo('02298642-a', 0), SenseInfo('02274537-a', 0), SenseInfo('01174222-a', 0), SenseInfo('01160775-a', 0), SenseInfo('01131803-a', 0), SenseInfo('01117226-a', 0), SenseInfo('01092572-a', 0) ],
"_candidate_n_for_rel" : [ SenseInfo('09889691-n', 20), SenseInfo('09890749-n', 5) ],
"_detergent_n_1_rel" : [ SenseInfo('15097017-n', 22), SenseInfo('03181899-n', 3) ],
"_pending_a_1_rel" : [ SenseInfo('01004703-a', 3), SenseInfo('01004703-a', 3), SenseInfo('01004703-a', 3), SenseInfo('01004703-a', 3), SenseInfo('01004703-a', 3), SenseInfo('01004703-a', 3) ],
"_interface_v_1_rel" : [  ],
"_delegation_n_of_rel" : [ SenseInfo('08402442-n', 1), SenseInfo('01140839-n', 0) ],
"_mill_n_1_rel" : [ SenseInfo('03316406-n', 4), SenseInfo('11179502-n', 0), SenseInfo('11179287-n', 0), SenseInfo('03765561-n', 0), SenseInfo('00358290-n', 0) ],
"_vicious_a_1_rel" : [ SenseInfo('01263013-a', 4), SenseInfo('02514099-a', 2), SenseInfo('02035765-a', 0), SenseInfo('00226105-a', 0) ],
"_alternate_v_1_rel" : [ SenseInfo('00121506-v', 3), SenseInfo('02393726-v', 0), SenseInfo('00604930-v', 0), SenseInfo('00121678-v', 0), SenseInfo('00121214-v', 0) ],
"_pate_n_1_rel" : [ SenseInfo('07857959-n', 0), SenseInfo('05539595-n', 0) ],
"_covet_v_1_rel" : [ SenseInfo('01827232-v', 1) ],
"_dismiss_v_1_rel" : [ SenseInfo('00800930-v', 14), SenseInfo('00801626-v', 4), SenseInfo('02465939-v', 1), SenseInfo('02402825-v', 0), SenseInfo('00900728-v', 0), SenseInfo('00338559-v', 0) ],
"_draught_n_1_rel" : [ SenseInfo('07883980-n', 2), SenseInfo('00840189-n', 1), SenseInfo('11522448-n', 0), SenseInfo('05135155-n', 0), SenseInfo('03230670-n', 0), SenseInfo('00115667-n', 0) ],
"_lock-in_n_1_rel" : [  ],
"_abut_v_1_rel" : [ SenseInfo('01466978-v', 0) ],
"_rout_n_1_rel" : [ SenseInfo('08184600-n', 0), SenseInfo('07476404-n', 0) ],
"_wand_n_1_rel" : [ SenseInfo('04549629-n', 1), SenseInfo('13164285-n', 0), SenseInfo('07267573-n', 0), SenseInfo('02809364-n', 0) ],
"_inscribe_v_1_rel" : [ SenseInfo('01321895-v', 2), SenseInfo('02471327-v', 0), SenseInfo('01583344-v', 0), SenseInfo('01001008-v', 0), SenseInfo('00997133-v', 0), SenseInfo('00994076-v', 0), SenseInfo('00887325-v', 0) ],
"_adipose_a_1_rel" : [ SenseInfo('00992133-a', 0) ],
"_contain_v_1_rel" : [ SenseInfo('02629535-v', 111), SenseInfo('02700867-v', 34), SenseInfo('02510337-v', 2), SenseInfo('02747287-v', 0), SenseInfo('02701210-v', 0), SenseInfo('01131473-v', 0) ],
"_want_n_of_rel" : [ SenseInfo('14493426-n', 3), SenseInfo('14449405-n', 1), SenseInfo('09367991-n', 1), SenseInfo('07486229-n', 1) ],
"_arable_a_1_rel" : [ SenseInfo('01865807-a', 1) ],
"_planting_n_1_rel" : [ SenseInfo('01052450-n', 3), SenseInfo('08064888-n', 0), SenseInfo('00919513-n', 0) ],
"_a+long+way_a_1_rel" : [  ],
"_cardphone_n_1_rel" : [  ],
"_blaze_v_1_rel" : [ SenseInfo('02764614-v', 5), SenseInfo('01135086-v', 3), SenseInfo('02764438-v', 0), SenseInfo('02014863-v', 0), SenseInfo('00922025-v', 0), SenseInfo('02764614-v', 5), SenseInfo('01135086-v', 3), SenseInfo('02764438-v', 0), SenseInfo('02014863-v', 0), SenseInfo('00922025-v', 0) ],
"_correspond_v_1_rel" : [ SenseInfo('02657219-v', 9), SenseInfo('02633534-v', 6), SenseInfo('01006810-v', 3), SenseInfo('02699497-v', 0) ],
"_rack_v_up_rel" : [ SenseInfo('01960491-v', 2), SenseInfo('01798678-v', 1), SenseInfo('02408722-v', 0), SenseInfo('02241107-v', 0), SenseInfo('01946138-v', 0), SenseInfo('01940782-v', 0), SenseInfo('01855058-v', 0), SenseInfo('01802689-v', 0), SenseInfo('01669419-v', 0), SenseInfo('01213348-v', 0), SenseInfo('00071547-v', 0), SenseInfo('01960491-v', 2), SenseInfo('01798678-v', 1), SenseInfo('02408722-v', 0), SenseInfo('02241107-v', 0), SenseInfo('01946138-v', 0), SenseInfo('01940782-v', 0), SenseInfo('01855058-v', 0), SenseInfo('01802689-v', 0), SenseInfo('01669419-v', 0), SenseInfo('01213348-v', 0), SenseInfo('00071547-v', 0) ],
"_democracy_n_1_rel" : [ SenseInfo('06217103-n', 7), SenseInfo('08361329-n', 3), SenseInfo('05964445-n', 0) ],
"_maximum_n_of_rel" : [ SenseInfo('13776137-n', 11), SenseInfo('05124928-n', 1), SenseInfo('08598132-n', 0) ],
"_health-and-benefits_n_1_rel" : [  ],
"_senseless_a_for_rel" : [ SenseInfo('01945139-a', 2), SenseInfo('00572534-a', 1), SenseInfo('02503305-a', 0), SenseInfo('00441365-a', 0), SenseInfo('01945139-a', 2), SenseInfo('00572534-a', 1), SenseInfo('02503305-a', 0), SenseInfo('00441365-a', 0), SenseInfo('01945139-a', 2), SenseInfo('00572534-a', 1), SenseInfo('02503305-a', 0), SenseInfo('00441365-a', 0) ],
"_foam_v_1_rel" : [ SenseInfo('00519363-v', 1) ],
"_apparatus_n_1_rel" : [ SenseInfo('02727825-n', 22), SenseInfo('05218899-n', 0) ],
"_grate_v_1_rel" : [ SenseInfo('02330583-v', 0), SenseInfo('01773825-v', 0), SenseInfo('01574077-v', 0), SenseInfo('01394464-v', 0), SenseInfo('01308160-v', 0) ],
"_communist_n_1_rel" : [ SenseInfo('09945603-n', 7), SenseInfo('09945319-n', 4) ],
"_unscathed_a_1_rel" : [ SenseInfo('01319712-a', 1) ],
"_viewer_n_of_rel" : [ SenseInfo('10633450-n', 1), SenseInfo('04534651-n', 0) ],
"_lift_v_off_rel" : [ SenseInfo('01974062-v', 31), SenseInfo('01579153-v', 10), SenseInfo('01973759-v', 2), SenseInfo('01968569-v', 2), SenseInfo('00986074-v', 2), SenseInfo('00799798-v', 2), SenseInfo('02276866-v', 1), SenseInfo('01455184-v', 1), SenseInfo('00549982-v', 1), SenseInfo('00544549-v', 1), SenseInfo('00178652-v', 1), SenseInfo('02696801-v', 0), SenseInfo('02352181-v', 0), SenseInfo('02278061-v', 0), SenseInfo('02277138-v', 0), SenseInfo('01452057-v', 0), SenseInfo('01311608-v', 0), SenseInfo('00792921-v', 0), SenseInfo('00357198-v', 0), SenseInfo('00354195-v', 0), SenseInfo('00198623-v', 0), SenseInfo('00178773-v', 0), SenseInfo('00178502-v', 0), SenseInfo('00061933-v', 0), SenseInfo('01974062-v', 31), SenseInfo('01579153-v', 10), SenseInfo('01973759-v', 2), SenseInfo('01968569-v', 2), SenseInfo('00986074-v', 2), SenseInfo('00799798-v', 2), SenseInfo('02276866-v', 1), SenseInfo('01455184-v', 1), SenseInfo('00549982-v', 1), SenseInfo('00544549-v', 1), SenseInfo('00178652-v', 1), SenseInfo('02696801-v', 0), SenseInfo('02352181-v', 0), SenseInfo('02278061-v', 0), SenseInfo('02277138-v', 0), SenseInfo('01452057-v', 0), SenseInfo('01311608-v', 0), SenseInfo('00792921-v', 0), SenseInfo('00357198-v', 0), SenseInfo('00354195-v', 0), SenseInfo('00198623-v', 0), SenseInfo('00178773-v', 0), SenseInfo('00178502-v', 0), SenseInfo('00061933-v', 0) ],
"_whatever_p_rel" : [ SenseInfo('02267686-a', 0) ],
"_crank_v_up_rel" : [ SenseInfo('01991744-v', 0), SenseInfo('01858796-v', 0), SenseInfo('01595149-v', 0), SenseInfo('01341815-v', 0), SenseInfo('01280958-v', 0) ],
"_catastrophe_n_1_rel" : [ SenseInfo('07314838-n', 3), SenseInfo('14476290-n', 1), SenseInfo('11434016-n', 0) ],
"_run_v_over_rel" : [ SenseInfo('01926311-v', 106), SenseInfo('02075049-v', 38), SenseInfo('02685951-v', 21), SenseInfo('02443849-v', 20), SenseInfo('02721284-v', 10), SenseInfo('02066939-v', 9), SenseInfo('01525666-v', 8), SenseInfo('02727039-v', 7), SenseInfo('01094086-v', 7), SenseInfo('01717169-v', 5), SenseInfo('02099829-v', 4), SenseInfo('02719399-v', 3), SenseInfo('01526290-v', 3), SenseInfo('00549063-v', 3), SenseInfo('00517529-v', 3), SenseInfo('02720904-v', 2), SenseInfo('02647497-v', 2), SenseInfo('02612234-v', 2), SenseInfo('02563327-v', 2), SenseInfo('01746359-v', 2), SenseInfo('01641545-v', 2), SenseInfo('01212230-v', 2), SenseInfo('02686625-v', 1), SenseInfo('02525312-v', 1), SenseInfo('02242256-v', 1), SenseInfo('02092309-v', 1), SenseInfo('02060792-v', 1), SenseInfo('01927903-v', 1), SenseInfo('01914947-v', 1), SenseInfo('02648110-v', 0), SenseInfo('02421921-v', 0), SenseInfo('01927747-v', 0), SenseInfo('01927447-v', 0), SenseInfo('01926984-v', 0), SenseInfo('01864038-v', 0), SenseInfo('01143838-v', 0), SenseInfo('01086103-v', 0), SenseInfo('00539110-v', 0), SenseInfo('00444629-v', 0), SenseInfo('00334803-v', 0), SenseInfo('00332672-v', 0), SenseInfo('01926311-v', 106), SenseInfo('02075049-v', 38), SenseInfo('02685951-v', 21), SenseInfo('02443849-v', 20), SenseInfo('02721284-v', 10), SenseInfo('02066939-v', 9), SenseInfo('01525666-v', 8), SenseInfo('02727039-v', 7), SenseInfo('01094086-v', 7), SenseInfo('01717169-v', 5), SenseInfo('02099829-v', 4), SenseInfo('02719399-v', 3), SenseInfo('01526290-v', 3), SenseInfo('00549063-v', 3), SenseInfo('00517529-v', 3), SenseInfo('02720904-v', 2), SenseInfo('02647497-v', 2), SenseInfo('02612234-v', 2), SenseInfo('02563327-v', 2), SenseInfo('01746359-v', 2), SenseInfo('01641545-v', 2), SenseInfo('01212230-v', 2), SenseInfo('02686625-v', 1), SenseInfo('02525312-v', 1), SenseInfo('02242256-v', 1), SenseInfo('02092309-v', 1), SenseInfo('02060792-v', 1), SenseInfo('01927903-v', 1), SenseInfo('01914947-v', 1), SenseInfo('02648110-v', 0), SenseInfo('02421921-v', 0), SenseInfo('01927747-v', 0), SenseInfo('01927447-v', 0), SenseInfo('01926984-v', 0), SenseInfo('01864038-v', 0), SenseInfo('01143838-v', 0), SenseInfo('01086103-v', 0), SenseInfo('00539110-v', 0), SenseInfo('00444629-v', 0), SenseInfo('00334803-v', 0), SenseInfo('00332672-v', 0) ],
"_fetus_n_1_rel" : [ SenseInfo('01459791-n', 0), SenseInfo('01459791-n', 0) ],
"_harrowing_a_1_rel" : [ SenseInfo('01711724-a', 0) ],
"_corinthian_a_1_rel" : [ SenseInfo('02845048-a', 0), SenseInfo('02704686-a', 0) ],
"_sultry_a_1_rel" : [ SenseInfo('01257145-a', 1), SenseInfo('01250121-a', 1), SenseInfo('01257145-a', 1), SenseInfo('01250121-a', 1), SenseInfo('01257145-a', 1), SenseInfo('01250121-a', 1) ],
"_preferential_a_1_rel" : [ SenseInfo('00065184-a', 1) ],
"_vulgar_a_1_rel" : [ SenseInfo('01950198-a', 2), SenseInfo('01593079-a', 0), SenseInfo('01046226-a', 0), SenseInfo('00683531-a', 0) ],
"_decree_v_to_rel" : [ SenseInfo('01027508-v', 2), SenseInfo('00715868-v', 0), SenseInfo('01027508-v', 2), SenseInfo('00715868-v', 0), SenseInfo('01027508-v', 2), SenseInfo('00715868-v', 0) ],
"_widen_v_1_rel" : [ SenseInfo('00303465-v', 7), SenseInfo('00303940-v', 1), SenseInfo('00303661-v', 1), SenseInfo('00540235-v', 0) ],
"_frolic_v_1_rel" : [ SenseInfo('01883716-v', 1) ],
"_geodesic_n_1_rel" : [ SenseInfo('13870414-n', 0) ],
"_travelogue_n_1_rel" : [ SenseInfo('06615348-n', 1) ],
"_fiction_n_1_rel" : [ SenseInfo('06367107-n', 14), SenseInfo('06757891-n', 0) ],
"_ammonia_n_1_rel" : [ SenseInfo('14743840-n', 0), SenseInfo('14743582-n', 0) ],
"_daddy_n_1_rel" : [ SenseInfo('09988063-n', 2) ],
"_overhasty_a_1_rel" : [ SenseInfo('01270868-a', 0) ],
"_infinite_a_1_rel" : [ SenseInfo('01007354-a', 8), SenseInfo('01008745-a', 0), SenseInfo('00301951-a', 0), SenseInfo('00005718-a', 0), SenseInfo('01007354-a', 8), SenseInfo('01008745-a', 0), SenseInfo('00301951-a', 0), SenseInfo('00005718-a', 0) ],
"_within_p_rel" : [ SenseInfo('00110815-r', 6), SenseInfo('00110815-r', 6) ],
"_smithy_n_1_rel" : [ SenseInfo('03383646-n', 0) ],
"_foot_v_1_rel" : [ SenseInfo('02287209-v', 1), SenseInfo('01906322-v', 0), SenseInfo('00641138-v', 0) ],
"_biomedicine_n_1_rel" : [ SenseInfo('06047096-n', 2), SenseInfo('06046898-n', 0) ],
"_precise_a_1_rel" : [ SenseInfo('01837744-a', 16), SenseInfo('00631798-a', 1), SenseInfo('01837744-a', 16), SenseInfo('00631798-a', 1), SenseInfo('01837744-a', 16), SenseInfo('00631798-a', 1) ],
"_pancake_n_1_rel" : [ SenseInfo('07640203-n', 0) ],
"_brink_n_of_rel" : [ SenseInfo('13903738-n', 1), SenseInfo('08517127-n', 0), SenseInfo('05125193-n', 0) ],
"_twist_v_1_rel" : [ SenseInfo('01868370-v', 13), SenseInfo('01280014-v', 5), SenseInfo('01222645-v', 2), SenseInfo('01223182-v', 1), SenseInfo('00143914-v', 1), SenseInfo('02738701-v', 0), SenseInfo('01895519-v', 0), SenseInfo('01349493-v', 0), SenseInfo('00932798-v', 0), SenseInfo('00091124-v', 0) ],
"_bouncy_a_1_rel" : [ SenseInfo('00843595-a', 0), SenseInfo('00805309-a', 0) ],
"_demolish_v_1_rel" : [ SenseInfo('01656458-v', 2), SenseInfo('01800195-v', 0), SenseInfo('01083373-v', 0) ],
"_send_v_out_rel" : [ SenseInfo('01951480-v', 79), SenseInfo('01437254-v', 20), SenseInfo('01031256-v', 20), SenseInfo('01950798-v', 14), SenseInfo('01088923-v', 5), SenseInfo('01062555-v', 5), SenseInfo('02348568-v', 3), SenseInfo('00973056-v', 2) ],
"_knob_n_1_rel" : [ SenseInfo('03626115-n', 2), SenseInfo('03626014-n', 1), SenseInfo('13895986-n', 0), SenseInfo('03626272-n', 0) ],
"_reel_v_out_rel" : [ SenseInfo('01924882-v', 2), SenseInfo('02046755-v', 1), SenseInfo('01523105-v', 0) ],
"_notable_a_1_rel" : [ SenseInfo('02586957-a', 5), SenseInfo('01375831-a', 1), SenseInfo('02586957-a', 5), SenseInfo('01375831-a', 1), SenseInfo('02586957-a', 5), SenseInfo('01375831-a', 1), SenseInfo('02586957-a', 5), SenseInfo('01375831-a', 1) ],
"_brunch_n_1_rel" : [ SenseInfo('07574923-n', 0) ],
"_speak_v_out_rel" : [ SenseInfo('00941990-v', 86), SenseInfo('00962447-v', 53), SenseInfo('00963570-v', 23), SenseInfo('00989201-v', 11), SenseInfo('02135607-v', 3) ],
"_bias_n_1_rel" : [ SenseInfo('06201908-n', 1), SenseInfo('13904164-n', 0) ],
"_subversive_a_1_rel" : [ SenseInfo('00963283-a', 0) ],
"_grease_v_up_rel" : [ SenseInfo('01269379-v', 1) ],
"_excited_a_1_rel" : [ SenseInfo('00085630-a', 4), SenseInfo('00919542-a', 3), SenseInfo('02390724-a', 2), SenseInfo('01928926-a', 0), SenseInfo('00085630-a', 4), SenseInfo('00919542-a', 3), SenseInfo('02390724-a', 2), SenseInfo('01928926-a', 0), SenseInfo('00085630-a', 4), SenseInfo('00919542-a', 3), SenseInfo('02390724-a', 2), SenseInfo('01928926-a', 0) ],
"_tell-all_a_1_rel" : [  ],
"_deer_n_1_rel" : [ SenseInfo('02430045-n', 2) ],
"_cool_v_1_rel" : [ SenseInfo('00370412-v', 15), SenseInfo('00369864-v', 1), SenseInfo('00370126-v', 0) ],
"_run+of+the+mill_a_1_rel" : [ SenseInfo('01674926-a', 0), SenseInfo('01674926-a', 0), SenseInfo('01674926-a', 0) ],
"_scotch_n_1_rel" : [ SenseInfo('13905405-n', 0), SenseInfo('07907548-n', 0) ],
"_secret_a_1_rel" : [ SenseInfo('02090069-a', 10), SenseInfo('01706465-a', 2), SenseInfo('00028984-a', 2), SenseInfo('01707404-a', 1), SenseInfo('00952181-a', 1), SenseInfo('02089514-a', 0), SenseInfo('01860580-a', 0), SenseInfo('01859571-a', 0), SenseInfo('01706986-a', 0), SenseInfo('00900071-a', 0), SenseInfo('00416045-a', 0), SenseInfo('02090069-a', 10), SenseInfo('01706465-a', 2), SenseInfo('00028984-a', 2), SenseInfo('01707404-a', 1), SenseInfo('00952181-a', 1), SenseInfo('02089514-a', 0), SenseInfo('01860580-a', 0), SenseInfo('01859571-a', 0), SenseInfo('01706986-a', 0), SenseInfo('00900071-a', 0), SenseInfo('00416045-a', 0) ],
"_viewpoint_n_1_rel" : [ SenseInfo('06210363-n', 14), SenseInfo('08677250-n', 0), SenseInfo('06210363-n', 14), SenseInfo('08677250-n', 0) ],
"_wiggle_n_1_rel" : [ SenseInfo('00349705-n', 0) ],
"_swear_v_off_rel" : [ SenseInfo('00865387-v', 20), SenseInfo('01011031-v', 8), SenseInfo('00889947-v', 2), SenseInfo('01013040-v', 1), SenseInfo('00688377-v', 0) ],
"_barricade_v_1_rel" : [ SenseInfo('01478002-v', 1), SenseInfo('01127215-v', 0), SenseInfo('01127075-v', 0) ],
"_outlet_n_1_rel" : [ SenseInfo('03748162-n', 3), SenseInfo('04548771-n', 1), SenseInfo('03303965-n', 0), SenseInfo('01264447-n', 0) ],
"_tube_n_1_rel" : [ SenseInfo('04493505-n', 26), SenseInfo('04494204-n', 7), SenseInfo('13901321-n', 1), SenseInfo('05246511-n', 0), SenseInfo('03757138-n', 0) ],
"_eyeball_v_1_rel" : [ SenseInfo('02167052-v', 0) ],
"_inflict_v_on_rel" : [ SenseInfo('00748282-v', 9), SenseInfo('00748282-v', 9) ],
"_side+by+side_p_rel" : [ SenseInfo('00447472-a', 2), SenseInfo('01974584-a', 0) ],
"_fashion_v_into_rel" : [ SenseInfo('01658188-v', 8), SenseInfo('01658188-v', 8) ],
"_truant_a_1_rel" : [ SenseInfo('01848171-a', 0) ],
"_habitation_n_1_rel" : [ SenseInfo('08580803-n', 0), SenseInfo('03259505-n', 0), SenseInfo('01054545-n', 0) ],
"_pass_n_1_rel" : [ SenseInfo('00286112-n', 0), SenseInfo('00286112-n', 0) ],
"_tense_v_up_rel" : [ SenseInfo('01572728-v', 0), SenseInfo('00536304-v', 0), SenseInfo('00026153-v', 0), SenseInfo('00025203-v', 0), SenseInfo('01572728-v', 0), SenseInfo('00536304-v', 0), SenseInfo('00026153-v', 0), SenseInfo('00025203-v', 0) ],
"_miner_n_1_rel" : [ SenseInfo('10319796-n', 2) ],
"_canton_n_1_rel" : [ SenseInfo('08725454-n', 0), SenseInfo('08540770-n', 0), SenseInfo('08725454-n', 0), SenseInfo('08540770-n', 0) ],
"_caliente_n_1_rel" : [  ],
"_love_n_of-for_rel" : [ SenseInfo('07543288-n', 42), SenseInfo('05813229-n', 3), SenseInfo('09849598-n', 2), SenseInfo('07488340-n', 1), SenseInfo('13596569-n', 0), SenseInfo('00846515-n', 0), SenseInfo('07543288-n', 42), SenseInfo('05813229-n', 3), SenseInfo('09849598-n', 2), SenseInfo('07488340-n', 1), SenseInfo('13596569-n', 0), SenseInfo('00846515-n', 0) ],
"_seem_v_to_rel" : [ SenseInfo('02133435-v', 607), SenseInfo('02134672-v', 84), SenseInfo('02745882-v', 0), SenseInfo('02198234-v', 0), SenseInfo('02133435-v', 607), SenseInfo('02134672-v', 84), SenseInfo('02745882-v', 0), SenseInfo('02198234-v', 0), SenseInfo('02133435-v', 607), SenseInfo('02134672-v', 84), SenseInfo('02745882-v', 0), SenseInfo('02198234-v', 0), SenseInfo('02133435-v', 607), SenseInfo('02134672-v', 84), SenseInfo('02745882-v', 0), SenseInfo('02198234-v', 0) ],
"_mailer_n_1_rel" : [ SenseInfo('11149762-n', 0), SenseInfo('10282920-n', 0), SenseInfo('07249336-n', 0), SenseInfo('03710528-n', 0) ],
"_unpaved_a_1_rel" : [ SenseInfo('01739987-a', 1), SenseInfo('01739987-a', 1) ],
"_solarium_n_1_rel" : [ SenseInfo('04356925-n', 0) ],
"_right+away_p_rel" : [ SenseInfo('00048739-r', 10), SenseInfo('00105467-r', 0) ],
"_write_v_back_rel" : [ SenseInfo('01698271-v', 112), SenseInfo('00993014-v', 94), SenseInfo('01744611-v', 33), SenseInfo('01007027-v', 15), SenseInfo('01031966-v', 10), SenseInfo('01705494-v', 9), SenseInfo('01691057-v', 8), SenseInfo('00998886-v', 4), SenseInfo('01699896-v', 1), SenseInfo('01692834-v', 0), SenseInfo('01698271-v', 112), SenseInfo('00993014-v', 94), SenseInfo('01744611-v', 33), SenseInfo('01007027-v', 15), SenseInfo('01031966-v', 10), SenseInfo('01705494-v', 9), SenseInfo('01691057-v', 8), SenseInfo('00998886-v', 4), SenseInfo('01699896-v', 1), SenseInfo('01692834-v', 0) ],
"_wingspan_n_1_rel" : [ SenseInfo('05130614-n', 0) ],
"_unwise_a_1_rel" : [ SenseInfo('02572657-a', 2), SenseInfo('01814252-a', 0), SenseInfo('02572657-a', 2), SenseInfo('01814252-a', 0), SenseInfo('02572657-a', 2), SenseInfo('01814252-a', 0), SenseInfo('02572657-a', 2), SenseInfo('01814252-a', 0), SenseInfo('02572657-a', 2), SenseInfo('01814252-a', 0), SenseInfo('02572657-a', 2), SenseInfo('01814252-a', 0) ],
"_scare_v_away_rel" : [ SenseInfo('01779165-v', 4), SenseInfo('01785748-v', 2) ],
"_letter_n_of_rel" : [ SenseInfo('06624161-n', 65), SenseInfo('06828818-n', 7), SenseInfo('10255207-n', 0), SenseInfo('07173389-n', 0), SenseInfo('06706504-n', 0) ],
"_tabs_n_i_rel" : [ SenseInfo('06517942-n', 0), SenseInfo('06267991-n', 0), SenseInfo('04379096-n', 0), SenseInfo('04378123-n', 0), SenseInfo('03936568-n', 0) ],
"_fleece_n_1_rel" : [ SenseInfo('15104752-n', 0), SenseInfo('14763508-n', 0), SenseInfo('03362639-n', 0), SenseInfo('01899593-n', 0) ],
"_thumb_v_1_rel" : [ SenseInfo('01956955-v', 2), SenseInfo('02153023-v', 0), SenseInfo('01209953-v', 0) ],
"_linguist_n_1_rel" : [ SenseInfo('10264437-n', 16), SenseInfo('10264219-n', 0) ],
"_unfamiliar_a_with_rel" : [ SenseInfo('00966477-a', 4), SenseInfo('00966477-a', 4) ],
"_renewable_a_1_rel" : [ SenseInfo('01962982-a', 0), SenseInfo('00925820-a', 0) ],
"_variation_n_of_rel" : [ SenseInfo('07337390-n', 24), SenseInfo('00194969-n', 9), SenseInfo('07030012-n', 2), SenseInfo('05840650-n', 1), SenseInfo('04521699-n', 1), SenseInfo('13893310-n', 0), SenseInfo('13572324-n', 0), SenseInfo('11415084-n', 0), SenseInfo('10341660-n', 0), SenseInfo('00529101-n', 0), SenseInfo('00195194-n', 0) ],
"_format_v_1_rel" : [ SenseInfo('01745141-v', 0), SenseInfo('00700336-v', 0), SenseInfo('00563552-v', 0) ],
"_disfigure_v_1_rel" : [ SenseInfo('01549905-v', 0), SenseInfo('01549905-v', 0) ],
"_database_n_of_rel" : [ SenseInfo('06637824-n', 0) ],
"_burn_v_1_rel" : [ SenseInfo('00378664-v', 11), SenseInfo('02768874-v', 10), SenseInfo('00377002-v', 9), SenseInfo('02120451-v', 4), SenseInfo('02762468-v', 2), SenseInfo('01829292-v', 2), SenseInfo('00378042-v', 2), SenseInfo('02485322-v', 1), SenseInfo('02268881-v', 1), SenseInfo('02121048-v', 1), SenseInfo('00373766-v', 1), SenseInfo('00104299-v', 1), SenseInfo('01756277-v', 0), SenseInfo('01205000-v', 0), SenseInfo('00196364-v', 0) ],
"_query_n_1_rel" : [ SenseInfo('07193596-n', 1), SenseInfo('07193596-n', 1) ],
"_shovel_v_1_rel" : [ SenseInfo('01312810-v', 1) ],
"_information_n_on-about_rel" : [ SenseInfo('06634376-n', 102), SenseInfo('05816287-n', 47), SenseInfo('07237561-n', 1), SenseInfo('08462320-n', 0), SenseInfo('05091527-n', 0), SenseInfo('06634376-n', 102), SenseInfo('05816287-n', 47), SenseInfo('07237561-n', 1), SenseInfo('08462320-n', 0), SenseInfo('05091527-n', 0), SenseInfo('06634376-n', 102), SenseInfo('05816287-n', 47), SenseInfo('07237561-n', 1), SenseInfo('08462320-n', 0), SenseInfo('05091527-n', 0) ],
"_subdue_v_1_rel" : [ SenseInfo('02424128-v', 2), SenseInfo('00462092-v', 2), SenseInfo('01801847-v', 0), SenseInfo('01108627-v', 0), SenseInfo('00579712-v', 0), SenseInfo('00202445-v', 0) ],
"_appeal_v_1_rel" : [ SenseInfo('02497586-v', 4), SenseInfo('00755447-v', 2), SenseInfo('01807882-v', 1), SenseInfo('02497824-v', 0), SenseInfo('01024864-v', 0) ],
"_sole_n_1_rel" : [ SenseInfo('04258982-n', 3), SenseInfo('07791274-n', 0), SenseInfo('05577190-n', 0), SenseInfo('02663849-n', 0) ],
"_switch_v_off_rel" : [ SenseInfo('00140751-v', 5), SenseInfo('02259005-v', 3), SenseInfo('00550117-v', 2), SenseInfo('00380159-v', 1), SenseInfo('01510173-v', 0), SenseInfo('01411630-v', 0), SenseInfo('00121678-v', 0), SenseInfo('00140751-v', 5), SenseInfo('02259005-v', 3), SenseInfo('00550117-v', 2), SenseInfo('00380159-v', 1), SenseInfo('01510173-v', 0), SenseInfo('01411630-v', 0), SenseInfo('00121678-v', 0) ],
"_loving_a_1_rel" : [ SenseInfo('01463965-a', 3), SenseInfo('01463965-a', 3) ],
"_vie_v_for_rel" : [ SenseInfo('01072262-v', 4) ],
"_squadroom_n_1_rel" : [  ],
"_under-the-table_a_1_rel" : [ SenseInfo('01707531-a', 0), SenseInfo('01707531-a', 0) ],
"_warn_v_1_rel" : [ SenseInfo('00870213-v', 22), SenseInfo('00870577-v', 5), SenseInfo('00833071-v', 0), SenseInfo('00832907-v', 0), SenseInfo('00870213-v', 22), SenseInfo('00870577-v', 5), SenseInfo('00833071-v', 0), SenseInfo('00832907-v', 0), SenseInfo('00870213-v', 22), SenseInfo('00870577-v', 5), SenseInfo('00833071-v', 0), SenseInfo('00832907-v', 0), SenseInfo('00870213-v', 22), SenseInfo('00870577-v', 5), SenseInfo('00833071-v', 0), SenseInfo('00832907-v', 0) ],
"_hug_v_1_rel" : [ SenseInfo('01424456-v', 6), SenseInfo('01396524-v', 2) ],
"_weep_v_1_rel" : [ SenseInfo('00066191-v', 20) ],
"_skydiving_n_1_rel" : [ SenseInfo('00304040-n', 0) ],
"_prescribe_v_1_rel" : [ SenseInfo('00747135-v', 7) ],
"_take_v_off_rel" : [ SenseInfo('02599636-v', 92), SenseInfo('02267989-v', 74), SenseInfo('01999798-v', 73), SenseInfo('01214265-v', 50), SenseInfo('00524682-v', 38), SenseInfo('00624476-v', 36), SenseInfo('02077656-v', 32), SenseInfo('02205272-v', 28), SenseInfo('01842690-v', 26), SenseInfo('00674607-v', 26), SenseInfo('02236124-v', 25), SenseInfo('02394183-v', 22), SenseInfo('00734054-v', 22), SenseInfo('02627934-v', 21), SenseInfo('02109045-v', 21), SenseInfo('01002740-v', 16), SenseInfo('00173338-v', 16), SenseInfo('01156834-v', 15), SenseInfo('00669762-v', 15), SenseInfo('02209936-v', 14), SenseInfo('02206619-v', 13), SenseInfo('01982395-v', 10), SenseInfo('02236624-v', 8), SenseInfo('00523095-v', 7), SenseInfo('00599992-v', 6), SenseInfo('00756076-v', 5), SenseInfo('02075857-v', 4), SenseInfo('01151110-v', 4), SenseInfo('00557404-v', 4), SenseInfo('02717102-v', 2), SenseInfo('02208537-v', 2), SenseInfo('02209745-v', 1), SenseInfo('02208118-v', 1), SenseInfo('02201138-v', 1), SenseInfo('01427127-v', 1), SenseInfo('00758333-v', 1), SenseInfo('02741546-v', 0), SenseInfo('02701210-v', 0), SenseInfo('02590253-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01100830-v', 0), SenseInfo('00087736-v', 0) ],
"_previous+to_p_rel" : [  ],
"_leafy_a_1_rel" : [ SenseInfo('01700414-a', 0), SenseInfo('01700414-a', 0), SenseInfo('01700414-a', 0) ],
"_gag_n_1_rel" : [ SenseInfo('06778102-n', 6), SenseInfo('03410740-n', 0) ],
"_misfeed_v_cause_rel" : [  ],
"_flowerbed_n_1_rel" : [ SenseInfo('03368352-n', 1) ],
"_uninsured_n_1_rel" : [ SenseInfo('02097029-a', 0) ],
"_sniff_n_1_rel" : [ SenseInfo('00883139-n', 0) ],
"_lean_v_towards_rel" : [ SenseInfo('02038357-v', 24), SenseInfo('01606574-v', 6), SenseInfo('02719399-v', 3), SenseInfo('00688261-v', 1), SenseInfo('02039013-v', 0), SenseInfo('02038357-v', 24), SenseInfo('01606574-v', 6), SenseInfo('02719399-v', 3), SenseInfo('00688261-v', 1), SenseInfo('02039013-v', 0) ],
"_cut_n_1_rel" : [ SenseInfo('13289159-n', 1), SenseInfo('06618234-n', 1), SenseInfo('03152619-n', 1), SenseInfo('14429885-n', 0), SenseInfo('14287113-n', 0), SenseInfo('07653394-n', 0), SenseInfo('06721461-n', 0), SenseInfo('06612865-n', 0), SenseInfo('06428216-n', 0), SenseInfo('05750948-n', 0), SenseInfo('03152743-n', 0), SenseInfo('01225997-n', 0), SenseInfo('00571444-n', 0), SenseInfo('00565809-n', 0), SenseInfo('00489475-n', 0), SenseInfo('00387657-n', 0), SenseInfo('00386915-n', 0), SenseInfo('00359238-n', 0), SenseInfo('00352331-n', 0), SenseInfo('00067254-n', 0) ],
"_settle_v_down_rel" : [ SenseInfo('01988458-v', 16), SenseInfo('00698855-v', 10), SenseInfo('00763399-v', 8), SenseInfo('00413876-v', 7), SenseInfo('00764902-v', 5), SenseInfo('01989873-v', 4), SenseInfo('00415398-v', 3), SenseInfo('00558673-v', 2), SenseInfo('00539338-v', 2), SenseInfo('01987058-v', 1), SenseInfo('01465921-v', 1), SenseInfo('00798091-v', 1), SenseInfo('00764032-v', 1), SenseInfo('02254258-v', 0), SenseInfo('01986715-v', 0), SenseInfo('01986551-v', 0), SenseInfo('01986185-v', 0), SenseInfo('01493619-v', 0), SenseInfo('01092128-v', 0), SenseInfo('00481941-v', 0), SenseInfo('00415044-v', 0), SenseInfo('00342164-v', 0), SenseInfo('01988458-v', 16), SenseInfo('00698855-v', 10), SenseInfo('00763399-v', 8), SenseInfo('00413876-v', 7), SenseInfo('00764902-v', 5), SenseInfo('01989873-v', 4), SenseInfo('00415398-v', 3), SenseInfo('00558673-v', 2), SenseInfo('00539338-v', 2), SenseInfo('01987058-v', 1), SenseInfo('01465921-v', 1), SenseInfo('00798091-v', 1), SenseInfo('00764032-v', 1), SenseInfo('02254258-v', 0), SenseInfo('01986715-v', 0), SenseInfo('01986551-v', 0), SenseInfo('01986185-v', 0), SenseInfo('01493619-v', 0), SenseInfo('01092128-v', 0), SenseInfo('00481941-v', 0), SenseInfo('00415044-v', 0), SenseInfo('00342164-v', 0) ],
"_injury_n_1_rel" : [ SenseInfo('14285662-n', 13), SenseInfo('07313636-n', 7), SenseInfo('07340249-n', 0), SenseInfo('00744443-n', 0), SenseInfo('00744305-n', 0) ],
"_right_a_2_rel" : [ SenseInfo('02031986-a', 20), SenseInfo('00631391-a', 20), SenseInfo('01879261-a', 16), SenseInfo('02034828-a', 10), SenseInfo('00633410-a', 2), SenseInfo('00135455-a', 1), SenseInfo('02030080-a', 0), SenseInfo('02082081-a', 0), SenseInfo('02029047-a', 0), SenseInfo('01879464-a', 0), SenseInfo('01720930-a', 0), SenseInfo('01693585-a', 0), SenseInfo('01661289-a', 0), SenseInfo('00023278-a', 0), SenseInfo('02031986-a', 20), SenseInfo('00631391-a', 20), SenseInfo('01879261-a', 16), SenseInfo('02034828-a', 10), SenseInfo('00633410-a', 2), SenseInfo('00135455-a', 1), SenseInfo('02030080-a', 0), SenseInfo('02082081-a', 0), SenseInfo('02029047-a', 0), SenseInfo('01879464-a', 0), SenseInfo('01720930-a', 0), SenseInfo('01693585-a', 0), SenseInfo('01661289-a', 0), SenseInfo('00023278-a', 0), SenseInfo('02031986-a', 20), SenseInfo('00631391-a', 20), SenseInfo('01879261-a', 16), SenseInfo('02034828-a', 10), SenseInfo('00633410-a', 2), SenseInfo('00135455-a', 1), SenseInfo('02030080-a', 0), SenseInfo('02082081-a', 0), SenseInfo('02029047-a', 0), SenseInfo('01879464-a', 0), SenseInfo('01720930-a', 0), SenseInfo('01693585-a', 0), SenseInfo('01661289-a', 0), SenseInfo('00023278-a', 0), SenseInfo('02031986-a', 20), SenseInfo('00631391-a', 20), SenseInfo('01879261-a', 16), SenseInfo('02034828-a', 10), SenseInfo('00633410-a', 2), SenseInfo('00135455-a', 1), SenseInfo('02030080-a', 0), SenseInfo('02082081-a', 0), SenseInfo('02029047-a', 0), SenseInfo('01879464-a', 0), SenseInfo('01720930-a', 0), SenseInfo('01693585-a', 0), SenseInfo('01661289-a', 0), SenseInfo('00023278-a', 0), SenseInfo('02031986-a', 20), SenseInfo('00631391-a', 20), SenseInfo('01879261-a', 16), SenseInfo('02034828-a', 10), SenseInfo('00633410-a', 2), SenseInfo('00135455-a', 1), SenseInfo('02030080-a', 0), SenseInfo('02082081-a', 0), SenseInfo('02029047-a', 0), SenseInfo('01879464-a', 0), SenseInfo('01720930-a', 0), SenseInfo('01693585-a', 0), SenseInfo('01661289-a', 0), SenseInfo('00023278-a', 0), SenseInfo('02031986-a', 20), SenseInfo('00631391-a', 20), SenseInfo('01879261-a', 16), SenseInfo('02034828-a', 10), SenseInfo('00633410-a', 2), SenseInfo('00135455-a', 1), SenseInfo('02030080-a', 0), SenseInfo('02082081-a', 0), SenseInfo('02029047-a', 0), SenseInfo('01879464-a', 0), SenseInfo('01720930-a', 0), SenseInfo('01693585-a', 0), SenseInfo('01661289-a', 0), SenseInfo('00023278-a', 0) ],
"_m-z_n_1_rel" : [  ],
"_snap_v_up_rel" : [ SenseInfo('00916274-v', 7), SenseInfo('01573515-v', 3), SenseInfo('00337065-v', 3), SenseInfo('01893771-v', 2), SenseInfo('00355670-v', 2), SenseInfo('02182851-v', 1), SenseInfo('02088949-v', 1), SenseInfo('01439745-v', 1), SenseInfo('01402872-v', 1), SenseInfo('01242208-v', 1), SenseInfo('01784295-v', 0), SenseInfo('01446301-v', 0), SenseInfo('01003249-v', 0) ],
"_writings_n_1_rel" : [ SenseInfo('00929718-n', 8), SenseInfo('06362953-n', 6), SenseInfo('06363778-n', 4), SenseInfo('06359877-n', 2), SenseInfo('00614224-n', 2), SenseInfo('00929718-n', 8), SenseInfo('06362953-n', 6), SenseInfo('06363778-n', 4), SenseInfo('06359877-n', 2), SenseInfo('00614224-n', 2) ],
"_max_a_1_rel" : [ SenseInfo('04253751-n', 0) ],
"_snarl_n_1_rel" : [ SenseInfo('07129758-n', 1), SenseInfo('06878706-n', 1), SenseInfo('05685879-n', 0) ],
"_video_v_1_rel" : [  ],
"_and+company_n_1_rel" : [  ],
"_lynx_n_1_rel" : [ SenseInfo('06571724-n', 0), SenseInfo('02127052-n', 0), SenseInfo('06571724-n', 0), SenseInfo('02127052-n', 0) ],
"_bodyguard_n_1_rel" : [ SenseInfo('09863031-n', 1), SenseInfo('08215801-n', 0) ],
"_imprint_n_1_rel" : [ SenseInfo('05693383-n', 1), SenseInfo('13896369-n', 0), SenseInfo('06855563-n', 0), SenseInfo('06855432-n', 0), SenseInfo('03565288-n', 0) ],
"_clutter_v_up_rel" : [ SenseInfo('00181875-v', 0) ],
"_lunar_a_1_rel" : [ SenseInfo('02757316-a', 8) ],
"_public_a_1_rel" : [ SenseInfo('01861205-a', 50), SenseInfo('00493297-a', 22), SenseInfo('01861205-a', 50), SenseInfo('00493297-a', 22) ],
"_menstrual_a_1_rel" : [ SenseInfo('02879273-a', 0) ],
"_dog_v_1_rel" : [ SenseInfo('02001858-v', 2) ],
"_equip_v_with_rel" : [ SenseInfo('02339413-v', 11), SenseInfo('00513177-v', 1), SenseInfo('02339413-v', 11), SenseInfo('00513177-v', 1) ],
"_mountaineer_n_1_rel" : [ SenseInfo('10334567-n', 0) ],
"_celery_n_1_rel" : [ SenseInfo('12933403-n', 0), SenseInfo('07730406-n', 0) ],
"_tri+mode_n_1_rel" : [  ],
"_physicist_n_1_rel" : [ SenseInfo('10428004-n', 3) ],
"_differ_v_from_rel" : [ SenseInfo('02666239-v', 27), SenseInfo('00804802-v', 1) ],
"_result_v_from_rel" : [ SenseInfo('02634265-v', 45), SenseInfo('02635659-v', 38), SenseInfo('00340704-v', 0) ],
"_convey_v_1_rel" : [ SenseInfo('00928630-v', 9), SenseInfo('01061017-v', 8), SenseInfo('02231661-v', 0), SenseInfo('02221454-v', 0), SenseInfo('02079933-v', 0), SenseInfo('02077656-v', 0), SenseInfo('01433294-v', 0), SenseInfo('00928630-v', 9), SenseInfo('01061017-v', 8), SenseInfo('02231661-v', 0), SenseInfo('02221454-v', 0), SenseInfo('02079933-v', 0), SenseInfo('02077656-v', 0), SenseInfo('01433294-v', 0) ],
"_time+wise_a_1_rel" : [  ],
"_shelf_n_1_rel" : [ SenseInfo('04190052-n', 8), SenseInfo('09337253-n', 0) ],
"_overturn_v_cause_rel" : [ SenseInfo('01909397-v', 2), SenseInfo('01909978-v', 1), SenseInfo('00716130-v', 1), SenseInfo('02402409-v', 0), SenseInfo('00799798-v', 0), SenseInfo('00125633-v', 0) ],
"_uncle_n_of_rel" : [ SenseInfo('10736091-n', 6), SenseInfo('10736259-n', 1) ],
"_dime_n_1_rel" : [ SenseInfo('13390040-n', 2), SenseInfo('03198819-n', 0) ],
"_recession_n_1_rel" : [ SenseInfo('14013368-n', 1), SenseInfo('13872421-n', 0), SenseInfo('08429556-n', 0), SenseInfo('01249991-n', 0), SenseInfo('00057486-n', 0) ],
"_delirium_n_1_rel" : [ SenseInfo('14391876-n', 2), SenseInfo('14387202-n', 0) ],
"_resistor_n_1_rel" : [ SenseInfo('04079933-n', 7) ],
"_cook_v_up_rel" : [ SenseInfo('01665638-v', 9), SenseInfo('01664172-v', 9), SenseInfo('00322847-v', 6), SenseInfo('02576921-v', 0), SenseInfo('00323377-v', 0) ],
"_rocker_n_1_rel" : [ SenseInfo('10536021-n', 0), SenseInfo('10535881-n', 0), SenseInfo('10535706-n', 0), SenseInfo('04099969-n', 0), SenseInfo('04098795-n', 0), SenseInfo('04098710-n', 0), SenseInfo('04098513-n', 0) ],
"_hebrew_n_1_rel" : [ SenseInfo('06987124-n', 1), SenseInfo('09681351-n', 0) ],
"_compact_v_1_rel" : [ SenseInfo('01484027-v', 0), SenseInfo('01483779-v', 0), SenseInfo('01389329-v', 0), SenseInfo('01387786-v', 0) ],
"_lot_n_of_rel" : [ SenseInfo('13774404-n', 13), SenseInfo('08674970-n', 5), SenseInfo('08240169-n', 4), SenseInfo('14473222-n', 3), SenseInfo('03233423-n', 3), SenseInfo('07954731-n', 1), SenseInfo('10273669-n', 0), SenseInfo('13774404-n', 13), SenseInfo('08674970-n', 5), SenseInfo('08240169-n', 4), SenseInfo('14473222-n', 3), SenseInfo('03233423-n', 3), SenseInfo('07954731-n', 1), SenseInfo('10273669-n', 0), SenseInfo('13774404-n', 13), SenseInfo('08674970-n', 5), SenseInfo('08240169-n', 4), SenseInfo('14473222-n', 3), SenseInfo('03233423-n', 3), SenseInfo('07954731-n', 1), SenseInfo('10273669-n', 0), SenseInfo('13774404-n', 13), SenseInfo('08674970-n', 5), SenseInfo('08240169-n', 4), SenseInfo('14473222-n', 3), SenseInfo('03233423-n', 3), SenseInfo('07954731-n', 1), SenseInfo('10273669-n', 0), SenseInfo('13774404-n', 13), SenseInfo('08674970-n', 5), SenseInfo('08240169-n', 4), SenseInfo('14473222-n', 3), SenseInfo('03233423-n', 3), SenseInfo('07954731-n', 1), SenseInfo('10273669-n', 0), SenseInfo('13774404-n', 13), SenseInfo('08674970-n', 5), SenseInfo('08240169-n', 4), SenseInfo('14473222-n', 3), SenseInfo('03233423-n', 3), SenseInfo('07954731-n', 1), SenseInfo('10273669-n', 0), SenseInfo('13774404-n', 13), SenseInfo('08674970-n', 5), SenseInfo('08240169-n', 4), SenseInfo('14473222-n', 3), SenseInfo('03233423-n', 3), SenseInfo('07954731-n', 1), SenseInfo('10273669-n', 0), SenseInfo('13774404-n', 13), SenseInfo('08674970-n', 5), SenseInfo('08240169-n', 4), SenseInfo('14473222-n', 3), SenseInfo('03233423-n', 3), SenseInfo('07954731-n', 1), SenseInfo('10273669-n', 0), SenseInfo('13774404-n', 13), SenseInfo('08674970-n', 5), SenseInfo('08240169-n', 4), SenseInfo('14473222-n', 3), SenseInfo('03233423-n', 3), SenseInfo('07954731-n', 1), SenseInfo('10273669-n', 0) ],
"_genealogical_a_1_rel" : [ SenseInfo('03067329-a', 0) ],
"_metal_n_1_rel" : [ SenseInfo('14625458-n', 21), SenseInfo('14586769-n', 0), SenseInfo('14625458-n', 21), SenseInfo('14586769-n', 0), SenseInfo('14625458-n', 21), SenseInfo('14586769-n', 0) ],
"_apart+from_p_rel" : [  ],
"_look_v_in_rel" : [ SenseInfo('02130524-v', 274), SenseInfo('02133435-v', 126), SenseInfo('00033599-v', 25), SenseInfo('02153709-v', 8), SenseInfo('02693319-v', 1), SenseInfo('02549581-v', 1), SenseInfo('00929362-v', 1), SenseInfo('00720063-v', 1), SenseInfo('02658447-v', 0), SenseInfo('00712708-v', 0), SenseInfo('02130524-v', 274), SenseInfo('02133435-v', 126), SenseInfo('00033599-v', 25), SenseInfo('02153709-v', 8), SenseInfo('02693319-v', 1), SenseInfo('02549581-v', 1), SenseInfo('00929362-v', 1), SenseInfo('00720063-v', 1), SenseInfo('02658447-v', 0), SenseInfo('00712708-v', 0), SenseInfo('02130524-v', 274), SenseInfo('02133435-v', 126), SenseInfo('00033599-v', 25), SenseInfo('02153709-v', 8), SenseInfo('02693319-v', 1), SenseInfo('02549581-v', 1), SenseInfo('00929362-v', 1), SenseInfo('00720063-v', 1), SenseInfo('02658447-v', 0), SenseInfo('00712708-v', 0) ],
"_test+market_v_1_rel" : [  ],
"_tortoise_n_1_rel" : [ SenseInfo('01670092-n', 0) ],
"_in+the+know_a_1_rel" : [  ],
"_revolt_v_2_rel" : [ SenseInfo('02583780-v', 0), SenseInfo('02194913-v', 0), SenseInfo('01808374-v', 0) ],
"_muddle_v_up_rel" : [ SenseInfo('01419867-v', 0), SenseInfo('00620532-v', 0) ],
"_honesty_n_1_rel" : [ SenseInfo('04871374-n', 2), SenseInfo('11891541-n', 0) ],
"_match_n_1_rel" : [ SenseInfo('03728437-n', 4), SenseInfo('07470671-n', 1), SenseInfo('03728982-n', 1), SenseInfo('03728811-n', 1), SenseInfo('13596673-n', 0), SenseInfo('09900981-n', 0), SenseInfo('09626238-n', 0), SenseInfo('07988857-n', 0), SenseInfo('05696020-n', 0) ],
"_desert_v_1_rel" : [ SenseInfo('00614057-v', 7), SenseInfo('02584097-v', 2), SenseInfo('01842367-v', 0) ],
"_accountability_n_1_rel" : [ SenseInfo('04669828-n', 0) ],
"_unchristian_a_1_rel" : [ SenseInfo('00411481-a', 0), SenseInfo('00411481-a', 0) ],
"_loaf_n_1_rel" : [ SenseInfo('07683786-n', 3), SenseInfo('07649582-n', 0) ],
"_torment_n_1_rel" : [ SenseInfo('14333433-n', 1), SenseInfo('07496755-n', 1), SenseInfo('07495551-n', 1), SenseInfo('07519040-n', 0), SenseInfo('07420354-n', 0), SenseInfo('00425278-n', 0) ],
"_babble_v_about_rel" : [ SenseInfo('01065630-v', 3), SenseInfo('01037650-v', 2), SenseInfo('02187922-v', 0), SenseInfo('00937208-v', 0) ],
"_hamlet_n_1_rel" : [ SenseInfo('08226978-n', 1), SenseInfo('09599891-n', 0), SenseInfo('08672738-n', 0) ],
"_spaceship_n_1_rel" : [ SenseInfo('04304215-n', 0) ],
"_white_n_1_rel" : [ SenseInfo('09638875-n', 10), SenseInfo('04960729-n', 6), SenseInfo('11384291-n', 0), SenseInfo('11384159-n', 0), SenseInfo('11384022-n', 0), SenseInfo('11383917-n', 0), SenseInfo('11383767-n', 0), SenseInfo('11383546-n', 0), SenseInfo('09478355-n', 0), SenseInfo('07841037-n', 0), SenseInfo('04579986-n', 0), SenseInfo('03357081-n', 0), SenseInfo('09638875-n', 10), SenseInfo('04960729-n', 6), SenseInfo('11384291-n', 0), SenseInfo('11384159-n', 0), SenseInfo('11384022-n', 0), SenseInfo('11383917-n', 0), SenseInfo('11383767-n', 0), SenseInfo('11383546-n', 0), SenseInfo('09478355-n', 0), SenseInfo('07841037-n', 0), SenseInfo('04579986-n', 0), SenseInfo('03357081-n', 0) ],
"_philosopher_n_1_rel" : [ SenseInfo('10423589-n', 15), SenseInfo('10425946-n', 1) ],
"_overall_p_rel" : [ SenseInfo('01102451-a', 9), SenseInfo('01582946-a', 8), SenseInfo('03863108-n', 4), SenseInfo('03863262-n', 0) ],
"_entail_v_1_rel" : [ SenseInfo('02635189-v', 7), SenseInfo('02634808-v', 3), SenseInfo('02363234-v', 0), SenseInfo('02635189-v', 7), SenseInfo('02634808-v', 3), SenseInfo('02363234-v', 0), SenseInfo('02635189-v', 7), SenseInfo('02634808-v', 3), SenseInfo('02363234-v', 0) ],
"_prod_n_1_rel" : [ SenseInfo('07252378-n', 0), SenseInfo('04007664-n', 0) ],
"_expand_v_1_rel" : [ SenseInfo('02077148-v', 7), SenseInfo('00257269-v', 6), SenseInfo('00541163-v', 4), SenseInfo('00310386-v', 4), SenseInfo('00264386-v', 3), SenseInfo('00955601-v', 0), SenseInfo('00540946-v', 0) ],
"_cradle_v_1_rel" : [ SenseInfo('01222177-v', 3), SenseInfo('02540262-v', 0), SenseInfo('01876735-v', 0), SenseInfo('01555648-v', 0), SenseInfo('01536663-v', 0), SenseInfo('01076514-v', 0) ],
"_iron_v_1_rel" : [ SenseInfo('01390833-v', 2) ],
"_herewith_a_1_rel" : [  ],
"_smoky_a_1_rel" : [ SenseInfo('02233927-a', 0), SenseInfo('02398928-a', 0), SenseInfo('02233927-a', 0), SenseInfo('02398928-a', 0), SenseInfo('02233927-a', 0), SenseInfo('02398928-a', 0) ],
"_go_v_after_rel" : [ SenseInfo('01835496-v', 343), SenseInfo('02372605-v', 95), SenseInfo('01848718-v', 49), SenseInfo('00149583-v', 29), SenseInfo('02653862-v', 14), SenseInfo('02721284-v', 10), SenseInfo('02685951-v', 10), SenseInfo('00341560-v', 10), SenseInfo('00359916-v', 9), SenseInfo('02618001-v', 7), SenseInfo('02176268-v', 3), SenseInfo('01525666-v', 3), SenseInfo('01192773-v', 3), SenseInfo('00539110-v', 3), SenseInfo('02618149-v', 2), SenseInfo('02617798-v', 2), SenseInfo('00358431-v', 2), SenseInfo('02737876-v', 1), SenseInfo('02729819-v', 1), SenseInfo('01864230-v', 1), SenseInfo('01076615-v', 1), SenseInfo('02700772-v', 0), SenseInfo('02700666-v', 0), SenseInfo('02700455-v', 0), SenseInfo('02686471-v', 0), SenseInfo('02659763-v', 0), SenseInfo('01318849-v', 0), SenseInfo('01192992-v', 0), SenseInfo('00676267-v', 0), SenseInfo('00434374-v', 0) ],
"_moderate_a_1_rel" : [ SenseInfo('01531375-a', 10), SenseInfo('01509367-a', 2), SenseInfo('02402078-a', 0), SenseInfo('01531375-a', 10), SenseInfo('01509367-a', 2), SenseInfo('02402078-a', 0) ],
"_crease_n_1_rel" : [ SenseInfo('13907415-n', 0), SenseInfo('13905792-n', 0), SenseInfo('03628728-n', 0) ],
"_affront_v_1_rel" : [ SenseInfo('00848420-v', 1) ],
"_infold_v_1_rel" : [  ],
"_concrete_a_1_rel" : [ SenseInfo('00013160-a', 9), SenseInfo('02260477-a', 0), SenseInfo('00013160-a', 9), SenseInfo('02260477-a', 0) ],
"_geneticist_n_1_rel" : [ SenseInfo('10126424-n', 1) ],
"_steamship_n_1_rel" : [ SenseInfo('04309348-n', 1) ],
"_lapel_n_1_rel" : [ SenseInfo('03642444-n', 1) ],
"_s40_n_1_rel" : [  ],
"_make_v_up-of_rel" : [ SenseInfo('02560585-v', 508), SenseInfo('00120316-v', 459), SenseInfo('01617192-v', 243), SenseInfo('00770437-v', 85), SenseInfo('01645601-v', 78), SenseInfo('01621555-v', 52), SenseInfo('00730758-v', 33), SenseInfo('01646075-v', 17), SenseInfo('01640207-v', 16), SenseInfo('02289295-v', 14), SenseInfo('01619014-v', 14), SenseInfo('02621395-v', 12), SenseInfo('02022162-v', 12), SenseInfo('02674708-v', 10), SenseInfo('01653873-v', 9), SenseInfo('01755816-v', 8), SenseInfo('01654628-v', 5), SenseInfo('00556855-v', 5), SenseInfo('00012267-v', 5), SenseInfo('02396716-v', 4), SenseInfo('02355596-v', 4), SenseInfo('02020590-v', 4), SenseInfo('00665476-v', 4), SenseInfo('02582921-v', 3), SenseInfo('02598483-v', 2), SenseInfo('01733477-v', 2), SenseInfo('00276068-v', 2), SenseInfo('02075857-v', 1), SenseInfo('00074038-v', 1), SenseInfo('02748759-v', 0), SenseInfo('02748627-v', 0), SenseInfo('02745332-v', 0), SenseInfo('02665124-v', 0), SenseInfo('02621133-v', 0), SenseInfo('02134050-v', 0), SenseInfo('02051031-v', 0), SenseInfo('02021532-v', 0), SenseInfo('01755504-v', 0), SenseInfo('01664172-v', 0), SenseInfo('01428578-v', 0), SenseInfo('00891038-v', 0), SenseInfo('00838524-v', 0), SenseInfo('00698256-v', 0), SenseInfo('00698104-v', 0), SenseInfo('00562182-v', 0), SenseInfo('00562067-v', 0), SenseInfo('00545953-v', 0), SenseInfo('00107369-v', 0), SenseInfo('00072012-v', 0) ],
"_secretary_n_of_rel" : [ SenseInfo('10570019-n', 14), SenseInfo('10569744-n', 14), SenseInfo('10521928-n', 0), SenseInfo('04164868-n', 0), SenseInfo('10570019-n', 14), SenseInfo('10569744-n', 14), SenseInfo('10521928-n', 0), SenseInfo('04164868-n', 0) ],
"_wrench_n_1_rel" : [ SenseInfo('14299070-n', 0), SenseInfo('07351909-n', 0), SenseInfo('04606574-n', 0) ],
"_reincarnation_n_1_rel" : [ SenseInfo('10518003-n', 0), SenseInfo('07321247-n', 0), SenseInfo('06191212-n', 0) ],
"_squeak_n_1_rel" : [ SenseInfo('07395623-n', 1), SenseInfo('00061014-n', 0) ],
"_sunbird_n_1_rel" : [  ],
"_firm_a_1_rel" : [ SenseInfo('01990653-a', 12), SenseInfo('01151740-a', 6), SenseInfo('00842199-a', 6), SenseInfo('02130272-a', 4), SenseInfo('02302366-a', 2), SenseInfo('02291336-a', 2), SenseInfo('02094388-a', 2), SenseInfo('01171076-a', 1), SenseInfo('01059711-a', 0), SenseInfo('00959244-a', 0), SenseInfo('01990653-a', 12), SenseInfo('01151740-a', 6), SenseInfo('00842199-a', 6), SenseInfo('02130272-a', 4), SenseInfo('02302366-a', 2), SenseInfo('02291336-a', 2), SenseInfo('02094388-a', 2), SenseInfo('01171076-a', 1), SenseInfo('01059711-a', 0), SenseInfo('00959244-a', 0), SenseInfo('01990653-a', 12), SenseInfo('01151740-a', 6), SenseInfo('00842199-a', 6), SenseInfo('02130272-a', 4), SenseInfo('02302366-a', 2), SenseInfo('02291336-a', 2), SenseInfo('02094388-a', 2), SenseInfo('01171076-a', 1), SenseInfo('01059711-a', 0), SenseInfo('00959244-a', 0), SenseInfo('01990653-a', 12), SenseInfo('01151740-a', 6), SenseInfo('00842199-a', 6), SenseInfo('02130272-a', 4), SenseInfo('02302366-a', 2), SenseInfo('02291336-a', 2), SenseInfo('02094388-a', 2), SenseInfo('01171076-a', 1), SenseInfo('01059711-a', 0), SenseInfo('00959244-a', 0) ],
"_fuel_v_1_rel" : [ SenseInfo('02338386-v', 2), SenseInfo('02356420-v', 0), SenseInfo('02237024-v', 0), SenseInfo('01762178-v', 0) ],
"_dent_n_1_rel" : [ SenseInfo('11413661-n', 1), SenseInfo('13904843-n', 0), SenseInfo('04693384-n', 0) ],
"_merge_v_1_rel" : [ SenseInfo('00367685-v', 10), SenseInfo('00394813-v', 3), SenseInfo('00243124-v', 0) ],
"_graphical_a_1_rel" : [ SenseInfo('02736808-a', 1), SenseInfo('02285278-a', 0), SenseInfo('02736808-a', 1), SenseInfo('02285278-a', 0) ],
"_flood_n_of_rel" : [ SenseInfo('11454591-n', 5), SenseInfo('13775706-n', 2), SenseInfo('03365374-n', 2), SenseInfo('00329819-n', 2), SenseInfo('01257542-n', 1), SenseInfo('07403030-n', 0) ],
"_iceblock_n_1_rel" : [  ],
"_symbolical_a_1_rel" : [ SenseInfo('02806907-a', 0), SenseInfo('01982186-a', 0) ],
"_unwed_a_1_rel" : [ SenseInfo('01482751-a', 1), SenseInfo('01482751-a', 1) ],
"_bolivian_n_1_rel" : [ SenseInfo('09694664-n', 0) ],
"_midfielder_n_1_rel" : [  ],
"_bid_n_1_rel" : [ SenseInfo('07168131-n', 1), SenseInfo('00786887-n', 1), SenseInfo('07165086-n', 0), SenseInfo('06737112-n', 0), SenseInfo('07168131-n', 1), SenseInfo('00786887-n', 1), SenseInfo('07165086-n', 0), SenseInfo('06737112-n', 0) ],
"_buffet_n_1_rel" : [ SenseInfo('02912065-n', 1), SenseInfo('07576182-n', 0), SenseInfo('04247736-n', 0) ],
"_swiss_a_1_rel" : [ SenseInfo('02960975-a', 3) ],
"_least_a_1_rel" : [ SenseInfo('01556061-a', 2), SenseInfo('01556061-a', 2), SenseInfo('01556061-a', 2) ],
"_put_v_forward_rel" : [ SenseInfo('01494310-v', 138), SenseInfo('01493741-v', 98), SenseInfo('00981276-v', 28), SenseInfo('01160370-v', 6), SenseInfo('02271137-v', 3), SenseInfo('00673448-v', 2), SenseInfo('02111499-v', 0), SenseInfo('01706375-v', 0), SenseInfo('00735571-v', 0) ],
"_tundra_a_1_rel" : [ SenseInfo('09463226-n', 0) ],
"_thrive_v_1_rel" : [ SenseInfo('00310386-v', 3), SenseInfo('02342800-v', 1) ],
"_carver_n_1_rel" : [ SenseInfo('10885603-n', 0), SenseInfo('10789963-n', 0), SenseInfo('10566072-n', 0), SenseInfo('09985470-n', 0) ],
"_undemanding_a_1_rel" : [ SenseInfo('00711528-a', 0), SenseInfo('00711528-a', 0) ],
"_choke_v_off_rel" : [ SenseInfo('00002724-v', 8), SenseInfo('01570562-v', 2), SenseInfo('01570744-v', 1), SenseInfo('00077950-v', 1), SenseInfo('00077698-v', 1), SenseInfo('02529669-v', 0), SenseInfo('02423999-v', 0), SenseInfo('01478603-v', 0), SenseInfo('01476180-v', 0), SenseInfo('00391203-v', 0), SenseInfo('00391021-v', 0), SenseInfo('00358431-v', 0), SenseInfo('00173159-v', 0), SenseInfo('00077606-v', 0) ],
"_mat_n_1_rel" : [ SenseInfo('03727837-n', 4), SenseInfo('03728318-n', 1), SenseInfo('03727946-n', 1), SenseInfo('09348827-n', 0), SenseInfo('06701251-n', 0), SenseInfo('04956110-n', 0), SenseInfo('03728131-n', 0) ],
"_succession_n_of_rel" : [ SenseInfo('05044822-n', 3), SenseInfo('08459908-n', 1), SenseInfo('01010458-n', 1), SenseInfo('13562862-n', 0), SenseInfo('00082754-n', 0) ],
"_less+than_a_1_rel" : [  ],
"_savor_v_of_rel" : [ SenseInfo('01820302-v', 4), SenseInfo('02194286-v', 1), SenseInfo('02193974-v', 1), SenseInfo('02194138-v', 0) ],
"_shop_v_around-for_rel" : [ SenseInfo('02325968-v', 7), SenseInfo('02466134-v', 1), SenseInfo('02326355-v', 0), SenseInfo('00841986-v', 0) ],
"_marvel_v_at_rel" : [ SenseInfo('00925490-v', 4), SenseInfo('00925735-v', 1) ],
"_antique_a_1_rel" : [ SenseInfo('01639446-a', 2), SenseInfo('00974159-a', 2), SenseInfo('01638962-a', 0) ],
"_teach_v_1_rel" : [ SenseInfo('00829107-v', 86), SenseInfo('00273734-v', 2), SenseInfo('00829107-v', 86), SenseInfo('00273734-v', 2), SenseInfo('00829107-v', 86), SenseInfo('00273734-v', 2), SenseInfo('00829107-v', 86), SenseInfo('00273734-v', 2), SenseInfo('00829107-v', 86), SenseInfo('00273734-v', 2) ],
"_do-it-yourselfer_n_1_rel" : [  ],
"_leaven_v_with_rel" : [ SenseInfo('01975587-v', 0), SenseInfo('01975587-v', 0) ],
"_shudder_v_1_rel" : [ SenseInfo('00014201-v', 5), SenseInfo('01888946-v', 3), SenseInfo('00014201-v', 5), SenseInfo('01888946-v', 3) ],
"_explode_v_1_rel" : [ SenseInfo('00306723-v', 14), SenseInfo('00306017-v', 5), SenseInfo('00719062-v', 4), SenseInfo('00306539-v', 3), SenseInfo('01565795-v', 0), SenseInfo('01055661-v', 0), SenseInfo('00862467-v', 0), SenseInfo('00665335-v', 0), SenseInfo('00306298-v', 0), SenseInfo('00157623-v', 0) ],
"_up_p_sel_rel" : [ SenseInfo('00096333-r', 79), SenseInfo('02490170-a', 8), SenseInfo('00186925-a', 5), SenseInfo('00154966-v', 2), SenseInfo('02487108-a', 1), SenseInfo('02485488-a', 1), SenseInfo('00097011-r', 0), SenseInfo('00096921-r', 0), SenseInfo('00096760-r', 0), SenseInfo('00096636-r', 0), SenseInfo('01845002-a', 0), SenseInfo('01208146-a', 0), SenseInfo('01091995-a', 0), SenseInfo('01004245-a', 0) ],
"_irresolute_a_1_rel" : [ SenseInfo('01992149-a', 1) ],
"_collisional_a_1_rel" : [  ],
"_cheyenne_a_1_rel" : [ SenseInfo('09159675-n', 2), SenseInfo('06908700-n', 1), SenseInfo('09651968-n', 0) ],
"_oh+dear_a_1_rel" : [  ],
"_glitter_v_1_rel" : [ SenseInfo('02162947-v', 4) ],
"_malfunction_v_1_rel" : [ SenseInfo('01525295-v', 0) ],
"_clean_v_up_rel" : [ SenseInfo('01532589-v', 16), SenseInfo('00177714-v', 3), SenseInfo('01533442-v', 2), SenseInfo('00035758-v', 1), SenseInfo('02741960-v', 0), SenseInfo('01608951-v', 0), SenseInfo('01608706-v', 0), SenseInfo('01532434-v', 0), SenseInfo('00180837-v', 0), SenseInfo('00177861-v', 0), SenseInfo('01532589-v', 16), SenseInfo('00177714-v', 3), SenseInfo('01533442-v', 2), SenseInfo('00035758-v', 1), SenseInfo('02741960-v', 0), SenseInfo('01608951-v', 0), SenseInfo('01608706-v', 0), SenseInfo('01532434-v', 0), SenseInfo('00180837-v', 0), SenseInfo('00177861-v', 0) ],
"_steep_a_1_rel" : [ SenseInfo('01144887-a', 5), SenseInfo('01534282-a', 0), SenseInfo('01206164-a', 0), SenseInfo('01144887-a', 5), SenseInfo('01534282-a', 0), SenseInfo('01206164-a', 0), SenseInfo('01144887-a', 5), SenseInfo('01534282-a', 0), SenseInfo('01206164-a', 0), SenseInfo('01144887-a', 5), SenseInfo('01534282-a', 0), SenseInfo('01206164-a', 0), SenseInfo('01144887-a', 5), SenseInfo('01534282-a', 0), SenseInfo('01206164-a', 0) ],
"_expel_v_1_rel" : [ SenseInfo('02501738-v', 3), SenseInfo('02401809-v', 0), SenseInfo('01108951-v', 0), SenseInfo('00104868-v', 0) ],
"_alike_a_1_rel" : [ SenseInfo('01410606-a', 2) ],
"_dance_n_1_rel" : [ SenseInfo('07020538-n', 15), SenseInfo('08253141-n', 3), SenseInfo('00428270-n', 1), SenseInfo('07448717-n', 0) ],
"_biosphere_n_1_rel" : [ SenseInfo('08499504-n', 0) ],
"_dissuade_v_from_rel" : [ SenseInfo('00770141-v', 3), SenseInfo('00770141-v', 3) ],
"_classic_n_1_rel" : [ SenseInfo('03038595-n', 2), SenseInfo('09926426-n', 1) ],
"_firelight_n_1_rel" : [ SenseInfo('11457841-n', 2) ],
"_gravity_n_1_rel" : [ SenseInfo('11464143-n', 2), SenseInfo('04647478-n', 1), SenseInfo('07512147-n', 0) ],
"_totality_n_1_rel" : [ SenseInfo('14461231-n', 1), SenseInfo('04765851-n', 0), SenseInfo('04353803-n', 0) ],
"_etcher_n_1_rel" : [ SenseInfo('10064977-n', 0) ],
"_scent_n_of_rel" : [ SenseInfo('05714466-n', 3), SenseInfo('05714161-n', 1), SenseInfo('04980008-n', 1) ],
"_veterinary_a_1_rel" : [ SenseInfo('03128816-a', 1) ],
"_fume_v_1_rel" : [ SenseInfo('01795333-v', 2), SenseInfo('02767922-v', 0), SenseInfo('02127100-v', 0), SenseInfo('00068627-v', 0), SenseInfo('01795333-v', 2), SenseInfo('02767922-v', 0), SenseInfo('02127100-v', 0), SenseInfo('00068627-v', 0) ],
"_farmwife_n_1_rel" : [  ],
"_semi_n_1_rel" : [ SenseInfo('07467393-n', 0), SenseInfo('04467665-n', 0), SenseInfo('04172342-n', 0) ],
"_shy_a_of_rel" : [ SenseInfo('00339941-a', 0), SenseInfo('02337558-a', 0), SenseInfo('00162863-a', 0), SenseInfo('00339941-a', 0), SenseInfo('02337558-a', 0), SenseInfo('00162863-a', 0), SenseInfo('00339941-a', 0), SenseInfo('02337558-a', 0), SenseInfo('00162863-a', 0), SenseInfo('00339941-a', 0), SenseInfo('02337558-a', 0), SenseInfo('00162863-a', 0), SenseInfo('00339941-a', 0), SenseInfo('02337558-a', 0), SenseInfo('00162863-a', 0) ],
"_shunt_n_1_rel" : [ SenseInfo('05548521-n', 5), SenseInfo('04211001-n', 1), SenseInfo('04210858-n', 0) ],
"_weirdy_n_1_rel" : [ SenseInfo('09976917-n', 0) ],
"_prohibit_v_from_rel" : [ SenseInfo('00795863-v', 8) ],
"_bagel_n_1_rel" : [ SenseInfo('07693725-n', 0) ],
"_trust_v_1_rel" : [ SenseInfo('00688377-v', 16), SenseInfo('02481819-v', 5), SenseInfo('00721098-v', 4), SenseInfo('01826723-v', 2), SenseInfo('02349212-v', 1), SenseInfo('02265726-v', 0), SenseInfo('00688377-v', 16), SenseInfo('02481819-v', 5), SenseInfo('00721098-v', 4), SenseInfo('01826723-v', 2), SenseInfo('02349212-v', 1), SenseInfo('02265726-v', 0), SenseInfo('00688377-v', 16), SenseInfo('02481819-v', 5), SenseInfo('00721098-v', 4), SenseInfo('01826723-v', 2), SenseInfo('02349212-v', 1), SenseInfo('02265726-v', 0), SenseInfo('00688377-v', 16), SenseInfo('02481819-v', 5), SenseInfo('00721098-v', 4), SenseInfo('01826723-v', 2), SenseInfo('02349212-v', 1), SenseInfo('02265726-v', 0) ],
"_pulsate_v_1_rel" : [ SenseInfo('01879251-v', 1), SenseInfo('01879579-v', 0), SenseInfo('01623027-v', 0) ],
"_finch_n_1_rel" : [ SenseInfo('01529672-n', 0) ],
"_draw_v_on_rel" : [ SenseInfo('01448100-v', 13), SenseInfo('02293148-v', 10), SenseInfo('01582645-v', 10), SenseInfo('00730758-v', 10), SenseInfo('01995211-v', 9), SenseInfo('01690294-v', 7), SenseInfo('01854132-v', 6), SenseInfo('00987071-v', 6), SenseInfo('00675901-v', 6), SenseInfo('01760300-v', 5), SenseInfo('01199009-v', 5), SenseInfo('02088107-v', 4), SenseInfo('02311387-v', 3), SenseInfo('01078050-v', 3), SenseInfo('01643297-v', 2), SenseInfo('00556593-v', 2), SenseInfo('02097800-v', 1), SenseInfo('01690816-v', 1), SenseInfo('01643464-v', 1), SenseInfo('01243148-v', 1), SenseInfo('02742107-v', 0), SenseInfo('02628832-v', 0), SenseInfo('02483564-v', 0), SenseInfo('02103162-v', 0), SenseInfo('01539063-v', 0), SenseInfo('01505254-v', 0), SenseInfo('01359432-v', 0), SenseInfo('01243298-v', 0), SenseInfo('01212230-v', 0), SenseInfo('01115190-v', 0), SenseInfo('00476965-v', 0), SenseInfo('00430808-v', 0), SenseInfo('00327982-v', 0), SenseInfo('00197590-v', 0), SenseInfo('00143338-v', 0), SenseInfo('00097029-v', 0) ],
"_ripple_v_cause_rel" : [ SenseInfo('02040054-v', 2), SenseInfo('02187922-v', 1) ],
"_intensive_a_1_rel" : [ SenseInfo('01512275-a', 1), SenseInfo('02858941-a', 0), SenseInfo('01514374-a', 0), SenseInfo('01512275-a', 1), SenseInfo('02858941-a', 0), SenseInfo('01514374-a', 0) ],
"_model_v_1_rel" : [ SenseInfo('01743784-v', 1), SenseInfo('01697027-v', 1), SenseInfo('02142775-v', 0), SenseInfo('02142626-v', 0), SenseInfo('01722980-v', 0), SenseInfo('01697406-v', 0) ],
"_convict_n_1_rel" : [ SenseInfo('09962966-n', 1), SenseInfo('09963159-n', 0) ],
"_electrospray_n_1_rel" : [  ],
"_limit_v_to_rel" : [ SenseInfo('00233335-v', 23), SenseInfo('00235368-v', 6), SenseInfo('00947077-v', 0) ],
"_babylonian_a_1_rel" : [ SenseInfo('02656539-a', 0) ],
"_protrusion_n_1_rel" : [ SenseInfo('13894434-n', 0), SenseInfo('00407090-n', 0) ],
"_valueless_a_1_rel" : [ SenseInfo('02504046-a', 1) ],
"_gameboy_n_1_rel" : [  ],
"_transcribe_v_into_rel" : [ SenseInfo('00995103-v', 1), SenseInfo('00994682-v', 1), SenseInfo('01708113-v', 0), SenseInfo('00994895-v', 0), SenseInfo('00556389-v', 0), SenseInfo('00995103-v', 1), SenseInfo('00994682-v', 1), SenseInfo('01708113-v', 0), SenseInfo('00994895-v', 0), SenseInfo('00556389-v', 0) ],
"_skip_v_out_rel" : [ SenseInfo('00616498-v', 7), SenseInfo('02613860-v', 1), SenseInfo('01966861-v', 1), SenseInfo('02010698-v', 0), SenseInfo('01892734-v', 0), SenseInfo('01515924-v', 0) ],
"_stealthy_a_1_rel" : [ SenseInfo('02088974-a', 1), SenseInfo('02088974-a', 1), SenseInfo('02088974-a', 1), SenseInfo('02088974-a', 1) ],
"_stink_v_up_rel" : [ SenseInfo('02674173-v', 2), SenseInfo('02124106-v', 0) ],
"_distortion_n_of_rel" : [ SenseInfo('07433973-n', 2), SenseInfo('13867276-n', 1), SenseInfo('11420139-n', 1), SenseInfo('11511765-n', 0), SenseInfo('00751529-n', 0), SenseInfo('00073713-n', 0) ],
"_trouble_n_1_rel" : [ SenseInfo('05687338-n', 21), SenseInfo('07372565-n', 16), SenseInfo('07289014-n', 11), SenseInfo('00623862-n', 8), SenseInfo('07524242-n', 1), SenseInfo('14046751-n', 0) ],
"_set_v_out_rel" : [ SenseInfo('01494310-v', 30), SenseInfo('00699815-v', 29), SenseInfo('00947077-v', 12), SenseInfo('01062395-v', 10), SenseInfo('00298896-v', 9), SenseInfo('01607445-v', 6), SenseInfo('00406243-v', 5), SenseInfo('00298556-v', 5), SenseInfo('01711749-v', 3), SenseInfo('01970646-v', 2), SenseInfo('01706129-v', 2), SenseInfo('01567275-v', 2), SenseInfo('01628899-v', 1), SenseInfo('00442669-v', 1), SenseInfo('01744888-v', 0), SenseInfo('01613239-v', 0), SenseInfo('01530273-v', 0), SenseInfo('01247322-v', 0), SenseInfo('01115006-v', 0), SenseInfo('00673448-v', 0), SenseInfo('00408085-v', 0), SenseInfo('00407848-v', 0), SenseInfo('00296178-v', 0), SenseInfo('00056188-v', 0), SenseInfo('00038849-v', 0), SenseInfo('01494310-v', 30), SenseInfo('00699815-v', 29), SenseInfo('00947077-v', 12), SenseInfo('01062395-v', 10), SenseInfo('00298896-v', 9), SenseInfo('01607445-v', 6), SenseInfo('00406243-v', 5), SenseInfo('00298556-v', 5), SenseInfo('01711749-v', 3), SenseInfo('01970646-v', 2), SenseInfo('01706129-v', 2), SenseInfo('01567275-v', 2), SenseInfo('01628899-v', 1), SenseInfo('00442669-v', 1), SenseInfo('01744888-v', 0), SenseInfo('01613239-v', 0), SenseInfo('01530273-v', 0), SenseInfo('01247322-v', 0), SenseInfo('01115006-v', 0), SenseInfo('00673448-v', 0), SenseInfo('00408085-v', 0), SenseInfo('00407848-v', 0), SenseInfo('00296178-v', 0), SenseInfo('00056188-v', 0), SenseInfo('00038849-v', 0) ],
"_4WD_n_1_rel" : [ SenseInfo('03389761-n', 0), SenseInfo('03389611-n', 0), SenseInfo('03389761-n', 0), SenseInfo('03389611-n', 0) ],
"_link_v_up_rel" : [ SenseInfo('00713167-v', 14), SenseInfo('01354673-v', 3), SenseInfo('02622234-v', 1), SenseInfo('01492052-v', 0), SenseInfo('00713167-v', 14), SenseInfo('01354673-v', 3), SenseInfo('02622234-v', 1), SenseInfo('01492052-v', 0) ],
"_diff_v_1_rel" : [  ],
"_lock_v_on_rel" : [ SenseInfo('01348174-v', 8), SenseInfo('01510827-v', 7), SenseInfo('00219775-v', 4), SenseInfo('01606736-v', 2), SenseInfo('01606018-v', 2), SenseInfo('01810320-v', 1), SenseInfo('01347678-v', 1), SenseInfo('02050865-v', 0), SenseInfo('01655347-v', 0), SenseInfo('01348174-v', 8), SenseInfo('01510827-v', 7), SenseInfo('00219775-v', 4), SenseInfo('01606736-v', 2), SenseInfo('01606018-v', 2), SenseInfo('01810320-v', 1), SenseInfo('01347678-v', 1), SenseInfo('02050865-v', 0), SenseInfo('01655347-v', 0), SenseInfo('01348174-v', 8), SenseInfo('01510827-v', 7), SenseInfo('00219775-v', 4), SenseInfo('01606736-v', 2), SenseInfo('01606018-v', 2), SenseInfo('01810320-v', 1), SenseInfo('01347678-v', 1), SenseInfo('02050865-v', 0), SenseInfo('01655347-v', 0), SenseInfo('01348174-v', 8), SenseInfo('01510827-v', 7), SenseInfo('00219775-v', 4), SenseInfo('01606736-v', 2), SenseInfo('01606018-v', 2), SenseInfo('01810320-v', 1), SenseInfo('01347678-v', 1), SenseInfo('02050865-v', 0), SenseInfo('01655347-v', 0) ],
"_valor_n_1_rel" : [ SenseInfo('04857738-n', 7) ],
"_commentary_n_1_rel" : [ SenseInfo('06762711-n', 4) ],
"_perpetual_a_1_rel" : [ SenseInfo('01755024-a', 1), SenseInfo('00595299-a', 0) ],
"_slack_v_off_rel" : [ SenseInfo('02464342-v', 0), SenseInfo('00616361-v', 0), SenseInfo('00536535-v', 0), SenseInfo('00441212-v', 0), SenseInfo('00440580-v', 0), SenseInfo('00245289-v', 0), SenseInfo('00245059-v', 0), SenseInfo('00214624-v', 0) ],
"_european_a_1_rel" : [ SenseInfo('02968325-a', 14) ],
"_cranky_a_1_rel" : [ SenseInfo('02292421-a', 1), SenseInfo('01136541-a', 0), SenseInfo('02292421-a', 1), SenseInfo('01136541-a', 0), SenseInfo('02292421-a', 1), SenseInfo('01136541-a', 0) ],
"_cheer_v_1_rel" : [ SenseInfo('01817938-v', 1), SenseInfo('00858568-v', 1), SenseInfo('00859325-v', 0), SenseInfo('00859153-v', 0), SenseInfo('00858781-v', 0), SenseInfo('01817938-v', 1), SenseInfo('00858568-v', 1), SenseInfo('00859325-v', 0), SenseInfo('00859153-v', 0), SenseInfo('00858781-v', 0) ],
"_cabin_n_1_rel" : [ SenseInfo('02932227-n', 5), SenseInfo('02932400-n', 3), SenseInfo('02932019-n', 0), SenseInfo('02932227-n', 5), SenseInfo('02932400-n', 3), SenseInfo('02932019-n', 0) ],
"_basic_x_deg_rel" : [ SenseInfo('01855764-a', 45), SenseInfo('02295298-a', 17), SenseInfo('06902909-n', 0), SenseInfo('02800793-n', 0), SenseInfo('01011753-a', 0), SenseInfo('00026168-a', 0) ],
"_dear_n_1_rel" : [ SenseInfo('09849598-n', 4), SenseInfo('10243872-n', 0), SenseInfo('09849598-n', 4), SenseInfo('10243872-n', 0) ],
"_deck_n_1_rel" : [ SenseInfo('03167666-n', 6), SenseInfo('03167978-n', 2), SenseInfo('07956721-n', 1), SenseInfo('03168107-n', 0), SenseInfo('03167666-n', 6), SenseInfo('03167978-n', 2), SenseInfo('07956721-n', 1), SenseInfo('03168107-n', 0) ],
"_advantageous_a_1_rel" : [ SenseInfo('00064479-a', 1), SenseInfo('00931833-a', 0), SenseInfo('00064479-a', 1), SenseInfo('00931833-a', 0) ],
"_thaw_n_1_rel" : [ SenseInfo('13566535-n', 1), SenseInfo('11482140-n', 1), SenseInfo('07443539-n', 0) ],
"_navigate_v_1_rel" : [ SenseInfo('01846320-v', 2), SenseInfo('01933305-v', 0), SenseInfo('01932704-v', 0) ],
"_scrub_v_off_rel" : [ SenseInfo('01251228-v', 4), SenseInfo('00036780-v', 1), SenseInfo('02477755-v', 0) ],
"_consistent_a_1_rel" : [ SenseInfo('00576680-a', 7), SenseInfo('01867996-a', 0), SenseInfo('00464513-a', 0), SenseInfo('01200095-a', 0), SenseInfo('00576680-a', 7), SenseInfo('01867996-a', 0), SenseInfo('00464513-a', 0), SenseInfo('01200095-a', 0) ],
"_pin_v_1_rel" : [ SenseInfo('01207149-v', 2), SenseInfo('01368264-v', 1), SenseInfo('01444723-v', 0), SenseInfo('01121621-v', 0) ],
"_train_v_1_rel" : [ SenseInfo('00603298-v', 14), SenseInfo('00602805-v', 9), SenseInfo('02553697-v', 5), SenseInfo('02387034-v', 5), SenseInfo('02388403-v', 1), SenseInfo('01151110-v', 1), SenseInfo('00833702-v', 1), SenseInfo('00100044-v', 1), SenseInfo('02509552-v', 0), SenseInfo('01936537-v', 0), SenseInfo('01453969-v', 0), SenseInfo('00603298-v', 14), SenseInfo('00602805-v', 9), SenseInfo('02553697-v', 5), SenseInfo('02387034-v', 5), SenseInfo('02388403-v', 1), SenseInfo('01151110-v', 1), SenseInfo('00833702-v', 1), SenseInfo('00100044-v', 1), SenseInfo('02509552-v', 0), SenseInfo('01936537-v', 0), SenseInfo('01453969-v', 0), SenseInfo('00603298-v', 14), SenseInfo('00602805-v', 9), SenseInfo('02553697-v', 5), SenseInfo('02387034-v', 5), SenseInfo('02388403-v', 1), SenseInfo('01151110-v', 1), SenseInfo('00833702-v', 1), SenseInfo('00100044-v', 1), SenseInfo('02509552-v', 0), SenseInfo('01936537-v', 0), SenseInfo('01453969-v', 0) ],
"_rerun_n_1_rel" : [ SenseInfo('06620063-n', 0), SenseInfo('06620063-n', 0) ],
"_expressible_a_by_rel" : [ SenseInfo('00943363-a', 1) ],
"_out-of-court_a_1_rel" : [  ],
"_along+with_p_rel" : [  ],
"_softness_n_1_rel" : [ SenseInfo('04938228-n', 2), SenseInfo('14547369-n', 0), SenseInfo('14522570-n', 0), SenseInfo('14489859-n', 0), SenseInfo('04990877-n', 0), SenseInfo('04956419-n', 0), SenseInfo('04910973-n', 0), SenseInfo('04704346-n', 0), SenseInfo('04668139-n', 0), SenseInfo('04638857-n', 0) ],
"_maneuver_n_1_rel" : [ SenseInfo('00959992-n', 5), SenseInfo('05905152-n', 0), SenseInfo('00556313-n', 0), SenseInfo('00168237-n', 0), SenseInfo('00059552-n', 0) ],
"_legislation_n_1_rel" : [ SenseInfo('06535222-n', 10), SenseInfo('01125693-n', 2), SenseInfo('06535222-n', 10), SenseInfo('01125693-n', 2) ],
"_bikini_n_1_rel" : [ SenseInfo('08839296-n', 0), SenseInfo('02837789-n', 0) ],
"_establishment_n_of_rel" : [ SenseInfo('00237078-n', 10), SenseInfo('08053576-n', 4), SenseInfo('08164585-n', 3), SenseInfo('03297735-n', 3), SenseInfo('08075847-n', 1), SenseInfo('13476267-n', 0), SenseInfo('05826291-n', 0) ],
"_jingle_n_1_rel" : [ SenseInfo('07385998-n', 0), SenseInfo('06379253-n', 0) ],
"_downward_a_1_rel" : [ SenseInfo('02486248-a', 3), SenseInfo('02492981-a', 1) ],
"_disappointing_a_for_rel" : [ SenseInfo('02082611-a', 1), SenseInfo('02082611-a', 1) ],
"_toddler_n_1_rel" : [ SenseInfo('10714465-n', 0) ],
"_deductible_n_1_rel" : [ SenseInfo('13273550-n', 0), SenseInfo('06393424-n', 0) ],
"_good+heavens_a_1_rel" : [  ],
"_pka2_n_1_rel" : [  ],
"_portable_a_1_rel" : [ SenseInfo('01525776-a', 3), SenseInfo('01291589-a', 0) ],
"_A$_n_1_rel" : [  ],
"_relative_n_1_rel" : [ SenseInfo('10235549-n', 8), SenseInfo('01328302-n', 2) ],
"_coldness_n_1_rel" : [ SenseInfo('05725676-n', 1), SenseInfo('04629604-n', 1), SenseInfo('05015117-n', 0) ],
"_sublease_v_1_rel" : [ SenseInfo('02209261-v', 0) ],
"_catalyze_v_cause_rel" : [ SenseInfo('00267519-v', 0) ],
"_possess_v_1_rel" : [ SenseInfo('02632167-v', 31), SenseInfo('02204692-v', 12), SenseInfo('02647311-v', 2) ],
"_glimpse_n_of_rel" : [ SenseInfo('00877625-n', 6), SenseInfo('05934396-n', 1), SenseInfo('06802444-n', 0) ],
"_ablation_n_1_rel" : [ SenseInfo('00393369-n', 2), SenseInfo('13423489-n', 0) ],
"_melt_v_dir_rel" : [ SenseInfo('00444629-v', 3), SenseInfo('00376106-v', 2), SenseInfo('00254486-v', 2), SenseInfo('00395841-v', 1), SenseInfo('00224651-v', 0), SenseInfo('00223928-v', 0) ],
"_genealogic_a_1_rel" : [ SenseInfo('03067329-a', 0) ],
"_nativity_n_1_rel" : [ SenseInfo('07320302-n', 0), SenseInfo('06192908-n', 0) ],
"_proof_n_of_rel" : [ SenseInfo('05824739-n', 10), SenseInfo('06647614-n', 8), SenseInfo('13780180-n', 0), SenseInfo('06590885-n', 0), SenseInfo('04011130-n', 0), SenseInfo('00153961-n', 0), SenseInfo('05824739-n', 10), SenseInfo('06647614-n', 8), SenseInfo('13780180-n', 0), SenseInfo('06590885-n', 0), SenseInfo('04011130-n', 0), SenseInfo('00153961-n', 0) ],
"_hurry_n_1_rel" : [ SenseInfo('14451189-n', 6), SenseInfo('05060189-n', 2), SenseInfo('00555648-n', 1) ],
"_oral_a_1_rel" : [ SenseInfo('02284169-a', 6), SenseInfo('02771485-a', 0), SenseInfo('01665184-a', 0), SenseInfo('00110252-a', 0), SenseInfo('02284169-a', 6), SenseInfo('02771485-a', 0), SenseInfo('01665184-a', 0), SenseInfo('00110252-a', 0) ],
"_bear_v_2_rel" : [ SenseInfo('02630871-v', 23), SenseInfo('00056930-v', 17), SenseInfo('00668099-v', 13), SenseInfo('01432601-v', 10), SenseInfo('01652139-v', 6), SenseInfo('02301825-v', 5), SenseInfo('02700867-v', 4), SenseInfo('02291708-v', 4), SenseInfo('00047745-v', 1), SenseInfo('02518161-v', 0), SenseInfo('02302220-v', 0), SenseInfo('01601234-v', 0), SenseInfo('00059019-v', 0) ],
"_coincidental_a_1_rel" : [ SenseInfo('02378496-a', 0) ],
"_second+base_n_1_rel" : [ SenseInfo('04164406-n', 1), SenseInfo('00723783-n', 0) ],
"_lily+of+the+valley_n_1_rel" : [ SenseInfo('12471544-n', 0) ],
"_cringe_v_1_rel" : [ SenseInfo('02061069-v', 2), SenseInfo('02063771-v', 1) ],
"_hard_a_on_rel" : [ SenseInfo('00744916-a', 37), SenseInfo('01155354-a', 20), SenseInfo('01150915-a', 15), SenseInfo('02322512-a', 5), SenseInfo('00836544-a', 3), SenseInfo('02286294-a', 0), SenseInfo('01157762-a', 0), SenseInfo('01156505-a', 0), SenseInfo('01299173-a', 0), SenseInfo('01158974-a', 0), SenseInfo('01127302-a', 0), SenseInfo('01069715-a', 0) ],
"_feeling_n_of_rel" : [ SenseInfo('00026192-n', 49), SenseInfo('05916739-n', 28), SenseInfo('14526182-n', 16), SenseInfo('05721500-n', 8), SenseInfo('05722427-n', 1), SenseInfo('05707718-n', 0), SenseInfo('00026192-n', 49), SenseInfo('05916739-n', 28), SenseInfo('14526182-n', 16), SenseInfo('05721500-n', 8), SenseInfo('05722427-n', 1), SenseInfo('05707718-n', 0) ],
"_react_v_1_rel" : [ SenseInfo('00717358-v', 22), SenseInfo('02378623-v', 2), SenseInfo('00446885-v', 2) ],
"_milieu_n_1_rel" : [ SenseInfo('14513944-n', 1) ],
"_tea_n_1_rel" : [ SenseInfo('07933274-n', 5), SenseInfo('07575510-n', 1), SenseInfo('12929783-n', 0), SenseInfo('08254741-n', 0), SenseInfo('07932841-n', 0) ],
"_invertebrate_n_1_rel" : [ SenseInfo('01905661-n', 0) ],
"_destination_n_1_rel" : [ SenseInfo('08567877-n', 2), SenseInfo('05981768-n', 1), SenseInfo('06787150-n', 0) ],
"_procession_n_1_rel" : [ SenseInfo('07327288-n', 0), SenseInfo('00296585-n', 0), SenseInfo('00282050-n', 0) ],
"_bacon_n_1_rel" : [ SenseInfo('07670433-n', 4), SenseInfo('10830731-n', 0), SenseInfo('10830456-n', 0) ],
"_prophecy_n_1_rel" : [ SenseInfo('05775407-n', 2), SenseInfo('06750154-n', 1) ],
"_immediate_a_1_rel" : [ SenseInfo('01731882-a', 11), SenseInfo('00449079-a', 6), SenseInfo('00770316-a', 3), SenseInfo('01579853-a', 2), SenseInfo('00978754-a', 0), SenseInfo('01731882-a', 11), SenseInfo('00449079-a', 6), SenseInfo('00770316-a', 3), SenseInfo('01579853-a', 2), SenseInfo('00978754-a', 0) ],
"_cycling_n_1_rel" : [ SenseInfo('00451370-n', 0) ],
"_obscure_a_1_rel" : [ SenseInfo('00431004-a', 4), SenseInfo('00534250-a', 2), SenseInfo('02089377-a', 0), SenseInfo('01122595-a', 0), SenseInfo('00581637-a', 0), SenseInfo('00567860-a', 0) ],
"_tar_v_1_rel" : [ SenseInfo('01272457-v', 0) ],
"_net_n_1_rel" : [ SenseInfo('03580615-n', 4), SenseInfo('03819994-n', 2), SenseInfo('13258362-n', 0), SenseInfo('03820318-n', 0), SenseInfo('03820154-n', 0), SenseInfo('03819595-n', 0) ],
"_tie-up_n_1_rel" : [ SenseInfo('13930385-n', 0), SenseInfo('07366145-n', 0), SenseInfo('13930385-n', 0), SenseInfo('07366145-n', 0) ],
"_crocked_a_1_rel" : [ SenseInfo('00798103-a', 1) ],
"_lord_n_1_rel" : [ SenseInfo('09536363-n', 10), SenseInfo('10388440-n', 3), SenseInfo('10271677-n', 1) ],
"_dq+stranded+left_a_1_rel" : [  ],
"_cheap_a_1_rel" : [ SenseInfo('00934199-a', 9), SenseInfo('02393791-a', 1), SenseInfo('02346013-a', 1), SenseInfo('01113114-a', 0), SenseInfo('00934199-a', 9), SenseInfo('02393791-a', 1), SenseInfo('02346013-a', 1), SenseInfo('01113114-a', 0), SenseInfo('00934199-a', 9), SenseInfo('02393791-a', 1), SenseInfo('02346013-a', 1), SenseInfo('01113114-a', 0), SenseInfo('00934199-a', 9), SenseInfo('02393791-a', 1), SenseInfo('02346013-a', 1), SenseInfo('01113114-a', 0) ],
"_gum_n_1_rel" : [ SenseInfo('07599998-n', 1), SenseInfo('05304932-n', 1), SenseInfo('14898470-n', 0), SenseInfo('14702875-n', 0), SenseInfo('12334520-n', 0), SenseInfo('12334293-n', 0) ],
"_vindicate_v_1_rel" : [ SenseInfo('00896141-v', 1), SenseInfo('00904690-v', 0), SenseInfo('00904494-v', 0) ],
"_romanian_n_1_rel" : [ SenseInfo('09728285-n', 0), SenseInfo('06968343-n', 0) ],
"_tentacle_n_1_rel" : [ SenseInfo('05195175-n', 1), SenseInfo('02584643-n', 0) ],
"_cushion_n_1_rel" : [ SenseInfo('04198797-n', 1), SenseInfo('03151800-n', 0), SenseInfo('03151500-n', 0) ],
"_herb_n_1_rel" : [ SenseInfo('12205694-n', 1), SenseInfo('07811416-n', 1) ],
"_museum_n_of_rel" : [ SenseInfo('03800563-n', 3), SenseInfo('03800563-n', 3) ],
"_elevator_n_1_rel" : [ SenseInfo('03281145-n', 5), SenseInfo('03281524-n', 0) ],
"_education_n_1_rel" : [ SenseInfo('00883297-n', 34), SenseInfo('05984287-n', 10), SenseInfo('05753564-n', 6), SenseInfo('00611433-n', 5), SenseInfo('04921900-n', 3), SenseInfo('08132637-n', 0) ],
"_sovereignty_n_1_rel" : [ SenseInfo('13992935-n', 1), SenseInfo('14443532-n', 0), SenseInfo('05198321-n', 0) ],
"_index_v_1_rel" : [ SenseInfo('02472817-v', 1), SenseInfo('02354112-v', 0), SenseInfo('00702434-v', 0) ],
"_caution_v_1_rel" : [ SenseInfo('00871195-v', 6), SenseInfo('00871195-v', 6), SenseInfo('00871195-v', 6), SenseInfo('00871195-v', 6) ],
"_pick_v_off_rel" : [ SenseInfo('00676450-v', 13), SenseInfo('01382083-v', 4), SenseInfo('00842772-v', 2), SenseInfo('01647131-v', 1), SenseInfo('00178102-v', 1), SenseInfo('00177714-v', 1), SenseInfo('02321648-v', 0), SenseInfo('02287209-v', 0), SenseInfo('01452546-v', 0), SenseInfo('01442578-v', 0), SenseInfo('01243474-v', 0), SenseInfo('01174294-v', 0) ],
"_burner_n_1_rel" : [ SenseInfo('02923129-n', 1), SenseInfo('02923331-n', 0) ],
"_skip_v_over_rel" : [ SenseInfo('00616498-v', 7), SenseInfo('02613860-v', 1), SenseInfo('01966861-v', 1), SenseInfo('02010698-v', 0), SenseInfo('01892734-v', 0), SenseInfo('01515924-v', 0) ],
"_swap_v_for_rel" : [ SenseInfo('02259005-v', 1), SenseInfo('01839030-v', 0), SenseInfo('02259005-v', 1), SenseInfo('01839030-v', 0) ],
"_eyebrow_n_1_rel" : [ SenseInfo('05313535-n', 3) ],
"_hawthorn_n_1_rel" : [ SenseInfo('12626353-n', 0) ],
"_procreation_n_1_rel" : [ SenseInfo('00849523-n', 5) ],
"_balk_v_at_rel" : [ SenseInfo('02583545-v', 3) ],
"_frisian_a_1_rel" : [ SenseInfo('02732405-a', 0) ],
"_disallow_v_1_rel" : [ SenseInfo('00795863-v', 1) ],
"_besides_a_1_rel" : [  ],
"_consultancy_n_1_rel" : [ SenseInfo('00631712-n', 0) ],
"_least-squares_a_1_rel" : [  ],
"_alumnus_n_1_rel" : [ SenseInfo('09786338-n', 0), SenseInfo('09786338-n', 0), SenseInfo('09786338-n', 0) ],
"_intimacy_n_1_rel" : [ SenseInfo('04655442-n', 1), SenseInfo('13931889-n', 0), SenseInfo('07530124-n', 0) ],
"_take_v_2_rel" : [ SenseInfo('02599636-v', 92), SenseInfo('02267989-v', 74), SenseInfo('01999798-v', 73), SenseInfo('01214265-v', 50), SenseInfo('00524682-v', 38), SenseInfo('00624476-v', 36), SenseInfo('02077656-v', 32), SenseInfo('02205272-v', 28), SenseInfo('01842690-v', 26), SenseInfo('00674607-v', 26), SenseInfo('02236124-v', 25), SenseInfo('02394183-v', 22), SenseInfo('00734054-v', 22), SenseInfo('02627934-v', 21), SenseInfo('02109045-v', 21), SenseInfo('01002740-v', 16), SenseInfo('00173338-v', 16), SenseInfo('01156834-v', 15), SenseInfo('00669762-v', 15), SenseInfo('02209936-v', 14), SenseInfo('02206619-v', 13), SenseInfo('01982395-v', 10), SenseInfo('02236624-v', 8), SenseInfo('00523095-v', 7), SenseInfo('00599992-v', 6), SenseInfo('00756076-v', 5), SenseInfo('02075857-v', 4), SenseInfo('01151110-v', 4), SenseInfo('00557404-v', 4), SenseInfo('02717102-v', 2), SenseInfo('02208537-v', 2), SenseInfo('02209745-v', 1), SenseInfo('02208118-v', 1), SenseInfo('02201138-v', 1), SenseInfo('01427127-v', 1), SenseInfo('00758333-v', 1), SenseInfo('02741546-v', 0), SenseInfo('02701210-v', 0), SenseInfo('02590253-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01100830-v', 0), SenseInfo('00087736-v', 0), SenseInfo('02599636-v', 92), SenseInfo('02267989-v', 74), SenseInfo('01999798-v', 73), SenseInfo('01214265-v', 50), SenseInfo('00524682-v', 38), SenseInfo('00624476-v', 36), SenseInfo('02077656-v', 32), SenseInfo('02205272-v', 28), SenseInfo('01842690-v', 26), SenseInfo('00674607-v', 26), SenseInfo('02236124-v', 25), SenseInfo('02394183-v', 22), SenseInfo('00734054-v', 22), SenseInfo('02627934-v', 21), SenseInfo('02109045-v', 21), SenseInfo('01002740-v', 16), SenseInfo('00173338-v', 16), SenseInfo('01156834-v', 15), SenseInfo('00669762-v', 15), SenseInfo('02209936-v', 14), SenseInfo('02206619-v', 13), SenseInfo('01982395-v', 10), SenseInfo('02236624-v', 8), SenseInfo('00523095-v', 7), SenseInfo('00599992-v', 6), SenseInfo('00756076-v', 5), SenseInfo('02075857-v', 4), SenseInfo('01151110-v', 4), SenseInfo('00557404-v', 4), SenseInfo('02717102-v', 2), SenseInfo('02208537-v', 2), SenseInfo('02209745-v', 1), SenseInfo('02208118-v', 1), SenseInfo('02201138-v', 1), SenseInfo('01427127-v', 1), SenseInfo('00758333-v', 1), SenseInfo('02741546-v', 0), SenseInfo('02701210-v', 0), SenseInfo('02590253-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01100830-v', 0), SenseInfo('00087736-v', 0), SenseInfo('02599636-v', 92), SenseInfo('02267989-v', 74), SenseInfo('01999798-v', 73), SenseInfo('01214265-v', 50), SenseInfo('00524682-v', 38), SenseInfo('00624476-v', 36), SenseInfo('02077656-v', 32), SenseInfo('02205272-v', 28), SenseInfo('01842690-v', 26), SenseInfo('00674607-v', 26), SenseInfo('02236124-v', 25), SenseInfo('02394183-v', 22), SenseInfo('00734054-v', 22), SenseInfo('02627934-v', 21), SenseInfo('02109045-v', 21), SenseInfo('01002740-v', 16), SenseInfo('00173338-v', 16), SenseInfo('01156834-v', 15), SenseInfo('00669762-v', 15), SenseInfo('02209936-v', 14), SenseInfo('02206619-v', 13), SenseInfo('01982395-v', 10), SenseInfo('02236624-v', 8), SenseInfo('00523095-v', 7), SenseInfo('00599992-v', 6), SenseInfo('00756076-v', 5), SenseInfo('02075857-v', 4), SenseInfo('01151110-v', 4), SenseInfo('00557404-v', 4), SenseInfo('02717102-v', 2), SenseInfo('02208537-v', 2), SenseInfo('02209745-v', 1), SenseInfo('02208118-v', 1), SenseInfo('02201138-v', 1), SenseInfo('01427127-v', 1), SenseInfo('00758333-v', 1), SenseInfo('02741546-v', 0), SenseInfo('02701210-v', 0), SenseInfo('02590253-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01100830-v', 0), SenseInfo('00087736-v', 0), SenseInfo('02599636-v', 92), SenseInfo('02267989-v', 74), SenseInfo('01999798-v', 73), SenseInfo('01214265-v', 50), SenseInfo('00524682-v', 38), SenseInfo('00624476-v', 36), SenseInfo('02077656-v', 32), SenseInfo('02205272-v', 28), SenseInfo('01842690-v', 26), SenseInfo('00674607-v', 26), SenseInfo('02236124-v', 25), SenseInfo('02394183-v', 22), SenseInfo('00734054-v', 22), SenseInfo('02627934-v', 21), SenseInfo('02109045-v', 21), SenseInfo('01002740-v', 16), SenseInfo('00173338-v', 16), SenseInfo('01156834-v', 15), SenseInfo('00669762-v', 15), SenseInfo('02209936-v', 14), SenseInfo('02206619-v', 13), SenseInfo('01982395-v', 10), SenseInfo('02236624-v', 8), SenseInfo('00523095-v', 7), SenseInfo('00599992-v', 6), SenseInfo('00756076-v', 5), SenseInfo('02075857-v', 4), SenseInfo('01151110-v', 4), SenseInfo('00557404-v', 4), SenseInfo('02717102-v', 2), SenseInfo('02208537-v', 2), SenseInfo('02209745-v', 1), SenseInfo('02208118-v', 1), SenseInfo('02201138-v', 1), SenseInfo('01427127-v', 1), SenseInfo('00758333-v', 1), SenseInfo('02741546-v', 0), SenseInfo('02701210-v', 0), SenseInfo('02590253-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01100830-v', 0), SenseInfo('00087736-v', 0), SenseInfo('02599636-v', 92), SenseInfo('02267989-v', 74), SenseInfo('01999798-v', 73), SenseInfo('01214265-v', 50), SenseInfo('00524682-v', 38), SenseInfo('00624476-v', 36), SenseInfo('02077656-v', 32), SenseInfo('02205272-v', 28), SenseInfo('01842690-v', 26), SenseInfo('00674607-v', 26), SenseInfo('02236124-v', 25), SenseInfo('02394183-v', 22), SenseInfo('00734054-v', 22), SenseInfo('02627934-v', 21), SenseInfo('02109045-v', 21), SenseInfo('01002740-v', 16), SenseInfo('00173338-v', 16), SenseInfo('01156834-v', 15), SenseInfo('00669762-v', 15), SenseInfo('02209936-v', 14), SenseInfo('02206619-v', 13), SenseInfo('01982395-v', 10), SenseInfo('02236624-v', 8), SenseInfo('00523095-v', 7), SenseInfo('00599992-v', 6), SenseInfo('00756076-v', 5), SenseInfo('02075857-v', 4), SenseInfo('01151110-v', 4), SenseInfo('00557404-v', 4), SenseInfo('02717102-v', 2), SenseInfo('02208537-v', 2), SenseInfo('02209745-v', 1), SenseInfo('02208118-v', 1), SenseInfo('02201138-v', 1), SenseInfo('01427127-v', 1), SenseInfo('00758333-v', 1), SenseInfo('02741546-v', 0), SenseInfo('02701210-v', 0), SenseInfo('02590253-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01100830-v', 0), SenseInfo('00087736-v', 0) ],
"_draft_v_in_rel" : [ SenseInfo('01701634-v', 4), SenseInfo('01097500-v', 2), SenseInfo('01683582-v', 0) ],
"_explanation_n_of_rel" : [ SenseInfo('06738281-n', 28), SenseInfo('05793000-n', 8), SenseInfo('07232421-n', 0), SenseInfo('06738281-n', 28), SenseInfo('05793000-n', 8), SenseInfo('07232421-n', 0), SenseInfo('06738281-n', 28), SenseInfo('05793000-n', 8), SenseInfo('07232421-n', 0) ],
"_pushbutton_n_1_rel" : [  ],
"_hooklet_n_1_rel" : [  ],
"_unsettle_v_1_rel" : [ SenseInfo('01783881-v', 0), SenseInfo('01783881-v', 0), SenseInfo('01783881-v', 0), SenseInfo('01783881-v', 0), SenseInfo('01783881-v', 0), SenseInfo('01783881-v', 0) ],
"_shove_v_1_rel" : [ SenseInfo('01871680-v', 6), SenseInfo('01584701-v', 5), SenseInfo('02094569-v', 0), SenseInfo('01871680-v', 6), SenseInfo('01584701-v', 5), SenseInfo('02094569-v', 0) ],
"_posh_a_1_rel" : [ SenseInfo('00975778-a', 0), SenseInfo('00975778-a', 0), SenseInfo('00975778-a', 0) ],
"_perceive_v_1_rel" : [ SenseInfo('02106506-v', 26), SenseInfo('00591519-v', 9), SenseInfo('02106506-v', 26), SenseInfo('00591519-v', 9), SenseInfo('02106506-v', 26), SenseInfo('00591519-v', 9) ],
"_psalm_n_1_rel" : [ SenseInfo('06466787-n', 0), SenseInfo('06466677-n', 0) ],
"_membership_n_1_rel" : [ SenseInfo('08400965-n', 10), SenseInfo('13931627-n', 9) ],
"_riven_a_1_rel" : [  ],
"_precarious_a_1_rel" : [ SenseInfo('00823192-a', 4), SenseInfo('02060496-a', 1), SenseInfo('02095037-a', 0) ],
"_book_n_of_rel" : [ SenseInfo('06410904-n', 46), SenseInfo('02870092-n', 10), SenseInfo('06636524-n', 2), SenseInfo('07009946-n', 1), SenseInfo('13404248-n', 0), SenseInfo('07954441-n', 0), SenseInfo('07954211-n', 0), SenseInfo('06461609-n', 0), SenseInfo('06431740-n', 0), SenseInfo('06394865-n', 0), SenseInfo('02870526-n', 0) ],
"_vibration_n_of_rel" : [ SenseInfo('00345926-n', 1), SenseInfo('14004572-n', 0), SenseInfo('07345166-n', 0), SenseInfo('04727883-n', 0) ],
"_rend_v_1_rel" : [ SenseInfo('01573276-v', 2) ],
"_tragic_a_1_rel" : [ SenseInfo('01363153-a', 7), SenseInfo('02973241-a', 3), SenseInfo('01363153-a', 7), SenseInfo('02973241-a', 3), SenseInfo('01363153-a', 7), SenseInfo('02973241-a', 3) ],
"_radiation_n_1_rel" : [ SenseInfo('11499284-n', 31), SenseInfo('01252918-n', 15), SenseInfo('14308472-n', 0), SenseInfo('13545184-n', 0), SenseInfo('07439883-n', 0), SenseInfo('05503555-n', 0), SenseInfo('00705580-n', 0) ],
"_unpliant_a_1_rel" : [  ],
"_passionate_a_1_rel" : [ SenseInfo('01725712-a', 7), SenseInfo('01725712-a', 7) ],
"_bindery_n_1_rel" : [ SenseInfo('02840515-n', 0) ],
"_piece_n_of_rel" : [ SenseInfo('03932203-n', 23), SenseInfo('03932499-n', 13), SenseInfo('09385911-n', 8), SenseInfo('07037465-n', 7), SenseInfo('07309457-n', 4), SenseInfo('06269396-n', 2), SenseInfo('03343853-n', 2), SenseInfo('07654667-n', 1), SenseInfo('05084889-n', 1), SenseInfo('03838535-n', 1), SenseInfo('15246353-n', 0), SenseInfo('13286524-n', 0), SenseInfo('03716327-n', 0), SenseInfo('03932203-n', 23), SenseInfo('03932499-n', 13), SenseInfo('09385911-n', 8), SenseInfo('07037465-n', 7), SenseInfo('07309457-n', 4), SenseInfo('06269396-n', 2), SenseInfo('03343853-n', 2), SenseInfo('07654667-n', 1), SenseInfo('05084889-n', 1), SenseInfo('03838535-n', 1), SenseInfo('15246353-n', 0), SenseInfo('13286524-n', 0), SenseInfo('03716327-n', 0), SenseInfo('03932203-n', 23), SenseInfo('03932499-n', 13), SenseInfo('09385911-n', 8), SenseInfo('07037465-n', 7), SenseInfo('07309457-n', 4), SenseInfo('06269396-n', 2), SenseInfo('03343853-n', 2), SenseInfo('07654667-n', 1), SenseInfo('05084889-n', 1), SenseInfo('03838535-n', 1), SenseInfo('15246353-n', 0), SenseInfo('13286524-n', 0), SenseInfo('03716327-n', 0) ],
"_curl_n_1_rel" : [ SenseInfo('13875970-n', 0), SenseInfo('10918119-n', 0), SenseInfo('05257737-n', 0) ],
"_at+most_x_deg_rel" : [ SenseInfo('00104528-r', 2) ],
"_kerf_n_1_rel" : [  ],
"_dusting_n_of_rel" : [  ],
"_jurisdiction_n_1_rel" : [ SenseInfo('05198427-n', 4), SenseInfo('08590369-n', 1), SenseInfo('05198427-n', 4), SenseInfo('08590369-n', 1) ],
"_embarrassed_a_1_rel" : [ SenseInfo('00531628-a', 1), SenseInfo('00154270-a', 0) ],
"_unhurried_a_1_rel" : [ SenseInfo('01271700-a', 1), SenseInfo('01737084-a', 0), SenseInfo('01271700-a', 1), SenseInfo('01737084-a', 0), SenseInfo('01271700-a', 1), SenseInfo('01737084-a', 0) ],
"_isolation_n_of_rel" : [ SenseInfo('14414715-n', 3), SenseInfo('07502576-n', 1), SenseInfo('01202029-n', 1), SenseInfo('13503673-n', 0), SenseInfo('01239717-n', 0) ],
"_basics_n_1_rel" : [ SenseInfo('06639563-n', 0), SenseInfo('05871362-n', 0), SenseInfo('06639563-n', 0), SenseInfo('05871362-n', 0) ],
"_cursor_n_1_rel" : [ SenseInfo('03150795-n', 0) ],
"_penmanship_n_1_rel" : [ SenseInfo('06403969-n', 0) ],
"_elephant_n_1_rel" : [ SenseInfo('02503517-n', 3), SenseInfo('06881662-n', 0) ],
"_profession_n_1_rel" : [ SenseInfo('08112096-n', 7), SenseInfo('00609953-n', 5), SenseInfo('06732925-n', 0), SenseInfo('06685040-n', 0) ],
"_way_n_to_rel" : [ SenseInfo('04928903-n', 183), SenseInfo('00172710-n', 61), SenseInfo('08679972-n', 40), SenseInfo('13939604-n', 28), SenseInfo('00415676-n', 19), SenseInfo('04564698-n', 16), SenseInfo('00312691-n', 12), SenseInfo('13777764-n', 10), SenseInfo('05084733-n', 7), SenseInfo('05791764-n', 3), SenseInfo('05839910-n', 1), SenseInfo('13285973-n', 0), SenseInfo('04928903-n', 183), SenseInfo('00172710-n', 61), SenseInfo('08679972-n', 40), SenseInfo('13939604-n', 28), SenseInfo('00415676-n', 19), SenseInfo('04564698-n', 16), SenseInfo('00312691-n', 12), SenseInfo('13777764-n', 10), SenseInfo('05084733-n', 7), SenseInfo('05791764-n', 3), SenseInfo('05839910-n', 1), SenseInfo('13285973-n', 0) ],
"_opposed_a_to_rel" : [ SenseInfo('01662756-a', 1) ],
"_mushroom_v_1_rel" : [ SenseInfo('01382437-v', 0), SenseInfo('00231445-v', 0) ],
"_standard_n_1_rel" : [ SenseInfo('07260623-n', 11), SenseInfo('05924920-n', 11), SenseInfo('13617952-n', 0), SenseInfo('13373214-n', 0), SenseInfo('04301242-n', 0), SenseInfo('04301140-n', 0), SenseInfo('07260623-n', 11), SenseInfo('05924920-n', 11), SenseInfo('13617952-n', 0), SenseInfo('13373214-n', 0), SenseInfo('04301242-n', 0), SenseInfo('04301140-n', 0), SenseInfo('07260623-n', 11), SenseInfo('05924920-n', 11), SenseInfo('13617952-n', 0), SenseInfo('13373214-n', 0), SenseInfo('04301242-n', 0), SenseInfo('04301140-n', 0) ],
"_paste_v_on_rel" : [ SenseInfo('01332205-v', 5), SenseInfo('01412644-v', 0), SenseInfo('01332599-v', 0) ],
"_high+time_a_expl-for_rel" : [  ],
"_unclear_a_1_rel" : [ SenseInfo('00698088-a', 0), SenseInfo('00430191-a', 0), SenseInfo('01405523-a', 0), SenseInfo('00698088-a', 0), SenseInfo('00430191-a', 0), SenseInfo('01405523-a', 0), SenseInfo('00698088-a', 0), SenseInfo('00430191-a', 0), SenseInfo('01405523-a', 0), SenseInfo('00698088-a', 0), SenseInfo('00430191-a', 0), SenseInfo('01405523-a', 0) ],
"_attract_v_1_rel" : [ SenseInfo('01505254-v', 23), SenseInfo('01807882-v', 4), SenseInfo('01350025-v', 0) ],
"_refundable_a_1_rel" : [  ],
"_poke_n_1_rel" : [ SenseInfo('11855553-n', 0), SenseInfo('09993252-n', 0), SenseInfo('04122825-n', 0), SenseInfo('00334935-n', 0), SenseInfo('00134780-n', 0) ],
"_cardboard_n_1_rel" : [ SenseInfo('14799601-n', 1) ],
"_obsessed_a_with_rel" : [ SenseInfo('00544478-a', 1), SenseInfo('00599468-a', 0) ],
"_comb_v_2_rel" : [ SenseInfo('01596645-v', 1), SenseInfo('01319193-v', 1), SenseInfo('00038365-v', 1) ],
"_blame_v_for_rel" : [ SenseInfo('00842538-v', 12), SenseInfo('00842772-v', 9), SenseInfo('00727991-v', 4), SenseInfo('00842538-v', 12), SenseInfo('00842772-v', 9), SenseInfo('00727991-v', 4) ],
"_hippo_n_1_rel" : [ SenseInfo('08707145-n', 0), SenseInfo('02398521-n', 0) ],
"_oscaradjective_a_1_rel" : [  ],
"_eucalyptus_n_1_rel" : [ SenseInfo('12335351-n', 0), SenseInfo('12334891-n', 0) ],
"_pint_n_1_rel" : [ SenseInfo('13621850-n', 0), SenseInfo('13620404-n', 0), SenseInfo('13619307-n', 0) ],
"_sterling_n_pound_rel" : [ SenseInfo('13385080-n', 0) ],
"_commons_n_1_rel" : [ SenseInfo('08615374-n', 1), SenseInfo('08615374-n', 1) ],
"_parity_n_1_rel" : [ SenseInfo('14047171-n', 0), SenseInfo('13790133-n', 0), SenseInfo('13625482-n', 0), SenseInfo('06105314-n', 0), SenseInfo('04748426-n', 0) ],
"_sneaker_n_1_rel" : [ SenseInfo('03472535-n', 2), SenseInfo('10091012-n', 0) ],
"_arousal_n_1_rel" : [ SenseInfo('00242808-n', 1), SenseInfo('14023997-n', 0), SenseInfo('05678745-n', 0), SenseInfo('00853835-n', 0) ],
"_ill_a_1_rel" : [ SenseInfo('02541302-a', 4), SenseInfo('01162267-a', 1), SenseInfo('01128010-a', 1), SenseInfo('01246004-a', 0), SenseInfo('00178126-a', 0), SenseInfo('02541302-a', 4), SenseInfo('01162267-a', 1), SenseInfo('01128010-a', 1), SenseInfo('01246004-a', 0), SenseInfo('00178126-a', 0) ],
"_equivalent_a_to_rel" : [ SenseInfo('00890351-a', 0) ],
"_sadness_n_1_rel" : [ SenseInfo('07532440-n', 2), SenseInfo('13989051-n', 0), SenseInfo('04631470-n', 0) ],
"_nail_v_down_rel" : [ SenseInfo('01357831-v', 8), SenseInfo('01215137-v', 2), SenseInfo('01401772-v', 1), SenseInfo('02524897-v', 0), SenseInfo('02522581-v', 0), SenseInfo('02287380-v', 0), SenseInfo('01117484-v', 0) ],
"_gallop_v_cause_rel" : [ SenseInfo('01959927-v', 8), SenseInfo('01960643-v', 3), SenseInfo('01960296-v', 0) ],
"_treatment_n_of_rel" : [ SenseInfo('00658082-n', 28), SenseInfo('01134861-n', 25), SenseInfo('04929976-n', 4), SenseInfo('07138085-n', 2) ],
"_radial_n_1_rel" : [ SenseInfo('04040247-n', 0) ],
"_intercede_v_1_rel" : [ SenseInfo('00760956-v', 1) ],
"_thief_n_1_rel" : [ SenseInfo('10707804-n', 10) ],
"_camp_v_1_rel" : [ SenseInfo('02653996-v', 7), SenseInfo('01514248-v', 0), SenseInfo('00525805-v', 0) ],
"_unthaw_v_cause_rel" : [ SenseInfo('00376106-v', 1), SenseInfo('00376106-v', 1) ],
"_unforeseen_a_1_rel" : [ SenseInfo('00930765-a', 1), SenseInfo('00930765-a', 1) ],
"_pulse_v_1_rel" : [ SenseInfo('01879251-v', 1), SenseInfo('01623027-v', 1), SenseInfo('01879777-v', 0) ],
"_adjoin_v_1_rel" : [ SenseInfo('01466978-v', 3), SenseInfo('01205696-v', 0), SenseInfo('00183383-v', 0), SenseInfo('01466978-v', 3), SenseInfo('01205696-v', 0), SenseInfo('00183383-v', 0) ],
"_careless_a_with-about-of_rel" : [ SenseInfo('00311663-a', 3), SenseInfo('00150055-a', 1), SenseInfo('01194099-a', 0), SenseInfo('00311663-a', 3), SenseInfo('00150055-a', 1), SenseInfo('01194099-a', 0), SenseInfo('00311663-a', 3), SenseInfo('00150055-a', 1), SenseInfo('01194099-a', 0), SenseInfo('00311663-a', 3), SenseInfo('00150055-a', 1), SenseInfo('01194099-a', 0) ],
"_sufficient_a_for_rel" : [ SenseInfo('02335828-a', 30), SenseInfo('02335828-a', 30) ],
"_sully_v_1_rel" : [ SenseInfo('01537959-v', 0), SenseInfo('01537409-v', 0), SenseInfo('00846509-v', 0) ],
"_terraced_a_1_rel" : [  ],
"_safety_n_1_rel" : [ SenseInfo('14538472-n', 13), SenseInfo('08643933-n', 4), SenseInfo('03464467-n', 1), SenseInfo('00131090-n', 1), SenseInfo('03088164-n', 0), SenseInfo('00188620-n', 0) ],
"_argue_v_over_rel" : [ SenseInfo('00772189-v', 34), SenseInfo('00773432-v', 17), SenseInfo('00772640-v', 0) ],
"_asterisk_n_1_rel" : [ SenseInfo('06828389-n', 2) ],
"_usher_v_to_rel" : [ SenseInfo('02000547-v', 2) ],
"_wrap_v_1_rel" : [ SenseInfo('01283208-v', 5), SenseInfo('01522276-v', 4), SenseInfo('01580467-v', 1), SenseInfo('01562478-v', 0), SenseInfo('01283208-v', 5), SenseInfo('01522276-v', 4), SenseInfo('01580467-v', 1), SenseInfo('01562478-v', 0) ],
"_whortleberry_n_1_rel" : [ SenseInfo('12248574-n', 0), SenseInfo('07743224-n', 0) ],
"_discontent_n_1_rel" : [ SenseInfo('07538965-n', 2) ],
"_stag_n_1_rel" : [ SenseInfo('02431337-n', 0), SenseInfo('02430559-n', 0) ],
"_inference_n_1_rel" : [ SenseInfo('05774614-n', 6), SenseInfo('05774614-n', 6) ],
"_farther+on_p_rel" : [  ],
"_methylate_n_1_rel" : [  ],
"_oust_v_1_rel" : [ SenseInfo('02401809-v', 4), SenseInfo('02406449-v', 0) ],
"_draw_v_down_rel" : [ SenseInfo('01448100-v', 13), SenseInfo('02293148-v', 10), SenseInfo('01582645-v', 10), SenseInfo('00730758-v', 10), SenseInfo('01995211-v', 9), SenseInfo('01690294-v', 7), SenseInfo('01854132-v', 6), SenseInfo('00987071-v', 6), SenseInfo('00675901-v', 6), SenseInfo('01760300-v', 5), SenseInfo('01199009-v', 5), SenseInfo('02088107-v', 4), SenseInfo('02311387-v', 3), SenseInfo('01078050-v', 3), SenseInfo('01643297-v', 2), SenseInfo('00556593-v', 2), SenseInfo('02097800-v', 1), SenseInfo('01690816-v', 1), SenseInfo('01643464-v', 1), SenseInfo('01243148-v', 1), SenseInfo('02742107-v', 0), SenseInfo('02628832-v', 0), SenseInfo('02483564-v', 0), SenseInfo('02103162-v', 0), SenseInfo('01539063-v', 0), SenseInfo('01505254-v', 0), SenseInfo('01359432-v', 0), SenseInfo('01243298-v', 0), SenseInfo('01212230-v', 0), SenseInfo('01115190-v', 0), SenseInfo('00476965-v', 0), SenseInfo('00430808-v', 0), SenseInfo('00327982-v', 0), SenseInfo('00197590-v', 0), SenseInfo('00143338-v', 0), SenseInfo('00097029-v', 0) ],
"_preach_v_of_rel" : [ SenseInfo('00828003-v', 9), SenseInfo('00827730-v', 4) ],
"_stress_v_to_rel" : [ SenseInfo('01013367-v', 29), SenseInfo('00983333-v', 4), SenseInfo('01798452-v', 0), SenseInfo('01013367-v', 29), SenseInfo('00983333-v', 4), SenseInfo('01798452-v', 0) ],
"_in-state_a_1_rel" : [  ],
"_reed_n_1_rel" : [ SenseInfo('12136720-n', 0), SenseInfo('11256494-n', 0), SenseInfo('11256335-n', 0), SenseInfo('04066888-n', 0), SenseInfo('02817799-n', 0) ],
"_vary_v_cause_rel" : [ SenseInfo('00123170-v', 26), SenseInfo('02661252-v', 20), SenseInfo('02662297-v', 7), SenseInfo('00436879-v', 5) ],
"_bubble_n_1_rel" : [ SenseInfo('09229709-n', 6), SenseInfo('05907251-n', 0), SenseInfo('05896379-n', 0), SenseInfo('02909053-n', 0) ],
"_transgression_n_1_rel" : [ SenseInfo('00745005-n', 1), SenseInfo('11520435-n', 0), SenseInfo('00744862-n', 0) ],
"_insensitive_a_to_rel" : [ SenseInfo('02105375-a', 1), SenseInfo('02106761-a', 0) ],
"_delightful_a_1_rel" : [ SenseInfo('01807964-a', 11), SenseInfo('01807964-a', 11) ],
"_dexterous_a_1_rel" : [ SenseInfo('00062367-a', 1), SenseInfo('00062367-a', 1) ],
"_streetcar_n_1_rel" : [ SenseInfo('04335435-n', 3) ],
"_particularize_v_1_rel" : [ SenseInfo('01021973-v', 0) ],
"_weather_v_1_rel" : [ SenseInfo('02707251-v', 0), SenseInfo('02038278-v', 0), SenseInfo('01928283-v', 0), SenseInfo('00275088-v', 0) ],
"_blast_n_1_rel" : [ SenseInfo('00128867-n', 2), SenseInfo('07376257-n', 1), SenseInfo('11465017-n', 0), SenseInfo('07408171-n', 0), SenseInfo('07287288-n', 0), SenseInfo('06711159-n', 0) ],
"_slushy_a_1_rel" : [ SenseInfo('01080060-a', 0), SenseInfo('00854413-a', 0), SenseInfo('01080060-a', 0), SenseInfo('00854413-a', 0), SenseInfo('01080060-a', 0), SenseInfo('00854413-a', 0) ],
"_snub_v_1_rel" : [ SenseInfo('01059564-v', 3), SenseInfo('00798539-v', 1) ],
"_trump_v_up_rel" : [ SenseInfo('02179154-v', 0), SenseInfo('01109259-v', 0), SenseInfo('01078235-v', 0), SenseInfo('00975202-v', 0) ],
"_secrete_v_1_rel" : [ SenseInfo('00069295-v', 1), SenseInfo('02145271-v', 0) ],
"_fright_n_1_rel" : [ SenseInfo('07519253-n', 2) ],
"_cancellation_n_of_rel" : [ SenseInfo('00232386-n', 2), SenseInfo('07207142-n', 0) ],
"_previously_p_rel" : [ SenseInfo('00060632-r', 30), SenseInfo('00060632-r', 30) ],
"_prismatic_a_1_rel" : [ SenseInfo('03102558-a', 0), SenseInfo('00403654-a', 0) ],
"_half-hearted_a_1_rel" : [ SenseInfo('00887472-a', 0), SenseInfo('00887472-a', 0), SenseInfo('00887472-a', 0), SenseInfo('00887472-a', 0) ],
"_wade_v_1_rel" : [ SenseInfo('01916214-v', 4), SenseInfo('01916214-v', 4) ],
"_grinder_n_1_rel" : [ SenseInfo('07697825-n', 0), SenseInfo('05307773-n', 0), SenseInfo('03765561-n', 0), SenseInfo('03460040-n', 0) ],
"_fin_n_1_rel" : [ SenseInfo('13744521-n', 0), SenseInfo('04384406-n', 0), SenseInfo('03692676-n', 0), SenseInfo('03364156-n', 0), SenseInfo('03340581-n', 0), SenseInfo('02466132-n', 0) ],
"_open_a_sel_rel" : [ SenseInfo('01652380-a', 34), SenseInfo('01652902-a', 17), SenseInfo('01886620-a', 13), SenseInfo('01861910-a', 7), SenseInfo('01654377-a', 4), SenseInfo('00185509-a', 4), SenseInfo('02003357-a', 3), SenseInfo('02523664-a', 2), SenseInfo('02232112-a', 2), SenseInfo('01659117-a', 2), SenseInfo('01659999-a', 1), SenseInfo('02130821-a', 1), SenseInfo('02087178-a', 1), SenseInfo('01449354-a', 1), SenseInfo('01985247-a', 0), SenseInfo('01704761-a', 0), SenseInfo('02474876-a', 0), SenseInfo('02361540-a', 0), SenseInfo('01622505-a', 0), SenseInfo('01310273-a', 0), SenseInfo('00036254-a', 0) ],
"_refinement_n_of_rel" : [ SenseInfo('14459824-n', 1), SenseInfo('07357679-n', 1), SenseInfo('13548105-n', 0), SenseInfo('06606191-n', 0), SenseInfo('04811995-n', 0) ],
"_horrific_a_for_rel" : [ SenseInfo('01626562-a', 0), SenseInfo('00193799-a', 0), SenseInfo('01626562-a', 0), SenseInfo('00193799-a', 0), SenseInfo('01626562-a', 0), SenseInfo('00193799-a', 0), SenseInfo('01626562-a', 0), SenseInfo('00193799-a', 0) ],
"_raven_n_1_rel" : [ SenseInfo('01579260-n', 0) ],
"_short_v_1_rel" : [ SenseInfo('02572667-v', 0), SenseInfo('01618884-v', 0) ],
"_a+totter_a_1_rel" : [  ],
"_biographer_n_1_rel" : [ SenseInfo('09855433-n', 0) ],
"_goodbye_n_1_rel" : [ SenseInfo('06629610-n', 0), SenseInfo('06629610-n', 0) ],
"_fraction_n_of_rel" : [ SenseInfo('14922107-n', 22), SenseInfo('03390207-n', 5), SenseInfo('13732078-n', 2), SenseInfo('14922107-n', 22), SenseInfo('03390207-n', 5), SenseInfo('13732078-n', 2) ],
"_the+same_a_as_rel" : [ SenseInfo('02068476-a', 129), SenseInfo('02062670-a', 80), SenseInfo('01411065-a', 20), SenseInfo('00355611-a', 17) ],
"_outcropping_n_1_rel" : [ SenseInfo('09381242-n', 0) ],
"_portuguese_n_1_rel" : [ SenseInfo('06966310-n', 1), SenseInfo('09728009-n', 0), SenseInfo('06966310-n', 1), SenseInfo('09728009-n', 0), SenseInfo('06966310-n', 1), SenseInfo('09728009-n', 0) ],
"_charge_v_up_rel" : [ SenseInfo('01121719-v', 16), SenseInfo('00843468-v', 10), SenseInfo('02320374-v', 7), SenseInfo('02055267-v', 6), SenseInfo('02475922-v', 4), SenseInfo('00869931-v', 3), SenseInfo('00843959-v', 3), SenseInfo('01488956-v', 2), SenseInfo('02321046-v', 1), SenseInfo('02348568-v', 0), SenseInfo('02347637-v', 0), SenseInfo('02317289-v', 0), SenseInfo('01985424-v', 0), SenseInfo('01762528-v', 0), SenseInfo('01685960-v', 0), SenseInfo('01490336-v', 0), SenseInfo('01152214-v', 0), SenseInfo('00750532-v', 0), SenseInfo('00750345-v', 0), SenseInfo('00750172-v', 0), SenseInfo('00727991-v', 0), SenseInfo('00700517-v', 0), SenseInfo('00518115-v', 0), SenseInfo('00517847-v', 0), SenseInfo('00498016-v', 0) ],
"_lunchbreak_n_1_rel" : [  ],
"_fragmented_a_1_rel" : [ SenseInfo('02481012-a', 0) ],
"_out_a_cmpar_rel" : [ SenseInfo('02061487-a', 3), SenseInfo('00100213-a', 2), SenseInfo('01823948-a', 1), SenseInfo('02334973-a', 0), SenseInfo('01761375-a', 0), SenseInfo('01295946-a', 0), SenseInfo('00974908-a', 0), SenseInfo('00952653-a', 0), SenseInfo('00949797-a', 0), SenseInfo('00572714-a', 0) ],
"_jackstay_n_1_rel" : [  ],
"_subterranean_a_1_rel" : [ SenseInfo('02472384-a', 0), SenseInfo('01707733-a', 0) ],
"_confide_v_to_rel" : [ SenseInfo('00936465-v', 6), SenseInfo('02349212-v', 1), SenseInfo('00936465-v', 6), SenseInfo('02349212-v', 1), SenseInfo('00936465-v', 6), SenseInfo('02349212-v', 1) ],
"_plus_n_1_rel" : [ SenseInfo('05154517-n', 0), SenseInfo('00872107-n', 0) ],
"_substitute_n_1_rel" : [ SenseInfo('05696425-n', 9), SenseInfo('10671042-n', 0), SenseInfo('10648237-n', 0) ],
"_resource_n_1_rel" : [ SenseInfo('13331778-n', 12), SenseInfo('05154676-n', 8), SenseInfo('05633860-n', 2), SenseInfo('13331778-n', 12), SenseInfo('05154676-n', 8), SenseInfo('05633860-n', 2), SenseInfo('13331778-n', 12), SenseInfo('05154676-n', 8), SenseInfo('05633860-n', 2) ],
"_ascend_v_1_rel" : [ SenseInfo('01969216-v', 3), SenseInfo('02751451-v', 0), SenseInfo('02381571-v', 0), SenseInfo('02105657-v', 0), SenseInfo('02103021-v', 0), SenseInfo('02037472-v', 0), SenseInfo('01970348-v', 0), SenseInfo('01969779-v', 0), SenseInfo('01969216-v', 3), SenseInfo('02751451-v', 0), SenseInfo('02381571-v', 0), SenseInfo('02105657-v', 0), SenseInfo('02103021-v', 0), SenseInfo('02037472-v', 0), SenseInfo('01970348-v', 0), SenseInfo('01969779-v', 0) ],
"_participant_n_1_rel" : [ SenseInfo('10401829-n', 1), SenseInfo('10439851-n', 0) ],
"_stocking_n_1_rel" : [ SenseInfo('04323819-n', 4), SenseInfo('01061029-n', 1) ],
"_aurora+borealis_n_1_rel" : [ SenseInfo('11427619-n', 0), SenseInfo('11427619-n', 0) ],
"_acknowledge_v_to_rel" : [ SenseInfo('00817311-v', 5), SenseInfo('00892698-v', 3), SenseInfo('01059123-v', 2), SenseInfo('00892467-v', 1), SenseInfo('00740449-v', 0), SenseInfo('00592883-v', 0), SenseInfo('00817311-v', 5), SenseInfo('00892698-v', 3), SenseInfo('01059123-v', 2), SenseInfo('00892467-v', 1), SenseInfo('00740449-v', 0), SenseInfo('00592883-v', 0) ],
"_decent_a_1_rel" : [ SenseInfo('01993408-a', 3), SenseInfo('01878870-a', 1), SenseInfo('00682932-a', 0), SenseInfo('02336109-a', 0), SenseInfo('01538583-a', 0), SenseInfo('01538311-a', 0), SenseInfo('01993408-a', 3), SenseInfo('01878870-a', 1), SenseInfo('00682932-a', 0), SenseInfo('02336109-a', 0), SenseInfo('01538583-a', 0), SenseInfo('01538311-a', 0) ],
"_roam_n_1_rel" : [  ],
"_sonata_n_1_rel" : [ SenseInfo('07044088-n', 0) ],
"_superior_n_1_rel" : [ SenseInfo('10676018-n', 1), SenseInfo('10675876-n', 1), SenseInfo('10752930-n', 0), SenseInfo('09333171-n', 0), SenseInfo('09158649-n', 0), SenseInfo('06820023-n', 0) ],
"_line_n_of_rel" : [ SenseInfo('08430568-n', 51), SenseInfo('06799897-n', 20), SenseInfo('08430203-n', 15), SenseInfo('13863771-n', 13), SenseInfo('07012534-n', 11), SenseInfo('11474637-n', 10), SenseInfo('08594286-n', 10), SenseInfo('05773049-n', 10), SenseInfo('02934168-n', 9), SenseInfo('08377085-n', 8), SenseInfo('08593262-n', 6), SenseInfo('13905792-n', 5), SenseInfo('03946325-n', 4), SenseInfo('03671272-n', 4), SenseInfo('04402057-n', 3), SenseInfo('01204294-n', 3), SenseInfo('08101937-n', 2), SenseInfo('03670849-n', 2), SenseInfo('00582388-n', 2), SenseInfo('08593924-n', 1), SenseInfo('06260121-n', 1), SenseInfo('03671668-n', 1), SenseInfo('03671473-n', 1), SenseInfo('13713003-n', 0), SenseInfo('13379413-n', 0), SenseInfo('07028373-n', 0), SenseInfo('07012979-n', 0), SenseInfo('06626286-n', 0), SenseInfo('05748786-n', 0), SenseInfo('04008385-n', 0), SenseInfo('08430568-n', 51), SenseInfo('06799897-n', 20), SenseInfo('08430203-n', 15), SenseInfo('13863771-n', 13), SenseInfo('07012534-n', 11), SenseInfo('11474637-n', 10), SenseInfo('08594286-n', 10), SenseInfo('05773049-n', 10), SenseInfo('02934168-n', 9), SenseInfo('08377085-n', 8), SenseInfo('08593262-n', 6), SenseInfo('13905792-n', 5), SenseInfo('03946325-n', 4), SenseInfo('03671272-n', 4), SenseInfo('04402057-n', 3), SenseInfo('01204294-n', 3), SenseInfo('08101937-n', 2), SenseInfo('03670849-n', 2), SenseInfo('00582388-n', 2), SenseInfo('08593924-n', 1), SenseInfo('06260121-n', 1), SenseInfo('03671668-n', 1), SenseInfo('03671473-n', 1), SenseInfo('13713003-n', 0), SenseInfo('13379413-n', 0), SenseInfo('07028373-n', 0), SenseInfo('07012979-n', 0), SenseInfo('06626286-n', 0), SenseInfo('05748786-n', 0), SenseInfo('04008385-n', 0), SenseInfo('08430568-n', 51), SenseInfo('06799897-n', 20), SenseInfo('08430203-n', 15), SenseInfo('13863771-n', 13), SenseInfo('07012534-n', 11), SenseInfo('11474637-n', 10), SenseInfo('08594286-n', 10), SenseInfo('05773049-n', 10), SenseInfo('02934168-n', 9), SenseInfo('08377085-n', 8), SenseInfo('08593262-n', 6), SenseInfo('13905792-n', 5), SenseInfo('03946325-n', 4), SenseInfo('03671272-n', 4), SenseInfo('04402057-n', 3), SenseInfo('01204294-n', 3), SenseInfo('08101937-n', 2), SenseInfo('03670849-n', 2), SenseInfo('00582388-n', 2), SenseInfo('08593924-n', 1), SenseInfo('06260121-n', 1), SenseInfo('03671668-n', 1), SenseInfo('03671473-n', 1), SenseInfo('13713003-n', 0), SenseInfo('13379413-n', 0), SenseInfo('07028373-n', 0), SenseInfo('07012979-n', 0), SenseInfo('06626286-n', 0), SenseInfo('05748786-n', 0), SenseInfo('04008385-n', 0) ],
"_grayish_a_1_rel" : [ SenseInfo('00389310-a', 0) ],
"_damage_n_to_rel" : [ SenseInfo('07420770-n', 11), SenseInfo('07339653-n', 1), SenseInfo('00403092-n', 1), SenseInfo('13303315-n', 0), SenseInfo('00744131-n', 0) ],
"_sparrow_n_1_rel" : [ SenseInfo('01539573-n', 1), SenseInfo('01527347-n', 0) ],
"_fun_a_for_rel" : [ SenseInfo('00429949-n', 9), SenseInfo('06780882-n', 3), SenseInfo('01260556-n', 1), SenseInfo('04649261-n', 0), SenseInfo('00429949-n', 9), SenseInfo('06780882-n', 3), SenseInfo('01260556-n', 1), SenseInfo('04649261-n', 0) ],
"_frost_v_1_rel" : [ SenseInfo('01517175-v', 1), SenseInfo('01208549-v', 0), SenseInfo('01208400-v', 0), SenseInfo('00196595-v', 0) ],
"_sociolinguistics_n_1_rel" : [ SenseInfo('06181123-n', 0) ],
"_doughnuttery_n_1_rel" : [  ],
"_lakeshore_n_1_rel" : [ SenseInfo('09332890-n', 0) ],
"_imprison_v_1_rel" : [ SenseInfo('02494356-v', 3), SenseInfo('02495817-v', 1) ],
"_teacart_n_1_rel" : [ SenseInfo('04397027-n', 2) ],
"_betoken_v_1_rel" : [ SenseInfo('00921300-v', 0), SenseInfo('00871942-v', 0) ],
"_dobbin_n_1_rel" : [ SenseInfo('02387254-n', 0) ],
"_soak_n_1_rel" : [ SenseInfo('13557158-n', 0), SenseInfo('00256501-n', 0) ],
"_compare-and-contrast_a_1_rel" : [  ],
"_buttercup_n_1_rel" : [ SenseInfo('11720353-n', 0) ],
"_weld_v_1_rel" : [ SenseInfo('01595830-v', 1), SenseInfo('00242976-v', 1) ],
"_alias_n_1_rel" : [ SenseInfo('06338158-n', 0) ],
"_primary+school_n_1_rel" : [ SenseInfo('08412749-n', 0), SenseInfo('08412749-n', 0) ],
"_hunger_v_1_rel" : [ SenseInfo('02121958-v', 0), SenseInfo('01188485-v', 0), SenseInfo('01188144-v', 0) ],
"_quicken_v_1_rel" : [ SenseInfo('00438178-v', 3), SenseInfo('02117534-v', 0), SenseInfo('00442063-v', 0), SenseInfo('00053035-v', 0), SenseInfo('00024279-v', 0) ],
"_heir_a_1_rel" : [ SenseInfo('10168584-n', 3), SenseInfo('10671613-n', 0) ],
"_insinuation_n_1_rel" : [ SenseInfo('07238455-n', 4), SenseInfo('00160073-n', 0), SenseInfo('07238455-n', 4), SenseInfo('00160073-n', 0) ],
"_excellent_a_1_rel" : [ SenseInfo('02343110-a', 17), SenseInfo('02343110-a', 17) ],
"_latch_n_1_rel" : [ SenseInfo('03645011-n', 0), SenseInfo('03644858-n', 0) ],
"_bypass_n_1_rel" : [ SenseInfo('02828648-n', 1), SenseInfo('05548203-n', 0), SenseInfo('04211001-n', 0) ],
"_coder_n_1_rel" : [ SenseInfo('10481268-n', 0) ],
"_exponential_a_1_rel" : [ SenseInfo('02965274-a', 0) ],
"_bobby_n_1_rel" : [ SenseInfo('09862621-n', 0) ],
"_teethe_v_1_rel" : [ SenseInfo('00095990-v', 0) ],
"_psychic_n_1_rel" : [ SenseInfo('10488309-n', 0) ],
"_lingua+franca_n_1_rel" : [ SenseInfo('06906116-n', 0) ],
"_think_v_up_rel" : [ SenseInfo('00689344-v', 274), SenseInfo('00631737-v', 188), SenseInfo('00628491-v', 111), SenseInfo('00607780-v', 8), SenseInfo('01637166-v', 4), SenseInfo('00723056-v', 3), SenseInfo('00708538-v', 2), SenseInfo('00739340-v', 0), SenseInfo('00739082-v', 0), SenseInfo('00689809-v', 0), SenseInfo('00629738-v', 0), SenseInfo('00608808-v', 0), SenseInfo('00561887-v', 0) ],
"_milkshake_n_1_rel" : [ SenseInfo('07923297-n', 0) ],
"_self-information_n_1_rel" : [  ],
"_perception_n_of_rel" : [ SenseInfo('05930136-n', 6), SenseInfo('05836468-n', 4), SenseInfo('05708432-n', 4), SenseInfo('05710020-n', 1), SenseInfo('00876874-n', 0), SenseInfo('05930136-n', 6), SenseInfo('05836468-n', 4), SenseInfo('05708432-n', 4), SenseInfo('05710020-n', 1), SenseInfo('00876874-n', 0) ],
"_beep_n_1_rel" : [ SenseInfo('07377082-n', 0) ],
"_formative_a_1_rel" : [ SenseInfo('00585597-a', 0), SenseInfo('00585398-a', 0) ],
"_sulky_n_1_rel" : [ SenseInfo('04353573-n', 2) ],
"_soldier_n_1_rel" : [ SenseInfo('10622053-n', 166), SenseInfo('02207647-n', 0) ],
"_print_n_1_rel" : [ SenseInfo('06678302-n', 2), SenseInfo('04003597-n', 2), SenseInfo('06798750-n', 0), SenseInfo('06678146-n', 0), SenseInfo('04003982-n', 0), SenseInfo('04003856-n', 0), SenseInfo('03926575-n', 0) ],
"_insufficient_a_for_rel" : [ SenseInfo('02336449-a', 3), SenseInfo('02336449-a', 3) ],
"_ouzo_n_1_rel" : [ SenseInfo('07904934-n', 0) ],
"_drop_v_by_rel" : [ SenseInfo('01977701-v', 36), SenseInfo('01976841-v', 21), SenseInfo('00432683-v', 12), SenseInfo('01985923-v', 7), SenseInfo('02403920-v', 6), SenseInfo('00941446-v', 6), SenseInfo('00363110-v', 5), SenseInfo('01489465-v', 3), SenseInfo('01258302-v', 2), SenseInfo('01100008-v', 2), SenseInfo('02267060-v', 1), SenseInfo('00393534-v', 1), SenseInfo('02717472-v', 0), SenseInfo('02465939-v', 0), SenseInfo('01611516-v', 0), SenseInfo('01513430-v', 0), SenseInfo('01200661-v', 0), SenseInfo('00615615-v', 0), SenseInfo('00614999-v', 0), SenseInfo('00548616-v', 0), SenseInfo('00148341-v', 0), SenseInfo('00092293-v', 0), SenseInfo('00057764-v', 0) ],
"_translation_n_of_rel" : [ SenseInfo('06536389-n', 4), SenseInfo('07446404-n', 2), SenseInfo('00398704-n', 2), SenseInfo('13785736-n', 0), SenseInfo('13568983-n', 0), SenseInfo('06429483-n', 0), SenseInfo('00330984-n', 0) ],
"_book_v_1_rel" : [ SenseInfo('00678777-v', 3), SenseInfo('02498320-v', 1), SenseInfo('02498136-v', 1), SenseInfo('02599754-v', 0), SenseInfo('00678777-v', 3), SenseInfo('02498320-v', 1), SenseInfo('02498136-v', 1), SenseInfo('02599754-v', 0), SenseInfo('00678777-v', 3), SenseInfo('02498320-v', 1), SenseInfo('02498136-v', 1), SenseInfo('02599754-v', 0) ],
"_portfolio_n_1_rel" : [ SenseInfo('03986355-n', 2), SenseInfo('08242428-n', 0), SenseInfo('06494153-n', 0), SenseInfo('00721282-n', 0) ],
"_enigmatic_a_1_rel" : [ SenseInfo('00534524-a', 2), SenseInfo('00102930-a', 0), SenseInfo('00534524-a', 2), SenseInfo('00102930-a', 0) ],
"_anorexia_n_1_rel" : [ SenseInfo('14055796-n', 1) ],
"_ladder_n_1_rel" : [ SenseInfo('03632277-n', 5), SenseInfo('13940311-n', 0), SenseInfo('07443010-n', 0) ],
"_swagger_n_1_rel" : [ SenseInfo('10682169-n', 0), SenseInfo('00290125-n', 0) ],
"_evoke_v_1_rel" : [ SenseInfo('01759326-v', 10), SenseInfo('01646866-v', 3), SenseInfo('01630532-v', 0), SenseInfo('01629958-v', 0), SenseInfo('00930368-v', 0) ],
"_mainstream_n_1_rel" : [ SenseInfo('05955186-n', 0) ],
"_banter_n_1_rel" : [ SenseInfo('06777794-n', 2) ],
"_differ_v_1_rel" : [ SenseInfo('02666239-v', 27), SenseInfo('00804802-v', 1) ],
"_no+go_n_1_rel" : [  ],
"_plc_n_1_rel" : [  ],
"_extort_v_1_rel" : [ SenseInfo('02241621-v', 0), SenseInfo('02241107-v', 0), SenseInfo('01630751-v', 0) ],
"_characterization_n_of_rel" : [ SenseInfo('07201804-n', 4), SenseInfo('07201562-n', 0), SenseInfo('00548802-n', 0), SenseInfo('07201804-n', 4), SenseInfo('07201562-n', 0), SenseInfo('00548802-n', 0) ],
"_whistle_v_1_rel" : [ SenseInfo('02183626-v', 3), SenseInfo('02093088-v', 2), SenseInfo('01043441-v', 2), SenseInfo('02093234-v', 1), SenseInfo('01043887-v', 1), SenseInfo('01043612-v', 0) ],
"_caucasian_a_1_rel" : [ SenseInfo('02843959-a', 0), SenseInfo('00243395-a', 0) ],
"_alpaca_n_1_rel" : [ SenseInfo('15104598-n', 0), SenseInfo('02698473-n', 0), SenseInfo('02438272-n', 0) ],
"_decode_v_1_rel" : [ SenseInfo('00994454-v', 0) ],
"_ins+and+outs_n_1_rel" : [  ],
"_see_v_about_rel" : [ SenseInfo('02129289-v', 613), SenseInfo('00591115-v', 159), SenseInfo('02128873-v', 140), SenseInfo('01635432-v', 58), SenseInfo('00690614-v', 47), SenseInfo('00598954-v', 40), SenseInfo('02150948-v', 29), SenseInfo('02023107-v', 27), SenseInfo('00920336-v', 27), SenseInfo('00662589-v', 22), SenseInfo('02488304-v', 13), SenseInfo('02488488-v', 12), SenseInfo('02493030-v', 10), SenseInfo('02549581-v', 7), SenseInfo('01470670-v', 4), SenseInfo('02486232-v', 1), SenseInfo('02129709-v', 1), SenseInfo('00703708-v', 1), SenseInfo('02156225-v', 0), SenseInfo('02131279-v', 0), SenseInfo('02110220-v', 0), SenseInfo('02026086-v', 0), SenseInfo('01156568-v', 0), SenseInfo('00623151-v', 0) ],
"_roar_v_out_rel" : [ SenseInfo('01046059-v', 15), SenseInfo('00915605-v', 7), SenseInfo('01046932-v', 6), SenseInfo('01996188-v', 1), SenseInfo('01048718-v', 1), SenseInfo('00029836-v', 0) ],
"_ethnic_a_1_rel" : [ SenseInfo('02248693-a', 3), SenseInfo('01784401-a', 0) ],
"_buffer_n_1_rel" : [ SenseInfo('14785941-n', 8), SenseInfo('08688424-n', 0), SenseInfo('03328201-n', 0), SenseInfo('02911485-n', 0), SenseInfo('02911332-n', 0), SenseInfo('02911158-n', 0), SenseInfo('02910964-n', 0) ],
"_first+thing_a_1_rel" : [  ],
"_championship_n_1_rel" : [ SenseInfo('13948912-n', 2), SenseInfo('07457834-n', 0), SenseInfo('01213886-n', 0) ],
"_relieve_v_1_rel" : [ SenseInfo('00064095-v', 9), SenseInfo('02412175-v', 4), SenseInfo('02564146-v', 2), SenseInfo('01815185-v', 2), SenseInfo('02550868-v', 1), SenseInfo('00936648-v', 1), SenseInfo('00082563-v', 1), SenseInfo('02312996-v', 0), SenseInfo('02312882-v', 0), SenseInfo('00893878-v', 0), SenseInfo('00199067-v', 0) ],
"_jury_n_1_rel" : [ SenseInfo('08414119-n', 21), SenseInfo('08414807-n', 2) ],
"_plot_n_1_rel" : [ SenseInfo('05907682-n', 9), SenseInfo('08674739-n', 6), SenseInfo('06373314-n', 5), SenseInfo('07000065-n', 0), SenseInfo('05907682-n', 9), SenseInfo('08674739-n', 6), SenseInfo('06373314-n', 5), SenseInfo('07000065-n', 0) ],
"_disadvantageous_a_1_rel" : [ SenseInfo('00065488-a', 0) ],
"_boot_v_out_rel" : [ SenseInfo('01372556-v', 0), SenseInfo('00098346-v', 0) ],
"_saboteur_n_1_rel" : [ SenseInfo('10544748-n', 0), SenseInfo('10087255-n', 0) ],
"_bust_v_up_rel" : [ SenseInfo('01369758-v', 1), SenseInfo('02494850-v', 0), SenseInfo('01573515-v', 0), SenseInfo('01369346-v', 0), SenseInfo('00333594-v', 0), SenseInfo('01369758-v', 1), SenseInfo('02494850-v', 0), SenseInfo('01573515-v', 0), SenseInfo('01369346-v', 0), SenseInfo('00333594-v', 0) ],
"_dreary_a_1_rel" : [ SenseInfo('00807399-a', 1), SenseInfo('00364881-a', 0), SenseInfo('00807399-a', 1), SenseInfo('00364881-a', 0), SenseInfo('00807399-a', 1), SenseInfo('00364881-a', 0) ],
"_volt_n_1_rel" : [ SenseInfo('13643276-n', 0) ],
"_blur_v_cause_rel" : [ SenseInfo('02158034-v', 2), SenseInfo('02161758-v', 1), SenseInfo('00620673-v', 1), SenseInfo('01251928-v', 0), SenseInfo('00312990-v', 0), SenseInfo('00311113-v', 0) ],
"_hustle_v_1_rel" : [ SenseInfo('02096312-v', 2), SenseInfo('02058191-v', 1), SenseInfo('02322596-v', 0), SenseInfo('02210496-v', 0), SenseInfo('00767019-v', 0), SenseInfo('02096312-v', 2), SenseInfo('02058191-v', 1), SenseInfo('02322596-v', 0), SenseInfo('02210496-v', 0), SenseInfo('00767019-v', 0), SenseInfo('02096312-v', 2), SenseInfo('02058191-v', 1), SenseInfo('02322596-v', 0), SenseInfo('02210496-v', 0), SenseInfo('00767019-v', 0) ],
"_fed+up_a_with_rel" : [ SenseInfo('01806677-a', 0) ],
"_downright_x_deg_rel" : [ SenseInfo('00097522-r', 3), SenseInfo('01222722-a', 0), SenseInfo('00520892-a', 0) ],
"_brown_v_1_rel" : [ SenseInfo('00320246-v', 1), SenseInfo('00285705-v', 0) ],
"_slickensides_n_1_rel" : [  ],
"_gut_v_out_rel" : [ SenseInfo('01591012-v', 0), SenseInfo('01590747-v', 0) ],
"_odor_n_1_rel" : [ SenseInfo('04980008-n', 7), SenseInfo('05713737-n', 2), SenseInfo('04980008-n', 7), SenseInfo('05713737-n', 2) ],
"_grave_n_1_rel" : [ SenseInfo('15143726-n', 5), SenseInfo('03455033-n', 5), SenseInfo('06822707-n', 0) ],
"_buyer_n_of_rel" : [ SenseInfo('09885145-n', 1) ],
"_anorak_n_1_rel" : [ SenseInfo('03891051-n', 0) ],
"_hardwood_n_1_rel" : [ SenseInfo('15100112-n', 0) ],
"_misleading_a_1_rel" : [ SenseInfo('01224253-a', 4) ],
"_twofold_a_1_rel" : [ SenseInfo('02217799-a', 2), SenseInfo('02217241-a', 1), SenseInfo('02217799-a', 2), SenseInfo('02217241-a', 1) ],
"_weak_a_1_rel" : [ SenseInfo('02324397-a', 13), SenseInfo('00756459-a', 3), SenseInfo('02320442-a', 1), SenseInfo('01259391-a', 1), SenseInfo('02493574-a', 0), SenseInfo('02230471-a', 0), SenseInfo('02040233-a', 0), SenseInfo('01960432-a', 0), SenseInfo('01828242-a', 0), SenseInfo('01747364-a', 0), SenseInfo('00964768-a', 0), SenseInfo('00441523-a', 0), SenseInfo('02324397-a', 13), SenseInfo('00756459-a', 3), SenseInfo('02320442-a', 1), SenseInfo('01259391-a', 1), SenseInfo('02493574-a', 0), SenseInfo('02230471-a', 0), SenseInfo('02040233-a', 0), SenseInfo('01960432-a', 0), SenseInfo('01828242-a', 0), SenseInfo('01747364-a', 0), SenseInfo('00964768-a', 0), SenseInfo('00441523-a', 0), SenseInfo('02324397-a', 13), SenseInfo('00756459-a', 3), SenseInfo('02320442-a', 1), SenseInfo('01259391-a', 1), SenseInfo('02493574-a', 0), SenseInfo('02230471-a', 0), SenseInfo('02040233-a', 0), SenseInfo('01960432-a', 0), SenseInfo('01828242-a', 0), SenseInfo('01747364-a', 0), SenseInfo('00964768-a', 0), SenseInfo('00441523-a', 0), SenseInfo('02324397-a', 13), SenseInfo('00756459-a', 3), SenseInfo('02320442-a', 1), SenseInfo('01259391-a', 1), SenseInfo('02493574-a', 0), SenseInfo('02230471-a', 0), SenseInfo('02040233-a', 0), SenseInfo('01960432-a', 0), SenseInfo('01828242-a', 0), SenseInfo('01747364-a', 0), SenseInfo('00964768-a', 0), SenseInfo('00441523-a', 0) ],
"_form_v_cause_rel" : [ SenseInfo('02448185-v', 28), SenseInfo('02621395-v', 26), SenseInfo('02623906-v', 18), SenseInfo('00142191-v', 12), SenseInfo('01659248-v', 11), SenseInfo('02430922-v', 3), SenseInfo('00144850-v', 0) ],
"_deja+vu_n_1_rel" : [ SenseInfo('05810440-n', 7) ],
"_gram_n_1_rel" : [ SenseInfo('13723712-n', 27), SenseInfo('11010936-n', 0), SenseInfo('13723712-n', 27), SenseInfo('11010936-n', 0), SenseInfo('13723712-n', 27), SenseInfo('11010936-n', 0) ],
"_insistent_a_1_rel" : [ SenseInfo('00592539-a', 2), SenseInfo('00712877-a', 1), SenseInfo('00592539-a', 2), SenseInfo('00712877-a', 1) ],
"_deploy_v_cause_rel" : [ SenseInfo('01149327-v', 2), SenseInfo('01379600-v', 0), SenseInfo('01149327-v', 2), SenseInfo('01379600-v', 0) ],
"_schedulewise_a_1_rel" : [  ],
"_geological_a_1_rel" : [ SenseInfo('02905591-a', 2), SenseInfo('02905591-a', 2) ],
"_thermocouple_n_1_rel" : [ SenseInfo('04420720-n', 6) ],
"_aqua_a_1_rel" : [ SenseInfo('04969798-n', 0) ],
"_startle_v_1_rel" : [ SenseInfo('01821634-v', 9), SenseInfo('01910373-v', 0), SenseInfo('01821634-v', 9), SenseInfo('01910373-v', 0), SenseInfo('01821634-v', 9), SenseInfo('01910373-v', 0), SenseInfo('01821634-v', 9), SenseInfo('01910373-v', 0), SenseInfo('01821634-v', 9), SenseInfo('01910373-v', 0), SenseInfo('01821634-v', 9), SenseInfo('01910373-v', 0), SenseInfo('01821634-v', 9), SenseInfo('01910373-v', 0), SenseInfo('01821634-v', 9), SenseInfo('01910373-v', 0) ],
"_flip_n_1_rel" : [ SenseInfo('00439484-n', 1), SenseInfo('07914887-n', 0), SenseInfo('01246206-n', 0), SenseInfo('01246086-n', 0), SenseInfo('00443803-n', 0), SenseInfo('00105820-n', 0) ],
"_sway_v_1_rel" : [ SenseInfo('01875295-v', 5), SenseInfo('01877355-v', 4), SenseInfo('02586121-v', 3), SenseInfo('01876028-v', 0) ],
"_archeologist_n_1_rel" : [ SenseInfo('09804806-n', 0), SenseInfo('09804806-n', 0), SenseInfo('09804806-n', 0) ],
"_all+of+a+sudden_a_1_rel" : [  ],
"_grit_n_1_rel" : [ SenseInfo('14700594-n', 0), SenseInfo('05032351-n', 0) ],
"_argue_v_with_rel" : [ SenseInfo('00772189-v', 34), SenseInfo('00773432-v', 17), SenseInfo('00772640-v', 0), SenseInfo('00772189-v', 34), SenseInfo('00773432-v', 17), SenseInfo('00772640-v', 0), SenseInfo('00772189-v', 34), SenseInfo('00773432-v', 17), SenseInfo('00772640-v', 0) ],
"_complexity_n_1_rel" : [ SenseInfo('04766275-n', 10) ],
"_negligent_a_1_rel" : [ SenseInfo('00754873-a', 1) ],
"_hear_v_1_rel" : [ SenseInfo('02169702-v', 275), SenseInfo('00598954-v', 60), SenseInfo('02500902-v', 12), SenseInfo('02107442-v', 8), SenseInfo('02171039-v', 0), SenseInfo('02169702-v', 275), SenseInfo('00598954-v', 60), SenseInfo('02500902-v', 12), SenseInfo('02107442-v', 8), SenseInfo('02171039-v', 0), SenseInfo('02169702-v', 275), SenseInfo('00598954-v', 60), SenseInfo('02500902-v', 12), SenseInfo('02107442-v', 8), SenseInfo('02171039-v', 0), SenseInfo('02169702-v', 275), SenseInfo('00598954-v', 60), SenseInfo('02500902-v', 12), SenseInfo('02107442-v', 8), SenseInfo('02171039-v', 0), SenseInfo('02169702-v', 275), SenseInfo('00598954-v', 60), SenseInfo('02500902-v', 12), SenseInfo('02107442-v', 8), SenseInfo('02171039-v', 0) ],
"_concatenate_v_1_rel" : [ SenseInfo('01465054-v', 0), SenseInfo('00190180-v', 0) ],
"_because_x_rel" : [  ],
"_segment_n_1_rel" : [ SenseInfo('04164989-n', 4), SenseInfo('09429387-n', 0) ],
"_expedition_n_1_rel" : [ SenseInfo('00968479-n', 4), SenseInfo('08409130-n', 3), SenseInfo('00309647-n', 3), SenseInfo('00311809-n', 1), SenseInfo('05059830-n', 0) ],
"_lab_n_1_rel" : [ SenseInfo('03629986-n', 2) ],
"_seagoing_a_1_rel" : [ SenseInfo('01381074-a', 0) ],
"_toilet_n_1_rel" : [ SenseInfo('04446276-n', 3), SenseInfo('04446521-n', 2), SenseInfo('14475992-n', 0), SenseInfo('00828704-n', 0) ],
"_interest_n_in_rel" : [ SenseInfo('05682950-n', 62), SenseInfo('05143077-n', 32), SenseInfo('05192451-n', 21), SenseInfo('13318584-n', 14), SenseInfo('13286801-n', 7), SenseInfo('07968702-n', 5), SenseInfo('00431552-n', 3) ],
"_back-off_n_1_rel" : [  ],
"_discreet_a_1_rel" : [ SenseInfo('00772910-a', 0), SenseInfo('02384672-a', 0), SenseInfo('01898490-a', 0), SenseInfo('00772910-a', 0), SenseInfo('02384672-a', 0), SenseInfo('01898490-a', 0) ],
"_enthuse_v_1_rel" : [ SenseInfo('01830192-v', 0), SenseInfo('00916679-v', 0) ],
"_cork_v_1_rel" : [ SenseInfo('01423623-v', 0), SenseInfo('00321341-v', 0) ],
"_floppy_a_1_rel" : [ SenseInfo('02404306-a', 0), SenseInfo('02404306-a', 0), SenseInfo('02404306-a', 0) ],
"_binding_n_1_rel" : [ SenseInfo('04689198-n', 4), SenseInfo('02840927-n', 1), SenseInfo('00696882-n', 1), SenseInfo('04228215-n', 0), SenseInfo('02840619-n', 0) ],
"_plaster_n_1_rel" : [ SenseInfo('14992287-n', 3), SenseInfo('14992613-n', 0), SenseInfo('03993403-n', 0), SenseInfo('03957567-n', 0), SenseInfo('03957420-n', 0) ],
"_superstructure_n_1_rel" : [ SenseInfo('04358874-n', 0) ],
"_protection_n_of_rel" : [ SenseInfo('00817680-n', 18), SenseInfo('04014297-n', 5), SenseInfo('13344071-n', 3), SenseInfo('14539960-n', 1), SenseInfo('01214863-n', 0), SenseInfo('01127874-n', 0), SenseInfo('00784755-n', 0) ],
"_crowfoot_n_1_rel" : [ SenseInfo('11720353-n', 0) ],
"_yellow_a_1_rel" : [ SenseInfo('00385756-a', 26), SenseInfo('00265314-a', 2), SenseInfo('01640729-a', 1), SenseInfo('02101942-a', 0), SenseInfo('01228370-a', 0), SenseInfo('01177556-a', 0), SenseInfo('00385756-a', 26), SenseInfo('00265314-a', 2), SenseInfo('01640729-a', 1), SenseInfo('02101942-a', 0), SenseInfo('01228370-a', 0), SenseInfo('01177556-a', 0), SenseInfo('00385756-a', 26), SenseInfo('00265314-a', 2), SenseInfo('01640729-a', 1), SenseInfo('02101942-a', 0), SenseInfo('01228370-a', 0), SenseInfo('01177556-a', 0) ],
"_alfalfa_n_1_rel" : [ SenseInfo('12549420-n', 0), SenseInfo('07801779-n', 0) ],
"_diverged_a_1_rel" : [  ],
"_blight_n_1_rel" : [ SenseInfo('14562854-n', 1), SenseInfo('14215331-n', 0) ],
"_unforgettable_a_1_rel" : [ SenseInfo('01040410-a', 3), SenseInfo('01040410-a', 3) ],
"_yum_a_1_rel" : [  ],
"_take_v_on_rel" : [ SenseInfo('02599636-v', 92), SenseInfo('02267989-v', 74), SenseInfo('01999798-v', 73), SenseInfo('01214265-v', 50), SenseInfo('00524682-v', 38), SenseInfo('00624476-v', 36), SenseInfo('02077656-v', 32), SenseInfo('02205272-v', 28), SenseInfo('01842690-v', 26), SenseInfo('00674607-v', 26), SenseInfo('02236124-v', 25), SenseInfo('02394183-v', 22), SenseInfo('00734054-v', 22), SenseInfo('02627934-v', 21), SenseInfo('02109045-v', 21), SenseInfo('01002740-v', 16), SenseInfo('00173338-v', 16), SenseInfo('01156834-v', 15), SenseInfo('00669762-v', 15), SenseInfo('02209936-v', 14), SenseInfo('02206619-v', 13), SenseInfo('01982395-v', 10), SenseInfo('02236624-v', 8), SenseInfo('00523095-v', 7), SenseInfo('00599992-v', 6), SenseInfo('00756076-v', 5), SenseInfo('02075857-v', 4), SenseInfo('01151110-v', 4), SenseInfo('00557404-v', 4), SenseInfo('02717102-v', 2), SenseInfo('02208537-v', 2), SenseInfo('02209745-v', 1), SenseInfo('02208118-v', 1), SenseInfo('02201138-v', 1), SenseInfo('01427127-v', 1), SenseInfo('00758333-v', 1), SenseInfo('02741546-v', 0), SenseInfo('02701210-v', 0), SenseInfo('02590253-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01100830-v', 0), SenseInfo('00087736-v', 0) ],
"_remove_v_1_rel" : [ SenseInfo('00173338-v', 86), SenseInfo('02404224-v', 4), SenseInfo('02224055-v', 4), SenseInfo('02404904-v', 3), SenseInfo('02086458-v', 3), SenseInfo('00421535-v', 2), SenseInfo('02482425-v', 0), SenseInfo('00571061-v', 0), SenseInfo('00173338-v', 86), SenseInfo('02404224-v', 4), SenseInfo('02224055-v', 4), SenseInfo('02404904-v', 3), SenseInfo('02086458-v', 3), SenseInfo('00421535-v', 2), SenseInfo('02482425-v', 0), SenseInfo('00571061-v', 0) ],
"_breadth_n_of_rel" : [ SenseInfo('05618293-n', 2), SenseInfo('05136150-n', 2) ],
"_inorganic_a_1_rel" : [ SenseInfo('01679244-a', 6), SenseInfo('01680116-a', 0) ],
"_invisible_a_to_rel" : [ SenseInfo('02517265-a', 5), SenseInfo('00581401-a', 0) ],
"_until_p_sel_rel" : [  ],
"_consist_v_in_rel" : [ SenseInfo('02653381-v', 4), SenseInfo('02750854-v', 0), SenseInfo('02658050-v', 0), SenseInfo('02633356-v', 0) ],
"_much+rather_a_1_rel" : [  ],
"_hotline_n_1_rel" : [  ],
"_uneasy_a_1_rel" : [ SenseInfo('00822449-a', 15), SenseInfo('01922562-a', 0), SenseInfo('02456157-a', 0), SenseInfo('00480439-a', 0), SenseInfo('00479073-a', 0) ],
"_fervent_a_1_rel" : [ SenseInfo('01726235-a', 3), SenseInfo('01248713-a', 0) ],
"_audio_n_1_rel" : [ SenseInfo('06278136-n', 0), SenseInfo('05056386-n', 0), SenseInfo('04262678-n', 0), SenseInfo('02756751-n', 0) ],
"_emetic_n_1_rel" : [ SenseInfo('03283519-n', 0) ],
"_pepper_v_1_rel" : [ SenseInfo('02196081-v', 1), SenseInfo('01121320-v', 1) ],
"_dove_n_1_rel" : [ SenseInfo('01812337-n', 2), SenseInfo('10028123-n', 0), SenseInfo('09250551-n', 0), SenseInfo('07646403-n', 0), SenseInfo('06881494-n', 0) ],
"_incur_v_1_rel" : [ SenseInfo('02721031-v', 11), SenseInfo('00522751-v', 0) ],
"_sleeper_n_1_rel" : [ SenseInfo('10610465-n', 1), SenseInfo('10610850-n', 0), SenseInfo('10610699-n', 0), SenseInfo('04433585-n', 0), SenseInfo('04236001-n', 0), SenseInfo('04235771-n', 0), SenseInfo('04235646-n', 0), SenseInfo('02619861-n', 0), SenseInfo('00064370-n', 0) ],
"_a+good+many_a_1_rel" : [  ],
"_can_n_1_rel" : [ SenseInfo('02946921-n', 2), SenseInfo('13765990-n', 0), SenseInfo('07266776-n', 0), SenseInfo('05559256-n', 0), SenseInfo('04446521-n', 0), SenseInfo('04446276-n', 0) ],
"_clothes_n_1_rel" : [ SenseInfo('02728440-n', 44) ],
"_repugnant_a_1_rel" : [ SenseInfo('01625063-a', 0) ],
"_rattle_v_1_rel" : [ SenseInfo('02175057-v', 4), SenseInfo('01890626-v', 3) ],
"_bosnian_n_1_rel" : [ SenseInfo('02964629-a', 0) ],
"_dexterity_n_1_rel" : [ SenseInfo('05642815-n', 0) ],
"_meltwater_n_1_rel" : [ SenseInfo('14950055-n', 0) ],
"_unreconstructed_a_1_rel" : [ SenseInfo('00288809-a', 5), SenseInfo('00288809-a', 5) ],
"_geez_a_1_rel" : [  ],
"_long+sleeved_a_1_rel" : [  ],
"_medium+grade_a_1_rel" : [  ],
"_clad_a_in_rel" : [ SenseInfo('00453726-a', 4), SenseInfo('02155233-a', 0) ],
"_impunity_n_1_rel" : [ SenseInfo('14529524-n', 1) ],
"_runoff_n_1_rel" : [ SenseInfo('07407272-n', 2), SenseInfo('00183357-n', 0), SenseInfo('07407272-n', 2), SenseInfo('00183357-n', 0) ],
"_committed_a_1_rel" : [ SenseInfo('00518164-a', 3), SenseInfo('00157925-a', 0) ],
"_yugoslav_a_1_rel" : [ SenseInfo('02962013-a', 0) ],
"_intellectual_a_1_rel" : [ SenseInfo('01780343-a', 3), SenseInfo('01332386-a', 1), SenseInfo('01927455-a', 0) ],
"_countryside_n_1_rel" : [ SenseInfo('08645033-n', 2) ],
"_lagomorph_n_1_rel" : [ SenseInfo('02323449-n', 0) ],
"_cross_a_at-with_rel" : [ SenseInfo('01445917-a', 4), SenseInfo('01136248-a', 1), SenseInfo('01445917-a', 4), SenseInfo('01136248-a', 1) ],
"_fillet_v_1_rel" : [ SenseInfo('01678957-v', 0), SenseInfo('01249294-v', 0) ],
"_wrench_v_1_rel" : [ SenseInfo('01349493-v', 5), SenseInfo('01868780-v', 2), SenseInfo('01349130-v', 0), SenseInfo('00091124-v', 0), SenseInfo('01349493-v', 5), SenseInfo('01868780-v', 2), SenseInfo('01349130-v', 0), SenseInfo('00091124-v', 0) ],
"_hospitality_n_1_rel" : [ SenseInfo('06631506-n', 1) ],
"_whitefish_n_1_rel" : [ SenseInfo('07795317-n', 0), SenseInfo('07795133-n', 0), SenseInfo('02538985-n', 0) ],
"_understanding_n_of_rel" : [ SenseInfo('05805475-n', 38), SenseInfo('06770275-n', 2), SenseInfo('06199142-n', 1), SenseInfo('05651680-n', 1), SenseInfo('05805475-n', 38), SenseInfo('06770275-n', 2), SenseInfo('06199142-n', 1), SenseInfo('05651680-n', 1), SenseInfo('05805475-n', 38), SenseInfo('06770275-n', 2), SenseInfo('06199142-n', 1), SenseInfo('05651680-n', 1) ],
"_squash_n_1_rel" : [ SenseInfo('12158798-n', 0), SenseInfo('07715561-n', 0), SenseInfo('00479887-n', 0) ],
"_tripod_n_1_rel" : [ SenseInfo('04485082-n', 1) ],
"_discretion_n_1_rel" : [ SenseInfo('13995824-n', 5), SenseInfo('05615500-n', 2), SenseInfo('05751707-n', 0), SenseInfo('05198756-n', 0), SenseInfo('04891010-n', 0), SenseInfo('13995824-n', 5), SenseInfo('05615500-n', 2), SenseInfo('05751707-n', 0), SenseInfo('05198756-n', 0), SenseInfo('04891010-n', 0) ],
"_re-marriage_n_1_rel" : [ SenseInfo('01248752-n', 0), SenseInfo('01248752-n', 0), SenseInfo('01248752-n', 0) ],
"_contradistinguish_v_1_rel" : [ SenseInfo('00661584-v', 0) ],
"_terrane_n_1_rel" : [  ],
"_hillock_n_1_rel" : [ SenseInfo('09326662-n', 2) ],
"_birth_n_1_rel" : [ SenseInfo('15142167-n', 6), SenseInfo('07320302-n', 2), SenseInfo('13532886-n', 1), SenseInfo('13813765-n', 0), SenseInfo('09856671-n', 0) ],
"_hitch_v_1_rel" : [ SenseInfo('01327816-v', 2), SenseInfo('01917244-v', 1), SenseInfo('01884383-v', 1), SenseInfo('01956955-v', 0), SenseInfo('01614774-v', 0), SenseInfo('01327816-v', 2), SenseInfo('01917244-v', 1), SenseInfo('01884383-v', 1), SenseInfo('01956955-v', 0), SenseInfo('01614774-v', 0) ],
"_posting_n_1_rel" : [ SenseInfo('06793426-n', 0), SenseInfo('06494373-n', 0), SenseInfo('00122338-n', 0) ],
"_virtuous_a_1_rel" : [ SenseInfo('02513269-a', 0), SenseInfo('00361125-a', 0) ],
"_decide_v_against_rel" : [ SenseInfo('00697589-v', 123), SenseInfo('00698855-v', 6), SenseInfo('00699485-v', 4), SenseInfo('00701877-v', 0) ],
"_hike_v_1_rel" : [ SenseInfo('01975912-v', 1), SenseInfo('01920932-v', 0), SenseInfo('01975912-v', 1), SenseInfo('01920932-v', 0) ],
"_creditable_a_1_rel" : [ SenseInfo('02585919-a', 1) ],
"_entirely_x_deg_rel" : [ SenseInfo('00008007-r', 43), SenseInfo('00008600-r', 2) ],
"_scuff_v_cause_rel" : [ SenseInfo('01917845-v', 1), SenseInfo('01370439-v', 0), SenseInfo('01370336-v', 0), SenseInfo('01370245-v', 0) ],
"_decision_n_1_rel" : [ SenseInfo('00162632-n', 25), SenseInfo('05838176-n', 10), SenseInfo('07293678-n', 2), SenseInfo('07293546-n', 1), SenseInfo('04863969-n', 0), SenseInfo('00162632-n', 25), SenseInfo('05838176-n', 10), SenseInfo('07293678-n', 2), SenseInfo('07293546-n', 1), SenseInfo('04863969-n', 0), SenseInfo('00162632-n', 25), SenseInfo('05838176-n', 10), SenseInfo('07293678-n', 2), SenseInfo('07293546-n', 1), SenseInfo('04863969-n', 0), SenseInfo('00162632-n', 25), SenseInfo('05838176-n', 10), SenseInfo('07293678-n', 2), SenseInfo('07293546-n', 1), SenseInfo('04863969-n', 0), SenseInfo('00162632-n', 25), SenseInfo('05838176-n', 10), SenseInfo('07293678-n', 2), SenseInfo('07293546-n', 1), SenseInfo('04863969-n', 0), SenseInfo('00162632-n', 25), SenseInfo('05838176-n', 10), SenseInfo('07293678-n', 2), SenseInfo('07293546-n', 1), SenseInfo('04863969-n', 0) ],
"_pollen_n_1_rel" : [ SenseInfo('11675537-n', 10) ],
"_nervous_a_of-about_rel" : [ SenseInfo('02406908-a', 9), SenseInfo('02456157-a', 3), SenseInfo('02904518-a', 0), SenseInfo('00919813-a', 0), SenseInfo('00919155-a', 0), SenseInfo('02406908-a', 9), SenseInfo('02456157-a', 3), SenseInfo('02904518-a', 0), SenseInfo('00919813-a', 0), SenseInfo('00919155-a', 0), SenseInfo('02406908-a', 9), SenseInfo('02456157-a', 3), SenseInfo('02904518-a', 0), SenseInfo('00919813-a', 0), SenseInfo('00919155-a', 0), SenseInfo('02406908-a', 9), SenseInfo('02456157-a', 3), SenseInfo('02904518-a', 0), SenseInfo('00919813-a', 0), SenseInfo('00919155-a', 0), SenseInfo('02406908-a', 9), SenseInfo('02456157-a', 3), SenseInfo('02904518-a', 0), SenseInfo('00919813-a', 0), SenseInfo('00919155-a', 0) ],
"_accelerate_v_1_rel" : [ SenseInfo('00438178-v', 11), SenseInfo('00439343-v', 1) ],
"_terrarium_n_1_rel" : [ SenseInfo('04414199-n', 0) ],
"_with_p_rel" : [  ],
"_chairwoman_n_of_rel" : [ SenseInfo('10468962-n', 0), SenseInfo('10468962-n', 0) ],
"_decay_v_1_rel" : [ SenseInfo('00399074-v', 3), SenseInfo('00208836-v', 2), SenseInfo('00552815-v', 0) ],
"_papal_a_1_rel" : [ SenseInfo('02879638-a', 1) ],
"_podium_n_1_rel" : [ SenseInfo('03159640-n', 0) ],
"_crossbreed_v_1_rel" : [ SenseInfo('01429953-v', 0), SenseInfo('01429953-v', 0), SenseInfo('01429953-v', 0), SenseInfo('01429953-v', 0), SenseInfo('01429953-v', 0) ],
"_simpler_a_for_rel" : [  ],
"_lethal_a_1_rel" : [ SenseInfo('00993885-a', 2) ],
"_work_v_on_rel" : [ SenseInfo('02413480-v', 74), SenseInfo('02410855-v', 62), SenseInfo('02525447-v', 32), SenseInfo('01525666-v', 20), SenseInfo('01668603-v', 9), SenseInfo('00100551-v', 9), SenseInfo('02051031-v', 5), SenseInfo('02594979-v', 4), SenseInfo('02373015-v', 3), SenseInfo('01852468-v', 3), SenseInfo('01629589-v', 3), SenseInfo('02407987-v', 2), SenseInfo('01741446-v', 2), SenseInfo('02751271-v', 0), SenseInfo('02536557-v', 0), SenseInfo('02444159-v', 0), SenseInfo('02436963-v', 0), SenseInfo('02116980-v', 0), SenseInfo('01817574-v', 0), SenseInfo('01659248-v', 0), SenseInfo('01541231-v', 0), SenseInfo('01235355-v', 0), SenseInfo('01162754-v', 0), SenseInfo('00634906-v', 0), SenseInfo('00458754-v', 0), SenseInfo('00458471-v', 0), SenseInfo('00150096-v', 0) ],
"_bias_v_against_rel" : [ SenseInfo('01085677-v', 0), SenseInfo('00680346-v', 0) ],
"_win_v_1_rel" : [ SenseInfo('01100145-v', 71), SenseInfo('02288295-v', 42), SenseInfo('01111028-v', 2), SenseInfo('02524171-v', 0), SenseInfo('01100145-v', 71), SenseInfo('02288295-v', 42), SenseInfo('01111028-v', 2), SenseInfo('02524171-v', 0), SenseInfo('01100145-v', 71), SenseInfo('02288295-v', 42), SenseInfo('01111028-v', 2), SenseInfo('02524171-v', 0) ],
"_alertness_n_1_rel" : [ SenseInfo('05705722-n', 2), SenseInfo('14036043-n', 0), SenseInfo('04664628-n', 0) ],
"_oblivious_a_to_rel" : [ SenseInfo('00192026-a', 2), SenseInfo('00165943-a', 0) ],
"_unwelcome_a_1_rel" : [ SenseInfo('02540236-a', 2), SenseInfo('02529148-a', 0), SenseInfo('02540236-a', 2), SenseInfo('02529148-a', 0) ],
"_designer_n_of_rel" : [ SenseInfo('10210648-n', 2), SenseInfo('09805475-n', 1), SenseInfo('10144055-n', 0), SenseInfo('10007809-n', 0), SenseInfo('09972157-n', 0) ],
"_kiss_n_1_rel" : [ SenseInfo('00138221-n', 7), SenseInfo('07636869-n', 0), SenseInfo('07606764-n', 0), SenseInfo('00138078-n', 0) ],
"_redwood_n_1_rel" : [ SenseInfo('11640898-n', 0), SenseInfo('11640645-n', 0) ],
"_evacuate_v_1_rel" : [ SenseInfo('01856450-v', 1), SenseInfo('00449295-v', 1), SenseInfo('02014024-v', 0), SenseInfo('00449567-v', 0), SenseInfo('00073343-v', 0) ],
"_edit_v_1_rel" : [ SenseInfo('00200397-v', 1), SenseInfo('00968038-v', 0), SenseInfo('00201722-v', 0), SenseInfo('00200863-v', 0) ],
"_gulash_n_1_rel" : [  ],
"_incoming+tide_n_1_rel" : [  ],
"_as+yet_a_1_rel" : [  ],
"_sell_n_1_rel" : [ SenseInfo('01115162-n', 0) ],
"_off-the-cuff_a_1_rel" : [ SenseInfo('01845451-a', 0), SenseInfo('01845451-a', 0), SenseInfo('01845451-a', 0) ],
"_signer_n_of_rel" : [ SenseInfo('10597505-n', 0), SenseInfo('10597234-n', 0) ],
"_amaze_v_to_rel" : [ SenseInfo('00724832-v', 4), SenseInfo('00622384-v', 1), SenseInfo('00724832-v', 4), SenseInfo('00622384-v', 1) ],
"_past_p_sel_rel" : [ SenseInfo('15120823-n', 42), SenseInfo('01727926-a', 29), SenseInfo('00417787-r', 15), SenseInfo('15141693-n', 5), SenseInfo('01296091-a', 4), SenseInfo('06330262-n', 1) ],
"_sporulation_n_1_rel" : [ SenseInfo('13517199-n', 0) ],
"_mask_v_1_rel" : [ SenseInfo('02147603-v', 1), SenseInfo('01358328-v', 1), SenseInfo('02158587-v', 0), SenseInfo('01358855-v', 0), SenseInfo('01358737-v', 0) ],
"_obstinate_a_1_rel" : [ SenseInfo('02326695-a', 0), SenseInfo('01957712-a', 0), SenseInfo('01613839-a', 0) ],
"_worldwide_a_1_rel" : [ SenseInfo('01567694-a', 1), SenseInfo('01568684-a', 0), SenseInfo('00527188-a', 0), SenseInfo('01567694-a', 1), SenseInfo('01568684-a', 0), SenseInfo('00527188-a', 0) ],
"_hookup_n_1_rel" : [ SenseInfo('03533654-n', 1), SenseInfo('03533486-n', 0), SenseInfo('03533654-n', 1), SenseInfo('03533486-n', 0), SenseInfo('03533654-n', 1), SenseInfo('03533486-n', 0) ],
"_I+guess_a_1_rel" : [  ],
"_to+begin+with_a_1_rel" : [  ],
"_mosquito_n_1_rel" : [ SenseInfo('02200198-n', 2) ],
"_calibration_n_of_rel" : [ SenseInfo('00999245-n', 7) ],
"_guitar_n_1_rel" : [ SenseInfo('03467517-n', 3) ],
"_characteristic_n_1_rel" : [ SenseInfo('05849789-n', 18), SenseInfo('04731497-n', 6), SenseInfo('06813310-n', 0), SenseInfo('04917870-n', 0) ],
"_call_v_upon_rel" : [ SenseInfo('01028748-v', 91), SenseInfo('00971015-v', 51), SenseInfo('00789448-v', 38), SenseInfo('00913065-v', 25), SenseInfo('00792471-v', 25), SenseInfo('02487573-v', 9), SenseInfo('02429810-v', 9), SenseInfo('01067995-v', 1), SenseInfo('01062739-v', 1), SenseInfo('00975036-v', 1), SenseInfo('02643421-v', 0), SenseInfo('02601456-v', 0), SenseInfo('02487901-v', 0), SenseInfo('02359061-v', 0), SenseInfo('02300060-v', 0), SenseInfo('01899017-v', 0), SenseInfo('01068793-v', 0), SenseInfo('00917772-v', 0), SenseInfo('00874002-v', 0), SenseInfo('00869393-v', 0), SenseInfo('00822746-v', 0), SenseInfo('00783523-v', 0), SenseInfo('00754156-v', 0), SenseInfo('00753881-v', 0), SenseInfo('00738747-v', 0), SenseInfo('00738583-v', 0), SenseInfo('00691516-v', 0), SenseInfo('00107231-v', 0), SenseInfo('01028748-v', 91), SenseInfo('00971015-v', 51), SenseInfo('00789448-v', 38), SenseInfo('00913065-v', 25), SenseInfo('00792471-v', 25), SenseInfo('02487573-v', 9), SenseInfo('02429810-v', 9), SenseInfo('01067995-v', 1), SenseInfo('01062739-v', 1), SenseInfo('00975036-v', 1), SenseInfo('02643421-v', 0), SenseInfo('02601456-v', 0), SenseInfo('02487901-v', 0), SenseInfo('02359061-v', 0), SenseInfo('02300060-v', 0), SenseInfo('01899017-v', 0), SenseInfo('01068793-v', 0), SenseInfo('00917772-v', 0), SenseInfo('00874002-v', 0), SenseInfo('00869393-v', 0), SenseInfo('00822746-v', 0), SenseInfo('00783523-v', 0), SenseInfo('00754156-v', 0), SenseInfo('00753881-v', 0), SenseInfo('00738747-v', 0), SenseInfo('00738583-v', 0), SenseInfo('00691516-v', 0), SenseInfo('00107231-v', 0) ],
"_assassination_n_of_rel" : [ SenseInfo('06719974-n', 0), SenseInfo('00221056-n', 0) ],
"_blood+and+guts_n_1_rel" : [  ],
"_august_a_1_rel" : [ SenseInfo('01591050-a', 0), SenseInfo('01226660-a', 0) ],
"_fertilizer_n_1_rel" : [ SenseInfo('14859344-n', 1), SenseInfo('14859344-n', 1), SenseInfo('14859344-n', 1) ],
"_yacht_n_1_rel" : [ SenseInfo('04610013-n', 1) ],
"_nap_n_1_rel" : [ SenseInfo('15273626-n', 0), SenseInfo('04947087-n', 0), SenseInfo('03936045-n', 0), SenseInfo('00858377-n', 0), SenseInfo('00493742-n', 0) ],
"_valuation_n_of_rel" : [ SenseInfo('05736149-n', 2), SenseInfo('13305673-n', 0) ],
"_haying_n_1_rel" : [ SenseInfo('01015477-n', 0), SenseInfo('00921926-n', 0) ],
"_nestling_n_1_rel" : [ SenseInfo('01504344-n', 1), SenseInfo('09917593-n', 0) ],
"_bidder_n_1_rel" : [ SenseInfo('09853087-n', 1), SenseInfo('09853184-n', 0) ],
"_budgie_n_1_rel" : [ SenseInfo('01821869-n', 0) ],
"_overcharge_v_1_rel" : [ SenseInfo('02319050-v', 0), SenseInfo('01488555-v', 0), SenseInfo('02319050-v', 0), SenseInfo('01488555-v', 0), SenseInfo('02319050-v', 0), SenseInfo('01488555-v', 0), SenseInfo('02319050-v', 0), SenseInfo('01488555-v', 0) ],
"_fray_v_1_rel" : [ SenseInfo('01369204-v', 0), SenseInfo('01250908-v', 0) ],
"_molybdenum_n_1_rel" : [ SenseInfo('14645661-n', 0) ],
"_neutralist_a_1_rel" : [ SenseInfo('10355306-n', 5) ],
"_neighbor_v_1_rel" : [ SenseInfo('02608176-v', 0), SenseInfo('02608004-v', 0), SenseInfo('02608176-v', 0), SenseInfo('02608004-v', 0) ],
"_emanate_v_1_rel" : [ SenseInfo('00546192-v', 1), SenseInfo('00004605-v', 0) ],
"_gel_n_1_rel" : [ SenseInfo('14590542-n', 0), SenseInfo('03432668-n', 0) ],
"_tradesman_n_1_rel" : [ SenseInfo('10592152-n', 1) ],
"_filofax_n_1_rel" : [  ],
"_antecedent_n_1_rel" : [ SenseInfo('09792555-n', 1), SenseInfo('07326880-n', 1), SenseInfo('13844923-n', 0), SenseInfo('06603651-n', 0) ],
"_walk_v_1_rel" : [ SenseInfo('01904930-v', 184), SenseInfo('01907076-v', 3), SenseInfo('01113473-v', 3), SenseInfo('01912893-v', 1), SenseInfo('01140654-v', 1), SenseInfo('02518839-v', 0), SenseInfo('02470518-v', 0), SenseInfo('01959776-v', 0), SenseInfo('01906823-v', 0), SenseInfo('01882170-v', 0), SenseInfo('01904930-v', 184), SenseInfo('01907076-v', 3), SenseInfo('01113473-v', 3), SenseInfo('01912893-v', 1), SenseInfo('01140654-v', 1), SenseInfo('02518839-v', 0), SenseInfo('02470518-v', 0), SenseInfo('01959776-v', 0), SenseInfo('01906823-v', 0), SenseInfo('01882170-v', 0) ],
"_schedule_v_in_rel" : [ SenseInfo('00678282-v', 21), SenseInfo('00794981-v', 6) ],
"_metalloid_n_1_rel" : [ SenseInfo('01529479-a', 0) ],
"_mesh_v_1_rel" : [ SenseInfo('01510827-v', 1), SenseInfo('00405079-v', 1), SenseInfo('02458017-v', 0), SenseInfo('01463340-v', 0) ],
"_break_v_off_rel" : [ SenseInfo('00364064-v', 15), SenseInfo('00334186-v', 13), SenseInfo('00258665-v', 9), SenseInfo('01369758-v', 8), SenseInfo('00334996-v', 8), SenseInfo('02566528-v', 5), SenseInfo('02073233-v', 4), SenseInfo('02029369-v', 4), SenseInfo('01785395-v', 4), SenseInfo('00362348-v', 4), SenseInfo('02570684-v', 3), SenseInfo('00202569-v', 3), SenseInfo('02668523-v', 2), SenseInfo('01106864-v', 2), SenseInfo('00933821-v', 2), SenseInfo('00558536-v', 2), SenseInfo('00434374-v', 2), SenseInfo('02535716-v', 1), SenseInfo('02030764-v', 1), SenseInfo('01972976-v', 1), SenseInfo('00390215-v', 1), SenseInfo('00202784-v', 1), SenseInfo('02746617-v', 0), SenseInfo('02746449-v', 0), SenseInfo('02681639-v', 0), SenseInfo('02681524-v', 0), SenseInfo('02625187-v', 0), SenseInfo('02600082-v', 0), SenseInfo('02559395-v', 0), SenseInfo('02478469-v', 0), SenseInfo('02431320-v', 0), SenseInfo('02399331-v', 0), SenseInfo('02318165-v', 0), SenseInfo('02101373-v', 0), SenseInfo('01991347-v', 0), SenseInfo('01989053-v', 0), SenseInfo('01896484-v', 0), SenseInfo('01610666-v', 0), SenseInfo('01610463-v', 0), SenseInfo('01597995-v', 0), SenseInfo('01557646-v', 0), SenseInfo('01369346-v', 0), SenseInfo('01298931-v', 0), SenseInfo('01228524-v', 0), SenseInfo('01228396-v', 0), SenseInfo('00935987-v', 0), SenseInfo('00779061-v', 0), SenseInfo('00778745-v', 0), SenseInfo('00744439-v', 0), SenseInfo('00738440-v', 0), SenseInfo('00738314-v', 0), SenseInfo('00551412-v', 0), SenseInfo('00339464-v', 0), SenseInfo('00336260-v', 0), SenseInfo('00258366-v', 0), SenseInfo('00155046-v', 0), SenseInfo('00107739-v', 0), SenseInfo('00107604-v', 0), SenseInfo('00030463-v', 0), SenseInfo('00364064-v', 15), SenseInfo('00334186-v', 13), SenseInfo('00258665-v', 9), SenseInfo('01369758-v', 8), SenseInfo('00334996-v', 8), SenseInfo('02566528-v', 5), SenseInfo('02073233-v', 4), SenseInfo('02029369-v', 4), SenseInfo('01785395-v', 4), SenseInfo('00362348-v', 4), SenseInfo('02570684-v', 3), SenseInfo('00202569-v', 3), SenseInfo('02668523-v', 2), SenseInfo('01106864-v', 2), SenseInfo('00933821-v', 2), SenseInfo('00558536-v', 2), SenseInfo('00434374-v', 2), SenseInfo('02535716-v', 1), SenseInfo('02030764-v', 1), SenseInfo('01972976-v', 1), SenseInfo('00390215-v', 1), SenseInfo('00202784-v', 1), SenseInfo('02746617-v', 0), SenseInfo('02746449-v', 0), SenseInfo('02681639-v', 0), SenseInfo('02681524-v', 0), SenseInfo('02625187-v', 0), SenseInfo('02600082-v', 0), SenseInfo('02559395-v', 0), SenseInfo('02478469-v', 0), SenseInfo('02431320-v', 0), SenseInfo('02399331-v', 0), SenseInfo('02318165-v', 0), SenseInfo('02101373-v', 0), SenseInfo('01991347-v', 0), SenseInfo('01989053-v', 0), SenseInfo('01896484-v', 0), SenseInfo('01610666-v', 0), SenseInfo('01610463-v', 0), SenseInfo('01597995-v', 0), SenseInfo('01557646-v', 0), SenseInfo('01369346-v', 0), SenseInfo('01298931-v', 0), SenseInfo('01228524-v', 0), SenseInfo('01228396-v', 0), SenseInfo('00935987-v', 0), SenseInfo('00779061-v', 0), SenseInfo('00778745-v', 0), SenseInfo('00744439-v', 0), SenseInfo('00738440-v', 0), SenseInfo('00738314-v', 0), SenseInfo('00551412-v', 0), SenseInfo('00339464-v', 0), SenseInfo('00336260-v', 0), SenseInfo('00258366-v', 0), SenseInfo('00155046-v', 0), SenseInfo('00107739-v', 0), SenseInfo('00107604-v', 0), SenseInfo('00030463-v', 0) ],
"_component_n_1_rel" : [ SenseInfo('05868954-n', 20), SenseInfo('13809207-n', 10), SenseInfo('03081021-n', 4) ],
"_feed_v_1_rel" : [ SenseInfo('01182021-v', 47), SenseInfo('01178565-v', 15), SenseInfo('01181166-v', 5), SenseInfo('00189511-v', 4), SenseInfo('02555787-v', 3), SenseInfo('01179865-v', 3), SenseInfo('01180206-v', 1), SenseInfo('02066939-v', 0), SenseInfo('01203715-v', 0), SenseInfo('01182152-v', 0), SenseInfo('00502757-v', 0), SenseInfo('01182021-v', 47), SenseInfo('01178565-v', 15), SenseInfo('01181166-v', 5), SenseInfo('00189511-v', 4), SenseInfo('02555787-v', 3), SenseInfo('01179865-v', 3), SenseInfo('01180206-v', 1), SenseInfo('02066939-v', 0), SenseInfo('01203715-v', 0), SenseInfo('01182152-v', 0), SenseInfo('00502757-v', 0) ],
"_sequence_n_1_rel" : [ SenseInfo('08459252-n', 13), SenseInfo('05044822-n', 3), SenseInfo('04173172-n', 3), SenseInfo('01010458-n', 3), SenseInfo('07342383-n', 0) ],
"_disloyal_a_to_rel" : [ SenseInfo('01740630-a', 0), SenseInfo('00962634-a', 0) ],
"_nimble_a_1_rel" : [ SenseInfo('00032733-a', 1), SenseInfo('01334833-a', 0), SenseInfo('00032733-a', 1), SenseInfo('01334833-a', 0), SenseInfo('00032733-a', 1), SenseInfo('01334833-a', 0) ],
"_any+more_q_rel" : [  ],
"_impregnate_v_1_rel" : [ SenseInfo('00498299-v', 0), SenseInfo('00497705-v', 0), SenseInfo('00053341-v', 0), SenseInfo('00053159-v', 0) ],
"_wanted_a_1_rel" : [ SenseInfo('02526925-a', 0), SenseInfo('01462625-a', 0), SenseInfo('02526925-a', 0), SenseInfo('01462625-a', 0), SenseInfo('02526925-a', 0), SenseInfo('01462625-a', 0) ],
"_orienteering_n_1_rel" : [  ],
"_cupboard_n_1_rel" : [ SenseInfo('03148324-n', 2) ],
"_ndoro_n_1_rel" : [  ],
"_placemat_n_1_rel" : [  ],
"_flunk_v_out_rel" : [ SenseInfo('02523521-v', 0) ],
"_waffle_n_1_rel" : [ SenseInfo('07641699-n', 1) ],
"_whipstock_n_1_rel" : [  ],
"_yawn_v_1_rel" : [ SenseInfo('00007328-v', 3), SenseInfo('02718750-v', 0) ],
"_spray_n_1_rel" : [ SenseInfo('15052555-n', 3), SenseInfo('13762305-n', 1), SenseInfo('04287610-n', 1), SenseInfo('02754103-n', 1), SenseInfo('15056541-n', 0), SenseInfo('07446533-n', 0) ],
"_bloodhound_n_1_rel" : [ SenseInfo('02088466-n', 2) ],
"_meteorological_a_1_rel" : [ SenseInfo('02865479-a', 1) ],
"_continuity_n_1_rel" : [ SenseInfo('14422035-n', 12), SenseInfo('07010393-n', 0), SenseInfo('05054130-n', 0) ],
"_a+little_x_deg_rel" : [ SenseInfo('00033663-r', 80), SenseInfo('00033663-r', 80) ],
"_unofficial_a_1_rel" : [ SenseInfo('01633591-a', 3), SenseInfo('01635018-a', 0), SenseInfo('01633591-a', 3), SenseInfo('01635018-a', 0) ],
"_prey_n_i_rel" : [ SenseInfo('10470460-n', 3), SenseInfo('02152881-n', 2) ],
"_enough_q_rel" : [  ],
"_soot_n_1_rel" : [ SenseInfo('14793533-n', 0) ],
"_grace_n_1_rel" : [ SenseInfo('14458181-n', 4), SenseInfo('05003590-n', 4), SenseInfo('04900357-n', 2), SenseInfo('04640356-n', 1), SenseInfo('09495382-n', 0), SenseInfo('07190039-n', 0), SenseInfo('04840715-n', 0) ],
"_with_p_sel_rel" : [  ],
"_blase_n_1_rel" : [ SenseInfo('02270782-a', 0), SenseInfo('01343200-a', 0), SenseInfo('00545484-a', 0) ],
"_convict_v_of_rel" : [ SenseInfo('00906367-v', 11), SenseInfo('00906367-v', 11) ],
"_constitutional_n_1_rel" : [ SenseInfo('00284544-n', 0) ],
"_distinctive_n_1_rel" : [ SenseInfo('00357556-a', 5), SenseInfo('01272718-a', 3) ],
"_the+case_a_1_rel" : [  ],
"_keep_v_to_rel" : [ SenseInfo('02681795-v', 206), SenseInfo('02684924-v', 39), SenseInfo('02202384-v', 32), SenseInfo('02450505-v', 22), SenseInfo('02578872-v', 10), SenseInfo('00732552-v', 9), SenseInfo('02202928-v', 8), SenseInfo('01065877-v', 4), SenseInfo('02651853-v', 3), SenseInfo('02410175-v', 3), SenseInfo('01184625-v', 3), SenseInfo('02734800-v', 2), SenseInfo('02578510-v', 2), SenseInfo('02422663-v', 2), SenseInfo('02733122-v', 1), SenseInfo('02652016-v', 0), SenseInfo('02283716-v', 0), SenseInfo('02204094-v', 0), SenseInfo('02203844-v', 0), SenseInfo('02203168-v', 0), SenseInfo('01302019-v', 0), SenseInfo('00212414-v', 0) ],
"_grain_n_1_rel" : [ SenseInfo('09290777-n', 2), SenseInfo('07802417-n', 1), SenseInfo('14760339-n', 0), SenseInfo('13723304-n', 0), SenseInfo('13721893-n', 0), SenseInfo('13719683-n', 0), SenseInfo('12156819-n', 0), SenseInfo('12141385-n', 0), SenseInfo('05107322-n', 0), SenseInfo('04950713-n', 0), SenseInfo('04934220-n', 0) ],
"_reef_v_1_rel" : [ SenseInfo('01973636-v', 0), SenseInfo('00436185-v', 0), SenseInfo('00241399-v', 0) ],
"_hunt_v_up_rel" : [ SenseInfo('01143838-v', 4), SenseInfo('02003601-v', 2), SenseInfo('02056691-v', 0), SenseInfo('02034147-v', 0), SenseInfo('01878376-v', 0), SenseInfo('01316401-v', 0), SenseInfo('01144657-v', 0) ],
"_colombian_a_1_rel" : [ SenseInfo('02967618-a', 1) ],
"_puffin_n_1_rel" : [ SenseInfo('02047614-n', 0) ],
"_phosphate_n_1_rel" : [ SenseInfo('14982265-n', 9), SenseInfo('07928578-n', 0) ],
"_LOL_a_1_rel" : [  ],
"_torpidness_n_1_rel" : [ SenseInfo('04636881-n', 0) ],
"_all+day+long_a_1_rel" : [  ],
"_poplar_n_1_rel" : [ SenseInfo('12731714-n', 0), SenseInfo('12731401-n', 0) ],
"_zone_v_out_rel" : [ SenseInfo('02512150-v', 0), SenseInfo('00332835-v', 0) ],
"_cease_v_cause_rel" : [ SenseInfo('02680814-v', 25), SenseInfo('02609764-v', 6) ],
"_stimulation_n_of_rel" : [ SenseInfo('01261974-n', 5), SenseInfo('05827684-n', 3), SenseInfo('13561719-n', 0), SenseInfo('00853835-n', 0) ],
"_tasteful_a_1_rel" : [ SenseInfo('02392878-a', 1), SenseInfo('00850648-a', 0), SenseInfo('02392878-a', 1), SenseInfo('00850648-a', 0) ],
"_versification_n_1_rel" : [ SenseInfo('07093759-n', 0), SenseInfo('07093603-n', 0), SenseInfo('07093489-n', 0) ],
"_cessation_n_1_rel" : [ SenseInfo('07362075-n', 0) ],
"_spice_n_1_rel" : [ SenseInfo('15050011-n', 1), SenseInfo('07812184-n', 0), SenseInfo('04992570-n', 0) ],
"_whence_p_rel" : [ SenseInfo('00495309-r', 1), SenseInfo('00495309-r', 1) ],
"_weird_a_1_rel" : [ SenseInfo('01575424-a', 8), SenseInfo('00970081-a', 0), SenseInfo('01575424-a', 8), SenseInfo('00970081-a', 0), SenseInfo('01575424-a', 8), SenseInfo('00970081-a', 0) ],
"_companion_n_1_rel" : [ SenseInfo('09945905-n', 25), SenseInfo('09946278-n', 9), SenseInfo('09760609-n', 0) ],
"_tint_v_1_rel" : [ SenseInfo('00286928-v', 1) ],
"_comprehension_n_1_rel" : [ SenseInfo('05805902-n', 5), SenseInfo('13794034-n', 0), SenseInfo('05805902-n', 5), SenseInfo('13794034-n', 0) ],
"_sage_a_1_rel" : [ SenseInfo('02570183-a', 0), SenseInfo('00383189-a', 0) ],
"_condemn_v_as_rel" : [ SenseInfo('00864159-v', 18), SenseInfo('00856578-v', 2), SenseInfo('02507093-v', 1), SenseInfo('02149302-v', 1), SenseInfo('00906735-v', 1), SenseInfo('02273768-v', 0), SenseInfo('00864159-v', 18), SenseInfo('00856578-v', 2), SenseInfo('02507093-v', 1), SenseInfo('02149302-v', 1), SenseInfo('00906735-v', 1), SenseInfo('02273768-v', 0) ],
"_barbarous_a_1_rel" : [ SenseInfo('01263013-a', 0), SenseInfo('00413224-a', 0) ],
"_alloy_n_1_rel" : [ SenseInfo('14586769-n', 0), SenseInfo('14487598-n', 0) ],
"_expiration_n_1_rel" : [ SenseInfo('15268682-n', 2), SenseInfo('07333649-n', 0), SenseInfo('00835267-n', 0) ],
"_smallholding_n_1_rel" : [ SenseInfo('13249245-n', 0) ],
"_post_n_of_rel" : [ SenseInfo('08624385-n', 3), SenseInfo('03763403-n', 3), SenseInfo('00586262-n', 3), SenseInfo('03988170-n', 2), SenseInfo('11243907-n', 0), SenseInfo('11243720-n', 0), SenseInfo('11243562-n', 0), SenseInfo('08463063-n', 0), SenseInfo('07257815-n', 0), SenseInfo('06264398-n', 0), SenseInfo('00318186-n', 0), SenseInfo('08624385-n', 3), SenseInfo('03763403-n', 3), SenseInfo('00586262-n', 3), SenseInfo('03988170-n', 2), SenseInfo('11243907-n', 0), SenseInfo('11243720-n', 0), SenseInfo('11243562-n', 0), SenseInfo('08463063-n', 0), SenseInfo('07257815-n', 0), SenseInfo('06264398-n', 0), SenseInfo('00318186-n', 0) ],
"_tt_a_1_rel" : [ SenseInfo('15156746-n', 0), SenseInfo('08978161-n', 0), SenseInfo('08837048-n', 0) ],
"_daisy_n_1_rel" : [ SenseInfo('11939491-n', 1) ],
"_server_n_1_rel" : [ SenseInfo('10763383-n', 0), SenseInfo('10582604-n', 0), SenseInfo('04175147-n', 0), SenseInfo('04175039-n', 0) ],
"_transition_n_1_rel" : [ SenseInfo('00201058-n', 10), SenseInfo('07415730-n', 3), SenseInfo('07358576-n', 1), SenseInfo('07087641-n', 0), SenseInfo('06401328-n', 0) ],
"_flute_v_1_rel" : [ SenseInfo('01457376-v', 0), SenseInfo('01457376-v', 0) ],
"_gaze_v_1_rel" : [ SenseInfo('02132745-v', 25) ],
"_commit_v_to_rel" : [ SenseInfo('02582615-v', 12), SenseInfo('00887463-v', 12), SenseInfo('02348568-v', 3), SenseInfo('02349212-v', 1), SenseInfo('02271137-v', 1), SenseInfo('02375468-v', 0), SenseInfo('02582615-v', 12), SenseInfo('00887463-v', 12), SenseInfo('02348568-v', 3), SenseInfo('02349212-v', 1), SenseInfo('02271137-v', 1), SenseInfo('02375468-v', 0) ],
"_cellule_n_1_rel" : [  ],
"_optimism_n_1_rel" : [ SenseInfo('07541558-n', 2), SenseInfo('05211793-n', 0), SenseInfo('07541558-n', 2), SenseInfo('05211793-n', 0) ],
"_cocaine_n_1_rel" : [ SenseInfo('03060294-n', 1) ],
"_over+and+over_a_1_rel" : [  ],
"_magic_n_1_rel" : [ SenseInfo('05967977-n', 4), SenseInfo('00099951-n', 0) ],
"_generous_a_1_rel" : [ SenseInfo('01111016-a', 2), SenseInfo('01114434-a', 1), SenseInfo('00106182-a', 1), SenseInfo('01111016-a', 2), SenseInfo('01114434-a', 1), SenseInfo('00106182-a', 1) ],
"_counter_n_1_rel" : [ SenseInfo('03116530-n', 3), SenseInfo('03117199-n', 1), SenseInfo('03116767-n', 1), SenseInfo('02912065-n', 1), SenseInfo('09969491-n', 0), SenseInfo('07199922-n', 0), SenseInfo('03117420-n', 0), SenseInfo('03116942-n', 0), SenseInfo('00135504-n', 0) ],
"_guilty_a_of_rel" : [ SenseInfo('01320988-a', 10), SenseInfo('00154583-a', 2) ],
"_timer_n_1_rel" : [ SenseInfo('04438304-n', 1), SenseInfo('10711483-n', 0), SenseInfo('04438507-n', 0) ],
"_surpass_v_1_rel" : [ SenseInfo('02673965-v', 2), SenseInfo('01105639-v', 2), SenseInfo('02051694-v', 1), SenseInfo('02669477-v', 0) ],
"_first+aid_n_1_rel" : [ SenseInfo('00656524-n', 1) ],
"_creek_n_1_rel" : [ SenseInfo('09229409-n', 7), SenseInfo('09654079-n', 0), SenseInfo('09229409-n', 7), SenseInfo('09654079-n', 0) ],
"_amnesty_n_1_rel" : [ SenseInfo('14529082-n', 0), SenseInfo('06552639-n', 0), SenseInfo('01249315-n', 0) ],
"_bc_x_rel" : [ SenseInfo('00002142-r', 0), SenseInfo('00002142-r', 0), SenseInfo('00002142-r', 0), SenseInfo('00002142-r', 0), SenseInfo('00002142-r', 0), SenseInfo('00002142-r', 0), SenseInfo('00002142-r', 0), SenseInfo('00002142-r', 0), SenseInfo('00002142-r', 0), SenseInfo('00002142-r', 0) ],
"_impart_v_to_rel" : [ SenseInfo('02296153-v', 7), SenseInfo('02324478-v', 1), SenseInfo('02079933-v', 0) ],
"_humorous_a_1_rel" : [ SenseInfo('01264336-a', 9), SenseInfo('01264336-a', 9), SenseInfo('01264336-a', 9), SenseInfo('01264336-a', 9) ],
"_derivative_a_1_rel" : [ SenseInfo('00698586-a', 0) ],
"_spanish_a_1_rel" : [ SenseInfo('02958576-a', 3) ],
"_enclave_n_1_rel" : [ SenseInfo('08553132-n', 1) ],
"_calm_v_down_rel" : [ SenseInfo('01764800-v', 5), SenseInfo('00416571-v', 1), SenseInfo('01763829-v', 0), SenseInfo('00022316-v', 0), SenseInfo('01764800-v', 5), SenseInfo('00416571-v', 1), SenseInfo('01763829-v', 0), SenseInfo('00022316-v', 0) ],
"_platinum_n_1_rel" : [ SenseInfo('14649543-n', 3) ],
"_tab_n_1_rel" : [ SenseInfo('06517942-n', 0), SenseInfo('06267991-n', 0), SenseInfo('04379096-n', 0), SenseInfo('04378123-n', 0), SenseInfo('03936568-n', 0) ],
"_gear_n_1_rel" : [ SenseInfo('03430551-n', 1), SenseInfo('03431745-n', 0), SenseInfo('03431243-n', 0), SenseInfo('03430959-n', 0) ],
"_linkage_n_1_rel" : [ SenseInfo('13792579-n', 0), SenseInfo('04923024-n', 0), SenseInfo('03674440-n', 0), SenseInfo('00148978-n', 0) ],
"_babble_n_1_rel" : [ SenseInfo('06610143-n', 0) ],
"_out-class_v_1_rel" : [ SenseInfo('00659373-v', 1), SenseInfo('00659373-v', 1) ],
"_parse_n_1_rel" : [  ],
"_windproof_n_1_rel" : [  ],
"_lunchtime_n_1_rel" : [ SenseInfo('15165917-n', 0), SenseInfo('15165917-n', 0) ],
"_barb_n_1_rel" : [ SenseInfo('06767922-n', 1), SenseInfo('02790550-n', 0), SenseInfo('02790322-n', 0), SenseInfo('01898185-n', 0) ],
"_bilk_v_of_rel" : [ SenseInfo('02572792-v', 1), SenseInfo('02558172-v', 0), SenseInfo('02313801-v', 0), SenseInfo('02074377-v', 0), SenseInfo('02572792-v', 1), SenseInfo('02558172-v', 0), SenseInfo('02313801-v', 0), SenseInfo('02074377-v', 0) ],
"_automatic_a_1_rel" : [ SenseInfo('00181476-a', 7), SenseInfo('01499999-a', 5), SenseInfo('02522669-a', 1), SenseInfo('00181476-a', 7), SenseInfo('01499999-a', 5), SenseInfo('02522669-a', 1) ],
"_uninspired_a_1_rel" : [ SenseInfo('00923066-a', 0), SenseInfo('00644560-a', 0), SenseInfo('00923066-a', 0), SenseInfo('00644560-a', 0) ],
"_similar_a_to_rel" : [ SenseInfo('02071420-a', 61), SenseInfo('01410606-a', 6), SenseInfo('01409581-a', 0), SenseInfo('02381495-a', 0), SenseInfo('01978532-a', 0), SenseInfo('02071420-a', 61), SenseInfo('01410606-a', 6), SenseInfo('01409581-a', 0), SenseInfo('02381495-a', 0), SenseInfo('01978532-a', 0), SenseInfo('02071420-a', 61), SenseInfo('01410606-a', 6), SenseInfo('01409581-a', 0), SenseInfo('02381495-a', 0), SenseInfo('01978532-a', 0) ],
"_marked_a_1_rel" : [ SenseInfo('01287808-a', 15), SenseInfo('00580684-a', 2), SenseInfo('01480186-a', 1) ],
"_cut_v_out_rel" : [ SenseInfo('01552519-v', 58), SenseInfo('00429060-v', 18), SenseInfo('02033295-v', 3), SenseInfo('01610834-v', 2), SenseInfo('02422283-v', 1), SenseInfo('01754915-v', 1), SenseInfo('01666717-v', 1), SenseInfo('01413917-v', 1), SenseInfo('01064799-v', 1), SenseInfo('00201722-v', 1), SenseInfo('02613860-v', 0), SenseInfo('02588280-v', 0), SenseInfo('02134232-v', 0), SenseInfo('02101649-v', 0), SenseInfo('01915865-v', 0), SenseInfo('01915730-v', 0), SenseInfo('01860107-v', 0), SenseInfo('01859995-v', 0), SenseInfo('01756563-v', 0), SenseInfo('01756416-v', 0), SenseInfo('01756277-v', 0), SenseInfo('01754737-v', 0), SenseInfo('01713491-v', 0), SenseInfo('01611123-v', 0), SenseInfo('01610990-v', 0), SenseInfo('01555437-v', 0), SenseInfo('01510576-v', 0), SenseInfo('01320424-v', 0), SenseInfo('01319738-v', 0), SenseInfo('01227088-v', 0), SenseInfo('01059564-v', 0), SenseInfo('00561090-v', 0), SenseInfo('00473322-v', 0), SenseInfo('00447654-v', 0), SenseInfo('00429968-v', 0), SenseInfo('00292507-v', 0), SenseInfo('00243900-v', 0), SenseInfo('00226071-v', 0), SenseInfo('00108475-v', 0), SenseInfo('00096136-v', 0), SenseInfo('00061219-v', 0) ],
"_while_x_rel" : [ SenseInfo('15246353-n', 23), SenseInfo('15246353-n', 23), SenseInfo('15246353-n', 23), SenseInfo('15246353-n', 23), SenseInfo('15246353-n', 23) ],
"_contemporaneous_a_1_rel" : [ SenseInfo('02378872-a', 0), SenseInfo('02378191-a', 0) ],
"_animate_v_1_rel" : [ SenseInfo('01812720-v', 1), SenseInfo('00547995-v', 0), SenseInfo('00192836-v', 0), SenseInfo('00024279-v', 0) ],
"_tribe_n_1_rel" : [ SenseInfo('08372411-n', 0), SenseInfo('08168531-n', 0), SenseInfo('08108784-n', 0), SenseInfo('07969695-n', 0) ],
"_what+is+more_a_1_rel" : [  ],
"_viewfinder_n_1_rel" : [ SenseInfo('03340723-n', 0) ],
"_twice_x_deg_rel" : [ SenseInfo('00065294-r', 21), SenseInfo('00083393-r', 4) ],
"_eloquent_a_1_rel" : [ SenseInfo('00150505-a', 4), SenseInfo('00150505-a', 4) ],
"_offshore_p_rel" : [ SenseInfo('00140049-r', 1), SenseInfo('00464399-a', 0), SenseInfo('01381340-a', 0) ],
"_warrant_n_1_rel" : [ SenseInfo('06547059-n', 2), SenseInfo('13418219-n', 0), SenseInfo('06687358-n', 0), SenseInfo('06685456-n', 0) ],
"_virgin_n_1_rel" : [ SenseInfo('10755257-n', 5), SenseInfo('09752927-n', 0), SenseInfo('08686979-n', 0) ],
"_snack_n_1_rel" : [ SenseInfo('07577374-n', 1) ],
"_control_v_1_rel" : [ SenseInfo('02441022-v', 28), SenseInfo('02510337-v', 20), SenseInfo('01224744-v', 7), SenseInfo('01803936-v', 1), SenseInfo('02520997-v', 0), SenseInfo('00663160-v', 0), SenseInfo('00662589-v', 0), SenseInfo('00597385-v', 0), SenseInfo('02441022-v', 28), SenseInfo('02510337-v', 20), SenseInfo('01224744-v', 7), SenseInfo('01803936-v', 1), SenseInfo('02520997-v', 0), SenseInfo('00663160-v', 0), SenseInfo('00662589-v', 0), SenseInfo('00597385-v', 0), SenseInfo('02441022-v', 28), SenseInfo('02510337-v', 20), SenseInfo('01224744-v', 7), SenseInfo('01803936-v', 1), SenseInfo('02520997-v', 0), SenseInfo('00663160-v', 0), SenseInfo('00662589-v', 0), SenseInfo('00597385-v', 0), SenseInfo('02441022-v', 28), SenseInfo('02510337-v', 20), SenseInfo('01224744-v', 7), SenseInfo('01803936-v', 1), SenseInfo('02520997-v', 0), SenseInfo('00663160-v', 0), SenseInfo('00662589-v', 0), SenseInfo('00597385-v', 0) ],
"_susceptible_a_to_rel" : [ SenseInfo('02360448-a', 2), SenseInfo('02365142-a', 0) ],
"_originate_v_1_rel" : [ SenseInfo('02624263-v', 12), SenseInfo('01628449-v', 4), SenseInfo('02743343-v', 0) ],
"_body+politic_n_1_rel" : [ SenseInfo('08168978-n', 0), SenseInfo('08168978-n', 0), SenseInfo('08168978-n', 0) ],
"_white_a_1_rel" : [ SenseInfo('00393105-a', 61), SenseInfo('00243180-a', 15), SenseInfo('01905235-a', 0), SenseInfo('01698231-a', 0), SenseInfo('01327680-a', 0), SenseInfo('01250991-a', 0), SenseInfo('01130932-a', 0), SenseInfo('01087093-a', 0), SenseInfo('00756638-a', 0), SenseInfo('00406743-a', 0), SenseInfo('00404568-a', 0), SenseInfo('00272950-a', 0), SenseInfo('00393105-a', 61), SenseInfo('00243180-a', 15), SenseInfo('01905235-a', 0), SenseInfo('01698231-a', 0), SenseInfo('01327680-a', 0), SenseInfo('01250991-a', 0), SenseInfo('01130932-a', 0), SenseInfo('01087093-a', 0), SenseInfo('00756638-a', 0), SenseInfo('00406743-a', 0), SenseInfo('00404568-a', 0), SenseInfo('00272950-a', 0), SenseInfo('00393105-a', 61), SenseInfo('00243180-a', 15), SenseInfo('01905235-a', 0), SenseInfo('01698231-a', 0), SenseInfo('01327680-a', 0), SenseInfo('01250991-a', 0), SenseInfo('01130932-a', 0), SenseInfo('01087093-a', 0), SenseInfo('00756638-a', 0), SenseInfo('00406743-a', 0), SenseInfo('00404568-a', 0), SenseInfo('00272950-a', 0) ],
"_year+to+year_a_1_rel" : [  ],
"_wolverine_n_1_rel" : [ SenseInfo('09743690-n', 0), SenseInfo('02449350-n', 0), SenseInfo('02449183-n', 0), SenseInfo('09743690-n', 0), SenseInfo('02449350-n', 0), SenseInfo('02449183-n', 0) ],
"_diver_n_1_rel" : [ SenseInfo('10019552-n', 0), SenseInfo('10019406-n', 0), SenseInfo('02049088-n', 0) ],
"_muffle_n_1_rel" : [ SenseInfo('03797062-n', 0) ],
"_sightseeing_a_for_rel" : [ SenseInfo('00879607-n', 2) ],
"_port_v_from-to_rel" : [ SenseInfo('02090854-v', 0), SenseInfo('02087472-v', 0), SenseInfo('01979085-v', 0), SenseInfo('01908204-v', 0), SenseInfo('01450792-v', 0), SenseInfo('01239202-v', 0), SenseInfo('01171661-v', 0), SenseInfo('00587268-v', 0) ],
"_bed_n_1_rel" : [ SenseInfo('02818832-n', 51), SenseInfo('02819474-n', 3), SenseInfo('09217638-n', 2), SenseInfo('09217867-n', 0), SenseInfo('08659076-n', 0), SenseInfo('03650173-n', 0), SenseInfo('02819881-n', 0), SenseInfo('02819697-n', 0), SenseInfo('02818832-n', 51), SenseInfo('02819474-n', 3), SenseInfo('09217638-n', 2), SenseInfo('09217867-n', 0), SenseInfo('08659076-n', 0), SenseInfo('03650173-n', 0), SenseInfo('02819881-n', 0), SenseInfo('02819697-n', 0) ],
"_semitone_n_1_rel" : [ SenseInfo('06859175-n', 0) ],
"_saga_n_of_rel" : [ SenseInfo('06370522-n', 2) ],
"_federal_a_1_rel" : [ SenseInfo('01106129-a', 39), SenseInfo('02725829-a', 5), SenseInfo('01606214-a', 4), SenseInfo('01107206-a', 0), SenseInfo('01106129-a', 39), SenseInfo('02725829-a', 5), SenseInfo('01606214-a', 4), SenseInfo('01107206-a', 0) ],
"_garter_n_1_rel" : [ SenseInfo('03421117-n', 0) ],
"_harangue_v_1_rel" : [ SenseInfo('00990249-v', 4) ],
"_contradict_v_1_rel" : [ SenseInfo('02663141-v', 5), SenseInfo('00823436-v', 1), SenseInfo('00776059-v', 0), SenseInfo('00666886-v', 0) ],
"_dean_v_1_rel" : [  ],
"_compulsion_n_1_rel" : [ SenseInfo('09181330-n', 3), SenseInfo('09183255-n', 1), SenseInfo('00156812-n', 1), SenseInfo('09181330-n', 3), SenseInfo('09183255-n', 1), SenseInfo('00156812-n', 1) ],
"_analogical_a_1_rel" : [ SenseInfo('01419462-a', 0) ],
"_syncline_n_1_rel" : [  ],
"_lament_n_1_rel" : [ SenseInfo('07211950-n', 0), SenseInfo('07050619-n', 0), SenseInfo('06379568-n', 0), SenseInfo('07211950-n', 0), SenseInfo('07050619-n', 0), SenseInfo('06379568-n', 0) ],
"_bitter_a_1_rel" : [ SenseInfo('00116744-a', 12), SenseInfo('02435901-a', 10), SenseInfo('01802165-a', 6), SenseInfo('01364993-a', 2), SenseInfo('01245610-a', 1), SenseInfo('02396098-a', 0), SenseInfo('01711910-a', 0), SenseInfo('00116744-a', 12), SenseInfo('02435901-a', 10), SenseInfo('01802165-a', 6), SenseInfo('01364993-a', 2), SenseInfo('01245610-a', 1), SenseInfo('02396098-a', 0), SenseInfo('01711910-a', 0), SenseInfo('00116744-a', 12), SenseInfo('02435901-a', 10), SenseInfo('01802165-a', 6), SenseInfo('01364993-a', 2), SenseInfo('01245610-a', 1), SenseInfo('02396098-a', 0), SenseInfo('01711910-a', 0), SenseInfo('00116744-a', 12), SenseInfo('02435901-a', 10), SenseInfo('01802165-a', 6), SenseInfo('01364993-a', 2), SenseInfo('01245610-a', 1), SenseInfo('02396098-a', 0), SenseInfo('01711910-a', 0) ],
"_due_x_dir_rel" : [ SenseInfo('00136354-a', 6), SenseInfo('05176082-n', 4), SenseInfo('00929916-a', 1), SenseInfo('00137725-a', 0), SenseInfo('13396861-n', 0), SenseInfo('00052152-r', 0), SenseInfo('00171872-a', 0) ],
"_diarrheal_a_1_rel" : [ SenseInfo('00638622-a', 0) ],
"_woman_n_1_rel" : [ SenseInfo('10787470-n', 143), SenseInfo('10788852-n', 1), SenseInfo('09911226-n', 0), SenseInfo('08477634-n', 0), SenseInfo('10787470-n', 143), SenseInfo('10788852-n', 1), SenseInfo('09911226-n', 0), SenseInfo('08477634-n', 0) ],
"_pass_v_over_rel" : [ SenseInfo('02050132-v', 32), SenseInfo('02051694-v', 31), SenseInfo('02466670-v', 29), SenseInfo('02072849-v', 17), SenseInfo('02230772-v', 13), SenseInfo('02685951-v', 8), SenseInfo('02049696-v', 8), SenseInfo('00339934-v', 7), SenseInfo('02523351-v', 4), SenseInfo('02708420-v', 3), SenseInfo('01212230-v', 3), SenseInfo('00742320-v', 3), SenseInfo('00421691-v', 3), SenseInfo('02525044-v', 2), SenseInfo('02669081-v', 1), SenseInfo('02523953-v', 1), SenseInfo('02423513-v', 1), SenseInfo('02221635-v', 1), SenseInfo('01972131-v', 1), SenseInfo('02231473-v', 0), SenseInfo('02229550-v', 0), SenseInfo('02052476-v', 0), SenseInfo('00803325-v', 0), SenseInfo('00358431-v', 0), SenseInfo('00072989-v', 0) ],
"_dig_n_1_rel" : [ SenseInfo('08550076-n', 0), SenseInfo('06767922-n', 0), SenseInfo('04693557-n', 0), SenseInfo('00941974-n', 0), SenseInfo('00135311-n', 0) ],
"_digest_n_1_rel" : [ SenseInfo('06593542-n', 0), SenseInfo('06593099-n', 0) ],
"_expensive_a_for_rel" : [ SenseInfo('00933154-a', 13), SenseInfo('00933154-a', 13), SenseInfo('00933154-a', 13) ],
"_colon_p_namely_rel" : [ SenseInfo('05535869-n', 2), SenseInfo('13667643-n', 0), SenseInfo('13667372-n', 0), SenseInfo('08739669-n', 0), SenseInfo('06842660-n', 0), SenseInfo('05535869-n', 2), SenseInfo('13667643-n', 0), SenseInfo('13667372-n', 0), SenseInfo('08739669-n', 0), SenseInfo('06842660-n', 0), SenseInfo('05535869-n', 2), SenseInfo('13667643-n', 0), SenseInfo('13667372-n', 0), SenseInfo('08739669-n', 0), SenseInfo('06842660-n', 0), SenseInfo('05535869-n', 2), SenseInfo('13667643-n', 0), SenseInfo('13667372-n', 0), SenseInfo('08739669-n', 0), SenseInfo('06842660-n', 0), SenseInfo('05535869-n', 2), SenseInfo('13667643-n', 0), SenseInfo('13667372-n', 0), SenseInfo('08739669-n', 0), SenseInfo('06842660-n', 0), SenseInfo('05535869-n', 2), SenseInfo('13667643-n', 0), SenseInfo('13667372-n', 0), SenseInfo('08739669-n', 0), SenseInfo('06842660-n', 0) ],
"_buy_v_1_rel" : [ SenseInfo('02207206-v', 102), SenseInfo('02284096-v', 2), SenseInfo('02646757-v', 0), SenseInfo('02212103-v', 0), SenseInfo('00683670-v', 0), SenseInfo('02207206-v', 102), SenseInfo('02284096-v', 2), SenseInfo('02646757-v', 0), SenseInfo('02212103-v', 0), SenseInfo('00683670-v', 0) ],
"_labor_n_1_rel" : [ SenseInfo('08180639-n', 20), SenseInfo('00620752-n', 20), SenseInfo('14048441-n', 0), SenseInfo('08472890-n', 0), SenseInfo('08261320-n', 0), SenseInfo('08137495-n', 0), SenseInfo('00795720-n', 0), SenseInfo('08180639-n', 20), SenseInfo('00620752-n', 20), SenseInfo('14048441-n', 0), SenseInfo('08472890-n', 0), SenseInfo('08261320-n', 0), SenseInfo('08137495-n', 0), SenseInfo('00795720-n', 0) ],
"_trim_a_1_rel" : [ SenseInfo('00991301-a', 1), SenseInfo('02423649-a', 0), SenseInfo('02423073-a', 0), SenseInfo('01793985-a', 0), SenseInfo('00991301-a', 1), SenseInfo('02423649-a', 0), SenseInfo('02423073-a', 0), SenseInfo('01793985-a', 0), SenseInfo('00991301-a', 1), SenseInfo('02423649-a', 0), SenseInfo('02423073-a', 0), SenseInfo('01793985-a', 0) ],
"_priority_n_1_rel" : [ SenseInfo('13949802-n', 7), SenseInfo('05047279-n', 0) ],
"_determine_v_1_rel" : [ SenseInfo('00918872-v', 107), SenseInfo('00701040-v', 21), SenseInfo('00699815-v', 18), SenseInfo('00947077-v', 11), SenseInfo('00697589-v', 9), SenseInfo('00700708-v', 7), SenseInfo('00763399-v', 1), SenseInfo('00920336-v', 0), SenseInfo('00918872-v', 107), SenseInfo('00701040-v', 21), SenseInfo('00699815-v', 18), SenseInfo('00947077-v', 11), SenseInfo('00697589-v', 9), SenseInfo('00700708-v', 7), SenseInfo('00763399-v', 1), SenseInfo('00920336-v', 0), SenseInfo('00918872-v', 107), SenseInfo('00701040-v', 21), SenseInfo('00699815-v', 18), SenseInfo('00947077-v', 11), SenseInfo('00697589-v', 9), SenseInfo('00700708-v', 7), SenseInfo('00763399-v', 1), SenseInfo('00920336-v', 0), SenseInfo('00918872-v', 107), SenseInfo('00701040-v', 21), SenseInfo('00699815-v', 18), SenseInfo('00947077-v', 11), SenseInfo('00697589-v', 9), SenseInfo('00700708-v', 7), SenseInfo('00763399-v', 1), SenseInfo('00920336-v', 0), SenseInfo('00918872-v', 107), SenseInfo('00701040-v', 21), SenseInfo('00699815-v', 18), SenseInfo('00947077-v', 11), SenseInfo('00697589-v', 9), SenseInfo('00700708-v', 7), SenseInfo('00763399-v', 1), SenseInfo('00920336-v', 0), SenseInfo('00918872-v', 107), SenseInfo('00701040-v', 21), SenseInfo('00699815-v', 18), SenseInfo('00947077-v', 11), SenseInfo('00697589-v', 9), SenseInfo('00700708-v', 7), SenseInfo('00763399-v', 1), SenseInfo('00920336-v', 0), SenseInfo('00918872-v', 107), SenseInfo('00701040-v', 21), SenseInfo('00699815-v', 18), SenseInfo('00947077-v', 11), SenseInfo('00697589-v', 9), SenseInfo('00700708-v', 7), SenseInfo('00763399-v', 1), SenseInfo('00920336-v', 0) ],
"_phd_n_1_rel" : [ SenseInfo('06704115-n', 0), SenseInfo('06704115-n', 0), SenseInfo('06704115-n', 0), SenseInfo('06704115-n', 0), SenseInfo('06704115-n', 0), SenseInfo('06704115-n', 0), SenseInfo('06704115-n', 0) ],
"_inhale_v_1_rel" : [ SenseInfo('01198779-v', 0), SenseInfo('00005041-v', 0) ],
"_marble_v_1_rel" : [ SenseInfo('01681492-v', 0) ],
"_thus_a_1_rel" : [ SenseInfo('14873951-n', 0), SenseInfo('14873951-n', 0), SenseInfo('14873951-n', 0) ],
"_splatter_v_1_rel" : [ SenseInfo('01542207-v', 0), SenseInfo('01374020-v', 0) ],
"_hoe_n_1_rel" : [ SenseInfo('03524574-n', 1) ],
"_discard_v_as_rel" : [ SenseInfo('02222318-v', 3), SenseInfo('02222318-v', 3) ],
"_cobble_n_1_rel" : [ SenseInfo('03059528-n', 0) ],
"_prepay_v_1_rel" : [ SenseInfo('02250340-v', 0) ],
"_windswept_a_1_rel" : [ SenseInfo('01243722-a', 0) ],
"_duplicate_n_1_rel" : [ SenseInfo('03307981-n', 0), SenseInfo('03257343-n', 0), SenseInfo('03307981-n', 0), SenseInfo('03257343-n', 0) ],
"_sun_n_1_rel" : [ SenseInfo('09450163-n', 42), SenseInfo('11485367-n', 13), SenseInfo('10674896-n', 1), SenseInfo('09450454-n', 1), SenseInfo('15163797-n', 0) ],
"_core_n_1_rel" : [ SenseInfo('08242223-n', 5), SenseInfo('08524262-n', 4), SenseInfo('09256815-n', 2), SenseInfo('05921123-n', 2), SenseInfo('09256895-n', 1), SenseInfo('08308922-n', 0), SenseInfo('06604066-n', 0), SenseInfo('03108069-n', 0), SenseInfo('03107904-n', 0), SenseInfo('03107716-n', 0) ],
"_vet_v_1_rel" : [ SenseInfo('02446504-v', 0), SenseInfo('02166117-v', 0), SenseInfo('00080589-v', 0), SenseInfo('00080456-v', 0) ],
"_dental_a_1_rel" : [ SenseInfo('02711098-a', 2), SenseInfo('02711194-a', 0) ],
"_ruin_v_1_rel" : [ SenseInfo('01564144-v', 4), SenseInfo('02558951-v', 0), SenseInfo('02318165-v', 0), SenseInfo('01566490-v', 0), SenseInfo('01428381-v', 0), SenseInfo('00578993-v', 0) ],
"_push_v_away_rel" : [ SenseInfo('01871979-v', 56), SenseInfo('00765977-v', 7), SenseInfo('00976653-v', 6), SenseInfo('02406916-v', 3), SenseInfo('01872645-v', 3), SenseInfo('02054864-v', 1), SenseInfo('02589576-v', 0), SenseInfo('02245555-v', 0), SenseInfo('01872877-v', 0), SenseInfo('01447632-v', 0) ],
"_silence_v_1_rel" : [ SenseInfo('00461493-v', 4), SenseInfo('00463007-v', 0) ],
"_series+A_n_1_rel" : [  ],
"_albeit_x_rel" : [  ],
"_implant_v_1_rel" : [ SenseInfo('01528821-v', 1), SenseInfo('01290730-v', 0), SenseInfo('00734790-v', 0), SenseInfo('01528821-v', 1), SenseInfo('01290730-v', 0), SenseInfo('00734790-v', 0) ],
"_snippet_n_1_rel" : [ SenseInfo('04250026-n', 0) ],
"_divine_n_1_rel" : [ SenseInfo('09536363-n', 1), SenseInfo('09928136-n', 0) ],
"_fare_v_1_rel" : [ SenseInfo('02617567-v', 1), SenseInfo('01172969-v', 0) ],
"_waterside_n_1_rel" : [ SenseInfo('09475925-n', 0) ],
"_mix_v_1_rel" : [ SenseInfo('00394813-v', 7), SenseInfo('02481900-v', 1), SenseInfo('00556193-v', 1), SenseInfo('00184117-v', 1), SenseInfo('01462005-v', 0), SenseInfo('01418667-v', 0) ],
"_nervous_n_1_rel" : [ SenseInfo('02406908-a', 9), SenseInfo('02456157-a', 3), SenseInfo('02904518-a', 0), SenseInfo('00919813-a', 0), SenseInfo('00919155-a', 0) ],
"_subclass_n_1_rel" : [ SenseInfo('08106661-n', 0) ],
"_yugoslav_n_1_rel" : [ SenseInfo('09750891-n', 0) ],
"_rite_n_1_rel" : [ SenseInfo('01029406-n', 2), SenseInfo('01027859-n', 2) ],
"_in-joke_n_1_rel" : [ SenseInfo('06779511-n', 0), SenseInfo('06779511-n', 0) ],
"_sanction_n_1_rel" : [ SenseInfo('06687358-n', 2), SenseInfo('01124246-n', 1), SenseInfo('05176607-n', 0), SenseInfo('01139000-n', 0), SenseInfo('06687358-n', 2), SenseInfo('01124246-n', 1), SenseInfo('05176607-n', 0), SenseInfo('01139000-n', 0), SenseInfo('06687358-n', 2), SenseInfo('01124246-n', 1), SenseInfo('05176607-n', 0), SenseInfo('01139000-n', 0) ],
"_sicken_v_1_rel" : [ SenseInfo('01808374-v', 2), SenseInfo('00087454-v', 1), SenseInfo('02195191-v', 0), SenseInfo('00088209-v', 0), SenseInfo('01808374-v', 2), SenseInfo('00087454-v', 1), SenseInfo('02195191-v', 0), SenseInfo('00088209-v', 0) ],
"_predicate_v_of_rel" : [ SenseInfo('01017222-v', 0), SenseInfo('01017001-v', 0), SenseInfo('00931232-v', 0), SenseInfo('01017222-v', 0), SenseInfo('01017001-v', 0), SenseInfo('00931232-v', 0) ],
"_scarify_v_1_rel" : [ SenseInfo('01274745-v', 1), SenseInfo('01275658-v', 0), SenseInfo('01275427-v', 0) ],
"_stand_v_1_rel" : [ SenseInfo('01546111-v', 169), SenseInfo('02611373-v', 53), SenseInfo('02734488-v', 38), SenseInfo('02702120-v', 18), SenseInfo('00668099-v', 9), SenseInfo('00670991-v', 8), SenseInfo('02707125-v', 5), SenseInfo('02703018-v', 3), SenseInfo('02702368-v', 2), SenseInfo('01546768-v', 1), SenseInfo('01115916-v', 1), SenseInfo('01428203-v', 0), SenseInfo('01546111-v', 169), SenseInfo('02611373-v', 53), SenseInfo('02734488-v', 38), SenseInfo('02702120-v', 18), SenseInfo('00668099-v', 9), SenseInfo('00670991-v', 8), SenseInfo('02707125-v', 5), SenseInfo('02703018-v', 3), SenseInfo('02702368-v', 2), SenseInfo('01546768-v', 1), SenseInfo('01115916-v', 1), SenseInfo('01428203-v', 0), SenseInfo('01546111-v', 169), SenseInfo('02611373-v', 53), SenseInfo('02734488-v', 38), SenseInfo('02702120-v', 18), SenseInfo('00668099-v', 9), SenseInfo('00670991-v', 8), SenseInfo('02707125-v', 5), SenseInfo('02703018-v', 3), SenseInfo('02702368-v', 2), SenseInfo('01546768-v', 1), SenseInfo('01115916-v', 1), SenseInfo('01428203-v', 0), SenseInfo('01546111-v', 169), SenseInfo('02611373-v', 53), SenseInfo('02734488-v', 38), SenseInfo('02702120-v', 18), SenseInfo('00668099-v', 9), SenseInfo('00670991-v', 8), SenseInfo('02707125-v', 5), SenseInfo('02703018-v', 3), SenseInfo('02702368-v', 2), SenseInfo('01546768-v', 1), SenseInfo('01115916-v', 1), SenseInfo('01428203-v', 0), SenseInfo('01546111-v', 169), SenseInfo('02611373-v', 53), SenseInfo('02734488-v', 38), SenseInfo('02702120-v', 18), SenseInfo('00668099-v', 9), SenseInfo('00670991-v', 8), SenseInfo('02707125-v', 5), SenseInfo('02703018-v', 3), SenseInfo('02702368-v', 2), SenseInfo('01546768-v', 1), SenseInfo('01115916-v', 1), SenseInfo('01428203-v', 0), SenseInfo('01546111-v', 169), SenseInfo('02611373-v', 53), SenseInfo('02734488-v', 38), SenseInfo('02702120-v', 18), SenseInfo('00668099-v', 9), SenseInfo('00670991-v', 8), SenseInfo('02707125-v', 5), SenseInfo('02703018-v', 3), SenseInfo('02702368-v', 2), SenseInfo('01546768-v', 1), SenseInfo('01115916-v', 1), SenseInfo('01428203-v', 0) ],
"_mantle_n_1_rel" : [ SenseInfo('06883956-n', 1), SenseInfo('11155196-n', 0), SenseInfo('09346450-n', 0), SenseInfo('09223725-n', 0), SenseInfo('05244045-n', 0), SenseInfo('03719343-n', 0), SenseInfo('03151077-n', 0), SenseInfo('02955767-n', 0) ],
"_lodge_n_1_rel" : [ SenseInfo('11136973-n', 0), SenseInfo('08227214-n', 0), SenseInfo('03685640-n', 0), SenseInfo('03685486-n', 0), SenseInfo('03685307-n', 0), SenseInfo('03541696-n', 0), SenseInfo('11136973-n', 0), SenseInfo('08227214-n', 0), SenseInfo('03685640-n', 0), SenseInfo('03685486-n', 0), SenseInfo('03685307-n', 0), SenseInfo('03541696-n', 0), SenseInfo('11136973-n', 0), SenseInfo('08227214-n', 0), SenseInfo('03685640-n', 0), SenseInfo('03685486-n', 0), SenseInfo('03685307-n', 0), SenseInfo('03541696-n', 0) ],
"_obstruct_v_1_rel" : [ SenseInfo('02557199-v', 2), SenseInfo('01476483-v', 2), SenseInfo('02145543-v', 0) ],
"_grade+school_n_1_rel" : [ SenseInfo('08412749-n', 1), SenseInfo('08412749-n', 1) ],
"_shortclothes_n_1_rel" : [  ],
"_dung_n_1_rel" : [ SenseInfo('14854847-n', 2) ],
"_current_a_1_rel" : [ SenseInfo('00666058-a', 17), SenseInfo('00666058-a', 17), SenseInfo('00666058-a', 17), SenseInfo('00666058-a', 17) ],
"_washroom_n_1_rel" : [ SenseInfo('04555291-n', 0) ],
"_vocals_n_1_rel" : [ SenseInfo('07282006-n', 0), SenseInfo('07048000-n', 0), SenseInfo('07282006-n', 0), SenseInfo('07048000-n', 0) ],
"_chilly_a_1_rel" : [ SenseInfo('00857206-a', 1), SenseInfo('01252566-a', 0), SenseInfo('01077263-a', 0), SenseInfo('00857206-a', 1), SenseInfo('01252566-a', 0), SenseInfo('01077263-a', 0), SenseInfo('00857206-a', 1), SenseInfo('01252566-a', 0), SenseInfo('01077263-a', 0), SenseInfo('00857206-a', 1), SenseInfo('01252566-a', 0), SenseInfo('01077263-a', 0), SenseInfo('00857206-a', 1), SenseInfo('01252566-a', 0), SenseInfo('01077263-a', 0), SenseInfo('00857206-a', 1), SenseInfo('01252566-a', 0), SenseInfo('01077263-a', 0) ],
"_tic_n_1_rel" : [ SenseInfo('14361972-n', 0) ],
"_parameter_n_1_rel" : [ SenseInfo('05859071-n', 5), SenseInfo('07328305-n', 2), SenseInfo('06356299-n', 0), SenseInfo('05859277-n', 0) ],
"_cosmic_a_1_rel" : [ SenseInfo('02702807-a', 7), SenseInfo('01385663-a', 0) ],
"_mud_n_1_rel" : [ SenseInfo('14956325-n', 23), SenseInfo('06720137-n', 0) ],
"_kangaroo_n_1_rel" : [ SenseInfo('01877134-n', 0) ],
"_stiffen_v_cause_rel" : [ SenseInfo('00418563-v', 11), SenseInfo('00417596-v', 2), SenseInfo('00418765-v', 0) ],
"_articulatory_a_1_rel" : [ SenseInfo('02643446-a', 0) ],
"_manhood_n_1_rel" : [ SenseInfo('14425319-n', 2), SenseInfo('04726938-n', 0), SenseInfo('00594953-n', 0) ],
"_thereupon_a_1_rel" : [  ],
"_prehistoric_a_1_rel" : [ SenseInfo('01730909-a', 1), SenseInfo('02946359-a', 0), SenseInfo('00975011-a', 0) ],
"_phenomena_n_1_rel" : [ SenseInfo('00034213-n', 25), SenseInfo('07423818-n', 5) ],
"_composite_a_1_rel" : [ SenseInfo('02177755-a', 2), SenseInfo('02701099-a', 0) ],
"_snarl_v_1_rel" : [ SenseInfo('00916274-v', 6), SenseInfo('00916520-v', 1), SenseInfo('01462928-v', 0), SenseInfo('00402831-v', 0), SenseInfo('00916274-v', 6), SenseInfo('00916520-v', 1), SenseInfo('01462928-v', 0), SenseInfo('00402831-v', 0), SenseInfo('00916274-v', 6), SenseInfo('00916520-v', 1), SenseInfo('01462928-v', 0), SenseInfo('00402831-v', 0) ],
"_faithful_n_1_rel" : [ SenseInfo('08223475-n', 1), SenseInfo('07991364-n', 0) ],
"_fishpond_n_1_rel" : [ SenseInfo('09280913-n', 0) ],
"_gasp_n_1_rel" : [ SenseInfo('00837098-n', 4) ],
"_diet_n_1_rel" : [ SenseInfo('07561112-n', 8), SenseInfo('08318777-n', 0), SenseInfo('07560903-n', 0), SenseInfo('01070187-n', 0) ],
"_boa_n_1_rel" : [ SenseInfo('03325584-n', 0), SenseInfo('01741943-n', 0) ],
"_construe_v_1_rel" : [ SenseInfo('00623151-v', 5), SenseInfo('00623151-v', 5), SenseInfo('00623151-v', 5) ],
"_mercenary_a_1_rel" : [ SenseInfo('02577907-a', 0), SenseInfo('01709081-a', 0), SenseInfo('00483816-a', 0) ],
"_goddaughter_n_1_rel" : [ SenseInfo('10134552-n', 0) ],
"_stick_v_on_rel" : [ SenseInfo('01528069-v', 5), SenseInfo('01857392-v', 2), SenseInfo('01356750-v', 2), SenseInfo('02754032-v', 0), SenseInfo('02647798-v', 0), SenseInfo('02638845-v', 0), SenseInfo('02638630-v', 0), SenseInfo('01667969-v', 0), SenseInfo('01614581-v', 0), SenseInfo('01614426-v', 0), SenseInfo('01614235-v', 0), SenseInfo('01441993-v', 0), SenseInfo('01441793-v', 0), SenseInfo('01220885-v', 0), SenseInfo('00748084-v', 0), SenseInfo('00622384-v', 0) ],
"_forcing_n_1_rel" : [  ],
"_warrior_n_1_rel" : [ SenseInfo('10768585-n', 3) ],
"_semantics_n_1_rel" : [ SenseInfo('06179792-n', 0), SenseInfo('05920651-n', 0) ],
"_wakeful_a_1_rel" : [ SenseInfo('00091764-a', 5), SenseInfo('00693570-a', 0), SenseInfo('00187590-a', 0) ],
"_curvature_n_1_rel" : [ SenseInfo('14213328-n', 0), SenseInfo('05102435-n', 0), SenseInfo('05072663-n', 0) ],
"_vegetation_n_1_rel" : [ SenseInfo('08436759-n', 2), SenseInfo('13573057-n', 0), SenseInfo('05603854-n', 0), SenseInfo('01065057-n', 0) ],
"_anthem_n_1_rel" : [ SenseInfo('07048928-n', 0), SenseInfo('07035870-n', 0) ],
"_farmstead_n_1_rel" : [ SenseInfo('13249599-n', 0), SenseInfo('03323096-n', 0) ],
"_run+around_n_1_rel" : [  ],
"_siskin_n_1_rel" : [ SenseInfo('01531512-n', 0) ],
"_parisian_a_1_rel" : [ SenseInfo('03023449-a', 2) ],
"_manatee_n_1_rel" : [ SenseInfo('02073831-n', 0) ],
"_swindle_n_1_rel" : [ SenseInfo('00780148-n', 0) ],
"_faulty_a_1_rel" : [ SenseInfo('01752953-a', 0), SenseInfo('00023854-a', 0), SenseInfo('01752953-a', 0), SenseInfo('00023854-a', 0), SenseInfo('01752953-a', 0), SenseInfo('00023854-a', 0) ],
"_leave_v_1_rel" : [ SenseInfo('02009433-v', 146), SenseInfo('00613683-v', 63), SenseInfo('02729414-v', 56), SenseInfo('00136991-v', 27), SenseInfo('02015598-v', 20), SenseInfo('02721438-v', 19), SenseInfo('02635659-v', 16), SenseInfo('02383440-v', 14), SenseInfo('02356230-v', 8), SenseInfo('02229055-v', 7), SenseInfo('02730135-v', 5), SenseInfo('00360092-v', 5), SenseInfo('02296153-v', 3), SenseInfo('00613018-v', 3), SenseInfo('02009433-v', 146), SenseInfo('00613683-v', 63), SenseInfo('02729414-v', 56), SenseInfo('00136991-v', 27), SenseInfo('02015598-v', 20), SenseInfo('02721438-v', 19), SenseInfo('02635659-v', 16), SenseInfo('02383440-v', 14), SenseInfo('02356230-v', 8), SenseInfo('02229055-v', 7), SenseInfo('02730135-v', 5), SenseInfo('00360092-v', 5), SenseInfo('02296153-v', 3), SenseInfo('00613018-v', 3), SenseInfo('02009433-v', 146), SenseInfo('00613683-v', 63), SenseInfo('02729414-v', 56), SenseInfo('00136991-v', 27), SenseInfo('02015598-v', 20), SenseInfo('02721438-v', 19), SenseInfo('02635659-v', 16), SenseInfo('02383440-v', 14), SenseInfo('02356230-v', 8), SenseInfo('02229055-v', 7), SenseInfo('02730135-v', 5), SenseInfo('00360092-v', 5), SenseInfo('02296153-v', 3), SenseInfo('00613018-v', 3) ],
"_bias_v_towards_rel" : [ SenseInfo('01085677-v', 0), SenseInfo('00680346-v', 0) ],
"_lemon_n_1_rel" : [ SenseInfo('07749582-n', 4), SenseInfo('04966543-n', 2), SenseInfo('12711596-n', 0), SenseInfo('05716342-n', 0), SenseInfo('03655838-n', 0) ],
"_flange_n_1_rel" : [ SenseInfo('03356858-n', 0) ],
"_d-_n_1_rel" : [ SenseInfo('15092227-n', 0), SenseInfo('13750712-n', 0), SenseInfo('06831498-n', 0) ],
"_solicit_v_1_rel" : [ SenseInfo('00782057-v', 4), SenseInfo('02534492-v', 0), SenseInfo('00781652-v', 0), SenseInfo('00771133-v', 0), SenseInfo('00753734-v', 0) ],
"_snake_v_1_rel" : [ SenseInfo('01888165-v', 3), SenseInfo('02738976-v', 0), SenseInfo('01883210-v', 0) ],
"_toss_v_1_rel" : [ SenseInfo('01512625-v', 13), SenseInfo('01893079-v', 10), SenseInfo('01514525-v', 5), SenseInfo('01890792-v', 4), SenseInfo('02222318-v', 1), SenseInfo('01418536-v', 1), SenseInfo('01512625-v', 13), SenseInfo('01893079-v', 10), SenseInfo('01514525-v', 5), SenseInfo('01890792-v', 4), SenseInfo('02222318-v', 1), SenseInfo('01418536-v', 1), SenseInfo('01512625-v', 13), SenseInfo('01893079-v', 10), SenseInfo('01514525-v', 5), SenseInfo('01890792-v', 4), SenseInfo('02222318-v', 1), SenseInfo('01418536-v', 1), SenseInfo('01512625-v', 13), SenseInfo('01893079-v', 10), SenseInfo('01514525-v', 5), SenseInfo('01890792-v', 4), SenseInfo('02222318-v', 1), SenseInfo('01418536-v', 1) ],
"_mean_a_1_rel" : [ SenseInfo('01594146-a', 16), SenseInfo('01587787-a', 6), SenseInfo('01589650-a', 3), SenseInfo('02227663-a', 0), SenseInfo('02025718-a', 0), SenseInfo('01113807-a', 0), SenseInfo('01112969-a', 0), SenseInfo('00905039-a', 0), SenseInfo('01594146-a', 16), SenseInfo('01587787-a', 6), SenseInfo('01589650-a', 3), SenseInfo('02227663-a', 0), SenseInfo('02025718-a', 0), SenseInfo('01113807-a', 0), SenseInfo('01112969-a', 0), SenseInfo('00905039-a', 0), SenseInfo('01594146-a', 16), SenseInfo('01587787-a', 6), SenseInfo('01589650-a', 3), SenseInfo('02227663-a', 0), SenseInfo('02025718-a', 0), SenseInfo('01113807-a', 0), SenseInfo('01112969-a', 0), SenseInfo('00905039-a', 0) ],
"_optic_a_1_rel" : [ SenseInfo('02869823-a', 0), SenseInfo('02869563-a', 0) ],
"_raspberry_n_1_rel" : [ SenseInfo('12655869-n', 0), SenseInfo('07745466-n', 0), SenseInfo('07123870-n', 0) ],
"_denote_v_1_rel" : [ SenseInfo('00932161-v', 11), SenseInfo('00931467-v', 7), SenseInfo('00974367-v', 1), SenseInfo('00932161-v', 11), SenseInfo('00931467-v', 7), SenseInfo('00974367-v', 1) ],
"_a+_n_1_rel" : [ SenseInfo('13658027-n', 6), SenseInfo('15089803-n', 0), SenseInfo('14829565-n', 0), SenseInfo('14706889-n', 0), SenseInfo('13637376-n', 0), SenseInfo('06831177-n', 0), SenseInfo('05400860-n', 0) ],
"_haitian_a_1_rel" : [ SenseInfo('03071651-a', 0) ],
"_grin_n_1_rel" : [ SenseInfo('06878071-n', 6) ],
"_scar_n_1_rel" : [ SenseInfo('14363483-n', 7), SenseInfo('04693900-n', 4) ],
"_vent_n_1_rel" : [ SenseInfo('04526241-n', 2), SenseInfo('01323901-n', 1), SenseInfo('09470550-n', 0), SenseInfo('04526416-n', 0), SenseInfo('01264447-n', 0) ],
"_lay_v_out_rel" : [ SenseInfo('01494310-v', 24), SenseInfo('01544692-v', 11), SenseInfo('01651972-v', 5), SenseInfo('01545079-v', 4), SenseInfo('02307261-v', 1) ],
"_sync_v_with_rel" : [ SenseInfo('00393953-v', 0), SenseInfo('00393953-v', 0), SenseInfo('00393953-v', 0) ],
"_chastisement_n_1_rel" : [ SenseInfo('01161017-n', 1), SenseInfo('06714288-n', 0) ],
"_bulge_n_1_rel" : [ SenseInfo('13894434-n', 3) ],
"_bake_v_cause_rel" : [ SenseInfo('00319886-v', 6), SenseInfo('01663749-v', 1), SenseInfo('00544136-v', 1), SenseInfo('02755565-v', 0), SenseInfo('00319886-v', 6), SenseInfo('01663749-v', 1), SenseInfo('00544136-v', 1), SenseInfo('02755565-v', 0) ],
"_inhabitancy_n_1_rel" : [ SenseInfo('01054545-n', 0) ],
"_six-shooter_n_1_rel" : [ SenseInfo('04086273-n', 0), SenseInfo('04086273-n', 0) ],
"_scot_n_1_rel" : [ SenseInfo('09730533-n', 5) ],
"_runaway_a_1_rel" : [ SenseInfo('00601150-a', 3) ],
"_interim_n_1_rel" : [ SenseInfo('15272887-n', 1) ],
"_recalcitrant_a_1_rel" : [ SenseInfo('01614127-a', 0), SenseInfo('00696335-a', 0) ],
"_jerk_v_cause_rel" : [ SenseInfo('01592072-v', 15), SenseInfo('01891817-v', 4), SenseInfo('00009631-v', 2), SenseInfo('01884383-v', 0), SenseInfo('01591158-v', 0) ],
"_basket_n_1_rel" : [ SenseInfo('02801938-n', 6), SenseInfo('13765207-n', 2), SenseInfo('02802215-n', 0), SenseInfo('00190431-n', 0) ],
"_push_n_1_rel" : [ SenseInfo('00112312-n', 4), SenseInfo('11498203-n', 1), SenseInfo('04836683-n', 0), SenseInfo('04027023-n', 0), SenseInfo('00282485-n', 0), SenseInfo('00112312-n', 4), SenseInfo('11498203-n', 1), SenseInfo('04836683-n', 0), SenseInfo('04027023-n', 0), SenseInfo('00282485-n', 0) ],
"_cb_n_1_rel" : [  ],
"_turbine_n_1_rel" : [ SenseInfo('04498523-n', 3) ],
"_friend-of-the-court_a_1_rel" : [  ],
"_mileage_n_1_rel" : [ SenseInfo('05131194-n', 1), SenseInfo('13823287-n', 0), SenseInfo('13294029-n', 0) ],
"_since_p_rel" : [  ],
"_A_n_1_rel" : [ SenseInfo('13658027-n', 6), SenseInfo('15089803-n', 0), SenseInfo('14829565-n', 0), SenseInfo('14706889-n', 0), SenseInfo('13637376-n', 0), SenseInfo('06831177-n', 0), SenseInfo('05400860-n', 0), SenseInfo('13658027-n', 6), SenseInfo('15089803-n', 0), SenseInfo('14829565-n', 0), SenseInfo('14706889-n', 0), SenseInfo('13637376-n', 0), SenseInfo('06831177-n', 0), SenseInfo('05400860-n', 0), SenseInfo('13658027-n', 6), SenseInfo('15089803-n', 0), SenseInfo('14829565-n', 0), SenseInfo('14706889-n', 0), SenseInfo('13637376-n', 0), SenseInfo('06831177-n', 0), SenseInfo('05400860-n', 0), SenseInfo('13658027-n', 6), SenseInfo('15089803-n', 0), SenseInfo('14829565-n', 0), SenseInfo('14706889-n', 0), SenseInfo('13637376-n', 0), SenseInfo('06831177-n', 0), SenseInfo('05400860-n', 0), SenseInfo('13658027-n', 6), SenseInfo('15089803-n', 0), SenseInfo('14829565-n', 0), SenseInfo('14706889-n', 0), SenseInfo('13637376-n', 0), SenseInfo('06831177-n', 0), SenseInfo('05400860-n', 0), SenseInfo('13658027-n', 6), SenseInfo('15089803-n', 0), SenseInfo('14829565-n', 0), SenseInfo('14706889-n', 0), SenseInfo('13637376-n', 0), SenseInfo('06831177-n', 0), SenseInfo('05400860-n', 0) ],
"_nasty_a_1_rel" : [ SenseInfo('01587077-a', 2), SenseInfo('00747727-a', 0), SenseInfo('00425313-a', 0), SenseInfo('00421590-a', 0), SenseInfo('01587077-a', 2), SenseInfo('00747727-a', 0), SenseInfo('00425313-a', 0), SenseInfo('00421590-a', 0), SenseInfo('01587077-a', 2), SenseInfo('00747727-a', 0), SenseInfo('00425313-a', 0), SenseInfo('00421590-a', 0), SenseInfo('01587077-a', 2), SenseInfo('00747727-a', 0), SenseInfo('00425313-a', 0), SenseInfo('00421590-a', 0) ],
"_fascist_n_1_rel" : [ SenseInfo('10079893-n', 0) ],
"_for+instance_a_1_rel" : [  ],
"_queer_v_1_rel" : [ SenseInfo('02558172-v', 0), SenseInfo('01036319-v', 0) ],
"_skunk_v_1_rel" : [ SenseInfo('01103693-v', 0) ],
"_accustom_v_to_rel" : [ SenseInfo('00273445-v', 2), SenseInfo('00273445-v', 2), SenseInfo('00273445-v', 2) ],
"_wattle_n_1_rel" : [ SenseInfo('05471427-n', 1), SenseInfo('04564118-n', 1), SenseInfo('11756669-n', 0) ],
"_flame_v_1_rel" : [ SenseInfo('02762981-v', 0), SenseInfo('02759443-v', 0), SenseInfo('00824593-v', 0) ],
"_south+korean_a_1_rel" : [ SenseInfo('02968166-a', 0) ],
"_depressed_a_1_rel" : [ SenseInfo('01212867-a', 1), SenseInfo('02413221-a', 0), SenseInfo('00703615-a', 0) ],
"_distrust_n_1_rel" : [ SenseInfo('05698791-n', 1), SenseInfo('04895773-n', 0) ],
"_rhino_n_1_rel" : [ SenseInfo('02391994-n', 2) ],
"_pass_v_by_rel" : [ SenseInfo('02050132-v', 32), SenseInfo('02051694-v', 31), SenseInfo('02466670-v', 29), SenseInfo('02072849-v', 17), SenseInfo('02230772-v', 13), SenseInfo('02685951-v', 8), SenseInfo('02049696-v', 8), SenseInfo('00339934-v', 7), SenseInfo('02523351-v', 4), SenseInfo('02708420-v', 3), SenseInfo('01212230-v', 3), SenseInfo('00742320-v', 3), SenseInfo('00421691-v', 3), SenseInfo('02525044-v', 2), SenseInfo('02669081-v', 1), SenseInfo('02523953-v', 1), SenseInfo('02423513-v', 1), SenseInfo('02221635-v', 1), SenseInfo('01972131-v', 1), SenseInfo('02231473-v', 0), SenseInfo('02229550-v', 0), SenseInfo('02052476-v', 0), SenseInfo('00803325-v', 0), SenseInfo('00358431-v', 0), SenseInfo('00072989-v', 0) ],
"_etching_n_1_rel" : [ SenseInfo('03299519-n', 0), SenseInfo('03299406-n', 0), SenseInfo('00938791-n', 0) ],
"_awl_n_1_rel" : [ SenseInfo('02763714-n', 0) ],
"_difficult_a_for_rel" : [ SenseInfo('00744916-a', 63), SenseInfo('01475282-a', 0), SenseInfo('00744916-a', 63), SenseInfo('01475282-a', 0) ],
"_moo_v_1_rel" : [ SenseInfo('01055018-v', 1) ],
"_ivy_n_1_rel" : [ SenseInfo('11798978-n', 1) ],
"_shack_n_1_rel" : [ SenseInfo('03547054-n', 1) ],
"_devastate_v_1_rel" : [ SenseInfo('00388635-v', 3), SenseInfo('00260311-v', 0), SenseInfo('00388635-v', 3), SenseInfo('00260311-v', 0), SenseInfo('00388635-v', 3), SenseInfo('00260311-v', 0), SenseInfo('00388635-v', 3), SenseInfo('00260311-v', 0) ],
"_dispatch_n_of_rel" : [ SenseInfo('06682794-n', 3), SenseInfo('00061290-n', 1), SenseInfo('05059830-n', 0), SenseInfo('00222248-n', 0) ],
"_diameter_n_1_rel" : [ SenseInfo('05101815-n', 27), SenseInfo('13871717-n', 1), SenseInfo('05101815-n', 27), SenseInfo('13871717-n', 1), SenseInfo('05101815-n', 27), SenseInfo('13871717-n', 1) ],
"_stanza_n_1_rel" : [ SenseInfo('07052291-n', 0) ],
"_board_v_up_rel" : [ SenseInfo('02018049-v', 5), SenseInfo('02656763-v', 2), SenseInfo('01177118-v', 0), SenseInfo('01176897-v', 0) ],
"_rabbit_v_on_rel" : [ SenseInfo('01142761-v', 0) ],
"_tear_v_apart_rel" : [ SenseInfo('01573515-v', 19), SenseInfo('01556346-v', 7), SenseInfo('02055267-v', 2), SenseInfo('01384275-v', 1), SenseInfo('00066977-v', 0) ],
"_stair_n_1_rel" : [ SenseInfo('04314914-n', 1) ],
"_drizzle_n_1_rel" : [ SenseInfo('11502322-n', 5) ],
"_melt_v_cause_rel" : [ SenseInfo('00444629-v', 3), SenseInfo('00376106-v', 2), SenseInfo('00254486-v', 2), SenseInfo('00395841-v', 1), SenseInfo('00224651-v', 0), SenseInfo('00223928-v', 0) ],
"_have_v_regarding_rel" : [ SenseInfo('02203362-v', 1202), SenseInfo('02630189-v', 377), SenseInfo('02108026-v', 220), SenseInfo('02204692-v', 143), SenseInfo('00120796-v', 64), SenseInfo('01156834-v', 42), SenseInfo('02378453-v', 31), SenseInfo('01733477-v', 30), SenseInfo('02205098-v', 28), SenseInfo('02740745-v', 25), SenseInfo('00121046-v', 25), SenseInfo('00065370-v', 11), SenseInfo('00770437-v', 8), SenseInfo('02236124-v', 7), SenseInfo('02210119-v', 7), SenseInfo('00065639-v', 5), SenseInfo('02355596-v', 3), SenseInfo('00056930-v', 3), SenseInfo('01427127-v', 2) ],
"_inability_n_1_rel" : [ SenseInfo('05644922-n', 5), SenseInfo('05207130-n', 0), SenseInfo('05644922-n', 5), SenseInfo('05207130-n', 0) ],
"_lime_n_1_rel" : [ SenseInfo('14936010-n', 0), SenseInfo('14789885-n', 0), SenseInfo('14702703-n', 0), SenseInfo('12711984-n', 0), SenseInfo('12202936-n', 0), SenseInfo('07749731-n', 0) ],
"_carer_n_1_rel" : [  ],
"_spire_n_1_rel" : [ SenseInfo('04312432-n', 4) ],
"_stingy_a_1_rel" : [ SenseInfo('01112573-a', 0), SenseInfo('00106456-a', 0) ],
"_newly-wed_n_1_rel" : [ SenseInfo('10356066-n', 0), SenseInfo('10356066-n', 0) ],
"_slim_v_down_rel" : [ SenseInfo('00045817-v', 0), SenseInfo('00045817-v', 0) ],
"_anxious_a_1_rel" : [ SenseInfo('00811248-a', 3), SenseInfo('02456157-a', 0), SenseInfo('00811248-a', 3), SenseInfo('02456157-a', 0), SenseInfo('00811248-a', 3), SenseInfo('02456157-a', 0) ],
"_text_v_1_rel" : [  ],
"_hash_v_out_rel" : [ SenseInfo('01257399-v', 0) ],
"_disadvantage_n_1_rel" : [ SenseInfo('05161614-n', 3), SenseInfo('05161614-n', 3) ],
"_deprive_v_of_rel" : [ SenseInfo('02314275-v', 3), SenseInfo('02313250-v', 3), SenseInfo('00172732-v', 0), SenseInfo('02314275-v', 3), SenseInfo('02313250-v', 3), SenseInfo('00172732-v', 0) ],
"_out+of+vocabulary_a_1_rel" : [  ],
"_pour_v_in_rel" : [ SenseInfo('02069551-v', 12), SenseInfo('02028366-v', 7), SenseInfo('02070296-v', 6), SenseInfo('02069248-v', 4), SenseInfo('02355806-v', 1), SenseInfo('02758033-v', 0), SenseInfo('02069551-v', 12), SenseInfo('02028366-v', 7), SenseInfo('02070296-v', 6), SenseInfo('02069248-v', 4), SenseInfo('02355806-v', 1), SenseInfo('02758033-v', 0) ],
"_emergence_n_1_rel" : [ SenseInfo('07324673-n', 1), SenseInfo('07319909-n', 1), SenseInfo('00050693-n', 0), SenseInfo('00044455-n', 0) ],
"_up+to+date_a_2_rel" : [ SenseInfo('00668208-a', 3), SenseInfo('00972642-a', 0), SenseInfo('00668208-a', 3), SenseInfo('00972642-a', 0), SenseInfo('00668208-a', 3), SenseInfo('00972642-a', 0), SenseInfo('00668208-a', 3), SenseInfo('00972642-a', 0), SenseInfo('00668208-a', 3), SenseInfo('00972642-a', 0), SenseInfo('00668208-a', 3), SenseInfo('00972642-a', 0) ],
"_naturalize_v_1_rel" : [ SenseInfo('00412292-v', 1), SenseInfo('00939757-v', 0), SenseInfo('00412993-v', 0), SenseInfo('00412696-v', 0), SenseInfo('00302464-v', 0), SenseInfo('00412292-v', 1), SenseInfo('00939757-v', 0), SenseInfo('00412993-v', 0), SenseInfo('00412696-v', 0), SenseInfo('00302464-v', 0) ],
"_fur_n_1_rel" : [ SenseInfo('14764061-n', 8), SenseInfo('01899062-n', 1), SenseInfo('03404149-n', 0) ],
"_unify_v_cause_rel" : [ SenseInfo('00367685-v', 5), SenseInfo('01462005-v', 2), SenseInfo('02603056-v', 0), SenseInfo('02469835-v', 0), SenseInfo('00243124-v', 0) ],
"_witness_v_1_rel" : [ SenseInfo('02128286-v', 17), SenseInfo('02128873-v', 7) ],
"_navvy_n_1_rel" : [ SenseInfo('10035809-n', 0) ],
"_monetary_a_1_rel" : [ SenseInfo('02775934-a', 0) ],
"_nevertheless_a_1_rel" : [  ],
"_life_n_of_rel" : [ SenseInfo('13963192-n', 66), SenseInfo('05810561-n', 54), SenseInfo('13961399-n', 41), SenseInfo('13961642-n', 29), SenseInfo('15140405-n', 22), SenseInfo('15140744-n', 18), SenseInfo('15140892-n', 5), SenseInfo('10260706-n', 5), SenseInfo('04632157-n', 5), SenseInfo('00006269-n', 5), SenseInfo('11473291-n', 3), SenseInfo('06515827-n', 2), SenseInfo('09178727-n', 1), SenseInfo('15225076-n', 0) ],
"_integration_n_of_rel" : [ SenseInfo('01202415-n', 20), SenseInfo('01237415-n', 2), SenseInfo('00871418-n', 2) ],
"_årdaler_n_1_rel" : [  ],
"_squally_a_1_rel" : [ SenseInfo('01924148-a', 0), SenseInfo('00305882-a', 0) ],
"_pipe_n_1_rel" : [ SenseInfo('03945167-n', 6), SenseInfo('03944672-n', 4), SenseInfo('13901321-n', 0), SenseInfo('03945615-n', 0), SenseInfo('03854815-n', 0) ],
"_retort_v_to_rel" : [ SenseInfo('00816353-v', 4) ],
"_professionalism_n_1_rel" : [ SenseInfo('05641089-n', 0), SenseInfo('05641089-n', 0) ],
"_careful_a_with-about-of_rel" : [ SenseInfo('00309021-a', 19), SenseInfo('01977488-a', 2), SenseInfo('01271961-a', 1), SenseInfo('02456698-a', 0), SenseInfo('01895099-a', 0), SenseInfo('00309021-a', 19), SenseInfo('01977488-a', 2), SenseInfo('01271961-a', 1), SenseInfo('02456698-a', 0), SenseInfo('01895099-a', 0), SenseInfo('00309021-a', 19), SenseInfo('01977488-a', 2), SenseInfo('01271961-a', 1), SenseInfo('02456698-a', 0), SenseInfo('01895099-a', 0), SenseInfo('00309021-a', 19), SenseInfo('01977488-a', 2), SenseInfo('01271961-a', 1), SenseInfo('02456698-a', 0), SenseInfo('01895099-a', 0), SenseInfo('00309021-a', 19), SenseInfo('01977488-a', 2), SenseInfo('01271961-a', 1), SenseInfo('02456698-a', 0), SenseInfo('01895099-a', 0), SenseInfo('00309021-a', 19), SenseInfo('01977488-a', 2), SenseInfo('01271961-a', 1), SenseInfo('02456698-a', 0), SenseInfo('01895099-a', 0) ],
"_mislay_v_1_rel" : [ SenseInfo('01503101-v', 1) ],
"_obesity_n_1_rel" : [ SenseInfo('05000342-n', 0) ],
"_underline_n_1_rel" : [ SenseInfo('06801418-n', 0) ],
"_rabid_a_1_rel" : [ SenseInfo('02786473-a', 0), SenseInfo('01726859-a', 0) ],
"_cpu_n_1_rel" : [ SenseInfo('02995345-n', 0) ],
"_rack_n_of_rel" : [ SenseInfo('04038727-n', 5), SenseInfo('07668073-n', 0), SenseInfo('07335581-n', 0), SenseInfo('04039041-n', 0), SenseInfo('04038440-n', 0), SenseInfo('00423916-n', 0), SenseInfo('00287276-n', 0) ],
"_soon_a_1_rel" : [  ],
"_gullible_n_1_rel" : [ SenseInfo('02272485-a', 1), SenseInfo('00163315-a', 0) ],
"_canvass_n_1_rel" : [ SenseInfo('14513489-n', 0), SenseInfo('05800998-n', 0), SenseInfo('04127904-n', 0), SenseInfo('02954163-n', 0), SenseInfo('02954068-n', 0), SenseInfo('02953850-n', 0), SenseInfo('02953673-n', 0) ],
"_tan_v_1_rel" : [ SenseInfo('00511430-v', 0), SenseInfo('00103875-v', 0) ],
"_lock_v_1_rel" : [ SenseInfo('01348174-v', 8), SenseInfo('01510827-v', 7), SenseInfo('00219775-v', 4), SenseInfo('01606736-v', 2), SenseInfo('01606018-v', 2), SenseInfo('01810320-v', 1), SenseInfo('01347678-v', 1), SenseInfo('02050865-v', 0), SenseInfo('01655347-v', 0) ],
"_principal_a_1_rel" : [ SenseInfo('01277426-a', 19), SenseInfo('01277426-a', 19) ],
"_beyond_p_rel" : [ SenseInfo('00045704-r', 10), SenseInfo('00045897-r', 1), SenseInfo('00045607-r', 0) ],
"_ruddy_a_1_rel" : [ SenseInfo('01172139-a', 1), SenseInfo('00381097-a', 0), SenseInfo('01172139-a', 1), SenseInfo('00381097-a', 0), SenseInfo('01172139-a', 1), SenseInfo('00381097-a', 0) ],
"_turn_v_upside+down_rel" : [ SenseInfo('01907258-v', 187), SenseInfo('00146138-v', 21), SenseInfo('02626604-v', 12), SenseInfo('02089984-v', 8), SenseInfo('00138508-v', 7), SenseInfo('01909812-v', 5), SenseInfo('00125841-v', 5), SenseInfo('01436518-v', 2), SenseInfo('02096167-v', 1), SenseInfo('02089420-v', 1), SenseInfo('01952208-v', 1), SenseInfo('01741864-v', 1), SenseInfo('01584450-v', 1), SenseInfo('00282523-v', 1), SenseInfo('00091124-v', 1), SenseInfo('02626934-v', 0), SenseInfo('02562425-v', 0), SenseInfo('02211948-v', 0), SenseInfo('02090435-v', 0), SenseInfo('01951937-v', 0), SenseInfo('01280014-v', 0), SenseInfo('01225215-v', 0), SenseInfo('01151889-v', 0), SenseInfo('00794640-v', 0), SenseInfo('00458471-v', 0), SenseInfo('00248387-v', 0) ],
"_tune_v_1_rel" : [ SenseInfo('00295966-v', 1), SenseInfo('00295346-v', 0) ],
"_principle_n_of_rel" : [ SenseInfo('05913538-n', 13), SenseInfo('05955323-n', 9), SenseInfo('05872477-n', 7), SenseInfo('05874232-n', 3), SenseInfo('06655388-n', 2), SenseInfo('05793210-n', 2), SenseInfo('05913538-n', 13), SenseInfo('05955323-n', 9), SenseInfo('05872477-n', 7), SenseInfo('05874232-n', 3), SenseInfo('06655388-n', 2), SenseInfo('05793210-n', 2), SenseInfo('05913538-n', 13), SenseInfo('05955323-n', 9), SenseInfo('05872477-n', 7), SenseInfo('05874232-n', 3), SenseInfo('06655388-n', 2), SenseInfo('05793210-n', 2), SenseInfo('05913538-n', 13), SenseInfo('05955323-n', 9), SenseInfo('05872477-n', 7), SenseInfo('05874232-n', 3), SenseInfo('06655388-n', 2), SenseInfo('05793210-n', 2) ],
"_fit_n_of_rel" : [ SenseInfo('14406303-n', 3), SenseInfo('14082788-n', 2), SenseInfo('04930307-n', 2), SenseInfo('00555325-n', 0) ],
"_parrot_v_1_rel" : [ SenseInfo('00958174-v', 1) ],
"_commend_v_on_rel" : [ SenseInfo('00882395-v', 10), SenseInfo('01689169-v', 1), SenseInfo('00883112-v', 1), SenseInfo('00882948-v', 0), SenseInfo('00882523-v', 0), SenseInfo('00882395-v', 10), SenseInfo('01689169-v', 1), SenseInfo('00883112-v', 1), SenseInfo('00882948-v', 0), SenseInfo('00882523-v', 0) ],
"_gulp_a_1_rel" : [ SenseInfo('00840189-n', 2), SenseInfo('00840363-n', 0), SenseInfo('00840189-n', 2), SenseInfo('00840363-n', 0) ],
"_lose_v_1_rel" : [ SenseInfo('02287789-v', 123), SenseInfo('01099592-v', 17), SenseInfo('01795082-v', 10), SenseInfo('01503101-v', 7), SenseInfo('02287618-v', 6), SenseInfo('02197091-v', 4), SenseInfo('02288828-v', 3), SenseInfo('02288155-v', 2), SenseInfo('01113806-v', 2), SenseInfo('02127853-v', 1), SenseInfo('00204872-v', 0) ],
"_replica_n_of_rel" : [ SenseInfo('04076533-n', 0) ],
"_shimmer_n_1_rel" : [ SenseInfo('07411851-n', 0) ],
"_ventilate_v_cause_rel" : [ SenseInfo('00488770-v', 1), SenseInfo('02112345-v', 0), SenseInfo('02042672-v', 0), SenseInfo('00944548-v', 0), SenseInfo('00581891-v', 0) ],
"_drink_n_1_rel" : [ SenseInfo('07885223-n', 20), SenseInfo('00748515-n', 4), SenseInfo('07881800-n', 3), SenseInfo('09270508-n', 0), SenseInfo('00839778-n', 0) ],
"_behave_v_1_rel" : [ SenseInfo('00010435-v', 18), SenseInfo('02518161-v', 3), SenseInfo('02519666-v', 1), SenseInfo('00010435-v', 18), SenseInfo('02518161-v', 3), SenseInfo('02519666-v', 1), SenseInfo('00010435-v', 18), SenseInfo('02518161-v', 3), SenseInfo('02519666-v', 1) ],
"_shield_n_1_rel" : [ SenseInfo('04192858-n', 3), SenseInfo('04192698-n', 2), SenseInfo('01903756-n', 0) ],
"_reasonable_a_for_rel" : [ SenseInfo('01943406-a', 16), SenseInfo('01532261-a', 14), SenseInfo('01926229-a', 0), SenseInfo('01943406-a', 16), SenseInfo('01532261-a', 14), SenseInfo('01926229-a', 0), SenseInfo('01943406-a', 16), SenseInfo('01532261-a', 14), SenseInfo('01926229-a', 0), SenseInfo('01943406-a', 16), SenseInfo('01532261-a', 14), SenseInfo('01926229-a', 0) ],
"_double_a_1_rel" : [ SenseInfo('02217799-a', 5), SenseInfo('02217452-a', 5), SenseInfo('02217241-a', 4), SenseInfo('02220308-a', 0), SenseInfo('01546826-a', 0), SenseInfo('01385149-a', 0), SenseInfo('00896026-a', 0) ],
"_electric_a_1_rel" : [ SenseInfo('02826877-a', 16), SenseInfo('02406640-a', 0), SenseInfo('00921631-a', 0) ],
"_crib_v_1_rel" : [ SenseInfo('02574977-v', 0), SenseInfo('02278470-v', 0), SenseInfo('01272234-v', 0) ],
"_dab_v_1_rel" : [ SenseInfo('01233194-v', 2), SenseInfo('01233027-v', 1) ],
"_watercourse_n_1_rel" : [ SenseInfo('09475179-n', 0), SenseInfo('09448361-n', 0), SenseInfo('04559275-n', 0) ],
"_awake_a_1_rel" : [ SenseInfo('00186616-a', 9), SenseInfo('00190653-a', 0) ],
"_hypocrite_n_1_rel" : [ SenseInfo('10195593-n', 3) ],
"_sitdown_a_1_rel" : [  ],
"_few+and+far+between_a_1_rel" : [  ],
"_peck_n_1_rel" : [ SenseInfo('13774404-n', 0), SenseInfo('13622451-n', 0), SenseInfo('13620713-n', 0), SenseInfo('13774404-n', 0), SenseInfo('13622451-n', 0), SenseInfo('13620713-n', 0) ],
"_a+little+bit_a_1_rel" : [  ],
"_generality_n_1_rel" : [ SenseInfo('05913275-n', 0), SenseInfo('04764412-n', 0) ],
"_charioteer_n_1_rel" : [ SenseInfo('09910222-n', 0), SenseInfo('09211056-n', 0) ],
"_band_n_1_rel" : [ SenseInfo('08240169-n', 12), SenseInfo('08249038-n', 8), SenseInfo('04680465-n', 2), SenseInfo('02784732-n', 2), SenseInfo('08249960-n', 1), SenseInfo('06260518-n', 1), SenseInfo('02784218-n', 1), SenseInfo('05267211-n', 0), SenseInfo('04092609-n', 0), SenseInfo('02785570-n', 0), SenseInfo('02785365-n', 0), SenseInfo('02785191-n', 0), SenseInfo('02784998-n', 0) ],
"_overhear_v_from_rel" : [ SenseInfo('02189168-v', 8) ],
"_pang_n_of_rel" : [ SenseInfo('07494972-n', 1), SenseInfo('14329762-n', 0), SenseInfo('14329654-n', 0) ],
"_compliance_n_1_rel" : [ SenseInfo('01203676-n', 1), SenseInfo('04641153-n', 0), SenseInfo('01166926-n', 0) ],
"_slug_v_1_rel" : [ SenseInfo('01415585-v', 7), SenseInfo('02417504-v', 0) ],
"_amazing_a_to_rel" : [ SenseInfo('02359789-a', 5), SenseInfo('01282510-a', 5), SenseInfo('02359789-a', 5), SenseInfo('01282510-a', 5), SenseInfo('02359789-a', 5), SenseInfo('01282510-a', 5) ],
"_filled+up_a_1_rel" : [  ],
"_finding_n_1_rel" : [ SenseInfo('00151497-n', 16), SenseInfo('01191975-n', 3), SenseInfo('09279458-n', 1), SenseInfo('00151497-n', 16), SenseInfo('01191975-n', 3), SenseInfo('09279458-n', 1) ],
"_venture_n_1_rel" : [ SenseInfo('00797878-n', 3), SenseInfo('13342692-n', 2), SenseInfo('01117164-n', 1), SenseInfo('00797878-n', 3), SenseInfo('13342692-n', 2), SenseInfo('01117164-n', 1) ],
"_conjecture_v_1_rel" : [ SenseInfo('00633443-v', 1) ],
"_inappropriate_a_for_rel" : [ SenseInfo('00135718-a', 2), SenseInfo('00562909-a', 0), SenseInfo('00135718-a', 2), SenseInfo('00562909-a', 0), SenseInfo('00135718-a', 2), SenseInfo('00562909-a', 0) ],
"_cross-platform_n_1_rel" : [  ],
"_pakistani_n_1_rel" : [ SenseInfo('09725772-n', 0) ],
"_shower_n_of_rel" : [ SenseInfo('04208936-n', 5), SenseInfo('00257580-n', 4), SenseInfo('11502497-n', 1), SenseInfo('07363668-n', 1), SenseInfo('10070563-n', 0), SenseInfo('08255795-n', 0) ],
"_neat_a_1_rel" : [ SenseInfo('02423284-a', 9), SenseInfo('02423432-a', 1), SenseInfo('00850648-a', 1), SenseInfo('00061664-a', 1), SenseInfo('01123879-a', 0), SenseInfo('00757120-a', 0), SenseInfo('02423284-a', 9), SenseInfo('02423432-a', 1), SenseInfo('00850648-a', 1), SenseInfo('00061664-a', 1), SenseInfo('01123879-a', 0), SenseInfo('00757120-a', 0), SenseInfo('02423284-a', 9), SenseInfo('02423432-a', 1), SenseInfo('00850648-a', 1), SenseInfo('00061664-a', 1), SenseInfo('01123879-a', 0), SenseInfo('00757120-a', 0), SenseInfo('02423284-a', 9), SenseInfo('02423432-a', 1), SenseInfo('00850648-a', 1), SenseInfo('00061664-a', 1), SenseInfo('01123879-a', 0), SenseInfo('00757120-a', 0) ],
"_kilo-x_n_1_rel" : [  ],
"_screwed_a_1_rel" : [  ],
"_to+make+sure_a_1_rel" : [  ],
"_down-shift_v_1_rel" : [  ],
"_undercurrent_n_1_rel" : [ SenseInfo('05922809-n', 1), SenseInfo('07404798-n', 0) ],
"_watchdog_n_1_rel" : [ SenseInfo('10769607-n', 0), SenseInfo('02103841-n', 0) ],
"_civic_a_1_rel" : [ SenseInfo('02697329-a', 4), SenseInfo('02696920-a', 0) ],
"_warehouse_n_of_rel" : [ SenseInfo('04551055-n', 5) ],
"_diabetic_n_1_rel" : [ SenseInfo('10010977-n', 2) ],
"_later+on_p_rel" : [ SenseInfo('00061203-r', 9) ],
"_synonym_n_1_rel" : [ SenseInfo('06303682-n', 2) ],
"_plant_v_1_rel" : [ SenseInfo('01567275-v', 8), SenseInfo('01528821-v', 2), SenseInfo('01647229-v', 1), SenseInfo('02322810-v', 0), SenseInfo('01371201-v', 0), SenseInfo('00734790-v', 0) ],
"_cumulo-nimbus_a_1_rel" : [  ],
"_blindfold_n_1_rel" : [ SenseInfo('02851939-n', 0), SenseInfo('02851939-n', 0) ],
"_national_n_1_rel" : [ SenseInfo('09625401-n', 2) ],
"_helping_n_1_rel" : [ SenseInfo('07578363-n', 0), SenseInfo('07578363-n', 0), SenseInfo('07578363-n', 0) ],
"_billow_v_1_rel" : [ SenseInfo('02041422-v', 1), SenseInfo('02041728-v', 0), SenseInfo('02041206-v', 0), SenseInfo('00256117-v', 0) ],
"_ramify_v_1_rel" : [ SenseInfo('00401373-v', 0), SenseInfo('00329244-v', 0), SenseInfo('00328802-v', 0) ],
"_detail_n_1_rel" : [ SenseInfo('05817845-n', 26), SenseInfo('13809920-n', 9), SenseInfo('07137807-n', 9), SenseInfo('08243081-n', 2), SenseInfo('08404549-n', 0), SenseInfo('05817845-n', 26), SenseInfo('13809920-n', 9), SenseInfo('07137807-n', 9), SenseInfo('08243081-n', 2), SenseInfo('08404549-n', 0) ],
"_caldera_n_1_rel" : [ SenseInfo('09231117-n', 0) ],
"_apportionment_n_1_rel" : [ SenseInfo('01083645-n', 0) ],
"_sunscreen_n_1_rel" : [ SenseInfo('04357314-n', 0), SenseInfo('04357314-n', 0) ],
"_benediction_n_1_rel" : [ SenseInfo('01043693-n', 1), SenseInfo('07189411-n', 0) ],
"_respectable_a_1_rel" : [ SenseInfo('01993140-a', 5), SenseInfo('01983162-a', 5), SenseInfo('00624576-a', 2), SenseInfo('01993140-a', 5), SenseInfo('01983162-a', 5), SenseInfo('00624576-a', 2) ],
"_fearless_a_1_rel" : [ SenseInfo('00081671-a', 1), SenseInfo('00250119-a', 0) ],
"_incumbent_n_1_rel" : [ SenseInfo('10202624-n', 0) ],
"_orthogonal_a_to_rel" : [ SenseInfo('01976532-a', 0), SenseInfo('01974979-a', 0), SenseInfo('01720642-a', 0) ],
"_first+off_a_1_rel" : [  ],
"_tooling_n_1_rel" : [  ],
"_cramp_v_1_rel" : [ SenseInfo('01304466-v', 0), SenseInfo('00236289-v', 0), SenseInfo('00031181-v', 0), SenseInfo('00031068-v', 0) ],
"_posterior_a_1_rel" : [ SenseInfo('00131426-a', 5), SenseInfo('00123485-a', 0) ],
"_microliter_n_1_rel" : [  ],
"_breach_v_1_rel" : [ SenseInfo('02566528-v', 1), SenseInfo('01593614-v', 1) ],
"_enzyme_n_1_rel" : [ SenseInfo('14732946-n', 7) ],
"_emergency_n_1_rel" : [ SenseInfo('07417405-n', 10), SenseInfo('14032599-n', 1), SenseInfo('03483637-n', 0), SenseInfo('07417405-n', 10), SenseInfo('14032599-n', 1), SenseInfo('03483637-n', 0) ],
"_rhyme_v_1_rel" : [ SenseInfo('01701858-v', 1), SenseInfo('02750432-v', 0) ],
"_proceed_v_with_rel" : [ SenseInfo('00781000-v', 19), SenseInfo('01995549-v', 17), SenseInfo('02372605-v', 8), SenseInfo('00341560-v', 3), SenseInfo('02684924-v', 1) ],
"_act_v_on_rel" : [ SenseInfo('02367363-v', 35), SenseInfo('00010435-v', 22), SenseInfo('01719302-v', 7), SenseInfo('01095899-v', 4), SenseInfo('00013615-v', 1), SenseInfo('02744977-v', 0), SenseInfo('02525447-v', 0), SenseInfo('02419073-v', 0), SenseInfo('01721556-v', 0), SenseInfo('01719921-v', 0) ],
"_descendant_n_1_rel" : [ SenseInfo('10006511-n', 1) ],
"_table_v_1_rel" : [ SenseInfo('02642814-v', 0), SenseInfo('01745536-v', 0) ],
"_ribbon_n_1_rel" : [ SenseInfo('09409203-n', 6), SenseInfo('06706676-n', 0), SenseInfo('04088058-n', 0), SenseInfo('04087899-n', 0) ],
"_magnetite_n_1_rel" : [ SenseInfo('14945914-n', 0) ],
"_quiver_v_1_rel" : [ SenseInfo('01889129-v', 8), SenseInfo('01878719-v', 1), SenseInfo('01879579-v', 0) ],
"_towel_n_1_rel" : [ SenseInfo('04459362-n', 6) ],
"_fake_v_1_rel" : [ SenseInfo('01654271-v', 1), SenseInfo('02576921-v', 0), SenseInfo('00839526-v', 0) ],
"_infix_v_1_rel" : [ SenseInfo('01421622-v', 0), SenseInfo('01298545-v', 0) ],
"_manifesto_n_1_rel" : [ SenseInfo('06727224-n', 0) ],
"_pomegranate_n_1_rel" : [ SenseInfo('12345280-n', 0), SenseInfo('07768694-n', 0) ],
"_fruit_n_1_rel" : [ SenseInfo('13134947-n', 10), SenseInfo('04612722-n', 3), SenseInfo('07294550-n', 1) ],
"_darned_a_1_rel" : [ SenseInfo('00669942-a', 6) ],
"_verification_n_of_rel" : [ SenseInfo('05825245-n', 1), SenseInfo('06736769-n', 0), SenseInfo('05825245-n', 1), SenseInfo('06736769-n', 0) ],
"_blacken_v_cause_rel" : [ SenseInfo('00280532-v', 2), SenseInfo('00379440-v', 0) ],
"_trustworthy_a_1_rel" : [ SenseInfo('02464693-a', 1), SenseInfo('01997748-a', 1) ],
"_scale_v_1_rel" : [ SenseInfo('02728388-v', 1), SenseInfo('01744082-v', 1), SenseInfo('02207036-v', 0), SenseInfo('01999082-v', 0), SenseInfo('01922466-v', 0), SenseInfo('01264148-v', 0), SenseInfo('00490428-v', 0), SenseInfo('00319406-v', 0) ],
"_brass_n_1_rel" : [ SenseInfo('14716997-n', 11), SenseInfo('02891788-n', 2), SenseInfo('08164585-n', 1), SenseInfo('04838210-n', 1), SenseInfo('02892304-n', 1), SenseInfo('08217135-n', 0), SenseInfo('02892201-n', 0) ],
"_fix_v_1_rel" : [ SenseInfo('00260648-v', 9), SenseInfo('01340439-v', 7), SenseInfo('00947077-v', 6), SenseInfo('01664172-v', 5), SenseInfo('01153947-v', 3), SenseInfo('01647543-v', 2), SenseInfo('00407458-v', 2), SenseInfo('00486998-v', 1), SenseInfo('00061595-v', 1), SenseInfo('02603299-v', 0), SenseInfo('01575675-v', 0), SenseInfo('00406243-v', 0), SenseInfo('00260648-v', 9), SenseInfo('01340439-v', 7), SenseInfo('00947077-v', 6), SenseInfo('01664172-v', 5), SenseInfo('01153947-v', 3), SenseInfo('01647543-v', 2), SenseInfo('00407458-v', 2), SenseInfo('00486998-v', 1), SenseInfo('00061595-v', 1), SenseInfo('02603299-v', 0), SenseInfo('01575675-v', 0), SenseInfo('00406243-v', 0) ],
"_artists_a_1_rel" : [  ],
"_diode_n_1_rel" : [ SenseInfo('03202940-n', 0), SenseInfo('03202760-n', 0) ],
"_mild_a_1_rel" : [ SenseInfo('01508719-a', 7), SenseInfo('01893510-a', 0), SenseInfo('00438332-a', 0), SenseInfo('01508719-a', 7), SenseInfo('01893510-a', 0), SenseInfo('00438332-a', 0), SenseInfo('01508719-a', 7), SenseInfo('01893510-a', 0), SenseInfo('00438332-a', 0), SenseInfo('01508719-a', 7), SenseInfo('01893510-a', 0), SenseInfo('00438332-a', 0), SenseInfo('01508719-a', 7), SenseInfo('01893510-a', 0), SenseInfo('00438332-a', 0), SenseInfo('01508719-a', 7), SenseInfo('01893510-a', 0), SenseInfo('00438332-a', 0), SenseInfo('01508719-a', 7), SenseInfo('01893510-a', 0), SenseInfo('00438332-a', 0) ],
"_argentinian_a_1_rel" : [ SenseInfo('02966972-a', 0) ],
"_answer_v_1_rel" : [ SenseInfo('00815686-v', 63), SenseInfo('00719590-v', 7), SenseInfo('00636279-v', 7), SenseInfo('00635523-v', 5), SenseInfo('00815171-v', 4), SenseInfo('02746017-v', 0), SenseInfo('02669789-v', 0), SenseInfo('02658570-v', 0), SenseInfo('01183896-v', 0), SenseInfo('00718308-v', 0), SenseInfo('00815686-v', 63), SenseInfo('00719590-v', 7), SenseInfo('00636279-v', 7), SenseInfo('00635523-v', 5), SenseInfo('00815171-v', 4), SenseInfo('02746017-v', 0), SenseInfo('02669789-v', 0), SenseInfo('02658570-v', 0), SenseInfo('01183896-v', 0), SenseInfo('00718308-v', 0), SenseInfo('00815686-v', 63), SenseInfo('00719590-v', 7), SenseInfo('00636279-v', 7), SenseInfo('00635523-v', 5), SenseInfo('00815171-v', 4), SenseInfo('02746017-v', 0), SenseInfo('02669789-v', 0), SenseInfo('02658570-v', 0), SenseInfo('01183896-v', 0), SenseInfo('00718308-v', 0), SenseInfo('00815686-v', 63), SenseInfo('00719590-v', 7), SenseInfo('00636279-v', 7), SenseInfo('00635523-v', 5), SenseInfo('00815171-v', 4), SenseInfo('02746017-v', 0), SenseInfo('02669789-v', 0), SenseInfo('02658570-v', 0), SenseInfo('01183896-v', 0), SenseInfo('00718308-v', 0), SenseInfo('00815686-v', 63), SenseInfo('00719590-v', 7), SenseInfo('00636279-v', 7), SenseInfo('00635523-v', 5), SenseInfo('00815171-v', 4), SenseInfo('02746017-v', 0), SenseInfo('02669789-v', 0), SenseInfo('02658570-v', 0), SenseInfo('01183896-v', 0), SenseInfo('00718308-v', 0) ],
"_baby_n_1_rel" : [ SenseInfo('09827683-n', 16), SenseInfo('09827519-n', 1), SenseInfo('09918554-n', 0), SenseInfo('09828216-n', 0), SenseInfo('09827363-n', 0), SenseInfo('01322221-n', 0), SenseInfo('00796767-n', 0) ],
"_witch+hazel_n_1_rel" : [ SenseInfo('12314808-n', 0), SenseInfo('04596224-n', 0) ],
"_write-down_n_1_rel" : [ SenseInfo('13328853-n', 0), SenseInfo('13328853-n', 0) ],
"_pit_v_1_rel" : [ SenseInfo('01081152-v', 1), SenseInfo('01551195-v', 0), SenseInfo('00179567-v', 0) ],
"_beefy_a_1_rel" : [ SenseInfo('02038126-a', 1), SenseInfo('02038126-a', 1), SenseInfo('02038126-a', 1) ],
"_piranha_n_1_rel" : [ SenseInfo('10293172-n', 0), SenseInfo('02584449-n', 0) ],
"_lapse_v_1_rel" : [ SenseInfo('01972131-v', 1), SenseInfo('00351824-v', 1), SenseInfo('00204585-v', 1), SenseInfo('00093327-v', 1), SenseInfo('02303761-v', 0), SenseInfo('02072849-v', 0), SenseInfo('01972131-v', 1), SenseInfo('00351824-v', 1), SenseInfo('00204585-v', 1), SenseInfo('00093327-v', 1), SenseInfo('02303761-v', 0), SenseInfo('02072849-v', 0) ],
"_log_v_on_rel" : [ SenseInfo('01002481-v', 2), SenseInfo('01258828-v', 1), SenseInfo('01002481-v', 2), SenseInfo('01258828-v', 1) ],
"_beat-up_a_1_rel" : [ SenseInfo('00679562-a', 1), SenseInfo('00679562-a', 1) ],
"_famous_n_1_rel" : [ SenseInfo('01375831-a', 21) ],
"_possible_a_for_rel" : [ SenseInfo('01821266-a', 136), SenseInfo('00044353-a', 20), SenseInfo('01821266-a', 136), SenseInfo('00044353-a', 20), SenseInfo('01821266-a', 136), SenseInfo('00044353-a', 20), SenseInfo('01821266-a', 136), SenseInfo('00044353-a', 20), SenseInfo('01821266-a', 136), SenseInfo('00044353-a', 20) ],
"_necessitate_v_1_rel" : [ SenseInfo('02627934-v', 12), SenseInfo('02635547-v', 4), SenseInfo('02627934-v', 12), SenseInfo('02635547-v', 4) ],
"_recordbook_n_1_rel" : [  ],
"_implore_v_1_rel" : [ SenseInfo('00759269-v', 4), SenseInfo('00759269-v', 4), SenseInfo('00759269-v', 4) ],
"_thwart_n_1_rel" : [ SenseInfo('04432043-n', 1) ],
"_self-selection_n_1_rel" : [  ],
"_goal_n_1_rel" : [ SenseInfo('05980875-n', 34), SenseInfo('08567877-n', 1), SenseInfo('03442756-n', 0), SenseInfo('00187337-n', 0), SenseInfo('05980875-n', 34), SenseInfo('08567877-n', 1), SenseInfo('03442756-n', 0), SenseInfo('00187337-n', 0) ],
"_omelet_n_1_rel" : [ SenseInfo('07842753-n', 0) ],
"_fitting_a_1_rel" : [ SenseInfo('01879667-a', 5), SenseInfo('01370141-a', 2), SenseInfo('01879667-a', 5), SenseInfo('01370141-a', 2), SenseInfo('01879667-a', 5), SenseInfo('01370141-a', 2), SenseInfo('01879667-a', 5), SenseInfo('01370141-a', 2) ],
"_colonnade_n_1_rel" : [ SenseInfo('03071160-n', 0), SenseInfo('02733213-n', 0) ],
"_co-opt_v_of_rel" : [ SenseInfo('02401051-v', 1), SenseInfo('02536098-v', 0), SenseInfo('02397266-v', 0), SenseInfo('02362460-v', 0), SenseInfo('02401051-v', 1), SenseInfo('02536098-v', 0), SenseInfo('02397266-v', 0), SenseInfo('02362460-v', 0), SenseInfo('02401051-v', 1), SenseInfo('02536098-v', 0), SenseInfo('02397266-v', 0), SenseInfo('02362460-v', 0) ],
"_twist_n_1_rel" : [ SenseInfo('07423365-n', 2), SenseInfo('07173959-n', 2), SenseInfo('00171249-n', 2), SenseInfo('00343249-n', 1), SenseInfo('14299070-n', 0), SenseInfo('13877918-n', 0), SenseInfo('13869327-n', 0), SenseInfo('07432973-n', 0), SenseInfo('07351909-n', 0), SenseInfo('05259512-n', 0), SenseInfo('00534631-n', 0), SenseInfo('00345641-n', 0), SenseInfo('00345454-n', 0) ],
"_reentrant_a_1_rel" : [ SenseInfo('02592015-a', 0), SenseInfo('02592015-a', 0) ],
"_translate_v_1_rel" : [ SenseInfo('00959827-v', 10), SenseInfo('00383542-v', 7), SenseInfo('00593852-v', 4), SenseInfo('01436290-v', 2), SenseInfo('00522441-v', 2), SenseInfo('02753100-v', 0), SenseInfo('02728142-v', 0), SenseInfo('02103925-v', 0), SenseInfo('00961947-v', 0), SenseInfo('00919608-v', 0) ],
"_impatient_n_1_rel" : [ SenseInfo('01737241-a', 5), SenseInfo('00811536-a', 2) ],
"_feminism_n_1_rel" : [ SenseInfo('05967773-n', 0), SenseInfo('00800421-n', 0) ],
"_pearly_a_1_rel" : [ SenseInfo('00390943-a', 1) ],
"_more+than_x_rel" : [ SenseInfo('01555133-a', 0) ],
"_amount_n_of_rel" : [ SenseInfo('13331198-n', 40), SenseInfo('05107765-n', 39), SenseInfo('00033615-n', 20), SenseInfo('05861067-n', 6), SenseInfo('13331198-n', 40), SenseInfo('05107765-n', 39), SenseInfo('00033615-n', 20), SenseInfo('05861067-n', 6), SenseInfo('13331198-n', 40), SenseInfo('05107765-n', 39), SenseInfo('00033615-n', 20), SenseInfo('05861067-n', 6) ],
"_percent_n_of_rel" : [ SenseInfo('13817526-n', 64), SenseInfo('13817526-n', 64), SenseInfo('13817526-n', 64), SenseInfo('13817526-n', 64), SenseInfo('13817526-n', 64), SenseInfo('13817526-n', 64), SenseInfo('13817526-n', 64), SenseInfo('13817526-n', 64), SenseInfo('13817526-n', 64) ],
"_gabbro_n_1_rel" : [ SenseInfo('14932645-n', 0) ],
"_completion_n_of_rel" : [ SenseInfo('00557419-n', 3), SenseInfo('00211110-n', 2) ],
"_ban_v_from_rel" : [ SenseInfo('02493666-v', 2), SenseInfo('00796392-v', 2), SenseInfo('02504280-v', 0), SenseInfo('02504017-v', 0), SenseInfo('02493666-v', 2), SenseInfo('00796392-v', 2), SenseInfo('02504280-v', 0), SenseInfo('02504017-v', 0) ],
"_colombian_n_1_rel" : [ SenseInfo('09698517-n', 0) ],
"_germinate_v_cause_rel" : [ SenseInfo('00357332-v', 2), SenseInfo('01738597-v', 0), SenseInfo('00357667-v', 0) ],
"_scope_n_of_rel" : [ SenseInfo('05125377-n', 15), SenseInfo('14513259-n', 0), SenseInfo('04403638-n', 0), SenseInfo('03857828-n', 0) ],
"_usd_n_1_rel" : [  ],
"_satirical_a_about_rel" : [ SenseInfo('02080110-a', 1) ],
"_roach_n_1_rel" : [ SenseInfo('05261088-n', 0), SenseInfo('04095853-n', 0), SenseInfo('04036494-n', 0), SenseInfo('02233338-n', 0), SenseInfo('01442450-n', 0) ],
"_diffuse_v_cause_rel" : [ SenseInfo('02060141-v', 1), SenseInfo('01229071-v', 1), SenseInfo('00968211-v', 1) ],
"_afraid+not_a_1_rel" : [  ],
"_descry_v_1_rel" : [ SenseInfo('02154312-v', 0) ],
"_trijet_n_1_rel" : [  ],
"_thesaurus_n_1_rel" : [ SenseInfo('06421016-n', 0) ],
"_canvas_v_1_rel" : [ SenseInfo('02458747-v', 0), SenseInfo('02454312-v', 0), SenseInfo('01268297-v', 0), SenseInfo('00644583-v', 0) ],
"_unimpeachable_a_1_rel" : [ SenseInfo('01918873-a', 1), SenseInfo('01320705-a', 0), SenseInfo('00018222-a', 0), SenseInfo('01918873-a', 1), SenseInfo('01320705-a', 0), SenseInfo('00018222-a', 0), SenseInfo('01918873-a', 1), SenseInfo('01320705-a', 0), SenseInfo('00018222-a', 0) ],
"_harem_n_1_rel" : [ SenseInfo('03494105-n', 1) ],
"_okay_n_1_rel" : [ SenseInfo('06687701-n', 0), SenseInfo('06687701-n', 0), SenseInfo('06687701-n', 0) ],
"_such+that_x_rel" : [  ],
"_rifleman_n_1_rel" : [ SenseInfo('10530677-n', 3), SenseInfo('10530571-n', 1) ],
"_gasp_v_for_rel" : [ SenseInfo('00005526-v', 9) ],
"_hayloft_n_1_rel" : [ SenseInfo('03500557-n', 0) ],
"_visor_n_1_rel" : [ SenseInfo('04538878-n', 0), SenseInfo('02838728-n', 0) ],
"_alma+mater_n_1_rel" : [ SenseInfo('08402339-n', 0) ],
"_scheme_n_1_rel" : [ SenseInfo('05905348-n', 10), SenseInfo('06756680-n', 1), SenseInfo('08435388-n', 0), SenseInfo('05927813-n', 0), SenseInfo('05891572-n', 0), SenseInfo('05905348-n', 10), SenseInfo('06756680-n', 1), SenseInfo('08435388-n', 0), SenseInfo('05927813-n', 0), SenseInfo('05891572-n', 0), SenseInfo('05905348-n', 10), SenseInfo('06756680-n', 1), SenseInfo('08435388-n', 0), SenseInfo('05927813-n', 0), SenseInfo('05891572-n', 0) ],
"_whatnot_n_1_rel" : [ SenseInfo('02897692-n', 0) ],
"_diminish_v_1_rel" : [ SenseInfo('00151689-v', 10), SenseInfo('00441881-v', 2) ],
"_influential_a_1_rel" : [ SenseInfo('01830134-a', 2) ],
"_lineage_n_1_rel" : [ SenseInfo('08101937-n', 2), SenseInfo('13813042-n', 0), SenseInfo('13713408-n', 0), SenseInfo('13326975-n', 0), SenseInfo('04922787-n', 0) ],
"_barbecue_n_1_rel" : [ SenseInfo('07654148-n', 0), SenseInfo('07576781-n', 0), SenseInfo('02790669-n', 0) ],
"_vacation_v_1_rel" : [ SenseInfo('02708707-v', 2) ],
"_permanent_a_1_rel" : [ SenseInfo('01754421-a', 13), SenseInfo('01759527-a', 0), SenseInfo('01754421-a', 13), SenseInfo('01759527-a', 0) ],
"_boo_n_1_rel" : [ SenseInfo('07123870-n', 0) ],
"_torpedo_v_1_rel" : [ SenseInfo('01137983-v', 0) ],
"_blah_n_1_rel" : [ SenseInfo('07087777-n', 0) ],
"_seizure_n_1_rel" : [ SenseInfo('14081941-n', 3), SenseInfo('00088481-n', 1), SenseInfo('00775286-n', 0), SenseInfo('00085219-n', 0) ],
"_nicer_a_for_rel" : [  ],
"_pontiff_n_1_rel" : [ SenseInfo('10453533-n', 0) ],
"_manifold_n_1_rel" : [ SenseInfo('03717750-n', 11), SenseInfo('14946750-n', 0), SenseInfo('08004548-n', 0) ],
"_act_v_as_rel" : [ SenseInfo('02367363-v', 35), SenseInfo('00010435-v', 22), SenseInfo('01719302-v', 7), SenseInfo('01095899-v', 4), SenseInfo('00013615-v', 1), SenseInfo('02744977-v', 0), SenseInfo('02525447-v', 0), SenseInfo('02419073-v', 0), SenseInfo('01721556-v', 0), SenseInfo('01719921-v', 0) ],
"_mol_n_1_rel" : [ SenseInfo('13724081-n', 0) ],
"_lived-in_a_1_rel" : [  ],
"_capitol_n_of_rel" : [ SenseInfo('02956699-n', 0), SenseInfo('02956500-n', 0) ],
"_or+not_a_1_rel" : [  ],
"_rectus_n_1_rel" : [ SenseInfo('05316590-n', 0) ],
"_uneasiness_n_1_rel" : [ SenseInfo('07525057-n', 2), SenseInfo('14447019-n', 0), SenseInfo('07507329-n', 0), SenseInfo('04904851-n', 0), SenseInfo('04625284-n', 0), SenseInfo('07525057-n', 2), SenseInfo('14447019-n', 0), SenseInfo('07507329-n', 0), SenseInfo('04904851-n', 0), SenseInfo('04625284-n', 0), SenseInfo('07525057-n', 2), SenseInfo('14447019-n', 0), SenseInfo('07507329-n', 0), SenseInfo('04904851-n', 0), SenseInfo('04625284-n', 0) ],
"_mercenary_n_1_rel" : [ SenseInfo('10309614-n', 2) ],
"_become_v_of_rel" : [ SenseInfo('00149583-v', 327), SenseInfo('02626604-v', 220), SenseInfo('02623529-v', 5), SenseInfo('02724258-v', 0) ],
"_behave_v_pos_rel" : [ SenseInfo('00010435-v', 18), SenseInfo('02518161-v', 3), SenseInfo('02519666-v', 1), SenseInfo('00010435-v', 18), SenseInfo('02518161-v', 3), SenseInfo('02519666-v', 1) ],
"_killer_n_1_rel" : [ SenseInfo('10231087-n', 8), SenseInfo('14540564-n', 0), SenseInfo('05688630-n', 0), SenseInfo('02071294-n', 0) ],
"_composer_n_of_rel" : [ SenseInfo('09947232-n', 24) ],
"_stitch_v_1_rel" : [ SenseInfo('01329239-v', 1) ],
"_potluck_n_1_rel" : [ SenseInfo('07574176-n', 0) ],
"_migrate_v_1_rel" : [ SenseInfo('01856626-v', 4), SenseInfo('01857093-v', 0) ],
"_female_a_1_rel" : [ SenseInfo('01477806-a', 11), SenseInfo('01484451-a', 3), SenseInfo('01478182-a', 0) ],
"_brighten_v_cause_rel" : [ SenseInfo('00312815-v', 1), SenseInfo('02771169-v', 0) ],
"_disconnection_n_of_rel" : [ SenseInfo('14417697-n', 0), SenseInfo('04753060-n', 0), SenseInfo('00385649-n', 0) ],
"_equal_n_1_rel" : [ SenseInfo('09626238-n', 1) ],
"_mousetrap_n_1_rel" : [ SenseInfo('03794056-n', 0), SenseInfo('00976270-n', 0) ],
"_literary_a_1_rel" : [ SenseInfo('02830501-a', 27), SenseInfo('01421368-a', 0), SenseInfo('01045518-a', 0) ],
"_tubular_a_1_rel" : [ SenseInfo('02264807-a', 1) ],
"_nanoparticle_n_1_rel" : [  ],
"_psychiatrist_n_1_rel" : [ SenseInfo('10488016-n', 4) ],
"_ability_n_1_rel" : [ SenseInfo('05200169-n', 19), SenseInfo('05616246-n', 9), SenseInfo('05200169-n', 19), SenseInfo('05616246-n', 9) ],
"_god+send_n_1_rel" : [ SenseInfo('07477587-n', 0), SenseInfo('07477587-n', 0), SenseInfo('07477587-n', 0) ],
"_infuriating_a_for_rel" : [ SenseInfo('01809245-a', 2) ],
"_bagpipe_n_1_rel" : [ SenseInfo('02775483-n', 1) ],
"_aside_p_rel" : [ SenseInfo('00233892-r', 7), SenseInfo('00234052-r', 5), SenseInfo('00180756-r', 4), SenseInfo('07011075-n', 0), SenseInfo('06600684-n', 0), SenseInfo('00234951-r', 0), SenseInfo('00234201-r', 0), SenseInfo('00233687-r', 0) ],
"_gallop_v_1_rel" : [ SenseInfo('01959927-v', 8), SenseInfo('01960643-v', 3), SenseInfo('01960296-v', 0) ],
"_fearsome_a_1_rel" : [ SenseInfo('00193799-a', 0) ],
"_unproductive_a_1_rel" : [ SenseInfo('01866535-a', 0), SenseInfo('00836111-a', 0), SenseInfo('01866535-a', 0), SenseInfo('00836111-a', 0), SenseInfo('01866535-a', 0), SenseInfo('00836111-a', 0) ],
"_frightening_a_1_rel" : [ SenseInfo('00193799-a', 6), SenseInfo('00193799-a', 6) ],
"_solid_n_1_rel" : [ SenseInfo('15046900-n', 14), SenseInfo('14480772-n', 1), SenseInfo('13860793-n', 0) ],
"_nicety_n_1_rel" : [ SenseInfo('04713853-n', 1), SenseInfo('06606191-n', 0) ],
"_promoter_n_of_rel" : [ SenseInfo('10482220-n', 2), SenseInfo('10593745-n', 0) ],
"_candle_n_1_rel" : [ SenseInfo('02948072-n', 4), SenseInfo('13641534-n', 0) ],
"_nod_v_off_rel" : [ SenseInfo('00898434-v', 35), SenseInfo('00898210-v', 16), SenseInfo('00016702-v', 1), SenseInfo('01877785-v', 0), SenseInfo('00016573-v', 0) ],
"temp_loc_x_rel" : [  ],
"_terrify_v_1_rel" : [ SenseInfo('01780941-v', 1), SenseInfo('01780941-v', 1), SenseInfo('01780941-v', 1), SenseInfo('01780941-v', 1), SenseInfo('01780941-v', 1) ],
"_guard_v_against_rel" : [ SenseInfo('02456031-v', 6), SenseInfo('01129337-v', 6), SenseInfo('01129876-v', 2), SenseInfo('02599878-v', 0), SenseInfo('02456031-v', 6), SenseInfo('01129337-v', 6), SenseInfo('01129876-v', 2), SenseInfo('02599878-v', 0) ],
"_I_n_num_rel" : [ SenseInfo('14641397-n', 0), SenseInfo('13742573-n', 0), SenseInfo('06832033-n', 0), SenseInfo('14641397-n', 0), SenseInfo('13742573-n', 0), SenseInfo('06832033-n', 0) ],
"_plough_n_1_rel" : [ SenseInfo('09219858-n', 0), SenseInfo('03967562-n', 0) ],
"_week+to+week_a_1_rel" : [  ],
"_animate_a_1_rel" : [ SenseInfo('00120252-a', 1), SenseInfo('00118066-a', 0), SenseInfo('00117385-a', 0) ],
"_scrape_v_together_rel" : [ SenseInfo('01308160-v', 4), SenseInfo('01750156-v', 1), SenseInfo('01309143-v', 1), SenseInfo('02040709-v', 0), SenseInfo('01384752-v', 0), SenseInfo('01309478-v', 0) ],
"_shoot_v_for_rel" : [ SenseInfo('01137138-v', 28), SenseInfo('02484570-v', 27), SenseInfo('01134781-v', 26), SenseInfo('01002740-v', 7), SenseInfo('02096047-v', 3), SenseInfo('02061495-v', 3), SenseInfo('02055267-v', 1), SenseInfo('01597286-v', 1), SenseInfo('01003249-v', 1), SenseInfo('02768259-v', 0), SenseInfo('02123175-v', 0), SenseInfo('01585523-v', 0), SenseInfo('01519184-v', 0), SenseInfo('01437144-v', 0), SenseInfo('01195804-v', 0), SenseInfo('01084466-v', 0), SenseInfo('00985219-v', 0), SenseInfo('00647508-v', 0), SenseInfo('00357332-v', 0), SenseInfo('00086320-v', 0) ],
"_carpet_n_1_rel" : [ SenseInfo('04118021-n', 3), SenseInfo('09236766-n', 0) ],
"_shrug_v_off_rel" : [ SenseInfo('00033955-v', 10) ],
"_composition_n_1_rel" : [ SenseInfo('05076472-n', 4), SenseInfo('04933544-n', 4), SenseInfo('14588492-n', 2), SenseInfo('07037465-n', 1), SenseInfo('00939452-n', 1), SenseInfo('00929718-n', 1), SenseInfo('06677974-n', 0), SenseInfo('06409752-n', 0), SenseInfo('03081660-n', 0) ],
"_forever_a_1_rel" : [  ],
"_shake_v_off_rel" : [ SenseInfo('01889610-v', 42), SenseInfo('00014034-v', 14), SenseInfo('01891638-v', 8), SenseInfo('01875295-v', 6), SenseInfo('00167385-v', 6), SenseInfo('01761706-v', 2), SenseInfo('02073545-v', 1), SenseInfo('00559556-v', 1), SenseInfo('00992518-v', 0) ],
"_warn_v_of_rel" : [ SenseInfo('00870213-v', 22), SenseInfo('00870577-v', 5), SenseInfo('00833071-v', 0), SenseInfo('00832907-v', 0), SenseInfo('00870213-v', 22), SenseInfo('00870577-v', 5), SenseInfo('00833071-v', 0), SenseInfo('00832907-v', 0) ],
"_stretch_v_out_rel" : [ SenseInfo('02607830-v', 16), SenseInfo('00027268-v', 11), SenseInfo('02054989-v', 4), SenseInfo('00240810-v', 4), SenseInfo('00318816-v', 3), SenseInfo('01985271-v', 1), SenseInfo('01449591-v', 1), SenseInfo('00541746-v', 1), SenseInfo('00487748-v', 0), SenseInfo('00154141-v', 0), SenseInfo('00101434-v', 0) ],
"_ecuadoran_n_1_rel" : [ SenseInfo('09700371-n', 0) ],
"_jubilee_n_1_rel" : [ SenseInfo('15250312-n', 0) ],
"_protective_a_of_rel" : [ SenseInfo('01887076-a', 9), SenseInfo('02449177-a', 1), SenseInfo('00311187-a', 0) ],
"_hire_v_1_rel" : [ SenseInfo('02409412-v', 33), SenseInfo('02460619-v', 1), SenseInfo('02208537-v', 0) ],
"_coral_n_1_rel" : [ SenseInfo('04971820-n', 1), SenseInfo('14823036-n', 0), SenseInfo('07793795-n', 0), SenseInfo('01915811-n', 0) ],
"_restroom_n_1_rel" : [ SenseInfo('04018667-n', 0) ],
"_all+the+way_a_1_rel" : [  ],
"_assertive_a_1_rel" : [ SenseInfo('00156101-a', 1) ],
"_relaxing_a_1_rel" : [ SenseInfo('01922227-a', 0) ],
"_separate_v_from_rel" : [ SenseInfo('02621853-v', 18), SenseInfo('01556921-v', 8), SenseInfo('00650353-v', 7), SenseInfo('02467662-v', 6), SenseInfo('01458973-v', 3), SenseInfo('00654625-v', 3), SenseInfo('02031158-v', 2), SenseInfo('02431320-v', 1), SenseInfo('02030158-v', 1), SenseInfo('00334186-v', 1), SenseInfo('02512305-v', 0), SenseInfo('01557774-v', 0), SenseInfo('00328802-v', 0), SenseInfo('02621853-v', 18), SenseInfo('01556921-v', 8), SenseInfo('00650353-v', 7), SenseInfo('02467662-v', 6), SenseInfo('01458973-v', 3), SenseInfo('00654625-v', 3), SenseInfo('02031158-v', 2), SenseInfo('02431320-v', 1), SenseInfo('02030158-v', 1), SenseInfo('00334186-v', 1), SenseInfo('02512305-v', 0), SenseInfo('01557774-v', 0), SenseInfo('00328802-v', 0) ],
"_speculate_v_1_rel" : [ SenseInfo('00633443-v', 5), SenseInfo('00927049-v', 4), SenseInfo('00630380-v', 1), SenseInfo('02272090-v', 0), SenseInfo('00633443-v', 5), SenseInfo('00927049-v', 4), SenseInfo('00630380-v', 1), SenseInfo('02272090-v', 0) ],
"_homeless_n_1_rel" : [ SenseInfo('10182190-n', 0), SenseInfo('07948314-n', 0), SenseInfo('10182190-n', 0), SenseInfo('07948314-n', 0) ],
"_squint_n_1_rel" : [ SenseInfo('14557415-n', 0), SenseInfo('00878328-n', 0) ],
"_shampoo_n_1_rel" : [ SenseInfo('04183516-n', 0), SenseInfo('00257115-n', 0) ],
"_campaign_v_1_rel" : [ SenseInfo('01094086-v', 7), SenseInfo('02589576-v', 2), SenseInfo('01093786-v', 0) ],
"_polish_n_2_rel" : [ SenseInfo('04955160-n', 2), SenseInfo('14459824-n', 1), SenseInfo('14996020-n', 0), SenseInfo('06944720-n', 0) ],
"_fatigues_n_1_rel" : [ SenseInfo('14016361-n', 4), SenseInfo('14463676-n', 0), SenseInfo('07540081-n', 0), SenseInfo('00730708-n', 0), SenseInfo('14016361-n', 4), SenseInfo('14463676-n', 0), SenseInfo('07540081-n', 0), SenseInfo('00730708-n', 0) ],
"_truss_n_1_rel" : [ SenseInfo('04492585-n', 0), SenseInfo('04492375-n', 0), SenseInfo('03105467-n', 0) ],
"_hydrophobia_n_1_rel" : [ SenseInfo('14383624-n', 0), SenseInfo('14383544-n', 0), SenseInfo('14271667-n', 0) ],
"_tipsy_a_1_rel" : [ SenseInfo('00798384-a', 1), SenseInfo('02293386-a', 0), SenseInfo('00798384-a', 1), SenseInfo('02293386-a', 0), SenseInfo('00798384-a', 1), SenseInfo('02293386-a', 0) ],
"_balloon_v_1_rel" : [ SenseInfo('01948659-v', 0), SenseInfo('00256117-v', 0) ],
"_temple_n_1_rel" : [ SenseInfo('04407435-n', 6), SenseInfo('05602683-n', 1), SenseInfo('04407686-n', 1), SenseInfo('04374735-n', 0), SenseInfo('04407435-n', 6), SenseInfo('05602683-n', 1), SenseInfo('04407686-n', 1), SenseInfo('04374735-n', 0) ],
"_inscrutability_n_1_rel" : [ SenseInfo('04822524-n', 1) ],
"_pound+sterling_n_1_rel" : [ SenseInfo('13686660-n', 0), SenseInfo('13686660-n', 0), SenseInfo('13686660-n', 0) ],
"_exile_n_1_rel" : [ SenseInfo('10071332-n', 0), SenseInfo('10071139-n', 0), SenseInfo('00207761-n', 0) ],
"_night_n_of_rel" : [ SenseInfo('15167027-n', 163), SenseInfo('15167577-n', 1), SenseInfo('15167474-n', 1), SenseInfo('15155747-n', 1), SenseInfo('13983717-n', 1), SenseInfo('15169759-n', 0), SenseInfo('15167349-n', 0), SenseInfo('09559769-n', 0), SenseInfo('15167027-n', 163), SenseInfo('15167577-n', 1), SenseInfo('15167474-n', 1), SenseInfo('15155747-n', 1), SenseInfo('13983717-n', 1), SenseInfo('15169759-n', 0), SenseInfo('15167349-n', 0), SenseInfo('09559769-n', 0), SenseInfo('15167027-n', 163), SenseInfo('15167577-n', 1), SenseInfo('15167474-n', 1), SenseInfo('15155747-n', 1), SenseInfo('13983717-n', 1), SenseInfo('15169759-n', 0), SenseInfo('15167349-n', 0), SenseInfo('09559769-n', 0), SenseInfo('15167027-n', 163), SenseInfo('15167577-n', 1), SenseInfo('15167474-n', 1), SenseInfo('15155747-n', 1), SenseInfo('13983717-n', 1), SenseInfo('15169759-n', 0), SenseInfo('15167349-n', 0), SenseInfo('09559769-n', 0), SenseInfo('15167027-n', 163), SenseInfo('15167577-n', 1), SenseInfo('15167474-n', 1), SenseInfo('15155747-n', 1), SenseInfo('13983717-n', 1), SenseInfo('15169759-n', 0), SenseInfo('15167349-n', 0), SenseInfo('09559769-n', 0), SenseInfo('15167027-n', 163), SenseInfo('15167577-n', 1), SenseInfo('15167474-n', 1), SenseInfo('15155747-n', 1), SenseInfo('13983717-n', 1), SenseInfo('15169759-n', 0), SenseInfo('15167349-n', 0), SenseInfo('09559769-n', 0) ],
"_wrongful_a_1_rel" : [ SenseInfo('01408421-a', 0), SenseInfo('01396628-a', 0), SenseInfo('01371009-a', 0), SenseInfo('01408421-a', 0), SenseInfo('01396628-a', 0), SenseInfo('01371009-a', 0) ],
"_rave_n_1_rel" : [ SenseInfo('07449676-n', 0), SenseInfo('06693744-n', 0) ],
"_tramway_n_1_rel" : [ SenseInfo('04469813-n', 0), SenseInfo('04469003-n', 0) ],
"_bachelor_n_1_rel" : [ SenseInfo('09829923-n', 2), SenseInfo('10238749-n', 0) ],
"_such_a_1_rel" : [ SenseInfo('01554230-a', 22) ],
"_rebate_v_1_rel" : [ SenseInfo('02320200-v', 0), SenseInfo('01555193-v', 0), SenseInfo('01295134-v', 0) ],
"_Band-Aid_n_1_rel" : [  ],
"_intestinal_a_1_rel" : [ SenseInfo('02935530-a', 0) ],
"_previously_p_1_rel" : [ SenseInfo('00060632-r', 30) ],
"_quicker_a_1_rel" : [  ],
"_renunciation_n_of_rel" : [ SenseInfo('07207410-n', 1), SenseInfo('14413411-n', 0), SenseInfo('07254594-n', 0), SenseInfo('00205079-n', 0) ],
"_salad_n_1_rel" : [ SenseInfo('07806221-n', 1) ],
"_hot_a_1_rel" : [ SenseInfo('01247240-a', 50), SenseInfo('02511800-a', 4), SenseInfo('01256332-a', 3), SenseInfo('02532114-a', 1), SenseInfo('02132607-a', 1), SenseInfo('01403632-a', 1), SenseInfo('00977372-a', 1), SenseInfo('02527402-a', 0), SenseInfo('02397732-a', 0), SenseInfo('02227485-a', 0), SenseInfo('01816525-a', 0), SenseInfo('01804034-a', 0), SenseInfo('01641791-a', 0), SenseInfo('01468420-a', 0), SenseInfo('01124441-a', 0), SenseInfo('01068438-a', 0), SenseInfo('00811421-a', 0), SenseInfo('00445440-a', 0), SenseInfo('00427105-a', 0), SenseInfo('00358392-a', 0), SenseInfo('00033077-a', 0), SenseInfo('01247240-a', 50), SenseInfo('02511800-a', 4), SenseInfo('01256332-a', 3), SenseInfo('02532114-a', 1), SenseInfo('02132607-a', 1), SenseInfo('01403632-a', 1), SenseInfo('00977372-a', 1), SenseInfo('02527402-a', 0), SenseInfo('02397732-a', 0), SenseInfo('02227485-a', 0), SenseInfo('01816525-a', 0), SenseInfo('01804034-a', 0), SenseInfo('01641791-a', 0), SenseInfo('01468420-a', 0), SenseInfo('01124441-a', 0), SenseInfo('01068438-a', 0), SenseInfo('00811421-a', 0), SenseInfo('00445440-a', 0), SenseInfo('00427105-a', 0), SenseInfo('00358392-a', 0), SenseInfo('00033077-a', 0), SenseInfo('01247240-a', 50), SenseInfo('02511800-a', 4), SenseInfo('01256332-a', 3), SenseInfo('02532114-a', 1), SenseInfo('02132607-a', 1), SenseInfo('01403632-a', 1), SenseInfo('00977372-a', 1), SenseInfo('02527402-a', 0), SenseInfo('02397732-a', 0), SenseInfo('02227485-a', 0), SenseInfo('01816525-a', 0), SenseInfo('01804034-a', 0), SenseInfo('01641791-a', 0), SenseInfo('01468420-a', 0), SenseInfo('01124441-a', 0), SenseInfo('01068438-a', 0), SenseInfo('00811421-a', 0), SenseInfo('00445440-a', 0), SenseInfo('00427105-a', 0), SenseInfo('00358392-a', 0), SenseInfo('00033077-a', 0), SenseInfo('01247240-a', 50), SenseInfo('02511800-a', 4), SenseInfo('01256332-a', 3), SenseInfo('02532114-a', 1), SenseInfo('02132607-a', 1), SenseInfo('01403632-a', 1), SenseInfo('00977372-a', 1), SenseInfo('02527402-a', 0), SenseInfo('02397732-a', 0), SenseInfo('02227485-a', 0), SenseInfo('01816525-a', 0), SenseInfo('01804034-a', 0), SenseInfo('01641791-a', 0), SenseInfo('01468420-a', 0), SenseInfo('01124441-a', 0), SenseInfo('01068438-a', 0), SenseInfo('00811421-a', 0), SenseInfo('00445440-a', 0), SenseInfo('00427105-a', 0), SenseInfo('00358392-a', 0), SenseInfo('00033077-a', 0), SenseInfo('01247240-a', 50), SenseInfo('02511800-a', 4), SenseInfo('01256332-a', 3), SenseInfo('02532114-a', 1), SenseInfo('02132607-a', 1), SenseInfo('01403632-a', 1), SenseInfo('00977372-a', 1), SenseInfo('02527402-a', 0), SenseInfo('02397732-a', 0), SenseInfo('02227485-a', 0), SenseInfo('01816525-a', 0), SenseInfo('01804034-a', 0), SenseInfo('01641791-a', 0), SenseInfo('01468420-a', 0), SenseInfo('01124441-a', 0), SenseInfo('01068438-a', 0), SenseInfo('00811421-a', 0), SenseInfo('00445440-a', 0), SenseInfo('00427105-a', 0), SenseInfo('00358392-a', 0), SenseInfo('00033077-a', 0), SenseInfo('01247240-a', 50), SenseInfo('02511800-a', 4), SenseInfo('01256332-a', 3), SenseInfo('02532114-a', 1), SenseInfo('02132607-a', 1), SenseInfo('01403632-a', 1), SenseInfo('00977372-a', 1), SenseInfo('02527402-a', 0), SenseInfo('02397732-a', 0), SenseInfo('02227485-a', 0), SenseInfo('01816525-a', 0), SenseInfo('01804034-a', 0), SenseInfo('01641791-a', 0), SenseInfo('01468420-a', 0), SenseInfo('01124441-a', 0), SenseInfo('01068438-a', 0), SenseInfo('00811421-a', 0), SenseInfo('00445440-a', 0), SenseInfo('00427105-a', 0), SenseInfo('00358392-a', 0), SenseInfo('00033077-a', 0) ],
"_wraith_n_1_rel" : [ SenseInfo('05898171-n', 0) ],
"_marvel_v_1_rel" : [ SenseInfo('00925490-v', 4), SenseInfo('00925735-v', 1), SenseInfo('00925490-v', 4), SenseInfo('00925735-v', 1) ],
"_skyline_n_1_rel" : [ SenseInfo('08651735-n', 0), SenseInfo('08585657-n', 0) ],
"_ormelid_n_1_rel" : [  ],
"_alkali_n_1_rel" : [ SenseInfo('14618253-n', 3), SenseInfo('14712036-n', 0) ],
"_purge_v_1_rel" : [ SenseInfo('02565090-v', 1), SenseInfo('00905283-v', 0), SenseInfo('00475819-v', 0), SenseInfo('00475647-v', 0), SenseInfo('00455529-v', 0), SenseInfo('00076400-v', 0), SenseInfo('00073813-v', 0) ],
"_azalea_n_1_rel" : [ SenseInfo('12245319-n', 0), SenseInfo('12245319-n', 0) ],
"_furl_n_1_rel" : [  ],
"_in+effect_a_1_rel" : [ SenseInfo('00832784-a', 4), SenseInfo('00832784-a', 4) ],
"_on+button_n_1_rel" : [  ],
"_ration_v_out_rel" : [ SenseInfo('02234988-v', 0), SenseInfo('02234803-v', 0) ],
"_albino_n_1_rel" : [ SenseInfo('09781650-n', 0) ],
"_sponge_v_off-of_rel" : [ SenseInfo('01392663-v', 2), SenseInfo('02270404-v', 0), SenseInfo('01549057-v', 0), SenseInfo('01393611-v', 0), SenseInfo('01383646-v', 0) ],
"_steady_v_1_rel" : [ SenseInfo('00416571-v', 2), SenseInfo('01219993-v', 1) ],
"_pda_n_1_rel" : [ SenseInfo('03918737-n', 0) ],
"_manual_a_1_rel" : [ SenseInfo('02759190-a', 0), SenseInfo('00182843-a', 0), SenseInfo('02557023-a', 0), SenseInfo('02759190-a', 0), SenseInfo('00182843-a', 0), SenseInfo('02557023-a', 0) ],
"_globe_n_1_rel" : [ SenseInfo('09270894-n', 5), SenseInfo('13899404-n', 0), SenseInfo('03440512-n', 0) ],
"_swish_v_cause_rel" : [ SenseInfo('02188198-v', 1) ],
"_predicable_a_1_rel" : [  ],
"_property_n_1_rel" : [ SenseInfo('13244109-n', 30), SenseInfo('04916342-n', 26), SenseInfo('08513718-n', 4), SenseInfo('05849040-n', 0), SenseInfo('04012260-n', 0) ],
"_tout_v_to_rel" : [ SenseInfo('00971460-v', 0), SenseInfo('00883226-v', 0) ],
"_specialist_n_1_rel" : [ SenseInfo('10631941-n', 19), SenseInfo('10632576-n', 1) ],
"_eat_v_of_rel" : [ SenseInfo('01168468-v', 61), SenseInfo('01166351-v', 13), SenseInfo('01179865-v', 4), SenseInfo('01766273-v', 0), SenseInfo('01157517-v', 0), SenseInfo('00274283-v', 0) ],
"_shield_v_from_rel" : [ SenseInfo('01130169-v', 5), SenseInfo('02148604-v', 0), SenseInfo('01130169-v', 5), SenseInfo('02148604-v', 0) ],
"_buddhist_n_1_rel" : [ SenseInfo('09683757-n', 1) ],
"_upset_n_1_rel" : [ SenseInfo('14403282-n', 1), SenseInfo('00554850-n', 1), SenseInfo('14052403-n', 0), SenseInfo('04515444-n', 0), SenseInfo('00348312-n', 0), SenseInfo('00068170-n', 0) ],
"_turn_v_over_rel" : [ SenseInfo('01907258-v', 187), SenseInfo('00146138-v', 21), SenseInfo('02626604-v', 12), SenseInfo('02089984-v', 8), SenseInfo('00138508-v', 7), SenseInfo('01909812-v', 5), SenseInfo('00125841-v', 5), SenseInfo('01436518-v', 2), SenseInfo('02096167-v', 1), SenseInfo('02089420-v', 1), SenseInfo('01952208-v', 1), SenseInfo('01741864-v', 1), SenseInfo('01584450-v', 1), SenseInfo('00282523-v', 1), SenseInfo('00091124-v', 1), SenseInfo('02626934-v', 0), SenseInfo('02562425-v', 0), SenseInfo('02211948-v', 0), SenseInfo('02090435-v', 0), SenseInfo('01951937-v', 0), SenseInfo('01280014-v', 0), SenseInfo('01225215-v', 0), SenseInfo('01151889-v', 0), SenseInfo('00794640-v', 0), SenseInfo('00458471-v', 0), SenseInfo('00248387-v', 0), SenseInfo('01907258-v', 187), SenseInfo('00146138-v', 21), SenseInfo('02626604-v', 12), SenseInfo('02089984-v', 8), SenseInfo('00138508-v', 7), SenseInfo('01909812-v', 5), SenseInfo('00125841-v', 5), SenseInfo('01436518-v', 2), SenseInfo('02096167-v', 1), SenseInfo('02089420-v', 1), SenseInfo('01952208-v', 1), SenseInfo('01741864-v', 1), SenseInfo('01584450-v', 1), SenseInfo('00282523-v', 1), SenseInfo('00091124-v', 1), SenseInfo('02626934-v', 0), SenseInfo('02562425-v', 0), SenseInfo('02211948-v', 0), SenseInfo('02090435-v', 0), SenseInfo('01951937-v', 0), SenseInfo('01280014-v', 0), SenseInfo('01225215-v', 0), SenseInfo('01151889-v', 0), SenseInfo('00794640-v', 0), SenseInfo('00458471-v', 0), SenseInfo('00248387-v', 0), SenseInfo('01907258-v', 187), SenseInfo('00146138-v', 21), SenseInfo('02626604-v', 12), SenseInfo('02089984-v', 8), SenseInfo('00138508-v', 7), SenseInfo('01909812-v', 5), SenseInfo('00125841-v', 5), SenseInfo('01436518-v', 2), SenseInfo('02096167-v', 1), SenseInfo('02089420-v', 1), SenseInfo('01952208-v', 1), SenseInfo('01741864-v', 1), SenseInfo('01584450-v', 1), SenseInfo('00282523-v', 1), SenseInfo('00091124-v', 1), SenseInfo('02626934-v', 0), SenseInfo('02562425-v', 0), SenseInfo('02211948-v', 0), SenseInfo('02090435-v', 0), SenseInfo('01951937-v', 0), SenseInfo('01280014-v', 0), SenseInfo('01225215-v', 0), SenseInfo('01151889-v', 0), SenseInfo('00794640-v', 0), SenseInfo('00458471-v', 0), SenseInfo('00248387-v', 0) ],
"_isolate_v_out_rel" : [ SenseInfo('00494269-v', 12), SenseInfo('00496770-v', 3), SenseInfo('00495808-v', 2), SenseInfo('00655378-v', 0) ],
"_several_a_1_rel" : [ SenseInfo('02268268-a', 112), SenseInfo('00494409-a', 16), SenseInfo('02068174-a', 10), SenseInfo('02268268-a', 112), SenseInfo('00494409-a', 16), SenseInfo('02068174-a', 10) ],
"_dedication_n_of_rel" : [ SenseInfo('04877421-n', 5), SenseInfo('07452348-n', 0), SenseInfo('06684383-n', 0), SenseInfo('06406317-n', 0), SenseInfo('01206153-n', 0) ],
"_pianoforte_n_1_rel" : [ SenseInfo('03928116-n', 0) ],
"_unfrost_v_1_rel" : [  ],
"_add_v_on_rel" : [ SenseInfo('00182406-v', 116), SenseInfo('01027174-v', 68), SenseInfo('02324478-v', 15), SenseInfo('00640828-v', 3), SenseInfo('00949288-v', 1), SenseInfo('02745172-v', 0) ],
"_graduate_n_1_rel" : [ SenseInfo('09786338-n', 6), SenseInfo('03451473-n', 0) ],
"_by+gum_a_1_rel" : [  ],
"_testis_n_1_rel" : [ SenseInfo('05524615-n', 0) ],
"_spam_n_1_rel" : [ SenseInfo('07573347-n', 0), SenseInfo('06280347-n', 0) ],
"_brine_n_1_rel" : [ SenseInfo('15008847-n', 0), SenseInfo('07937203-n', 0) ],
"_palm+pilot_n_1_rel" : [  ],
"_two+thirds+majority_n_of_rel" : [  ],
"_retail_v_1_rel" : [ SenseInfo('02728570-v', 1), SenseInfo('02247028-v', 0) ],
"_remit_v_1_rel" : [ SenseInfo('02255081-v', 1), SenseInfo('02642814-v', 0), SenseInfo('01018800-v', 0), SenseInfo('00949974-v', 0), SenseInfo('00903947-v', 0), SenseInfo('00421125-v', 0), SenseInfo('00268314-v', 0) ],
"_when-issued_a_1_rel" : [  ],
"_hard-working_a_1_rel" : [ SenseInfo('00754682-a', 1) ],
"_tenure_n_1_rel" : [ SenseInfo('15291498-n', 2), SenseInfo('13242719-n', 0) ],
"_ex_n_1_rel" : [ SenseInfo('10194231-n', 0), SenseInfo('10020533-n', 0), SenseInfo('06833663-n', 0) ],
"_beware_v_1_rel" : [ SenseInfo('00724664-v', 2), SenseInfo('00724664-v', 2), SenseInfo('00724664-v', 2) ],
"_how+come_x_rel" : [  ],
"_brick_v_up_rel" : [  ],
"_preposition_n_1_rel" : [ SenseInfo('06325145-n', 2), SenseInfo('06483992-n', 0), SenseInfo('06325145-n', 2), SenseInfo('06483992-n', 0), SenseInfo('06325145-n', 2), SenseInfo('06483992-n', 0) ],
"_evaporate_v_1_rel" : [ SenseInfo('00366858-v', 2), SenseInfo('00575970-v', 0), SenseInfo('00575720-v', 0), SenseInfo('00223928-v', 0) ],
"_look_v_upon_rel" : [ SenseInfo('02130524-v', 274), SenseInfo('02133435-v', 126), SenseInfo('00033599-v', 25), SenseInfo('02153709-v', 8), SenseInfo('02693319-v', 1), SenseInfo('02549581-v', 1), SenseInfo('00929362-v', 1), SenseInfo('00720063-v', 1), SenseInfo('02658447-v', 0), SenseInfo('00712708-v', 0) ],
"_fairness_n_1_rel" : [ SenseInfo('04839154-n', 1), SenseInfo('06203030-n', 0), SenseInfo('04977247-n', 0), SenseInfo('04685396-n', 0) ],
"_clamber_v_1_rel" : [ SenseInfo('01921772-v', 7), SenseInfo('01921772-v', 7) ],
"_lattice_n_1_rel" : [ SenseInfo('05729875-n', 0), SenseInfo('04582454-n', 0), SenseInfo('03646916-n', 0) ],
"_tramp_n_1_rel" : [ SenseInfo('10723300-n', 1), SenseInfo('10683675-n', 0), SenseInfo('10176111-n', 0), SenseInfo('07398560-n', 0), SenseInfo('04469684-n', 0), SenseInfo('00288970-n', 0) ],
"_offline_v_1_rel" : [  ],
"_ratio_n_of_rel" : [ SenseInfo('13819207-n', 21), SenseInfo('13815449-n', 0) ],
"_seek_v_after_rel" : [ SenseInfo('02240481-v', 44), SenseInfo('01315613-v', 41), SenseInfo('02530167-v', 32), SenseInfo('01839170-v', 0), SenseInfo('01069989-v', 0) ],
"_naive_a_1_rel" : [ SenseInfo('02271544-a', 6), SenseInfo('01912858-a', 0), SenseInfo('01637371-a', 0), SenseInfo('01309657-a', 0), SenseInfo('00937341-a', 0) ],
"_reconcile_v_to_rel" : [ SenseInfo('00482893-v', 2), SenseInfo('00482473-v', 2), SenseInfo('00764902-v', 1), SenseInfo('00732394-v', 1) ],
"_outdoors_n_1_rel" : [ SenseInfo('08613733-n', 0) ],
"_master_v_1_rel" : [ SenseInfo('00597634-v', 4), SenseInfo('01108627-v', 2), SenseInfo('02539334-v', 1), SenseInfo('00597385-v', 0) ],
"_connect_v_1_rel" : [ SenseInfo('01354673-v', 8), SenseInfo('00713167-v', 4), SenseInfo('02622234-v', 3), SenseInfo('01069391-v', 3), SenseInfo('01237761-v', 1), SenseInfo('01069190-v', 1), SenseInfo('02747403-v', 0), SenseInfo('02389592-v', 0), SenseInfo('02389346-v', 0), SenseInfo('01421122-v', 0), SenseInfo('01407568-v', 0) ],
"_oh+yes_a_1_rel" : [  ],
"_arab_n_1_rel" : [ SenseInfo('09729530-n', 0), SenseInfo('02379908-n', 0) ],
"_sa_n_1_rel" : [ SenseInfo('08212146-n', 0), SenseInfo('08212146-n', 0), SenseInfo('08212146-n', 0) ],
"_assign_v_to_rel" : [ SenseInfo('02391803-v', 15), SenseInfo('02228698-v', 15), SenseInfo('00726300-v', 7), SenseInfo('00677683-v', 7), SenseInfo('01160370-v', 1), SenseInfo('02276746-v', 0), SenseInfo('02228531-v', 0), SenseInfo('00740053-v', 0) ],
"_else_x_rel" : [  ],
"_terribly_x_deg_rel" : [ SenseInfo('00054950-r', 8), SenseInfo('00055101-r', 0) ],
"_sinister_a_1_rel" : [ SenseInfo('00194357-a', 3), SenseInfo('01131935-a', 1), SenseInfo('00743742-a', 0) ],
"_afflict_v_with_rel" : [ SenseInfo('01797730-v', 0), SenseInfo('00259927-v', 0) ],
"_contradiction_n_1_rel" : [ SenseInfo('13857676-n', 7), SenseInfo('07206887-n', 1), SenseInfo('07206596-n', 0) ],
"_caviar_n_1_rel" : [ SenseInfo('07799579-n', 0) ],
"_fireman_n_1_rel" : [ SenseInfo('00432587-n', 1), SenseInfo('10659042-n', 0), SenseInfo('10518194-n', 0), SenseInfo('10091651-n', 0) ],
"_third+place_n_1_rel" : [  ],
"_innovation_n_1_rel" : [ SenseInfo('03582658-n', 3), SenseInfo('05633385-n', 1), SenseInfo('00240184-n', 0) ],
"_sheeting_n_1_rel" : [ SenseInfo('04189282-n', 0) ],
"_bounce_v_back_rel" : [ SenseInfo('01892104-v', 13), SenseInfo('01404389-v', 5), SenseInfo('01892608-v', 4), SenseInfo('02254923-v', 1), SenseInfo('01964788-v', 1), SenseInfo('02254767-v', 0), SenseInfo('01469080-v', 0), SenseInfo('01892104-v', 13), SenseInfo('01404389-v', 5), SenseInfo('01892608-v', 4), SenseInfo('02254923-v', 1), SenseInfo('01964788-v', 1), SenseInfo('02254767-v', 0), SenseInfo('01469080-v', 0) ],
"_clie_n_1_rel" : [  ],
"_well_v_up_rel" : [ SenseInfo('01991204-v', 3) ],
"_georgian_n_1_rel" : [ SenseInfo('09742443-n', 1), SenseInfo('09729156-n', 0), SenseInfo('06978766-n', 0) ],
"_dough_n_1_rel" : [ SenseInfo('07860988-n', 3), SenseInfo('13385216-n', 1) ],
"_half_a_1_rel" : [ SenseInfo('00517554-a', 22), SenseInfo('00524496-a', 11), SenseInfo('00518035-a', 0) ],
"_enshrine_v_in_rel" : [ SenseInfo('01482958-v', 1), SenseInfo('01776383-v', 0), SenseInfo('01482958-v', 1), SenseInfo('01776383-v', 0) ],
"_seat_v_cause_rel" : [ SenseInfo('01543998-v', 9), SenseInfo('02701962-v', 2), SenseInfo('02384275-v', 2), SenseInfo('02334302-v', 0), SenseInfo('02333979-v', 0), SenseInfo('01616901-v', 0), SenseInfo('01544285-v', 0) ],
"_troublemaker_n_1_rel" : [ SenseInfo('10731244-n', 0) ],
"_incorrect_a_1_rel" : [ SenseInfo('00632438-a', 1), SenseInfo('01881478-a', 0), SenseInfo('01146371-a', 0), SenseInfo('00023854-a', 0), SenseInfo('00632438-a', 1), SenseInfo('01881478-a', 0), SenseInfo('01146371-a', 0), SenseInfo('00023854-a', 0) ],
"_headdress_n_1_rel" : [ SenseInfo('03502509-n', 0) ],
"_oh+where_x_rel" : [  ],
"_lyric_a_1_rel" : [ SenseInfo('00856011-a', 3), SenseInfo('01468994-a', 1), SenseInfo('02856460-a', 0), SenseInfo('02856286-a', 0) ],
"_surge_v_1_rel" : [ SenseInfo('02041206-v', 8), SenseInfo('01943718-v', 1), SenseInfo('01903756-v', 1), SenseInfo('01885239-v', 1), SenseInfo('00168217-v', 0) ],
"_kluge_n_1_rel" : [  ],
"_diaper_n_1_rel" : [ SenseInfo('03188531-n', 1), SenseInfo('03188725-n', 0) ],
"_uphill_n_1_rel" : [ SenseInfo('09466678-n', 0) ],
"_turn_v_2-upside+down_rel" : [ SenseInfo('01907258-v', 187), SenseInfo('00146138-v', 21), SenseInfo('02626604-v', 12), SenseInfo('02089984-v', 8), SenseInfo('00138508-v', 7), SenseInfo('01909812-v', 5), SenseInfo('00125841-v', 5), SenseInfo('01436518-v', 2), SenseInfo('02096167-v', 1), SenseInfo('02089420-v', 1), SenseInfo('01952208-v', 1), SenseInfo('01741864-v', 1), SenseInfo('01584450-v', 1), SenseInfo('00282523-v', 1), SenseInfo('00091124-v', 1), SenseInfo('02626934-v', 0), SenseInfo('02562425-v', 0), SenseInfo('02211948-v', 0), SenseInfo('02090435-v', 0), SenseInfo('01951937-v', 0), SenseInfo('01280014-v', 0), SenseInfo('01225215-v', 0), SenseInfo('01151889-v', 0), SenseInfo('00794640-v', 0), SenseInfo('00458471-v', 0), SenseInfo('00248387-v', 0) ],
"_marrowbone_n_1_rel" : [ SenseInfo('07872915-n', 1) ],
"_hopper_n_1_rel" : [ SenseInfo('03535284-n', 1), SenseInfo('10185327-n', 0), SenseInfo('03535429-n', 0), SenseInfo('02226429-n', 0), SenseInfo('00129089-n', 0) ],
"_behold_v_1_rel" : [ SenseInfo('02130160-v', 7) ],
"_come_v_together_rel" : [ SenseInfo('01849221-v', 276), SenseInfo('02005948-v', 235), SenseInfo('00341917-v', 147), SenseInfo('00542120-v', 41), SenseInfo('02625339-v', 40), SenseInfo('00342812-v', 11), SenseInfo('02743921-v', 9), SenseInfo('02743214-v', 7), SenseInfo('02686805-v', 6), SenseInfo('02743565-v', 3), SenseInfo('01839690-v', 3), SenseInfo('02729963-v', 2), SenseInfo('00344886-v', 2), SenseInfo('02645007-v', 1), SenseInfo('02627363-v', 1), SenseInfo('02006709-v', 1), SenseInfo('00723349-v', 1), SenseInfo('02737187-v', 0), SenseInfo('02617567-v', 0), SenseInfo('02197360-v', 0), SenseInfo('00659984-v', 0) ],
"_blast_a_1_rel" : [ SenseInfo('00128867-n', 2), SenseInfo('07376257-n', 1), SenseInfo('11465017-n', 0), SenseInfo('07408171-n', 0), SenseInfo('07287288-n', 0), SenseInfo('06711159-n', 0) ],
"_fee_n_1_rel" : [ SenseInfo('13320168-n', 11), SenseInfo('13288529-n', 0) ],
"_subtraction_n_of_rel" : [ SenseInfo('00871862-n', 0), SenseInfo('00360757-n', 0) ],
"_appeal_v_to_rel" : [ SenseInfo('02497586-v', 4), SenseInfo('00755447-v', 2), SenseInfo('01807882-v', 1), SenseInfo('02497824-v', 0), SenseInfo('01024864-v', 0), SenseInfo('02497586-v', 4), SenseInfo('00755447-v', 2), SenseInfo('01807882-v', 1), SenseInfo('02497824-v', 0), SenseInfo('01024864-v', 0), SenseInfo('02497586-v', 4), SenseInfo('00755447-v', 2), SenseInfo('01807882-v', 1), SenseInfo('02497824-v', 0), SenseInfo('01024864-v', 0) ],
"_capability_n_to_rel" : [ SenseInfo('05202497-n', 8), SenseInfo('14530836-n', 0), SenseInfo('05623181-n', 0), SenseInfo('05202497-n', 8), SenseInfo('14530836-n', 0), SenseInfo('05623181-n', 0), SenseInfo('05202497-n', 8), SenseInfo('14530836-n', 0), SenseInfo('05623181-n', 0) ],
"_cuddly_a_1_rel" : [ SenseInfo('01460266-a', 0) ],
"_overwhelming_a_1_rel" : [ SenseInfo('01989446-a', 8), SenseInfo('01511152-a', 0), SenseInfo('01989446-a', 8), SenseInfo('01511152-a', 0) ],
"_waterpower_n_1_rel" : [ SenseInfo('11524213-n', 0) ],
"_spur_n_1_rel" : [ SenseInfo('07252378-n', 3), SenseInfo('13912839-n', 1), SenseInfo('13089135-n', 1), SenseInfo('04290259-n', 1), SenseInfo('02891430-n', 1) ],
"_overwhelm_v_1_rel" : [ SenseInfo('01809321-v', 1), SenseInfo('00751131-v', 1), SenseInfo('01339294-v', 0), SenseInfo('01110517-v', 0), SenseInfo('01809321-v', 1), SenseInfo('00751131-v', 1), SenseInfo('01339294-v', 0), SenseInfo('01110517-v', 0), SenseInfo('01809321-v', 1), SenseInfo('00751131-v', 1), SenseInfo('01339294-v', 0), SenseInfo('01110517-v', 0), SenseInfo('01809321-v', 1), SenseInfo('00751131-v', 1), SenseInfo('01339294-v', 0), SenseInfo('01110517-v', 0), SenseInfo('01809321-v', 1), SenseInfo('00751131-v', 1), SenseInfo('01339294-v', 0), SenseInfo('01110517-v', 0) ],
"_expose_v_to_rel" : [ SenseInfo('02112029-v', 14), SenseInfo('00933821-v', 7), SenseInfo('02140033-v', 4), SenseInfo('01339505-v', 3), SenseInfo('02137710-v', 2), SenseInfo('01036319-v', 1), SenseInfo('02113430-v', 0), SenseInfo('00853195-v', 0), SenseInfo('00614444-v', 0) ],
"_regal_a_1_rel" : [ SenseInfo('01591394-a', 1), SenseInfo('01591394-a', 1) ],
"_level_n_1_rel" : [ SenseInfo('05093890-n', 69), SenseInfo('14428160-n', 22), SenseInfo('13939892-n', 15), SenseInfo('05131902-n', 5), SenseInfo('03658858-n', 1), SenseInfo('03536348-n', 1), SenseInfo('06246896-n', 0), SenseInfo('03365991-n', 0), SenseInfo('05093890-n', 69), SenseInfo('14428160-n', 22), SenseInfo('13939892-n', 15), SenseInfo('05131902-n', 5), SenseInfo('03658858-n', 1), SenseInfo('03536348-n', 1), SenseInfo('06246896-n', 0), SenseInfo('03365991-n', 0) ],
"_overload_n_1_rel" : [ SenseInfo('03865171-n', 1), SenseInfo('03864994-n', 0) ],
"_butcher_n_1_rel" : [ SenseInfo('09884391-n', 0), SenseInfo('09884305-n', 0), SenseInfo('09884133-n', 0), SenseInfo('09879744-n', 0) ],
"_reality_n_1_rel" : [ SenseInfo('05809878-n', 21), SenseInfo('13955461-n', 14), SenseInfo('13956097-n', 4), SenseInfo('04762355-n', 0) ],
"_cant_n_1_rel" : [ SenseInfo('06608277-n', 1), SenseInfo('09213828-n', 0), SenseInfo('07157273-n', 0), SenseInfo('07136098-n', 0), SenseInfo('02833576-n', 0) ],
"_paramount_a_1_rel" : [ SenseInfo('00792202-a', 3) ],
"_windbreaker_n_1_rel" : [ SenseInfo('03891051-n', 0) ],
"_twist_v_into_rel" : [ SenseInfo('01868370-v', 13), SenseInfo('01280014-v', 5), SenseInfo('01222645-v', 2), SenseInfo('01223182-v', 1), SenseInfo('00143914-v', 1), SenseInfo('02738701-v', 0), SenseInfo('01895519-v', 0), SenseInfo('01349493-v', 0), SenseInfo('00932798-v', 0), SenseInfo('00091124-v', 0) ],
"_trigger_n_1_rel" : [ SenseInfo('03470629-n', 5), SenseInfo('04483073-n', 0), SenseInfo('00156390-n', 0) ],
"_keep_v_unspec_rel" : [ SenseInfo('02681795-v', 206), SenseInfo('02684924-v', 39), SenseInfo('02202384-v', 32), SenseInfo('02450505-v', 22), SenseInfo('02578872-v', 10), SenseInfo('00732552-v', 9), SenseInfo('02202928-v', 8), SenseInfo('01065877-v', 4), SenseInfo('02651853-v', 3), SenseInfo('02410175-v', 3), SenseInfo('01184625-v', 3), SenseInfo('02734800-v', 2), SenseInfo('02578510-v', 2), SenseInfo('02422663-v', 2), SenseInfo('02733122-v', 1), SenseInfo('02652016-v', 0), SenseInfo('02283716-v', 0), SenseInfo('02204094-v', 0), SenseInfo('02203844-v', 0), SenseInfo('02203168-v', 0), SenseInfo('01302019-v', 0), SenseInfo('00212414-v', 0) ],
"_sell_v_1_rel" : [ SenseInfo('02242464-v', 73), SenseInfo('02727883-v', 12), SenseInfo('00767635-v', 5), SenseInfo('02244956-v', 4), SenseInfo('02235666-v', 2), SenseInfo('02748355-v', 0), SenseInfo('02748206-v', 0), SenseInfo('02537407-v', 0), SenseInfo('02242464-v', 73), SenseInfo('02727883-v', 12), SenseInfo('00767635-v', 5), SenseInfo('02244956-v', 4), SenseInfo('02235666-v', 2), SenseInfo('02748355-v', 0), SenseInfo('02748206-v', 0), SenseInfo('02537407-v', 0) ],
"_melodious_a_1_rel" : [ SenseInfo('01502195-a', 1), SenseInfo('01501113-a', 0) ],
"_fight_v_1_rel" : [ SenseInfo('01090335-v', 112), SenseInfo('01091427-v', 34), SenseInfo('02407338-v', 8), SenseInfo('02589576-v', 5), SenseInfo('01090335-v', 112), SenseInfo('01091427-v', 34), SenseInfo('02407338-v', 8), SenseInfo('02589576-v', 5) ],
"_plush_a_1_rel" : [ SenseInfo('02025274-a', 1), SenseInfo('02025274-a', 1), SenseInfo('02025274-a', 1) ],
"_branch_v_out_rel" : [ SenseInfo('00329244-v', 0), SenseInfo('00328802-v', 0) ],
"_grey_a_1_rel" : [ SenseInfo('00389310-a', 1), SenseInfo('01645678-a', 0), SenseInfo('01607120-a', 0), SenseInfo('01014685-a', 0), SenseInfo('00389310-a', 1), SenseInfo('01645678-a', 0), SenseInfo('01607120-a', 0), SenseInfo('01014685-a', 0), SenseInfo('00389310-a', 1), SenseInfo('01645678-a', 0), SenseInfo('01607120-a', 0), SenseInfo('01014685-a', 0), SenseInfo('00389310-a', 1), SenseInfo('01645678-a', 0), SenseInfo('01607120-a', 0), SenseInfo('01014685-a', 0) ],
"_application_n_of_rel" : [ SenseInfo('00949134-n', 17), SenseInfo('06512580-n', 8), SenseInfo('00712225-n', 4), SenseInfo('06570110-n', 0), SenseInfo('03691128-n', 0), SenseInfo('00633329-n', 0), SenseInfo('00036061-n', 0) ],
"_common_n_1_rel" : [ SenseInfo('08615374-n', 1), SenseInfo('08615374-n', 1) ],
"_cost_n_1_rel" : [ SenseInfo('13275847-n', 75), SenseInfo('05145118-n', 7), SenseInfo('05163807-n', 4) ],
"_plunder_v_1_rel" : [ SenseInfo('02345288-v', 1), SenseInfo('02345048-v', 0), SenseInfo('02344568-v', 0), SenseInfo('01565472-v', 0) ],
"_dregs_n_1_rel" : [ SenseInfo('09269972-n', 4), SenseInfo('09269972-n', 4) ],
"_at+worst_p_rel" : [ SenseInfo('00105908-r', 1) ],
"_midline_n_1_rel" : [ SenseInfo('13861686-n', 0) ],
"_cage_n_1_rel" : [ SenseInfo('02936714-n', 4), SenseInfo('13998966-n', 2), SenseInfo('10878530-n', 0), SenseInfo('02936921-n', 0), SenseInfo('02811059-n', 0) ],
"_Sen_n_abb_rel" : [ SenseInfo('13672555-n', 0), SenseInfo('13672555-n', 0) ],
"_understanding_a_1_rel" : [ SenseInfo('01745946-a', 1) ],
"_evangelist_n_1_rel" : [ SenseInfo('10067011-n', 1), SenseInfo('10067305-n', 0) ],
"_seventh_n_of_rel" : [ SenseInfo('13847498-n', 0), SenseInfo('13738043-n', 0), SenseInfo('06860049-n', 0), SenseInfo('13847498-n', 0), SenseInfo('13738043-n', 0), SenseInfo('06860049-n', 0), SenseInfo('13847498-n', 0), SenseInfo('13738043-n', 0), SenseInfo('06860049-n', 0) ],
"_dismay_v_1_rel" : [ SenseInfo('01814396-v', 0), SenseInfo('01782650-v', 0), SenseInfo('01814396-v', 0), SenseInfo('01782650-v', 0), SenseInfo('01814396-v', 0), SenseInfo('01782650-v', 0) ],
"_msl_n_1_rel" : [  ],
"_thump_n_1_rel" : [ SenseInfo('07396945-n', 0), SenseInfo('01175099-n', 0) ],
"_cancelable_a_1_rel" : [  ],
"_diminution_n_of_rel" : [ SenseInfo('13457378-n', 1), SenseInfo('07030549-n', 0), SenseInfo('00351638-n', 0) ],
"_close+by_p_rel" : [  ],
"_kestrel_n_1_rel" : [ SenseInfo('01612122-n', 0), SenseInfo('01611969-n', 0) ],
"_cancerous_a_1_rel" : [ SenseInfo('02594940-a', 0), SenseInfo('00227301-a', 0) ],
"_windward_n_1_rel" : [ SenseInfo('13829586-n', 0), SenseInfo('08610023-n', 0) ],
"_fellowship_n_1_rel" : [ SenseInfo('08227916-n', 7), SenseInfo('13929588-n', 1), SenseInfo('13266348-n', 0) ],
"_disaffiliation_n_1_rel" : [  ],
"_noble_n_1_rel" : [ SenseInfo('10271677-n', 0) ],
"_stockholder_n_1_rel" : [ SenseInfo('10657969-n', 18) ],
"_fifteen+to+the+dozen_a_1_rel" : [  ],
"_boy_n_1_rel" : [ SenseInfo('10285313-n', 144), SenseInfo('09870926-n', 42), SenseInfo('10624074-n', 16), SenseInfo('09637837-n', 1) ],
"_okay_a_1_rel" : [ SenseInfo('02081114-a', 2), SenseInfo('02081114-a', 2), SenseInfo('02081114-a', 2), SenseInfo('02081114-a', 2), SenseInfo('02081114-a', 2), SenseInfo('02081114-a', 2), SenseInfo('02081114-a', 2), SenseInfo('02081114-a', 2) ],
"_no_n_1_rel" : [ SenseInfo('07205104-n', 21), SenseInfo('14647722-n', 0), SenseInfo('07205104-n', 21), SenseInfo('14647722-n', 0) ],
"_suck_v_up_rel" : [ SenseInfo('01169704-v', 4), SenseInfo('01854888-v', 2), SenseInfo('02765692-v', 0), SenseInfo('02674340-v', 0), SenseInfo('02117170-v', 0), SenseInfo('01539063-v', 0), SenseInfo('01186428-v', 0), SenseInfo('01169704-v', 4), SenseInfo('01854888-v', 2), SenseInfo('02765692-v', 0), SenseInfo('02674340-v', 0), SenseInfo('02117170-v', 0), SenseInfo('01539063-v', 0), SenseInfo('01186428-v', 0), SenseInfo('01169704-v', 4), SenseInfo('01854888-v', 2), SenseInfo('02765692-v', 0), SenseInfo('02674340-v', 0), SenseInfo('02117170-v', 0), SenseInfo('01539063-v', 0), SenseInfo('01186428-v', 0) ],
"_alien_a_to_rel" : [ SenseInfo('01349927-a', 3), SenseInfo('01035007-a', 2), SenseInfo('01349927-a', 3), SenseInfo('01035007-a', 2), SenseInfo('01349927-a', 3), SenseInfo('01035007-a', 2), SenseInfo('01349927-a', 3), SenseInfo('01035007-a', 2) ],
"_erupt_v_1_rel" : [ SenseInfo('00345508-v', 6), SenseInfo('00307785-v', 2), SenseInfo('02760622-v', 1), SenseInfo('00548266-v', 1), SenseInfo('00307568-v', 1), SenseInfo('01785395-v', 0), SenseInfo('00422899-v', 0), SenseInfo('00309074-v', 0) ],
"_identification_n_of_rel" : [ SenseInfo('00152018-n', 10), SenseInfo('06885083-n', 3), SenseInfo('14577046-n', 0), SenseInfo('05762998-n', 0), SenseInfo('04618581-n', 0) ],
"_style_n_of_rel" : [ SenseInfo('04928903-n', 28), SenseInfo('07066659-n', 7), SenseInfo('05844105-n', 7), SenseInfo('05750163-n', 2), SenseInfo('11677259-n', 0), SenseInfo('06789215-n', 0), SenseInfo('04812871-n', 0), SenseInfo('04346511-n', 0), SenseInfo('01901213-n', 0), SenseInfo('04928903-n', 28), SenseInfo('07066659-n', 7), SenseInfo('05844105-n', 7), SenseInfo('05750163-n', 2), SenseInfo('11677259-n', 0), SenseInfo('06789215-n', 0), SenseInfo('04812871-n', 0), SenseInfo('04346511-n', 0), SenseInfo('01901213-n', 0), SenseInfo('04928903-n', 28), SenseInfo('07066659-n', 7), SenseInfo('05844105-n', 7), SenseInfo('05750163-n', 2), SenseInfo('11677259-n', 0), SenseInfo('06789215-n', 0), SenseInfo('04812871-n', 0), SenseInfo('04346511-n', 0), SenseInfo('01901213-n', 0) ],
"_constructive_a_1_rel" : [ SenseInfo('00584820-a', 5), SenseInfo('01818077-a', 0), SenseInfo('00584820-a', 5), SenseInfo('01818077-a', 0) ],
"_crunch_a_1_rel" : [ SenseInfo('07382414-n', 1), SenseInfo('13934070-n', 0), SenseInfo('00358089-n', 0) ],
"_rent_v_1_rel" : [ SenseInfo('02460199-v', 6), SenseInfo('02208903-v', 2), SenseInfo('02208537-v', 1), SenseInfo('02460619-v', 0), SenseInfo('02460199-v', 6), SenseInfo('02208903-v', 2), SenseInfo('02208537-v', 1), SenseInfo('02460619-v', 0) ],
"_waymark_n_1_rel" : [  ],
"_repute_n_1_rel" : [ SenseInfo('14438125-n', 1) ],
"_cosine_n_1_rel" : [ SenseInfo('13787723-n', 0) ],
"_niece_n_of_rel" : [ SenseInfo('10357613-n', 1) ],
"_beef_n_1_rel" : [ SenseInfo('02404186-n', 6), SenseInfo('07663592-n', 3), SenseInfo('07209965-n', 0) ],
"_forested_a_1_rel" : [ SenseInfo('02573859-a', 0) ],
"_aye_a_1_rel" : [  ],
"_disturb_v_1_rel" : [ SenseInfo('01770501-v', 8), SenseInfo('01419473-v', 4), SenseInfo('01207527-v', 2), SenseInfo('00520019-v', 2), SenseInfo('00259755-v', 1), SenseInfo('01770501-v', 8), SenseInfo('01419473-v', 4), SenseInfo('01207527-v', 2), SenseInfo('00520019-v', 2), SenseInfo('00259755-v', 1), SenseInfo('01770501-v', 8), SenseInfo('01419473-v', 4), SenseInfo('01207527-v', 2), SenseInfo('00520019-v', 2), SenseInfo('00259755-v', 1), SenseInfo('01770501-v', 8), SenseInfo('01419473-v', 4), SenseInfo('01207527-v', 2), SenseInfo('00520019-v', 2), SenseInfo('00259755-v', 1), SenseInfo('01770501-v', 8), SenseInfo('01419473-v', 4), SenseInfo('01207527-v', 2), SenseInfo('00520019-v', 2), SenseInfo('00259755-v', 1) ],
"_refurbish_v_1_rel" : [ SenseInfo('00163441-v', 1) ],
"_pistil_n_1_rel" : [ SenseInfo('11676500-n', 0) ],
"_mile_n_1_rel" : [ SenseInfo('13651218-n', 49), SenseInfo('13660337-n', 5), SenseInfo('13776342-n', 0), SenseInfo('13660868-n', 0), SenseInfo('13660619-n', 0), SenseInfo('13655414-n', 0), SenseInfo('13655262-n', 0), SenseInfo('07469325-n', 0), SenseInfo('13651218-n', 49), SenseInfo('13660337-n', 5), SenseInfo('13776342-n', 0), SenseInfo('13660868-n', 0), SenseInfo('13660619-n', 0), SenseInfo('13655414-n', 0), SenseInfo('13655262-n', 0), SenseInfo('07469325-n', 0), SenseInfo('13651218-n', 49), SenseInfo('13660337-n', 5), SenseInfo('13776342-n', 0), SenseInfo('13660868-n', 0), SenseInfo('13660619-n', 0), SenseInfo('13655414-n', 0), SenseInfo('13655262-n', 0), SenseInfo('07469325-n', 0) ],
"_mark_v_off_rel" : [ SenseInfo('01588493-v', 13), SenseInfo('00921738-v', 13), SenseInfo('00651991-v', 13), SenseInfo('00612612-v', 9), SenseInfo('00508032-v', 5), SenseInfo('02508245-v', 2), SenseInfo('02118476-v', 2), SenseInfo('01551195-v', 1), SenseInfo('01275762-v', 0), SenseInfo('01062395-v', 0), SenseInfo('01004062-v', 0), SenseInfo('00800750-v', 0), SenseInfo('00662182-v', 0), SenseInfo('00657728-v', 0), SenseInfo('00190023-v', 0) ],
"_louse_n_1_rel" : [ SenseInfo('02183857-n', 2), SenseInfo('10792028-n', 0), SenseInfo('02251775-n', 0), SenseInfo('02185481-n', 0) ],
"_title_v_1_rel" : [ SenseInfo('01029500-v', 3), SenseInfo('01028466-v', 0), SenseInfo('01029500-v', 3), SenseInfo('01028466-v', 0) ],
"_alternatively_a_1_rel" : [  ],
"_optimization_n_of_rel" : [ SenseInfo('00260051-n', 0) ],
"_intimate_a_1_rel" : [ SenseInfo('00453308-a', 5), SenseInfo('01076145-a', 1), SenseInfo('00453053-a', 1), SenseInfo('02132735-a', 0), SenseInfo('01348835-a', 0), SenseInfo('00936038-a', 0), SenseInfo('00453308-a', 5), SenseInfo('01076145-a', 1), SenseInfo('00453053-a', 1), SenseInfo('02132735-a', 0), SenseInfo('01348835-a', 0), SenseInfo('00936038-a', 0) ],
"_pox_n_1_rel" : [ SenseInfo('14133985-n', 0), SenseInfo('14124232-n', 0) ],
"_conjoin_v_1_rel" : [ SenseInfo('01291069-v', 1), SenseInfo('02488834-v', 0) ],
"_get_v_1_rel" : [ SenseInfo('02210855-v', 235), SenseInfo('00149583-v', 157), SenseInfo('00120796-v', 82), SenseInfo('00522751-v', 64), SenseInfo('02005948-v', 58), SenseInfo('01433294-v', 45), SenseInfo('02108026-v', 36), SenseInfo('01153947-v', 14), SenseInfo('02355596-v', 9), SenseInfo('00770437-v', 7), SenseInfo('01215421-v', 4), SenseInfo('00094460-v', 4), SenseInfo('00087736-v', 4), SenseInfo('01066036-v', 3), SenseInfo('00120316-v', 3), SenseInfo('01026975-v', 2), SenseInfo('00589904-v', 2), SenseInfo('01505958-v', 1), SenseInfo('01401115-v', 1), SenseInfo('00639849-v', 1), SenseInfo('02359340-v', 0), SenseInfo('02208265-v', 0), SenseInfo('02189398-v', 0), SenseInfo('02109645-v', 0), SenseInfo('02108654-v', 0), SenseInfo('02010864-v', 0), SenseInfo('02006573-v', 0), SenseInfo('01771194-v', 0), SenseInfo('01771039-v', 0), SenseInfo('01738107-v', 0), SenseInfo('01643297-v', 0), SenseInfo('01565211-v', 0), SenseInfo('00622384-v', 0), SenseInfo('00345761-v', 0), SenseInfo('00065639-v', 0), SenseInfo('00054628-v', 0), SenseInfo('02210855-v', 235), SenseInfo('00149583-v', 157), SenseInfo('00120796-v', 82), SenseInfo('00522751-v', 64), SenseInfo('02005948-v', 58), SenseInfo('01433294-v', 45), SenseInfo('02108026-v', 36), SenseInfo('01153947-v', 14), SenseInfo('02355596-v', 9), SenseInfo('00770437-v', 7), SenseInfo('01215421-v', 4), SenseInfo('00094460-v', 4), SenseInfo('00087736-v', 4), SenseInfo('01066036-v', 3), SenseInfo('00120316-v', 3), SenseInfo('01026975-v', 2), SenseInfo('00589904-v', 2), SenseInfo('01505958-v', 1), SenseInfo('01401115-v', 1), SenseInfo('00639849-v', 1), SenseInfo('02359340-v', 0), SenseInfo('02208265-v', 0), SenseInfo('02189398-v', 0), SenseInfo('02109645-v', 0), SenseInfo('02108654-v', 0), SenseInfo('02010864-v', 0), SenseInfo('02006573-v', 0), SenseInfo('01771194-v', 0), SenseInfo('01771039-v', 0), SenseInfo('01738107-v', 0), SenseInfo('01643297-v', 0), SenseInfo('01565211-v', 0), SenseInfo('00622384-v', 0), SenseInfo('00345761-v', 0), SenseInfo('00065639-v', 0), SenseInfo('00054628-v', 0) ],
"_sweats_n_1_rel" : [ SenseInfo('04370774-n', 0), SenseInfo('04370774-n', 0) ],
"_spacewalk_n_1_rel" : [  ],
"_football_n_1_rel" : [ SenseInfo('00468480-n', 9), SenseInfo('03378765-n', 2) ],
"_self-sufficient_a_1_rel" : [ SenseInfo('00729439-a', 2) ],
"_fiesta_n_1_rel" : [ SenseInfo('07449862-n', 0) ],
"_electronic_a_1_rel" : [ SenseInfo('02718497-a', 4), SenseInfo('02718719-a', 0), SenseInfo('02718497-a', 4), SenseInfo('02718719-a', 0) ],
"_sheathe_v_1_rel" : [ SenseInfo('01581635-v', 0), SenseInfo('01581362-v', 0), SenseInfo('01578714-v', 0) ],
"_clinch_v_1_rel" : [ SenseInfo('01344903-v', 3), SenseInfo('01573143-v', 0), SenseInfo('01572978-v', 0), SenseInfo('01424867-v', 0), SenseInfo('01344748-v', 0), SenseInfo('00763713-v', 0) ],
"_wait_a_1_rel" : [ SenseInfo('15272029-n', 2), SenseInfo('01063939-n', 2) ],
"_okay_a_for_rel" : [ SenseInfo('02081114-a', 2), SenseInfo('02081114-a', 2), SenseInfo('02081114-a', 2), SenseInfo('02081114-a', 2), SenseInfo('02081114-a', 2) ],
"_expand_v_on_rel" : [ SenseInfo('02077148-v', 7), SenseInfo('00257269-v', 6), SenseInfo('00541163-v', 4), SenseInfo('00310386-v', 4), SenseInfo('00264386-v', 3), SenseInfo('00955601-v', 0), SenseInfo('00540946-v', 0) ],
"_pubescence_n_1_rel" : [ SenseInfo('15148295-n', 0) ],
"_go_v_out_rel" : [ SenseInfo('01835496-v', 343), SenseInfo('02372605-v', 95), SenseInfo('01848718-v', 49), SenseInfo('00149583-v', 29), SenseInfo('02653862-v', 14), SenseInfo('02721284-v', 10), SenseInfo('02685951-v', 10), SenseInfo('00341560-v', 10), SenseInfo('00359916-v', 9), SenseInfo('02618001-v', 7), SenseInfo('02176268-v', 3), SenseInfo('01525666-v', 3), SenseInfo('01192773-v', 3), SenseInfo('00539110-v', 3), SenseInfo('02618149-v', 2), SenseInfo('02617798-v', 2), SenseInfo('00358431-v', 2), SenseInfo('02737876-v', 1), SenseInfo('02729819-v', 1), SenseInfo('01864230-v', 1), SenseInfo('01076615-v', 1), SenseInfo('02700772-v', 0), SenseInfo('02700666-v', 0), SenseInfo('02700455-v', 0), SenseInfo('02686471-v', 0), SenseInfo('02659763-v', 0), SenseInfo('01318849-v', 0), SenseInfo('01192992-v', 0), SenseInfo('00676267-v', 0), SenseInfo('00434374-v', 0), SenseInfo('01835496-v', 343), SenseInfo('02372605-v', 95), SenseInfo('01848718-v', 49), SenseInfo('00149583-v', 29), SenseInfo('02653862-v', 14), SenseInfo('02721284-v', 10), SenseInfo('02685951-v', 10), SenseInfo('00341560-v', 10), SenseInfo('00359916-v', 9), SenseInfo('02618001-v', 7), SenseInfo('02176268-v', 3), SenseInfo('01525666-v', 3), SenseInfo('01192773-v', 3), SenseInfo('00539110-v', 3), SenseInfo('02618149-v', 2), SenseInfo('02617798-v', 2), SenseInfo('00358431-v', 2), SenseInfo('02737876-v', 1), SenseInfo('02729819-v', 1), SenseInfo('01864230-v', 1), SenseInfo('01076615-v', 1), SenseInfo('02700772-v', 0), SenseInfo('02700666-v', 0), SenseInfo('02700455-v', 0), SenseInfo('02686471-v', 0), SenseInfo('02659763-v', 0), SenseInfo('01318849-v', 0), SenseInfo('01192992-v', 0), SenseInfo('00676267-v', 0), SenseInfo('00434374-v', 0) ],
"_rehearsal_n_of_rel" : [ SenseInfo('00897026-n', 6), SenseInfo('00896832-n', 0) ],
"_officer_n_1_rel" : [ SenseInfo('10317007-n', 86), SenseInfo('10371450-n', 23), SenseInfo('10448983-n', 8), SenseInfo('10371741-n', 1), SenseInfo('10317007-n', 86), SenseInfo('10371450-n', 23), SenseInfo('10448983-n', 8), SenseInfo('10371741-n', 1) ],
"_so_a_true_rel" : [ SenseInfo('06868844-n', 0), SenseInfo('06868844-n', 0) ],
"_banister_n_1_rel" : [ SenseInfo('02788148-n', 2) ],
"_fallen_n_1_rel" : [ SenseInfo('02493137-a', 1), SenseInfo('00736196-a', 0), SenseInfo('00362173-a', 0), SenseInfo('00097577-a', 0) ],
"_irregular_a_1_rel" : [ SenseInfo('01960656-a', 4), SenseInfo('00594146-a', 1), SenseInfo('01971046-a', 0), SenseInfo('01962107-a', 0), SenseInfo('01753249-a', 0), SenseInfo('01596809-a', 0), SenseInfo('01089775-a', 0), SenseInfo('00912094-a', 0), SenseInfo('00607202-a', 0), SenseInfo('01960656-a', 4), SenseInfo('00594146-a', 1), SenseInfo('01971046-a', 0), SenseInfo('01962107-a', 0), SenseInfo('01753249-a', 0), SenseInfo('01596809-a', 0), SenseInfo('01089775-a', 0), SenseInfo('00912094-a', 0), SenseInfo('00607202-a', 0) ],
"_blow_v_up_rel" : [ SenseInfo('00007012-v', 6), SenseInfo('02769241-v', 5), SenseInfo('00034948-v', 3), SenseInfo('01902783-v', 2), SenseInfo('02135877-v', 1), SenseInfo('00477247-v', 1), SenseInfo('02527651-v', 0), SenseInfo('02268351-v', 0), SenseInfo('02266148-v', 0), SenseInfo('02178340-v', 0), SenseInfo('02135727-v', 0), SenseInfo('02117170-v', 0), SenseInfo('02101046-v', 0), SenseInfo('02100632-v', 0), SenseInfo('02068745-v', 0), SenseInfo('01849054-v', 0), SenseInfo('01545208-v', 0), SenseInfo('00934965-v', 0), SenseInfo('00883226-v', 0), SenseInfo('00779804-v', 0), SenseInfo('00435294-v', 0), SenseInfo('00310155-v', 0), SenseInfo('00007012-v', 6), SenseInfo('02769241-v', 5), SenseInfo('00034948-v', 3), SenseInfo('01902783-v', 2), SenseInfo('02135877-v', 1), SenseInfo('00477247-v', 1), SenseInfo('02527651-v', 0), SenseInfo('02268351-v', 0), SenseInfo('02266148-v', 0), SenseInfo('02178340-v', 0), SenseInfo('02135727-v', 0), SenseInfo('02117170-v', 0), SenseInfo('02101046-v', 0), SenseInfo('02100632-v', 0), SenseInfo('02068745-v', 0), SenseInfo('01849054-v', 0), SenseInfo('01545208-v', 0), SenseInfo('00934965-v', 0), SenseInfo('00883226-v', 0), SenseInfo('00779804-v', 0), SenseInfo('00435294-v', 0), SenseInfo('00310155-v', 0) ],
"_doormat_n_1_rel" : [ SenseInfo('10771636-n', 0), SenseInfo('03223299-n', 0) ],
"_all+day_a_1_rel" : [  ],
"_ranking_n_1_rel" : [ SenseInfo('14429484-n', 0) ],
"_mistransmission_n_1_rel" : [  ],
"_off_a_1_rel" : [ SenseInfo('01651469-a', 3), SenseInfo('02082924-a', 1), SenseInfo('01651896-a', 0), SenseInfo('02369869-a', 0), SenseInfo('00035254-a', 0) ],
"_timely_a_1_rel" : [ SenseInfo('01900771-a', 3), SenseInfo('01661529-a', 1), SenseInfo('01900771-a', 3), SenseInfo('01661529-a', 1), SenseInfo('01900771-a', 3), SenseInfo('01661529-a', 1) ],
"_enroll_v_in_rel" : [ SenseInfo('02471327-v', 6), SenseInfo('02471327-v', 6), SenseInfo('02471327-v', 6) ],
"_tyrannosaurus_n_1_rel" : [ SenseInfo('01713764-n', 0) ],
"_haste_n_1_rel" : [ SenseInfo('05060189-n', 12), SenseInfo('00555648-n', 2), SenseInfo('14451189-n', 1) ],
"_buff_n_1_rel" : [ SenseInfo('10077593-n', 2), SenseInfo('14760696-n', 0), SenseInfo('05239589-n', 0), SenseInfo('04973957-n', 0), SenseInfo('02910964-n', 0) ],
"_practice_v_1_rel" : [ SenseInfo('02568672-v', 11), SenseInfo('00606093-v', 7), SenseInfo('01723224-v', 5), SenseInfo('02561332-v', 2), SenseInfo('02375468-v', 0), SenseInfo('02568672-v', 11), SenseInfo('00606093-v', 7), SenseInfo('01723224-v', 5), SenseInfo('02561332-v', 2), SenseInfo('02375468-v', 0) ],
"_snow_n_1_rel" : [ SenseInfo('11508382-n', 13), SenseInfo('15043763-n', 11), SenseInfo('11307082-n', 0), SenseInfo('03066743-n', 0) ],
"_cyborg_n_1_rel" : [ SenseInfo('09985978-n', 0) ],
"_bus_v_1_rel" : [ SenseInfo('01950128-v', 0), SenseInfo('01949110-v', 0), SenseInfo('00180728-v', 0), SenseInfo('01950128-v', 0), SenseInfo('01949110-v', 0), SenseInfo('00180728-v', 0) ],
"_volatility_n_1_rel" : [ SenseInfo('05009921-n', 0), SenseInfo('04866671-n', 0), SenseInfo('04628850-n', 0) ],
"_crib_n_1_rel" : [ SenseInfo('03131574-n', 3), SenseInfo('06347225-n', 0), SenseInfo('03131669-n', 0), SenseInfo('00492083-n', 0), SenseInfo('00491901-n', 0) ],
"_motorboat_n_1_rel" : [ SenseInfo('03790230-n', 0) ],
"_round_p_rel" : [ SenseInfo('02040652-a', 12), SenseInfo('04113641-n', 6), SenseInfo('00071456-r', 3), SenseInfo('01858910-v', 3), SenseInfo('15287830-n', 2), SenseInfo('08507381-n', 1), SenseInfo('01055688-n', 1), SenseInfo('00466377-n', 1), SenseInfo('00415098-n', 1), SenseInfo('01457486-a', 1), SenseInfo('00916524-a', 1), SenseInfo('00145147-v', 1), SenseInfo('15256714-n', 0), SenseInfo('09417097-n', 0), SenseInfo('07884266-n', 0), SenseInfo('07662156-n', 0), SenseInfo('07053089-n', 0), SenseInfo('06692464-n', 0), SenseInfo('04119892-n', 0), SenseInfo('03032811-n', 0), SenseInfo('00980339-v', 0), SenseInfo('00862683-v', 0), SenseInfo('00473799-v', 0), SenseInfo('00145623-v', 0), SenseInfo('00046382-v', 0), SenseInfo('02040652-a', 12), SenseInfo('04113641-n', 6), SenseInfo('00071456-r', 3), SenseInfo('01858910-v', 3), SenseInfo('15287830-n', 2), SenseInfo('08507381-n', 1), SenseInfo('01055688-n', 1), SenseInfo('00466377-n', 1), SenseInfo('00415098-n', 1), SenseInfo('01457486-a', 1), SenseInfo('00916524-a', 1), SenseInfo('00145147-v', 1), SenseInfo('15256714-n', 0), SenseInfo('09417097-n', 0), SenseInfo('07884266-n', 0), SenseInfo('07662156-n', 0), SenseInfo('07053089-n', 0), SenseInfo('06692464-n', 0), SenseInfo('04119892-n', 0), SenseInfo('03032811-n', 0), SenseInfo('00980339-v', 0), SenseInfo('00862683-v', 0), SenseInfo('00473799-v', 0), SenseInfo('00145623-v', 0), SenseInfo('00046382-v', 0) ],
"_tussle_v_1_rel" : [ SenseInfo('01504480-v', 0), SenseInfo('01473886-v', 0) ],
"_parturition_n_1_rel" : [ SenseInfo('13532886-n', 0) ],
"_stress_v_out_rel" : [ SenseInfo('01013367-v', 29), SenseInfo('00983333-v', 4), SenseInfo('01798452-v', 0) ],
"_underside_n_1_rel" : [ SenseInfo('08511241-n', 1) ],
"_crisscross_v_1_rel" : [ SenseInfo('01913237-v', 1), SenseInfo('01276800-v', 0), SenseInfo('00510713-v', 0), SenseInfo('01913237-v', 1), SenseInfo('01276800-v', 0), SenseInfo('00510713-v', 0), SenseInfo('01913237-v', 1), SenseInfo('01276800-v', 0), SenseInfo('00510713-v', 0) ],
"_doodle_n_1_rel" : [ SenseInfo('04155310-n', 0) ],
"_earnest_a_1_rel" : [ SenseInfo('02118840-a', 2), SenseInfo('02179968-a', 0), SenseInfo('01910114-a', 0), SenseInfo('02118840-a', 2), SenseInfo('02179968-a', 0), SenseInfo('01910114-a', 0) ],
"_sulfuric_a_1_rel" : [ SenseInfo('03121394-a', 0) ],
"_more+than_p_rel" : [ SenseInfo('01555133-a', 0), SenseInfo('01555133-a', 0), SenseInfo('01555133-a', 0) ],
"_subside_v_1_rel" : [ SenseInfo('00232956-v', 4), SenseInfo('01986367-v', 0), SenseInfo('01986185-v', 0), SenseInfo('01971929-v', 0) ],
"_refurbished_a_1_rel" : [  ],
"_mayan_n_1_rel" : [ SenseInfo('09648309-n', 0), SenseInfo('06919215-n', 0) ],
"_eliminate_v_from_rel" : [ SenseInfo('00471711-v', 40), SenseInfo('02629256-v', 13), SenseInfo('00470701-v', 2), SenseInfo('00685419-v', 1), SenseInfo('00072989-v', 1), SenseInfo('01102839-v', 0), SenseInfo('00575561-v', 0), SenseInfo('00471711-v', 40), SenseInfo('02629256-v', 13), SenseInfo('00470701-v', 2), SenseInfo('00685419-v', 1), SenseInfo('00072989-v', 1), SenseInfo('01102839-v', 0), SenseInfo('00575561-v', 0) ],
"_lass_n_1_rel" : [ SenseInfo('10247358-n', 0) ],
"_craving_n_for_rel" : [ SenseInfo('07485475-n', 0) ],
"_word-for-word_a_1_rel" : [  ],
"_korean_a_1_rel" : [ SenseInfo('02967791-a', 1) ],
"_installation_n_of_rel" : [ SenseInfo('00240938-n', 4), SenseInfo('03315023-n', 3), SenseInfo('07453195-n', 0) ],
"_leer_n_1_rel" : [ SenseInfo('06716483-n', 0), SenseInfo('04680027-n', 0) ],
"_kit_v_out_rel" : [ SenseInfo('02341200-v', 0) ],
"_paraguayan_a_1_rel" : [ SenseInfo('02967179-a', 0) ],
"_penny-ante_a_1_rel" : [  ],
"_enlist_v_1_rel" : [ SenseInfo('01097192-v', 7), SenseInfo('02240151-v', 6), SenseInfo('01097500-v', 1) ],
"_pad_v_1_rel" : [ SenseInfo('00956405-v', 1), SenseInfo('01921204-v', 0), SenseInfo('01526956-v', 0), SenseInfo('00321486-v', 0) ],
"_criticize_v_for-as_rel" : [ SenseInfo('00826509-v', 13), SenseInfo('01096097-v', 0), SenseInfo('00826509-v', 13), SenseInfo('01096097-v', 0), SenseInfo('00826509-v', 13), SenseInfo('01096097-v', 0), SenseInfo('00826509-v', 13), SenseInfo('01096097-v', 0), SenseInfo('00826509-v', 13), SenseInfo('01096097-v', 0), SenseInfo('00826509-v', 13), SenseInfo('01096097-v', 0), SenseInfo('00826509-v', 13), SenseInfo('01096097-v', 0), SenseInfo('00826509-v', 13), SenseInfo('01096097-v', 0) ],
"_scream_n_of_rel" : [ SenseInfo('07123012-n', 6), SenseInfo('07393161-n', 1), SenseInfo('06778925-n', 0) ],
"_dale_n_1_rel" : [ SenseInfo('09262690-n', 0) ],
"_discernment_n_of_rel" : [ SenseInfo('05805475-n', 0), SenseInfo('05749619-n', 0), SenseInfo('05710210-n', 0), SenseInfo('05614175-n', 0), SenseInfo('04891010-n', 0), SenseInfo('05805475-n', 0), SenseInfo('05749619-n', 0), SenseInfo('05710210-n', 0), SenseInfo('05614175-n', 0), SenseInfo('04891010-n', 0) ],
"_slop_n_1_rel" : [ SenseInfo('07805006-n', 1), SenseInfo('14956523-n', 0), SenseInfo('14858451-n', 0), SenseInfo('07938427-n', 0), SenseInfo('06775969-n', 0) ],
"_tierce_n_1_rel" : [ SenseInfo('15229875-n', 0), SenseInfo('13744044-n', 0), SenseInfo('13737190-n', 0) ],
"_delegate_n_1_rel" : [ SenseInfo('10000787-n', 1) ],
"_concatenative_a_1_rel" : [  ],
"_suffer_v_1_rel" : [ SenseInfo('02109190-v', 17), SenseInfo('00065639-v', 17), SenseInfo('01794668-v', 12), SenseInfo('00668099-v', 8), SenseInfo('00204750-v', 7), SenseInfo('00065070-v', 4), SenseInfo('02121511-v', 1), SenseInfo('00078401-v', 1), SenseInfo('02719807-v', 0), SenseInfo('02110082-v', 0), SenseInfo('00204872-v', 0) ],
"_heap_n_1_rel" : [ SenseInfo('07961480-n', 6), SenseInfo('13774404-n', 2), SenseInfo('02924554-n', 0) ],
"_hang_v_out_rel" : [ SenseInfo('01482075-v', 35), SenseInfo('01481360-v', 12), SenseInfo('02485451-v', 11), SenseInfo('01977962-v', 6), SenseInfo('01542668-v', 5), SenseInfo('02734952-v', 2), SenseInfo('02170427-v', 1), SenseInfo('01481957-v', 1), SenseInfo('01216331-v', 1), SenseInfo('02741003-v', 0), SenseInfo('02557790-v', 0), SenseInfo('01677716-v', 0), SenseInfo('01481819-v', 0), SenseInfo('01481647-v', 0), SenseInfo('00210110-v', 0) ],
"_link_v_1_rel" : [ SenseInfo('00713167-v', 14), SenseInfo('01354673-v', 3), SenseInfo('02622234-v', 1), SenseInfo('01492052-v', 0), SenseInfo('00713167-v', 14), SenseInfo('01354673-v', 3), SenseInfo('02622234-v', 1), SenseInfo('01492052-v', 0), SenseInfo('00713167-v', 14), SenseInfo('01354673-v', 3), SenseInfo('02622234-v', 1), SenseInfo('01492052-v', 0) ],
"_curious_a_about_rel" : [ SenseInfo('00968010-a', 14), SenseInfo('00664449-a', 13), SenseInfo('01342572-a', 0), SenseInfo('00968010-a', 14), SenseInfo('00664449-a', 13), SenseInfo('01342572-a', 0), SenseInfo('00968010-a', 14), SenseInfo('00664449-a', 13), SenseInfo('01342572-a', 0), SenseInfo('00968010-a', 14), SenseInfo('00664449-a', 13), SenseInfo('01342572-a', 0) ],
"_undue_a_1_rel" : [ SenseInfo('00137641-a', 2), SenseInfo('00137943-a', 1), SenseInfo('01945350-a', 0), SenseInfo('01533974-a', 0), SenseInfo('00137641-a', 2), SenseInfo('00137943-a', 1), SenseInfo('01945350-a', 0), SenseInfo('01533974-a', 0), SenseInfo('00137641-a', 2), SenseInfo('00137943-a', 1), SenseInfo('01945350-a', 0), SenseInfo('01533974-a', 0) ],
"_pal_v_around_rel" : [ SenseInfo('02588871-v', 0) ],
"_residual_n_1_rel" : [ SenseInfo('13810818-n', 0), SenseInfo('13292989-n', 0) ],
"_passage_n_of_rel" : [ SenseInfo('00201058-n', 6), SenseInfo('06400271-n', 5), SenseInfo('03895293-n', 4), SenseInfo('01126856-n', 3), SenseInfo('00309115-n', 3), SenseInfo('07044917-n', 2), SenseInfo('05248181-n', 1), SenseInfo('00865600-n', 1), SenseInfo('07310642-n', 0), SenseInfo('00318035-n', 0) ],
"_engaging_a_1_rel" : [ SenseInfo('00167671-a', 0) ],
"_jerry_n_1_rel" : [ SenseInfo('09748239-n', 0) ],
"_phony_n_1_rel" : [ SenseInfo('10195593-n', 1) ],
"_modernize_v_1_rel" : [ SenseInfo('00262076-v', 3), SenseInfo('00411020-v', 1) ],
"_suspension_n_of_rel" : [ SenseInfo('14591091-n', 6), SenseInfo('15271008-n', 0), SenseInfo('14010636-n', 0), SenseInfo('07368256-n', 0), SenseInfo('04366116-n', 0), SenseInfo('01017701-n', 0), SenseInfo('00209132-n', 0) ],
"_trim_v_off_rel" : [ SenseInfo('01262564-v', 8), SenseInfo('01679806-v', 1), SenseInfo('00429060-v', 1), SenseInfo('02752107-v', 0), SenseInfo('02751952-v', 0), SenseInfo('01679433-v', 0), SenseInfo('01321002-v', 0), SenseInfo('01248782-v', 0), SenseInfo('00297193-v', 0) ],
"_quadrangular_a_1_rel" : [ SenseInfo('02834340-a', 0) ],
"_kind+of_x_deg_rel" : [ SenseInfo('00018302-r', 7), SenseInfo('00018302-r', 7) ],
"_comb_v_1_rel" : [ SenseInfo('01596645-v', 1), SenseInfo('01319193-v', 1), SenseInfo('00038365-v', 1) ],
"_fax_v_1_rel" : [ SenseInfo('01007676-v', 0), SenseInfo('01007676-v', 0) ],
"_transcription_n_of_rel" : [ SenseInfo('06349597-n', 1), SenseInfo('13568238-n', 0), SenseInfo('04470605-n', 0), SenseInfo('00939628-n', 0), SenseInfo('00910203-n', 0) ],
"_weak_n_1_rel" : [ SenseInfo('02324397-a', 13), SenseInfo('00756459-a', 3), SenseInfo('02320442-a', 1), SenseInfo('01259391-a', 1), SenseInfo('02493574-a', 0), SenseInfo('02230471-a', 0), SenseInfo('02040233-a', 0), SenseInfo('01960432-a', 0), SenseInfo('01828242-a', 0), SenseInfo('01747364-a', 0), SenseInfo('00964768-a', 0), SenseInfo('00441523-a', 0) ],
"_throttle_v_back_rel" : [ SenseInfo('00233335-v', 2), SenseInfo('01570935-v', 1), SenseInfo('00173159-v', 0) ],
"_basketball_n_1_rel" : [ SenseInfo('00480993-n', 3), SenseInfo('02802426-n', 0) ],
"_fascinated_a_1_rel" : [ SenseInfo('00865848-a', 1) ],
"_plunder_n_1_rel" : [ SenseInfo('13262663-n', 1) ],
"_sort+of_x_deg_rel" : [ SenseInfo('00018302-r', 10), SenseInfo('00018302-r', 10) ],
"_between_p_sel_rel" : [ SenseInfo('00498387-r', 1), SenseInfo('00250898-r', 1) ],
"_hoot_n_1_rel" : [ SenseInfo('07122555-n', 1), SenseInfo('07123870-n', 0), SenseInfo('05140793-n', 0) ],
"_fight_n_1_rel" : [ SenseInfo('00953559-n', 21), SenseInfo('01170962-n', 18), SenseInfo('04837425-n', 2), SenseInfo('07184391-n', 0), SenseInfo('00446493-n', 0) ],
"_colleague_n_1_rel" : [ SenseInfo('09936215-n', 7), SenseInfo('09935990-n', 1) ],
"_dire_a_1_rel" : [ SenseInfo('00651451-a', 0), SenseInfo('00193799-a', 0), SenseInfo('00651451-a', 0), SenseInfo('00193799-a', 0), SenseInfo('00651451-a', 0), SenseInfo('00193799-a', 0) ],
"_close+to_x_deg_rel" : [ SenseInfo('00007015-r', 3) ],
"_nationwide_a_1_rel" : [ SenseInfo('00526984-a', 0), SenseInfo('00526984-a', 0) ],
"_overreact_v_1_rel" : [ SenseInfo('00718117-v', 0), SenseInfo('00718117-v', 0) ],
"_etch_v_1_rel" : [ SenseInfo('01750421-v', 1), SenseInfo('02199119-v', 0), SenseInfo('01749790-v', 0), SenseInfo('01322223-v', 0), SenseInfo('00448110-v', 0), SenseInfo('01750421-v', 1), SenseInfo('02199119-v', 0), SenseInfo('01749790-v', 0), SenseInfo('01322223-v', 0), SenseInfo('00448110-v', 0) ],
"_polish_v_off_rel" : [ SenseInfo('01245637-v', 7), SenseInfo('00474017-v', 3), SenseInfo('00473799-v', 0) ],
"_certify_v_1_rel" : [ SenseInfo('00820976-v', 4), SenseInfo('02349813-v', 3), SenseInfo('02444662-v', 2), SenseInfo('02447793-v', 0), SenseInfo('00822262-v', 0), SenseInfo('00820976-v', 4), SenseInfo('02349813-v', 3), SenseInfo('02444662-v', 2), SenseInfo('02447793-v', 0), SenseInfo('00822262-v', 0) ],
"_localize_v_1_rel" : [ SenseInfo('02695895-v', 0), SenseInfo('02692335-v', 0), SenseInfo('02509919-v', 0), SenseInfo('01711749-v', 0), SenseInfo('02695895-v', 0), SenseInfo('02692335-v', 0), SenseInfo('02509919-v', 0), SenseInfo('01711749-v', 0) ],
"_off+button_n_1_rel" : [  ],
"_poetical_a_1_rel" : [ SenseInfo('02857099-a', 0), SenseInfo('02018141-a', 0) ],
"_unlike_p_rel" : [ SenseInfo('01410363-a', 6), SenseInfo('01411291-a', 0), SenseInfo('01410363-a', 6), SenseInfo('01411291-a', 0) ],
"_operative_a_1_rel" : [ SenseInfo('00832347-a', 1), SenseInfo('01169194-a', 0), SenseInfo('02164050-a', 0), SenseInfo('01091728-a', 0) ],
"_inject_v_into_rel" : [ SenseInfo('00086320-v', 4), SenseInfo('00187268-v', 3), SenseInfo('01585523-v', 0), SenseInfo('01199213-v', 0), SenseInfo('01195201-v', 0), SenseInfo('00914769-v', 0), SenseInfo('00086320-v', 4), SenseInfo('00187268-v', 3), SenseInfo('01585523-v', 0), SenseInfo('01199213-v', 0), SenseInfo('01195201-v', 0), SenseInfo('00914769-v', 0) ],
"_orifice_n_1_rel" : [ SenseInfo('05249636-n', 2) ],
"_sly_a_1_rel" : [ SenseInfo('00148078-a', 1), SenseInfo('00148078-a', 1), SenseInfo('00148078-a', 1) ],
"_by_p_n-n_rel" : [ SenseInfo('00417787-r', 2), SenseInfo('00233687-r', 0) ],
"_bother_n_1_rel" : [ SenseInfo('07372565-n', 0), SenseInfo('05830059-n', 0) ],
"_pare_v_1_rel" : [ SenseInfo('00233089-v', 1), SenseInfo('01552219-v', 0), SenseInfo('01262936-v', 0), SenseInfo('01262564-v', 0) ],
"_dub_v_1_rel" : [ SenseInfo('01028640-v', 2), SenseInfo('00960562-v', 1), SenseInfo('02399185-v', 0), SenseInfo('01028640-v', 2), SenseInfo('00960562-v', 1), SenseInfo('02399185-v', 0), SenseInfo('01028640-v', 2), SenseInfo('00960562-v', 1), SenseInfo('02399185-v', 0) ],
"_clear_v_of_rel" : [ SenseInfo('00181664-v', 16), SenseInfo('00195617-v', 5), SenseInfo('02771169-v', 2), SenseInfo('00803325-v', 2), SenseInfo('00195342-v', 2), SenseInfo('02523351-v', 1), SenseInfo('02289134-v', 1), SenseInfo('02156844-v', 1), SenseInfo('02081178-v', 1), SenseInfo('00621058-v', 1), SenseInfo('02422409-v', 0), SenseInfo('02350440-v', 0), SenseInfo('02291548-v', 0), SenseInfo('02291258-v', 0), SenseInfo('02289295-v', 0), SenseInfo('02208409-v', 0), SenseInfo('02053490-v', 0), SenseInfo('00904046-v', 0), SenseInfo('00761454-v', 0), SenseInfo('00549217-v', 0), SenseInfo('00450863-v', 0), SenseInfo('00450691-v', 0), SenseInfo('00450565-v', 0), SenseInfo('00178235-v', 0) ],
"_honk_v_1_rel" : [ SenseInfo('02183175-v', 0), SenseInfo('01053495-v', 0), SenseInfo('01053339-v', 0), SenseInfo('00076400-v', 0) ],
"_dutchess_n_1_rel" : [ SenseInfo('09699763-n', 0), SenseInfo('06952572-n', 0) ],
"_fundamental_a_1_rel" : [ SenseInfo('01277097-a', 10), SenseInfo('01856419-a', 7), SenseInfo('02162934-a', 1), SenseInfo('01277097-a', 10), SenseInfo('01856419-a', 7), SenseInfo('02162934-a', 1) ],
"_aged_n_1_rel" : [ SenseInfo('07943870-n', 1) ],
"_self-image_n_1_rel" : [  ],
"_riddle_n_1_rel" : [ SenseInfo('06785223-n', 1), SenseInfo('04088696-n', 0) ],
"_mum_a_1_rel" : [ SenseInfo('00501820-a', 1) ],
"_drink_v_1_rel" : [ SenseInfo('01170052-v', 30), SenseInfo('01171183-v', 10), SenseInfo('01175467-v', 1), SenseInfo('00737005-v', 1), SenseInfo('01172275-v', 0) ],
"_sash_n_1_rel" : [ SenseInfo('04136510-n', 1), SenseInfo('03438071-n', 1) ],
"_humiliating_a_1_rel" : [ SenseInfo('00752555-a', 2) ],
"_carpark_n_1_rel" : [  ],
"_inlet_n_1_rel" : [ SenseInfo('09313716-n', 3), SenseInfo('03576617-n', 0) ],
"_viaduct_n_1_rel" : [ SenseInfo('04532670-n', 0), SenseInfo('04532670-n', 0) ],
"_offset_n_1_rel" : [ SenseInfo('15265518-n', 0), SenseInfo('13291189-n', 0), SenseInfo('13127843-n', 0), SenseInfo('11415721-n', 0), SenseInfo('06680570-n', 0), SenseInfo('04176747-n', 0) ],
"_lineman_n_1_rel" : [ SenseInfo('10263411-n', 1), SenseInfo('10263580-n', 0), SenseInfo('10049363-n', 0), SenseInfo('00726100-n', 0) ],
"_characteristic_a_of_rel" : [ SenseInfo('00356926-a', 22), SenseInfo('00356926-a', 22) ],
"_gasp_a_1_rel" : [ SenseInfo('00837098-n', 4), SenseInfo('00837098-n', 4) ],
"_low_x_deg_rel" : [ SenseInfo('01212469-a', 55), SenseInfo('01206474-a', 23), SenseInfo('01455888-a', 11), SenseInfo('01951008-a', 6), SenseInfo('01215421-a', 4), SenseInfo('00393149-r', 3), SenseInfo('00904745-a', 3), SenseInfo('14520829-n', 0), SenseInfo('11142155-n', 0), SenseInfo('05097706-n', 0), SenseInfo('03350011-n', 0), SenseInfo('02340458-a', 0), SenseInfo('02336759-a', 0), SenseInfo('01893303-a', 0), SenseInfo('00703615-a', 0), SenseInfo('01055018-v', 0) ],
"_daffodil_n_1_rel" : [ SenseInfo('12421683-n', 1) ],
"_dissolve_v_1_rel" : [ SenseInfo('00447771-v', 4), SenseInfo('00447309-v', 3), SenseInfo('00355803-v', 2), SenseInfo('02029944-v', 1), SenseInfo('01784799-v', 0), SenseInfo('01784592-v', 0), SenseInfo('00447950-v', 0), SenseInfo('00446329-v', 0), SenseInfo('00376106-v', 0), SenseInfo('00355955-v', 0), SenseInfo('00338559-v', 0) ],
"_mist_v_2_rel" : [ SenseInfo('00361495-v', 1), SenseInfo('02157731-v', 0), SenseInfo('01373303-v', 0) ],
"_disengage_v_1_rel" : [ SenseInfo('01511380-v', 1), SenseInfo('01475953-v', 0), SenseInfo('00220276-v', 0) ],
"_rich_n_1_rel" : [ SenseInfo('08179455-n', 0) ],
"_gone_a_1_rel" : [ SenseInfo('00735882-a', 5), SenseInfo('00095873-a', 3), SenseInfo('01728919-a', 1), SenseInfo('01450084-a', 1) ],
"_ration_n_1_rel" : [ SenseInfo('07565725-n', 7), SenseInfo('13286099-n', 1) ],
"_cement_v_1_rel" : [ SenseInfo('01304076-v', 2), SenseInfo('01366926-v', 0), SenseInfo('01366653-v', 0) ],
"_justifiable_a_1_rel" : [ SenseInfo('01722140-a', 0), SenseInfo('01722140-a', 0), SenseInfo('01722140-a', 0), SenseInfo('01722140-a', 0) ],
"_prowler_n_1_rel" : [ SenseInfo('10486679-n', 1) ],
"_evaporation_n_1_rel" : [ SenseInfo('13572436-n', 2), SenseInfo('13460568-n', 0) ],
"_sequential_a_1_rel" : [ SenseInfo('01667729-a', 1), SenseInfo('01667729-a', 1) ],
"_negotiate_v_with_rel" : [ SenseInfo('00761713-v', 17), SenseInfo('02050688-v', 0) ],
"_grow_v_1_rel" : [ SenseInfo('00125841-v', 70), SenseInfo('00230746-v', 62), SenseInfo('00231557-v', 32), SenseInfo('00245457-v', 12), SenseInfo('00250181-v', 8), SenseInfo('02624263-v', 7), SenseInfo('01739814-v', 3), SenseInfo('00094460-v', 3), SenseInfo('00543410-v', 2), SenseInfo('00250539-v', 0), SenseInfo('00125841-v', 70), SenseInfo('00230746-v', 62), SenseInfo('00231557-v', 32), SenseInfo('00245457-v', 12), SenseInfo('00250181-v', 8), SenseInfo('02624263-v', 7), SenseInfo('01739814-v', 3), SenseInfo('00094460-v', 3), SenseInfo('00543410-v', 2), SenseInfo('00250539-v', 0), SenseInfo('00125841-v', 70), SenseInfo('00230746-v', 62), SenseInfo('00231557-v', 32), SenseInfo('00245457-v', 12), SenseInfo('00250181-v', 8), SenseInfo('02624263-v', 7), SenseInfo('01739814-v', 3), SenseInfo('00094460-v', 3), SenseInfo('00543410-v', 2), SenseInfo('00250539-v', 0), SenseInfo('00125841-v', 70), SenseInfo('00230746-v', 62), SenseInfo('00231557-v', 32), SenseInfo('00245457-v', 12), SenseInfo('00250181-v', 8), SenseInfo('02624263-v', 7), SenseInfo('01739814-v', 3), SenseInfo('00094460-v', 3), SenseInfo('00543410-v', 2), SenseInfo('00250539-v', 0) ],
"_also-ran_n_1_rel" : [ SenseInfo('10272913-n', 0), SenseInfo('10272913-n', 0) ],
"_gin_n_1_rel" : [ SenseInfo('07904395-n', 0), SenseInfo('04248851-n', 0), SenseInfo('03115525-n', 0), SenseInfo('00496877-n', 0) ],
"_tale_n_1_rel" : [ SenseInfo('07221094-n', 26), SenseInfo('06757057-n', 6) ],
"_peel_v_away_rel" : [ SenseInfo('01262936-v', 3), SenseInfo('01259951-v', 0), SenseInfo('00049900-v', 0) ],
"_paycheck_n_1_rel" : [ SenseInfo('13382975-n', 0) ],
"_in-home_a_1_rel" : [  ],
"_replication_n_of_rel" : [ SenseInfo('01019901-n', 1), SenseInfo('13549916-n', 0), SenseInfo('07199922-n', 0), SenseInfo('06563168-n', 0), SenseInfo('05010801-n', 0), SenseInfo('04076533-n', 0), SenseInfo('01249060-n', 0) ],
"_warm_v_up-to_rel" : [ SenseInfo('00373250-v', 2), SenseInfo('00372958-v', 1), SenseInfo('00373250-v', 2), SenseInfo('00372958-v', 1) ],
"_dairymaid_n_1_rel" : [ SenseInfo('09988216-n', 0) ],
"_even+so_a_1_rel" : [  ],
"_timesaving_a_1_rel" : [  ],
"_loathing_n_for_rel" : [ SenseInfo('07503430-n', 0) ],
"_misread_v_1_rel" : [ SenseInfo('00627693-v', 1), SenseInfo('00624801-v', 0), SenseInfo('00627693-v', 1), SenseInfo('00624801-v', 0) ],
"_in+principle_a_1_rel" : [  ],
"_gouge_v_1_rel" : [ SenseInfo('01281611-v', 3), SenseInfo('02241107-v', 2), SenseInfo('01281782-v', 2) ],
"_just+then_a_1_rel" : [  ],
"_registration_n_of_rel" : [ SenseInfo('00050037-n', 7), SenseInfo('08479986-n', 0), SenseInfo('06479374-n', 0), SenseInfo('04987356-n', 0), SenseInfo('00999787-n', 0) ],
"_fan_n_1_rel" : [ SenseInfo('03320046-n', 4), SenseInfo('10639925-n', 3), SenseInfo('10077593-n', 3) ],
"_circuitous_a_1_rel" : [ SenseInfo('00767349-a', 0), SenseInfo('00763013-a', 0), SenseInfo('00767349-a', 0), SenseInfo('00763013-a', 0) ],
"_mainly_x_deg_rel" : [ SenseInfo('00073897-r', 11) ],
"_circumvent_v_1_rel" : [ SenseInfo('01127411-v', 0), SenseInfo('01104852-v', 0), SenseInfo('00809654-v', 0) ],
"_kick-start_v_1_rel" : [ SenseInfo('01858016-v', 0), SenseInfo('01858016-v', 0) ],
"_mom_n_1_rel" : [ SenseInfo('10278128-n', 0) ],
"_link_n_1_rel" : [ SenseInfo('13792692-n', 5), SenseInfo('03673971-n', 5), SenseInfo('14419164-n', 0), SenseInfo('13870805-n', 0), SenseInfo('13654777-n', 0), SenseInfo('06586471-n', 0), SenseInfo('06261260-n', 0), SenseInfo('04042795-n', 0), SenseInfo('03674270-n', 0) ],
"_inherit_v_1_rel" : [ SenseInfo('02315525-v', 14), SenseInfo('02315938-v', 0), SenseInfo('02315759-v', 0) ],
"_sword_n_1_rel" : [ SenseInfo('04373894-n', 9) ],
"_rather+than_p_rel" : [  ],
"_outfitter_n_1_rel" : [ SenseInfo('10387712-n', 0), SenseInfo('03860234-n', 0) ],
"_patient_n_1_rel" : [ SenseInfo('10405694-n', 73), SenseInfo('06332136-n', 0) ],
"_channel_n_1_rel" : [ SenseInfo('06259898-n', 4), SenseInfo('03006105-n', 1), SenseInfo('13893786-n', 0), SenseInfo('09241247-n', 0), SenseInfo('06260121-n', 0), SenseInfo('05250659-n', 0), SenseInfo('03006398-n', 0), SenseInfo('01113595-n', 0), SenseInfo('06259898-n', 4), SenseInfo('03006105-n', 1), SenseInfo('13893786-n', 0), SenseInfo('09241247-n', 0), SenseInfo('06260121-n', 0), SenseInfo('05250659-n', 0), SenseInfo('03006398-n', 0), SenseInfo('01113595-n', 0), SenseInfo('06259898-n', 4), SenseInfo('03006105-n', 1), SenseInfo('13893786-n', 0), SenseInfo('09241247-n', 0), SenseInfo('06260121-n', 0), SenseInfo('05250659-n', 0), SenseInfo('03006398-n', 0), SenseInfo('01113595-n', 0) ],
"_polar_a_1_rel" : [ SenseInfo('00358820-a', 3), SenseInfo('02066312-a', 1), SenseInfo('02838005-a', 0), SenseInfo('02444147-a', 0), SenseInfo('01252151-a', 0), SenseInfo('00656507-a', 0) ],
"_encourage_v_1_rel" : [ SenseInfo('02554922-v', 53), SenseInfo('01818235-v', 12), SenseInfo('00771341-v', 1), SenseInfo('02554922-v', 53), SenseInfo('01818235-v', 12), SenseInfo('00771341-v', 1), SenseInfo('02554922-v', 53), SenseInfo('01818235-v', 12), SenseInfo('00771341-v', 1) ],
"_Q_a_colon_rel" : [  ],
"_blouse_n_1_rel" : [ SenseInfo('02854926-n', 0) ],
"_republican_n_1_rel" : [ SenseInfo('10522633-n', 8), SenseInfo('10522495-n', 1), SenseInfo('09407632-n', 0) ],
"_leave_v_transfer_rel" : [ SenseInfo('02009433-v', 146), SenseInfo('00613683-v', 63), SenseInfo('02729414-v', 56), SenseInfo('00136991-v', 27), SenseInfo('02015598-v', 20), SenseInfo('02721438-v', 19), SenseInfo('02635659-v', 16), SenseInfo('02383440-v', 14), SenseInfo('02356230-v', 8), SenseInfo('02229055-v', 7), SenseInfo('02730135-v', 5), SenseInfo('00360092-v', 5), SenseInfo('02296153-v', 3), SenseInfo('00613018-v', 3) ],
"_enclose_v_1_rel" : [ SenseInfo('01580467-v', 3), SenseInfo('02711114-v', 2), SenseInfo('01587062-v', 1), SenseInfo('00187526-v', 0) ],
"_foul_a_1_rel" : [ SenseInfo('01625893-a', 1), SenseInfo('01053634-a', 1), SenseInfo('00957743-a', 1), SenseInfo('00955915-a', 0), SenseInfo('01405390-a', 0), SenseInfo('00425313-a', 0), SenseInfo('00421590-a', 0), SenseInfo('00255308-a', 0), SenseInfo('01625893-a', 1), SenseInfo('01053634-a', 1), SenseInfo('00957743-a', 1), SenseInfo('00955915-a', 0), SenseInfo('01405390-a', 0), SenseInfo('00425313-a', 0), SenseInfo('00421590-a', 0), SenseInfo('00255308-a', 0), SenseInfo('01625893-a', 1), SenseInfo('01053634-a', 1), SenseInfo('00957743-a', 1), SenseInfo('00955915-a', 0), SenseInfo('01405390-a', 0), SenseInfo('00425313-a', 0), SenseInfo('00421590-a', 0), SenseInfo('00255308-a', 0) ],
"_election_n_of-for_rel" : [ SenseInfo('00181781-n', 67), SenseInfo('00180962-n', 1), SenseInfo('13926329-n', 0), SenseInfo('05966798-n', 0), SenseInfo('00181781-n', 67), SenseInfo('00180962-n', 1), SenseInfo('13926329-n', 0), SenseInfo('05966798-n', 0) ],
"_just+in+case_a_1_rel" : [  ],
"_browse_v_1_rel" : [ SenseInfo('02326355-v', 0), SenseInfo('01576165-v', 0), SenseInfo('01315333-v', 0), SenseInfo('01174742-v', 0) ],
"_door-to-door_a_1_rel" : [ SenseInfo('00761260-a', 0), SenseInfo('00527551-a', 0), SenseInfo('00761260-a', 0), SenseInfo('00527551-a', 0), SenseInfo('00761260-a', 0), SenseInfo('00527551-a', 0), SenseInfo('00761260-a', 0), SenseInfo('00527551-a', 0), SenseInfo('00761260-a', 0), SenseInfo('00527551-a', 0), SenseInfo('00761260-a', 0), SenseInfo('00527551-a', 0) ],
"_not+quite_x_rel" : [ SenseInfo('00018781-r', 57), SenseInfo('00018577-r', 47), SenseInfo('00018918-r', 6), SenseInfo('00019181-r', 0) ],
"_kwh_n_1_rel" : [  ],
"_godfather_n_1_rel" : [ SenseInfo('10134760-n', 0), SenseInfo('10134627-n', 0) ],
"_metrical_a_1_rel" : [ SenseInfo('02995636-a', 0), SenseInfo('02020310-a', 0) ],
"_pedal_v_1_rel" : [ SenseInfo('01935476-v', 0), SenseInfo('01728052-v', 0) ],
"_dignified_a_1_rel" : [ SenseInfo('00751525-a', 2), SenseInfo('01890988-a', 1) ],
"_ugly_a_1_rel" : [ SenseInfo('00220956-a', 3), SenseInfo('01139067-a', 0), SenseInfo('01133017-a', 0), SenseInfo('00193480-a', 0), SenseInfo('00220956-a', 3), SenseInfo('01139067-a', 0), SenseInfo('01133017-a', 0), SenseInfo('00193480-a', 0), SenseInfo('00220956-a', 3), SenseInfo('01139067-a', 0), SenseInfo('01133017-a', 0), SenseInfo('00193480-a', 0) ],
"_adverbial_a_1_rel" : [ SenseInfo('02936235-a', 1) ],
"_pathetic_a_1_rel" : [ SenseInfo('01050890-a', 1), SenseInfo('00905181-a', 1), SenseInfo('00752847-a', 0), SenseInfo('01050890-a', 1), SenseInfo('00905181-a', 1), SenseInfo('00752847-a', 0), SenseInfo('01050890-a', 1), SenseInfo('00905181-a', 1), SenseInfo('00752847-a', 0), SenseInfo('01050890-a', 1), SenseInfo('00905181-a', 1), SenseInfo('00752847-a', 0) ],
"_interior_n_1_rel" : [ SenseInfo('08588294-n', 16), SenseInfo('08588152-n', 0), SenseInfo('08139000-n', 0) ],
"_sprain_v_1_rel" : [ SenseInfo('00091124-v', 1) ],
"_live_v_out_rel" : [ SenseInfo('02649830-v', 129), SenseInfo('02614387-v', 51), SenseInfo('02618149-v', 29), SenseInfo('02616713-v', 16), SenseInfo('02614181-v', 14), SenseInfo('00596644-v', 1), SenseInfo('02614970-v', 0) ],
"_spark_n_1_rel" : [ SenseInfo('07412310-n', 4), SenseInfo('04953380-n', 4), SenseInfo('11511523-n', 2), SenseInfo('13773539-n', 0), SenseInfo('11309613-n', 0), SenseInfo('09442341-n', 0) ],
"_super+bowl_n_1_rel" : [  ],
"_abed_a_1_rel" : [  ],
"_hitherward_p_rel" : [  ],
"_peanut_n_1_rel" : [ SenseInfo('11748811-n', 0), SenseInfo('11748501-n', 0), SenseInfo('10410440-n', 0), SenseInfo('07737745-n', 0) ],
"_pauper_n_1_rel" : [ SenseInfo('10409011-n', 0) ],
"_czech_a_1_rel" : [ SenseInfo('02961688-a', 0) ],
"_fishermans_a_1_rel" : [  ],
"_universal_n_1_rel" : [ SenseInfo('07259984-n', 0), SenseInfo('06751367-n', 0), SenseInfo('05668359-n', 0), SenseInfo('04510706-n', 0) ],
"_internals_n_1_rel" : [  ],
"_tootle_n_of_rel" : [ SenseInfo('07398362-n', 0) ],
"_wary_a_of_rel" : [ SenseInfo('00162386-a', 2), SenseInfo('02464277-a', 0) ],
"_cardinal_n_1_rel" : [ SenseInfo('09894143-n', 2), SenseInfo('13597585-n', 0), SenseInfo('04963449-n', 0), SenseInfo('01541386-n', 0) ],
"_fabulous_a_1_rel" : [ SenseInfo('01808227-a', 1), SenseInfo('01936184-a', 0), SenseInfo('00645982-a', 0), SenseInfo('01808227-a', 1), SenseInfo('01936184-a', 0), SenseInfo('00645982-a', 0) ],
"_foolhardy_a_1_rel" : [ SenseInfo('00250739-a', 1) ],
"_secretive_a_1_rel" : [ SenseInfo('00501004-a', 0) ],
"_brush_v_away_rel" : [ SenseInfo('01243809-v', 11), SenseInfo('01240720-v', 10), SenseInfo('01243982-v', 5), SenseInfo('01870043-v', 2), SenseInfo('00555780-v', 1), SenseInfo('01373718-v', 0) ],
"_self_n_1_rel" : [ SenseInfo('05675601-n', 16), SenseInfo('09604981-n', 7) ],
"_persist_v_in_rel" : [ SenseInfo('02647497-v', 11), SenseInfo('00350461-v', 8), SenseInfo('02731024-v', 1) ],
"_deceased_n_1_rel" : [ SenseInfo('09994943-n', 1) ],
"_operator_n_of_rel" : [ SenseInfo('13786413-n', 27), SenseInfo('10378412-n', 9), SenseInfo('10378780-n', 1), SenseInfo('10194566-n', 1), SenseInfo('10378952-n', 0) ],
"_mechanic_n_1_rel" : [ SenseInfo('10279018-n', 1), SenseInfo('09825750-n', 1) ],
"_microelectronics_n_1_rel" : [ SenseInfo('06115179-n', 0) ],
"_toft_n_1_rel" : [  ],
"_untouched_a_1_rel" : [ SenseInfo('01086339-a', 1), SenseInfo('00072790-a', 1), SenseInfo('02445554-a', 0), SenseInfo('01560320-a', 0), SenseInfo('01086339-a', 1), SenseInfo('00072790-a', 1), SenseInfo('02445554-a', 0), SenseInfo('01560320-a', 0) ],
"_mental_a_1_rel" : [ SenseInfo('01779986-a', 12), SenseInfo('02898750-a', 4), SenseInfo('02734914-a', 0), SenseInfo('02734776-a', 0), SenseInfo('01177899-a', 0), SenseInfo('01779986-a', 12), SenseInfo('02898750-a', 4), SenseInfo('02734914-a', 0), SenseInfo('02734776-a', 0), SenseInfo('01177899-a', 0) ],
"_nudge_n_1_rel" : [ SenseInfo('00112997-n', 0) ],
"_prostate_n_1_rel" : [ SenseInfo('05331404-n', 0) ],
"_handicraft_n_1_rel" : [ SenseInfo('03485655-n', 0), SenseInfo('00714944-n', 0) ],
"_spar_v_1_rel" : [ SenseInfo('02362700-v', 0), SenseInfo('01420304-v', 0), SenseInfo('01420194-v', 0), SenseInfo('00773922-v', 0) ],
"_perfunctory_a_1_rel" : [ SenseInfo('00312234-a', 1), SenseInfo('01043619-a', 0), SenseInfo('00312234-a', 1), SenseInfo('01043619-a', 0) ],
"_scud_n_1_rel" : [ SenseInfo('00330836-n', 0) ],
"_urge_n_for_rel" : [ SenseInfo('09180431-n', 2), SenseInfo('07490451-n', 2), SenseInfo('09180431-n', 2), SenseInfo('07490451-n', 2), SenseInfo('09180431-n', 2), SenseInfo('07490451-n', 2) ],
"_foreword_n_1_rel" : [ SenseInfo('06397903-n', 0) ],
"_dieresis_n_1_rel" : [ SenseInfo('06823760-n', 0) ],
"_devoid_a_of_rel" : [ SenseInfo('00927978-a', 0) ],
"_undecided_a_1_rel" : [ SenseInfo('02130821-a', 0), SenseInfo('00686356-a', 0), SenseInfo('00519103-a', 0), SenseInfo('02130821-a', 0), SenseInfo('00686356-a', 0), SenseInfo('00519103-a', 0) ],
"_frosting_n_1_rel" : [ SenseInfo('07620822-n', 0) ],
"_treatise_n_1_rel" : [ SenseInfo('06408651-n', 0) ],
"_one-upmanship_n_1_rel" : [ SenseInfo('00412006-n', 1), SenseInfo('00412006-n', 1) ],
"_madam_n_1_rel" : [ SenseInfo('09989290-n', 1), SenseInfo('10279669-n', 0) ],
"_insurance_n_1_rel" : [ SenseInfo('13344804-n', 7), SenseInfo('06523641-n', 2), SenseInfo('14539826-n', 0) ],
"_preach_v_1_rel" : [ SenseInfo('00828003-v', 9), SenseInfo('00827730-v', 4) ],
"_slither_n_1_rel" : [  ],
"_novice_n_at_rel" : [ SenseInfo('10364198-n', 0), SenseInfo('10363913-n', 0) ],
"_nibble_n_1_rel" : [ SenseInfo('13625884-n', 0), SenseInfo('00842197-n', 0) ],
"_bleach_n_1_rel" : [ SenseInfo('04961136-n', 1), SenseInfo('14779205-n', 0), SenseInfo('00274009-n', 0) ],
"_nymphomaniac_n_1_rel" : [ SenseInfo('10368798-n', 2) ],
"_frantic_a_1_rel" : [ SenseInfo('00086341-a', 10), SenseInfo('02390724-a', 1), SenseInfo('00086341-a', 10), SenseInfo('02390724-a', 1) ],
"_fertility_n_1_rel" : [ SenseInfo('15276427-n', 0), SenseInfo('14051494-n', 0), SenseInfo('05147586-n', 0) ],
"_shriek_v_1_rel" : [ SenseInfo('00914420-v', 4), SenseInfo('00914420-v', 4) ],
"_facile_a_1_rel" : [ SenseInfo('01874561-a', 0), SenseInfo('00838533-a', 0), SenseInfo('00150505-a', 0) ],
"_trek_v_1_rel" : [ SenseInfo('01847392-v', 0), SenseInfo('01847220-v', 0), SenseInfo('01847392-v', 0), SenseInfo('01847220-v', 0) ],
"_photocopier_n_1_rel" : [ SenseInfo('03924679-n', 0) ],
"_premier_a_1_rel" : [ SenseInfo('01012990-a', 0), SenseInfo('01012855-a', 0) ],
"_maim_v_1_rel" : [ SenseInfo('00090888-v', 0) ],
"_invite_v_out_rel" : [ SenseInfo('01760143-v', 7), SenseInfo('02384686-v', 6), SenseInfo('01807529-v', 6), SenseInfo('00793580-v', 6), SenseInfo('02384940-v', 3), SenseInfo('01469770-v', 2), SenseInfo('01063695-v', 2), SenseInfo('01470225-v', 0) ],
"_departmental_a_1_rel" : [ SenseInfo('03059966-a', 1) ],
"_swirl_n_of_rel" : [ SenseInfo('13878112-n', 2) ],
"_leave_v_on_rel" : [ SenseInfo('02009433-v', 146), SenseInfo('00613683-v', 63), SenseInfo('02729414-v', 56), SenseInfo('00136991-v', 27), SenseInfo('02015598-v', 20), SenseInfo('02721438-v', 19), SenseInfo('02635659-v', 16), SenseInfo('02383440-v', 14), SenseInfo('02356230-v', 8), SenseInfo('02229055-v', 7), SenseInfo('02730135-v', 5), SenseInfo('00360092-v', 5), SenseInfo('02296153-v', 3), SenseInfo('00613018-v', 3) ],
"_cone_n_of_rel" : [ SenseInfo('03089348-n', 4), SenseInfo('13872592-n', 0), SenseInfo('11682842-n', 0), SenseInfo('05456257-n', 0) ],
"_jaguar_n_1_rel" : [ SenseInfo('02128925-n', 0) ],
"_patience_n_1_rel" : [ SenseInfo('04640538-n', 9), SenseInfo('00495524-n', 0) ],
"_beechwood_n_1_rel" : [ SenseInfo('12261179-n', 0) ],
"_midway_x_rel" : [ SenseInfo('00330506-a', 2), SenseInfo('00255415-r', 1), SenseInfo('08614746-n', 0), SenseInfo('01287782-n', 0) ],
"_arch_a_1_rel" : [ SenseInfo('02338917-a', 0), SenseInfo('02226661-a', 0), SenseInfo('02122715-a', 0) ],
"_awhile_n_1_rel" : [  ],
"_oversee_v_1_rel" : [ SenseInfo('02443049-v', 0) ],
"_pretty_x_deg_rel" : [ SenseInfo('00035718-r', 35), SenseInfo('00220082-a', 20), SenseInfo('01128871-a', 3) ],
"_shun_v_1_rel" : [ SenseInfo('00812149-v', 4), SenseInfo('02504017-v', 0) ],
"_source_n_of_rel" : [ SenseInfo('08507558-n', 34), SenseInfo('06675122-n', 12), SenseInfo('05834758-n', 12), SenseInfo('04263614-n', 8), SenseInfo('10205985-n', 3), SenseInfo('10126177-n', 1), SenseInfo('13558953-n', 0), SenseInfo('09407867-n', 0), SenseInfo('07258664-n', 0) ],
"_nerve-racking_a_for_rel" : [ SenseInfo('00090408-a', 0), SenseInfo('00090408-a', 0), SenseInfo('00090408-a', 0), SenseInfo('00090408-a', 0), SenseInfo('00090408-a', 0), SenseInfo('00090408-a', 0), SenseInfo('00090408-a', 0), SenseInfo('00090408-a', 0), SenseInfo('00090408-a', 0) ],
"_md_n_1_rel" : [ SenseInfo('14645092-n', 0), SenseInfo('10020890-n', 0), SenseInfo('09093608-n', 0), SenseInfo('06703321-n', 0), SenseInfo('14645092-n', 0), SenseInfo('10020890-n', 0), SenseInfo('09093608-n', 0), SenseInfo('06703321-n', 0), SenseInfo('14645092-n', 0), SenseInfo('10020890-n', 0), SenseInfo('09093608-n', 0), SenseInfo('06703321-n', 0), SenseInfo('14645092-n', 0), SenseInfo('10020890-n', 0), SenseInfo('09093608-n', 0), SenseInfo('06703321-n', 0), SenseInfo('14645092-n', 0), SenseInfo('10020890-n', 0), SenseInfo('09093608-n', 0), SenseInfo('06703321-n', 0), SenseInfo('14645092-n', 0), SenseInfo('10020890-n', 0), SenseInfo('09093608-n', 0), SenseInfo('06703321-n', 0), SenseInfo('14645092-n', 0), SenseInfo('10020890-n', 0), SenseInfo('09093608-n', 0), SenseInfo('06703321-n', 0), SenseInfo('14645092-n', 0), SenseInfo('10020890-n', 0), SenseInfo('09093608-n', 0), SenseInfo('06703321-n', 0) ],
"_pot_n_1_rel" : [ SenseInfo('03990474-n', 6), SenseInfo('04446521-n', 5), SenseInfo('13769033-n', 1), SenseInfo('03991062-n', 1), SenseInfo('13774404-n', 0), SenseInfo('13343774-n', 0), SenseInfo('05556071-n', 0), SenseInfo('03991646-n', 0), SenseInfo('03990834-n', 0) ],
"_amuse_v_1_rel" : [ SenseInfo('02492362-v', 6), SenseInfo('00859758-v', 1), SenseInfo('02492362-v', 6), SenseInfo('00859758-v', 1), SenseInfo('02492362-v', 6), SenseInfo('00859758-v', 1), SenseInfo('02492362-v', 6), SenseInfo('00859758-v', 1), SenseInfo('02492362-v', 6), SenseInfo('00859758-v', 1), SenseInfo('02492362-v', 6), SenseInfo('00859758-v', 1) ],
"_joist_n_1_rel" : [ SenseInfo('03601840-n', 0) ],
"_baud_n_1_rel" : [ SenseInfo('13579679-n', 0) ],
"_veto_n_1_rel" : [ SenseInfo('00209546-n', 2), SenseInfo('05198928-n', 0) ],
"_worthiness_n_1_rel" : [ SenseInfo('04806804-n', 0), SenseInfo('04806804-n', 0) ],
"_descriptive_a_1_rel" : [ SenseInfo('00732682-a', 2), SenseInfo('00732318-a', 0) ],
"_at+last_a_1_rel" : [  ],
"_shortness_n_of_rel" : [ SenseInfo('05133944-n', 1), SenseInfo('14450339-n', 0), SenseInfo('05137938-n', 0), SenseInfo('05052832-n', 0), SenseInfo('05002680-n', 0), SenseInfo('04915462-n', 0), SenseInfo('05133944-n', 1), SenseInfo('14450339-n', 0), SenseInfo('05137938-n', 0), SenseInfo('05052832-n', 0), SenseInfo('05002680-n', 0), SenseInfo('04915462-n', 0) ],
"_walk-on_a_1_rel" : [ SenseInfo('00153239-a', 0), SenseInfo('00153239-a', 0) ],
"_spin_v_out_rel" : [ SenseInfo('02046755-v', 11), SenseInfo('02068062-v', 5), SenseInfo('02048051-v', 0), SenseInfo('01639500-v', 0), SenseInfo('01639364-v', 0), SenseInfo('01518772-v', 0), SenseInfo('00953700-v', 0), SenseInfo('00318706-v', 0), SenseInfo('02046755-v', 11), SenseInfo('02068062-v', 5), SenseInfo('02048051-v', 0), SenseInfo('01639500-v', 0), SenseInfo('01639364-v', 0), SenseInfo('01518772-v', 0), SenseInfo('00953700-v', 0), SenseInfo('00318706-v', 0) ],
"_further_a_1_rel" : [ SenseInfo('00443988-a', 2), SenseInfo('00443988-a', 2), SenseInfo('00443988-a', 2) ],
"_=_v_1_rel" : [  ],
"_cheesecloth_n_1_rel" : [ SenseInfo('03012373-n', 1) ],
"_trig_n_1_rel" : [ SenseInfo('06012513-n', 0) ],
"_atelier_n_1_rel" : [ SenseInfo('02746841-n', 0) ],
"_gorgeous_a_1_rel" : [ SenseInfo('00219705-a', 1), SenseInfo('00219705-a', 1) ],
"_code_n_1_rel" : [ SenseInfo('06667317-n', 9), SenseInfo('06353934-n', 1), SenseInfo('06355894-n', 0) ],
"_carbene_n_1_rel" : [  ],
"_hedge_n_1_rel" : [ SenseInfo('03511175-n', 2), SenseInfo('13344462-n', 0), SenseInfo('06761603-n', 0) ],
"_overcook_v_1_rel" : [ SenseInfo('00323571-v', 0), SenseInfo('00323571-v', 0) ],
"_fundamental_n_1_rel" : [ SenseInfo('07328058-n', 0), SenseInfo('05719958-n', 0) ],
"_a+lot_x_rel" : [ SenseInfo('00059171-r', 17) ],
"_busboy_n_1_rel" : [ SenseInfo('09881358-n', 3) ],
"_beam_n_of_rel" : [ SenseInfo('06792645-n', 9), SenseInfo('02815950-n', 9), SenseInfo('11428379-n', 3), SenseInfo('11428023-n', 3), SenseInfo('05136546-n', 0), SenseInfo('02816381-n', 0), SenseInfo('02777292-n', 0) ],
"_trim_v_away_rel" : [ SenseInfo('01262564-v', 8), SenseInfo('01679806-v', 1), SenseInfo('00429060-v', 1), SenseInfo('02752107-v', 0), SenseInfo('02751952-v', 0), SenseInfo('01679433-v', 0), SenseInfo('01321002-v', 0), SenseInfo('01248782-v', 0), SenseInfo('00297193-v', 0) ],
"_patronize_v_1_rel" : [ SenseInfo('02219940-v', 2), SenseInfo('02466134-v', 1), SenseInfo('00908977-v', 1), SenseInfo('00908621-v', 0), SenseInfo('02219940-v', 2), SenseInfo('02466134-v', 1), SenseInfo('00908977-v', 1), SenseInfo('00908621-v', 0) ],
"_czech_n_1_rel" : [ SenseInfo('09699403-n', 0), SenseInfo('09699200-n', 0), SenseInfo('06944911-n', 0), SenseInfo('09699403-n', 0), SenseInfo('09699200-n', 0), SenseInfo('06944911-n', 0), SenseInfo('09699403-n', 0), SenseInfo('09699200-n', 0), SenseInfo('06944911-n', 0) ],
"_the+hell_x_rel" : [ SenseInfo('08582837-n', 6), SenseInfo('07305907-n', 0), SenseInfo('05629682-n', 0), SenseInfo('05629381-n', 0), SenseInfo('01260731-n', 0), SenseInfo('00736786-n', 0) ],
"_rail_n_1_rel" : [ SenseInfo('04047401-n', 5), SenseInfo('04046810-n', 3), SenseInfo('04463679-n', 0), SenseInfo('04046590-n', 0), SenseInfo('02014941-n', 0) ],
"_log_v_out_rel" : [ SenseInfo('01002481-v', 2), SenseInfo('01258828-v', 1), SenseInfo('01002481-v', 2), SenseInfo('01258828-v', 1) ],
"_sprout_v_1_rel" : [ SenseInfo('00357332-v', 4), SenseInfo('00095377-v', 0) ],
"_piss_v_1_rel" : [ SenseInfo('00072012-v', 1) ],
"_botanic_a_1_rel" : [ SenseInfo('02668258-a', 0) ],
"_exhibit_n_1_rel" : [ SenseInfo('06734322-n', 1), SenseInfo('00521209-n', 0), SenseInfo('06734322-n', 1), SenseInfo('00521209-n', 0) ],
"_sculptured_a_1_rel" : [ SenseInfo('00317481-a', 1), SenseInfo('02139884-a', 0) ],
"_jar_v_1_rel" : [ SenseInfo('02667698-v', 1), SenseInfo('01864865-v', 1), SenseInfo('01865051-v', 0), SenseInfo('01769090-v', 0), SenseInfo('01497864-v', 0), SenseInfo('02667698-v', 1), SenseInfo('01864865-v', 1), SenseInfo('01865051-v', 0), SenseInfo('01769090-v', 0), SenseInfo('01497864-v', 0) ],
"_volatile_a_1_rel" : [ SenseInfo('02519555-a', 2), SenseInfo('02292573-a', 0), SenseInfo('00584626-a', 0), SenseInfo('00346847-a', 0) ],
"_retrieve_v_1_rel" : [ SenseInfo('02247977-v', 10), SenseInfo('01433991-v', 0), SenseInfo('01433809-v', 0), SenseInfo('00607780-v', 0) ],
"_reckless_a_of_rel" : [ SenseInfo('00250739-a', 2), SenseInfo('00312757-a', 0), SenseInfo('00250739-a', 2), SenseInfo('00312757-a', 0) ],
"_cherry_n_1_rel" : [ SenseInfo('12641796-n', 0), SenseInfo('12641413-n', 0), SenseInfo('07757132-n', 0), SenseInfo('04964443-n', 0) ],
"_dispassionate_a_1_rel" : [ SenseInfo('01723648-a', 1) ],
"_time_v_1_rel" : [ SenseInfo('00490968-v', 4), SenseInfo('00678547-v', 3), SenseInfo('00702226-v', 1), SenseInfo('00297906-v', 0), SenseInfo('00296973-v', 0) ],
"_graph_n_of_rel" : [ SenseInfo('07000195-n', 15) ],
"_go_v_about_rel" : [ SenseInfo('01835496-v', 343), SenseInfo('02372605-v', 95), SenseInfo('01848718-v', 49), SenseInfo('00149583-v', 29), SenseInfo('02653862-v', 14), SenseInfo('02721284-v', 10), SenseInfo('02685951-v', 10), SenseInfo('00341560-v', 10), SenseInfo('00359916-v', 9), SenseInfo('02618001-v', 7), SenseInfo('02176268-v', 3), SenseInfo('01525666-v', 3), SenseInfo('01192773-v', 3), SenseInfo('00539110-v', 3), SenseInfo('02618149-v', 2), SenseInfo('02617798-v', 2), SenseInfo('00358431-v', 2), SenseInfo('02737876-v', 1), SenseInfo('02729819-v', 1), SenseInfo('01864230-v', 1), SenseInfo('01076615-v', 1), SenseInfo('02700772-v', 0), SenseInfo('02700666-v', 0), SenseInfo('02700455-v', 0), SenseInfo('02686471-v', 0), SenseInfo('02659763-v', 0), SenseInfo('01318849-v', 0), SenseInfo('01192992-v', 0), SenseInfo('00676267-v', 0), SenseInfo('00434374-v', 0) ],
"_racist_a_1_rel" : [ SenseInfo('01928283-a', 0), SenseInfo('00285905-a', 0) ],
"_take_v_in-i_rel" : [ SenseInfo('02599636-v', 92), SenseInfo('02267989-v', 74), SenseInfo('01999798-v', 73), SenseInfo('01214265-v', 50), SenseInfo('00524682-v', 38), SenseInfo('00624476-v', 36), SenseInfo('02077656-v', 32), SenseInfo('02205272-v', 28), SenseInfo('01842690-v', 26), SenseInfo('00674607-v', 26), SenseInfo('02236124-v', 25), SenseInfo('02394183-v', 22), SenseInfo('00734054-v', 22), SenseInfo('02627934-v', 21), SenseInfo('02109045-v', 21), SenseInfo('01002740-v', 16), SenseInfo('00173338-v', 16), SenseInfo('01156834-v', 15), SenseInfo('00669762-v', 15), SenseInfo('02209936-v', 14), SenseInfo('02206619-v', 13), SenseInfo('01982395-v', 10), SenseInfo('02236624-v', 8), SenseInfo('00523095-v', 7), SenseInfo('00599992-v', 6), SenseInfo('00756076-v', 5), SenseInfo('02075857-v', 4), SenseInfo('01151110-v', 4), SenseInfo('00557404-v', 4), SenseInfo('02717102-v', 2), SenseInfo('02208537-v', 2), SenseInfo('02209745-v', 1), SenseInfo('02208118-v', 1), SenseInfo('02201138-v', 1), SenseInfo('01427127-v', 1), SenseInfo('00758333-v', 1), SenseInfo('02741546-v', 0), SenseInfo('02701210-v', 0), SenseInfo('02590253-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01100830-v', 0), SenseInfo('00087736-v', 0) ],
"_ecommerce_n_1_rel" : [  ],
"_have_v_1_rel" : [ SenseInfo('02203362-v', 1202), SenseInfo('02630189-v', 377), SenseInfo('02108026-v', 220), SenseInfo('02204692-v', 143), SenseInfo('00120796-v', 64), SenseInfo('01156834-v', 42), SenseInfo('02378453-v', 31), SenseInfo('01733477-v', 30), SenseInfo('02205098-v', 28), SenseInfo('02740745-v', 25), SenseInfo('00121046-v', 25), SenseInfo('00065370-v', 11), SenseInfo('00770437-v', 8), SenseInfo('02236124-v', 7), SenseInfo('02210119-v', 7), SenseInfo('00065639-v', 5), SenseInfo('02355596-v', 3), SenseInfo('00056930-v', 3), SenseInfo('01427127-v', 2), SenseInfo('02203362-v', 1202), SenseInfo('02630189-v', 377), SenseInfo('02108026-v', 220), SenseInfo('02204692-v', 143), SenseInfo('00120796-v', 64), SenseInfo('01156834-v', 42), SenseInfo('02378453-v', 31), SenseInfo('01733477-v', 30), SenseInfo('02205098-v', 28), SenseInfo('02740745-v', 25), SenseInfo('00121046-v', 25), SenseInfo('00065370-v', 11), SenseInfo('00770437-v', 8), SenseInfo('02236124-v', 7), SenseInfo('02210119-v', 7), SenseInfo('00065639-v', 5), SenseInfo('02355596-v', 3), SenseInfo('00056930-v', 3), SenseInfo('01427127-v', 2), SenseInfo('02203362-v', 1202), SenseInfo('02630189-v', 377), SenseInfo('02108026-v', 220), SenseInfo('02204692-v', 143), SenseInfo('00120796-v', 64), SenseInfo('01156834-v', 42), SenseInfo('02378453-v', 31), SenseInfo('01733477-v', 30), SenseInfo('02205098-v', 28), SenseInfo('02740745-v', 25), SenseInfo('00121046-v', 25), SenseInfo('00065370-v', 11), SenseInfo('00770437-v', 8), SenseInfo('02236124-v', 7), SenseInfo('02210119-v', 7), SenseInfo('00065639-v', 5), SenseInfo('02355596-v', 3), SenseInfo('00056930-v', 3), SenseInfo('01427127-v', 2), SenseInfo('02203362-v', 1202), SenseInfo('02630189-v', 377), SenseInfo('02108026-v', 220), SenseInfo('02204692-v', 143), SenseInfo('00120796-v', 64), SenseInfo('01156834-v', 42), SenseInfo('02378453-v', 31), SenseInfo('01733477-v', 30), SenseInfo('02205098-v', 28), SenseInfo('02740745-v', 25), SenseInfo('00121046-v', 25), SenseInfo('00065370-v', 11), SenseInfo('00770437-v', 8), SenseInfo('02236124-v', 7), SenseInfo('02210119-v', 7), SenseInfo('00065639-v', 5), SenseInfo('02355596-v', 3), SenseInfo('00056930-v', 3), SenseInfo('01427127-v', 2) ],
"_prairie_n_1_rel" : [ SenseInfo('08619524-n', 2) ],
"_twinkling_n_of_rel" : [ SenseInfo('15247110-n', 1) ],
"_teal_n_1_rel" : [ SenseInfo('04968426-n', 0), SenseInfo('01848123-n', 0), SenseInfo('04968426-n', 0), SenseInfo('01848123-n', 0) ],
"_pulpy_a_1_rel" : [ SenseInfo('02576918-a', 0), SenseInfo('02576918-a', 0), SenseInfo('02576918-a', 0) ],
"_ever_a_1_rel" : [  ],
"_swing_v_around_rel" : [ SenseInfo('02087745-v', 35), SenseInfo('01877355-v', 15), SenseInfo('01877620-v', 6), SenseInfo('02537238-v', 4), SenseInfo('01593763-v', 4), SenseInfo('02717472-v', 2), SenseInfo('01152040-v', 2), SenseInfo('00557216-v', 2), SenseInfo('02615140-v', 1), SenseInfo('02752277-v', 0), SenseInfo('02389815-v', 0), SenseInfo('01725375-v', 0), SenseInfo('01427483-v', 0) ],
"_telescope_n_1_rel" : [ SenseInfo('04403638-n', 0) ],
"_cease-fire_n_1_rel" : [ SenseInfo('13970912-n', 0), SenseInfo('13970912-n', 0), SenseInfo('13970912-n', 0) ],
"_bavarian_n_1_rel" : [ SenseInfo('09844457-n', 0) ],
"_piquancy_n_1_rel" : [ SenseInfo('04993108-n', 0), SenseInfo('04720393-n', 0) ],
"_generalize_v_1_rel" : [ SenseInfo('01022420-v', 6), SenseInfo('01022906-v', 0), SenseInfo('00970215-v', 0), SenseInfo('00104465-v', 0), SenseInfo('01022420-v', 6), SenseInfo('01022906-v', 0), SenseInfo('00970215-v', 0), SenseInfo('00104465-v', 0) ],
"_recourse_n_1_rel" : [ SenseInfo('01208597-n', 2), SenseInfo('05155123-n', 0) ],
"_board_v_1_rel" : [ SenseInfo('02018049-v', 5), SenseInfo('02656763-v', 2), SenseInfo('01177118-v', 0), SenseInfo('01176897-v', 0) ],
"_lava_n_1_rel" : [ SenseInfo('14930989-n', 0) ],
"_buff_v_up_rel" : [ SenseInfo('01417578-v', 1), SenseInfo('01246095-v', 0) ],
"_rheumatism_n_1_rel" : [ SenseInfo('14080210-n', 2), SenseInfo('14186738-n', 0) ],
"_conventioner_n_1_rel" : [  ],
"_saber_n_1_rel" : [ SenseInfo('04121511-n', 0), SenseInfo('02987492-n', 0) ],
"_specialize_v_in_rel" : [ SenseInfo('00437449-v', 3), SenseInfo('01021973-v', 2), SenseInfo('00437732-v', 2), SenseInfo('02446164-v', 0), SenseInfo('00119266-v', 0), SenseInfo('00437449-v', 3), SenseInfo('01021973-v', 2), SenseInfo('00437732-v', 2), SenseInfo('02446164-v', 0), SenseInfo('00119266-v', 0) ],
"_preferable_a_for_rel" : [ SenseInfo('00733743-a', 1), SenseInfo('00733743-a', 1), SenseInfo('00733743-a', 1) ],
"_interrogation_n_of_rel" : [ SenseInfo('07196682-n', 1), SenseInfo('07280599-n', 0), SenseInfo('07193958-n', 0), SenseInfo('07193596-n', 0) ],
"_can_v_modal_rel" : [ SenseInfo('00213794-v', 2), SenseInfo('02402825-v', 1), SenseInfo('00213794-v', 2), SenseInfo('02402825-v', 1), SenseInfo('00213794-v', 2), SenseInfo('02402825-v', 1), SenseInfo('00213794-v', 2), SenseInfo('02402825-v', 1), SenseInfo('00213794-v', 2), SenseInfo('02402825-v', 1), SenseInfo('00213794-v', 2), SenseInfo('02402825-v', 1), SenseInfo('00213794-v', 2), SenseInfo('02402825-v', 1), SenseInfo('00213794-v', 2), SenseInfo('02402825-v', 1), SenseInfo('00213794-v', 2), SenseInfo('02402825-v', 1), SenseInfo('00213794-v', 2), SenseInfo('02402825-v', 1), SenseInfo('00213794-v', 2), SenseInfo('02402825-v', 1), SenseInfo('00213794-v', 2), SenseInfo('02402825-v', 1), SenseInfo('00213794-v', 2), SenseInfo('02402825-v', 1), SenseInfo('00213794-v', 2), SenseInfo('02402825-v', 1), SenseInfo('00213794-v', 2), SenseInfo('02402825-v', 1), SenseInfo('00213794-v', 2), SenseInfo('02402825-v', 1), SenseInfo('00213794-v', 2), SenseInfo('02402825-v', 1), SenseInfo('00213794-v', 2), SenseInfo('02402825-v', 1), SenseInfo('00213794-v', 2), SenseInfo('02402825-v', 1) ],
"_yard_n_1_rel" : [ SenseInfo('13650447-n', 34), SenseInfo('04610879-n', 12), SenseInfo('08684294-n', 1), SenseInfo('13750844-n', 0), SenseInfo('13618076-n', 0), SenseInfo('08684676-n', 0), SenseInfo('04611154-n', 0), SenseInfo('04610676-n', 0), SenseInfo('04610503-n', 0) ],
"_canvas_n_1_rel" : [ SenseInfo('02953673-n', 7), SenseInfo('02954068-n', 3), SenseInfo('14513489-n', 1), SenseInfo('02954163-n', 1), SenseInfo('04127904-n', 0), SenseInfo('02953850-n', 0) ],
"_pendulum_n_1_rel" : [ SenseInfo('03909160-n', 1) ],
"_doctrinaire_a_1_rel" : [ SenseInfo('01324271-a', 2) ],
"_underdose_n_1_rel" : [  ],
"_scribe_n_1_rel" : [ SenseInfo('11289999-n', 0), SenseInfo('10564660-n', 0), SenseInfo('09964805-n', 0), SenseInfo('04155457-n', 0) ],
"_mascot_n_1_rel" : [ SenseInfo('10297234-n', 0) ],
"_decrease_n_1_rel" : [ SenseInfo('07355887-n', 5), SenseInfo('13458571-n', 0), SenseInfo('05109808-n', 0), SenseInfo('00351638-n', 0) ],
"_ascent_n_1_rel" : [ SenseInfo('09206985-n', 0), SenseInfo('07445480-n', 0), SenseInfo('00324384-n', 0) ],
"_workstation_n_1_rel" : [ SenseInfo('04603399-n', 0) ],
"_edentate_j_1_rel" : [  ],
"_booklet_n_of_rel" : [ SenseInfo('06413889-n', 0) ],
"_primary_a_1_rel" : [ SenseInfo('01852174-a', 16), SenseInfo('00699521-a', 8), SenseInfo('01277426-a', 7), SenseInfo('01856238-a', 0), SenseInfo('00901060-a', 0), SenseInfo('01852174-a', 16), SenseInfo('00699521-a', 8), SenseInfo('01277426-a', 7), SenseInfo('01856238-a', 0), SenseInfo('00901060-a', 0), SenseInfo('01852174-a', 16), SenseInfo('00699521-a', 8), SenseInfo('01277426-a', 7), SenseInfo('01856238-a', 0), SenseInfo('00901060-a', 0) ],
"_insert_v_into_rel" : [ SenseInfo('01421622-v', 12), SenseInfo('00187526-v', 4), SenseInfo('01389776-v', 3), SenseInfo('01025602-v', 0), SenseInfo('01421622-v', 12), SenseInfo('00187526-v', 4), SenseInfo('01389776-v', 3), SenseInfo('01025602-v', 0) ],
"_ass_n_1_rel" : [ SenseInfo('05559256-n', 3), SenseInfo('09813632-n', 1), SenseInfo('02389346-n', 0), SenseInfo('00846021-n', 0) ],
"_fishery_n_1_rel" : [ SenseInfo('03350880-n', 0) ],
"_planter_n_1_rel" : [ SenseInfo('10438619-n', 7), SenseInfo('10438728-n', 0), SenseInfo('03957315-n', 0) ],
"_attraction_n_of_rel" : [ SenseInfo('11426530-n', 4), SenseInfo('06615561-n', 2), SenseInfo('04688246-n', 2), SenseInfo('05850823-n', 1), SenseInfo('10032676-n', 0) ],
"_about_p_rel" : [ SenseInfo('00007015-r', 55), SenseInfo('00071840-r', 10), SenseInfo('00071165-r', 5), SenseInfo('00072329-r', 3), SenseInfo('00072201-r', 3), SenseInfo('00358114-r', 2), SenseInfo('00073033-r', 1), SenseInfo('00032358-a', 0), SenseInfo('00007015-r', 55), SenseInfo('00071840-r', 10), SenseInfo('00071165-r', 5), SenseInfo('00072329-r', 3), SenseInfo('00072201-r', 3), SenseInfo('00358114-r', 2), SenseInfo('00073033-r', 1), SenseInfo('00032358-a', 0), SenseInfo('00007015-r', 55), SenseInfo('00071840-r', 10), SenseInfo('00071165-r', 5), SenseInfo('00072329-r', 3), SenseInfo('00072201-r', 3), SenseInfo('00358114-r', 2), SenseInfo('00073033-r', 1), SenseInfo('00032358-a', 0), SenseInfo('00007015-r', 55), SenseInfo('00071840-r', 10), SenseInfo('00071165-r', 5), SenseInfo('00072329-r', 3), SenseInfo('00072201-r', 3), SenseInfo('00358114-r', 2), SenseInfo('00073033-r', 1), SenseInfo('00032358-a', 0), SenseInfo('00007015-r', 55), SenseInfo('00071840-r', 10), SenseInfo('00071165-r', 5), SenseInfo('00072329-r', 3), SenseInfo('00072201-r', 3), SenseInfo('00358114-r', 2), SenseInfo('00073033-r', 1), SenseInfo('00032358-a', 0) ],
"_bivouac_v_1_rel" : [ SenseInfo('02653996-v', 0) ],
"_distributor_n_of_rel" : [ SenseInfo('10018861-n', 6), SenseInfo('09784707-n', 0), SenseInfo('08061905-n', 0), SenseInfo('03213014-n', 0) ],
"_unnatural_a_1_rel" : [ SenseInfo('01570470-a', 4), SenseInfo('01595596-a', 0), SenseInfo('00073048-a', 0), SenseInfo('01570470-a', 4), SenseInfo('01595596-a', 0), SenseInfo('00073048-a', 0) ],
"_bull_n_1_rel" : [ SenseInfo('02403325-n', 2), SenseInfo('09878702-n', 1), SenseInfo('06611376-n', 1), SenseInfo('00075790-n', 1), SenseInfo('09879144-n', 0), SenseInfo('09878921-n', 0), SenseInfo('09752381-n', 0), SenseInfo('08686332-n', 0), SenseInfo('08517449-n', 0), SenseInfo('06726761-n', 0), SenseInfo('01887623-n', 0) ],
"_debug_v_cause_rel" : [ SenseInfo('00200242-v', 0) ],
"_plunge_v_1_rel" : [ SenseInfo('01577635-v', 6), SenseInfo('01967373-v', 4), SenseInfo('01834053-v', 4), SenseInfo('00347918-v', 4), SenseInfo('00601378-v', 1), SenseInfo('01977080-v', 0), SenseInfo('01577093-v', 0), SenseInfo('00601043-v', 0) ],
"_specious_a_1_rel" : [ SenseInfo('02462210-a', 0), SenseInfo('02182302-a', 0) ],
"_alter-ego_n_1_rel" : [ SenseInfo('09785992-n', 1), SenseInfo('09785992-n', 1) ],
"_longing_n_1_rel" : [ SenseInfo('07486628-n', 4) ],
"_infix_n_1_rel" : [ SenseInfo('06309272-n', 0) ],
"_eco-labeling_n_1_rel" : [  ],
"_activity_n_1_rel" : [ SenseInfo('00407535-n', 43), SenseInfo('14006945-n', 36), SenseInfo('13440063-n', 13), SenseInfo('14531203-n', 0), SenseInfo('13518963-n', 0), SenseInfo('04635104-n', 0) ],
"_focus_v_on_rel" : [ SenseInfo('00722232-v', 6), SenseInfo('02161922-v', 4), SenseInfo('00731789-v', 1), SenseInfo('00314782-v', 0), SenseInfo('00314272-v', 0), SenseInfo('00722232-v', 6), SenseInfo('02161922-v', 4), SenseInfo('00731789-v', 1), SenseInfo('00314782-v', 0), SenseInfo('00314272-v', 0) ],
"_ace_n_1_rel" : [ SenseInfo('13742573-n', 10), SenseInfo('02673291-n', 3), SenseInfo('09762509-n', 2), SenseInfo('14735642-n', 0), SenseInfo('08175498-n', 0), SenseInfo('00568701-n', 0) ],
"_snap_v_in_rel" : [ SenseInfo('00916274-v', 7), SenseInfo('01573515-v', 3), SenseInfo('00337065-v', 3), SenseInfo('01893771-v', 2), SenseInfo('00355670-v', 2), SenseInfo('02182851-v', 1), SenseInfo('02088949-v', 1), SenseInfo('01439745-v', 1), SenseInfo('01402872-v', 1), SenseInfo('01242208-v', 1), SenseInfo('01784295-v', 0), SenseInfo('01446301-v', 0), SenseInfo('01003249-v', 0), SenseInfo('00916274-v', 7), SenseInfo('01573515-v', 3), SenseInfo('00337065-v', 3), SenseInfo('01893771-v', 2), SenseInfo('00355670-v', 2), SenseInfo('02182851-v', 1), SenseInfo('02088949-v', 1), SenseInfo('01439745-v', 1), SenseInfo('01402872-v', 1), SenseInfo('01242208-v', 1), SenseInfo('01784295-v', 0), SenseInfo('01446301-v', 0), SenseInfo('01003249-v', 0) ],
"_toll_n_1_rel" : [ SenseInfo('13323749-n', 1), SenseInfo('05163807-n', 1), SenseInfo('07377244-n', 0) ],
"_alley_n_1_rel" : [ SenseInfo('02697759-n', 1), SenseInfo('02882014-n', 0) ],
"_small_a_1_rel" : [ SenseInfo('01391351-a', 213), SenseInfo('01415219-a', 13), SenseInfo('01649031-a', 8), SenseInfo('01554940-a', 2), SenseInfo('02340458-a', 1), SenseInfo('01467534-a', 1), SenseInfo('01455732-a', 1), SenseInfo('02233680-a', 0), SenseInfo('01532912-a', 0), SenseInfo('00882580-a', 0), SenseInfo('01391351-a', 213), SenseInfo('01415219-a', 13), SenseInfo('01649031-a', 8), SenseInfo('01554940-a', 2), SenseInfo('02340458-a', 1), SenseInfo('01467534-a', 1), SenseInfo('01455732-a', 1), SenseInfo('02233680-a', 0), SenseInfo('01532912-a', 0), SenseInfo('00882580-a', 0), SenseInfo('01391351-a', 213), SenseInfo('01415219-a', 13), SenseInfo('01649031-a', 8), SenseInfo('01554940-a', 2), SenseInfo('02340458-a', 1), SenseInfo('01467534-a', 1), SenseInfo('01455732-a', 1), SenseInfo('02233680-a', 0), SenseInfo('01532912-a', 0), SenseInfo('00882580-a', 0) ],
"_wall_v_in_rel" : [ SenseInfo('01130607-v', 0) ],
"_skimp_v_1_rel" : [ SenseInfo('02516437-v', 0), SenseInfo('02509820-v', 0), SenseInfo('02345498-v', 0), SenseInfo('02225739-v', 0) ],
"_worried_a_about_rel" : [ SenseInfo('02457167-a', 7), SenseInfo('00822907-a', 0), SenseInfo('02457167-a', 7), SenseInfo('00822907-a', 0) ],
"_potentiality_n_1_rel" : [ SenseInfo('14482620-n', 3), SenseInfo('05623181-n', 2) ],
"_an+additional_q_rel" : [  ],
"_screw_v_up_rel" : [ SenseInfo('01426397-v', 0), SenseInfo('01353169-v', 0), SenseInfo('01352996-v', 0), SenseInfo('01352806-v', 0), SenseInfo('01104624-v', 0), SenseInfo('01426397-v', 0), SenseInfo('01353169-v', 0), SenseInfo('01352996-v', 0), SenseInfo('01352806-v', 0), SenseInfo('01104624-v', 0) ],
"_at+will_a_1_rel" : [  ],
"_media_n_1_rel" : [ SenseInfo('06254669-n', 5), SenseInfo('08568142-n', 4), SenseInfo('06254475-n', 2), SenseInfo('14899328-n', 1), SenseInfo('14899888-n', 0), SenseInfo('14899530-n', 0), SenseInfo('14899152-n', 0), SenseInfo('13920169-n', 0), SenseInfo('10306279-n', 0), SenseInfo('06261586-n', 0), SenseInfo('00610222-n', 0) ],
"_kite_v_1_rel" : [ SenseInfo('02206313-v', 0), SenseInfo('02206140-v', 0), SenseInfo('01942560-v', 0), SenseInfo('01848190-v', 0) ],
"_ideology_n_1_rel" : [ SenseInfo('06212839-n', 4), SenseInfo('05779568-n', 1) ],
"_primitive_a_1_rel" : [ SenseInfo('00818175-a', 8), SenseInfo('00817731-a', 2), SenseInfo('00413432-a', 1), SenseInfo('01912858-a', 0) ],
"_continuance_n_1_rel" : [ SenseInfo('01017987-n', 2), SenseInfo('15133621-n', 0), SenseInfo('15133488-n', 0) ],
"_in+particular_x_deg_rel" : [ SenseInfo('00248765-r', 9) ],
"_courtesy_n_1_rel" : [ SenseInfo('01228245-n', 2), SenseInfo('06714874-n', 0), SenseInfo('04912732-n', 0) ],
"_hardworking_a_1_rel" : [ SenseInfo('00754682-a', 1) ],
"_deletion_n_of_rel" : [ SenseInfo('13524399-n', 0), SenseInfo('07425577-n', 0), SenseInfo('06428216-n', 0), SenseInfo('00394610-n', 0) ],
"_curly_a_1_rel" : [ SenseInfo('01030022-a', 2), SenseInfo('01030022-a', 2), SenseInfo('01030022-a', 2) ],
"_parser_n_1_rel" : [ SenseInfo('06577369-n', 0) ],
"_noncapital_a_1_rel" : [  ],
"_unbeatable_a_1_rel" : [ SenseInfo('02288252-a', 0), SenseInfo('00570322-a', 0), SenseInfo('02288252-a', 0), SenseInfo('00570322-a', 0) ],
"_winter_v_1_rel" : [ SenseInfo('02709573-v', 2) ],
"_temptation_n_1_rel" : [ SenseInfo('05694791-n', 8), SenseInfo('07485281-n', 0), SenseInfo('00159620-n', 0), SenseInfo('05694791-n', 8), SenseInfo('07485281-n', 0), SenseInfo('00159620-n', 0), SenseInfo('05694791-n', 8), SenseInfo('07485281-n', 0), SenseInfo('00159620-n', 0) ],
"_plebeian_a_1_rel" : [ SenseInfo('01593079-a', 0) ],
"_wilt_v_1_rel" : [ SenseInfo('00469794-v', 1), SenseInfo('00469637-v', 0) ],
"_whale_n_1_rel" : [ SenseInfo('10129133-n', 1), SenseInfo('02062744-n', 0) ],
"_beat_v_to_rel" : [ SenseInfo('01101913-v', 18), SenseInfo('01397210-v', 9), SenseInfo('01398919-v', 8), SenseInfo('01880113-v', 4), SenseInfo('01624897-v', 3), SenseInfo('02174830-v', 2), SenseInfo('02162815-v', 1), SenseInfo('02093610-v', 1), SenseInfo('01945938-v', 1), SenseInfo('01418179-v', 1), SenseInfo('01399576-v', 1), SenseInfo('02746140-v', 0), SenseInfo('02573853-v', 0), SenseInfo('02175578-v', 0), SenseInfo('02093390-v', 0), SenseInfo('01880673-v', 0), SenseInfo('01879579-v', 0), SenseInfo('01756006-v', 0), SenseInfo('01726879-v', 0), SenseInfo('01399450-v', 0), SenseInfo('01104852-v', 0), SenseInfo('00622384-v', 0), SenseInfo('00075421-v', 0), SenseInfo('01101913-v', 18), SenseInfo('01397210-v', 9), SenseInfo('01398919-v', 8), SenseInfo('01880113-v', 4), SenseInfo('01624897-v', 3), SenseInfo('02174830-v', 2), SenseInfo('02162815-v', 1), SenseInfo('02093610-v', 1), SenseInfo('01945938-v', 1), SenseInfo('01418179-v', 1), SenseInfo('01399576-v', 1), SenseInfo('02746140-v', 0), SenseInfo('02573853-v', 0), SenseInfo('02175578-v', 0), SenseInfo('02093390-v', 0), SenseInfo('01880673-v', 0), SenseInfo('01879579-v', 0), SenseInfo('01756006-v', 0), SenseInfo('01726879-v', 0), SenseInfo('01399450-v', 0), SenseInfo('01104852-v', 0), SenseInfo('00622384-v', 0), SenseInfo('00075421-v', 0) ],
"_if+only_x_rel" : [  ],
"_utensil_n_1_rel" : [ SenseInfo('04516672-n', 2) ],
"_might_n_1_rel" : [ SenseInfo('05030680-n', 3) ],
"_worsen_v_cause_rel" : [ SenseInfo('00203866-v', 1), SenseInfo('00208210-v', 0) ],
"_fancy_v_1_rel" : [ SenseInfo('01635432-v', 3), SenseInfo('01776468-v', 1), SenseInfo('01635432-v', 3), SenseInfo('01776468-v', 1), SenseInfo('01635432-v', 3), SenseInfo('01776468-v', 1), SenseInfo('01635432-v', 3), SenseInfo('01776468-v', 1), SenseInfo('01635432-v', 3), SenseInfo('01776468-v', 1) ],
"_civil_a_1_rel" : [ SenseInfo('01518161-a', 7), SenseInfo('00642379-a', 1), SenseInfo('02697116-a', 0), SenseInfo('02696920-a', 0), SenseInfo('00642934-a', 0), SenseInfo('00412355-a', 0) ],
"_purify_v_of_rel" : [ SenseInfo('00475183-v', 2), SenseInfo('00475819-v', 1), SenseInfo('00476133-v', 0) ],
"_perfect_v_1_rel" : [ SenseInfo('00473572-v', 4) ],
"_specifics_n_of_rel" : [ SenseInfo('05818182-n', 0), SenseInfo('04271640-n', 0) ],
"_auditorium_n_1_rel" : [ SenseInfo('02758134-n', 3), SenseInfo('02758134-n', 3) ],
"_as+far+as_x_rel" : [  ],
"_interstate_n_1_rel" : [ SenseInfo('03581354-n', 0) ],
"_few_a_1_rel" : [ SenseInfo('01552885-a', 80), SenseInfo('01552885-a', 80) ],
"_passe_a_1_rel" : [ SenseInfo('00974159-a', 0) ],
"_run_v_out_rel" : [ SenseInfo('01926311-v', 106), SenseInfo('02075049-v', 38), SenseInfo('02685951-v', 21), SenseInfo('02443849-v', 20), SenseInfo('02721284-v', 10), SenseInfo('02066939-v', 9), SenseInfo('01525666-v', 8), SenseInfo('02727039-v', 7), SenseInfo('01094086-v', 7), SenseInfo('01717169-v', 5), SenseInfo('02099829-v', 4), SenseInfo('02719399-v', 3), SenseInfo('01526290-v', 3), SenseInfo('00549063-v', 3), SenseInfo('00517529-v', 3), SenseInfo('02720904-v', 2), SenseInfo('02647497-v', 2), SenseInfo('02612234-v', 2), SenseInfo('02563327-v', 2), SenseInfo('01746359-v', 2), SenseInfo('01641545-v', 2), SenseInfo('01212230-v', 2), SenseInfo('02686625-v', 1), SenseInfo('02525312-v', 1), SenseInfo('02242256-v', 1), SenseInfo('02092309-v', 1), SenseInfo('02060792-v', 1), SenseInfo('01927903-v', 1), SenseInfo('01914947-v', 1), SenseInfo('02648110-v', 0), SenseInfo('02421921-v', 0), SenseInfo('01927747-v', 0), SenseInfo('01927447-v', 0), SenseInfo('01926984-v', 0), SenseInfo('01864038-v', 0), SenseInfo('01143838-v', 0), SenseInfo('01086103-v', 0), SenseInfo('00539110-v', 0), SenseInfo('00444629-v', 0), SenseInfo('00334803-v', 0), SenseInfo('00332672-v', 0) ],
"_wean_v_1_rel" : [ SenseInfo('01186958-v', 1), SenseInfo('01824253-v', 0) ],
"_in+back+of_p_rel" : [  ],
"_expire_v_1_rel" : [ SenseInfo('02684784-v', 3), SenseInfo('00358431-v', 2), SenseInfo('00004227-v', 0), SenseInfo('02684784-v', 3), SenseInfo('00358431-v', 2), SenseInfo('00004227-v', 0) ],
"_this_x_deg_rel" : [  ],
"_process_v_1_rel" : [ SenseInfo('00515154-v', 2), SenseInfo('02438535-v', 1), SenseInfo('00638837-v', 1), SenseInfo('02582042-v', 0), SenseInfo('01996735-v', 0), SenseInfo('01668603-v', 0), SenseInfo('01438681-v', 0) ],
"_striking_a_1_rel" : [ SenseInfo('01284212-a', 14), SenseInfo('00580805-a', 0) ],
"_substitution_n_of_rel" : [ SenseInfo('07443761-n', 1), SenseInfo('00196485-n', 0) ],
"_thud_n_1_rel" : [ SenseInfo('07396945-n', 1) ],
"_inboard+of_p_rel" : [  ],
"_engineer_n_1_rel" : [ SenseInfo('09615807-n', 13), SenseInfo('10057714-n', 0) ],
"_stud_v_with_rel" : [ SenseInfo('02689882-v', 3), SenseInfo('01358023-v', 0) ],
"_barbecue_v_1_rel" : [ SenseInfo('00324806-v', 2) ],
"_expression_n_of_rel" : [ SenseInfo('04679738-n', 23), SenseInfo('06880249-n', 18), SenseInfo('07139873-n', 15), SenseInfo('07151380-n', 5), SenseInfo('07069948-n', 4), SenseInfo('06731802-n', 4), SenseInfo('13478205-n', 0), SenseInfo('06313651-n', 0), SenseInfo('00358528-n', 0) ],
"_reversal_n_of_rel" : [ SenseInfo('00234892-n', 1), SenseInfo('07475870-n', 0), SenseInfo('07411160-n', 0), SenseInfo('05789808-n', 0), SenseInfo('01185981-n', 0), SenseInfo('00346693-n', 0), SenseInfo('00339776-n', 0), SenseInfo('00163406-n', 0) ],
"_wind_v_down_rel" : [ SenseInfo('01882814-v', 3), SenseInfo('02738701-v', 2), SenseInfo('01522276-v', 2), SenseInfo('02125223-v', 0), SenseInfo('01522052-v', 0), SenseInfo('01516965-v', 0), SenseInfo('01455184-v', 0), SenseInfo('01882814-v', 3), SenseInfo('02738701-v', 2), SenseInfo('01522276-v', 2), SenseInfo('02125223-v', 0), SenseInfo('01522052-v', 0), SenseInfo('01516965-v', 0), SenseInfo('01455184-v', 0) ],
"_memorable_a_1_rel" : [ SenseInfo('01040752-a', 6) ],
"_reinforcement_n_1_rel" : [ SenseInfo('00971463-n', 4), SenseInfo('06650238-n', 0), SenseInfo('05828552-n', 0), SenseInfo('04336034-n', 0), SenseInfo('01219551-n', 0) ],
"_gross_a_1_rel" : [ SenseInfo('01582821-a', 8), SenseInfo('01102308-a', 1), SenseInfo('00987974-a', 1), SenseInfo('02516435-a', 0), SenseInfo('01520091-a', 0), SenseInfo('00683531-a', 0), SenseInfo('00580039-a', 0), SenseInfo('01582821-a', 8), SenseInfo('01102308-a', 1), SenseInfo('00987974-a', 1), SenseInfo('02516435-a', 0), SenseInfo('01520091-a', 0), SenseInfo('00683531-a', 0), SenseInfo('00580039-a', 0), SenseInfo('01582821-a', 8), SenseInfo('01102308-a', 1), SenseInfo('00987974-a', 1), SenseInfo('02516435-a', 0), SenseInfo('01520091-a', 0), SenseInfo('00683531-a', 0), SenseInfo('00580039-a', 0) ],
"_qmark_a_1_rel" : [  ],
"_creed_n_1_rel" : [ SenseInfo('05959954-n', 2), SenseInfo('06789411-n', 1) ],
"_abate_v_1_rel" : [ SenseInfo('00245289-v', 0), SenseInfo('00245059-v', 0) ],
"_noun_n_1_rel" : [ SenseInfo('06319293-n', 1), SenseInfo('06317862-n', 1), SenseInfo('06319293-n', 1), SenseInfo('06317862-n', 1) ],
"_solo_a_1_rel" : [ SenseInfo('02252480-a', 0) ],
"_tense_a_1_rel" : [ SenseInfo('02405326-a', 0), SenseInfo('02404868-a', 0), SenseInfo('02403206-a', 0), SenseInfo('02405326-a', 0), SenseInfo('02404868-a', 0), SenseInfo('02403206-a', 0), SenseInfo('02405326-a', 0), SenseInfo('02404868-a', 0), SenseInfo('02403206-a', 0), SenseInfo('02405326-a', 0), SenseInfo('02404868-a', 0), SenseInfo('02403206-a', 0) ],
"_round_v_out_rel" : [ SenseInfo('01858910-v', 3), SenseInfo('00145147-v', 1), SenseInfo('00980339-v', 0), SenseInfo('00862683-v', 0), SenseInfo('00473799-v', 0), SenseInfo('00145623-v', 0), SenseInfo('00046382-v', 0) ],
"_mindful_a_of_rel" : [ SenseInfo('01977155-a', 3) ],
"_pair_v_1_rel" : [ SenseInfo('02490430-v', 3), SenseInfo('01292885-v', 2), SenseInfo('01465365-v', 0), SenseInfo('01465218-v', 0), SenseInfo('01428853-v', 0), SenseInfo('02490430-v', 3), SenseInfo('01292885-v', 2), SenseInfo('01465365-v', 0), SenseInfo('01465218-v', 0), SenseInfo('01428853-v', 0) ],
"_authenticity_n_1_rel" : [ SenseInfo('04783247-n', 7) ],
"_reindeer_n_1_rel" : [ SenseInfo('02433925-n', 0) ],
"_suspense_n_1_rel" : [ SenseInfo('07522632-n', 2), SenseInfo('05699770-n', 2), SenseInfo('07511238-n', 0) ],
"_salty_a_1_rel" : [ SenseInfo('02306874-a', 1), SenseInfo('01073822-a', 0), SenseInfo('02398773-a', 0), SenseInfo('02306874-a', 1), SenseInfo('01073822-a', 0), SenseInfo('02398773-a', 0), SenseInfo('02306874-a', 1), SenseInfo('01073822-a', 0), SenseInfo('02398773-a', 0) ],
"_square_n_of_rel" : [ SenseInfo('13878634-n', 23), SenseInfo('13731021-n', 2), SenseInfo('08619620-n', 2), SenseInfo('13878951-n', 0), SenseInfo('10642988-n', 0), SenseInfo('10642845-n', 0), SenseInfo('04291511-n', 0), SenseInfo('04291242-n', 0), SenseInfo('13878634-n', 23), SenseInfo('13731021-n', 2), SenseInfo('08619620-n', 2), SenseInfo('13878951-n', 0), SenseInfo('10642988-n', 0), SenseInfo('10642845-n', 0), SenseInfo('04291511-n', 0), SenseInfo('04291242-n', 0), SenseInfo('13878634-n', 23), SenseInfo('13731021-n', 2), SenseInfo('08619620-n', 2), SenseInfo('13878951-n', 0), SenseInfo('10642988-n', 0), SenseInfo('10642845-n', 0), SenseInfo('04291511-n', 0), SenseInfo('04291242-n', 0) ],
"_accountable_a_1_rel" : [ SenseInfo('01996875-a', 0) ],
"_treble_n_1_rel" : [ SenseInfo('04985930-n', 0) ],
"_cotton_v_1_rel" : [ SenseInfo('01777107-v', 0) ],
"_queen_n_of_rel" : [ SenseInfo('02313008-n', 16), SenseInfo('10499355-n', 4), SenseInfo('10499857-n', 1), SenseInfo('10500217-n', 0), SenseInfo('10235024-n', 0), SenseInfo('10076033-n', 0), SenseInfo('04033425-n', 0), SenseInfo('04033287-n', 0), SenseInfo('02369935-n', 0), SenseInfo('02122878-n', 0), SenseInfo('02313008-n', 16), SenseInfo('10499355-n', 4), SenseInfo('10499857-n', 1), SenseInfo('10500217-n', 0), SenseInfo('10235024-n', 0), SenseInfo('10076033-n', 0), SenseInfo('04033425-n', 0), SenseInfo('04033287-n', 0), SenseInfo('02369935-n', 0), SenseInfo('02122878-n', 0) ],
"_input_n_to_rel" : [ SenseInfo('07264820-n', 3), SenseInfo('06765044-n', 0), SenseInfo('05827684-n', 0), SenseInfo('03573154-n', 0), SenseInfo('07264820-n', 3), SenseInfo('06765044-n', 0), SenseInfo('05827684-n', 0), SenseInfo('03573154-n', 0) ],
"_mess_v_around-with_rel" : [ SenseInfo('01176079-v', 0), SenseInfo('00276214-v', 0) ],
"_stand_v_in-for_rel" : [ SenseInfo('01546111-v', 169), SenseInfo('02611373-v', 53), SenseInfo('02734488-v', 38), SenseInfo('02702120-v', 18), SenseInfo('00668099-v', 9), SenseInfo('00670991-v', 8), SenseInfo('02707125-v', 5), SenseInfo('02703018-v', 3), SenseInfo('02702368-v', 2), SenseInfo('01546768-v', 1), SenseInfo('01115916-v', 1), SenseInfo('01428203-v', 0) ],
"_stringy_a_1_rel" : [ SenseInfo('00991584-a', 1), SenseInfo('02446239-a', 0), SenseInfo('02416765-a', 0), SenseInfo('00626701-a', 0), SenseInfo('00991584-a', 1), SenseInfo('02446239-a', 0), SenseInfo('02416765-a', 0), SenseInfo('00626701-a', 0), SenseInfo('00991584-a', 1), SenseInfo('02446239-a', 0), SenseInfo('02416765-a', 0), SenseInfo('00626701-a', 0) ],
"_pilgrimage_n_1_rel" : [ SenseInfo('00311687-n', 2) ],
"_retrovision_n_1_rel" : [ SenseInfo('05775919-n', 1) ],
"_inbox_n_1_rel" : [  ],
"_epistle_n_1_rel" : [ SenseInfo('06626183-n', 0), SenseInfo('06442616-n', 0) ],
"_summer_v_1_rel" : [ SenseInfo('02709774-v', 0) ],
"_disconcert_v_1_rel" : [ SenseInfo('01790739-v', 0), SenseInfo('01790020-v', 0), SenseInfo('01790739-v', 0), SenseInfo('01790020-v', 0), SenseInfo('01790739-v', 0), SenseInfo('01790020-v', 0), SenseInfo('01790739-v', 0), SenseInfo('01790020-v', 0), SenseInfo('01790739-v', 0), SenseInfo('01790020-v', 0) ],
"_thrust_n_1_rel" : [ SenseInfo('11498203-n', 2), SenseInfo('01173965-n', 1), SenseInfo('00103834-n', 1), SenseInfo('06711404-n', 0), SenseInfo('00334935-n', 0) ],
"_overgrowing_n_1_rel" : [  ],
"_removal_n_of_rel" : [ SenseInfo('00391599-n', 9), SenseInfo('00216723-n', 0) ],
"_proposition_n_1_rel" : [ SenseInfo('06750804-n', 6), SenseInfo('07162680-n', 2), SenseInfo('07161912-n', 0), SenseInfo('07161429-n', 0), SenseInfo('00797581-n', 0), SenseInfo('06750804-n', 6), SenseInfo('07162680-n', 2), SenseInfo('07161912-n', 0), SenseInfo('07161429-n', 0), SenseInfo('00797581-n', 0) ],
"_bluebonnet_n_1_rel" : [ SenseInfo('12547215-n', 0), SenseInfo('02783567-n', 0) ],
"_semiotic_a_1_rel" : [ SenseInfo('02796042-a', 0) ],
"_congeal_v_1_rel" : [ SenseInfo('00442669-v', 2) ],
"_level_a_1_rel" : [ SenseInfo('00910101-a', 3), SenseInfo('02302537-a', 1), SenseInfo('01233104-a', 1), SenseInfo('00911091-a', 1), SenseInfo('00892243-a', 0) ],
"_mate_v_cause_rel" : [ SenseInfo('01428853-v', 7), SenseInfo('01292885-v', 1), SenseInfo('01114475-v', 0) ],
"_qualifier_n_1_rel" : [ SenseInfo('10498196-n', 0), SenseInfo('06320801-n', 0) ],
"_marxist_a_1_rel" : [ SenseInfo('02875282-a', 2) ],
"_perturbation_n_1_rel" : [ SenseInfo('14403282-n', 2), SenseInfo('11414874-n', 0), SenseInfo('07428450-n', 0), SenseInfo('04904996-n', 0), SenseInfo('00553173-n', 0) ],
"_manufacture_v_1_rel" : [ SenseInfo('01653442-v', 3), SenseInfo('01634424-v', 1), SenseInfo('01758882-v', 0), SenseInfo('01758696-v', 0) ],
"_jet_n_1_rel" : [ SenseInfo('03595860-n', 2), SenseInfo('07436100-n', 1), SenseInfo('14925378-n', 0), SenseInfo('11475067-n', 0), SenseInfo('03606572-n', 0), SenseInfo('03387926-n', 0) ],
"_lighten_v_1_rel" : [ SenseInfo('01814074-v', 1), SenseInfo('01487573-v', 0), SenseInfo('00860136-v', 0), SenseInfo('00312815-v', 0), SenseInfo('00280930-v', 0), SenseInfo('00199067-v', 0) ],
"_drive_v_out_rel" : [ SenseInfo('01930874-v', 56), SenseInfo('01930117-v', 24), SenseInfo('02056971-v', 13), SenseInfo('01516534-v', 13), SenseInfo('02505358-v', 6), SenseInfo('01506157-v', 5), SenseInfo('01646300-v', 4), SenseInfo('01512259-v', 2), SenseInfo('01509584-v', 2), SenseInfo('02406916-v', 1), SenseInfo('01026975-v', 1), SenseInfo('02742232-v', 0), SenseInfo('02408281-v', 0), SenseInfo('02057656-v', 0), SenseInfo('01939553-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01407904-v', 0), SenseInfo('01407722-v', 0), SenseInfo('01310964-v', 0), SenseInfo('01181741-v', 0), SenseInfo('01142636-v', 0), SenseInfo('01142490-v', 0) ],
"_opening_n_1_rel" : [ SenseInfo('09379111-n', 5), SenseInfo('07452699-n', 2), SenseInfo('00383390-n', 2), SenseInfo('07329363-n', 1), SenseInfo('00338641-n', 1), SenseInfo('14485249-n', 0), SenseInfo('06397476-n', 0), SenseInfo('05792010-n', 0), SenseInfo('05249636-n', 0), SenseInfo('03848729-n', 0), SenseInfo('03499142-n', 0), SenseInfo('00457890-n', 0), SenseInfo('00239230-n', 0) ],
"_swell_v_up_rel" : [ SenseInfo('00555084-v', 5), SenseInfo('02596908-v', 4), SenseInfo('00256507-v', 4), SenseInfo('02626405-v', 1), SenseInfo('01991204-v', 1), SenseInfo('00257650-v', 0) ],
"_consist_v_of_rel" : [ SenseInfo('02653381-v', 4), SenseInfo('02750854-v', 0), SenseInfo('02658050-v', 0), SenseInfo('02633356-v', 0) ],
"_emptiness_n_1_rel" : [ SenseInfo('14455206-n', 1), SenseInfo('14039974-n', 0), SenseInfo('13910116-n', 0), SenseInfo('05141040-n', 0) ],
"_to+no+avail_a_1_rel" : [  ],
"_rendezvous_v_1_rel" : [ SenseInfo('02487226-v', 0) ],
"_panorama_n_1_rel" : [ SenseInfo('05933246-n', 0), SenseInfo('03884072-n', 0) ],
"_spike_v_1_rel" : [ SenseInfo('02558090-v', 0), SenseInfo('01444326-v', 0), SenseInfo('01306175-v', 0), SenseInfo('00294718-v', 0), SenseInfo('00222135-v', 0), SenseInfo('00157219-v', 0) ],
"_doze_n_1_rel" : [ SenseInfo('00858849-n', 0) ],
"_nose_v_1_rel" : [ SenseInfo('02169119-v', 1), SenseInfo('01994128-v', 1), SenseInfo('02125223-v', 0), SenseInfo('01873051-v', 0), SenseInfo('01424350-v', 0), SenseInfo('01109644-v', 0) ],
"_unsolicited_a_1_rel" : [ SenseInfo('01965512-a', 0), SenseInfo('01965512-a', 0) ],
"_start_v_over_rel" : [ SenseInfo('00345761-v', 159), SenseInfo('00348746-v', 45), SenseInfo('02014165-v', 29), SenseInfo('02608347-v', 17), SenseInfo('01628449-v', 16), SenseInfo('01650610-v', 11), SenseInfo('01910373-v', 7), SenseInfo('01857717-v', 7), SenseInfo('01864230-v', 5), SenseInfo('02379528-v', 2), SenseInfo('01075164-v', 1), SenseInfo('02608823-v', 0), SenseInfo('02600948-v', 0), SenseInfo('02081946-v', 0), SenseInfo('00345761-v', 159), SenseInfo('00348746-v', 45), SenseInfo('02014165-v', 29), SenseInfo('02608347-v', 17), SenseInfo('01628449-v', 16), SenseInfo('01650610-v', 11), SenseInfo('01910373-v', 7), SenseInfo('01857717-v', 7), SenseInfo('01864230-v', 5), SenseInfo('02379528-v', 2), SenseInfo('01075164-v', 1), SenseInfo('02608823-v', 0), SenseInfo('02600948-v', 0), SenseInfo('02081946-v', 0) ],
"_oven_n_1_rel" : [ SenseInfo('03862676-n', 1) ],
"_divorce_n_1_rel" : [ SenseInfo('01201271-n', 8) ],
"_jewelry_n_1_rel" : [ SenseInfo('03597469-n', 0) ],
"_surplus_n_of_rel" : [ SenseInfo('05119714-n', 8) ],
"_wheelbarrow_n_1_rel" : [ SenseInfo('02797295-n', 0) ],
"_attic_n_1_rel" : [ SenseInfo('03686130-n', 2), SenseInfo('06977610-n', 0), SenseInfo('05539454-n', 0), SenseInfo('02755823-n', 0) ],
"_punish_v_1_rel" : [ SenseInfo('02499629-v', 10), SenseInfo('02499629-v', 10) ],
"_schmuck_n_1_rel" : [ SenseInfo('10557404-n', 0) ],
"_feel_v_seem-about_rel" : [ SenseInfo('01771535-v', 181), SenseInfo('00715239-v', 150), SenseInfo('02106006-v', 66), SenseInfo('00105958-v', 39), SenseInfo('00690305-v', 37), SenseInfo('02110552-v', 34), SenseInfo('02730471-v', 14), SenseInfo('02127613-v', 5), SenseInfo('01209678-v', 4), SenseInfo('01210352-v', 3), SenseInfo('02286027-v', 1), SenseInfo('02134350-v', 0), SenseInfo('01210152-v', 0) ],
"_smooth_v_out_rel" : [ SenseInfo('01252971-v', 7), SenseInfo('01245637-v', 1), SenseInfo('02313098-v', 0), SenseInfo('01252971-v', 7), SenseInfo('01245637-v', 1), SenseInfo('02313098-v', 0) ],
"_gee-string_n_1_rel" : [  ],
"_billet_v_cause_rel" : [ SenseInfo('02653159-v', 0) ],
"_flexible_a_1_rel" : [ SenseInfo('01024073-a', 2), SenseInfo('01022064-a', 2), SenseInfo('01028163-a', 1), SenseInfo('00844719-a', 1), SenseInfo('01026262-a', 0), SenseInfo('01024073-a', 2), SenseInfo('01022064-a', 2), SenseInfo('01028163-a', 1), SenseInfo('00844719-a', 1), SenseInfo('01026262-a', 0) ],
"_unproblematical_a_1_rel" : [  ],
"_illumination_n_of_rel" : [ SenseInfo('14563784-n', 2), SenseInfo('13983147-n', 1), SenseInfo('07171206-n', 0), SenseInfo('05018542-n', 0), SenseInfo('03769397-n', 0) ],
"_blend_n_1_rel" : [ SenseInfo('07375405-n', 2), SenseInfo('06288527-n', 0), SenseInfo('00380696-n', 0) ],
"_galley_n_1_rel" : [ SenseInfo('03412674-n', 0), SenseInfo('03412511-n', 0), SenseInfo('03412387-n', 0), SenseInfo('03412220-n', 0) ],
"_instrumentality_n_1_rel" : [ SenseInfo('08146135-n', 1), SenseInfo('05150458-n', 1), SenseInfo('03575240-n', 0) ],
"_assistant_n_1_rel" : [ SenseInfo('09815790-n', 7), SenseInfo('09815790-n', 7) ],
"_type_n_of_rel" : [ SenseInfo('05840188-n', 136), SenseInfo('09909060-n', 7), SenseInfo('08111419-n', 0), SenseInfo('06825120-n', 0), SenseInfo('06795967-n', 0), SenseInfo('04504486-n', 0) ],
"_olive_a_1_rel" : [ SenseInfo('00378782-a', 2) ],
"_undress_v_1_rel" : [ SenseInfo('00049900-v', 2), SenseInfo('00177243-v', 0) ],
"_racist_n_1_rel" : [ SenseInfo('10502950-n', 1) ],
"_replicate_v_1_rel" : [ SenseInfo('02036498-v', 0), SenseInfo('01734929-v', 0), SenseInfo('01734502-v', 0) ],
"_pleasurable_a_1_rel" : [ SenseInfo('01801029-a', 0) ],
"_rusty_a_1_rel" : [ SenseInfo('02053094-a', 3), SenseInfo('00382874-a', 1), SenseInfo('02230205-a', 0), SenseInfo('01639891-a', 0), SenseInfo('02053094-a', 3), SenseInfo('00382874-a', 1), SenseInfo('02230205-a', 0), SenseInfo('01639891-a', 0), SenseInfo('02053094-a', 3), SenseInfo('00382874-a', 1), SenseInfo('02230205-a', 0), SenseInfo('01639891-a', 0) ],
"_harsh_a_1_rel" : [ SenseInfo('01803583-a', 3), SenseInfo('01803792-a', 2), SenseInfo('02230990-a', 0), SenseInfo('01374183-a', 0), SenseInfo('01190916-a', 0), SenseInfo('00090219-a', 0), SenseInfo('01803583-a', 3), SenseInfo('01803792-a', 2), SenseInfo('02230990-a', 0), SenseInfo('01374183-a', 0), SenseInfo('01190916-a', 0), SenseInfo('00090219-a', 0), SenseInfo('01803583-a', 3), SenseInfo('01803792-a', 2), SenseInfo('02230990-a', 0), SenseInfo('01374183-a', 0), SenseInfo('01190916-a', 0), SenseInfo('00090219-a', 0), SenseInfo('01803583-a', 3), SenseInfo('01803792-a', 2), SenseInfo('02230990-a', 0), SenseInfo('01374183-a', 0), SenseInfo('01190916-a', 0), SenseInfo('00090219-a', 0) ],
"_spill_v_1_rel" : [ SenseInfo('01542207-v', 2), SenseInfo('02069888-v', 1), SenseInfo('01541579-v', 1), SenseInfo('01541803-v', 0), SenseInfo('00952841-v', 0), SenseInfo('00429642-v', 0) ],
"_work_v_out_rel" : [ SenseInfo('02413480-v', 74), SenseInfo('02410855-v', 62), SenseInfo('02525447-v', 32), SenseInfo('01525666-v', 20), SenseInfo('01668603-v', 9), SenseInfo('00100551-v', 9), SenseInfo('02051031-v', 5), SenseInfo('02594979-v', 4), SenseInfo('02373015-v', 3), SenseInfo('01852468-v', 3), SenseInfo('01629589-v', 3), SenseInfo('02407987-v', 2), SenseInfo('01741446-v', 2), SenseInfo('02751271-v', 0), SenseInfo('02536557-v', 0), SenseInfo('02444159-v', 0), SenseInfo('02436963-v', 0), SenseInfo('02116980-v', 0), SenseInfo('01817574-v', 0), SenseInfo('01659248-v', 0), SenseInfo('01541231-v', 0), SenseInfo('01235355-v', 0), SenseInfo('01162754-v', 0), SenseInfo('00634906-v', 0), SenseInfo('00458754-v', 0), SenseInfo('00458471-v', 0), SenseInfo('00150096-v', 0), SenseInfo('02413480-v', 74), SenseInfo('02410855-v', 62), SenseInfo('02525447-v', 32), SenseInfo('01525666-v', 20), SenseInfo('01668603-v', 9), SenseInfo('00100551-v', 9), SenseInfo('02051031-v', 5), SenseInfo('02594979-v', 4), SenseInfo('02373015-v', 3), SenseInfo('01852468-v', 3), SenseInfo('01629589-v', 3), SenseInfo('02407987-v', 2), SenseInfo('01741446-v', 2), SenseInfo('02751271-v', 0), SenseInfo('02536557-v', 0), SenseInfo('02444159-v', 0), SenseInfo('02436963-v', 0), SenseInfo('02116980-v', 0), SenseInfo('01817574-v', 0), SenseInfo('01659248-v', 0), SenseInfo('01541231-v', 0), SenseInfo('01235355-v', 0), SenseInfo('01162754-v', 0), SenseInfo('00634906-v', 0), SenseInfo('00458754-v', 0), SenseInfo('00458471-v', 0), SenseInfo('00150096-v', 0) ],
"_if+that_a_1_rel" : [  ],
"_privy_n_1_rel" : [ SenseInfo('04446276-n', 1), SenseInfo('03860404-n', 1) ],
"_reasoned_a_1_rel" : [ SenseInfo('02499511-a', 0) ],
"_schlep_v_1_rel" : [ SenseInfo('01453718-v', 0) ],
"_limbo_n_1_rel" : [ SenseInfo('14436769-n', 1), SenseInfo('05631076-n', 0), SenseInfo('05630874-n', 0) ],
"_counterexample_n_1_rel" : [ SenseInfo('05826832-n', 0), SenseInfo('05826832-n', 0), SenseInfo('05826832-n', 0), SenseInfo('05826832-n', 0), SenseInfo('05826832-n', 0), SenseInfo('05826832-n', 0), SenseInfo('05826832-n', 0), SenseInfo('05826832-n', 0) ],
"_cognac_n_1_rel" : [ SenseInfo('07903841-n', 0) ],
"_denunciation_n_of_rel" : [ SenseInfo('07232988-n', 3) ],
"_trinitarian_n_1_rel" : [ SenseInfo('10738787-n', 0) ],
"_numb_a_1_rel" : [ SenseInfo('02103333-a', 3), SenseInfo('02107386-a', 0), SenseInfo('00080698-a', 0), SenseInfo('02103333-a', 3), SenseInfo('02107386-a', 0), SenseInfo('00080698-a', 0) ],
"_half+way_a_1_rel" : [ SenseInfo('00330506-a', 4), SenseInfo('01014838-a', 1), SenseInfo('00517710-a', 0) ],
"_grammar_n_1_rel" : [ SenseInfo('06174404-n', 0) ],
"_pyromaniac_n_1_rel" : [ SenseInfo('10277027-n', 0) ],
"_render_v_up_rel" : [ SenseInfo('00120675-v', 12), SenseInfo('02327200-v', 10), SenseInfo('01732172-v', 4), SenseInfo('01629000-v', 2), SenseInfo('01062253-v', 1), SenseInfo('02310328-v', 0), SenseInfo('02310007-v', 0), SenseInfo('02293321-v', 0), SenseInfo('01686956-v', 0), SenseInfo('01361240-v', 0), SenseInfo('01060746-v', 0), SenseInfo('00959827-v', 0), SenseInfo('00444975-v', 0) ],
"_such+as_x_h_rel" : [  ],
"_squint_v_1_rel" : [ SenseInfo('00008602-v', 3), SenseInfo('02168070-v', 0), SenseInfo('00008799-v', 0) ],
"_bumper+to+bumper_a_1_rel" : [ SenseInfo('00980961-a', 0), SenseInfo('00980961-a', 0), SenseInfo('00980961-a', 0), SenseInfo('00980961-a', 0) ],
"_fantastic_n_1_rel" : [ SenseInfo('00967646-a', 4), SenseInfo('01676517-a', 3), SenseInfo('01942732-a', 2), SenseInfo('01936778-a', 1), SenseInfo('01796452-a', 0) ],
"_awesome_a_1_rel" : [ SenseInfo('01282510-a', 0) ],
"_succulent_a_1_rel" : [ SenseInfo('01369078-a', 0) ],
"_canoe_v_dir_rel" : [ SenseInfo('01947543-v', 0) ],
"_later_a_1_rel" : [ SenseInfo('00123485-a', 16), SenseInfo('00819235-a', 0) ],
"_rough_a_1_rel" : [ SenseInfo('02238462-a', 13), SenseInfo('01951197-a', 2), SenseInfo('00915976-a', 2), SenseInfo('00747910-a', 1), SenseInfo('00304949-a', 1), SenseInfo('00299476-a', 1), SenseInfo('00084353-a', 1), SenseInfo('02245403-a', 0), SenseInfo('02243567-a', 0), SenseInfo('00664167-a', 0), SenseInfo('02229584-a', 0), SenseInfo('01813183-a', 0), SenseInfo('01803583-a', 0), SenseInfo('01374183-a', 0), SenseInfo('02238462-a', 13), SenseInfo('01951197-a', 2), SenseInfo('00915976-a', 2), SenseInfo('00747910-a', 1), SenseInfo('00304949-a', 1), SenseInfo('00299476-a', 1), SenseInfo('00084353-a', 1), SenseInfo('02245403-a', 0), SenseInfo('02243567-a', 0), SenseInfo('00664167-a', 0), SenseInfo('02229584-a', 0), SenseInfo('01813183-a', 0), SenseInfo('01803583-a', 0), SenseInfo('01374183-a', 0), SenseInfo('02238462-a', 13), SenseInfo('01951197-a', 2), SenseInfo('00915976-a', 2), SenseInfo('00747910-a', 1), SenseInfo('00304949-a', 1), SenseInfo('00299476-a', 1), SenseInfo('00084353-a', 1), SenseInfo('02245403-a', 0), SenseInfo('02243567-a', 0), SenseInfo('00664167-a', 0), SenseInfo('02229584-a', 0), SenseInfo('01813183-a', 0), SenseInfo('01803583-a', 0), SenseInfo('01374183-a', 0), SenseInfo('02238462-a', 13), SenseInfo('01951197-a', 2), SenseInfo('00915976-a', 2), SenseInfo('00747910-a', 1), SenseInfo('00304949-a', 1), SenseInfo('00299476-a', 1), SenseInfo('00084353-a', 1), SenseInfo('02245403-a', 0), SenseInfo('02243567-a', 0), SenseInfo('00664167-a', 0), SenseInfo('02229584-a', 0), SenseInfo('01813183-a', 0), SenseInfo('01803583-a', 0), SenseInfo('01374183-a', 0) ],
"_stabilization_n_of_rel" : [ SenseInfo('01159025-n', 2), SenseInfo('01266945-n', 0), SenseInfo('01159025-n', 2), SenseInfo('01266945-n', 0) ],
"_pasture_n_1_rel" : [ SenseInfo('08616050-n', 4), SenseInfo('07801091-n', 1), SenseInfo('08616050-n', 4), SenseInfo('07801091-n', 1) ],
"_lifesaving_a_1_rel" : [ SenseInfo('00093874-n', 0) ],
"_last+but+not+least_a_1_rel" : [  ],
"_stuck_a_with_rel" : [ SenseInfo('00161065-a', 0), SenseInfo('01766958-a', 0) ],
"_bunny_n_1_rel" : [ SenseInfo('09880189-n', 0), SenseInfo('02324587-n', 0) ],
"_wed_v_to_rel" : [ SenseInfo('02488834-v', 3), SenseInfo('02489456-v', 0) ],
"_prior+to_p_rel" : [  ],
"_down_p_sel_rel" : [ SenseInfo('00095320-r', 98), SenseInfo('00095612-r', 22), SenseInfo('02491961-a', 9), SenseInfo('01202374-v', 3), SenseInfo('00095841-r', 2), SenseInfo('02486248-a', 2), SenseInfo('01896561-n', 1), SenseInfo('00458286-n', 1), SenseInfo('02487414-a', 1), SenseInfo('02061678-a', 1), SenseInfo('01750617-a', 1), SenseInfo('01197014-v', 1), SenseInfo('01103336-v', 1), SenseInfo('10942144-n', 0), SenseInfo('09269341-n', 0), SenseInfo('05255692-n', 0), SenseInfo('00096232-r', 0), SenseInfo('00096089-r', 0), SenseInfo('00095946-r', 0), SenseInfo('01212867-a', 0), SenseInfo('01208492-a', 0), SenseInfo('00833737-a', 0), SenseInfo('00703615-a', 0), SenseInfo('01981279-v', 0), SenseInfo('01239862-v', 0), SenseInfo('00474017-v', 0) ],
"_heterogenous_a_1_rel" : [ SenseInfo('01198737-a', 0), SenseInfo('00181373-a', 0), SenseInfo('01198737-a', 0), SenseInfo('00181373-a', 0) ],
"_comics_n_1_rel" : [ SenseInfo('09940146-n', 0) ],
"_better_x_deg_rel" : [ SenseInfo('00230335-a', 69), SenseInfo('00059607-r', 45), SenseInfo('00231761-a', 23), SenseInfo('00067379-a', 8), SenseInfo('00509846-r', 2), SenseInfo('05143558-n', 1), SenseInfo('01106864-v', 1), SenseInfo('00205885-v', 1), SenseInfo('00205046-v', 1), SenseInfo('09851876-n', 0), SenseInfo('09851719-n', 0), SenseInfo('05143690-n', 0), SenseInfo('01471260-a', 0) ],
"_send_v_around_rel" : [ SenseInfo('01951480-v', 79), SenseInfo('01437254-v', 20), SenseInfo('01031256-v', 20), SenseInfo('01950798-v', 14), SenseInfo('01088923-v', 5), SenseInfo('01062555-v', 5), SenseInfo('02348568-v', 3), SenseInfo('00973056-v', 2), SenseInfo('01951480-v', 79), SenseInfo('01437254-v', 20), SenseInfo('01031256-v', 20), SenseInfo('01950798-v', 14), SenseInfo('01088923-v', 5), SenseInfo('01062555-v', 5), SenseInfo('02348568-v', 3), SenseInfo('00973056-v', 2) ],
"_drive_v_down_rel" : [ SenseInfo('01930874-v', 56), SenseInfo('01930117-v', 24), SenseInfo('02056971-v', 13), SenseInfo('01516534-v', 13), SenseInfo('02505358-v', 6), SenseInfo('01506157-v', 5), SenseInfo('01646300-v', 4), SenseInfo('01512259-v', 2), SenseInfo('01509584-v', 2), SenseInfo('02406916-v', 1), SenseInfo('01026975-v', 1), SenseInfo('02742232-v', 0), SenseInfo('02408281-v', 0), SenseInfo('02057656-v', 0), SenseInfo('01939553-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01407904-v', 0), SenseInfo('01407722-v', 0), SenseInfo('01310964-v', 0), SenseInfo('01181741-v', 0), SenseInfo('01142636-v', 0), SenseInfo('01142490-v', 0) ],
"_on-site_a_1_rel" : [ SenseInfo('01637454-a', 1), SenseInfo('01637454-a', 1) ],
"_thai_a_1_rel" : [ SenseInfo('03117012-a', 0), SenseInfo('03116809-a', 0), SenseInfo('03116651-a', 0) ],
"_lather_v_1_rel" : [ SenseInfo('01411085-v', 0), SenseInfo('00512043-v', 0), SenseInfo('00109540-v', 0), SenseInfo('00036932-v', 0) ],
"_corner_v_1_rel" : [ SenseInfo('02442924-v', 1), SenseInfo('01934205-v', 0), SenseInfo('01909275-v', 0) ],
"_fiddle_n_1_rel" : [ SenseInfo('04536866-n', 1) ],
"_string_n_of_rel" : [ SenseInfo('04337974-n', 5), SenseInfo('02880546-n', 3), SenseInfo('04338143-n', 2), SenseInfo('08459648-n', 1), SenseInfo('07013549-n', 1), SenseInfo('03235560-n', 1), SenseInfo('14867365-n', 0), SenseInfo('09449282-n', 0), SenseInfo('04338359-n', 0), SenseInfo('02999757-n', 0), SenseInfo('04337974-n', 5), SenseInfo('02880546-n', 3), SenseInfo('04338143-n', 2), SenseInfo('08459648-n', 1), SenseInfo('07013549-n', 1), SenseInfo('03235560-n', 1), SenseInfo('14867365-n', 0), SenseInfo('09449282-n', 0), SenseInfo('04338359-n', 0), SenseInfo('02999757-n', 0), SenseInfo('04337974-n', 5), SenseInfo('02880546-n', 3), SenseInfo('04338143-n', 2), SenseInfo('08459648-n', 1), SenseInfo('07013549-n', 1), SenseInfo('03235560-n', 1), SenseInfo('14867365-n', 0), SenseInfo('09449282-n', 0), SenseInfo('04338359-n', 0), SenseInfo('02999757-n', 0), SenseInfo('04337974-n', 5), SenseInfo('02880546-n', 3), SenseInfo('04338143-n', 2), SenseInfo('08459648-n', 1), SenseInfo('07013549-n', 1), SenseInfo('03235560-n', 1), SenseInfo('14867365-n', 0), SenseInfo('09449282-n', 0), SenseInfo('04338359-n', 0), SenseInfo('02999757-n', 0), SenseInfo('04337974-n', 5), SenseInfo('02880546-n', 3), SenseInfo('04338143-n', 2), SenseInfo('08459648-n', 1), SenseInfo('07013549-n', 1), SenseInfo('03235560-n', 1), SenseInfo('14867365-n', 0), SenseInfo('09449282-n', 0), SenseInfo('04338359-n', 0), SenseInfo('02999757-n', 0) ],
"_declivity_n_1_rel" : [ SenseInfo('09265620-n', 1) ],
"_scout_v_1_rel" : [ SenseInfo('02167571-v', 2) ],
"_square_v_up_rel" : [ SenseInfo('00145448-v', 4), SenseInfo('00640136-v', 2), SenseInfo('02659656-v', 1), SenseInfo('01987493-v', 1), SenseInfo('02659541-v', 0), SenseInfo('02253341-v', 0), SenseInfo('01124964-v', 0), SenseInfo('01124828-v', 0) ],
"_croak_v_1_rel" : [ SenseInfo('00358431-v', 1), SenseInfo('01064401-v', 0), SenseInfo('00909219-v', 0) ],
"_business_n_1_rel" : [ SenseInfo('08061042-n', 35), SenseInfo('01094725-n', 20), SenseInfo('00582388-n', 13), SenseInfo('05833022-n', 12), SenseInfo('05983801-n', 9), SenseInfo('01096245-n', 7), SenseInfo('07966927-n', 5), SenseInfo('08401554-n', 0), SenseInfo('00550341-n', 0) ],
"_etch_n_1_rel" : [  ],
"_nanotechnology_n_1_rel" : [ SenseInfo('06134899-n', 0) ],
"_concrete_n_1_rel" : [ SenseInfo('14820180-n', 16) ],
"_on_p_temp_rel" : [ SenseInfo('00068368-r', 40), SenseInfo('01651196-a', 6), SenseInfo('00069346-r', 2), SenseInfo('00069472-r', 1), SenseInfo('01651741-a', 0) ],
"_nicotine_n_1_rel" : [ SenseInfo('14714817-n', 1) ],
"_coincide_v_with_rel" : [ SenseInfo('02660442-v', 9), SenseInfo('00345312-v', 5), SenseInfo('02658734-v', 4) ],
"_pub_n_1_rel" : [ SenseInfo('04018399-n', 0) ],
"_aberration_n_1_rel" : [ SenseInfo('14503665-n', 1), SenseInfo('14386590-n', 0), SenseInfo('11420139-n', 0) ],
"_weighty_a_1_rel" : [ SenseInfo('01187611-a', 0), SenseInfo('01770392-a', 0), SenseInfo('01278423-a', 0), SenseInfo('01190168-a', 0), SenseInfo('00987180-a', 0), SenseInfo('01187611-a', 0), SenseInfo('01770392-a', 0), SenseInfo('01278423-a', 0), SenseInfo('01190168-a', 0), SenseInfo('00987180-a', 0), SenseInfo('01187611-a', 0), SenseInfo('01770392-a', 0), SenseInfo('01278423-a', 0), SenseInfo('01190168-a', 0), SenseInfo('00987180-a', 0) ],
"_number_n_of_rel" : [ SenseInfo('05121418-n', 131), SenseInfo('13582013-n', 63), SenseInfo('06892016-n', 5), SenseInfo('06426111-n', 5), SenseInfo('06807198-n', 2), SenseInfo('06596978-n', 2), SenseInfo('08480512-n', 1), SenseInfo('06425065-n', 1), SenseInfo('05096294-n', 1), SenseInfo('06326526-n', 0), SenseInfo('03835412-n', 0), SenseInfo('05121418-n', 131), SenseInfo('13582013-n', 63), SenseInfo('06892016-n', 5), SenseInfo('06426111-n', 5), SenseInfo('06807198-n', 2), SenseInfo('06596978-n', 2), SenseInfo('08480512-n', 1), SenseInfo('06425065-n', 1), SenseInfo('05096294-n', 1), SenseInfo('06326526-n', 0), SenseInfo('03835412-n', 0), SenseInfo('05121418-n', 131), SenseInfo('13582013-n', 63), SenseInfo('06892016-n', 5), SenseInfo('06426111-n', 5), SenseInfo('06807198-n', 2), SenseInfo('06596978-n', 2), SenseInfo('08480512-n', 1), SenseInfo('06425065-n', 1), SenseInfo('05096294-n', 1), SenseInfo('06326526-n', 0), SenseInfo('03835412-n', 0), SenseInfo('05121418-n', 131), SenseInfo('13582013-n', 63), SenseInfo('06892016-n', 5), SenseInfo('06426111-n', 5), SenseInfo('06807198-n', 2), SenseInfo('06596978-n', 2), SenseInfo('08480512-n', 1), SenseInfo('06425065-n', 1), SenseInfo('05096294-n', 1), SenseInfo('06326526-n', 0), SenseInfo('03835412-n', 0), SenseInfo('05121418-n', 131), SenseInfo('13582013-n', 63), SenseInfo('06892016-n', 5), SenseInfo('06426111-n', 5), SenseInfo('06807198-n', 2), SenseInfo('06596978-n', 2), SenseInfo('08480512-n', 1), SenseInfo('06425065-n', 1), SenseInfo('05096294-n', 1), SenseInfo('06326526-n', 0), SenseInfo('03835412-n', 0), SenseInfo('05121418-n', 131), SenseInfo('13582013-n', 63), SenseInfo('06892016-n', 5), SenseInfo('06426111-n', 5), SenseInfo('06807198-n', 2), SenseInfo('06596978-n', 2), SenseInfo('08480512-n', 1), SenseInfo('06425065-n', 1), SenseInfo('05096294-n', 1), SenseInfo('06326526-n', 0), SenseInfo('03835412-n', 0), SenseInfo('05121418-n', 131), SenseInfo('13582013-n', 63), SenseInfo('06892016-n', 5), SenseInfo('06426111-n', 5), SenseInfo('06807198-n', 2), SenseInfo('06596978-n', 2), SenseInfo('08480512-n', 1), SenseInfo('06425065-n', 1), SenseInfo('05096294-n', 1), SenseInfo('06326526-n', 0), SenseInfo('03835412-n', 0), SenseInfo('05121418-n', 131), SenseInfo('13582013-n', 63), SenseInfo('06892016-n', 5), SenseInfo('06426111-n', 5), SenseInfo('06807198-n', 2), SenseInfo('06596978-n', 2), SenseInfo('08480512-n', 1), SenseInfo('06425065-n', 1), SenseInfo('05096294-n', 1), SenseInfo('06326526-n', 0), SenseInfo('03835412-n', 0), SenseInfo('05121418-n', 131), SenseInfo('13582013-n', 63), SenseInfo('06892016-n', 5), SenseInfo('06426111-n', 5), SenseInfo('06807198-n', 2), SenseInfo('06596978-n', 2), SenseInfo('08480512-n', 1), SenseInfo('06425065-n', 1), SenseInfo('05096294-n', 1), SenseInfo('06326526-n', 0), SenseInfo('03835412-n', 0), SenseInfo('05121418-n', 131), SenseInfo('13582013-n', 63), SenseInfo('06892016-n', 5), SenseInfo('06426111-n', 5), SenseInfo('06807198-n', 2), SenseInfo('06596978-n', 2), SenseInfo('08480512-n', 1), SenseInfo('06425065-n', 1), SenseInfo('05096294-n', 1), SenseInfo('06326526-n', 0), SenseInfo('03835412-n', 0) ],
"_hand_v_over_rel" : [ SenseInfo('02230772-v', 25), SenseInfo('02000133-v', 0) ],
"_israeli_a_1_rel" : [ SenseInfo('02972925-a', 0) ],
"_spurt_n_1_rel" : [ SenseInfo('07436100-n', 0) ],
"_topology_n_1_rel" : [ SenseInfo('06122747-n', 0), SenseInfo('06060463-n', 0), SenseInfo('06017594-n', 0), SenseInfo('05730365-n', 0) ],
"_knit_v_1_rel" : [ SenseInfo('01671039-v', 2), SenseInfo('01672014-v', 1), SenseInfo('01278817-v', 0), SenseInfo('01671039-v', 2), SenseInfo('01672014-v', 1), SenseInfo('01278817-v', 0) ],
"_trout_n_1_rel" : [ SenseInfo('07794452-n', 0), SenseInfo('02537085-n', 0) ],
"_irk_v_1_rel" : [ SenseInfo('01786760-v', 0), SenseInfo('01786760-v', 0) ],
"_co-author_n_1_rel" : [ SenseInfo('09932892-n', 0), SenseInfo('09932892-n', 0), SenseInfo('09932892-n', 0), SenseInfo('09932892-n', 0) ],
"_suck_v_in_rel" : [ SenseInfo('01169704-v', 4), SenseInfo('01854888-v', 2), SenseInfo('02765692-v', 0), SenseInfo('02674340-v', 0), SenseInfo('02117170-v', 0), SenseInfo('01539063-v', 0), SenseInfo('01186428-v', 0) ],
"_slap_v_on_rel" : [ SenseInfo('01416871-v', 15) ],
"_metro_n_1_rel" : [ SenseInfo('03757138-n', 1) ],
"_max_x_deg_rel" : [ SenseInfo('04253751-n', 0) ],
"_comparison_n_1_rel" : [ SenseInfo('00142665-n', 16), SenseInfo('13853808-n', 8), SenseInfo('04746842-n', 0) ],
"_deign_v_1_rel" : [ SenseInfo('02591312-v', 1) ],
"_air_v_1_rel" : [ SenseInfo('02112891-v', 1), SenseInfo('00973728-v', 0), SenseInfo('00973056-v', 0), SenseInfo('00954608-v', 0), SenseInfo('00489029-v', 0), SenseInfo('00488770-v', 0) ],
"_childbirth_n_1_rel" : [ SenseInfo('13448334-n', 0) ],
"_know_v_as_rel" : [ SenseInfo('00594621-v', 585), SenseInfo('00595935-v', 142), SenseInfo('00595630-v', 123), SenseInfo('00594337-v', 76), SenseInfo('00596644-v', 17), SenseInfo('00592883-v', 10), SenseInfo('00596132-v', 1), SenseInfo('01426397-v', 0), SenseInfo('00608670-v', 0), SenseInfo('00608502-v', 0), SenseInfo('00608372-v', 0), SenseInfo('00594621-v', 585), SenseInfo('00595935-v', 142), SenseInfo('00595630-v', 123), SenseInfo('00594337-v', 76), SenseInfo('00596644-v', 17), SenseInfo('00592883-v', 10), SenseInfo('00596132-v', 1), SenseInfo('01426397-v', 0), SenseInfo('00608670-v', 0), SenseInfo('00608502-v', 0), SenseInfo('00608372-v', 0) ],
"_eventuality_n_1_rel" : [ SenseInfo('07290761-n', 0) ],
"_fawn_n_1_rel" : [ SenseInfo('04973110-n', 1), SenseInfo('02430830-n', 0) ],
"_ceramic_a_1_rel" : [ SenseInfo('03015441-a', 1) ],
"_flag_n_1_rel" : [ SenseInfo('03354903-n', 31), SenseInfo('06493158-n', 3), SenseInfo('12411922-n', 1), SenseInfo('06875094-n', 0), SenseInfo('03940894-n', 0), SenseInfo('03355339-n', 0), SenseInfo('02158846-n', 0) ],
"_mbps_n_1_rel" : [  ],
"_condemn_v_to_rel" : [ SenseInfo('00864159-v', 18), SenseInfo('00856578-v', 2), SenseInfo('02507093-v', 1), SenseInfo('02149302-v', 1), SenseInfo('00906735-v', 1), SenseInfo('02273768-v', 0), SenseInfo('00864159-v', 18), SenseInfo('00856578-v', 2), SenseInfo('02507093-v', 1), SenseInfo('02149302-v', 1), SenseInfo('00906735-v', 1), SenseInfo('02273768-v', 0), SenseInfo('00864159-v', 18), SenseInfo('00856578-v', 2), SenseInfo('02507093-v', 1), SenseInfo('02149302-v', 1), SenseInfo('00906735-v', 1), SenseInfo('02273768-v', 0) ],
"_shatter_v_cause_rel" : [ SenseInfo('00333758-v', 12), SenseInfo('00334050-v', 0), SenseInfo('00333907-v', 0) ],
"_mouthwatering_a_1_rel" : [  ],
"_simple_a_1_rel" : [ SenseInfo('02174896-a', 56), SenseInfo('00750296-a', 10), SenseInfo('01792573-a', 4), SenseInfo('02272047-a', 2), SenseInfo('01841390-a', 1), SenseInfo('02166346-a', 0), SenseInfo('01793812-a', 0), SenseInfo('02174896-a', 56), SenseInfo('00750296-a', 10), SenseInfo('01792573-a', 4), SenseInfo('02272047-a', 2), SenseInfo('01841390-a', 1), SenseInfo('02166346-a', 0), SenseInfo('01793812-a', 0), SenseInfo('02174896-a', 56), SenseInfo('00750296-a', 10), SenseInfo('01792573-a', 4), SenseInfo('02272047-a', 2), SenseInfo('01841390-a', 1), SenseInfo('02166346-a', 0), SenseInfo('01793812-a', 0) ],
"_quarterly_n_1_rel" : [ SenseInfo('06594625-n', 0) ],
"_clarity_n_1_rel" : [ SenseInfo('04820258-n', 17), SenseInfo('04701460-n', 1) ],
"_chemical_n_1_rel" : [ SenseInfo('14806838-n', 6), SenseInfo('14806838-n', 6), SenseInfo('14806838-n', 6) ],
"_tab_v_1_rel" : [  ],
"_convolve_v_1_rel" : [ SenseInfo('01281184-v', 0) ],
"_pass_v_up_rel" : [ SenseInfo('02050132-v', 32), SenseInfo('02051694-v', 31), SenseInfo('02466670-v', 29), SenseInfo('02072849-v', 17), SenseInfo('02230772-v', 13), SenseInfo('02685951-v', 8), SenseInfo('02049696-v', 8), SenseInfo('00339934-v', 7), SenseInfo('02523351-v', 4), SenseInfo('02708420-v', 3), SenseInfo('01212230-v', 3), SenseInfo('00742320-v', 3), SenseInfo('00421691-v', 3), SenseInfo('02525044-v', 2), SenseInfo('02669081-v', 1), SenseInfo('02523953-v', 1), SenseInfo('02423513-v', 1), SenseInfo('02221635-v', 1), SenseInfo('01972131-v', 1), SenseInfo('02231473-v', 0), SenseInfo('02229550-v', 0), SenseInfo('02052476-v', 0), SenseInfo('00803325-v', 0), SenseInfo('00358431-v', 0), SenseInfo('00072989-v', 0) ],
"_nitrate_n_1_rel" : [ SenseInfo('15015501-n', 1) ],
"_teal_a_1_rel" : [ SenseInfo('00371163-a', 0) ],
"_roll_n_of_rel" : [ SenseInfo('07441619-n', 2), SenseInfo('06495000-n', 2), SenseInfo('07349532-n', 1), SenseInfo('04101375-n', 1), SenseInfo('13875970-n', 0), SenseInfo('13356569-n', 0), SenseInfo('07680932-n', 0), SenseInfo('07389330-n', 0), SenseInfo('07388816-n', 0), SenseInfo('06407733-n', 0), SenseInfo('04101232-n', 0), SenseInfo('01245813-n', 0), SenseInfo('00289659-n', 0), SenseInfo('00170340-n', 0), SenseInfo('00104409-n', 0) ],
"_elliptical_a_1_rel" : [ SenseInfo('02046199-a', 0), SenseInfo('00548029-a', 0), SenseInfo('02046199-a', 0), SenseInfo('00548029-a', 0) ],
"_post-9/11_a_1_rel" : [  ],
"_sublease_n_1_rel" : [ SenseInfo('13248928-n', 0) ],
"_bookshop_n_1_rel" : [ SenseInfo('02871525-n', 0), SenseInfo('02871525-n', 0) ],
"_wiry_a_1_rel" : [ SenseInfo('00991584-a', 4), SenseInfo('03145054-a', 0), SenseInfo('00216560-a', 0), SenseInfo('00991584-a', 4), SenseInfo('03145054-a', 0), SenseInfo('00216560-a', 0), SenseInfo('00991584-a', 4), SenseInfo('03145054-a', 0), SenseInfo('00216560-a', 0) ],
"_assent_v_1_rel" : [ SenseInfo('00804139-v', 3) ],
"_binary_n_1_rel" : [ SenseInfo('09221070-n', 0), SenseInfo('06570963-n', 0) ],
"_notable_n_1_rel" : [ SenseInfo('10276238-n', 1) ],
"_class_v_among_rel" : [ SenseInfo('00654625-v', 2) ],
"_banqueting_n_1_rel" : [ SenseInfo('00840751-n', 0) ],
"_computation_n_1_rel" : [ SenseInfo('00868910-n', 3), SenseInfo('05802185-n', 1) ],
"_vidda_n_1_rel" : [  ],
"_putt_v_1_rel" : [ SenseInfo('01403540-v', 3), SenseInfo('01403785-v', 0) ],
"_cleaner_a_1_rel" : [ SenseInfo('03040587-n', 4), SenseInfo('09927305-n', 0), SenseInfo('09927089-n', 0) ],
"_geometrical_a_1_rel" : [ SenseInfo('02735208-a', 1), SenseInfo('01981009-a', 0) ],
"_dictatorship_n_1_rel" : [ SenseInfo('08440630-n', 3) ],
"_together_p_rel" : [ SenseInfo('00116791-r', 22), SenseInfo('00116994-r', 18), SenseInfo('00507927-r', 12), SenseInfo('00116510-r', 9), SenseInfo('00116588-r', 7), SenseInfo('01586194-a', 2), SenseInfo('00116705-r', 1) ],
"_fake_n_1_rel" : [ SenseInfo('03318438-n', 1), SenseInfo('10201535-n', 0), SenseInfo('00172217-n', 0) ],
"_purchaser_n_1_rel" : [ SenseInfo('09885145-n', 0) ],
"_stranger_n_1_rel" : [ SenseInfo('10661002-n', 15), SenseInfo('10661216-n', 0) ],
"_think+tank_n_1_rel" : [ SenseInfo('08478702-n', 0), SenseInfo('08478702-n', 0) ],
"_broccoli_n_1_rel" : [ SenseInfo('11876803-n', 0), SenseInfo('07714990-n', 0) ],
"_stage_v_1_rel" : [ SenseInfo('01711445-v', 9), SenseInfo('01648126-v', 5) ],
"_actor_n_1_rel" : [ SenseInfo('09765278-n', 14), SenseInfo('09767197-n', 0) ],
"_figurine_n_1_rel" : [ SenseInfo('03336459-n', 1) ],
"_psyche_n_1_rel" : [ SenseInfo('05611302-n', 2), SenseInfo('10627082-n', 1), SenseInfo('09577601-n', 0) ],
"_dupe_v_1_rel" : [ SenseInfo('00854904-v', 1) ],
"_neanderthal_n_1_rel" : [ SenseInfo('02475078-n', 0) ],
"_muddle_v_along_rel" : [ SenseInfo('01419867-v', 0), SenseInfo('00620532-v', 0) ],
"_disperse_v_cause_rel" : [ SenseInfo('01376245-v', 2), SenseInfo('02030424-v', 1), SenseInfo('00330565-v', 1), SenseInfo('02028994-v', 0), SenseInfo('01616608-v', 0), SenseInfo('00968211-v', 0), SenseInfo('01376245-v', 2), SenseInfo('02030424-v', 1), SenseInfo('00330565-v', 1), SenseInfo('02028994-v', 0), SenseInfo('01616608-v', 0), SenseInfo('00968211-v', 0) ],
"_goatee_n_1_rel" : [ SenseInfo('05263029-n', 0) ],
"_in-to-use_a_1_rel" : [  ],
"_rate_n_of_rel" : [ SenseInfo('15286249-n', 68), SenseInfo('13325010-n', 39), SenseInfo('05058580-n', 1), SenseInfo('13816649-n', 0) ],
"_clash_v_with_rel" : [ SenseInfo('01561143-v', 1), SenseInfo('02667698-v', 0), SenseInfo('00805228-v', 0), SenseInfo('01561143-v', 1), SenseInfo('02667698-v', 0), SenseInfo('00805228-v', 0) ],
"_chop_v_off_rel" : [ SenseInfo('01258091-v', 2), SenseInfo('01871471-v', 0), SenseInfo('01758410-v', 0), SenseInfo('01415454-v', 0), SenseInfo('01257173-v', 0), SenseInfo('01124535-v', 0) ],
"_attention_n_to_rel" : [ SenseInfo('05702275-n', 56), SenseInfo('00654885-n', 10), SenseInfo('05853636-n', 4), SenseInfo('01228645-n', 4), SenseInfo('05650579-n', 2), SenseInfo('05082790-n', 1), SenseInfo('05702275-n', 56), SenseInfo('00654885-n', 10), SenseInfo('05853636-n', 4), SenseInfo('01228645-n', 4), SenseInfo('05650579-n', 2), SenseInfo('05082790-n', 1), SenseInfo('05702275-n', 56), SenseInfo('00654885-n', 10), SenseInfo('05853636-n', 4), SenseInfo('01228645-n', 4), SenseInfo('05650579-n', 2), SenseInfo('05082790-n', 1) ],
"_ordain_v_1_rel" : [ SenseInfo('02427916-v', 3), SenseInfo('02386012-v', 1), SenseInfo('02427726-v', 0), SenseInfo('00746084-v', 0), SenseInfo('02427916-v', 3), SenseInfo('02386012-v', 1), SenseInfo('02427726-v', 0), SenseInfo('00746084-v', 0), SenseInfo('02427916-v', 3), SenseInfo('02386012-v', 1), SenseInfo('02427726-v', 0), SenseInfo('00746084-v', 0), SenseInfo('02427916-v', 3), SenseInfo('02386012-v', 1), SenseInfo('02427726-v', 0), SenseInfo('00746084-v', 0) ],
"_file_v_dir_rel" : [ SenseInfo('01001857-v', 50), SenseInfo('01387022-v', 10), SenseInfo('01920048-v', 3), SenseInfo('00869931-v', 2), SenseInfo('01001643-v', 1) ],
"_critique_n_of_rel" : [ SenseInfo('06410391-n', 0), SenseInfo('05734018-n', 0) ],
"_subtitle_n_1_rel" : [ SenseInfo('06347588-n', 0), SenseInfo('06347037-n', 0) ],
"_flour_n_1_rel" : [ SenseInfo('07569106-n', 3) ],
"_pickle_n_1_rel" : [ SenseInfo('07824988-n', 1), SenseInfo('14409489-n', 0) ],
"_dream_n_1_rel" : [ SenseInfo('05768553-n', 31), SenseInfo('05768806-n', 7), SenseInfo('07484547-n', 4), SenseInfo('05632732-n', 2), SenseInfo('05700925-n', 1), SenseInfo('14459715-n', 0), SenseInfo('05768553-n', 31), SenseInfo('05768806-n', 7), SenseInfo('07484547-n', 4), SenseInfo('05632732-n', 2), SenseInfo('05700925-n', 1), SenseInfo('14459715-n', 0) ],
"_reduce_v_1_rel" : [ SenseInfo('00429060-v', 102), SenseInfo('00242396-v', 9), SenseInfo('02399888-v', 5), SenseInfo('02258291-v', 3), SenseInfo('01800907-v', 3), SenseInfo('00237704-v', 3), SenseInfo('00241038-v', 2), SenseInfo('02317836-v', 1), SenseInfo('00240131-v', 1), SenseInfo('00237877-v', 1), SenseInfo('00233203-v', 1), SenseInfo('02424128-v', 0), SenseInfo('01558582-v', 0), SenseInfo('01499137-v', 0), SenseInfo('00587522-v', 0), SenseInfo('00243900-v', 0), SenseInfo('00237259-v', 0), SenseInfo('00236999-v', 0), SenseInfo('00226071-v', 0), SenseInfo('00045817-v', 0) ],
"_mythical_a_1_rel" : [ SenseInfo('01936184-a', 0) ],
"_parsnip_n_1_rel" : [ SenseInfo('12941914-n', 0), SenseInfo('12941536-n', 0), SenseInfo('07735404-n', 0) ],
"_bistro_n_1_rel" : [ SenseInfo('02844214-n', 0) ],
"_handhold_n_1_rel" : [ SenseInfo('03485575-n', 0) ],
"_proud_a_1_rel" : [ SenseInfo('01889256-a', 14), SenseInfo('01285136-a', 2), SenseInfo('01889256-a', 14), SenseInfo('01285136-a', 2) ],
"_spit_v_out_rel" : [ SenseInfo('00101956-v', 11), SenseInfo('01045318-v', 1), SenseInfo('02757828-v', 0), SenseInfo('01444563-v', 0) ],
"_fielder_n_1_rel" : [ SenseInfo('10086568-n', 1), SenseInfo('10086383-n', 0) ],
"_crowd_n_of_rel" : [ SenseInfo('08182379-n', 35), SenseInfo('08273843-n', 1), SenseInfo('08182379-n', 35), SenseInfo('08273843-n', 1) ],
"_ally_v_to-with_rel" : [ SenseInfo('02430191-v', 0), SenseInfo('02430191-v', 0), SenseInfo('02430191-v', 0) ],
"_defeat_v_1_rel" : [ SenseInfo('01108148-v', 14), SenseInfo('02473688-v', 5) ],
"_tool_v_2_rel" : [ SenseInfo('02100341-v', 1), SenseInfo('01956708-v', 1), SenseInfo('02338003-v', 0), SenseInfo('01669547-v', 0) ],
"_hitherto_a_1_rel" : [  ],
"_well+known_a_1_rel" : [ SenseInfo('01376705-a', 6), SenseInfo('00966167-a', 1), SenseInfo('01376705-a', 6), SenseInfo('00966167-a', 1) ],
"_curt_a_1_rel" : [ SenseInfo('00640660-a', 0), SenseInfo('00547641-a', 0) ],
"_routine_a_1_rel" : [ SenseInfo('01674242-a', 2), SenseInfo('01674242-a', 2) ],
"_spirituous_a_1_rel" : [ SenseInfo('01159217-a', 0) ],
"_chip_v_in_rel" : [ SenseInfo('01259691-v', 1), SenseInfo('01259005-v', 1), SenseInfo('01598140-v', 0), SenseInfo('01260291-v', 0), SenseInfo('01259458-v', 0) ],
"_available_a_to-for_rel" : [ SenseInfo('00183053-a', 91), SenseInfo('01062631-a', 0), SenseInfo('00777650-a', 0), SenseInfo('00183053-a', 91), SenseInfo('01062631-a', 0), SenseInfo('00777650-a', 0), SenseInfo('00183053-a', 91), SenseInfo('01062631-a', 0), SenseInfo('00777650-a', 0) ],
"_epithet_n_1_rel" : [ SenseInfo('06720964-n', 3), SenseInfo('07202311-n', 0) ],
"_cheer_n_1_rel" : [ SenseInfo('06692572-n', 14), SenseInfo('04630689-n', 0) ],
"_flatten_v_out_rel" : [ SenseInfo('00463778-v', 6), SenseInfo('00463469-v', 1), SenseInfo('00393534-v', 0), SenseInfo('00463778-v', 6), SenseInfo('00463469-v', 1), SenseInfo('00393534-v', 0) ],
"_pricey_a_1_rel" : [ SenseInfo('00933599-a', 0), SenseInfo('00933599-a', 0), SenseInfo('00933599-a', 0) ],
"_encouragement_n_of_rel" : [ SenseInfo('06691442-n', 3), SenseInfo('01211019-n', 2), SenseInfo('07541449-n', 0), SenseInfo('06691442-n', 3), SenseInfo('01211019-n', 2), SenseInfo('07541449-n', 0), SenseInfo('06691442-n', 3), SenseInfo('01211019-n', 2), SenseInfo('07541449-n', 0) ],
"_rope_v_together_rel" : [ SenseInfo('01604251-v', 0), SenseInfo('01289155-v', 0) ],
"_spearhead_n_1_rel" : [ SenseInfo('10631512-n', 0), SenseInfo('08415661-n', 0), SenseInfo('04271371-n', 0) ],
"_campmate_n_1_rel" : [ SenseInfo('09890411-n', 1) ],
"_pen_n_1_rel" : [ SenseInfo('03906997-n', 8), SenseInfo('03907227-n', 1), SenseInfo('03964495-n', 0), SenseInfo('03911513-n', 0), SenseInfo('01858845-n', 0) ],
"_theft_n_of_rel" : [ SenseInfo('00780889-n', 0) ],
"_swan_n_1_rel" : [ SenseInfo('01858441-n', 1) ],
"_capstan_n_1_rel" : [ SenseInfo('02957252-n', 1) ],
"_servant_n_1_rel" : [ SenseInfo('10582154-n', 9), SenseInfo('13952171-n', 0) ],
"_stall_v_cause_rel" : [ SenseInfo('02642238-v', 2), SenseInfo('01862340-v', 1), SenseInfo('00460555-v', 1), SenseInfo('02460070-v', 0), SenseInfo('01862776-v', 0), SenseInfo('01862640-v', 0), SenseInfo('01862496-v', 0) ],
"_fair_n_1_rel" : [ SenseInfo('00519333-n', 1), SenseInfo('08408557-n', 0), SenseInfo('08408267-n', 0), SenseInfo('01118182-n', 0) ],
"_ending_n_1_rel" : [ SenseInfo('06308765-n', 3), SenseInfo('00209943-n', 1), SenseInfo('15266911-n', 0), SenseInfo('07291312-n', 0), SenseInfo('06398401-n', 0) ],
"_freeze_v_1_rel" : [ SenseInfo('01834730-v', 5), SenseInfo('00374135-v', 5), SenseInfo('00078138-v', 3), SenseInfo('00375865-v', 1), SenseInfo('00363493-v', 1), SenseInfo('02758826-v', 0), SenseInfo('00445711-v', 0), SenseInfo('00269423-v', 0), SenseInfo('00021997-v', 0), SenseInfo('00012613-v', 0) ],
"_slack_n_1_rel" : [ SenseInfo('14858099-n', 0), SenseInfo('13556509-n', 0), SenseInfo('09436906-n', 0), SenseInfo('09355850-n', 0), SenseInfo('04775357-n', 0), SenseInfo('04233556-n', 0) ],
"_significant_a_for_rel" : [ SenseInfo('02161432-a', 18), SenseInfo('00625055-a', 9), SenseInfo('02165655-a', 3), SenseInfo('01497387-a', 2), SenseInfo('02161432-a', 18), SenseInfo('00625055-a', 9), SenseInfo('02165655-a', 3), SenseInfo('01497387-a', 2), SenseInfo('02161432-a', 18), SenseInfo('00625055-a', 9), SenseInfo('02165655-a', 3), SenseInfo('01497387-a', 2) ],
"_weapon_n_1_rel" : [ SenseInfo('04565375-n', 29), SenseInfo('07246932-n', 2), SenseInfo('04565375-n', 29), SenseInfo('07246932-n', 2), SenseInfo('04565375-n', 29), SenseInfo('07246932-n', 2) ],
"_semicolon_n_1_rel" : [ SenseInfo('06844739-n', 0) ],
"_habitat_n_1_rel" : [ SenseInfo('08580583-n', 2) ],
"_segment_v_1_rel" : [ SenseInfo('01563005-v', 0), SenseInfo('01558440-v', 0) ],
"_enlargement_n_1_rel" : [ SenseInfo('00365709-n', 2), SenseInfo('14315071-n', 0), SenseInfo('07172756-n', 0), SenseInfo('03289462-n', 0) ],
"_subpoena_n_1_rel" : [ SenseInfo('06557047-n', 0) ],
"_sweet_a_to_rel" : [ SenseInfo('02368336-a', 9), SenseInfo('01459949-a', 4), SenseInfo('01501821-a', 3), SenseInfo('01808671-a', 2), SenseInfo('01808413-a', 2), SenseInfo('01052611-a', 2), SenseInfo('02367604-a', 1), SenseInfo('01073707-a', 0), SenseInfo('02370083-a', 0), SenseInfo('02338197-a', 0), SenseInfo('02368336-a', 9), SenseInfo('01459949-a', 4), SenseInfo('01501821-a', 3), SenseInfo('01808671-a', 2), SenseInfo('01808413-a', 2), SenseInfo('01052611-a', 2), SenseInfo('02367604-a', 1), SenseInfo('01073707-a', 0), SenseInfo('02370083-a', 0), SenseInfo('02338197-a', 0), SenseInfo('02368336-a', 9), SenseInfo('01459949-a', 4), SenseInfo('01501821-a', 3), SenseInfo('01808671-a', 2), SenseInfo('01808413-a', 2), SenseInfo('01052611-a', 2), SenseInfo('02367604-a', 1), SenseInfo('01073707-a', 0), SenseInfo('02370083-a', 0), SenseInfo('02338197-a', 0), SenseInfo('02368336-a', 9), SenseInfo('01459949-a', 4), SenseInfo('01501821-a', 3), SenseInfo('01808671-a', 2), SenseInfo('01808413-a', 2), SenseInfo('01052611-a', 2), SenseInfo('02367604-a', 1), SenseInfo('01073707-a', 0), SenseInfo('02370083-a', 0), SenseInfo('02338197-a', 0), SenseInfo('02368336-a', 9), SenseInfo('01459949-a', 4), SenseInfo('01501821-a', 3), SenseInfo('01808671-a', 2), SenseInfo('01808413-a', 2), SenseInfo('01052611-a', 2), SenseInfo('02367604-a', 1), SenseInfo('01073707-a', 0), SenseInfo('02370083-a', 0), SenseInfo('02338197-a', 0), SenseInfo('02368336-a', 9), SenseInfo('01459949-a', 4), SenseInfo('01501821-a', 3), SenseInfo('01808671-a', 2), SenseInfo('01808413-a', 2), SenseInfo('01052611-a', 2), SenseInfo('02367604-a', 1), SenseInfo('01073707-a', 0), SenseInfo('02370083-a', 0), SenseInfo('02338197-a', 0) ],
"_ceramic_n_1_rel" : [ SenseInfo('02997391-n', 0) ],
"_year-round_a_1_rel" : [ SenseInfo('01494429-a', 1), SenseInfo('01494429-a', 1), SenseInfo('01494429-a', 1), SenseInfo('01494429-a', 1) ],
"_shake_v_up_rel" : [ SenseInfo('01889610-v', 42), SenseInfo('00014034-v', 14), SenseInfo('01891638-v', 8), SenseInfo('01875295-v', 6), SenseInfo('00167385-v', 6), SenseInfo('01761706-v', 2), SenseInfo('02073545-v', 1), SenseInfo('00559556-v', 1), SenseInfo('00992518-v', 0) ],
"_indirection_n_1_rel" : [ SenseInfo('01026191-n', 1), SenseInfo('00752798-n', 0) ],
"_stratum_n_1_rel" : [ SenseInfo('08657249-n', 3), SenseInfo('07974025-n', 0), SenseInfo('06246896-n', 0) ],
"_bubble_v_1_rel" : [ SenseInfo('00519056-v', 3), SenseInfo('02187922-v', 0), SenseInfo('01969084-v', 0), SenseInfo('00519229-v', 0), SenseInfo('00003431-v', 0) ],
"_calibrate_v_1_rel" : [ SenseInfo('00295697-v', 4), SenseInfo('01589497-v', 0), SenseInfo('00739536-v', 0) ],
"_plantation_n_1_rel" : [ SenseInfo('13252513-n', 4), SenseInfo('08374773-n', 0), SenseInfo('03463832-n', 0) ],
"_by+far_a_1_rel" : [  ],
"_outport_n_1_rel" : [ SenseInfo('08638260-n', 0) ],
"_amend_v_1_rel" : [ SenseInfo('00996328-v', 9), SenseInfo('00205885-v', 2), SenseInfo('00199912-v', 0), SenseInfo('00996328-v', 9), SenseInfo('00205885-v', 2), SenseInfo('00199912-v', 0) ],
"_hangman_n_1_rel" : [ SenseInfo('10159615-n', 0) ],
"_good_a_at-for-of_rel" : [ SenseInfo('01123148-a', 190), SenseInfo('00106020-a', 22), SenseInfo('01129977-a', 12), SenseInfo('01983162-a', 10), SenseInfo('00064787-a', 5), SenseInfo('01586752-a', 4), SenseInfo('02036934-a', 3), SenseInfo('02226162-a', 2), SenseInfo('00523364-a', 2), SenseInfo('00452883-a', 2), SenseInfo('02273643-a', 1), SenseInfo('01661289-a', 1), SenseInfo('01048762-a', 1), SenseInfo('00832784-a', 1), SenseInfo('01808329-a', 0), SenseInfo('01333477-a', 0), SenseInfo('01171213-a', 0), SenseInfo('01166413-a', 0), SenseInfo('01116026-a', 0), SenseInfo('01068306-a', 0), SenseInfo('00775611-a', 0), SenseInfo('01123148-a', 190), SenseInfo('00106020-a', 22), SenseInfo('01129977-a', 12), SenseInfo('01983162-a', 10), SenseInfo('00064787-a', 5), SenseInfo('01586752-a', 4), SenseInfo('02036934-a', 3), SenseInfo('02226162-a', 2), SenseInfo('00523364-a', 2), SenseInfo('00452883-a', 2), SenseInfo('02273643-a', 1), SenseInfo('01661289-a', 1), SenseInfo('01048762-a', 1), SenseInfo('00832784-a', 1), SenseInfo('01808329-a', 0), SenseInfo('01333477-a', 0), SenseInfo('01171213-a', 0), SenseInfo('01166413-a', 0), SenseInfo('01116026-a', 0), SenseInfo('01068306-a', 0), SenseInfo('00775611-a', 0), SenseInfo('01123148-a', 190), SenseInfo('00106020-a', 22), SenseInfo('01129977-a', 12), SenseInfo('01983162-a', 10), SenseInfo('00064787-a', 5), SenseInfo('01586752-a', 4), SenseInfo('02036934-a', 3), SenseInfo('02226162-a', 2), SenseInfo('00523364-a', 2), SenseInfo('00452883-a', 2), SenseInfo('02273643-a', 1), SenseInfo('01661289-a', 1), SenseInfo('01048762-a', 1), SenseInfo('00832784-a', 1), SenseInfo('01808329-a', 0), SenseInfo('01333477-a', 0), SenseInfo('01171213-a', 0), SenseInfo('01166413-a', 0), SenseInfo('01116026-a', 0), SenseInfo('01068306-a', 0), SenseInfo('00775611-a', 0), SenseInfo('01123148-a', 190), SenseInfo('00106020-a', 22), SenseInfo('01129977-a', 12), SenseInfo('01983162-a', 10), SenseInfo('00064787-a', 5), SenseInfo('01586752-a', 4), SenseInfo('02036934-a', 3), SenseInfo('02226162-a', 2), SenseInfo('00523364-a', 2), SenseInfo('00452883-a', 2), SenseInfo('02273643-a', 1), SenseInfo('01661289-a', 1), SenseInfo('01048762-a', 1), SenseInfo('00832784-a', 1), SenseInfo('01808329-a', 0), SenseInfo('01333477-a', 0), SenseInfo('01171213-a', 0), SenseInfo('01166413-a', 0), SenseInfo('01116026-a', 0), SenseInfo('01068306-a', 0), SenseInfo('00775611-a', 0), SenseInfo('01123148-a', 190), SenseInfo('00106020-a', 22), SenseInfo('01129977-a', 12), SenseInfo('01983162-a', 10), SenseInfo('00064787-a', 5), SenseInfo('01586752-a', 4), SenseInfo('02036934-a', 3), SenseInfo('02226162-a', 2), SenseInfo('00523364-a', 2), SenseInfo('00452883-a', 2), SenseInfo('02273643-a', 1), SenseInfo('01661289-a', 1), SenseInfo('01048762-a', 1), SenseInfo('00832784-a', 1), SenseInfo('01808329-a', 0), SenseInfo('01333477-a', 0), SenseInfo('01171213-a', 0), SenseInfo('01166413-a', 0), SenseInfo('01116026-a', 0), SenseInfo('01068306-a', 0), SenseInfo('00775611-a', 0), SenseInfo('01123148-a', 190), SenseInfo('00106020-a', 22), SenseInfo('01129977-a', 12), SenseInfo('01983162-a', 10), SenseInfo('00064787-a', 5), SenseInfo('01586752-a', 4), SenseInfo('02036934-a', 3), SenseInfo('02226162-a', 2), SenseInfo('00523364-a', 2), SenseInfo('00452883-a', 2), SenseInfo('02273643-a', 1), SenseInfo('01661289-a', 1), SenseInfo('01048762-a', 1), SenseInfo('00832784-a', 1), SenseInfo('01808329-a', 0), SenseInfo('01333477-a', 0), SenseInfo('01171213-a', 0), SenseInfo('01166413-a', 0), SenseInfo('01116026-a', 0), SenseInfo('01068306-a', 0), SenseInfo('00775611-a', 0), SenseInfo('01123148-a', 190), SenseInfo('00106020-a', 22), SenseInfo('01129977-a', 12), SenseInfo('01983162-a', 10), SenseInfo('00064787-a', 5), SenseInfo('01586752-a', 4), SenseInfo('02036934-a', 3), SenseInfo('02226162-a', 2), SenseInfo('00523364-a', 2), SenseInfo('00452883-a', 2), SenseInfo('02273643-a', 1), SenseInfo('01661289-a', 1), SenseInfo('01048762-a', 1), SenseInfo('00832784-a', 1), SenseInfo('01808329-a', 0), SenseInfo('01333477-a', 0), SenseInfo('01171213-a', 0), SenseInfo('01166413-a', 0), SenseInfo('01116026-a', 0), SenseInfo('01068306-a', 0), SenseInfo('00775611-a', 0), SenseInfo('01123148-a', 190), SenseInfo('00106020-a', 22), SenseInfo('01129977-a', 12), SenseInfo('01983162-a', 10), SenseInfo('00064787-a', 5), SenseInfo('01586752-a', 4), SenseInfo('02036934-a', 3), SenseInfo('02226162-a', 2), SenseInfo('00523364-a', 2), SenseInfo('00452883-a', 2), SenseInfo('02273643-a', 1), SenseInfo('01661289-a', 1), SenseInfo('01048762-a', 1), SenseInfo('00832784-a', 1), SenseInfo('01808329-a', 0), SenseInfo('01333477-a', 0), SenseInfo('01171213-a', 0), SenseInfo('01166413-a', 0), SenseInfo('01116026-a', 0), SenseInfo('01068306-a', 0), SenseInfo('00775611-a', 0) ],
"_painstaking_a_1_rel" : [ SenseInfo('00310138-a', 0) ],
"_terminal_a_1_rel" : [ SenseInfo('02812306-a', 0), SenseInfo('02812147-a', 0), SenseInfo('01016035-a', 0), SenseInfo('01010271-a', 0), SenseInfo('00994073-a', 0) ],
"_agricultural_a_1_rel" : [ SenseInfo('02790222-a', 6), SenseInfo('02050841-a', 0) ],
"_brown_v_cause_rel" : [ SenseInfo('00320246-v', 1), SenseInfo('00285705-v', 0) ],
"_archerfish_n_1_rel" : [ SenseInfo('02620578-n', 0) ],
"_murky_a_1_rel" : [ SenseInfo('00433529-a', 2), SenseInfo('00276689-a', 0), SenseInfo('00433529-a', 2), SenseInfo('00276689-a', 0), SenseInfo('00433529-a', 2), SenseInfo('00276689-a', 0) ],
"_curfew_n_1_rel" : [ SenseInfo('15180209-n', 0), SenseInfo('06804606-n', 0), SenseInfo('06540527-n', 0) ],
"_decibel_n_1_rel" : [ SenseInfo('13713633-n', 0), SenseInfo('13713633-n', 0) ],
"_modification_n_of_rel" : [ SenseInfo('00199707-n', 2), SenseInfo('03778302-n', 1), SenseInfo('13800801-n', 0), SenseInfo('07296428-n', 0) ],
"_contrivance_n_1_rel" : [ SenseInfo('02729965-n', 2), SenseInfo('05634457-n', 1), SenseInfo('05905802-n', 0), SenseInfo('05727808-n', 0), SenseInfo('03644248-n', 0), SenseInfo('00940709-n', 0) ],
"_indentation_n_1_rel" : [ SenseInfo('13908021-n', 1), SenseInfo('13537894-n', 0), SenseInfo('06389753-n', 0), SenseInfo('00406939-n', 0) ],
"_kd_n_1_rel" : [  ],
"_technique_n_1_rel" : [ SenseInfo('05665146-n', 58), SenseInfo('05643190-n', 4) ],
"_governed_n_1_rel" : [ SenseInfo('08161258-n', 4) ],
"_atremble_a_1_rel" : [  ],
"_purulent_a_1_rel" : [ SenseInfo('02114613-a', 0) ],
"_no_a_1_rel" : [ SenseInfo('02268485-a', 135), SenseInfo('02268485-a', 135), SenseInfo('02268485-a', 135) ],
"_forfeit_v_1_rel" : [ SenseInfo('02303331-v', 2) ],
"_cool_v_down-cause_rel" : [ SenseInfo('00370412-v', 15), SenseInfo('00369864-v', 1), SenseInfo('00370126-v', 0) ],
"_lace_v_with_rel" : [ SenseInfo('01517662-v', 1), SenseInfo('01674717-v', 0), SenseInfo('01674375-v', 0), SenseInfo('01521603-v', 0), SenseInfo('00222135-v', 0), SenseInfo('01517662-v', 1), SenseInfo('01674717-v', 0), SenseInfo('01674375-v', 0), SenseInfo('01521603-v', 0), SenseInfo('00222135-v', 0) ],
"_mph_n_1_rel" : [ SenseInfo('15280346-n', 2), SenseInfo('15284878-n', 1), SenseInfo('15280346-n', 2), SenseInfo('15284878-n', 1) ],
"_drive_v_home_rel" : [ SenseInfo('01930874-v', 56), SenseInfo('01930117-v', 24), SenseInfo('02056971-v', 13), SenseInfo('01516534-v', 13), SenseInfo('02505358-v', 6), SenseInfo('01506157-v', 5), SenseInfo('01646300-v', 4), SenseInfo('01512259-v', 2), SenseInfo('01509584-v', 2), SenseInfo('02406916-v', 1), SenseInfo('01026975-v', 1), SenseInfo('02742232-v', 0), SenseInfo('02408281-v', 0), SenseInfo('02057656-v', 0), SenseInfo('01939553-v', 0), SenseInfo('01930482-v', 0), SenseInfo('01407904-v', 0), SenseInfo('01407722-v', 0), SenseInfo('01310964-v', 0), SenseInfo('01181741-v', 0), SenseInfo('01142636-v', 0), SenseInfo('01142490-v', 0) ],
"_skipper_n_1_rel" : [ SenseInfo('10607824-n', 0), SenseInfo('10298912-n', 0), SenseInfo('09892831-n', 0) ],
"_instability_n_1_rel" : [ SenseInfo('13975659-n', 1), SenseInfo('04806067-n', 1), SenseInfo('14004149-n', 0), SenseInfo('04775747-n', 0) ],
"_diffraction_n_of_rel" : [ SenseInfo('11446934-n', 1) ],
"_disgrace_v_1_rel" : [ SenseInfo('02547225-v', 2), SenseInfo('01800422-v', 0), SenseInfo('00847478-v', 0) ],
"_lowlying_a_1_rel" : [  ],
"_bravo_a_1_rel" : [ SenseInfo('09813696-n', 0), SenseInfo('06692834-n', 0) ],
"_protect_v_1_rel" : [ SenseInfo('01128193-v', 43), SenseInfo('01129710-v', 1), SenseInfo('01128193-v', 43), SenseInfo('01129710-v', 1), SenseInfo('01128193-v', 43), SenseInfo('01129710-v', 1) ],
"_razorback_a_1_rel" : [ SenseInfo('00200603-a', 0) ],
"_ya_a_1_rel" : [  ],
"_term_v_1_rel" : [ SenseInfo('01029642-v', 15), SenseInfo('01029642-v', 15) ],
"_bumblebee_n_1_rel" : [ SenseInfo('02209624-n', 13) ],
"_semi_a_1_rel" : [ SenseInfo('07467393-n', 0), SenseInfo('04467665-n', 0), SenseInfo('04172342-n', 0), SenseInfo('07467393-n', 0), SenseInfo('04467665-n', 0), SenseInfo('04172342-n', 0) ],
"_ancient_n_1_rel" : [ SenseInfo('09793248-n', 0), SenseInfo('09793141-n', 0) ],
"_coefficient_n_1_rel" : [ SenseInfo('13586122-n', 4) ],
"_tablet_n_1_rel" : [ SenseInfo('04381302-n', 1), SenseInfo('14973133-n', 0), SenseInfo('04381183-n', 0), SenseInfo('03936568-n', 0) ],
"_aim_n_1_rel" : [ SenseInfo('05982152-n', 12), SenseInfo('05981230-n', 4), SenseInfo('00815644-n', 4), SenseInfo('08680888-n', 0) ],
"_adventurous_a_1_rel" : [ SenseInfo('00065791-a', 1) ],
"_metaphysical_a_1_rel" : [ SenseInfo('02865814-a', 2), SenseInfo('01576729-a', 1), SenseInfo('00862067-a', 0), SenseInfo('02865814-a', 2), SenseInfo('01576729-a', 1), SenseInfo('00862067-a', 0) ],
"_persuasion_n_1_rel" : [ SenseInfo('07245125-n', 0), SenseInfo('05945642-n', 0) ],
"_scenery_n_1_rel" : [ SenseInfo('04145056-n', 3), SenseInfo('08646787-n', 1) ],
"_sack_v_out_rel" : [ SenseInfo('02345048-v', 1), SenseInfo('02402825-v', 0), SenseInfo('02291258-v', 0), SenseInfo('01486151-v', 0) ],
"_significantly_x_deg_rel" : [ SenseInfo('00509970-r', 6), SenseInfo('00006259-r', 3), SenseInfo('00367868-r', 0) ],
"_web_n_of_rel" : [ SenseInfo('09477037-n', 1), SenseInfo('04568557-n', 1), SenseInfo('01897991-n', 1), SenseInfo('08434259-n', 0), SenseInfo('04604276-n', 0), SenseInfo('04568713-n', 0), SenseInfo('01898328-n', 0) ],
"_unravel_v_cause_rel" : [ SenseInfo('01520844-v', 1), SenseInfo('01521367-v', 0), SenseInfo('00332672-v', 0) ],
"_voucher_n_1_rel" : [ SenseInfo('10760763-n', 0), SenseInfo('06675691-n', 0), SenseInfo('06518068-n', 0) ],
"_adjective_a_1_rel" : [ SenseInfo('02936020-a', 0), SenseInfo('00055340-a', 0) ],
"_robbery_n_of_rel" : [ SenseInfo('00781685-n', 3), SenseInfo('00966599-n', 0) ],
"_splinter_n_1_rel" : [ SenseInfo('09442838-n', 3) ],
"_eddy_n_1_rel" : [ SenseInfo('10948656-n', 0), SenseInfo('07432973-n', 0) ],
"_unseasoned_a_1_rel" : [ SenseInfo('01495181-a', 0), SenseInfo('02400125-a', 0), SenseInfo('00937732-a', 0), SenseInfo('01495181-a', 0), SenseInfo('02400125-a', 0), SenseInfo('00937732-a', 0) ],
"_dry_v_up_rel" : [ SenseInfo('00218475-v', 12), SenseInfo('00219403-v', 11), SenseInfo('00218475-v', 12), SenseInfo('00219403-v', 11) ],
"_ghetto_n_1_rel" : [ SenseInfo('08578951-n', 5), SenseInfo('13963342-n', 0), SenseInfo('08549292-n', 0) ],
"_trooper_n_1_rel" : [ SenseInfo('09902611-n', 9), SenseInfo('10730542-n', 1), SenseInfo('10730728-n', 0), SenseInfo('09902353-n', 0) ],
"_logical_a_1_rel" : [ SenseInfo('01430111-a', 6), SenseInfo('02499301-a', 5), SenseInfo('00464513-a', 0), SenseInfo('01925708-a', 0) ],
"_mainstream_a_1_rel" : [ SenseInfo('05955186-n', 0) ],
"_turn_v_down_rel" : [ SenseInfo('01907258-v', 187), SenseInfo('00146138-v', 21), SenseInfo('02626604-v', 12), SenseInfo('02089984-v', 8), SenseInfo('00138508-v', 7), SenseInfo('01909812-v', 5), SenseInfo('00125841-v', 5), SenseInfo('01436518-v', 2), SenseInfo('02096167-v', 1), SenseInfo('02089420-v', 1), SenseInfo('01952208-v', 1), SenseInfo('01741864-v', 1), SenseInfo('01584450-v', 1), SenseInfo('00282523-v', 1), SenseInfo('00091124-v', 1), SenseInfo('02626934-v', 0), SenseInfo('02562425-v', 0), SenseInfo('02211948-v', 0), SenseInfo('02090435-v', 0), SenseInfo('01951937-v', 0), SenseInfo('01280014-v', 0), SenseInfo('01225215-v', 0), SenseInfo('01151889-v', 0), SenseInfo('00794640-v', 0), SenseInfo('00458471-v', 0), SenseInfo('00248387-v', 0) ],
"_shiver_v_1_rel" : [ SenseInfo('01888946-v', 5), SenseInfo('00014201-v', 4), SenseInfo('01888946-v', 5), SenseInfo('00014201-v', 4) ],
"_judgment_n_1_rel" : [ SenseInfo('05837957-n', 19), SenseInfo('00874067-n', 11), SenseInfo('01187810-n', 4), SenseInfo('05789432-n', 3), SenseInfo('06551784-n', 1), SenseInfo('04892084-n', 1), SenseInfo('05614175-n', 0), SenseInfo('05837957-n', 19), SenseInfo('00874067-n', 11), SenseInfo('01187810-n', 4), SenseInfo('05789432-n', 3), SenseInfo('06551784-n', 1), SenseInfo('04892084-n', 1), SenseInfo('05614175-n', 0), SenseInfo('05837957-n', 19), SenseInfo('00874067-n', 11), SenseInfo('01187810-n', 4), SenseInfo('05789432-n', 3), SenseInfo('06551784-n', 1), SenseInfo('04892084-n', 1), SenseInfo('05614175-n', 0) ],
"_peahen_n_1_rel" : [ SenseInfo('01806297-n', 0) ],
"_officials_a_1_rel" : [ SenseInfo('01632537-a', 10), SenseInfo('02991463-a', 1), SenseInfo('01634736-a', 1), SenseInfo('01959918-a', 0), SenseInfo('01636363-a', 0), SenseInfo('01632537-a', 10), SenseInfo('02991463-a', 1), SenseInfo('01634736-a', 1), SenseInfo('01959918-a', 0), SenseInfo('01636363-a', 0) ],
"_build_v_up_rel" : [ SenseInfo('01654628-v', 123), SenseInfo('00252990-v', 11), SenseInfo('01655505-v', 4), SenseInfo('00447158-v', 1), SenseInfo('02443424-v', 0), SenseInfo('01739099-v', 0), SenseInfo('01685601-v', 0), SenseInfo('00637115-v', 0), SenseInfo('00253277-v', 0), SenseInfo('00226882-v', 0), SenseInfo('01654628-v', 123), SenseInfo('00252990-v', 11), SenseInfo('01655505-v', 4), SenseInfo('00447158-v', 1), SenseInfo('02443424-v', 0), SenseInfo('01739099-v', 0), SenseInfo('01685601-v', 0), SenseInfo('00637115-v', 0), SenseInfo('00253277-v', 0), SenseInfo('00226882-v', 0) ],
"_wear_v_on_rel" : [ SenseInfo('00052374-v', 83), SenseInfo('00047745-v', 22), SenseInfo('02740034-v', 6), SenseInfo('00469382-v', 2), SenseInfo('00047610-v', 2), SenseInfo('02705132-v', 1), SenseInfo('01369346-v', 0), SenseInfo('00075021-v', 0), SenseInfo('00050652-v', 0) ],
"_unfriendly_a_1_rel" : [ SenseInfo('01078178-a', 0), SenseInfo('01076793-a', 0), SenseInfo('01246388-a', 0), SenseInfo('01243373-a', 0), SenseInfo('01078178-a', 0), SenseInfo('01076793-a', 0), SenseInfo('01246388-a', 0), SenseInfo('01243373-a', 0) ],
"_dominate_v_1_rel" : [ SenseInfo('02644234-v', 9), SenseInfo('02646931-v', 6), SenseInfo('02539334-v', 6), SenseInfo('02744280-v', 0), SenseInfo('02696129-v', 0), SenseInfo('02644234-v', 9), SenseInfo('02646931-v', 6), SenseInfo('02539334-v', 6), SenseInfo('02744280-v', 0), SenseInfo('02696129-v', 0) ],
"_confluence_n_1_rel" : [ SenseInfo('08542634-n', 0), SenseInfo('00380881-n', 0), SenseInfo('00147091-n', 0) ],
"_phony_a_1_rel" : [ SenseInfo('01117477-a', 6), SenseInfo('01117477-a', 6), SenseInfo('01117477-a', 6) ],
"_heavies_n_1_rel" : [ SenseInfo('10167361-n', 0), SenseInfo('05929582-n', 0), SenseInfo('10167361-n', 0), SenseInfo('05929582-n', 0) ],
"_successor_n_to_rel" : [ SenseInfo('10671736-n', 4), SenseInfo('05696803-n', 2), SenseInfo('10671613-n', 0) ],
"_printer_n_of_rel" : [ SenseInfo('10475297-n', 0), SenseInfo('04004767-n', 0), SenseInfo('04004475-n', 0) ],
"_pleading_n_1_rel" : [ SenseInfo('06559365-n', 0) ],
"_rise_n_i_rel" : [ SenseInfo('07324917-n', 8), SenseInfo('00324384-n', 3), SenseInfo('09206985-n', 1), SenseInfo('07445480-n', 1), SenseInfo('05110185-n', 1), SenseInfo('05068918-n', 1), SenseInfo('07348399-n', 0), SenseInfo('07327288-n', 0), SenseInfo('05110408-n', 0), SenseInfo('00364260-n', 0) ],
"_inquire_v_about_rel" : [ SenseInfo('00784342-v', 13), SenseInfo('00729378-v', 4), SenseInfo('00785962-v', 0) ],
"_leisure_n_1_rel" : [ SenseInfo('15137676-n', 3), SenseInfo('01065286-n', 2) ],
"_pilot_n_of_rel" : [ SenseInfo('10433164-n', 6), SenseInfo('10433452-n', 0), SenseInfo('06620906-n', 0), SenseInfo('05938400-n', 0), SenseInfo('03939281-n', 0), SenseInfo('03328201-n', 0) ],
"_organ_n_1_rel" : [ SenseInfo('05297523-n', 8), SenseInfo('08349350-n', 1), SenseInfo('03273551-n', 1), SenseInfo('06595056-n', 0), SenseInfo('03854065-n', 0), SenseInfo('03494537-n', 0) ],
"_venture_v_1_rel" : [ SenseInfo('02373336-v', 5), SenseInfo('00916909-v', 4), SenseInfo('02545272-v', 0), SenseInfo('02373336-v', 5), SenseInfo('00916909-v', 4), SenseInfo('02545272-v', 0), SenseInfo('02373336-v', 5), SenseInfo('00916909-v', 4), SenseInfo('02545272-v', 0), SenseInfo('02373336-v', 5), SenseInfo('00916909-v', 4), SenseInfo('02545272-v', 0) ],
"_choke_v_1_rel" : [ SenseInfo('00002724-v', 8), SenseInfo('01570562-v', 2), SenseInfo('01570744-v', 1), SenseInfo('00077950-v', 1), SenseInfo('00077698-v', 1), SenseInfo('02529669-v', 0), SenseInfo('02423999-v', 0), SenseInfo('01478603-v', 0), SenseInfo('01476180-v', 0), SenseInfo('00391203-v', 0), SenseInfo('00391021-v', 0), SenseInfo('00358431-v', 0), SenseInfo('00173159-v', 0), SenseInfo('00077606-v', 0) ],
"_widow_n_1_rel" : [ SenseInfo('10780284-n', 4) ],
"_on-board_a_1_rel" : [  ],
"_disco_n_1_rel" : [ SenseInfo('07059626-n', 0), SenseInfo('03206282-n', 0) ],
"_serviceable_a_1_rel" : [ SenseInfo('02123812-a', 2), SenseInfo('02496534-a', 0), SenseInfo('01835843-a', 0) ],
"_lash_v_at_rel" : [ SenseInfo('01411085-v', 4), SenseInfo('01877946-v', 0), SenseInfo('01398032-v', 0), SenseInfo('01303707-v', 0) ],
"_cushion_v_1_rel" : [ SenseInfo('01576917-v', 2) ],
"_sawhorse_n_1_rel" : [ SenseInfo('04140631-n', 1) ],
"_buster_n_1_rel" : [ SenseInfo('10083358-n', 0), SenseInfo('09883740-n', 0), SenseInfo('09883630-n', 0), SenseInfo('09883452-n', 0), SenseInfo('09828600-n', 0) ],
"_pink_a_1_rel" : [ SenseInfo('00379595-a', 12), SenseInfo('00379595-a', 12), SenseInfo('00379595-a', 12) ],
"_rear_v_1_rel" : [ SenseInfo('01981623-v', 7), SenseInfo('02539788-v', 2), SenseInfo('02696801-v', 1), SenseInfo('01982866-v', 0), SenseInfo('01661243-v', 0) ],
"_hovertrain_n_1_rel" : [  ],
"_zenith_n_1_rel" : [ SenseInfo('08684769-n', 1) ],
"_say_v_loc_rel" : [ SenseInfo('01009240-v', 1861), SenseInfo('01016002-v', 254), SenseInfo('00917300-v', 29), SenseInfo('02730813-v', 8), SenseInfo('00746718-v', 8), SenseInfo('00978549-v', 4), SenseInfo('00928959-v', 2), SenseInfo('00979870-v', 1), SenseInfo('01009821-v', 0), SenseInfo('00945499-v', 0), SenseInfo('00923197-v', 0) ],
"_awake_v_cause_rel" : [ SenseInfo('00018526-v', 7) ],
"_seaman_n_1_rel" : [ SenseInfo('10294602-n', 2), SenseInfo('11290653-n', 0) ],
"_cruise_n_1_rel" : [ SenseInfo('00312932-n', 0) ],
"_materialize_v_1_rel" : [ SenseInfo('00344174-v', 3) ],
"_mother_n_of_rel" : [ SenseInfo('10332385-n', 100), SenseInfo('15106674-n', 0), SenseInfo('10332953-n', 0), SenseInfo('10332861-n', 0), SenseInfo('05835292-n', 0) ],
"_usable_a_1_rel" : [ SenseInfo('02496674-a', 3), SenseInfo('02124253-a', 0), SenseInfo('00777650-a', 0) ],
"_prop_v_open_rel" : [ SenseInfo('01219004-v', 1) ],
"_backchannel_n_1_rel" : [  ],
"_kindle_v_1_rel" : [ SenseInfo('02761685-v', 0), SenseInfo('02761372-v', 0), SenseInfo('01759326-v', 0) ],
"_malicious_a_1_rel" : [ SenseInfo('00224731-a', 0) ],
"_mass_v_cause_rel" : [ SenseInfo('02024168-v', 3) ],
"_casual_a_1_rel" : [ SenseInfo('00545746-a', 3), SenseInfo('01798484-a', 2), SenseInfo('01044557-a', 2), SenseInfo('01798162-a', 1), SenseInfo('00312234-a', 1), SenseInfo('01961205-a', 0), SenseInfo('01190484-a', 0), SenseInfo('01044730-a', 0), SenseInfo('00749749-a', 0), SenseInfo('00545746-a', 3), SenseInfo('01798484-a', 2), SenseInfo('01044557-a', 2), SenseInfo('01798162-a', 1), SenseInfo('00312234-a', 1), SenseInfo('01961205-a', 0), SenseInfo('01190484-a', 0), SenseInfo('01044730-a', 0), SenseInfo('00749749-a', 0) ],
"_outboard+of_p_rel" : [  ],
"_from_p_rel" : [  ],
"_look_v_over_rel" : [ SenseInfo('02130524-v', 274), SenseInfo('02133435-v', 126), SenseInfo('00033599-v', 25), SenseInfo('02153709-v', 8), SenseInfo('02693319-v', 1), SenseInfo('02549581-v', 1), SenseInfo('00929362-v', 1), SenseInfo('00720063-v', 1), SenseInfo('02658447-v', 0), SenseInfo('00712708-v', 0) ],
"_mix_n_of_rel" : [ SenseInfo('07882886-n', 0), SenseInfo('07374756-n', 0), SenseInfo('00380083-n', 0) ],
"_objet+d'art_n_1_rel" : [ SenseInfo('03838535-n', 1), SenseInfo('03838535-n', 1), SenseInfo('03838535-n', 1), SenseInfo('03838535-n', 1) ],
"_in+so+far+as_x_rel" : [  ],
"_permeate_v_into_rel" : [ SenseInfo('01229071-v', 2), SenseInfo('01457954-v', 0), SenseInfo('01227235-v', 0) ],
"_squeak_v_cause_rel" : [ SenseInfo('02171664-v', 3) ],
"_packboarding_n_1_rel" : [  ],
"_consortium_n_of_rel" : [ SenseInfo('08236438-n', 0) ],
"_noble_a_1_rel" : [ SenseInfo('01283508-a', 3), SenseInfo('01590115-a', 2), SenseInfo('01588172-a', 1), SenseInfo('01930244-a', 0), SenseInfo('01283508-a', 3), SenseInfo('01590115-a', 2), SenseInfo('01588172-a', 1), SenseInfo('01930244-a', 0), SenseInfo('01283508-a', 3), SenseInfo('01590115-a', 2), SenseInfo('01588172-a', 1), SenseInfo('01930244-a', 0) ],
"_bawl_v_out_rel" : [ SenseInfo('01048569-v', 8), SenseInfo('01046480-v', 0), SenseInfo('00066862-v', 0) ],
"_set_v_in_rel" : [ SenseInfo('01494310-v', 30), SenseInfo('00699815-v', 29), SenseInfo('00947077-v', 12), SenseInfo('01062395-v', 10), SenseInfo('00298896-v', 9), SenseInfo('01607445-v', 6), SenseInfo('00406243-v', 5), SenseInfo('00298556-v', 5), SenseInfo('01711749-v', 3), SenseInfo('01970646-v', 2), SenseInfo('01706129-v', 2), SenseInfo('01567275-v', 2), SenseInfo('01628899-v', 1), SenseInfo('00442669-v', 1), SenseInfo('01744888-v', 0), SenseInfo('01613239-v', 0), SenseInfo('01530273-v', 0), SenseInfo('01247322-v', 0), SenseInfo('01115006-v', 0), SenseInfo('00673448-v', 0), SenseInfo('00408085-v', 0), SenseInfo('00407848-v', 0), SenseInfo('00296178-v', 0), SenseInfo('00056188-v', 0), SenseInfo('00038849-v', 0) ],
"_semiquaver_n_1_rel" : [ SenseInfo('06871534-n', 0) ],
"_crucial_a_for_rel" : [ SenseInfo('00655779-a', 6), SenseInfo('01487943-a', 1), SenseInfo('01276150-a', 0), SenseInfo('00655779-a', 6), SenseInfo('01487943-a', 1), SenseInfo('01276150-a', 0), SenseInfo('00655779-a', 6), SenseInfo('01487943-a', 1), SenseInfo('01276150-a', 0), SenseInfo('00655779-a', 6), SenseInfo('01487943-a', 1), SenseInfo('01276150-a', 0) ],
"_shear_n_1_rel" : [ SenseInfo('11506738-n', 21), SenseInfo('04186709-n', 0) ],
"_statuary_n_1_rel" : [ SenseInfo('07958727-n', 1) ],
"_broaden_v_1_rel" : [ SenseInfo('00317569-v', 9), SenseInfo('00540235-v', 1), SenseInfo('00436404-v', 1), SenseInfo('00317468-v', 1), SenseInfo('00317569-v', 9), SenseInfo('00540235-v', 1), SenseInfo('00436404-v', 1), SenseInfo('00317468-v', 1) ],
"_dervish_n_1_rel" : [ SenseInfo('10006337-n', 1) ],
"_backpack_v_1_rel" : [ SenseInfo('01926031-v', 0) ],
"_victim_n_of_rel" : [ SenseInfo('10752093-n', 8), SenseInfo('10752480-n', 4) ],
"_guidance_n_1_rel" : [ SenseInfo('06650701-n', 8), SenseInfo('01144876-n', 4), SenseInfo('00815320-n', 1) ],
"_rubbish_n_1_rel" : [ SenseInfo('14857497-n', 1), SenseInfo('06611998-n', 0) ],
"_alluvial_a_1_rel" : [ SenseInfo('03006126-a', 0) ],
"_robber_n_1_rel" : [ SenseInfo('10534586-n', 5) ],
"_frame_v_as_rel" : [ SenseInfo('01586850-v', 4), SenseInfo('02711835-v', 3), SenseInfo('02578008-v', 1), SenseInfo('00981276-v', 1), SenseInfo('00706804-v', 1), SenseInfo('01655763-v', 0), SenseInfo('01586850-v', 4), SenseInfo('02711835-v', 3), SenseInfo('02578008-v', 1), SenseInfo('00981276-v', 1), SenseInfo('00706804-v', 1), SenseInfo('01655763-v', 0) ],
"_gig_n_1_rel" : [ SenseInfo('03436891-n', 1), SenseInfo('04271148-n', 0), SenseInfo('03436990-n', 0), SenseInfo('03436772-n', 0), SenseInfo('03436656-n', 0), SenseInfo('00271155-n', 0) ],
"_donation_n_1_rel" : [ SenseInfo('13270038-n', 2), SenseInfo('01089778-n', 1) ],
"_dusty_a_1_rel" : [ SenseInfo('01696346-a', 0), SenseInfo('01689580-a', 0), SenseInfo('01696346-a', 0), SenseInfo('01689580-a', 0), SenseInfo('01696346-a', 0), SenseInfo('01689580-a', 0) ],
"_laugh_v_1_rel" : [ SenseInfo('00031820-v', 64) ],
"_vary_v_1_rel" : [ SenseInfo('00123170-v', 26), SenseInfo('02661252-v', 20), SenseInfo('02662297-v', 7), SenseInfo('00436879-v', 5) ],
"_chip_v_cause_rel" : [ SenseInfo('01259691-v', 1), SenseInfo('01259005-v', 1), SenseInfo('01598140-v', 0), SenseInfo('01260291-v', 0), SenseInfo('01259458-v', 0) ],
"_pat_v_down_rel" : [ SenseInfo('01243661-v', 11), SenseInfo('01233027-v', 2) ],
"_intimate_v_to_rel" : [ SenseInfo('00927711-v', 4), SenseInfo('00930806-v', 2), SenseInfo('00927711-v', 4), SenseInfo('00930806-v', 2) ],
"_quit_v_prd_rel" : [ SenseInfo('02680814-v', 13), SenseInfo('02382367-v', 1), SenseInfo('02008396-v', 1), SenseInfo('02227487-v', 0), SenseInfo('01083044-v', 0) ],
"_doctrine_n_1_rel" : [ SenseInfo('05943300-n', 20) ],
"_long+before_a_1_rel" : [  ],
"_vantage_n_1_rel" : [ SenseInfo('08677075-n', 0), SenseInfo('05155821-n', 0) ],
"_righteous_a_1_rel" : [ SenseInfo('02036578-a', 1), SenseInfo('01549087-a', 0), SenseInfo('02036578-a', 1), SenseInfo('01549087-a', 0) ],
"_scale_v_up_rel" : [ SenseInfo('02728388-v', 1), SenseInfo('01744082-v', 1), SenseInfo('02207036-v', 0), SenseInfo('01999082-v', 0), SenseInfo('01922466-v', 0), SenseInfo('01264148-v', 0), SenseInfo('00490428-v', 0), SenseInfo('00319406-v', 0), SenseInfo('02728388-v', 1), SenseInfo('01744082-v', 1), SenseInfo('02207036-v', 0), SenseInfo('01999082-v', 0), SenseInfo('01922466-v', 0), SenseInfo('01264148-v', 0), SenseInfo('00490428-v', 0), SenseInfo('00319406-v', 0) ],
"_track_v_1_rel" : [ SenseInfo('02078453-v', 2), SenseInfo('02197629-v', 1), SenseInfo('02001858-v', 1), SenseInfo('01912159-v', 0), SenseInfo('01618468-v', 0), SenseInfo('02078453-v', 2), SenseInfo('02197629-v', 1), SenseInfo('02001858-v', 1), SenseInfo('01912159-v', 0), SenseInfo('01618468-v', 0), SenseInfo('02078453-v', 2), SenseInfo('02197629-v', 1), SenseInfo('02001858-v', 1), SenseInfo('01912159-v', 0), SenseInfo('01618468-v', 0) ],
"_deserve_v_1_rel" : [ SenseInfo('02646378-v', 29), SenseInfo('02646378-v', 29), SenseInfo('02646378-v', 29), SenseInfo('02646378-v', 29) ],
"_salvage_n_1_rel" : [ SenseInfo('13247554-n', 0), SenseInfo('00096343-n', 0), SenseInfo('00096211-n', 0) ],
"_buy_v_off_rel" : [ SenseInfo('02207206-v', 102), SenseInfo('02284096-v', 2), SenseInfo('02646757-v', 0), SenseInfo('02212103-v', 0), SenseInfo('00683670-v', 0) ],
"_group_v_1_rel" : [ SenseInfo('00656576-v', 4), SenseInfo('01089878-v', 1) ],
"_general-purpose_a_1_rel" : [ SenseInfo('01102058-a', 1), SenseInfo('01102058-a', 1) ],
"_ray_v_1_rel" : [ SenseInfo('02768431-v', 0), SenseInfo('02686952-v', 0), SenseInfo('00291444-v', 0) ],
"_secondary_a_1_rel" : [ SenseInfo('01853461-a', 11), SenseInfo('02100968-a', 0), SenseInfo('01857956-a', 0), SenseInfo('01473558-a', 0), SenseInfo('00793592-a', 0) ],
"_checking_n_1_rel" : [  ],
"_marsh_n_1_rel" : [ SenseInfo('09347779-n', 1), SenseInfo('11158651-n', 0), SenseInfo('11158533-n', 0) ],
"_layer_v_1_rel" : [ SenseInfo('01262113-v', 3) ],
"_wastebasket_n_1_rel" : [ SenseInfo('04555700-n', 3) ],
"_criminal_a_1_rel" : [ SenseInfo('02035765-a', 1), SenseInfo('01322323-a', 1), SenseInfo('01402763-a', 0) ],
"_system_n_1_rel" : [ SenseInfo('04377057-n', 43), SenseInfo('08435388-n', 23), SenseInfo('14981183-n', 14), SenseInfo('05661996-n', 10), SenseInfo('05726596-n', 8), SenseInfo('05237227-n', 7), SenseInfo('05902872-n', 6), SenseInfo('05219097-n', 1), SenseInfo('04768657-n', 0) ],
"_destroyer_n_1_rel" : [ SenseInfo('03180504-n', 1), SenseInfo('10008716-n', 0) ],
"_equivalence_n_1_rel" : [ SenseInfo('13946760-n', 1), SenseInfo('04748273-n', 0), SenseInfo('04746842-n', 0) ],
"_comparative_n_1_rel" : [ SenseInfo('06322693-n', 0) ],
"_as+of+yet_a_1_rel" : [  ],
"_tug_n_1_rel" : [ SenseInfo('00115500-n', 1), SenseInfo('04495843-n', 0) ],
"_totter_n_1_rel" : [  ],
"_rehearse_v_1_rel" : [ SenseInfo('01723224-v', 5) ],
"_phrase_v_1_rel" : [ SenseInfo('00980453-v', 3), SenseInfo('00961114-v', 0) ],
"_motorbike_n_1_rel" : [ SenseInfo('03769722-n', 0) ],
"_endearment_n_1_rel" : [ SenseInfo('01227805-n', 0) ],
"_pull_v_apart_rel" : [ SenseInfo('01448100-v', 44), SenseInfo('01505254-v', 8), SenseInfo('02057499-v', 6), SenseInfo('01609287-v', 3), SenseInfo('02582615-v', 2), SenseInfo('01995211-v', 2), SenseInfo('02057337-v', 1), SenseInfo('00071803-v', 1), SenseInfo('02103162-v', 0), SenseInfo('01947247-v', 0), SenseInfo('01858573-v', 0), SenseInfo('01573276-v', 0), SenseInfo('01407059-v', 0), SenseInfo('01384275-v', 0), SenseInfo('01351170-v', 0), SenseInfo('01148710-v', 0), SenseInfo('00571596-v', 0), SenseInfo('01448100-v', 44), SenseInfo('01505254-v', 8), SenseInfo('02057499-v', 6), SenseInfo('01609287-v', 3), SenseInfo('02582615-v', 2), SenseInfo('01995211-v', 2), SenseInfo('02057337-v', 1), SenseInfo('00071803-v', 1), SenseInfo('02103162-v', 0), SenseInfo('01947247-v', 0), SenseInfo('01858573-v', 0), SenseInfo('01573276-v', 0), SenseInfo('01407059-v', 0), SenseInfo('01384275-v', 0), SenseInfo('01351170-v', 0), SenseInfo('01148710-v', 0), SenseInfo('00571596-v', 0) ],
"_unmarried_a_1_rel" : [ SenseInfo('01482228-a', 2), SenseInfo('01482228-a', 2) ],
"_buck_v_for_rel" : [ SenseInfo('02531500-v', 2), SenseInfo('02378851-v', 1), SenseInfo('02055267-v', 0), SenseInfo('01884383-v', 0) ],
"_ladykiller_n_1_rel" : [  ],
"_dirty_a_1_rel" : [ SenseInfo('00419289-a', 12), SenseInfo('00424370-a', 2), SenseInfo('01587474-a', 1), SenseInfo('00426608-a', 0), SenseInfo('02114296-a', 0), SenseInfo('01909077-a', 0), SenseInfo('01405390-a', 0), SenseInfo('01403012-a', 0), SenseInfo('01245778-a', 0), SenseInfo('00957743-a', 0), SenseInfo('00621857-a', 0), SenseInfo('00305590-a', 0), SenseInfo('00419289-a', 12), SenseInfo('00424370-a', 2), SenseInfo('01587474-a', 1), SenseInfo('00426608-a', 0), SenseInfo('02114296-a', 0), SenseInfo('01909077-a', 0), SenseInfo('01405390-a', 0), SenseInfo('01403012-a', 0), SenseInfo('01245778-a', 0), SenseInfo('00957743-a', 0), SenseInfo('00621857-a', 0), SenseInfo('00305590-a', 0), SenseInfo('00419289-a', 12), SenseInfo('00424370-a', 2), SenseInfo('01587474-a', 1), SenseInfo('00426608-a', 0), SenseInfo('02114296-a', 0), SenseInfo('01909077-a', 0), SenseInfo('01405390-a', 0), SenseInfo('01403012-a', 0), SenseInfo('01245778-a', 0), SenseInfo('00957743-a', 0), SenseInfo('00621857-a', 0), SenseInfo('00305590-a', 0) ],
"_irrigate_v_1_rel" : [ SenseInfo('00228236-v', 2), SenseInfo('00079951-v', 0) ],
"_will_v_to_rel" : [ SenseInfo('00746366-v', 3), SenseInfo('00698398-v', 2), SenseInfo('02229055-v', 0) ],
"_shove_v_in_rel" : [ SenseInfo('01871680-v', 6), SenseInfo('01584701-v', 5), SenseInfo('02094569-v', 0) ],
"_barbershop_n_1_rel" : [ SenseInfo('02791270-n', 0) ],
"_unbreakable_a_1_rel" : [ SenseInfo('00709744-a', 1), SenseInfo('00709744-a', 1) ],
"_victorian_n_1_rel" : [ SenseInfo('10753061-n', 0) ],
"_cotyledon_n_1_rel" : [ SenseInfo('11686398-n', 0) ],
"_hard+up_a_1_rel" : [ SenseInfo('02023661-a', 0) ],
"_solid_a_1_rel" : [ SenseInfo('01125006-a', 8), SenseInfo('02260035-a', 6), SenseInfo('02263680-a', 5), SenseInfo('01200339-a', 4), SenseInfo('00291181-a', 4), SenseInfo('02558528-a', 1), SenseInfo('02275412-a', 1), SenseInfo('01151740-a', 1), SenseInfo('00658166-a', 1), SenseInfo('00434597-a', 1), SenseInfo('02273952-a', 0), SenseInfo('02120276-a', 0), SenseInfo('01993693-a', 0), SenseInfo('01200491-a', 0), SenseInfo('00784215-a', 0), SenseInfo('01125006-a', 8), SenseInfo('02260035-a', 6), SenseInfo('02263680-a', 5), SenseInfo('01200339-a', 4), SenseInfo('00291181-a', 4), SenseInfo('02558528-a', 1), SenseInfo('02275412-a', 1), SenseInfo('01151740-a', 1), SenseInfo('00658166-a', 1), SenseInfo('00434597-a', 1), SenseInfo('02273952-a', 0), SenseInfo('02120276-a', 0), SenseInfo('01993693-a', 0), SenseInfo('01200491-a', 0), SenseInfo('00784215-a', 0) ],
"_new_a_1_rel" : [ SenseInfo('01640850-a', 310), SenseInfo('01687167-a', 36), SenseInfo('00937186-a', 11), SenseInfo('00128733-a', 5), SenseInfo('02070491-a', 3), SenseInfo('02584699-a', 0), SenseInfo('01687965-a', 0), SenseInfo('00821208-a', 0), SenseInfo('00820975-a', 0), SenseInfo('00818008-a', 0), SenseInfo('00024996-a', 0), SenseInfo('01640850-a', 310), SenseInfo('01687167-a', 36), SenseInfo('00937186-a', 11), SenseInfo('00128733-a', 5), SenseInfo('02070491-a', 3), SenseInfo('02584699-a', 0), SenseInfo('01687965-a', 0), SenseInfo('00821208-a', 0), SenseInfo('00820975-a', 0), SenseInfo('00818008-a', 0), SenseInfo('00024996-a', 0), SenseInfo('01640850-a', 310), SenseInfo('01687167-a', 36), SenseInfo('00937186-a', 11), SenseInfo('00128733-a', 5), SenseInfo('02070491-a', 3), SenseInfo('02584699-a', 0), SenseInfo('01687965-a', 0), SenseInfo('00821208-a', 0), SenseInfo('00820975-a', 0), SenseInfo('00818008-a', 0), SenseInfo('00024996-a', 0), SenseInfo('01640850-a', 310), SenseInfo('01687167-a', 36), SenseInfo('00937186-a', 11), SenseInfo('00128733-a', 5), SenseInfo('02070491-a', 3), SenseInfo('02584699-a', 0), SenseInfo('01687965-a', 0), SenseInfo('00821208-a', 0), SenseInfo('00820975-a', 0), SenseInfo('00818008-a', 0), SenseInfo('00024996-a', 0) ],
"_climbable_a_1_rel" : [ SenseInfo('02083391-a', 0), SenseInfo('01725031-a', 0) ],
"_but+only_x_deg_rel" : [  ],
"_domineering_a_1_rel" : [ SenseInfo('00787136-a', 1) ],
"_dereliction_n_of_rel" : [ SenseInfo('04666083-n', 1), SenseInfo('00738966-n', 1) ],
"_direct_a_1_rel" : [ SenseInfo('00760916-a', 23), SenseInfo('00770480-a', 16), SenseInfo('00763901-a', 5), SenseInfo('01416508-a', 0), SenseInfo('00769926-a', 0), SenseInfo('00769239-a', 0), SenseInfo('00763633-a', 0), SenseInfo('01852666-a', 0), SenseInfo('00914808-a', 0), SenseInfo('00005473-a', 0), SenseInfo('00760916-a', 23), SenseInfo('00770480-a', 16), SenseInfo('00763901-a', 5), SenseInfo('01416508-a', 0), SenseInfo('00769926-a', 0), SenseInfo('00769239-a', 0), SenseInfo('00763633-a', 0), SenseInfo('01852666-a', 0), SenseInfo('00914808-a', 0), SenseInfo('00005473-a', 0) ],
"_interesting_a_1_rel" : [ SenseInfo('01343918-a', 27) ],
"_penalize_v_1_rel" : [ SenseInfo('02499629-v', 3) ],
"_bust_v_1_rel" : [ SenseInfo('01369758-v', 1), SenseInfo('02494850-v', 0), SenseInfo('01573515-v', 0), SenseInfo('01369346-v', 0), SenseInfo('00333594-v', 0) ],
"_in+view+of_p_rel" : [  ],
"_mention_n_of_rel" : [ SenseInfo('06766190-n', 8), SenseInfo('06763681-n', 1), SenseInfo('06706317-n', 0), SenseInfo('06766190-n', 8), SenseInfo('06763681-n', 1), SenseInfo('06706317-n', 0) ],
"_impose_v_on_rel" : [ SenseInfo('02560424-v', 12), SenseInfo('00748282-v', 7), SenseInfo('02306462-v', 4), SenseInfo('02560424-v', 12), SenseInfo('00748282-v', 7), SenseInfo('02306462-v', 4), SenseInfo('02560424-v', 12), SenseInfo('00748282-v', 7), SenseInfo('02306462-v', 4) ],
"_along_p_rel" : [ SenseInfo('00068368-r', 25), SenseInfo('00068577-r', 9), SenseInfo('00068986-r', 2), SenseInfo('00068753-r', 2), SenseInfo('00069164-r', 0), SenseInfo('00068368-r', 25), SenseInfo('00068577-r', 9), SenseInfo('00068986-r', 2), SenseInfo('00068753-r', 2), SenseInfo('00069164-r', 0), SenseInfo('00068368-r', 25), SenseInfo('00068577-r', 9), SenseInfo('00068986-r', 2), SenseInfo('00068753-r', 2), SenseInfo('00069164-r', 0) ],
"_abrasive_a_1_rel" : [ SenseInfo('02239289-a', 0), SenseInfo('00090219-a', 0) ],
"_conjure_v_up_rel" : [ SenseInfo('01629958-v', 0), SenseInfo('00759657-v', 0), SenseInfo('00706975-v', 0) ],
"_dry_v_off_rel" : [ SenseInfo('00218475-v', 12), SenseInfo('00219403-v', 11), SenseInfo('00218475-v', 12), SenseInfo('00219403-v', 11) ],
"_housework_n_1_rel" : [ SenseInfo('00580961-n', 1) ],
"_behavioral_a_1_rel" : [ SenseInfo('02941652-a', 1), SenseInfo('02941652-a', 1) ],
"_orthopedic_a_1_rel" : [ SenseInfo('03095068-a', 1) ],
"_nonthreatening_a_1_rel" : [  ],
"_paddle_v_1_rel" : [ SenseInfo('01947887-v', 1), SenseInfo('02419613-v', 0), SenseInfo('01961859-v', 0), SenseInfo('01918803-v', 0), SenseInfo('01420928-v', 0), SenseInfo('01419373-v', 0) ],
"_unsure_a_of_rel" : [ SenseInfo('00339941-a', 0), SenseInfo('00337404-a', 0), SenseInfo('00339941-a', 0), SenseInfo('00337404-a', 0), SenseInfo('00339941-a', 0), SenseInfo('00337404-a', 0), SenseInfo('00339941-a', 0), SenseInfo('00337404-a', 0) ],
"_cloudburst_n_1_rel" : [ SenseInfo('11502102-n', 1) ],
"_credit_v_1_rel" : [ SenseInfo('00727143-v', 4), SenseInfo('00727791-v', 3), SenseInfo('02264752-v', 2), SenseInfo('00683930-v', 1), SenseInfo('00727143-v', 4), SenseInfo('00727791-v', 3), SenseInfo('02264752-v', 2), SenseInfo('00683930-v', 1), SenseInfo('00727143-v', 4), SenseInfo('00727791-v', 3), SenseInfo('02264752-v', 2), SenseInfo('00683930-v', 1) ],
"_postgraduate_n_1_rel" : [ SenseInfo('10141109-n', 0) ],
"_fetal_n_1_rel" : [ SenseInfo('02892819-a', 0) ],
"_university_n_of_rel" : [ SenseInfo('08286163-n', 20), SenseInfo('04511002-n', 14), SenseInfo('08286569-n', 0), SenseInfo('08286163-n', 20), SenseInfo('04511002-n', 14), SenseInfo('08286569-n', 0), SenseInfo('08286163-n', 20), SenseInfo('04511002-n', 14), SenseInfo('08286569-n', 0), SenseInfo('08286163-n', 20), SenseInfo('04511002-n', 14), SenseInfo('08286569-n', 0), SenseInfo('08286163-n', 20), SenseInfo('04511002-n', 14), SenseInfo('08286569-n', 0), SenseInfo('08286163-n', 20), SenseInfo('04511002-n', 14), SenseInfo('08286569-n', 0) ],
"_schematic_a_1_rel" : [ SenseInfo('01980796-a', 3), SenseInfo('01980796-a', 3) ],
"_bear_v_1_rel" : [ SenseInfo('02630871-v', 23), SenseInfo('00056930-v', 17), SenseInfo('00668099-v', 13), SenseInfo('01432601-v', 10), SenseInfo('01652139-v', 6), SenseInfo('02301825-v', 5), SenseInfo('02700867-v', 4), SenseInfo('02291708-v', 4), SenseInfo('00047745-v', 1), SenseInfo('02518161-v', 0), SenseInfo('02302220-v', 0), SenseInfo('01601234-v', 0), SenseInfo('00059019-v', 0), SenseInfo('02630871-v', 23), SenseInfo('00056930-v', 17), SenseInfo('00668099-v', 13), SenseInfo('01432601-v', 10), SenseInfo('01652139-v', 6), SenseInfo('02301825-v', 5), SenseInfo('02700867-v', 4), SenseInfo('02291708-v', 4), SenseInfo('00047745-v', 1), SenseInfo('02518161-v', 0), SenseInfo('02302220-v', 0), SenseInfo('01601234-v', 0), SenseInfo('00059019-v', 0), SenseInfo('02630871-v', 23), SenseInfo('00056930-v', 17), SenseInfo('00668099-v', 13), SenseInfo('01432601-v', 10), SenseInfo('01652139-v', 6), SenseInfo('02301825-v', 5), SenseInfo('02700867-v', 4), SenseInfo('02291708-v', 4), SenseInfo('00047745-v', 1), SenseInfo('02518161-v', 0), SenseInfo('02302220-v', 0), SenseInfo('01601234-v', 0), SenseInfo('00059019-v', 0), SenseInfo('02630871-v', 23), SenseInfo('00056930-v', 17), SenseInfo('00668099-v', 13), SenseInfo('01432601-v', 10), SenseInfo('01652139-v', 6), SenseInfo('02301825-v', 5), SenseInfo('02700867-v', 4), SenseInfo('02291708-v', 4), SenseInfo('00047745-v', 1), SenseInfo('02518161-v', 0), SenseInfo('02302220-v', 0), SenseInfo('01601234-v', 0), SenseInfo('00059019-v', 0) ],
"_perplexing_a_1_rel" : [ SenseInfo('00430756-a', 2) ],
"_columbian_a_1_rel" : [ SenseInfo('03029984-a', 0) ],
"_clipboard_n_1_rel" : [ SenseInfo('03044418-n', 0) ],
"_till_v_1_rel" : [ SenseInfo('01740608-v', 0) ],
"_steal_n_1_rel" : [ SenseInfo('13253751-n', 0), SenseInfo('00725152-n', 0) ],
"_groan_v_1_rel" : [ SenseInfo('01045419-v', 7) ],
"_haul_v_in_rel" : [ SenseInfo('01454810-v', 7), SenseInfo('01452255-v', 5) ],
"_lexeme_n_1_rel" : [ SenseInfo('06306034-n', 0) ],
"_sag_v_1_rel" : [ SenseInfo('01985524-v', 5), SenseInfo('01985757-v', 1) ],
"_mini_a_1_rel" : [ SenseInfo('01432712-a', 0) ],
"_septagenarian_n_1_rel" : [  ],
"_leaf_n_1_rel" : [ SenseInfo('13152742-n', 20), SenseInfo('06256229-n', 0), SenseInfo('03652226-n', 0), SenseInfo('13152742-n', 20), SenseInfo('06256229-n', 0), SenseInfo('03652226-n', 0) ],
"_longtime_a_1_rel" : [ SenseInfo('01640261-a', 0) ],
"_resemble_v_1_rel" : [ SenseInfo('02665282-v', 24) ],
"_drag_v_in_rel" : [ SenseInfo('01453433-v', 16), SenseInfo('01454810-v', 13), SenseInfo('02677797-v', 1), SenseInfo('02099544-v', 1), SenseInfo('02058756-v', 1), SenseInfo('01199009-v', 1), SenseInfo('02101789-v', 0), SenseInfo('01917845-v', 0), SenseInfo('01244692-v', 0), SenseInfo('00783689-v', 0), SenseInfo('00341757-v', 0) ],
"_either+that+or_a_1_rel" : [  ],
"_squeaky-clean_a_1_rel" : [  ],
"_unselfconsciousness_n_1_rel" : [ SenseInfo('05677097-n', 1) ],
"_swirl_v_cause_rel" : [ SenseInfo('02048891-v', 3), SenseInfo('02047650-v', 3) ],
"_comprehensible_a_1_rel" : [ SenseInfo('00532892-a', 0), SenseInfo('00532892-a', 0) ],
"_the+devil_x_rel" : [ SenseInfo('09543353-n', 12), SenseInfo('09542339-n', 5), SenseInfo('07125786-n', 3), SenseInfo('10169419-n', 1), SenseInfo('10329945-n', 0), SenseInfo('01787955-v', 0), SenseInfo('01665507-v', 0) ],
"_bottleneck_n_1_rel" : [ SenseInfo('13912992-n', 1), SenseInfo('02877865-n', 0) ],
"_king+size_a_1_rel" : [ SenseInfo('01388228-a', 0) ],
"_shine_v_out_rel" : [ SenseInfo('02765924-v', 9), SenseInfo('02763740-v', 6), SenseInfo('02162947-v', 5), SenseInfo('02733334-v', 3), SenseInfo('02655958-v', 1), SenseInfo('02161530-v', 1), SenseInfo('02763283-v', 0), SenseInfo('02611976-v', 0), SenseInfo('01829747-v', 0), SenseInfo('01245637-v', 0) ],
"_structural_a_1_rel" : [ SenseInfo('02897335-a', 6), SenseInfo('02897158-a', 2), SenseInfo('01090593-a', 1), SenseInfo('00586060-a', 1), SenseInfo('02949511-a', 0), SenseInfo('02949275-a', 0), SenseInfo('02897335-a', 6), SenseInfo('02897158-a', 2), SenseInfo('01090593-a', 1), SenseInfo('00586060-a', 1), SenseInfo('02949511-a', 0), SenseInfo('02949275-a', 0) ],
"_undock_v_1_rel" : [ SenseInfo('02085971-v', 0), SenseInfo('01306047-v', 0), SenseInfo('02085971-v', 0), SenseInfo('01306047-v', 0) ],
"_deed_n_1_rel" : [ SenseInfo('06545137-n', 1), SenseInfo('00030358-n', 0) ],
"_if+any_p_rel" : [  ],
"_cab_n_1_rel" : [ SenseInfo('02931148-n', 4), SenseInfo('02931013-n', 0), SenseInfo('02930766-n', 0) ],
"_undoubted_a_1_rel" : [  ],
"_steak_n_1_rel" : [ SenseInfo('07657903-n', 2) ],
"_rhinoceros_n_1_rel" : [ SenseInfo('02391994-n', 1) ],
"_cloth_n_1_rel" : [ SenseInfo('03309808-n', 16) ],
"_marshal_v_1_rel" : [ SenseInfo('01988325-v', 1), SenseInfo('01360197-v', 1), SenseInfo('00270215-v', 1), SenseInfo('02000757-v', 0) ],
"_code_v_1_rel" : [ SenseInfo('01589723-v', 1), SenseInfo('00994076-v', 0) ],
"_resplendent_a_1_rel" : [ SenseInfo('00219389-a', 1) ],
"_apiece_p_rel" : [ SenseInfo('00239908-r', 2) ],
"_digitize_v_1_rel" : [ SenseInfo('00563824-v', 0) ],
"_odds-on_a_1_rel" : [ SenseInfo('00893118-a', 0), SenseInfo('00893118-a', 0) ],
"_membranous_a_1_rel" : [ SenseInfo('03085572-a', 0), SenseInfo('01177704-a', 0) ],
"_jargon_n_1_rel" : [ SenseInfo('07157273-n', 1), SenseInfo('14924915-n', 0), SenseInfo('07071017-n', 0) ],
"_missus_n_1_rel" : [ SenseInfo('10323529-n', 0), SenseInfo('10323529-n', 0), SenseInfo('10323529-n', 0), SenseInfo('10323529-n', 0), SenseInfo('10323529-n', 0), SenseInfo('10323529-n', 0) ],
"_downcomer_n_1_rel" : [  ],
"_kimono_n_1_rel" : [ SenseInfo('03617480-n', 0) ],
"unspec_manner_rel" : [  ],
"_leach_n_1_rel" : [ SenseInfo('13506587-n', 0) ],
"_brand_v_1_rel" : [ SenseInfo('02508663-v', 1), SenseInfo('02508245-v', 0), SenseInfo('01588876-v', 0), SenseInfo('01031109-v', 0), SenseInfo('02508663-v', 1), SenseInfo('02508245-v', 0), SenseInfo('01588876-v', 0), SenseInfo('01031109-v', 0) ],
"_interwoven_a_1_rel" : [ SenseInfo('02178348-a', 2) ],
"_criss-cross_n_1_rel" : [ SenseInfo('04681387-n', 0), SenseInfo('04681387-n', 0), SenseInfo('04681387-n', 0) ],
"_heir_n_1_rel" : [ SenseInfo('10168584-n', 3), SenseInfo('10671613-n', 0) ],
"_snag_v_1_rel" : [ SenseInfo('01328212-v', 2), SenseInfo('02353088-v', 0), SenseInfo('01260593-v', 0) ],
"_match_v_with_rel" : [ SenseInfo('02657219-v', 16), SenseInfo('02332627-v', 12), SenseInfo('01292885-v', 6), SenseInfo('02672187-v', 5), SenseInfo('00456740-v', 3), SenseInfo('02594674-v', 0), SenseInfo('01293389-v', 0), SenseInfo('01081152-v', 0), SenseInfo('00456596-v', 0), SenseInfo('00417001-v', 0) ],
"_least_x_deg_rel" : [ SenseInfo('00111758-r', 5), SenseInfo('01556061-a', 2), SenseInfo('05671526-n', 0), SenseInfo('00111758-r', 5), SenseInfo('01556061-a', 2), SenseInfo('05671526-n', 0) ],
"_peseta_n_1_rel" : [ SenseInfo('13690758-n', 0) ],
"_cause_n_of_rel" : [ SenseInfo('07326557-n', 18), SenseInfo('06740402-n', 9), SenseInfo('00798245-n', 8), SenseInfo('00007347-n', 4), SenseInfo('01182654-n', 2), SenseInfo('07326557-n', 18), SenseInfo('06740402-n', 9), SenseInfo('00798245-n', 8), SenseInfo('00007347-n', 4), SenseInfo('01182654-n', 2), SenseInfo('07326557-n', 18), SenseInfo('06740402-n', 9), SenseInfo('00798245-n', 8), SenseInfo('00007347-n', 4), SenseInfo('01182654-n', 2), SenseInfo('07326557-n', 18), SenseInfo('06740402-n', 9), SenseInfo('00798245-n', 8), SenseInfo('00007347-n', 4), SenseInfo('01182654-n', 2) ],
"_return_n_of_rel" : [ SenseInfo('06548671-n', 32), SenseInfo('00051192-n', 6), SenseInfo('07447022-n', 3), SenseInfo('00089351-n', 3), SenseInfo('00328015-n', 2), SenseInfo('13260190-n', 1), SenseInfo('07343363-n', 0), SenseInfo('07199922-n', 0), SenseInfo('04084517-n', 0), SenseInfo('01234729-n', 0), SenseInfo('00566298-n', 0), SenseInfo('00559724-n', 0), SenseInfo('00050887-n', 0) ],
"_reclaim_v_1_rel" : [ SenseInfo('02276322-v', 2), SenseInfo('02226833-v', 0), SenseInfo('00384620-v', 0), SenseInfo('00383871-v', 0), SenseInfo('00302130-v', 0) ],
"_munch_v_on_rel" : [ SenseInfo('01201693-v', 0) ],
"_poster_n_1_rel" : [ SenseInfo('06793426-n', 1), SenseInfo('09854510-n', 0), SenseInfo('02387722-n', 0) ],
"_crispy_a_1_rel" : [ SenseInfo('02446931-a', 0), SenseInfo('02446931-a', 0), SenseInfo('02446931-a', 0) ],
"_wavy_a_1_rel" : [ SenseInfo('01030691-a', 2), SenseInfo('00911762-a', 1), SenseInfo('01030691-a', 2), SenseInfo('00911762-a', 1), SenseInfo('01030691-a', 2), SenseInfo('00911762-a', 1) ],
"_analyst_n_1_rel" : [ SenseInfo('09790482-n', 9), SenseInfo('09791530-n', 0), SenseInfo('09790278-n', 0) ],
"_smooth_v_away_rel" : [ SenseInfo('01252971-v', 7), SenseInfo('01245637-v', 1), SenseInfo('02313098-v', 0) ],
"_forgetfulness_n_1_rel" : [ SenseInfo('05673209-n', 3), SenseInfo('05673908-n', 0) ],
"_absurdity_n_1_rel" : [ SenseInfo('06607809-n', 6), SenseInfo('04891683-n', 1) ],
"_certification_n_of_rel" : [ SenseInfo('01139830-n', 2), SenseInfo('06650431-n', 1), SenseInfo('06471345-n', 0), SenseInfo('00154233-n', 0), SenseInfo('01139830-n', 2), SenseInfo('06650431-n', 1), SenseInfo('06471345-n', 0), SenseInfo('00154233-n', 0) ],
"_negative_n_1_rel" : [ SenseInfo('07204911-n', 1), SenseInfo('03817191-n', 0) ],
"_curdle_n_1_rel" : [  ],
"_star_n_1_rel" : [ SenseInfo('09444100-n', 8), SenseInfo('09762509-n', 3), SenseInfo('09444783-n', 3), SenseInfo('10648696-n', 1), SenseInfo('13881644-n', 0), SenseInfo('10163723-n', 0), SenseInfo('06828389-n', 0), SenseInfo('05730930-n', 0) ],
"_circumscribe_v_1_rel" : [ SenseInfo('01583494-v', 1), SenseInfo('00235368-v', 1), SenseInfo('01583656-v', 0) ],
"_brittle_a_1_rel" : [ SenseInfo('00708498-a', 2), SenseInfo('02533682-a', 0), SenseInfo('01522214-a', 0), SenseInfo('00708498-a', 2), SenseInfo('02533682-a', 0), SenseInfo('01522214-a', 0), SenseInfo('00708498-a', 2), SenseInfo('02533682-a', 0), SenseInfo('01522214-a', 0) ],
"_fatten_v_1_rel" : [ SenseInfo('01194938-v', 1) ],
"_pitch_v_1_rel" : [ SenseInfo('01512625-v', 6), SenseInfo('01864634-v', 5), SenseInfo('01978436-v', 2), SenseInfo('00298420-v', 1), SenseInfo('02302817-v', 0), SenseInfo('02037090-v', 0), SenseInfo('01884577-v', 0), SenseInfo('01514126-v', 0), SenseInfo('01509079-v', 0), SenseInfo('01402637-v', 0), SenseInfo('01149868-v', 0), SenseInfo('00298244-v', 0), SenseInfo('01512625-v', 6), SenseInfo('01864634-v', 5), SenseInfo('01978436-v', 2), SenseInfo('00298420-v', 1), SenseInfo('02302817-v', 0), SenseInfo('02037090-v', 0), SenseInfo('01884577-v', 0), SenseInfo('01514126-v', 0), SenseInfo('01509079-v', 0), SenseInfo('01402637-v', 0), SenseInfo('01149868-v', 0), SenseInfo('00298244-v', 0) ],
"_flood_n_1_rel" : [ SenseInfo('11454591-n', 5), SenseInfo('13775706-n', 2), SenseInfo('03365374-n', 2), SenseInfo('00329819-n', 2), SenseInfo('01257542-n', 1), SenseInfo('07403030-n', 0), SenseInfo('11454591-n', 5), SenseInfo('13775706-n', 2), SenseInfo('03365374-n', 2), SenseInfo('00329819-n', 2), SenseInfo('01257542-n', 1), SenseInfo('07403030-n', 0) ],
"_squat_v_1_rel" : [ SenseInfo('01545314-v', 8), SenseInfo('02725562-v', 2), SenseInfo('02649712-v', 0) ],
"_ravages_n_1_rel" : [ SenseInfo('07334876-n', 1), SenseInfo('07334876-n', 1) ],
"_jaw_n_1_rel" : [ SenseInfo('05546040-n', 9), SenseInfo('05603160-n', 0), SenseInfo('03594277-n', 0) ],
"_chapel_n_1_rel" : [ SenseInfo('03007130-n', 8), SenseInfo('01033024-n', 0), SenseInfo('03007130-n', 8), SenseInfo('01033024-n', 0) ],
"_in+and+of_p_rel" : [  ],
"_cellular_a_1_rel" : [ SenseInfo('02685299-a', 0), SenseInfo('00327031-a', 0) ],
"_impending_a_1_rel" : [ SenseInfo('00448314-a', 4) ],
"_anchor_n_1_rel" : [ SenseInfo('02709367-n', 3), SenseInfo('05694232-n', 1), SenseInfo('09792969-n', 0) ],
"_frustrating_a_1_rel" : [ SenseInfo('00867758-a', 2), SenseInfo('01764745-a', 0) ],
"_love_v_1_rel" : [ SenseInfo('01775164-v', 43), SenseInfo('01828736-v', 26), SenseInfo('01775535-v', 13), SenseInfo('01426397-v', 0), SenseInfo('01775164-v', 43), SenseInfo('01828736-v', 26), SenseInfo('01775535-v', 13), SenseInfo('01426397-v', 0), SenseInfo('01775164-v', 43), SenseInfo('01828736-v', 26), SenseInfo('01775535-v', 13), SenseInfo('01426397-v', 0), SenseInfo('01775164-v', 43), SenseInfo('01828736-v', 26), SenseInfo('01775535-v', 13), SenseInfo('01426397-v', 0) ],
"_planning_n_1_rel" : [ SenseInfo('01144133-n', 25), SenseInfo('00928371-n', 4), SenseInfo('05794694-n', 3) ],
"_create_v_1_rel" : [ SenseInfo('01617192-v', 94), SenseInfo('01753788-v', 38), SenseInfo('01685313-v', 6), SenseInfo('02476385-v', 0), SenseInfo('01640207-v', 0), SenseInfo('01621555-v', 0) ],
"_likeness_n_1_rel" : [ SenseInfo('04744814-n', 1), SenseInfo('03668642-n', 0) ],
"_hilarious_a_1_rel" : [ SenseInfo('01266841-a', 1), SenseInfo('01266841-a', 1) ],
"_minor_a_1_rel" : [ SenseInfo('01473083-a', 6), SenseInfo('01471723-a', 3), SenseInfo('01471368-a', 2), SenseInfo('01472225-a', 1), SenseInfo('01471954-a', 1), SenseInfo('01473826-a', 0), SenseInfo('01472509-a', 0), SenseInfo('02101240-a', 0), SenseInfo('01721401-a', 0), SenseInfo('01415219-a', 0) ],
"_actuality_n_1_rel" : [ SenseInfo('13954818-n', 4) ],
"_mutineer_n_1_rel" : [ SenseInfo('10342180-n', 1) ],
"_swiss_n_1_rel" : [ SenseInfo('09733333-n', 5), SenseInfo('09733333-n', 5), SenseInfo('09733333-n', 5) ],
"_doom_v_1_rel" : [ SenseInfo('00746479-v', 9), SenseInfo('00906735-v', 0), SenseInfo('00890855-v', 0) ],
"_transitive_a_1_rel" : [ SenseInfo('02488705-a', 0) ],
"_window_n_1_rel" : [ SenseInfo('04587648-n', 72), SenseInfo('04588365-n', 6), SenseInfo('04588587-n', 3), SenseInfo('09480077-n', 1), SenseInfo('15299783-n', 0), SenseInfo('04589745-n', 0), SenseInfo('04588986-n', 0), SenseInfo('04588739-n', 0) ],
"_no-no_n_1_rel" : [  ],
"_excavation_n_of_rel" : [ SenseInfo('00941974-n', 2), SenseInfo('08550076-n', 0), SenseInfo('03302121-n', 0), SenseInfo('00922327-n', 0) ],
"_generator_n_1_rel" : [ SenseInfo('03434188-n', 4), SenseInfo('03433877-n', 1), SenseInfo('10126177-n', 0), SenseInfo('03434285-n', 0) ],
"_downright_a_1_rel" : [ SenseInfo('01222722-a', 0), SenseInfo('00520892-a', 0) ],
"_bludgeon_v_1_rel" : [ SenseInfo('02505606-v', 0), SenseInfo('01423929-v', 0) ],
"_butter_v_1_rel" : [ SenseInfo('01267998-v', 0) ],
"_telecom_n_1_rel" : [ SenseInfo('06271778-n', 0) ],
"_limo_n_1_rel" : [ SenseInfo('03670208-n', 0) ],
"_second+hand_a_1_rel" : [ SenseInfo('01854702-a', 1), SenseInfo('01640482-a', 1), SenseInfo('01854702-a', 1), SenseInfo('01640482-a', 1) ],
"_yikes_a_1_rel" : [  ],
"_shirt_n_1_rel" : [ SenseInfo('04197391-n', 15) ],
"_hmmm_a_1_rel" : [  ],
"_from_p_place-in_rel" : [  ],
"_wound_n_1_rel" : [ SenseInfo('14298815-n', 22), SenseInfo('07340249-n', 2), SenseInfo('07497122-n', 0), SenseInfo('00403783-n', 0) ],
"_platinum_a_1_rel" : [ SenseInfo('14649543-n', 3) ],
"_payroll_n_1_rel" : [ SenseInfo('13412721-n', 1), SenseInfo('13412877-n', 0), SenseInfo('08120079-n', 0) ],
"_worried_a_1_rel" : [ SenseInfo('02457167-a', 7), SenseInfo('00822907-a', 0) ],
"_all-too_x_deg_rel" : [ SenseInfo('00250258-r', 8), SenseInfo('00250258-r', 8), SenseInfo('00250258-r', 8) ],
"_tutor_v_1_rel" : [ SenseInfo('00830188-v', 1), SenseInfo('02592667-v', 0) ],
"_blind_a_1_rel" : [ SenseInfo('02158826-a', 11), SenseInfo('01746292-a', 4), SenseInfo('01926654-a', 3), SenseInfo('02158826-a', 11), SenseInfo('01746292-a', 4), SenseInfo('01926654-a', 3), SenseInfo('02158826-a', 11), SenseInfo('01746292-a', 4), SenseInfo('01926654-a', 3), SenseInfo('02158826-a', 11), SenseInfo('01746292-a', 4), SenseInfo('01926654-a', 3) ],
"_far+off_a_1_rel" : [ SenseInfo('00443274-a', 2), SenseInfo('00443274-a', 2), SenseInfo('00443274-a', 2) ],
"_shadowy_a_1_rel" : [ SenseInfo('00276862-a', 1), SenseInfo('00782216-a', 0), SenseInfo('00626483-a', 0) ],
"_indefinable_a_1_rel" : [ SenseInfo('00697691-a', 1), SenseInfo('00944111-a', 0) ],
"_combine_n_1_rel" : [ SenseInfo('03075634-n', 1), SenseInfo('08236621-n', 0), SenseInfo('07373803-n', 0) ],
"_undervoltage_n_1_rel" : [  ],
"_pine_n_1_rel" : [ SenseInfo('11608250-n', 4), SenseInfo('11608885-n', 2) ],
"_drainage_n_1_rel" : [ SenseInfo('00396029-n', 3) ],
"_individualism_n_1_rel" : [ SenseInfo('04763293-n', 9), SenseInfo('05963101-n', 1), SenseInfo('05962936-n', 1) ],
"_appreciable_a_1_rel" : [ SenseInfo('00624416-a', 4) ],
"_or+else_a_1_rel" : [  ],
"_support_n_of_rel" : [ SenseInfo('01215902-n', 15), SenseInfo('01212519-n', 9), SenseInfo('05693919-n', 4), SenseInfo('00971463-n', 4), SenseInfo('00154433-n', 3), SenseInfo('13365286-n', 2), SenseInfo('04360501-n', 2), SenseInfo('01017320-n', 2), SenseInfo('07031752-n', 1), SenseInfo('04359589-n', 1), SenseInfo('13365698-n', 0), SenseInfo('01215902-n', 15), SenseInfo('01212519-n', 9), SenseInfo('05693919-n', 4), SenseInfo('00971463-n', 4), SenseInfo('00154433-n', 3), SenseInfo('13365286-n', 2), SenseInfo('04360501-n', 2), SenseInfo('01017320-n', 2), SenseInfo('07031752-n', 1), SenseInfo('04359589-n', 1), SenseInfo('13365698-n', 0) ],
"_eta_n_for_rel" : [ SenseInfo('08018189-n', 0), SenseInfo('06834780-n', 0) ],
"_sweet_n_1_rel" : [ SenseInfo('11326730-n', 0), SenseInfo('07609840-n', 0), SenseInfo('07596684-n', 0), SenseInfo('05716577-n', 0), SenseInfo('04994413-n', 0) ],
"_signal_v_1_rel" : [ SenseInfo('01039330-v', 4), SenseInfo('00921300-v', 3), SenseInfo('01039330-v', 4), SenseInfo('00921300-v', 3), SenseInfo('01039330-v', 4), SenseInfo('00921300-v', 3), SenseInfo('01039330-v', 4), SenseInfo('00921300-v', 3), SenseInfo('01039330-v', 4), SenseInfo('00921300-v', 3) ],
"_subassembly_n_1_rel" : [  ],
"_tickle_v_1_rel" : [ SenseInfo('02120140-v', 0), SenseInfo('01796346-v', 0), SenseInfo('01431987-v', 0) ],
"_orator_n_1_rel" : [ SenseInfo('10380672-n', 1) ],
"_cream_v_1_rel" : [ SenseInfo('01418037-v', 0), SenseInfo('01412912-v', 0), SenseInfo('01364483-v', 0), SenseInfo('01261018-v', 0), SenseInfo('00171339-v', 0) ],
"_holiday_n_1_rel" : [ SenseInfo('15137890-n', 9), SenseInfo('15183428-n', 4), SenseInfo('15137890-n', 9), SenseInfo('15183428-n', 4) ],
"_fly_v_in_rel" : [ SenseInfo('01940403-v', 33), SenseInfo('01842068-v', 9), SenseInfo('01941093-v', 5), SenseInfo('01451842-v', 3), SenseInfo('01848058-v', 2), SenseInfo('01839404-v', 2), SenseInfo('00545292-v', 2), SenseInfo('02073065-v', 1), SenseInfo('01840238-v', 1), SenseInfo('02140965-v', 0), SenseInfo('02075462-v', 0), SenseInfo('01847845-v', 0), SenseInfo('01402765-v', 0), SenseInfo('00153061-v', 0) ],
"_aboriginal_a_1_rel" : [ SenseInfo('02599509-a', 0), SenseInfo('01037148-a', 0), SenseInfo('00813589-a', 0) ],
"_khakis_n_1_rel" : [ SenseInfo('03615406-n', 0), SenseInfo('03615406-n', 0) ],
"_programmer_n_of_rel" : [ SenseInfo('10481268-n', 0) ],
"_seascape_n_1_rel" : [ SenseInfo('08647049-n', 0), SenseInfo('04161233-n', 0) ],
"_agreeable_a_1_rel" : [ SenseInfo('00089051-a', 0), SenseInfo('00577122-a', 0), SenseInfo('00553279-a', 0), SenseInfo('00089051-a', 0), SenseInfo('00577122-a', 0), SenseInfo('00553279-a', 0) ],
"_patchy_a_1_rel" : [ SenseInfo('00912814-a', 0), SenseInfo('00912814-a', 0), SenseInfo('00912814-a', 0) ],
"_gutter_n_1_rel" : [ SenseInfo('03471473-n', 2), SenseInfo('14475992-n', 0), SenseInfo('10153009-n', 0), SenseInfo('03471685-n', 0) ],
"_busy_v_1_rel" : [ SenseInfo('02415831-v', 1) ],
"_infrequent_a_1_rel" : [ SenseInfo('01067193-a', 2) ],
"_self-assurance_n_1_rel" : [ SenseInfo('05697363-n', 0) ],
"_self-contradictory_a_1_rel" : [ SenseInfo('00939895-a', 0), SenseInfo('00578234-a', 0) ],
"_perennial_n_1_rel" : [ SenseInfo('11553240-n', 0) ],
"_add_v_in_rel" : [ SenseInfo('00182406-v', 116), SenseInfo('01027174-v', 68), SenseInfo('02324478-v', 15), SenseInfo('00640828-v', 3), SenseInfo('00949288-v', 1), SenseInfo('02745172-v', 0) ],
"_sight_n_of_rel" : [ SenseInfo('05933054-n', 17), SenseInfo('06888944-n', 12), SenseInfo('05654362-n', 6), SenseInfo('06210964-n', 2), SenseInfo('05623818-n', 2), SenseInfo('00881649-n', 2), SenseInfo('13774404-n', 1), SenseInfo('05933054-n', 17), SenseInfo('06888944-n', 12), SenseInfo('05654362-n', 6), SenseInfo('06210964-n', 2), SenseInfo('05623818-n', 2), SenseInfo('00881649-n', 2), SenseInfo('13774404-n', 1), SenseInfo('05933054-n', 17), SenseInfo('06888944-n', 12), SenseInfo('05654362-n', 6), SenseInfo('06210964-n', 2), SenseInfo('05623818-n', 2), SenseInfo('00881649-n', 2), SenseInfo('13774404-n', 1) ],
"_hold_v_on_rel" : [ SenseInfo('02681795-v', 79), SenseInfo('01216670-v', 65), SenseInfo('01733477-v', 62), SenseInfo('02203362-v', 26), SenseInfo('00693780-v', 20), SenseInfo('01773130-v', 17), SenseInfo('01301410-v', 17), SenseInfo('02283324-v', 14), SenseInfo('02302220-v', 9), SenseInfo('01217043-v', 9), SenseInfo('02700867-v', 7), SenseInfo('02732798-v', 3), SenseInfo('02683489-v', 3), SenseInfo('01601234-v', 3), SenseInfo('02648502-v', 2), SenseInfo('00683771-v', 2), SenseInfo('02746275-v', 1), SenseInfo('02701210-v', 1), SenseInfo('02498320-v', 1), SenseInfo('01129876-v', 1), SenseInfo('00885217-v', 1), SenseInfo('00736586-v', 1), SenseInfo('00607000-v', 1), SenseInfo('02706816-v', 0), SenseInfo('02676789-v', 0), SenseInfo('02643574-v', 0), SenseInfo('02510337-v', 0), SenseInfo('02450989-v', 0), SenseInfo('02441897-v', 0), SenseInfo('01859586-v', 0), SenseInfo('01334744-v', 0), SenseInfo('01205153-v', 0), SenseInfo('01151753-v', 0), SenseInfo('00822367-v', 0), SenseInfo('00805376-v', 0), SenseInfo('00004492-v', 0) ],
"_rise_v_1_rel" : [ SenseInfo('01968569-v', 26), SenseInfo('00155143-v', 23), SenseInfo('01983264-v', 20), SenseInfo('02696801-v', 8), SenseInfo('01990281-v', 5), SenseInfo('02624263-v', 4), SenseInfo('01969779-v', 4), SenseInfo('00433232-v', 4), SenseInfo('00432436-v', 4), SenseInfo('00018158-v', 4), SenseInfo('00155547-v', 3), SenseInfo('01818116-v', 2), SenseInfo('01155545-v', 2), SenseInfo('02583139-v', 1), SenseInfo('01983134-v', 1), SenseInfo('01970348-v', 1), SenseInfo('00098770-v', 0) ],
"_dreadfully_x_deg_rel" : [ SenseInfo('00056340-r', 1), SenseInfo('00316486-r', 0) ],
"_trip_v_1_rel" : [ SenseInfo('01900408-v', 2), SenseInfo('01900760-v', 0), SenseInfo('01843055-v', 0), SenseInfo('01643657-v', 0), SenseInfo('01200934-v', 0) ],
"_keep_v_down_rel" : [ SenseInfo('02681795-v', 206), SenseInfo('02684924-v', 39), SenseInfo('02202384-v', 32), SenseInfo('02450505-v', 22), SenseInfo('02578872-v', 10), SenseInfo('00732552-v', 9), SenseInfo('02202928-v', 8), SenseInfo('01065877-v', 4), SenseInfo('02651853-v', 3), SenseInfo('02410175-v', 3), SenseInfo('01184625-v', 3), SenseInfo('02734800-v', 2), SenseInfo('02578510-v', 2), SenseInfo('02422663-v', 2), SenseInfo('02733122-v', 1), SenseInfo('02652016-v', 0), SenseInfo('02283716-v', 0), SenseInfo('02204094-v', 0), SenseInfo('02203844-v', 0), SenseInfo('02203168-v', 0), SenseInfo('01302019-v', 0), SenseInfo('00212414-v', 0) ],
"_hide_n_1_rel" : [ SenseInfo('14759275-n', 2), SenseInfo('01895735-n', 2) ],
"_compression_n_of_rel" : [ SenseInfo('07419233-n', 0), SenseInfo('07313241-n', 0), SenseInfo('00616083-n', 0), SenseInfo('00356790-n', 0) ],
"_literal_a_1_rel" : [ SenseInfo('02460964-a', 10), SenseInfo('00914983-a', 1), SenseInfo('01418789-a', 0), SenseInfo('01793674-a', 0), SenseInfo('02460964-a', 10), SenseInfo('00914983-a', 1), SenseInfo('01418789-a', 0), SenseInfo('01793674-a', 0) ],
"_camcorder_n_1_rel" : [ SenseInfo('02942349-n', 0) ],
"_southwestern_a_1_rel" : [ SenseInfo('01603869-a', 0), SenseInfo('00826215-a', 0), SenseInfo('01603869-a', 0), SenseInfo('00826215-a', 0) ],
"_taboo_a_1_rel" : [ SenseInfo('01761375-a', 1), SenseInfo('02056761-a', 0) ],
"_juniper_n_1_rel" : [ SenseInfo('12567490-n', 0), SenseInfo('11636566-n', 0) ],
"_in-store_a_1_rel" : [ SenseInfo('01733189-a', 1), SenseInfo('01733189-a', 1) ],
"_stifle_v_1_rel" : [ SenseInfo('01568630-v', 2), SenseInfo('00390842-v', 1), SenseInfo('01476180-v', 0), SenseInfo('00359511-v', 0) ],
"_scrub_v_out_rel" : [ SenseInfo('01251228-v', 4), SenseInfo('00036780-v', 1), SenseInfo('02477755-v', 0) ],
"_scrubbing_n_1_rel" : [ SenseInfo('00251780-n', 1) ],
"_VAT_n_tax_rel" : [ SenseInfo('13316722-n', 0), SenseInfo('04493381-n', 0) ],
"_slump_n_1_rel" : [ SenseInfo('13556509-n', 2), SenseInfo('14489113-n', 0) ],
"_patagonian_a_1_rel" : [  ],
"_stall_n_1_rel" : [ SenseInfo('04299370-n', 10), SenseInfo('02873839-n', 3), SenseInfo('04299215-n', 2), SenseInfo('07318824-n', 0), SenseInfo('04299699-n', 0), SenseInfo('02968333-n', 0), SenseInfo('01075725-n', 0) ],
"_market+share_n_1_rel" : [  ],
"_pelvic_a_1_rel" : [ SenseInfo('02894741-a', 2) ],
"_cleat_n_1_rel" : [ SenseInfo('03041265-n', 1), SenseInfo('03041114-n', 0), SenseInfo('03040983-n', 0) ],
"_scrumptious_a_1_rel" : [ SenseInfo('02396720-a', 0) ],
"_contents_n_1_rel" : [ SenseInfo('06489659-n', 0), SenseInfo('06489659-n', 0) ],
"_wager_n_1_rel" : [ SenseInfo('00506658-n', 1), SenseInfo('13343526-n', 0), SenseInfo('00506658-n', 1), SenseInfo('13343526-n', 0) ],
"_olympic_a_1_rel" : [ SenseInfo('03093076-a', 4), SenseInfo('03093379-a', 0) ],
"_taste_v_1_rel" : [ SenseInfo('02194286-v', 10), SenseInfo('02191546-v', 3), SenseInfo('01195299-v', 3), SenseInfo('02194495-v', 0), SenseInfo('02192992-v', 0), SenseInfo('00597061-v', 0) ],
"_polarize_v_cause_rel" : [ SenseInfo('00487554-v', 2), SenseInfo('00487350-v', 1), SenseInfo('00487182-v', 1), SenseInfo('00487554-v', 2), SenseInfo('00487350-v', 1), SenseInfo('00487182-v', 1), SenseInfo('00487554-v', 2), SenseInfo('00487350-v', 1), SenseInfo('00487182-v', 1), SenseInfo('00487554-v', 2), SenseInfo('00487350-v', 1), SenseInfo('00487182-v', 1), SenseInfo('00487554-v', 2), SenseInfo('00487350-v', 1), SenseInfo('00487182-v', 1) ],
"_parent_n_of_rel" : [ SenseInfo('10399491-n', 35), SenseInfo('00006150-n', 0) ],
"_sprawl_v_out_rel" : [ SenseInfo('01543426-v', 8), SenseInfo('02032227-v', 2) ],
"_welsh_n_1_rel" : [ SenseInfo('09747329-n', 0), SenseInfo('06961557-n', 0), SenseInfo('02405577-n', 0) ],
"_bothered_a_1_rel" : [ SenseInfo('00532147-a', 0), SenseInfo('00532147-a', 0) ],
"_lapp_n_1_rel" : [ SenseInfo('09720033-n', 0), SenseInfo('06959427-n', 0) ],
"_motel_n_1_rel" : [ SenseInfo('03788498-n', 1) ],
"_subgenus_n_1_rel" : [ SenseInfo('08109624-n', 0) ],
"_utter_v_1_rel" : [ SenseInfo('00940384-v', 6), SenseInfo('00983824-v', 3), SenseInfo('00941990-v', 1), SenseInfo('02043851-v', 0) ],
"_seeker_n_1_rel" : [ SenseInfo('10575787-n', 1), SenseInfo('04167489-n', 0) ],
"_don_v_1_rel" : [ SenseInfo('00050652-v', 4) ],
"_kindred_a_1_rel" : [ SenseInfo('02071782-a', 2), SenseInfo('01972479-a', 0) ],
"_establish_v_as_rel" : [ SenseInfo('02427103-v', 50), SenseInfo('01647229-v', 28), SenseInfo('00664788-v', 23), SenseInfo('00665476-v', 15), SenseInfo('01647672-v', 6), SenseInfo('01570108-v', 2), SenseInfo('01655505-v', 1), SenseInfo('00636888-v', 1), SenseInfo('02427103-v', 50), SenseInfo('01647229-v', 28), SenseInfo('00664788-v', 23), SenseInfo('00665476-v', 15), SenseInfo('01647672-v', 6), SenseInfo('01570108-v', 2), SenseInfo('01655505-v', 1), SenseInfo('00636888-v', 1) ],
"_cake_v_1_rel" : [ SenseInfo('01262321-v', 0), SenseInfo('01262321-v', 0) ],
"_joke_v_1_rel" : [ SenseInfo('00853633-v', 2), SenseInfo('00105554-v', 1), SenseInfo('00853633-v', 2), SenseInfo('00105554-v', 1), SenseInfo('00853633-v', 2), SenseInfo('00105554-v', 1) ],
"_profit_n_1_rel" : [ SenseInfo('13258362-n', 6), SenseInfo('05157574-n', 1) ],
"_top_a_1_rel" : [ SenseInfo('02439949-a', 11) ],
"_buff_a_1_rel" : [ SenseInfo('00372476-a', 0), SenseInfo('00372476-a', 0), SenseInfo('00372476-a', 0) ],
"_shekel_n_1_rel" : [ SenseInfo('13706310-n', 0) ],
"_shred_v_1_rel" : [ SenseInfo('01573891-v', 1) ],
"_grammarian_n_1_rel" : [ SenseInfo('10141364-n', 1) ],
"_next+door_p_rel" : [ SenseInfo('00240082-r', 3), SenseInfo('00240082-r', 3), SenseInfo('00240082-r', 3) ],
"_agate_n_1_rel" : [ SenseInfo('14708232-n', 1) ],
"_Asian-American_a_1_rel" : [  ],
"_nude_a_1_rel" : [ SenseInfo('00457998-a', 2) ],
"_store_v_cause_rel" : [ SenseInfo('02281093-v', 16), SenseInfo('02282506-v', 11), SenseInfo('02281093-v', 16), SenseInfo('02282506-v', 11) ],
"_demoralize_v_1_rel" : [ SenseInfo('02579447-v', 0), SenseInfo('01814396-v', 0), SenseInfo('00622204-v', 0), SenseInfo('02579447-v', 0), SenseInfo('01814396-v', 0), SenseInfo('00622204-v', 0), SenseInfo('02579447-v', 0), SenseInfo('01814396-v', 0), SenseInfo('00622204-v', 0), SenseInfo('02579447-v', 0), SenseInfo('01814396-v', 0), SenseInfo('00622204-v', 0), SenseInfo('02579447-v', 0), SenseInfo('01814396-v', 0), SenseInfo('00622204-v', 0), SenseInfo('02579447-v', 0), SenseInfo('01814396-v', 0), SenseInfo('00622204-v', 0), SenseInfo('02579447-v', 0), SenseInfo('01814396-v', 0), SenseInfo('00622204-v', 0) ],
"_script_n_1_rel" : [ SenseInfo('07009946-n', 6), SenseInfo('06403393-n', 0), SenseInfo('06351613-n', 0) ],
"_slur_v_1_rel" : [ SenseInfo('01727866-v', 0), SenseInfo('01044891-v', 0), SenseInfo('01044811-v', 0), SenseInfo('00311113-v', 0) ],
"_observe_v_to_rel" : [ SenseInfo('02154508-v', 39), SenseInfo('01020005-v', 17), SenseInfo('02118933-v', 12), SenseInfo('02169352-v', 10), SenseInfo('02457233-v', 4), SenseInfo('02578510-v', 3), SenseInfo('02455407-v', 2), SenseInfo('00732552-v', 1), SenseInfo('02578872-v', 0), SenseInfo('02154508-v', 39), SenseInfo('01020005-v', 17), SenseInfo('02118933-v', 12), SenseInfo('02169352-v', 10), SenseInfo('02457233-v', 4), SenseInfo('02578510-v', 3), SenseInfo('02455407-v', 2), SenseInfo('00732552-v', 1), SenseInfo('02578872-v', 0), SenseInfo('02154508-v', 39), SenseInfo('01020005-v', 17), SenseInfo('02118933-v', 12), SenseInfo('02169352-v', 10), SenseInfo('02457233-v', 4), SenseInfo('02578510-v', 3), SenseInfo('02455407-v', 2), SenseInfo('00732552-v', 1), SenseInfo('02578872-v', 0), SenseInfo('02154508-v', 39), SenseInfo('01020005-v', 17), SenseInfo('02118933-v', 12), SenseInfo('02169352-v', 10), SenseInfo('02457233-v', 4), SenseInfo('02578510-v', 3), SenseInfo('02455407-v', 2), SenseInfo('00732552-v', 1), SenseInfo('02578872-v', 0), SenseInfo('02154508-v', 39), SenseInfo('01020005-v', 17), SenseInfo('02118933-v', 12), SenseInfo('02169352-v', 10), SenseInfo('02457233-v', 4), SenseInfo('02578510-v', 3), SenseInfo('02455407-v', 2), SenseInfo('00732552-v', 1), SenseInfo('02578872-v', 0) ],
"_module_n_1_rel" : [ SenseInfo('05650329-n', 0), SenseInfo('03779000-n', 0), SenseInfo('03778817-n', 0), SenseInfo('03778600-n', 0) ],
"_set_v_up_rel" : [ SenseInfo('01494310-v', 30), SenseInfo('00699815-v', 29), SenseInfo('00947077-v', 12), SenseInfo('01062395-v', 10), SenseInfo('00298896-v', 9), SenseInfo('01607445-v', 6), SenseInfo('00406243-v', 5), SenseInfo('00298556-v', 5), SenseInfo('01711749-v', 3), SenseInfo('01970646-v', 2), SenseInfo('01706129-v', 2), SenseInfo('01567275-v', 2), SenseInfo('01628899-v', 1), SenseInfo('00442669-v', 1), SenseInfo('01744888-v', 0), SenseInfo('01613239-v', 0), SenseInfo('01530273-v', 0), SenseInfo('01247322-v', 0), SenseInfo('01115006-v', 0), SenseInfo('00673448-v', 0), SenseInfo('00408085-v', 0), SenseInfo('00407848-v', 0), SenseInfo('00296178-v', 0), SenseInfo('00056188-v', 0), SenseInfo('00038849-v', 0), SenseInfo('01494310-v', 30), SenseInfo('00699815-v', 29), SenseInfo('00947077-v', 12), SenseInfo('01062395-v', 10), SenseInfo('00298896-v', 9), SenseInfo('01607445-v', 6), SenseInfo('00406243-v', 5), SenseInfo('00298556-v', 5), SenseInfo('01711749-v', 3), SenseInfo('01970646-v', 2), SenseInfo('01706129-v', 2), SenseInfo('01567275-v', 2), SenseInfo('01628899-v', 1), SenseInfo('00442669-v', 1), SenseInfo('01744888-v', 0), SenseInfo('01613239-v', 0), SenseInfo('01530273-v', 0), SenseInfo('01247322-v', 0), SenseInfo('01115006-v', 0), SenseInfo('00673448-v', 0), SenseInfo('00408085-v', 0), SenseInfo('00407848-v', 0), SenseInfo('00296178-v', 0), SenseInfo('00056188-v', 0), SenseInfo('00038849-v', 0), SenseInfo('01494310-v', 30), SenseInfo('00699815-v', 29), SenseInfo('00947077-v', 12), SenseInfo('01062395-v', 10), SenseInfo('00298896-v', 9), SenseInfo('01607445-v', 6), SenseInfo('00406243-v', 5), SenseInfo('00298556-v', 5), SenseInfo('01711749-v', 3), SenseInfo('01970646-v', 2), SenseInfo('01706129-v', 2), SenseInfo('01567275-v', 2), SenseInfo('01628899-v', 1), SenseInfo('00442669-v', 1), SenseInfo('01744888-v', 0), SenseInfo('01613239-v', 0), SenseInfo('01530273-v', 0), SenseInfo('01247322-v', 0), SenseInfo('01115006-v', 0), SenseInfo('00673448-v', 0), SenseInfo('00408085-v', 0), SenseInfo('00407848-v', 0), SenseInfo('00296178-v', 0), SenseInfo('00056188-v', 0), SenseInfo('00038849-v', 0) ],
"_nonprofit_n_1_rel" : [ SenseInfo('01137597-n', 0) ],
"_absent_a_1_rel" : [ SenseInfo('01847672-a', 12), SenseInfo('00927832-a', 0), SenseInfo('00165171-a', 0) ],
"_happy_a_about_rel" : [ SenseInfo('01148283-a', 37), SenseInfo('01048406-a', 2), SenseInfo('02565583-a', 0), SenseInfo('01000442-a', 0) ],
"_undemocratic_a_1_rel" : [ SenseInfo('00717417-a', 0), SenseInfo('00717417-a', 0) ],
"_monopoly_n_on_rel" : [ SenseInfo('14444326-n', 5), SenseInfo('14444114-n', 2), SenseInfo('00505238-n', 0) ],
"_the+same_a_1_rel" : [ SenseInfo('02068476-a', 129), SenseInfo('02062670-a', 80), SenseInfo('01411065-a', 20), SenseInfo('00355611-a', 17), SenseInfo('02068476-a', 129), SenseInfo('02062670-a', 80), SenseInfo('01411065-a', 20), SenseInfo('00355611-a', 17) ],
"_wrangling_n_1_rel" : [ SenseInfo('07150138-n', 0) ],
"_regenerate_a_1_rel" : [ SenseInfo('01956964-a', 0) ],
"_clam_v_up_rel" : [ SenseInfo('01383947-v', 0) ],
"_damnation_n_1_rel" : [ SenseInfo('07233542-n', 2), SenseInfo('14458593-n', 0) ],
"_harness_n_1_rel" : [ SenseInfo('03495039-n', 2), SenseInfo('03494706-n', 1) ],
"_landward_a_1_rel" : [  ],
"_resiny_a_1_rel" : [ SenseInfo('00054364-a', 1) ],
"_in+any+way_a_1_rel" : [  ],
"_shit_a_1_rel" : [ SenseInfo('14854581-n', 1), SenseInfo('06611376-n', 1), SenseInfo('13773047-n', 0), SenseInfo('13555775-n', 0), SenseInfo('09815188-n', 0), SenseInfo('05140793-n', 0), SenseInfo('14854581-n', 1), SenseInfo('06611376-n', 1), SenseInfo('13773047-n', 0), SenseInfo('13555775-n', 0), SenseInfo('09815188-n', 0), SenseInfo('05140793-n', 0) ],
"_uttermost_a_1_rel" : [ SenseInfo('01511520-a', 0), SenseInfo('00443618-a', 0) ],
"_dandy_a_1_rel" : [ SenseInfo('01123879-a', 0) ],
"_status_n_of-as_rel" : [ SenseInfo('13945919-n', 20), SenseInfo('13920835-n', 1), SenseInfo('13945919-n', 20), SenseInfo('13920835-n', 1), SenseInfo('13945919-n', 20), SenseInfo('13920835-n', 1) ],
"_isolator_n_1_rel" : [  ],
"_well-kept_a_1_rel" : [ SenseInfo('00737515-a', 2), SenseInfo('02423649-a', 1), SenseInfo('00737515-a', 2), SenseInfo('02423649-a', 1) ],
"_flurry_n_of_rel" : [ SenseInfo('00555138-n', 4), SenseInfo('11508578-n', 1) ],
"_damn_a_1_rel" : [ SenseInfo('00670530-a', 19), SenseInfo('00669942-a', 2), SenseInfo('00670530-a', 19), SenseInfo('00669942-a', 2), SenseInfo('00670530-a', 19), SenseInfo('00669942-a', 2) ],
"_the+best_x_subord_rel" : [ SenseInfo('00227507-a', 94), SenseInfo('00188137-r', 14), SenseInfo('00127531-n', 6), SenseInfo('00188057-r', 6), SenseInfo('09851165-n', 1), SenseInfo('01109259-v', 1), SenseInfo('10850049-n', 0), SenseInfo('00509846-r', 0), SenseInfo('00067379-a', 0) ],
"_lactose_n_1_rel" : [ SenseInfo('14929462-n', 0) ],
"_stricken_a_with_rel" : [ SenseInfo('02542148-a', 3), SenseInfo('00071242-a', 1), SenseInfo('02545385-a', 0) ],
"_length_n_of_rel" : [ SenseInfo('05129201-n', 38), SenseInfo('05051249-n', 6), SenseInfo('05133107-n', 3), SenseInfo('05129565-n', 1), SenseInfo('03656231-n', 0), SenseInfo('05129201-n', 38), SenseInfo('05051249-n', 6), SenseInfo('05133107-n', 3), SenseInfo('05129565-n', 1), SenseInfo('03656231-n', 0), SenseInfo('05129201-n', 38), SenseInfo('05051249-n', 6), SenseInfo('05133107-n', 3), SenseInfo('05129565-n', 1), SenseInfo('03656231-n', 0), SenseInfo('05129201-n', 38), SenseInfo('05051249-n', 6), SenseInfo('05133107-n', 3), SenseInfo('05129565-n', 1), SenseInfo('03656231-n', 0) ],
"_not+even_x_deg_rel" : [ SenseInfo('00017445-r', 394), SenseInfo('00018043-r', 13), SenseInfo('00017639-r', 6), SenseInfo('00913387-a', 4), SenseInfo('00891170-a', 3), SenseInfo('00909545-a', 2), SenseInfo('15166462-n', 0), SenseInfo('00018189-r', 0), SenseInfo('02372520-a', 0), SenseInfo('02302187-a', 0), SenseInfo('00892243-a', 0), SenseInfo('01307142-v', 0), SenseInfo('00416880-v', 0), SenseInfo('00416705-v', 0) ],
"_ponytail_n_1_rel" : [ SenseInfo('05260380-n', 0) ],
"_pucker_v_up_rel" : [ SenseInfo('01278817-v', 3), SenseInfo('01330822-v', 0), SenseInfo('01279015-v', 0) ],
"_sale_n_of_rel" : [ SenseInfo('01114824-n', 29), SenseInfo('01117541-n', 18), SenseInfo('01117723-n', 1), SenseInfo('14564306-n', 0), SenseInfo('06527851-n', 0), SenseInfo('01114824-n', 29), SenseInfo('01117541-n', 18), SenseInfo('01117723-n', 1), SenseInfo('14564306-n', 0), SenseInfo('06527851-n', 0), SenseInfo('01114824-n', 29), SenseInfo('01117541-n', 18), SenseInfo('01117723-n', 1), SenseInfo('14564306-n', 0), SenseInfo('06527851-n', 0), SenseInfo('01114824-n', 29), SenseInfo('01117541-n', 18), SenseInfo('01117723-n', 1), SenseInfo('14564306-n', 0), SenseInfo('06527851-n', 0) ],
"_attribute_v_to_rel" : [ SenseInfo('00726300-v', 16), SenseInfo('00740053-v', 0) ],
"_ruin_n_1_rel" : [ SenseInfo('14562324-n', 3), SenseInfo('04118635-n', 2), SenseInfo('13466312-n', 0), SenseInfo('07335243-n', 0), SenseInfo('07318133-n', 0), SenseInfo('00217773-n', 0) ],
"_matrimony_n_1_rel" : [ SenseInfo('13963970-n', 1), SenseInfo('01036903-n', 0) ],
"_joker_n_1_rel" : [ SenseInfo('10224098-n', 1), SenseInfo('10224295-n', 0), SenseInfo('06394051-n', 0), SenseInfo('03601964-n', 0) ],
"_shuffle_n_1_rel" : [ SenseInfo('00340463-n', 0), SenseInfo('00292712-n', 0) ],
"_unimpressed_a_with_rel" : [ SenseInfo('00072673-a', 3), SenseInfo('00072673-a', 3) ],
"_administrator_n_of_rel" : [ SenseInfo('09770949-n', 5), SenseInfo('09770743-n', 3), SenseInfo('09770472-n', 0) ],
"_thaw_v_1_rel" : [ SenseInfo('00376106-v', 5) ],
"_emailing_n_1_rel" : [  ],
"_fleecy_a_1_rel" : [ SenseInfo('01153141-a', 0), SenseInfo('01153141-a', 0), SenseInfo('01153141-a', 0) ],
"_African-American_a_1_rel" : [ SenseInfo('00242293-a', 0), SenseInfo('00242293-a', 0) ],
"_hatch_v_1_rel" : [ SenseInfo('00063095-v', 2), SenseInfo('01634142-v', 1), SenseInfo('01682234-v', 0), SenseInfo('01276593-v', 0), SenseInfo('00060185-v', 0) ],
"_strictly+speaking_a_1_rel" : [  ],
"_nonessential_n_1_rel" : [ SenseInfo('09312645-n', 0) ],
"_curb_v_1_rel" : [ SenseInfo('02510337-v', 2), SenseInfo('00462092-v', 2), SenseInfo('01300937-v', 0), SenseInfo('00236592-v', 0) ],
"_revision_n_of_rel" : [ SenseInfo('00399393-n', 3), SenseInfo('06428976-n', 1), SenseInfo('06364149-n', 1) ],
"_sap_v_1_rel" : [ SenseInfo('02280869-v', 1), SenseInfo('01310555-v', 0) ],
"_insight_n_into_rel" : [ SenseInfo('05710356-n', 9), SenseInfo('07513247-n', 3), SenseInfo('05807306-n', 3), SenseInfo('05708207-n', 0) ],
"_classification_n_of_rel" : [ SenseInfo('01012712-n', 8), SenseInfo('07939638-n', 7), SenseInfo('05732756-n', 0), SenseInfo('01148904-n', 0) ],
"_all-time_a_1_rel" : [ SenseInfo('00505086-a', 1), SenseInfo('00505086-a', 1) ],
"_phone_v_1_rel" : [ SenseInfo('00789448-v', 7) ],
"_on/off_a_1_rel" : [  ],
"_halt_n_1_rel" : [ SenseInfo('14010927-n', 1), SenseInfo('07365849-n', 1), SenseInfo('01063697-n', 1) ],
"_privileged_a_1_rel" : [ SenseInfo('01864123-a', 4), SenseInfo('02366078-a', 0), SenseInfo('01863066-a', 0) ],
"_hundred_n_1_rel" : [ SenseInfo('13750415-n', 22) ],
"_diocese_n_1_rel" : [ SenseInfo('08550966-n', 0) ],
"_welsh_a_1_rel" : [ SenseInfo('03130073-a', 0) ],
"_catch_n_i_rel" : [ SenseInfo('05164673-n', 1), SenseInfo('13755822-n', 0), SenseInfo('09900981-n', 0), SenseInfo('09238143-n', 0), SenseInfo('07067760-n', 0), SenseInfo('02982790-n', 0), SenseInfo('02982599-n', 0), SenseInfo('00458641-n', 0), SenseInfo('00138956-n', 0), SenseInfo('00088725-n', 0) ],
"_crocket_n_1_rel" : [ SenseInfo('03133744-n', 0) ],
"_sit-up_n_1_rel" : [ SenseInfo('00630786-n', 0), SenseInfo('00630786-n', 0), SenseInfo('00630786-n', 0) ],
"_overseas_a_2_rel" : [ SenseInfo('01037763-a', 1), SenseInfo('01381473-a', 0) ],
"_reach_n_1_rel" : [ SenseInfo('08628921-n', 2), SenseInfo('05125377-n', 2), SenseInfo('00341243-n', 2), SenseInfo('05623628-n', 1), SenseInfo('08628921-n', 2), SenseInfo('05125377-n', 2), SenseInfo('00341243-n', 2), SenseInfo('05623628-n', 1) ],
"_squire_v_1_rel" : [ SenseInfo('02026203-v', 0) ],
"_fall_v_state_rel" : [ SenseInfo('01972298-v', 43), SenseInfo('01970826-v', 21), SenseInfo('00147815-v', 16), SenseInfo('02729963-v', 6), SenseInfo('02756821-v', 4), SenseInfo('02528985-v', 4), SenseInfo('02620213-v', 3), SenseInfo('02611976-v', 3), SenseInfo('02304507-v', 3), SenseInfo('00342443-v', 3), SenseInfo('00151689-v', 3), SenseInfo('02565911-v', 2), SenseInfo('02385153-v', 2), SenseInfo('02358655-v', 2), SenseInfo('02099413-v', 1), SenseInfo('02661015-v', 0), SenseInfo('02566092-v', 0), SenseInfo('02358922-v', 0), SenseInfo('02230056-v', 0), SenseInfo('02229828-v', 0), SenseInfo('02229550-v', 0), SenseInfo('02037839-v', 0), SenseInfo('01984317-v', 0), SenseInfo('01984119-v', 0), SenseInfo('01542668-v', 0), SenseInfo('00561375-v', 0), SenseInfo('00561266-v', 0), SenseInfo('00530177-v', 0), SenseInfo('00360678-v', 0), SenseInfo('00346839-v', 0), SenseInfo('00342314-v', 0), SenseInfo('00342164-v', 0) ],
"_hunter_n_1_rel" : [ SenseInfo('10193026-n', 7), SenseInfo('10193719-n', 0), SenseInfo('09380117-n', 0), SenseInfo('03549350-n', 0) ],
"_handheld_a_1_rel" : [ SenseInfo('03149169-a', 0) ],
"_kinsman_n_1_rel" : [ SenseInfo('10236946-n', 0) ],
"_why+not_x_rel" : [  ],
"_vow_n_1_rel" : [ SenseInfo('07228751-n', 0), SenseInfo('07228751-n', 0) ],
"_beam_v_at_rel" : [ SenseInfo('00029214-v', 5), SenseInfo('02763740-v', 1), SenseInfo('01067380-v', 1), SenseInfo('00973056-v', 1), SenseInfo('02161530-v', 0), SenseInfo('01829747-v', 0) ],
"_scottish_a_1_rel" : [ SenseInfo('03024647-a', 0) ],
"_sheep_n_1_rel" : [ SenseInfo('02411705-n', 14), SenseInfo('10588074-n', 1), SenseInfo('10587894-n', 0) ],
"_marshy_a_1_rel" : [ SenseInfo('02548066-a', 0), SenseInfo('02548066-a', 0), SenseInfo('02548066-a', 0) ],
"_cyclist_n_1_rel" : [ SenseInfo('09986189-n', 8) ],
"_colander_n_1_rel" : [ SenseInfo('03066849-n', 0) ],
"_set_a_1_rel" : [ SenseInfo('01931203-a', 4), SenseInfo('01564603-a', 3), SenseInfo('02126430-a', 2), SenseInfo('01681307-a', 1), SenseInfo('02493300-a', 0), SenseInfo('02129908-a', 0), SenseInfo('01152091-a', 0) ],
"_zigzag_a_1_rel" : [ SenseInfo('02314451-a', 0), SenseInfo('02314451-a', 0) ],
"_come_v_up_rel" : [ SenseInfo('01849221-v', 276), SenseInfo('02005948-v', 235), SenseInfo('00341917-v', 147), SenseInfo('00542120-v', 41), SenseInfo('02625339-v', 40), SenseInfo('00342812-v', 11), SenseInfo('02743921-v', 9), SenseInfo('02743214-v', 7), SenseInfo('02686805-v', 6), SenseInfo('02743565-v', 3), SenseInfo('01839690-v', 3), SenseInfo('02729963-v', 2), SenseInfo('00344886-v', 2), SenseInfo('02645007-v', 1), SenseInfo('02627363-v', 1), SenseInfo('02006709-v', 1), SenseInfo('00723349-v', 1), SenseInfo('02737187-v', 0), SenseInfo('02617567-v', 0), SenseInfo('02197360-v', 0), SenseInfo('00659984-v', 0), SenseInfo('01849221-v', 276), SenseInfo('02005948-v', 235), SenseInfo('00341917-v', 147), SenseInfo('00542120-v', 41), SenseInfo('02625339-v', 40), SenseInfo('00342812-v', 11), SenseInfo('02743921-v', 9), SenseInfo('02743214-v', 7), SenseInfo('02686805-v', 6), SenseInfo('02743565-v', 3), SenseInfo('01839690-v', 3), SenseInfo('02729963-v', 2), SenseInfo('00344886-v', 2), SenseInfo('02645007-v', 1), SenseInfo('02627363-v', 1), SenseInfo('02006709-v', 1), SenseInfo('00723349-v', 1), SenseInfo('02737187-v', 0), SenseInfo('02617567-v', 0), SenseInfo('02197360-v', 0), SenseInfo('00659984-v', 0) ],
"_aloud_a_1_rel" : [  ],
"_accidental_a_1_rel" : [ SenseInfo('01338909-a', 0), SenseInfo('01338909-a', 0), SenseInfo('01338909-a', 0) ],
"_nouveau-riche_n_1_rel" : [ SenseInfo('10740868-n', 0), SenseInfo('10740868-n', 0), SenseInfo('10740868-n', 0), SenseInfo('10740868-n', 0) ],
"_reprimand_v_for_rel" : [ SenseInfo('00823669-v', 2), SenseInfo('00824767-v', 0), SenseInfo('00823669-v', 2), SenseInfo('00824767-v', 0) ],
"_maple_n_1_rel" : [ SenseInfo('12752666-n', 2), SenseInfo('12752205-n', 1) ],
"_carpenter_n_1_rel" : [ SenseInfo('09896685-n', 8) ],
"_bankruptcy_n_1_rel" : [ SenseInfo('14478684-n', 1), SenseInfo('14478433-n', 1), SenseInfo('01186397-n', 0) ],
"_colt_n_1_rel" : [ SenseInfo('02376791-n', 2), SenseInfo('03073296-n', 1) ],
"_put_v_away_rel" : [ SenseInfo('01494310-v', 138), SenseInfo('01493741-v', 98), SenseInfo('00981276-v', 28), SenseInfo('01160370-v', 6), SenseInfo('02271137-v', 3), SenseInfo('00673448-v', 2), SenseInfo('02111499-v', 0), SenseInfo('01706375-v', 0), SenseInfo('00735571-v', 0) ],
"_easy-to-use_a_1_rel" : [  ],
"_quibble_v_with_rel" : [ SenseInfo('00810385-v', 0), SenseInfo('00774056-v', 0), SenseInfo('00810385-v', 0), SenseInfo('00774056-v', 0), SenseInfo('00810385-v', 0), SenseInfo('00774056-v', 0) ],
"_mayan_a_1_rel" : [ SenseInfo('09648309-n', 0), SenseInfo('06919215-n', 0) ],
"no_rel" : [  ],
"_fudge_n_1_rel" : [ SenseInfo('07605474-n', 0) ],
"_austrian_a_1_rel" : [ SenseInfo('02961099-a', 0) ],
"_all+over_p_rel" : [ SenseInfo('00521976-a', 0), SenseInfo('00521976-a', 0) ],
"_half_n_of_rel" : [ SenseInfo('13736799-n', 42), SenseInfo('15257829-n', 0) ],
"_afghani_a_1_rel" : [ SenseInfo('03003928-a', 0) ],
"_tenth_n_of_rel" : [ SenseInfo('13738327-n', 2), SenseInfo('13847858-n', 0), SenseInfo('13738327-n', 2), SenseInfo('13847858-n', 0), SenseInfo('13738327-n', 2), SenseInfo('13847858-n', 0) ],
"_peel_v_1_rel" : [ SenseInfo('01262936-v', 3), SenseInfo('01259951-v', 0), SenseInfo('00049900-v', 0) ],
"_lintel_n_1_rel" : [ SenseInfo('03503233-n', 0) ],
"_sweep_v_up_rel" : [ SenseInfo('01870043-v', 13), SenseInfo('01869563-v', 12), SenseInfo('01393714-v', 5), SenseInfo('02677797-v', 3), SenseInfo('02685390-v', 2), SenseInfo('01393996-v', 1), SenseInfo('01100952-v', 1), SenseInfo('02688403-v', 0), SenseInfo('01593763-v', 0), SenseInfo('01870043-v', 13), SenseInfo('01869563-v', 12), SenseInfo('01393714-v', 5), SenseInfo('02677797-v', 3), SenseInfo('02685390-v', 2), SenseInfo('01393996-v', 1), SenseInfo('01100952-v', 1), SenseInfo('02688403-v', 0), SenseInfo('01593763-v', 0) ],
"_grieve_v_at_rel" : [ SenseInfo('01797347-v', 1), SenseInfo('01797582-v', 0) ],
"_roadside_a_1_rel" : [ SenseInfo('04565233-n', 2) ],
"_marine_n_1_rel" : [ SenseInfo('10294139-n', 1), SenseInfo('10294318-n', 0) ],
"_legal_a_1_rel" : [ SenseInfo('01400562-a', 11), SenseInfo('02754096-a', 5), SenseInfo('02499148-a', 3), SenseInfo('02754197-a', 2), SenseInfo('00852754-a', 0), SenseInfo('01400562-a', 11), SenseInfo('02754096-a', 5), SenseInfo('02499148-a', 3), SenseInfo('02754197-a', 2), SenseInfo('00852754-a', 0) ],
"_invert_v_cause_rel" : [ SenseInfo('00387153-v', 1), SenseInfo('00386965-v', 0), SenseInfo('00386715-v', 0) ],
"_suicide_n_1_rel" : [ SenseInfo('00222485-n', 3), SenseInfo('10673669-n', 0) ],
"_tank_v_1_rel" : [ SenseInfo('02282082-v', 0), SenseInfo('01171563-v', 0), SenseInfo('00185348-v', 0) ],
"_lime_a_1_rel" : [ SenseInfo('14936010-n', 0), SenseInfo('14789885-n', 0), SenseInfo('14702703-n', 0), SenseInfo('12711984-n', 0), SenseInfo('12202936-n', 0), SenseInfo('07749731-n', 0) ],
"_build_v_on_rel" : [ SenseInfo('01654628-v', 123), SenseInfo('00252990-v', 11), SenseInfo('01655505-v', 4), SenseInfo('00447158-v', 1), SenseInfo('02443424-v', 0), SenseInfo('01739099-v', 0), SenseInfo('01685601-v', 0), SenseInfo('00637115-v', 0), SenseInfo('00253277-v', 0), SenseInfo('00226882-v', 0), SenseInfo('01654628-v', 123), SenseInfo('00252990-v', 11), SenseInfo('01655505-v', 4), SenseInfo('00447158-v', 1), SenseInfo('02443424-v', 0), SenseInfo('01739099-v', 0), SenseInfo('01685601-v', 0), SenseInfo('00637115-v', 0), SenseInfo('00253277-v', 0), SenseInfo('00226882-v', 0), SenseInfo('01654628-v', 123), SenseInfo('00252990-v', 11), SenseInfo('01655505-v', 4), SenseInfo('00447158-v', 1), SenseInfo('02443424-v', 0), SenseInfo('01739099-v', 0), SenseInfo('01685601-v', 0), SenseInfo('00637115-v', 0), SenseInfo('00253277-v', 0), SenseInfo('00226882-v', 0) ],
"_sphincter_n_1_rel" : [ SenseInfo('05570839-n', 0) ],
"_saw_n_1_rel" : [ SenseInfo('07153838-n', 0), SenseInfo('04140064-n', 0), SenseInfo('03996145-n', 0) ],
"_sector_n_1_rel" : [ SenseInfo('13875027-n', 5), SenseInfo('07966719-n', 4), SenseInfo('05853100-n', 3), SenseInfo('13626240-n', 0), SenseInfo('08648658-n', 0), SenseInfo('04165551-n', 0) ],
"_hard-to-read_a_1_rel" : [  ],
"_belief_n_in_rel" : [ SenseInfo('05941423-n', 19), SenseInfo('05916739-n', 6), SenseInfo('05941423-n', 19), SenseInfo('05916739-n', 6), SenseInfo('05941423-n', 19), SenseInfo('05916739-n', 6), SenseInfo('05941423-n', 19), SenseInfo('05916739-n', 6) ],
"_sitting_n_1_rel" : [ SenseInfo('00344421-n', 1), SenseInfo('00344259-n', 1), SenseInfo('08417920-n', 0), SenseInfo('07146190-n', 0) ],
"_knack_n_1_rel" : [ SenseInfo('05624254-n', 2) ],
"_financeman_n_1_rel" : [  ],
"_hatch_v_cause_rel" : [ SenseInfo('00063095-v', 2), SenseInfo('01634142-v', 1), SenseInfo('01682234-v', 0), SenseInfo('01276593-v', 0), SenseInfo('00060185-v', 0) ],
"_muslim_a_1_rel" : [ SenseInfo('02923510-a', 0) ],
"_massif_n_1_rel" : [ SenseInfo('09348460-n', 0) ],
"_distance_v_from_rel" : [ SenseInfo('02683127-v', 0), SenseInfo('02081795-v', 0), SenseInfo('02683127-v', 0), SenseInfo('02081795-v', 0) ],
"_shell_n_1_rel" : [ SenseInfo('04190464-n', 14), SenseInfo('14758536-n', 3), SenseInfo('01903756-n', 2), SenseInfo('11683556-n', 0), SenseInfo('09432430-n', 0), SenseInfo('09432283-n', 0), SenseInfo('04190997-n', 0), SenseInfo('04190747-n', 0), SenseInfo('03959701-n', 0), SenseInfo('01904182-n', 0) ],
"_even_x_deg_rel" : [ SenseInfo('00017445-r', 394), SenseInfo('00018043-r', 13), SenseInfo('00017639-r', 6), SenseInfo('00913387-a', 4), SenseInfo('00891170-a', 3), SenseInfo('00909545-a', 2), SenseInfo('15166462-n', 0), SenseInfo('00018189-r', 0), SenseInfo('02372520-a', 0), SenseInfo('02302187-a', 0), SenseInfo('00892243-a', 0), SenseInfo('01307142-v', 0), SenseInfo('00416880-v', 0), SenseInfo('00416705-v', 0), SenseInfo('00017445-r', 394), SenseInfo('00018043-r', 13), SenseInfo('00017639-r', 6), SenseInfo('00913387-a', 4), SenseInfo('00891170-a', 3), SenseInfo('00909545-a', 2), SenseInfo('15166462-n', 0), SenseInfo('00018189-r', 0), SenseInfo('02372520-a', 0), SenseInfo('02302187-a', 0), SenseInfo('00892243-a', 0), SenseInfo('01307142-v', 0), SenseInfo('00416880-v', 0), SenseInfo('00416705-v', 0) ],
"_o-post_n_1_rel" : [  ],
"_throw_v_off_rel" : [ SenseInfo('01508368-v', 53), SenseInfo('02097204-v', 9), SenseInfo('01513430-v', 7), SenseInfo('01499265-v', 7), SenseInfo('01060317-v', 6), SenseInfo('01510173-v', 5), SenseInfo('01632897-v', 4), SenseInfo('02097341-v', 2), SenseInfo('01791232-v', 2), SenseInfo('01067664-v', 2), SenseInfo('01733477-v', 1), SenseInfo('01663443-v', 0), SenseInfo('01527754-v', 0), SenseInfo('01437011-v', 0), SenseInfo('00621734-v', 0) ],
"_moon_v_1_rel" : [ SenseInfo('02418205-v', 0), SenseInfo('02417908-v', 0), SenseInfo('02141840-v', 0) ],
"_trade-off_n_1_rel" : [ SenseInfo('01166760-n', 0), SenseInfo('01166760-n', 0), SenseInfo('01166760-n', 0) ],
"_resistible_a_1_rel" : [ SenseInfo('01989012-a', 0) ],
"_change_v_from-to_rel" : [ SenseInfo('00126264-v', 57), SenseInfo('00109660-v', 54), SenseInfo('00123170-v', 13), SenseInfo('00550117-v', 7), SenseInfo('00169458-v', 6), SenseInfo('00161225-v', 5), SenseInfo('02257370-v', 3), SenseInfo('02088241-v', 3), SenseInfo('00551210-v', 0), SenseInfo('00163251-v', 0), SenseInfo('00126264-v', 57), SenseInfo('00109660-v', 54), SenseInfo('00123170-v', 13), SenseInfo('00550117-v', 7), SenseInfo('00169458-v', 6), SenseInfo('00161225-v', 5), SenseInfo('02257370-v', 3), SenseInfo('02088241-v', 3), SenseInfo('00551210-v', 0), SenseInfo('00163251-v', 0) ],
"_bent_n_1_rel" : [ SenseInfo('06199702-n', 2), SenseInfo('12106786-n', 0), SenseInfo('08570533-n', 0), SenseInfo('05624254-n', 0) ],
"_seal_v_1_rel" : [ SenseInfo('01354006-v', 3), SenseInfo('01353405-v', 3), SenseInfo('00698732-v', 2), SenseInfo('01356582-v', 0), SenseInfo('01269008-v', 0), SenseInfo('01143498-v', 0) ],
"_fireplace_n_1_rel" : [ SenseInfo('03346455-n', 5) ],
"_hew_v_out_rel" : [ SenseInfo('01260685-v', 0), SenseInfo('01260428-v', 0) ],
"_claudication_n_1_rel" : [ SenseInfo('14549937-n', 0) ],
"_bce_x_rel" : [ SenseInfo('00002296-r', 0), SenseInfo('00002296-r', 0), SenseInfo('00002296-r', 0), SenseInfo('00002296-r', 0), SenseInfo('00002296-r', 0), SenseInfo('00002296-r', 0), SenseInfo('00002296-r', 0) ],
"_incredible_a_to_rel" : [ SenseInfo('00645493-a', 10), SenseInfo('00645493-a', 10), SenseInfo('00645493-a', 10) ],
"_brood_n_1_rel" : [ SenseInfo('07990824-n', 10) ],
"_interact_v_1_rel" : [ SenseInfo('02376958-v', 2) ],
"_uncultivated_a_1_rel" : [ SenseInfo('01833791-a', 0), SenseInfo('01949740-a', 0), SenseInfo('01334075-a', 0), SenseInfo('01833791-a', 0), SenseInfo('01949740-a', 0), SenseInfo('01334075-a', 0) ],
"_kilometer+2_n_1_rel" : [  ],
"_mischievous_a_1_rel" : [ SenseInfo('02122715-a', 1), SenseInfo('01162633-a', 0) ],
"_reactive_a_1_rel" : [ SenseInfo('01928608-a', 0), SenseInfo('02105176-a', 0) ],
"_converse_a_1_rel" : [ SenseInfo('02382762-a', 0), SenseInfo('00201961-a', 0), SenseInfo('02382762-a', 0), SenseInfo('00201961-a', 0) ],
"_honor_v_1_rel" : [ SenseInfo('02546075-v', 28), SenseInfo('02457233-v', 3), SenseInfo('02237631-v', 0), SenseInfo('02546075-v', 28), SenseInfo('02457233-v', 3), SenseInfo('02237631-v', 0), SenseInfo('02546075-v', 28), SenseInfo('02457233-v', 3), SenseInfo('02237631-v', 0), SenseInfo('02546075-v', 28), SenseInfo('02457233-v', 3), SenseInfo('02237631-v', 0) ],
"_amphibian_a_1_rel" : [ SenseInfo('02831979-a', 0) ],
"_translate_v_to_rel" : [ SenseInfo('00959827-v', 10), SenseInfo('00383542-v', 7), SenseInfo('00593852-v', 4), SenseInfo('01436290-v', 2), SenseInfo('00522441-v', 2), SenseInfo('02753100-v', 0), SenseInfo('02728142-v', 0), SenseInfo('02103925-v', 0), SenseInfo('00961947-v', 0), SenseInfo('00919608-v', 0), SenseInfo('00959827-v', 10), SenseInfo('00383542-v', 7), SenseInfo('00593852-v', 4), SenseInfo('01436290-v', 2), SenseInfo('00522441-v', 2), SenseInfo('02753100-v', 0), SenseInfo('02728142-v', 0), SenseInfo('02103925-v', 0), SenseInfo('00961947-v', 0), SenseInfo('00919608-v', 0) ],
"_patron_n_1_rel" : [ SenseInfo('10407726-n', 4), SenseInfo('10408324-n', 0), SenseInfo('10407954-n', 0) ],
"_dream_v_of_rel" : [ SenseInfo('01637633-v', 15), SenseInfo('02118242-v', 11) ],
"_rig_n_1_rel" : [ SenseInfo('04091097-n', 2), SenseInfo('04467665-n', 0), SenseInfo('04091247-n', 0), SenseInfo('03859958-n', 0), SenseInfo('03351434-n', 0), SenseInfo('02968473-n', 0), SenseInfo('00780148-n', 0) ],
"_botany_n_1_rel" : [ SenseInfo('08436759-n', 0), SenseInfo('06066555-n', 0) ],
"_pidgin_n_1_rel" : [ SenseInfo('06905680-n', 1) ],
"_peek_n_at_rel" : [ SenseInfo('00878221-n', 0) ],
"_robustness_n_1_rel" : [ SenseInfo('05031012-n', 1), SenseInfo('04920000-n', 0) ],
"_in+front+of_p_rel" : [  ],
"_help_n_1_rel" : [ SenseInfo('01207609-n', 20), SenseInfo('09815790-n', 3), SenseInfo('05154908-n', 1), SenseInfo('05149832-n', 1) ],
"_champagne_n_1_rel" : [ SenseInfo('07893642-n', 6), SenseInfo('08941535-n', 0) ],
"_perishable_a_1_rel" : [ SenseInfo('01753365-a', 0) ],
"_pork_n_1_rel" : [ SenseInfo('07668702-n', 4), SenseInfo('13358000-n', 0) ],
"_pier_n_1_rel" : [ SenseInfo('03933529-n', 1), SenseInfo('03934042-n', 0), SenseInfo('03933933-n', 0) ],
"_pavement_n_1_rel" : [ SenseInfo('03900750-n', 2), SenseInfo('14977504-n', 1), SenseInfo('04215402-n', 1) ],
"_gravestone_n_1_rel" : [ SenseInfo('03455488-n', 1) ],
"_spacecraft_n_1_rel" : [ SenseInfo('04264914-n', 0) ],
"_mucosa_n_1_rel" : [ SenseInfo('05327134-n', 5) ],
"_megapixel_n_of_rel" : [  ],
"_toolkit_n_1_rel" : [  ],
"_frighten_v_off_rel" : [ SenseInfo('01779165-v', 10), SenseInfo('01780104-v', 1) ],
"_general_a_1_rel" : [ SenseInfo('01101391-a', 87), SenseInfo('00783840-a', 3), SenseInfo('00487198-a', 1), SenseInfo('01426077-a', 0), SenseInfo('01839663-a', 0), SenseInfo('00527188-a', 0), SenseInfo('01101391-a', 87), SenseInfo('00783840-a', 3), SenseInfo('00487198-a', 1), SenseInfo('01426077-a', 0), SenseInfo('01839663-a', 0), SenseInfo('00527188-a', 0), SenseInfo('01101391-a', 87), SenseInfo('00783840-a', 3), SenseInfo('00487198-a', 1), SenseInfo('01426077-a', 0), SenseInfo('01839663-a', 0), SenseInfo('00527188-a', 0), SenseInfo('01101391-a', 87), SenseInfo('00783840-a', 3), SenseInfo('00487198-a', 1), SenseInfo('01426077-a', 0), SenseInfo('01839663-a', 0), SenseInfo('00527188-a', 0) ],
"_walk_v_over_rel" : [ SenseInfo('01904930-v', 184), SenseInfo('01907076-v', 3), SenseInfo('01113473-v', 3), SenseInfo('01912893-v', 1), SenseInfo('01140654-v', 1), SenseInfo('02518839-v', 0), SenseInfo('02470518-v', 0), SenseInfo('01959776-v', 0), SenseInfo('01906823-v', 0), SenseInfo('01882170-v', 0) ],
"_disposal_n_1_rel" : [ SenseInfo('05198622-n', 4), SenseInfo('01135952-n', 1), SenseInfo('00043609-n', 1), SenseInfo('03212114-n', 0) ],
"_royal_a_1_rel" : [ SenseInfo('02789579-a', 4), SenseInfo('02789798-a', 1), SenseInfo('01592509-a', 0), SenseInfo('01591394-a', 0), SenseInfo('00654685-a', 0) ],
"_ramp_n_1_rel" : [ SenseInfo('04051549-n', 2), SenseInfo('12435338-n', 0), SenseInfo('04615728-n', 0) ],
"_playstation_n_1_rel" : [  ],
"_peace_n_1_rel" : [ SenseInfo('13970236-n', 13), SenseInfo('13969700-n', 6), SenseInfo('07515790-n', 6), SenseInfo('14539524-n', 1), SenseInfo('06773976-n', 0) ],
"_encouraging_a_for_rel" : [ SenseInfo('00866471-a', 0), SenseInfo('02356244-a', 0), SenseInfo('00866471-a', 0), SenseInfo('02356244-a', 0), SenseInfo('00866471-a', 0), SenseInfo('02356244-a', 0) ],
"_minute_n_1_rel" : [ SenseInfo('15234764-n', 83), SenseInfo('15246853-n', 8), SenseInfo('15244650-n', 1), SenseInfo('13611567-n', 0), SenseInfo('06506315-n', 0), SenseInfo('05131023-n', 0), SenseInfo('15234764-n', 83), SenseInfo('15246853-n', 8), SenseInfo('15244650-n', 1), SenseInfo('13611567-n', 0), SenseInfo('06506315-n', 0), SenseInfo('05131023-n', 0), SenseInfo('15234764-n', 83), SenseInfo('15246853-n', 8), SenseInfo('15244650-n', 1), SenseInfo('13611567-n', 0), SenseInfo('06506315-n', 0), SenseInfo('05131023-n', 0) ],
"_aid_v_1_rel" : [ SenseInfo('02547586-v', 36), SenseInfo('00082081-v', 1) ],
"_peel_n_1_rel" : [ SenseInfo('11228039-n', 0), SenseInfo('07738353-n', 0) ],
"_keep_v_on-i_rel" : [ SenseInfo('02681795-v', 206), SenseInfo('02684924-v', 39), SenseInfo('02202384-v', 32), SenseInfo('02450505-v', 22), SenseInfo('02578872-v', 10), SenseInfo('00732552-v', 9), SenseInfo('02202928-v', 8), SenseInfo('01065877-v', 4), SenseInfo('02651853-v', 3), SenseInfo('02410175-v', 3), SenseInfo('01184625-v', 3), SenseInfo('02734800-v', 2), SenseInfo('02578510-v', 2), SenseInfo('02422663-v', 2), SenseInfo('02733122-v', 1), SenseInfo('02652016-v', 0), SenseInfo('02283716-v', 0), SenseInfo('02204094-v', 0), SenseInfo('02203844-v', 0), SenseInfo('02203168-v', 0), SenseInfo('01302019-v', 0), SenseInfo('00212414-v', 0) ],
"_scent_v_1_rel" : [ SenseInfo('02125641-v', 0), SenseInfo('02125223-v', 0), SenseInfo('00043480-v', 0) ],
"_among_p_rel" : [  ],
"_dumpling_n_1_rel" : [ SenseInfo('07702193-n', 0), SenseInfo('07611148-n', 0) ],
"_screen_n_1_rel" : [ SenseInfo('04152829-n', 4), SenseInfo('02851099-n', 3), SenseInfo('04152593-n', 2), SenseInfo('04151940-n', 2), SenseInfo('04151581-n', 1), SenseInfo('08068457-n', 0), SenseInfo('04216634-n', 0), SenseInfo('04153025-n', 0), SenseInfo('04152387-n', 0) ],
"_press_v_on_rel" : [ SenseInfo('01447257-v', 32), SenseInfo('00765649-v', 7), SenseInfo('02646064-v', 2), SenseInfo('01390616-v', 2), SenseInfo('01387786-v', 2), SenseInfo('02024367-v', 1), SenseInfo('01754105-v', 1), SenseInfo('02722782-v', 0), SenseInfo('02589576-v', 0), SenseInfo('01662614-v', 0), SenseInfo('01447632-v', 0), SenseInfo('01390833-v', 0), SenseInfo('01150370-v', 0), SenseInfo('00759657-v', 0) ],
"_publication_n_of_rel" : [ SenseInfo('06589574-n', 6), SenseInfo('01103614-n', 5), SenseInfo('01102436-n', 0), SenseInfo('01101958-n', 0) ],
"_thorn_n_1_rel" : [ SenseInfo('05831784-n', 1), SenseInfo('13089631-n', 0), SenseInfo('06840442-n', 0) ]
}
